// Note: Some Emscripten settings will significantly limit the speed of the generated code.
// Note: Some Emscripten settings may limit the speed of the generated code.
// TODO: " u s e   s t r i c t ";

try {
  this['Module'] = Module;
} catch(e) {
  this['Module'] = Module = {};
}

// The environment setup code below is customized to use Module.
// *** Environment setup code ***
var ENVIRONMENT_IS_NODE = typeof process === 'object';
var ENVIRONMENT_IS_WEB = typeof window === 'object';
var ENVIRONMENT_IS_WORKER = typeof importScripts === 'function';
var ENVIRONMENT_IS_SHELL = !ENVIRONMENT_IS_WEB && !ENVIRONMENT_IS_NODE && !ENVIRONMENT_IS_WORKER;

if (ENVIRONMENT_IS_NODE) {
  // Expose functionality in the same simple way that the shells work
  // Note that we pollute the global namespace here, otherwise we break in node
  Module['print'] = function(x) {
    process['stdout'].write(x + '\n');
  };
  Module['printErr'] = function(x) {
    process['stderr'].write(x + '\n');
  };

  var nodeFS = require('fs');
  var nodePath = require('path');

  Module['read'] = function(filename) {
    filename = nodePath['normalize'](filename);
    var ret = nodeFS['readFileSync'](filename).toString();
    // The path is absolute if the normalized version is the same as the resolved.
    if (!ret && filename != nodePath['resolve'](filename)) {
      filename = path.join(__dirname, '..', 'src', filename);
      ret = nodeFS['readFileSync'](filename).toString();
    }
    return ret;
  };

  Module['load'] = function(f) {
    globalEval(read(f));
  };

  if (!Module['arguments']) {
    Module['arguments'] = process['argv'].slice(2);
  }
} else if (ENVIRONMENT_IS_SHELL) {
  Module['print'] = print;
  if (typeof printErr != 'undefined') Module['printErr'] = printErr; // not present in v8 or older sm

  // Polyfill over SpiderMonkey/V8 differences
  if (typeof read != 'undefined') {
    Module['read'] = read;
  } else {
    Module['read'] = function(f) { snarf(f) };
  }

  if (!Module['arguments']) {
    if (typeof scriptArgs != 'undefined') {
      Module['arguments'] = scriptArgs;
    } else if (typeof arguments != 'undefined') {
      Module['arguments'] = arguments;
    }
  }
} else if (ENVIRONMENT_IS_WEB) {
  if (!Module['print']) {
    Module['print'] = function(x) {
      console.log(x);
    };
  }

  if (!Module['printErr']) {
    Module['printErr'] = function(x) {
      console.log(x);
    };
  }

  Module['read'] = function(url) {
    var xhr = new XMLHttpRequest();
    xhr.open('GET', url, false);
    xhr.send(null);
    return xhr.responseText;
  };

  if (!Module['arguments']) {
    if (typeof arguments != 'undefined') {
      Module['arguments'] = arguments;
    }
  }
} else if (ENVIRONMENT_IS_WORKER) {
  // We can do very little here...

  Module['load'] = importScripts;

} else {
  throw 'Unknown runtime environment. Where are we?';
}

function globalEval(x) {
  eval.call(null, x);
}
if (!Module['load'] == 'undefined' && Module['read']) {
  Module['load'] = function(f) {
    globalEval(Module['read'](f));
  };
}
if (!Module['print']) {
  Module['print'] = function(){};
}
if (!Module['printErr']) {
  Module['printErr'] = Module['print'];
}
if (!Module['arguments']) {
  Module['arguments'] = [];
}
// *** Environment setup code ***

// Closure helpers
Module.print = Module['print'];
Module.printErr = Module['printErr'];

// Callbacks
if (!Module['preRun']) Module['preRun'] = [];
if (!Module['postRun']) Module['postRun'] = [];

  
// === Auto-generated preamble library stuff ===

//========================================
// Runtime code shared with compiler
//========================================

var Runtime = {
  stackSave: function () {
    return STACKTOP;
  },
  stackRestore: function (stackTop) {
    STACKTOP = stackTop;
  },
  forceAlign: function (target, quantum) {
    quantum = quantum || 4;
    if (quantum == 1) return target;
    if (isNumber(target) && isNumber(quantum)) {
      return Math.ceil(target/quantum)*quantum;
    } else if (isNumber(quantum) && isPowerOfTwo(quantum)) {
      var logg = log2(quantum);
      return '((((' +target + ')+' + (quantum-1) + ')>>' + logg + ')<<' + logg + ')';
    }
    return 'Math.ceil((' + target + ')/' + quantum + ')*' + quantum;
  },
  isNumberType: function (type) {
    return type in Runtime.INT_TYPES || type in Runtime.FLOAT_TYPES;
  },
  isPointerType: function isPointerType(type) {
  return type[type.length-1] == '*';
},
  isStructType: function isStructType(type) {
  if (isPointerType(type)) return false;
  if (/^\[\d+\ x\ (.*)\]/.test(type)) return true; // [15 x ?] blocks. Like structs
  if (/<?{ ?[^}]* ?}>?/.test(type)) return true; // { i32, i8 } etc. - anonymous struct types
  // See comment in isStructPointerType()
  return type[0] == '%';
},
  INT_TYPES: {"i1":0,"i8":0,"i16":0,"i32":0,"i64":0},
  FLOAT_TYPES: {"float":0,"double":0},
  bitshift64: function (low, high, op, bits) {
    var ander = Math.pow(2, bits)-1;
    if (bits < 32) {
      switch (op) {
        case 'shl':
          return [low << bits, (high << bits) | ((low&(ander << (32 - bits))) >>> (32 - bits))];
        case 'ashr':
          return [(((low >>> bits ) | ((high&ander) << (32 - bits))) >> 0) >>> 0, (high >> bits) >>> 0];
        case 'lshr':
          return [((low >>> bits) | ((high&ander) << (32 - bits))) >>> 0, high >>> bits];
      }
    } else if (bits == 32) {
      switch (op) {
        case 'shl':
          return [0, low];
        case 'ashr':
          return [high, (high|0) < 0 ? ander : 0];
        case 'lshr':
          return [high, 0];
      }
    } else { // bits > 32
      switch (op) {
        case 'shl':
          return [0, low << (bits - 32)];
        case 'ashr':
          return [(high >> (bits - 32)) >>> 0, (high|0) < 0 ? ander : 0];
        case 'lshr':
          return [high >>>  (bits - 32) , 0];
      }
    }
    abort('unknown bitshift64 op: ' + [value, op, bits]);
  },
  or64: function (x, y) {
    var l = (x | 0) | (y | 0);
    var h = (Math.round(x / 4294967296) | Math.round(y / 4294967296)) * 4294967296;
    return l + h;
  },
  and64: function (x, y) {
    var l = (x | 0) & (y | 0);
    var h = (Math.round(x / 4294967296) & Math.round(y / 4294967296)) * 4294967296;
    return l + h;
  },
  xor64: function (x, y) {
    var l = (x | 0) ^ (y | 0);
    var h = (Math.round(x / 4294967296) ^ Math.round(y / 4294967296)) * 4294967296;
    return l + h;
  },
  getNativeTypeSize: function (type, quantumSize) {
    if (Runtime.QUANTUM_SIZE == 1) return 1;
    var size = {
      '%i1': 1,
      '%i8': 1,
      '%i16': 2,
      '%i32': 4,
      '%i64': 8,
      "%float": 4,
      "%double": 8
    }['%'+type]; // add '%' since float and double confuse Closure compiler as keys, and also spidermonkey as a compiler will remove 's from '_i8' etc
    if (!size) {
      if (type[type.length-1] == '*') {
        size = Runtime.QUANTUM_SIZE; // A pointer
      } else if (type[0] == 'i') {
        var bits = parseInt(type.substr(1));
        assert(bits % 8 == 0);
        size = bits/8;
      }
    }
    return size;
  },
  getNativeFieldSize: function (type) {
    return Math.max(Runtime.getNativeTypeSize(type), Runtime.QUANTUM_SIZE);
  },
  dedup: function dedup(items, ident) {
  var seen = {};
  if (ident) {
    return items.filter(function(item) {
      if (seen[item[ident]]) return false;
      seen[item[ident]] = true;
      return true;
    });
  } else {
    return items.filter(function(item) {
      if (seen[item]) return false;
      seen[item] = true;
      return true;
    });
  }
},
  set: function set() {
  var args = typeof arguments[0] === 'object' ? arguments[0] : arguments;
  var ret = {};
  for (var i = 0; i < args.length; i++) {
    ret[args[i]] = 0;
  }
  return ret;
},
  calculateStructAlignment: function calculateStructAlignment(type) {
    type.flatSize = 0;
    type.alignSize = 0;
    var diffs = [];
    var prev = -1;
    type.flatIndexes = type.fields.map(function(field) {
      var size, alignSize;
      if (Runtime.isNumberType(field) || Runtime.isPointerType(field)) {
        size = Runtime.getNativeTypeSize(field); // pack char; char; in structs, also char[X]s.
        alignSize = size;
      } else if (Runtime.isStructType(field)) {
        size = Types.types[field].flatSize;
        alignSize = Types.types[field].alignSize;
      } else {
        throw 'Unclear type in struct: ' + field + ', in ' + type.name_ + ' :: ' + dump(Types.types[type.name_]);
      }
      alignSize = type.packed ? 1 : Math.min(alignSize, Runtime.QUANTUM_SIZE);
      type.alignSize = Math.max(type.alignSize, alignSize);
      var curr = Runtime.alignMemory(type.flatSize, alignSize); // if necessary, place this on aligned memory
      type.flatSize = curr + size;
      if (prev >= 0) {
        diffs.push(curr-prev);
      }
      prev = curr;
      return curr;
    });
    type.flatSize = Runtime.alignMemory(type.flatSize, type.alignSize);
    if (diffs.length == 0) {
      type.flatFactor = type.flatSize;
    } else if (Runtime.dedup(diffs).length == 1) {
      type.flatFactor = diffs[0];
    }
    type.needsFlattening = (type.flatFactor != 1);
    return type.flatIndexes;
  },
  generateStructInfo: function (struct, typeName, offset) {
    var type, alignment;
    if (typeName) {
      offset = offset || 0;
      type = (typeof Types === 'undefined' ? Runtime.typeInfo : Types.types)[typeName];
      if (!type) return null;
      if (type.fields.length != struct.length) {
        printErr('Number of named fields must match the type for ' + typeName + ': possibly duplicate struct names. Cannot return structInfo');
        return null;
      }
      alignment = type.flatIndexes;
    } else {
      var type = { fields: struct.map(function(item) { return item[0] }) };
      alignment = Runtime.calculateStructAlignment(type);
    }
    var ret = {
      __size__: type.flatSize
    };
    if (typeName) {
      struct.forEach(function(item, i) {
        if (typeof item === 'string') {
          ret[item] = alignment[i] + offset;
        } else {
          // embedded struct
          var key;
          for (var k in item) key = k;
          ret[key] = Runtime.generateStructInfo(item[key], type.fields[i], alignment[i]);
        }
      });
    } else {
      struct.forEach(function(item, i) {
        ret[item[1]] = alignment[i];
      });
    }
    return ret;
  },
  addFunction: function (func) {
    var ret = FUNCTION_TABLE.length;
    FUNCTION_TABLE.push(func);
    FUNCTION_TABLE.push(0);
    return ret;
  },
  warnOnce: function (text) {
    if (!Runtime.warnOnce.shown) Runtime.warnOnce.shown = {};
    if (!Runtime.warnOnce.shown[text]) {
      Runtime.warnOnce.shown[text] = 1;
      Module.printErr(text);
    }
  },
  funcWrappers: {},
  getFuncWrapper: function (func) {
    if (!Runtime.funcWrappers[func]) {
      Runtime.funcWrappers[func] = function() {
        FUNCTION_TABLE[func].apply(null, arguments);
      };
    }
    return Runtime.funcWrappers[func];
  },
  UTF8Processor: function () {
    var buffer = [];
    var needed = 0;
    this.processCChar = function (code) {
      code = code & 0xff;
      if (needed) {
        buffer.push(code);
        needed--;
      }
      if (buffer.length == 0) {
        if (code < 128) return String.fromCharCode(code);
        buffer.push(code);
        if (code > 191 && code < 224) {
          needed = 1;
        } else {
          needed = 2;
        }
        return '';
      }
      if (needed > 0) return '';
      var c1 = buffer[0];
      var c2 = buffer[1];
      var c3 = buffer[2];
      var ret;
      if (c1 > 191 && c1 < 224) {
        ret = String.fromCharCode(((c1 & 31) << 6) | (c2 & 63));
      } else {
        ret = String.fromCharCode(((c1 & 15) << 12) | ((c2 & 63) << 6) | (c3 & 63));
      }
      buffer.length = 0;
      return ret;
    }
    this.processJSString = function(string) {
      string = unescape(encodeURIComponent(string));
      var ret = [];
      for (var i = 0; i < string.length; i++) {
        ret.push(string.charCodeAt(i));
      }
      return ret;
    }
  },
  stackAlloc: function stackAlloc(size) { var ret = STACKTOP;STACKTOP += size;STACKTOP = ((((STACKTOP)+3)>>2)<<2);assert(STACKTOP < STACK_ROOT + STACK_MAX, "Ran out of stack"); return ret; },
  staticAlloc: function staticAlloc(size) { var ret = STATICTOP;STATICTOP += size;STATICTOP = ((((STATICTOP)+3)>>2)<<2); if (STATICTOP >= TOTAL_MEMORY) enlargeMemory();; return ret; },
  alignMemory: function alignMemory(size,quantum) { var ret = size = Math.ceil((size)/(quantum ? quantum : 4))*(quantum ? quantum : 4); return ret; },
  makeBigInt: function makeBigInt(low,high,unsigned) { var ret = (unsigned ? (((low)>>>0)+(((high)>>>0)*4294967296)) : (((low)>>>0)+(((high)|0)*4294967296))); return ret; },
  QUANTUM_SIZE: 4,
  __dummy__: 0
}



var CorrectionsMonitor = {
  MAX_ALLOWED: 0, // XXX
  corrections: 0,
  sigs: {},

  note: function(type, succeed, sig) {
    if (!succeed) {
      this.corrections++;
      if (this.corrections >= this.MAX_ALLOWED) abort('\n\nToo many corrections!');
    }
  },

  print: function() {
  }
};





//========================================
// Runtime essentials
//========================================

var __THREW__ = false; // Used in checking for thrown exceptions.

var ABORT = false;

var undef = 0;
// tempInt is used for 32-bit signed values or smaller. tempBigInt is used
// for 32-bit unsigned values or more than 32 bits. TODO: audit all uses of tempInt
var tempValue, tempInt, tempBigInt, tempInt2, tempBigInt2, tempPair, tempBigIntI, tempBigIntR, tempBigIntS, tempBigIntP, tempBigIntD;
var tempI64, tempI64b;

function abort(text) {
  Module.print(text + ':\n' + (new Error).stack);
  ABORT = true;
  throw "Assertion: " + text;
}

function assert(condition, text) {
  if (!condition) {
    abort('Assertion failed: ' + text);
  }
}

var globalScope = this;

// C calling interface. A convenient way to call C functions (in C files, or
// defined with extern "C").
//
// Note: LLVM optimizations can inline and remove functions, after which you will not be
//       able to call them. Adding
//
//         __attribute__((used))
//
//       to the function definition will prevent that.
//
// Note: Closure optimizations will minify function names, making
//       functions no longer callable. If you run closure (on by default
//       in -O2 and above), you should export the functions you will call
//       by calling emcc with something like
//
//         -s EXPORTED_FUNCTIONS='["_func1","_func2"]'
//
// @param ident      The name of the C function (note that C++ functions will be name-mangled - use extern "C")
// @param returnType The return type of the function, one of the JS types 'number', 'string' or 'array' (use 'number' for any C pointer, and
//                   'array' for JavaScript arrays and typed arrays).
// @param argTypes   An array of the types of arguments for the function (if there are no arguments, this can be ommitted). Types are as in returnType,
//                   except that 'array' is not possible (there is no way for us to know the length of the array)
// @param args       An array of the arguments to the function, as native JS values (as in returnType)
//                   Note that string arguments will be stored on the stack (the JS string will become a C string on the stack).
// @return           The return value, as a native JS value (as in returnType)
function ccall(ident, returnType, argTypes, args) {
  var stack = 0;
  function toC(value, type) {
    if (type == 'string') {
      if (value === null || value === undefined || value === 0) return 0; // null string
      if (!stack) stack = Runtime.stackSave();
      var ret = Runtime.stackAlloc(value.length+1);
      writeStringToMemory(value, ret);
      return ret;
    } else if (type == 'array') {
      if (!stack) stack = Runtime.stackSave();
      var ret = Runtime.stackAlloc(value.length);
      writeArrayToMemory(value, ret);
      return ret;
    }
    return value;
  }
  function fromC(value, type) {
    if (type == 'string') {
      return Pointer_stringify(value);
    }
    assert(type != 'array');
    return value;
  }
  try {
    var func = eval('_' + ident);
  } catch(e) {
    try {
      func = globalScope['Module']['_' + ident]; // closure exported function
    } catch(e) {}
  }
  assert(func, 'Cannot call unknown function ' + ident + ' (perhaps LLVM optimizations or closure removed it?)');
  var i = 0;
  var cArgs = args ? args.map(function(arg) {
    return toC(arg, argTypes[i++]);
  }) : [];
  var ret = fromC(func.apply(null, cArgs), returnType);
  if (stack) Runtime.stackRestore(stack);
  return ret;
}
Module["ccall"] = ccall;

// Returns a native JS wrapper for a C function. This is similar to ccall, but
// returns a function you can call repeatedly in a normal way. For example:
//
//   var my_function = cwrap('my_c_function', 'number', ['number', 'number']);
//   alert(my_function(5, 22));
//   alert(my_function(99, 12));
//
function cwrap(ident, returnType, argTypes) {
  // TODO: optimize this, eval the whole function once instead of going through ccall each time
  return function() {
    return ccall(ident, returnType, argTypes, Array.prototype.slice.call(arguments));
  }
}
Module["cwrap"] = cwrap;

// Sets a value in memory in a dynamic way at run-time. Uses the
// type data. This is the same as makeSetValue, except that
// makeSetValue is done at compile-time and generates the needed
// code then, whereas this function picks the right code at
// run-time.
// Note that setValue and getValue only do *aligned* writes and reads!
// Note that ccall uses JS types as for defining types, while setValue and
// getValue need LLVM types ('i8', 'i32') - this is a lower-level operation
function setValue(ptr, value, type, noSafe) {
  type = type || 'i8';
  if (type[type.length-1] === '*') type = 'i32'; // pointers are 32-bit
    switch(type) {
      case 'i1': HEAP8[(ptr)]=value; break;
      case 'i8': HEAP8[(ptr)]=value; break;
      case 'i16': HEAP16[((ptr)>>1)]=value; break;
      case 'i32': HEAP32[((ptr)>>2)]=value; break;
      case 'i64': HEAP32[((ptr)>>2)]=value; break;
      case 'float': HEAPF32[((ptr)>>2)]=value; break;
      case 'double': (tempDoubleF64[0]=value,HEAP32[((ptr)>>2)]=tempDoubleI32[0],HEAP32[(((ptr)+(4))>>2)]=tempDoubleI32[1]); break;
      default: abort('invalid type for setValue: ' + type);
    }
}
Module['setValue'] = setValue;

// Parallel to setValue.
function getValue(ptr, type, noSafe) {
  type = type || 'i8';
  if (type[type.length-1] === '*') type = 'i32'; // pointers are 32-bit
    switch(type) {
      case 'i1': return HEAP8[(ptr)];
      case 'i8': return HEAP8[(ptr)];
      case 'i16': return HEAP16[((ptr)>>1)];
      case 'i32': return HEAP32[((ptr)>>2)];
      case 'i64': return HEAP32[((ptr)>>2)];
      case 'float': return HEAPF32[((ptr)>>2)];
      case 'double': return (tempDoubleI32[0]=HEAP32[((ptr)>>2)],tempDoubleI32[1]=HEAP32[(((ptr)+(4))>>2)],tempDoubleF64[0]);
      default: abort('invalid type for setValue: ' + type);
    }
  return null;
}
Module['getValue'] = getValue;

var ALLOC_NORMAL = 0; // Tries to use _malloc()
var ALLOC_STACK = 1; // Lives for the duration of the current function call
var ALLOC_STATIC = 2; // Cannot be freed
Module['ALLOC_NORMAL'] = ALLOC_NORMAL;
Module['ALLOC_STACK'] = ALLOC_STACK;
Module['ALLOC_STATIC'] = ALLOC_STATIC;

// allocate(): This is for internal use. You can use it yourself as well, but the interface
//             is a little tricky (see docs right below). The reason is that it is optimized
//             for multiple syntaxes to save space in generated code. So you should
//             normally not use allocate(), and instead allocate memory using _malloc(),
//             initialize it with setValue(), and so forth.
// @slab: An array of data, or a number. If a number, then the size of the block to allocate,
//        in *bytes* (note that this is sometimes confusing: the next parameter does not
//        affect this!)
// @types: Either an array of types, one for each byte (or 0 if no type at that position),
//         or a single type which is used for the entire block. This only matters if there
//         is initial data - if @slab is a number, then this does not matter at all and is
//         ignored.
// @allocator: How to allocate memory, see ALLOC_*
function allocate(slab, types, allocator) {
  var zeroinit, size;
  if (typeof slab === 'number') {
    zeroinit = true;
    size = slab;
  } else {
    zeroinit = false;
    size = slab.length;
  }

  var singleType = typeof types === 'string' ? types : null;

  var ret = [_malloc, Runtime.stackAlloc, Runtime.staticAlloc][allocator === undefined ? ALLOC_STATIC : allocator](Math.max(size, singleType ? 1 : types.length));

  if (zeroinit) {
      _memset(ret, 0, size);
      return ret;
  }
  
  var i = 0, type;
  while (i < size) {
    var curr = slab[i];

    if (typeof curr === 'function') {
      curr = Runtime.getFunctionIndex(curr);
    }

    type = singleType || types[i];
    if (type === 0) {
      i++;
      continue;
    }
    assert(type, 'Must know what type to store in allocate!');

    if (type == 'i64') type = 'i32'; // special case: we have one i32 here, and one i32 later

    setValue(ret+i, curr, type);
    i += Runtime.getNativeTypeSize(type);
  }

  return ret;
}
Module['allocate'] = allocate;

function Pointer_stringify(ptr, /* optional */ length) {
  var utf8 = new Runtime.UTF8Processor();
  var nullTerminated = typeof(length) == "undefined";
  var ret = "";
  var i = 0;
  var t;
  while (1) {
    t = HEAPU8[((ptr)+(i))];
    if (nullTerminated && t == 0) break;
    ret += utf8.processCChar(t);
    i += 1;
    if (!nullTerminated && i == length) break;
  }
  return ret;
}
Module['Pointer_stringify'] = Pointer_stringify;

function Array_stringify(array) {
  var ret = "";
  for (var i = 0; i < array.length; i++) {
    ret += String.fromCharCode(array[i]);
  }
  return ret;
}
Module['Array_stringify'] = Array_stringify;

// Memory management

var FUNCTION_TABLE; // XXX: In theory the indexes here can be equal to pointers to stacked or malloced memory. Such comparisons should
                    //      be false, but can turn out true. We should probably set the top bit to prevent such issues.

var PAGE_SIZE = 4096;
function alignMemoryPage(x) {
  return ((x+4095)>>12)<<12;
}

var HEAP;
var HEAP8, HEAPU8, HEAP16, HEAPU16, HEAP32, HEAPU32, HEAPF32, HEAPF64;

var STACK_ROOT, STACKTOP, STACK_MAX;
var STATICTOP;
function enlargeMemory() {
  // TOTAL_MEMORY is the current size of the actual array, and STATICTOP is the new top.
  Module.printErr('Warning: Enlarging memory arrays, this is not fast! ' + [STATICTOP, TOTAL_MEMORY]);
  assert(STATICTOP >= TOTAL_MEMORY);
  assert(TOTAL_MEMORY > 4); // So the loop below will not be infinite
  while (TOTAL_MEMORY <= STATICTOP) { // Simple heuristic. Override enlargeMemory() if your program has something more optimal for it
    TOTAL_MEMORY = alignMemoryPage(2*TOTAL_MEMORY);
  }
  var oldHEAP8 = HEAP8;
  var buffer = new ArrayBuffer(TOTAL_MEMORY);
  HEAP8 = new Int8Array(buffer);
  HEAP16 = new Int16Array(buffer);
  HEAP32 = new Int32Array(buffer);
  HEAPU8 = new Uint8Array(buffer);
  HEAPU16 = new Uint16Array(buffer);
  HEAPU32 = new Uint32Array(buffer);
  HEAPF32 = new Float32Array(buffer);
  HEAPF64 = new Float64Array(buffer);
  HEAP8.set(oldHEAP8);
}

var TOTAL_STACK = Module['TOTAL_STACK'] || 5242880;
var TOTAL_MEMORY = Module['TOTAL_MEMORY'] || 10485760;
var FAST_MEMORY = Module['FAST_MEMORY'] || 2097152;

// Initialize the runtime's memory
// check for full engine support (use string 'subarray' to avoid closure compiler confusion)
  assert(!!Int32Array && !!Float64Array && !!(new Int32Array(1)['subarray']) && !!(new Int32Array(1)['set']),
         'Cannot fallback to non-typed array case: Code is too specialized');

  var buffer = new ArrayBuffer(TOTAL_MEMORY);
  HEAP8 = new Int8Array(buffer);
  HEAP16 = new Int16Array(buffer);
  HEAP32 = new Int32Array(buffer);
  HEAPU8 = new Uint8Array(buffer);
  HEAPU16 = new Uint16Array(buffer);
  HEAPU32 = new Uint32Array(buffer);
  HEAPF32 = new Float32Array(buffer);
  HEAPF64 = new Float64Array(buffer);

  // Endianness check (note: assumes compiler arch was little-endian)
  HEAP32[0] = 255;
  assert(HEAPU8[0] === 255 && HEAPU8[3] === 0, 'Typed arrays 2 must be run on a little-endian system');

Module['HEAP'] = HEAP;
Module['HEAP8'] = HEAP8;
Module['HEAP16'] = HEAP16;
Module['HEAP32'] = HEAP32;
Module['HEAPU8'] = HEAPU8;
Module['HEAPU16'] = HEAPU16;
Module['HEAPU32'] = HEAPU32;
Module['HEAPF32'] = HEAPF32;
Module['HEAPF64'] = HEAPF64;

STACK_ROOT = STACKTOP = Runtime.alignMemory(1);
STACK_MAX = STACK_ROOT + TOTAL_STACK;

var tempDoublePtr = Runtime.alignMemory(STACK_MAX, 8);
var tempDoubleI8  = HEAP8.subarray(tempDoublePtr);
var tempDoubleI32 = HEAP32.subarray(tempDoublePtr >> 2);
var tempDoubleF32 = HEAPF32.subarray(tempDoublePtr >> 2);
var tempDoubleF64 = HEAPF64.subarray(tempDoublePtr >> 3);
function copyTempFloat(ptr) { // functions, because inlining this code is increases code size too much
  tempDoubleI8[0] = HEAP8[ptr];
  tempDoubleI8[1] = HEAP8[ptr+1];
  tempDoubleI8[2] = HEAP8[ptr+2];
  tempDoubleI8[3] = HEAP8[ptr+3];
}
function copyTempDouble(ptr) {
  tempDoubleI8[0] = HEAP8[ptr];
  tempDoubleI8[1] = HEAP8[ptr+1];
  tempDoubleI8[2] = HEAP8[ptr+2];
  tempDoubleI8[3] = HEAP8[ptr+3];
  tempDoubleI8[4] = HEAP8[ptr+4];
  tempDoubleI8[5] = HEAP8[ptr+5];
  tempDoubleI8[6] = HEAP8[ptr+6];
  tempDoubleI8[7] = HEAP8[ptr+7];
}
STACK_MAX = tempDoublePtr + 8;

STATICTOP = alignMemoryPage(STACK_MAX);

var nullString = allocate(intArrayFromString('(null)'), 'i8', ALLOC_STATIC);

function callRuntimeCallbacks(callbacks) {
  while(callbacks.length > 0) {
    var callback = callbacks.shift();
    var func = callback.func;
    if (typeof func === 'number') {
      func = FUNCTION_TABLE[func];
    }
    func(callback.arg === undefined ? null : callback.arg);
  }
}

var __ATINIT__ = []; // functions called during startup
var __ATMAIN__ = []; // functions called when main() is to be run
var __ATEXIT__ = []; // functions called during shutdown

function initRuntime() {
  callRuntimeCallbacks(__ATINIT__);
}
function preMain() {
  callRuntimeCallbacks(__ATMAIN__);
}
function exitRuntime() {
  callRuntimeCallbacks(__ATEXIT__);

  // Print summary of correction activity
  CorrectionsMonitor.print();
}

function String_len(ptr) {
  var i = ptr;
  while (HEAP8[(i++)]) {}; // Note: should be |!= 0|, technically. But this helps catch bugs with undefineds
  return i - ptr - 1;
}
Module['String_len'] = String_len;

// Tools

// This processes a JS string into a C-line array of numbers, 0-terminated.
// For LLVM-originating strings, see parser.js:parseLLVMString function
function intArrayFromString(stringy, dontAddNull, length /* optional */) {
  var ret = (new Runtime.UTF8Processor()).processJSString(stringy);
  if (length) {
    ret.length = length;
  }
  if (!dontAddNull) {
    ret.push(0);
  }
  return ret;
}
Module['intArrayFromString'] = intArrayFromString;

function intArrayToString(array) {
  var ret = [];
  for (var i = 0; i < array.length; i++) {
    var chr = array[i];
    if (chr > 0xFF) {
        assert(false, 'Character code ' + chr + ' (' + String.fromCharCode(chr) + ')  at offset ' + i + ' not in 0x00-0xFF.');
      chr &= 0xFF;
    }
    ret.push(String.fromCharCode(chr));
  }
  return ret.join('');
}
Module['intArrayToString'] = intArrayToString;

// Write a Javascript array to somewhere in the heap
function writeStringToMemory(string, buffer, dontAddNull) {
  var array = intArrayFromString(string, dontAddNull);
  var i = 0;
  while (i < array.length) {
    var chr = array[i];
    HEAP8[((buffer)+(i))]=chr
    i = i + 1;
  }
}
Module['writeStringToMemory'] = writeStringToMemory;

function writeArrayToMemory(array, buffer) {
  for (var i = 0; i < array.length; i++) {
    HEAP8[((buffer)+(i))]=array[i];
  }
}
Module['writeArrayToMemory'] = writeArrayToMemory;

var STRING_TABLE = [];

function unSign(value, bits, ignore, sig) {
  if (value >= 0) {
    return value;
  }
  return bits <= 32 ? 2*Math.abs(1 << (bits-1)) + value // Need some trickery, since if bits == 32, we are right at the limit of the bits JS uses in bitshifts
                    : Math.pow(2, bits)         + value;
  // TODO: clean up previous line
}
function reSign(value, bits, ignore, sig) {
  if (value <= 0) {
    return value;
  }
  var half = bits <= 32 ? Math.abs(1 << (bits-1)) // abs is needed if bits == 32
                        : Math.pow(2, bits-1);
  if (value >= half && (bits <= 32 || value > half)) { // for huge values, we can hit the precision limit and always get true here. so don't do that
                                                       // but, in general there is no perfect solution here. With 64-bit ints, we get rounding and errors
                                                       // TODO: In i64 mode 1, resign the two parts separately and safely
    value = -2*half + value; // Cannot bitshift half, as it may be at the limit of the bits JS uses in bitshifts
  }
  return value;
}

// A counter of dependencies for calling run(). If we need to
// do asynchronous work before running, increment this and
// decrement it. Incrementing must happen in a place like
// PRE_RUN_ADDITIONS (used by emcc to add file preloading).
// Note that you can add dependencies in preRun, even though
// it happens right before run - run will be postponed until
// the dependencies are met.
var runDependencies = 0;
var runDependencyTracking = {};
var calledRun = false;
var runDependencyWatcher = null;
function addRunDependency(id) {
  runDependencies++;
  if (Module['monitorRunDependencies']) {
    Module['monitorRunDependencies'](runDependencies);
  }
  if (id) {
    assert(!runDependencyTracking[id]);
    runDependencyTracking[id] = 1;
    if (runDependencyWatcher === null && typeof setInterval !== 'undefined') {
      // Check for missing dependencies every few seconds
      runDependencyWatcher = setInterval(function() {
        var shown = false;
        for (var dep in runDependencyTracking) {
          if (!shown) {
            shown = true;
            Module.printErr('still waiting on run dependencies:');
          }
          Module.printErr('dependency: ' + dep);
        }
        if (shown) {
          Module.printErr('(end of list)');
        }
      }, 6000);
    }
  } else {
    Module.printErr('warning: run dependency added without ID');
  }
}
Module['addRunDependency'] = addRunDependency;
function removeRunDependency(id) {
  runDependencies--;
  if (Module['monitorRunDependencies']) {
    Module['monitorRunDependencies'](runDependencies);
  }
  if (id) {
    assert(runDependencyTracking[id]);
    delete runDependencyTracking[id];
  } else {
    Module.printErr('warning: run dependency removed without ID');
  }
  if (runDependencies == 0) {
    if (runDependencyWatcher !== null) {
      clearInterval(runDependencyWatcher);
      runDependencyWatcher = null;
    } 
    if (!calledRun) run();
  }
}
Module['removeRunDependency'] = removeRunDependency;

Module["preloadedImages"] = {}; // maps url to image data
Module["preloadedAudios"] = {}; // maps url to audio data

// === Body ===




function _adler32($adler, $buf, $len) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $sum2;
      var $n;
      $2=$adler;
      $3=$buf;
      $4=$len;
      var $5=$2;
      var $6=$5 >>> 16;
      var $7=$6 & 65535;
      $sum2=$7;
      var $8=$2;
      var $9=$8 & 65535;
      $2=$9;
      var $10=$4;
      var $11=(($10)|0)==1;
      if ($11) { __label__ = 3; break; } else { __label__ = 8; break; }
    case 3: 
      var $13=$3;
      var $14=(($13)|0);
      var $15=HEAPU8[($14)];
      var $16=(($15)&255);
      var $17=$2;
      var $18=((($17)+($16))|0);
      $2=$18;
      var $19=$2;
      var $20=(($19)>>>0) >= 65521;
      if ($20) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      var $22=$2;
      var $23=((($22)-(65521))|0);
      $2=$23;
      __label__ = 5; break;
    case 5: 
      var $25=$2;
      var $26=$sum2;
      var $27=((($26)+($25))|0);
      $sum2=$27;
      var $28=$sum2;
      var $29=(($28)>>>0) >= 65521;
      if ($29) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      var $31=$sum2;
      var $32=((($31)-(65521))|0);
      $sum2=$32;
      __label__ = 7; break;
    case 7: 
      var $34=$2;
      var $35=$sum2;
      var $36=$35 << 16;
      var $37=$34 | $36;
      $1=$37;
      __label__ = 32; break;
    case 8: 
      var $39=$3;
      var $40=(($39)|0)==0;
      if ($40) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      $1=1;
      __label__ = 32; break;
    case 10: 
      var $43=$4;
      var $44=(($43)>>>0) < 16;
      if ($44) { __label__ = 11; break; } else { __label__ = 17; break; }
    case 11: 
      __label__ = 12; break;
    case 12: 
      var $47=$4;
      var $48=((($47)-(1))|0);
      $4=$48;
      var $49=(($47)|0)!=0;
      if ($49) { __label__ = 13; break; } else { __label__ = 14; break; }
    case 13: 
      var $51=$3;
      var $52=(($51+1)|0);
      $3=$52;
      var $53=HEAPU8[($51)];
      var $54=(($53)&255);
      var $55=$2;
      var $56=((($55)+($54))|0);
      $2=$56;
      var $57=$2;
      var $58=$sum2;
      var $59=((($58)+($57))|0);
      $sum2=$59;
      __label__ = 12; break;
    case 14: 
      var $61=$2;
      var $62=(($61)>>>0) >= 65521;
      if ($62) { __label__ = 15; break; } else { __label__ = 16; break; }
    case 15: 
      var $64=$2;
      var $65=((($64)-(65521))|0);
      $2=$65;
      __label__ = 16; break;
    case 16: 
      var $67=$sum2;
      var $68=((($67)>>>0))%(65521);
      $sum2=$68;
      var $69=$2;
      var $70=$sum2;
      var $71=$70 << 16;
      var $72=$69 | $71;
      $1=$72;
      __label__ = 32; break;
    case 17: 
      __label__ = 18; break;
    case 18: 
      var $75=$4;
      var $76=(($75)>>>0) >= 5552;
      if ($76) { __label__ = 19; break; } else { __label__ = 23; break; }
    case 19: 
      var $78=$4;
      var $79=((($78)-(5552))|0);
      $4=$79;
      $n=347;
      __label__ = 20; break;
    case 20: 
      var $81=$3;
      var $82=(($81)|0);
      var $83=HEAPU8[($82)];
      var $84=(($83)&255);
      var $85=$2;
      var $86=((($85)+($84))|0);
      $2=$86;
      var $87=$2;
      var $88=$sum2;
      var $89=((($88)+($87))|0);
      $sum2=$89;
      var $90=$3;
      var $91=(($90+1)|0);
      var $92=HEAPU8[($91)];
      var $93=(($92)&255);
      var $94=$2;
      var $95=((($94)+($93))|0);
      $2=$95;
      var $96=$2;
      var $97=$sum2;
      var $98=((($97)+($96))|0);
      $sum2=$98;
      var $99=$3;
      var $100=(($99+2)|0);
      var $101=HEAPU8[($100)];
      var $102=(($101)&255);
      var $103=$2;
      var $104=((($103)+($102))|0);
      $2=$104;
      var $105=$2;
      var $106=$sum2;
      var $107=((($106)+($105))|0);
      $sum2=$107;
      var $108=$3;
      var $109=(($108+3)|0);
      var $110=HEAPU8[($109)];
      var $111=(($110)&255);
      var $112=$2;
      var $113=((($112)+($111))|0);
      $2=$113;
      var $114=$2;
      var $115=$sum2;
      var $116=((($115)+($114))|0);
      $sum2=$116;
      var $117=$3;
      var $118=(($117+4)|0);
      var $119=HEAPU8[($118)];
      var $120=(($119)&255);
      var $121=$2;
      var $122=((($121)+($120))|0);
      $2=$122;
      var $123=$2;
      var $124=$sum2;
      var $125=((($124)+($123))|0);
      $sum2=$125;
      var $126=$3;
      var $127=(($126+5)|0);
      var $128=HEAPU8[($127)];
      var $129=(($128)&255);
      var $130=$2;
      var $131=((($130)+($129))|0);
      $2=$131;
      var $132=$2;
      var $133=$sum2;
      var $134=((($133)+($132))|0);
      $sum2=$134;
      var $135=$3;
      var $136=(($135+6)|0);
      var $137=HEAPU8[($136)];
      var $138=(($137)&255);
      var $139=$2;
      var $140=((($139)+($138))|0);
      $2=$140;
      var $141=$2;
      var $142=$sum2;
      var $143=((($142)+($141))|0);
      $sum2=$143;
      var $144=$3;
      var $145=(($144+7)|0);
      var $146=HEAPU8[($145)];
      var $147=(($146)&255);
      var $148=$2;
      var $149=((($148)+($147))|0);
      $2=$149;
      var $150=$2;
      var $151=$sum2;
      var $152=((($151)+($150))|0);
      $sum2=$152;
      var $153=$3;
      var $154=(($153+8)|0);
      var $155=HEAPU8[($154)];
      var $156=(($155)&255);
      var $157=$2;
      var $158=((($157)+($156))|0);
      $2=$158;
      var $159=$2;
      var $160=$sum2;
      var $161=((($160)+($159))|0);
      $sum2=$161;
      var $162=$3;
      var $163=(($162+9)|0);
      var $164=HEAPU8[($163)];
      var $165=(($164)&255);
      var $166=$2;
      var $167=((($166)+($165))|0);
      $2=$167;
      var $168=$2;
      var $169=$sum2;
      var $170=((($169)+($168))|0);
      $sum2=$170;
      var $171=$3;
      var $172=(($171+10)|0);
      var $173=HEAPU8[($172)];
      var $174=(($173)&255);
      var $175=$2;
      var $176=((($175)+($174))|0);
      $2=$176;
      var $177=$2;
      var $178=$sum2;
      var $179=((($178)+($177))|0);
      $sum2=$179;
      var $180=$3;
      var $181=(($180+11)|0);
      var $182=HEAPU8[($181)];
      var $183=(($182)&255);
      var $184=$2;
      var $185=((($184)+($183))|0);
      $2=$185;
      var $186=$2;
      var $187=$sum2;
      var $188=((($187)+($186))|0);
      $sum2=$188;
      var $189=$3;
      var $190=(($189+12)|0);
      var $191=HEAPU8[($190)];
      var $192=(($191)&255);
      var $193=$2;
      var $194=((($193)+($192))|0);
      $2=$194;
      var $195=$2;
      var $196=$sum2;
      var $197=((($196)+($195))|0);
      $sum2=$197;
      var $198=$3;
      var $199=(($198+13)|0);
      var $200=HEAPU8[($199)];
      var $201=(($200)&255);
      var $202=$2;
      var $203=((($202)+($201))|0);
      $2=$203;
      var $204=$2;
      var $205=$sum2;
      var $206=((($205)+($204))|0);
      $sum2=$206;
      var $207=$3;
      var $208=(($207+14)|0);
      var $209=HEAPU8[($208)];
      var $210=(($209)&255);
      var $211=$2;
      var $212=((($211)+($210))|0);
      $2=$212;
      var $213=$2;
      var $214=$sum2;
      var $215=((($214)+($213))|0);
      $sum2=$215;
      var $216=$3;
      var $217=(($216+15)|0);
      var $218=HEAPU8[($217)];
      var $219=(($218)&255);
      var $220=$2;
      var $221=((($220)+($219))|0);
      $2=$221;
      var $222=$2;
      var $223=$sum2;
      var $224=((($223)+($222))|0);
      $sum2=$224;
      var $225=$3;
      var $226=(($225+16)|0);
      $3=$226;
      __label__ = 21; break;
    case 21: 
      var $228=$n;
      var $229=((($228)-(1))|0);
      $n=$229;
      var $230=(($229)|0)!=0;
      if ($230) { __label__ = 20; break; } else { __label__ = 22; break; }
    case 22: 
      var $232=$2;
      var $233=((($232)>>>0))%(65521);
      $2=$233;
      var $234=$sum2;
      var $235=((($234)>>>0))%(65521);
      $sum2=$235;
      __label__ = 18; break;
    case 23: 
      var $237=$4;
      var $238=(($237)|0)!=0;
      if ($238) { __label__ = 24; break; } else { __label__ = 31; break; }
    case 24: 
      __label__ = 25; break;
    case 25: 
      var $241=$4;
      var $242=(($241)>>>0) >= 16;
      if ($242) { __label__ = 26; break; } else { __label__ = 27; break; }
    case 26: 
      var $244=$4;
      var $245=((($244)-(16))|0);
      $4=$245;
      var $246=$3;
      var $247=(($246)|0);
      var $248=HEAPU8[($247)];
      var $249=(($248)&255);
      var $250=$2;
      var $251=((($250)+($249))|0);
      $2=$251;
      var $252=$2;
      var $253=$sum2;
      var $254=((($253)+($252))|0);
      $sum2=$254;
      var $255=$3;
      var $256=(($255+1)|0);
      var $257=HEAPU8[($256)];
      var $258=(($257)&255);
      var $259=$2;
      var $260=((($259)+($258))|0);
      $2=$260;
      var $261=$2;
      var $262=$sum2;
      var $263=((($262)+($261))|0);
      $sum2=$263;
      var $264=$3;
      var $265=(($264+2)|0);
      var $266=HEAPU8[($265)];
      var $267=(($266)&255);
      var $268=$2;
      var $269=((($268)+($267))|0);
      $2=$269;
      var $270=$2;
      var $271=$sum2;
      var $272=((($271)+($270))|0);
      $sum2=$272;
      var $273=$3;
      var $274=(($273+3)|0);
      var $275=HEAPU8[($274)];
      var $276=(($275)&255);
      var $277=$2;
      var $278=((($277)+($276))|0);
      $2=$278;
      var $279=$2;
      var $280=$sum2;
      var $281=((($280)+($279))|0);
      $sum2=$281;
      var $282=$3;
      var $283=(($282+4)|0);
      var $284=HEAPU8[($283)];
      var $285=(($284)&255);
      var $286=$2;
      var $287=((($286)+($285))|0);
      $2=$287;
      var $288=$2;
      var $289=$sum2;
      var $290=((($289)+($288))|0);
      $sum2=$290;
      var $291=$3;
      var $292=(($291+5)|0);
      var $293=HEAPU8[($292)];
      var $294=(($293)&255);
      var $295=$2;
      var $296=((($295)+($294))|0);
      $2=$296;
      var $297=$2;
      var $298=$sum2;
      var $299=((($298)+($297))|0);
      $sum2=$299;
      var $300=$3;
      var $301=(($300+6)|0);
      var $302=HEAPU8[($301)];
      var $303=(($302)&255);
      var $304=$2;
      var $305=((($304)+($303))|0);
      $2=$305;
      var $306=$2;
      var $307=$sum2;
      var $308=((($307)+($306))|0);
      $sum2=$308;
      var $309=$3;
      var $310=(($309+7)|0);
      var $311=HEAPU8[($310)];
      var $312=(($311)&255);
      var $313=$2;
      var $314=((($313)+($312))|0);
      $2=$314;
      var $315=$2;
      var $316=$sum2;
      var $317=((($316)+($315))|0);
      $sum2=$317;
      var $318=$3;
      var $319=(($318+8)|0);
      var $320=HEAPU8[($319)];
      var $321=(($320)&255);
      var $322=$2;
      var $323=((($322)+($321))|0);
      $2=$323;
      var $324=$2;
      var $325=$sum2;
      var $326=((($325)+($324))|0);
      $sum2=$326;
      var $327=$3;
      var $328=(($327+9)|0);
      var $329=HEAPU8[($328)];
      var $330=(($329)&255);
      var $331=$2;
      var $332=((($331)+($330))|0);
      $2=$332;
      var $333=$2;
      var $334=$sum2;
      var $335=((($334)+($333))|0);
      $sum2=$335;
      var $336=$3;
      var $337=(($336+10)|0);
      var $338=HEAPU8[($337)];
      var $339=(($338)&255);
      var $340=$2;
      var $341=((($340)+($339))|0);
      $2=$341;
      var $342=$2;
      var $343=$sum2;
      var $344=((($343)+($342))|0);
      $sum2=$344;
      var $345=$3;
      var $346=(($345+11)|0);
      var $347=HEAPU8[($346)];
      var $348=(($347)&255);
      var $349=$2;
      var $350=((($349)+($348))|0);
      $2=$350;
      var $351=$2;
      var $352=$sum2;
      var $353=((($352)+($351))|0);
      $sum2=$353;
      var $354=$3;
      var $355=(($354+12)|0);
      var $356=HEAPU8[($355)];
      var $357=(($356)&255);
      var $358=$2;
      var $359=((($358)+($357))|0);
      $2=$359;
      var $360=$2;
      var $361=$sum2;
      var $362=((($361)+($360))|0);
      $sum2=$362;
      var $363=$3;
      var $364=(($363+13)|0);
      var $365=HEAPU8[($364)];
      var $366=(($365)&255);
      var $367=$2;
      var $368=((($367)+($366))|0);
      $2=$368;
      var $369=$2;
      var $370=$sum2;
      var $371=((($370)+($369))|0);
      $sum2=$371;
      var $372=$3;
      var $373=(($372+14)|0);
      var $374=HEAPU8[($373)];
      var $375=(($374)&255);
      var $376=$2;
      var $377=((($376)+($375))|0);
      $2=$377;
      var $378=$2;
      var $379=$sum2;
      var $380=((($379)+($378))|0);
      $sum2=$380;
      var $381=$3;
      var $382=(($381+15)|0);
      var $383=HEAPU8[($382)];
      var $384=(($383)&255);
      var $385=$2;
      var $386=((($385)+($384))|0);
      $2=$386;
      var $387=$2;
      var $388=$sum2;
      var $389=((($388)+($387))|0);
      $sum2=$389;
      var $390=$3;
      var $391=(($390+16)|0);
      $3=$391;
      __label__ = 25; break;
    case 27: 
      __label__ = 28; break;
    case 28: 
      var $394=$4;
      var $395=((($394)-(1))|0);
      $4=$395;
      var $396=(($394)|0)!=0;
      if ($396) { __label__ = 29; break; } else { __label__ = 30; break; }
    case 29: 
      var $398=$3;
      var $399=(($398+1)|0);
      $3=$399;
      var $400=HEAPU8[($398)];
      var $401=(($400)&255);
      var $402=$2;
      var $403=((($402)+($401))|0);
      $2=$403;
      var $404=$2;
      var $405=$sum2;
      var $406=((($405)+($404))|0);
      $sum2=$406;
      __label__ = 28; break;
    case 30: 
      var $408=$2;
      var $409=((($408)>>>0))%(65521);
      $2=$409;
      var $410=$sum2;
      var $411=((($410)>>>0))%(65521);
      $sum2=$411;
      __label__ = 31; break;
    case 31: 
      var $413=$2;
      var $414=$sum2;
      var $415=$414 << 16;
      var $416=$413 | $415;
      $1=$416;
      __label__ = 32; break;
    case 32: 
      var $418=$1;
      ;
      return $418;
    default: assert(0, "bad label: " + __label__);
  }
}
_adler32["X"]=1;

function _crc32($crc, $buf, $len) {
  var __stackBase__  = STACKTOP; STACKTOP += 4; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $endian=__stackBase__;
      $2=$crc;
      $3=$buf;
      $4=$len;
      var $5=$3;
      var $6=(($5)|0)==0;
      if ($6) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      $1=0;
      __label__ = 7; break;
    case 4: 
      HEAP32[(($endian)>>2)]=1;
      var $9=$endian;
      var $10=HEAP8[($9)];
      var $11=(($10 << 24) >> 24)!=0;
      if ($11) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $13=$2;
      var $14=$3;
      var $15=$4;
      var $16=_crc32_little($13, $14, $15);
      $1=$16;
      __label__ = 7; break;
    case 6: 
      var $18=$2;
      var $19=$3;
      var $20=$4;
      var $21=_crc32_big($18, $19, $20);
      $1=$21;
      __label__ = 7; break;
    case 7: 
      var $23=$1;
      STACKTOP = __stackBase__;
      return $23;
    default: assert(0, "bad label: " + __label__);
  }
}


function _crc32_little($crc, $buf, $len) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $c;
      var $buf4;
      $1=$crc;
      $2=$buf;
      $3=$len;
      var $4=$1;
      $c=$4;
      var $5=$c;
      var $6=$5 ^ -1;
      $c=$6;
      __label__ = 3; break;
    case 3: 
      var $8=$3;
      var $9=(($8)|0)!=0;
      if ($9) { __label__ = 4; break; } else { var $16 = 0;__label__ = 5; break; }
    case 4: 
      var $11=$2;
      var $12=$11;
      var $13=$12 & 3;
      var $14=(($13)|0)!=0;
      var $16 = $14;__label__ = 5; break;
    case 5: 
      var $16;
      if ($16) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      var $18=$c;
      var $19=$2;
      var $20=(($19+1)|0);
      $2=$20;
      var $21=HEAPU8[($19)];
      var $22=(($21)&255);
      var $23=$18 ^ $22;
      var $24=$23 & 255;
      var $25=((((_crc_table)|0)+($24<<2))|0);
      var $26=HEAP32[(($25)>>2)];
      var $27=$c;
      var $28=$27 >>> 8;
      var $29=$26 ^ $28;
      $c=$29;
      var $30=$3;
      var $31=((($30)-(1))|0);
      $3=$31;
      __label__ = 3; break;
    case 7: 
      var $33=$2;
      var $34=$33;
      $buf4=$34;
      __label__ = 8; break;
    case 8: 
      var $36=$3;
      var $37=(($36)>>>0) >= 32;
      if ($37) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      var $39=$buf4;
      var $40=(($39+4)|0);
      $buf4=$40;
      var $41=HEAP32[(($39)>>2)];
      var $42=$c;
      var $43=$42 ^ $41;
      $c=$43;
      var $44=$c;
      var $45=$44 & 255;
      var $46=((((_crc_table+3072)|0)+($45<<2))|0);
      var $47=HEAP32[(($46)>>2)];
      var $48=$c;
      var $49=$48 >>> 8;
      var $50=$49 & 255;
      var $51=((((_crc_table+2048)|0)+($50<<2))|0);
      var $52=HEAP32[(($51)>>2)];
      var $53=$47 ^ $52;
      var $54=$c;
      var $55=$54 >>> 16;
      var $56=$55 & 255;
      var $57=((((_crc_table+1024)|0)+($56<<2))|0);
      var $58=HEAP32[(($57)>>2)];
      var $59=$53 ^ $58;
      var $60=$c;
      var $61=$60 >>> 24;
      var $62=((((_crc_table)|0)+($61<<2))|0);
      var $63=HEAP32[(($62)>>2)];
      var $64=$59 ^ $63;
      $c=$64;
      var $65=$buf4;
      var $66=(($65+4)|0);
      $buf4=$66;
      var $67=HEAP32[(($65)>>2)];
      var $68=$c;
      var $69=$68 ^ $67;
      $c=$69;
      var $70=$c;
      var $71=$70 & 255;
      var $72=((((_crc_table+3072)|0)+($71<<2))|0);
      var $73=HEAP32[(($72)>>2)];
      var $74=$c;
      var $75=$74 >>> 8;
      var $76=$75 & 255;
      var $77=((((_crc_table+2048)|0)+($76<<2))|0);
      var $78=HEAP32[(($77)>>2)];
      var $79=$73 ^ $78;
      var $80=$c;
      var $81=$80 >>> 16;
      var $82=$81 & 255;
      var $83=((((_crc_table+1024)|0)+($82<<2))|0);
      var $84=HEAP32[(($83)>>2)];
      var $85=$79 ^ $84;
      var $86=$c;
      var $87=$86 >>> 24;
      var $88=((((_crc_table)|0)+($87<<2))|0);
      var $89=HEAP32[(($88)>>2)];
      var $90=$85 ^ $89;
      $c=$90;
      var $91=$buf4;
      var $92=(($91+4)|0);
      $buf4=$92;
      var $93=HEAP32[(($91)>>2)];
      var $94=$c;
      var $95=$94 ^ $93;
      $c=$95;
      var $96=$c;
      var $97=$96 & 255;
      var $98=((((_crc_table+3072)|0)+($97<<2))|0);
      var $99=HEAP32[(($98)>>2)];
      var $100=$c;
      var $101=$100 >>> 8;
      var $102=$101 & 255;
      var $103=((((_crc_table+2048)|0)+($102<<2))|0);
      var $104=HEAP32[(($103)>>2)];
      var $105=$99 ^ $104;
      var $106=$c;
      var $107=$106 >>> 16;
      var $108=$107 & 255;
      var $109=((((_crc_table+1024)|0)+($108<<2))|0);
      var $110=HEAP32[(($109)>>2)];
      var $111=$105 ^ $110;
      var $112=$c;
      var $113=$112 >>> 24;
      var $114=((((_crc_table)|0)+($113<<2))|0);
      var $115=HEAP32[(($114)>>2)];
      var $116=$111 ^ $115;
      $c=$116;
      var $117=$buf4;
      var $118=(($117+4)|0);
      $buf4=$118;
      var $119=HEAP32[(($117)>>2)];
      var $120=$c;
      var $121=$120 ^ $119;
      $c=$121;
      var $122=$c;
      var $123=$122 & 255;
      var $124=((((_crc_table+3072)|0)+($123<<2))|0);
      var $125=HEAP32[(($124)>>2)];
      var $126=$c;
      var $127=$126 >>> 8;
      var $128=$127 & 255;
      var $129=((((_crc_table+2048)|0)+($128<<2))|0);
      var $130=HEAP32[(($129)>>2)];
      var $131=$125 ^ $130;
      var $132=$c;
      var $133=$132 >>> 16;
      var $134=$133 & 255;
      var $135=((((_crc_table+1024)|0)+($134<<2))|0);
      var $136=HEAP32[(($135)>>2)];
      var $137=$131 ^ $136;
      var $138=$c;
      var $139=$138 >>> 24;
      var $140=((((_crc_table)|0)+($139<<2))|0);
      var $141=HEAP32[(($140)>>2)];
      var $142=$137 ^ $141;
      $c=$142;
      var $143=$buf4;
      var $144=(($143+4)|0);
      $buf4=$144;
      var $145=HEAP32[(($143)>>2)];
      var $146=$c;
      var $147=$146 ^ $145;
      $c=$147;
      var $148=$c;
      var $149=$148 & 255;
      var $150=((((_crc_table+3072)|0)+($149<<2))|0);
      var $151=HEAP32[(($150)>>2)];
      var $152=$c;
      var $153=$152 >>> 8;
      var $154=$153 & 255;
      var $155=((((_crc_table+2048)|0)+($154<<2))|0);
      var $156=HEAP32[(($155)>>2)];
      var $157=$151 ^ $156;
      var $158=$c;
      var $159=$158 >>> 16;
      var $160=$159 & 255;
      var $161=((((_crc_table+1024)|0)+($160<<2))|0);
      var $162=HEAP32[(($161)>>2)];
      var $163=$157 ^ $162;
      var $164=$c;
      var $165=$164 >>> 24;
      var $166=((((_crc_table)|0)+($165<<2))|0);
      var $167=HEAP32[(($166)>>2)];
      var $168=$163 ^ $167;
      $c=$168;
      var $169=$buf4;
      var $170=(($169+4)|0);
      $buf4=$170;
      var $171=HEAP32[(($169)>>2)];
      var $172=$c;
      var $173=$172 ^ $171;
      $c=$173;
      var $174=$c;
      var $175=$174 & 255;
      var $176=((((_crc_table+3072)|0)+($175<<2))|0);
      var $177=HEAP32[(($176)>>2)];
      var $178=$c;
      var $179=$178 >>> 8;
      var $180=$179 & 255;
      var $181=((((_crc_table+2048)|0)+($180<<2))|0);
      var $182=HEAP32[(($181)>>2)];
      var $183=$177 ^ $182;
      var $184=$c;
      var $185=$184 >>> 16;
      var $186=$185 & 255;
      var $187=((((_crc_table+1024)|0)+($186<<2))|0);
      var $188=HEAP32[(($187)>>2)];
      var $189=$183 ^ $188;
      var $190=$c;
      var $191=$190 >>> 24;
      var $192=((((_crc_table)|0)+($191<<2))|0);
      var $193=HEAP32[(($192)>>2)];
      var $194=$189 ^ $193;
      $c=$194;
      var $195=$buf4;
      var $196=(($195+4)|0);
      $buf4=$196;
      var $197=HEAP32[(($195)>>2)];
      var $198=$c;
      var $199=$198 ^ $197;
      $c=$199;
      var $200=$c;
      var $201=$200 & 255;
      var $202=((((_crc_table+3072)|0)+($201<<2))|0);
      var $203=HEAP32[(($202)>>2)];
      var $204=$c;
      var $205=$204 >>> 8;
      var $206=$205 & 255;
      var $207=((((_crc_table+2048)|0)+($206<<2))|0);
      var $208=HEAP32[(($207)>>2)];
      var $209=$203 ^ $208;
      var $210=$c;
      var $211=$210 >>> 16;
      var $212=$211 & 255;
      var $213=((((_crc_table+1024)|0)+($212<<2))|0);
      var $214=HEAP32[(($213)>>2)];
      var $215=$209 ^ $214;
      var $216=$c;
      var $217=$216 >>> 24;
      var $218=((((_crc_table)|0)+($217<<2))|0);
      var $219=HEAP32[(($218)>>2)];
      var $220=$215 ^ $219;
      $c=$220;
      var $221=$buf4;
      var $222=(($221+4)|0);
      $buf4=$222;
      var $223=HEAP32[(($221)>>2)];
      var $224=$c;
      var $225=$224 ^ $223;
      $c=$225;
      var $226=$c;
      var $227=$226 & 255;
      var $228=((((_crc_table+3072)|0)+($227<<2))|0);
      var $229=HEAP32[(($228)>>2)];
      var $230=$c;
      var $231=$230 >>> 8;
      var $232=$231 & 255;
      var $233=((((_crc_table+2048)|0)+($232<<2))|0);
      var $234=HEAP32[(($233)>>2)];
      var $235=$229 ^ $234;
      var $236=$c;
      var $237=$236 >>> 16;
      var $238=$237 & 255;
      var $239=((((_crc_table+1024)|0)+($238<<2))|0);
      var $240=HEAP32[(($239)>>2)];
      var $241=$235 ^ $240;
      var $242=$c;
      var $243=$242 >>> 24;
      var $244=((((_crc_table)|0)+($243<<2))|0);
      var $245=HEAP32[(($244)>>2)];
      var $246=$241 ^ $245;
      $c=$246;
      var $247=$3;
      var $248=((($247)-(32))|0);
      $3=$248;
      __label__ = 8; break;
    case 10: 
      __label__ = 11; break;
    case 11: 
      var $251=$3;
      var $252=(($251)>>>0) >= 4;
      if ($252) { __label__ = 12; break; } else { __label__ = 13; break; }
    case 12: 
      var $254=$buf4;
      var $255=(($254+4)|0);
      $buf4=$255;
      var $256=HEAP32[(($254)>>2)];
      var $257=$c;
      var $258=$257 ^ $256;
      $c=$258;
      var $259=$c;
      var $260=$259 & 255;
      var $261=((((_crc_table+3072)|0)+($260<<2))|0);
      var $262=HEAP32[(($261)>>2)];
      var $263=$c;
      var $264=$263 >>> 8;
      var $265=$264 & 255;
      var $266=((((_crc_table+2048)|0)+($265<<2))|0);
      var $267=HEAP32[(($266)>>2)];
      var $268=$262 ^ $267;
      var $269=$c;
      var $270=$269 >>> 16;
      var $271=$270 & 255;
      var $272=((((_crc_table+1024)|0)+($271<<2))|0);
      var $273=HEAP32[(($272)>>2)];
      var $274=$268 ^ $273;
      var $275=$c;
      var $276=$275 >>> 24;
      var $277=((((_crc_table)|0)+($276<<2))|0);
      var $278=HEAP32[(($277)>>2)];
      var $279=$274 ^ $278;
      $c=$279;
      var $280=$3;
      var $281=((($280)-(4))|0);
      $3=$281;
      __label__ = 11; break;
    case 13: 
      var $283=$buf4;
      var $284=$283;
      $2=$284;
      var $285=$3;
      var $286=(($285)|0)!=0;
      if ($286) { __label__ = 14; break; } else { __label__ = 18; break; }
    case 14: 
      __label__ = 15; break;
    case 15: 
      var $289=$c;
      var $290=$2;
      var $291=(($290+1)|0);
      $2=$291;
      var $292=HEAPU8[($290)];
      var $293=(($292)&255);
      var $294=$289 ^ $293;
      var $295=$294 & 255;
      var $296=((((_crc_table)|0)+($295<<2))|0);
      var $297=HEAP32[(($296)>>2)];
      var $298=$c;
      var $299=$298 >>> 8;
      var $300=$297 ^ $299;
      $c=$300;
      __label__ = 16; break;
    case 16: 
      var $302=$3;
      var $303=((($302)-(1))|0);
      $3=$303;
      var $304=(($303)|0)!=0;
      if ($304) { __label__ = 15; break; } else { __label__ = 17; break; }
    case 17: 
      __label__ = 18; break;
    case 18: 
      var $307=$c;
      var $308=$307 ^ -1;
      $c=$308;
      var $309=$c;
      ;
      return $309;
    default: assert(0, "bad label: " + __label__);
  }
}
_crc32_little["X"]=1;

function _crc32_big($crc, $buf, $len) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $c;
      var $buf4;
      $1=$crc;
      $2=$buf;
      $3=$len;
      var $4=$1;
      var $5=$4 >>> 24;
      var $6=$5 & 255;
      var $7=$1;
      var $8=$7 >>> 8;
      var $9=$8 & 65280;
      var $10=((($6)+($9))|0);
      var $11=$1;
      var $12=$11 & 65280;
      var $13=$12 << 8;
      var $14=((($10)+($13))|0);
      var $15=$1;
      var $16=$15 & 255;
      var $17=$16 << 24;
      var $18=((($14)+($17))|0);
      $c=$18;
      var $19=$c;
      var $20=$19 ^ -1;
      $c=$20;
      __label__ = 3; break;
    case 3: 
      var $22=$3;
      var $23=(($22)|0)!=0;
      if ($23) { __label__ = 4; break; } else { var $30 = 0;__label__ = 5; break; }
    case 4: 
      var $25=$2;
      var $26=$25;
      var $27=$26 & 3;
      var $28=(($27)|0)!=0;
      var $30 = $28;__label__ = 5; break;
    case 5: 
      var $30;
      if ($30) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      var $32=$c;
      var $33=$32 >>> 24;
      var $34=$2;
      var $35=(($34+1)|0);
      $2=$35;
      var $36=HEAPU8[($34)];
      var $37=(($36)&255);
      var $38=$33 ^ $37;
      var $39=((((_crc_table+4096)|0)+($38<<2))|0);
      var $40=HEAP32[(($39)>>2)];
      var $41=$c;
      var $42=$41 << 8;
      var $43=$40 ^ $42;
      $c=$43;
      var $44=$3;
      var $45=((($44)-(1))|0);
      $3=$45;
      __label__ = 3; break;
    case 7: 
      var $47=$2;
      var $48=$47;
      $buf4=$48;
      var $49=$buf4;
      var $50=((($49)-(4))|0);
      $buf4=$50;
      __label__ = 8; break;
    case 8: 
      var $52=$3;
      var $53=(($52)>>>0) >= 32;
      if ($53) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      var $55=$buf4;
      var $56=(($55+4)|0);
      $buf4=$56;
      var $57=HEAP32[(($56)>>2)];
      var $58=$c;
      var $59=$58 ^ $57;
      $c=$59;
      var $60=$c;
      var $61=$60 & 255;
      var $62=((((_crc_table+4096)|0)+($61<<2))|0);
      var $63=HEAP32[(($62)>>2)];
      var $64=$c;
      var $65=$64 >>> 8;
      var $66=$65 & 255;
      var $67=((((_crc_table+5120)|0)+($66<<2))|0);
      var $68=HEAP32[(($67)>>2)];
      var $69=$63 ^ $68;
      var $70=$c;
      var $71=$70 >>> 16;
      var $72=$71 & 255;
      var $73=((((_crc_table+6144)|0)+($72<<2))|0);
      var $74=HEAP32[(($73)>>2)];
      var $75=$69 ^ $74;
      var $76=$c;
      var $77=$76 >>> 24;
      var $78=((((_crc_table+7168)|0)+($77<<2))|0);
      var $79=HEAP32[(($78)>>2)];
      var $80=$75 ^ $79;
      $c=$80;
      var $81=$buf4;
      var $82=(($81+4)|0);
      $buf4=$82;
      var $83=HEAP32[(($82)>>2)];
      var $84=$c;
      var $85=$84 ^ $83;
      $c=$85;
      var $86=$c;
      var $87=$86 & 255;
      var $88=((((_crc_table+4096)|0)+($87<<2))|0);
      var $89=HEAP32[(($88)>>2)];
      var $90=$c;
      var $91=$90 >>> 8;
      var $92=$91 & 255;
      var $93=((((_crc_table+5120)|0)+($92<<2))|0);
      var $94=HEAP32[(($93)>>2)];
      var $95=$89 ^ $94;
      var $96=$c;
      var $97=$96 >>> 16;
      var $98=$97 & 255;
      var $99=((((_crc_table+6144)|0)+($98<<2))|0);
      var $100=HEAP32[(($99)>>2)];
      var $101=$95 ^ $100;
      var $102=$c;
      var $103=$102 >>> 24;
      var $104=((((_crc_table+7168)|0)+($103<<2))|0);
      var $105=HEAP32[(($104)>>2)];
      var $106=$101 ^ $105;
      $c=$106;
      var $107=$buf4;
      var $108=(($107+4)|0);
      $buf4=$108;
      var $109=HEAP32[(($108)>>2)];
      var $110=$c;
      var $111=$110 ^ $109;
      $c=$111;
      var $112=$c;
      var $113=$112 & 255;
      var $114=((((_crc_table+4096)|0)+($113<<2))|0);
      var $115=HEAP32[(($114)>>2)];
      var $116=$c;
      var $117=$116 >>> 8;
      var $118=$117 & 255;
      var $119=((((_crc_table+5120)|0)+($118<<2))|0);
      var $120=HEAP32[(($119)>>2)];
      var $121=$115 ^ $120;
      var $122=$c;
      var $123=$122 >>> 16;
      var $124=$123 & 255;
      var $125=((((_crc_table+6144)|0)+($124<<2))|0);
      var $126=HEAP32[(($125)>>2)];
      var $127=$121 ^ $126;
      var $128=$c;
      var $129=$128 >>> 24;
      var $130=((((_crc_table+7168)|0)+($129<<2))|0);
      var $131=HEAP32[(($130)>>2)];
      var $132=$127 ^ $131;
      $c=$132;
      var $133=$buf4;
      var $134=(($133+4)|0);
      $buf4=$134;
      var $135=HEAP32[(($134)>>2)];
      var $136=$c;
      var $137=$136 ^ $135;
      $c=$137;
      var $138=$c;
      var $139=$138 & 255;
      var $140=((((_crc_table+4096)|0)+($139<<2))|0);
      var $141=HEAP32[(($140)>>2)];
      var $142=$c;
      var $143=$142 >>> 8;
      var $144=$143 & 255;
      var $145=((((_crc_table+5120)|0)+($144<<2))|0);
      var $146=HEAP32[(($145)>>2)];
      var $147=$141 ^ $146;
      var $148=$c;
      var $149=$148 >>> 16;
      var $150=$149 & 255;
      var $151=((((_crc_table+6144)|0)+($150<<2))|0);
      var $152=HEAP32[(($151)>>2)];
      var $153=$147 ^ $152;
      var $154=$c;
      var $155=$154 >>> 24;
      var $156=((((_crc_table+7168)|0)+($155<<2))|0);
      var $157=HEAP32[(($156)>>2)];
      var $158=$153 ^ $157;
      $c=$158;
      var $159=$buf4;
      var $160=(($159+4)|0);
      $buf4=$160;
      var $161=HEAP32[(($160)>>2)];
      var $162=$c;
      var $163=$162 ^ $161;
      $c=$163;
      var $164=$c;
      var $165=$164 & 255;
      var $166=((((_crc_table+4096)|0)+($165<<2))|0);
      var $167=HEAP32[(($166)>>2)];
      var $168=$c;
      var $169=$168 >>> 8;
      var $170=$169 & 255;
      var $171=((((_crc_table+5120)|0)+($170<<2))|0);
      var $172=HEAP32[(($171)>>2)];
      var $173=$167 ^ $172;
      var $174=$c;
      var $175=$174 >>> 16;
      var $176=$175 & 255;
      var $177=((((_crc_table+6144)|0)+($176<<2))|0);
      var $178=HEAP32[(($177)>>2)];
      var $179=$173 ^ $178;
      var $180=$c;
      var $181=$180 >>> 24;
      var $182=((((_crc_table+7168)|0)+($181<<2))|0);
      var $183=HEAP32[(($182)>>2)];
      var $184=$179 ^ $183;
      $c=$184;
      var $185=$buf4;
      var $186=(($185+4)|0);
      $buf4=$186;
      var $187=HEAP32[(($186)>>2)];
      var $188=$c;
      var $189=$188 ^ $187;
      $c=$189;
      var $190=$c;
      var $191=$190 & 255;
      var $192=((((_crc_table+4096)|0)+($191<<2))|0);
      var $193=HEAP32[(($192)>>2)];
      var $194=$c;
      var $195=$194 >>> 8;
      var $196=$195 & 255;
      var $197=((((_crc_table+5120)|0)+($196<<2))|0);
      var $198=HEAP32[(($197)>>2)];
      var $199=$193 ^ $198;
      var $200=$c;
      var $201=$200 >>> 16;
      var $202=$201 & 255;
      var $203=((((_crc_table+6144)|0)+($202<<2))|0);
      var $204=HEAP32[(($203)>>2)];
      var $205=$199 ^ $204;
      var $206=$c;
      var $207=$206 >>> 24;
      var $208=((((_crc_table+7168)|0)+($207<<2))|0);
      var $209=HEAP32[(($208)>>2)];
      var $210=$205 ^ $209;
      $c=$210;
      var $211=$buf4;
      var $212=(($211+4)|0);
      $buf4=$212;
      var $213=HEAP32[(($212)>>2)];
      var $214=$c;
      var $215=$214 ^ $213;
      $c=$215;
      var $216=$c;
      var $217=$216 & 255;
      var $218=((((_crc_table+4096)|0)+($217<<2))|0);
      var $219=HEAP32[(($218)>>2)];
      var $220=$c;
      var $221=$220 >>> 8;
      var $222=$221 & 255;
      var $223=((((_crc_table+5120)|0)+($222<<2))|0);
      var $224=HEAP32[(($223)>>2)];
      var $225=$219 ^ $224;
      var $226=$c;
      var $227=$226 >>> 16;
      var $228=$227 & 255;
      var $229=((((_crc_table+6144)|0)+($228<<2))|0);
      var $230=HEAP32[(($229)>>2)];
      var $231=$225 ^ $230;
      var $232=$c;
      var $233=$232 >>> 24;
      var $234=((((_crc_table+7168)|0)+($233<<2))|0);
      var $235=HEAP32[(($234)>>2)];
      var $236=$231 ^ $235;
      $c=$236;
      var $237=$buf4;
      var $238=(($237+4)|0);
      $buf4=$238;
      var $239=HEAP32[(($238)>>2)];
      var $240=$c;
      var $241=$240 ^ $239;
      $c=$241;
      var $242=$c;
      var $243=$242 & 255;
      var $244=((((_crc_table+4096)|0)+($243<<2))|0);
      var $245=HEAP32[(($244)>>2)];
      var $246=$c;
      var $247=$246 >>> 8;
      var $248=$247 & 255;
      var $249=((((_crc_table+5120)|0)+($248<<2))|0);
      var $250=HEAP32[(($249)>>2)];
      var $251=$245 ^ $250;
      var $252=$c;
      var $253=$252 >>> 16;
      var $254=$253 & 255;
      var $255=((((_crc_table+6144)|0)+($254<<2))|0);
      var $256=HEAP32[(($255)>>2)];
      var $257=$251 ^ $256;
      var $258=$c;
      var $259=$258 >>> 24;
      var $260=((((_crc_table+7168)|0)+($259<<2))|0);
      var $261=HEAP32[(($260)>>2)];
      var $262=$257 ^ $261;
      $c=$262;
      var $263=$3;
      var $264=((($263)-(32))|0);
      $3=$264;
      __label__ = 8; break;
    case 10: 
      __label__ = 11; break;
    case 11: 
      var $267=$3;
      var $268=(($267)>>>0) >= 4;
      if ($268) { __label__ = 12; break; } else { __label__ = 13; break; }
    case 12: 
      var $270=$buf4;
      var $271=(($270+4)|0);
      $buf4=$271;
      var $272=HEAP32[(($271)>>2)];
      var $273=$c;
      var $274=$273 ^ $272;
      $c=$274;
      var $275=$c;
      var $276=$275 & 255;
      var $277=((((_crc_table+4096)|0)+($276<<2))|0);
      var $278=HEAP32[(($277)>>2)];
      var $279=$c;
      var $280=$279 >>> 8;
      var $281=$280 & 255;
      var $282=((((_crc_table+5120)|0)+($281<<2))|0);
      var $283=HEAP32[(($282)>>2)];
      var $284=$278 ^ $283;
      var $285=$c;
      var $286=$285 >>> 16;
      var $287=$286 & 255;
      var $288=((((_crc_table+6144)|0)+($287<<2))|0);
      var $289=HEAP32[(($288)>>2)];
      var $290=$284 ^ $289;
      var $291=$c;
      var $292=$291 >>> 24;
      var $293=((((_crc_table+7168)|0)+($292<<2))|0);
      var $294=HEAP32[(($293)>>2)];
      var $295=$290 ^ $294;
      $c=$295;
      var $296=$3;
      var $297=((($296)-(4))|0);
      $3=$297;
      __label__ = 11; break;
    case 13: 
      var $299=$buf4;
      var $300=(($299+4)|0);
      $buf4=$300;
      var $301=$buf4;
      var $302=$301;
      $2=$302;
      var $303=$3;
      var $304=(($303)|0)!=0;
      if ($304) { __label__ = 14; break; } else { __label__ = 18; break; }
    case 14: 
      __label__ = 15; break;
    case 15: 
      var $307=$c;
      var $308=$307 >>> 24;
      var $309=$2;
      var $310=(($309+1)|0);
      $2=$310;
      var $311=HEAPU8[($309)];
      var $312=(($311)&255);
      var $313=$308 ^ $312;
      var $314=((((_crc_table+4096)|0)+($313<<2))|0);
      var $315=HEAP32[(($314)>>2)];
      var $316=$c;
      var $317=$316 << 8;
      var $318=$315 ^ $317;
      $c=$318;
      __label__ = 16; break;
    case 16: 
      var $320=$3;
      var $321=((($320)-(1))|0);
      $3=$321;
      var $322=(($321)|0)!=0;
      if ($322) { __label__ = 15; break; } else { __label__ = 17; break; }
    case 17: 
      __label__ = 18; break;
    case 18: 
      var $325=$c;
      var $326=$325 ^ -1;
      $c=$326;
      var $327=$c;
      var $328=$327 >>> 24;
      var $329=$328 & 255;
      var $330=$c;
      var $331=$330 >>> 8;
      var $332=$331 & 65280;
      var $333=((($329)+($332))|0);
      var $334=$c;
      var $335=$334 & 65280;
      var $336=$335 << 8;
      var $337=((($333)+($336))|0);
      var $338=$c;
      var $339=$338 & 255;
      var $340=$339 << 24;
      var $341=((($337)+($340))|0);
      ;
      return $341;
    default: assert(0, "bad label: " + __label__);
  }
}
_crc32_big["X"]=1;

function _deflateInit_($strm, $level, $version, $stream_size) {
  ;
  var __label__;

  var $1;
  var $2;
  var $3;
  var $4;
  $1=$strm;
  $2=$level;
  $3=$version;
  $4=$stream_size;
  var $5=$1;
  var $6=$2;
  var $7=$3;
  var $8=$4;
  var $9=_deflateInit2_($5, $6, 8, 15, 8, 0, $7, $8);
  ;
  return $9;
}


function _deflateInit2_($strm, $level, $method, $windowBits, $memLevel, $strategy, $version, $stream_size) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $5;
      var $6;
      var $7;
      var $8;
      var $9;
      var $s;
      var $wrap;
      var $overlay;
      $2=$strm;
      $3=$level;
      $4=$method;
      $5=$windowBits;
      $6=$memLevel;
      $7=$strategy;
      $8=$version;
      $9=$stream_size;
      $wrap=1;
      var $10=$8;
      var $11=(($10)|0)==0;
      if ($11) { __label__ = 5; break; } else { __label__ = 3; break; }
    case 3: 
      var $13=$8;
      var $14=(($13)|0);
      var $15=HEAP8[($14)];
      var $16=(($15 << 24) >> 24);
      var $17=HEAP8[(((STRING_TABLE._deflateInit2__my_version)|0))];
      var $18=(($17 << 24) >> 24);
      var $19=(($16)|0)!=(($18)|0);
      if ($19) { __label__ = 5; break; } else { __label__ = 4; break; }
    case 4: 
      var $21=$9;
      var $22=(($21)|0)!=56;
      if ($22) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      $1=-6;
      __label__ = 39; break;
    case 6: 
      var $25=$2;
      var $26=(($25)|0)==0;
      if ($26) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      $1=-2;
      __label__ = 39; break;
    case 8: 
      var $29=$2;
      var $30=(($29+24)|0);
      HEAP32[(($30)>>2)]=0;
      var $31=$2;
      var $32=(($31+32)|0);
      var $33=HEAP32[(($32)>>2)];
      var $34=(($33)|0)==0;
      if ($34) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      var $36=$2;
      var $37=(($36+32)|0);
      HEAP32[(($37)>>2)]=2;
      var $38=$2;
      var $39=(($38+40)|0);
      HEAP32[(($39)>>2)]=0;
      __label__ = 10; break;
    case 10: 
      var $41=$2;
      var $42=(($41+36)|0);
      var $43=HEAP32[(($42)>>2)];
      var $44=(($43)|0)==0;
      if ($44) { __label__ = 11; break; } else { __label__ = 12; break; }
    case 11: 
      var $46=$2;
      var $47=(($46+36)|0);
      HEAP32[(($47)>>2)]=4;
      __label__ = 12; break;
    case 12: 
      var $49=$3;
      var $50=(($49)|0)==-1;
      if ($50) { __label__ = 13; break; } else { __label__ = 14; break; }
    case 13: 
      $3=6;
      __label__ = 14; break;
    case 14: 
      var $53=$5;
      var $54=(($53)|0) < 0;
      if ($54) { __label__ = 15; break; } else { __label__ = 16; break; }
    case 15: 
      $wrap=0;
      var $56=$5;
      var $57=(((-$56))|0);
      $5=$57;
      __label__ = 19; break;
    case 16: 
      var $59=$5;
      var $60=(($59)|0) > 15;
      if ($60) { __label__ = 17; break; } else { __label__ = 18; break; }
    case 17: 
      $wrap=2;
      var $62=$5;
      var $63=((($62)-(16))|0);
      $5=$63;
      __label__ = 18; break;
    case 18: 
      __label__ = 19; break;
    case 19: 
      var $66=$6;
      var $67=(($66)|0) < 1;
      if ($67) { __label__ = 28; break; } else { __label__ = 20; break; }
    case 20: 
      var $69=$6;
      var $70=(($69)|0) > 9;
      if ($70) { __label__ = 28; break; } else { __label__ = 21; break; }
    case 21: 
      var $72=$4;
      var $73=(($72)|0)!=8;
      if ($73) { __label__ = 28; break; } else { __label__ = 22; break; }
    case 22: 
      var $75=$5;
      var $76=(($75)|0) < 8;
      if ($76) { __label__ = 28; break; } else { __label__ = 23; break; }
    case 23: 
      var $78=$5;
      var $79=(($78)|0) > 15;
      if ($79) { __label__ = 28; break; } else { __label__ = 24; break; }
    case 24: 
      var $81=$3;
      var $82=(($81)|0) < 0;
      if ($82) { __label__ = 28; break; } else { __label__ = 25; break; }
    case 25: 
      var $84=$3;
      var $85=(($84)|0) > 9;
      if ($85) { __label__ = 28; break; } else { __label__ = 26; break; }
    case 26: 
      var $87=$7;
      var $88=(($87)|0) < 0;
      if ($88) { __label__ = 28; break; } else { __label__ = 27; break; }
    case 27: 
      var $90=$7;
      var $91=(($90)|0) > 4;
      if ($91) { __label__ = 28; break; } else { __label__ = 29; break; }
    case 28: 
      $1=-2;
      __label__ = 39; break;
    case 29: 
      var $94=$5;
      var $95=(($94)|0)==8;
      if ($95) { __label__ = 30; break; } else { __label__ = 31; break; }
    case 30: 
      $5=9;
      __label__ = 31; break;
    case 31: 
      var $98=$2;
      var $99=(($98+32)|0);
      var $100=HEAP32[(($99)>>2)];
      var $101=$2;
      var $102=(($101+40)|0);
      var $103=HEAP32[(($102)>>2)];
      var $104=FUNCTION_TABLE[$100]($103, 1, 5828);
      var $105=$104;
      $s=$105;
      var $106=$s;
      var $107=(($106)|0)==0;
      if ($107) { __label__ = 32; break; } else { __label__ = 33; break; }
    case 32: 
      $1=-4;
      __label__ = 39; break;
    case 33: 
      var $110=$s;
      var $111=$2;
      var $112=(($111+28)|0);
      HEAP32[(($112)>>2)]=$110;
      var $113=$2;
      var $114=$s;
      var $115=(($114)|0);
      HEAP32[(($115)>>2)]=$113;
      var $116=$wrap;
      var $117=$s;
      var $118=(($117+24)|0);
      HEAP32[(($118)>>2)]=$116;
      var $119=$s;
      var $120=(($119+28)|0);
      HEAP32[(($120)>>2)]=0;
      var $121=$5;
      var $122=$s;
      var $123=(($122+48)|0);
      HEAP32[(($123)>>2)]=$121;
      var $124=$s;
      var $125=(($124+48)|0);
      var $126=HEAP32[(($125)>>2)];
      var $127=1 << $126;
      var $128=$s;
      var $129=(($128+44)|0);
      HEAP32[(($129)>>2)]=$127;
      var $130=$s;
      var $131=(($130+44)|0);
      var $132=HEAP32[(($131)>>2)];
      var $133=((($132)-(1))|0);
      var $134=$s;
      var $135=(($134+52)|0);
      HEAP32[(($135)>>2)]=$133;
      var $136=$6;
      var $137=((($136)+(7))|0);
      var $138=$s;
      var $139=(($138+80)|0);
      HEAP32[(($139)>>2)]=$137;
      var $140=$s;
      var $141=(($140+80)|0);
      var $142=HEAP32[(($141)>>2)];
      var $143=1 << $142;
      var $144=$s;
      var $145=(($144+76)|0);
      HEAP32[(($145)>>2)]=$143;
      var $146=$s;
      var $147=(($146+76)|0);
      var $148=HEAP32[(($147)>>2)];
      var $149=((($148)-(1))|0);
      var $150=$s;
      var $151=(($150+84)|0);
      HEAP32[(($151)>>2)]=$149;
      var $152=$s;
      var $153=(($152+80)|0);
      var $154=HEAP32[(($153)>>2)];
      var $155=((($154)+(3))|0);
      var $156=((($155)-(1))|0);
      var $157=Math.floor(((($156)>>>0))/(3));
      var $158=$s;
      var $159=(($158+88)|0);
      HEAP32[(($159)>>2)]=$157;
      var $160=$2;
      var $161=(($160+32)|0);
      var $162=HEAP32[(($161)>>2)];
      var $163=$2;
      var $164=(($163+40)|0);
      var $165=HEAP32[(($164)>>2)];
      var $166=$s;
      var $167=(($166+44)|0);
      var $168=HEAP32[(($167)>>2)];
      var $169=FUNCTION_TABLE[$162]($165, $168, 2);
      var $170=$s;
      var $171=(($170+56)|0);
      HEAP32[(($171)>>2)]=$169;
      var $172=$2;
      var $173=(($172+32)|0);
      var $174=HEAP32[(($173)>>2)];
      var $175=$2;
      var $176=(($175+40)|0);
      var $177=HEAP32[(($176)>>2)];
      var $178=$s;
      var $179=(($178+44)|0);
      var $180=HEAP32[(($179)>>2)];
      var $181=FUNCTION_TABLE[$174]($177, $180, 2);
      var $182=$181;
      var $183=$s;
      var $184=(($183+64)|0);
      HEAP32[(($184)>>2)]=$182;
      var $185=$2;
      var $186=(($185+32)|0);
      var $187=HEAP32[(($186)>>2)];
      var $188=$2;
      var $189=(($188+40)|0);
      var $190=HEAP32[(($189)>>2)];
      var $191=$s;
      var $192=(($191+76)|0);
      var $193=HEAP32[(($192)>>2)];
      var $194=FUNCTION_TABLE[$187]($190, $193, 2);
      var $195=$194;
      var $196=$s;
      var $197=(($196+68)|0);
      HEAP32[(($197)>>2)]=$195;
      var $198=$s;
      var $199=(($198+5824)|0);
      HEAP32[(($199)>>2)]=0;
      var $200=$6;
      var $201=((($200)+(6))|0);
      var $202=1 << $201;
      var $203=$s;
      var $204=(($203+5788)|0);
      HEAP32[(($204)>>2)]=$202;
      var $205=$2;
      var $206=(($205+32)|0);
      var $207=HEAP32[(($206)>>2)];
      var $208=$2;
      var $209=(($208+40)|0);
      var $210=HEAP32[(($209)>>2)];
      var $211=$s;
      var $212=(($211+5788)|0);
      var $213=HEAP32[(($212)>>2)];
      var $214=FUNCTION_TABLE[$207]($210, $213, 4);
      var $215=$214;
      $overlay=$215;
      var $216=$overlay;
      var $217=$216;
      var $218=$s;
      var $219=(($218+8)|0);
      HEAP32[(($219)>>2)]=$217;
      var $220=$s;
      var $221=(($220+5788)|0);
      var $222=HEAP32[(($221)>>2)];
      var $223=((($222<<2))|0);
      var $224=$s;
      var $225=(($224+12)|0);
      HEAP32[(($225)>>2)]=$223;
      var $226=$s;
      var $227=(($226+56)|0);
      var $228=HEAP32[(($227)>>2)];
      var $229=(($228)|0)==0;
      if ($229) { __label__ = 37; break; } else { __label__ = 34; break; }
    case 34: 
      var $231=$s;
      var $232=(($231+64)|0);
      var $233=HEAP32[(($232)>>2)];
      var $234=(($233)|0)==0;
      if ($234) { __label__ = 37; break; } else { __label__ = 35; break; }
    case 35: 
      var $236=$s;
      var $237=(($236+68)|0);
      var $238=HEAP32[(($237)>>2)];
      var $239=(($238)|0)==0;
      if ($239) { __label__ = 37; break; } else { __label__ = 36; break; }
    case 36: 
      var $241=$s;
      var $242=(($241+8)|0);
      var $243=HEAP32[(($242)>>2)];
      var $244=(($243)|0)==0;
      if ($244) { __label__ = 37; break; } else { __label__ = 38; break; }
    case 37: 
      var $246=$s;
      var $247=(($246+4)|0);
      HEAP32[(($247)>>2)]=666;
      var $248=HEAP32[((((_z_errmsg+24)|0))>>2)];
      var $249=$2;
      var $250=(($249+24)|0);
      HEAP32[(($250)>>2)]=$248;
      var $251=$2;
      var $252=_deflateEnd($251);
      $1=-4;
      __label__ = 39; break;
    case 38: 
      var $254=$overlay;
      var $255=$s;
      var $256=(($255+5788)|0);
      var $257=HEAPU32[(($256)>>2)];
      var $258=Math.floor(((($257)>>>0))/(2));
      var $259=(($254+($258<<1))|0);
      var $260=$s;
      var $261=(($260+5796)|0);
      HEAP32[(($261)>>2)]=$259;
      var $262=$s;
      var $263=(($262+8)|0);
      var $264=HEAP32[(($263)>>2)];
      var $265=$s;
      var $266=(($265+5788)|0);
      var $267=HEAP32[(($266)>>2)];
      var $268=((($267)*(3))|0);
      var $269=(($264+$268)|0);
      var $270=$s;
      var $271=(($270+5784)|0);
      HEAP32[(($271)>>2)]=$269;
      var $272=$3;
      var $273=$s;
      var $274=(($273+132)|0);
      HEAP32[(($274)>>2)]=$272;
      var $275=$7;
      var $276=$s;
      var $277=(($276+136)|0);
      HEAP32[(($277)>>2)]=$275;
      var $278=$4;
      var $279=(($278) & 255);
      var $280=$s;
      var $281=(($280+36)|0);
      HEAP8[($281)]=$279;
      var $282=$2;
      var $283=_deflateReset($282);
      $1=$283;
      __label__ = 39; break;
    case 39: 
      var $285=$1;
      ;
      return $285;
    default: assert(0, "bad label: " + __label__);
  }
}
_deflateInit2_["X"]=1;

function _deflateEnd($strm) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $status;
      $2=$strm;
      var $3=$2;
      var $4=(($3)|0)==0;
      if ($4) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      var $6=$2;
      var $7=(($6+28)|0);
      var $8=HEAP32[(($7)>>2)];
      var $9=(($8)|0)==0;
      if ($9) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      $1=-2;
      __label__ = 22; break;
    case 5: 
      var $12=$2;
      var $13=(($12+28)|0);
      var $14=HEAP32[(($13)>>2)];
      var $15=(($14+4)|0);
      var $16=HEAP32[(($15)>>2)];
      $status=$16;
      var $17=$status;
      var $18=(($17)|0)!=42;
      if ($18) { __label__ = 6; break; } else { __label__ = 13; break; }
    case 6: 
      var $20=$status;
      var $21=(($20)|0)!=69;
      if ($21) { __label__ = 7; break; } else { __label__ = 13; break; }
    case 7: 
      var $23=$status;
      var $24=(($23)|0)!=73;
      if ($24) { __label__ = 8; break; } else { __label__ = 13; break; }
    case 8: 
      var $26=$status;
      var $27=(($26)|0)!=91;
      if ($27) { __label__ = 9; break; } else { __label__ = 13; break; }
    case 9: 
      var $29=$status;
      var $30=(($29)|0)!=103;
      if ($30) { __label__ = 10; break; } else { __label__ = 13; break; }
    case 10: 
      var $32=$status;
      var $33=(($32)|0)!=113;
      if ($33) { __label__ = 11; break; } else { __label__ = 13; break; }
    case 11: 
      var $35=$status;
      var $36=(($35)|0)!=666;
      if ($36) { __label__ = 12; break; } else { __label__ = 13; break; }
    case 12: 
      $1=-2;
      __label__ = 22; break;
    case 13: 
      var $39=$2;
      var $40=(($39+28)|0);
      var $41=HEAP32[(($40)>>2)];
      var $42=(($41+8)|0);
      var $43=HEAP32[(($42)>>2)];
      var $44=(($43)|0)!=0;
      if ($44) { __label__ = 14; break; } else { __label__ = 15; break; }
    case 14: 
      var $46=$2;
      var $47=(($46+36)|0);
      var $48=HEAP32[(($47)>>2)];
      var $49=$2;
      var $50=(($49+40)|0);
      var $51=HEAP32[(($50)>>2)];
      var $52=$2;
      var $53=(($52+28)|0);
      var $54=HEAP32[(($53)>>2)];
      var $55=(($54+8)|0);
      var $56=HEAP32[(($55)>>2)];
      FUNCTION_TABLE[$48]($51, $56);
      __label__ = 15; break;
    case 15: 
      var $58=$2;
      var $59=(($58+28)|0);
      var $60=HEAP32[(($59)>>2)];
      var $61=(($60+68)|0);
      var $62=HEAP32[(($61)>>2)];
      var $63=(($62)|0)!=0;
      if ($63) { __label__ = 16; break; } else { __label__ = 17; break; }
    case 16: 
      var $65=$2;
      var $66=(($65+36)|0);
      var $67=HEAP32[(($66)>>2)];
      var $68=$2;
      var $69=(($68+40)|0);
      var $70=HEAP32[(($69)>>2)];
      var $71=$2;
      var $72=(($71+28)|0);
      var $73=HEAP32[(($72)>>2)];
      var $74=(($73+68)|0);
      var $75=HEAP32[(($74)>>2)];
      var $76=$75;
      FUNCTION_TABLE[$67]($70, $76);
      __label__ = 17; break;
    case 17: 
      var $78=$2;
      var $79=(($78+28)|0);
      var $80=HEAP32[(($79)>>2)];
      var $81=(($80+64)|0);
      var $82=HEAP32[(($81)>>2)];
      var $83=(($82)|0)!=0;
      if ($83) { __label__ = 18; break; } else { __label__ = 19; break; }
    case 18: 
      var $85=$2;
      var $86=(($85+36)|0);
      var $87=HEAP32[(($86)>>2)];
      var $88=$2;
      var $89=(($88+40)|0);
      var $90=HEAP32[(($89)>>2)];
      var $91=$2;
      var $92=(($91+28)|0);
      var $93=HEAP32[(($92)>>2)];
      var $94=(($93+64)|0);
      var $95=HEAP32[(($94)>>2)];
      var $96=$95;
      FUNCTION_TABLE[$87]($90, $96);
      __label__ = 19; break;
    case 19: 
      var $98=$2;
      var $99=(($98+28)|0);
      var $100=HEAP32[(($99)>>2)];
      var $101=(($100+56)|0);
      var $102=HEAP32[(($101)>>2)];
      var $103=(($102)|0)!=0;
      if ($103) { __label__ = 20; break; } else { __label__ = 21; break; }
    case 20: 
      var $105=$2;
      var $106=(($105+36)|0);
      var $107=HEAP32[(($106)>>2)];
      var $108=$2;
      var $109=(($108+40)|0);
      var $110=HEAP32[(($109)>>2)];
      var $111=$2;
      var $112=(($111+28)|0);
      var $113=HEAP32[(($112)>>2)];
      var $114=(($113+56)|0);
      var $115=HEAP32[(($114)>>2)];
      FUNCTION_TABLE[$107]($110, $115);
      __label__ = 21; break;
    case 21: 
      var $117=$2;
      var $118=(($117+36)|0);
      var $119=HEAP32[(($118)>>2)];
      var $120=$2;
      var $121=(($120+40)|0);
      var $122=HEAP32[(($121)>>2)];
      var $123=$2;
      var $124=(($123+28)|0);
      var $125=HEAP32[(($124)>>2)];
      var $126=$125;
      FUNCTION_TABLE[$119]($122, $126);
      var $127=$2;
      var $128=(($127+28)|0);
      HEAP32[(($128)>>2)]=0;
      var $129=$status;
      var $130=(($129)|0)==113;
      var $131=$130 ? -3 : 0;
      $1=$131;
      __label__ = 22; break;
    case 22: 
      var $133=$1;
      ;
      return $133;
    default: assert(0, "bad label: " + __label__);
  }
}
_deflateEnd["X"]=1;

function _deflateReset($strm) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $ret;
      $1=$strm;
      var $2=$1;
      var $3=_deflateResetKeep($2);
      $ret=$3;
      var $4=$ret;
      var $5=(($4)|0)==0;
      if ($5) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $7=$1;
      var $8=(($7+28)|0);
      var $9=HEAP32[(($8)>>2)];
      _lm_init($9);
      __label__ = 4; break;
    case 4: 
      var $11=$ret;
      ;
      return $11;
    default: assert(0, "bad label: " + __label__);
  }
}


function _fill_window($s) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $n;
      var $m;
      var $p;
      var $more;
      var $wsize;
      var $str;
      var $curr;
      var $init;
      $1=$s;
      var $2=$1;
      var $3=(($2+44)|0);
      var $4=HEAP32[(($3)>>2)];
      $wsize=$4;
      __label__ = 3; break;
    case 3: 
      var $6=$1;
      var $7=(($6+60)|0);
      var $8=HEAP32[(($7)>>2)];
      var $9=$1;
      var $10=(($9+116)|0);
      var $11=HEAP32[(($10)>>2)];
      var $12=((($8)-($11))|0);
      var $13=$1;
      var $14=(($13+108)|0);
      var $15=HEAP32[(($14)>>2)];
      var $16=((($12)-($15))|0);
      $more=$16;
      var $17=$1;
      var $18=(($17+108)|0);
      var $19=HEAPU32[(($18)>>2)];
      var $20=$wsize;
      var $21=$1;
      var $22=(($21+44)|0);
      var $23=HEAP32[(($22)>>2)];
      var $24=((($23)-(262))|0);
      var $25=((($20)+($24))|0);
      var $26=(($19)>>>0) >= (($25)>>>0);
      if ($26) { __label__ = 4; break; } else { __label__ = 17; break; }
    case 4: 
      var $28=$1;
      var $29=(($28+56)|0);
      var $30=HEAP32[(($29)>>2)];
      var $31=$1;
      var $32=(($31+56)|0);
      var $33=HEAP32[(($32)>>2)];
      var $34=$wsize;
      var $35=(($33+$34)|0);
      var $36=$wsize;
      assert($36 % 1 === 0, 'memcpy given ' + $36 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');_memcpy($30, $35, $36, 1);
      var $37=$wsize;
      var $38=$1;
      var $39=(($38+112)|0);
      var $40=HEAP32[(($39)>>2)];
      var $41=((($40)-($37))|0);
      HEAP32[(($39)>>2)]=$41;
      var $42=$wsize;
      var $43=$1;
      var $44=(($43+108)|0);
      var $45=HEAP32[(($44)>>2)];
      var $46=((($45)-($42))|0);
      HEAP32[(($44)>>2)]=$46;
      var $47=$wsize;
      var $48=$1;
      var $49=(($48+92)|0);
      var $50=HEAP32[(($49)>>2)];
      var $51=((($50)-($47))|0);
      HEAP32[(($49)>>2)]=$51;
      var $52=$1;
      var $53=(($52+76)|0);
      var $54=HEAP32[(($53)>>2)];
      $n=$54;
      var $55=$n;
      var $56=$1;
      var $57=(($56+68)|0);
      var $58=HEAP32[(($57)>>2)];
      var $59=(($58+($55<<1))|0);
      $p=$59;
      __label__ = 5; break;
    case 5: 
      var $61=$p;
      var $62=((($61)-(2))|0);
      $p=$62;
      var $63=HEAPU16[(($62)>>1)];
      var $64=(($63)&65535);
      $m=$64;
      var $65=$m;
      var $66=$wsize;
      var $67=(($65)>>>0) >= (($66)>>>0);
      if ($67) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      var $69=$m;
      var $70=$wsize;
      var $71=((($69)-($70))|0);
      var $74 = $71;__label__ = 8; break;
    case 7: 
      var $74 = 0;__label__ = 8; break;
    case 8: 
      var $74;
      var $75=(($74) & 65535);
      var $76=$p;
      HEAP16[(($76)>>1)]=$75;
      __label__ = 9; break;
    case 9: 
      var $78=$n;
      var $79=((($78)-(1))|0);
      $n=$79;
      var $80=(($79)|0)!=0;
      if ($80) { __label__ = 5; break; } else { __label__ = 10; break; }
    case 10: 
      var $82=$wsize;
      $n=$82;
      var $83=$n;
      var $84=$1;
      var $85=(($84+64)|0);
      var $86=HEAP32[(($85)>>2)];
      var $87=(($86+($83<<1))|0);
      $p=$87;
      __label__ = 11; break;
    case 11: 
      var $89=$p;
      var $90=((($89)-(2))|0);
      $p=$90;
      var $91=HEAPU16[(($90)>>1)];
      var $92=(($91)&65535);
      $m=$92;
      var $93=$m;
      var $94=$wsize;
      var $95=(($93)>>>0) >= (($94)>>>0);
      if ($95) { __label__ = 12; break; } else { __label__ = 13; break; }
    case 12: 
      var $97=$m;
      var $98=$wsize;
      var $99=((($97)-($98))|0);
      var $102 = $99;__label__ = 14; break;
    case 13: 
      var $102 = 0;__label__ = 14; break;
    case 14: 
      var $102;
      var $103=(($102) & 65535);
      var $104=$p;
      HEAP16[(($104)>>1)]=$103;
      __label__ = 15; break;
    case 15: 
      var $106=$n;
      var $107=((($106)-(1))|0);
      $n=$107;
      var $108=(($107)|0)!=0;
      if ($108) { __label__ = 11; break; } else { __label__ = 16; break; }
    case 16: 
      var $110=$wsize;
      var $111=$more;
      var $112=((($111)+($110))|0);
      $more=$112;
      __label__ = 17; break;
    case 17: 
      var $114=$1;
      var $115=(($114)|0);
      var $116=HEAP32[(($115)>>2)];
      var $117=(($116+4)|0);
      var $118=HEAP32[(($117)>>2)];
      var $119=(($118)|0)==0;
      if ($119) { __label__ = 18; break; } else { __label__ = 19; break; }
    case 18: 
      __label__ = 30; break;
    case 19: 
      var $122=$1;
      var $123=(($122)|0);
      var $124=HEAP32[(($123)>>2)];
      var $125=$1;
      var $126=(($125+56)|0);
      var $127=HEAP32[(($126)>>2)];
      var $128=$1;
      var $129=(($128+108)|0);
      var $130=HEAP32[(($129)>>2)];
      var $131=(($127+$130)|0);
      var $132=$1;
      var $133=(($132+116)|0);
      var $134=HEAP32[(($133)>>2)];
      var $135=(($131+$134)|0);
      var $136=$more;
      var $137=_read_buf($124, $135, $136);
      $n=$137;
      var $138=$n;
      var $139=$1;
      var $140=(($139+116)|0);
      var $141=HEAP32[(($140)>>2)];
      var $142=((($141)+($138))|0);
      HEAP32[(($140)>>2)]=$142;
      var $143=$1;
      var $144=(($143+116)|0);
      var $145=HEAP32[(($144)>>2)];
      var $146=$1;
      var $147=(($146+5812)|0);
      var $148=HEAP32[(($147)>>2)];
      var $149=((($145)+($148))|0);
      var $150=(($149)>>>0) >= 3;
      if ($150) { __label__ = 20; break; } else { __label__ = 26; break; }
    case 20: 
      var $152=$1;
      var $153=(($152+108)|0);
      var $154=HEAP32[(($153)>>2)];
      var $155=$1;
      var $156=(($155+5812)|0);
      var $157=HEAP32[(($156)>>2)];
      var $158=((($154)-($157))|0);
      $str=$158;
      var $159=$str;
      var $160=$1;
      var $161=(($160+56)|0);
      var $162=HEAP32[(($161)>>2)];
      var $163=(($162+$159)|0);
      var $164=HEAPU8[($163)];
      var $165=(($164)&255);
      var $166=$1;
      var $167=(($166+72)|0);
      HEAP32[(($167)>>2)]=$165;
      var $168=$1;
      var $169=(($168+72)|0);
      var $170=HEAP32[(($169)>>2)];
      var $171=$1;
      var $172=(($171+88)|0);
      var $173=HEAP32[(($172)>>2)];
      var $174=$170 << $173;
      var $175=$str;
      var $176=((($175)+(1))|0);
      var $177=$1;
      var $178=(($177+56)|0);
      var $179=HEAP32[(($178)>>2)];
      var $180=(($179+$176)|0);
      var $181=HEAPU8[($180)];
      var $182=(($181)&255);
      var $183=$174 ^ $182;
      var $184=$1;
      var $185=(($184+84)|0);
      var $186=HEAP32[(($185)>>2)];
      var $187=$183 & $186;
      var $188=$1;
      var $189=(($188+72)|0);
      HEAP32[(($189)>>2)]=$187;
      __label__ = 21; break;
    case 21: 
      var $191=$1;
      var $192=(($191+5812)|0);
      var $193=HEAP32[(($192)>>2)];
      var $194=(($193)|0)!=0;
      if ($194) { __label__ = 22; break; } else { __label__ = 25; break; }
    case 22: 
      var $196=$1;
      var $197=(($196+72)|0);
      var $198=HEAP32[(($197)>>2)];
      var $199=$1;
      var $200=(($199+88)|0);
      var $201=HEAP32[(($200)>>2)];
      var $202=$198 << $201;
      var $203=$str;
      var $204=((($203)+(3))|0);
      var $205=((($204)-(1))|0);
      var $206=$1;
      var $207=(($206+56)|0);
      var $208=HEAP32[(($207)>>2)];
      var $209=(($208+$205)|0);
      var $210=HEAPU8[($209)];
      var $211=(($210)&255);
      var $212=$202 ^ $211;
      var $213=$1;
      var $214=(($213+84)|0);
      var $215=HEAP32[(($214)>>2)];
      var $216=$212 & $215;
      var $217=$1;
      var $218=(($217+72)|0);
      HEAP32[(($218)>>2)]=$216;
      var $219=$1;
      var $220=(($219+72)|0);
      var $221=HEAP32[(($220)>>2)];
      var $222=$1;
      var $223=(($222+68)|0);
      var $224=HEAP32[(($223)>>2)];
      var $225=(($224+($221<<1))|0);
      var $226=HEAP16[(($225)>>1)];
      var $227=$str;
      var $228=$1;
      var $229=(($228+52)|0);
      var $230=HEAP32[(($229)>>2)];
      var $231=$227 & $230;
      var $232=$1;
      var $233=(($232+64)|0);
      var $234=HEAP32[(($233)>>2)];
      var $235=(($234+($231<<1))|0);
      HEAP16[(($235)>>1)]=$226;
      var $236=$str;
      var $237=(($236) & 65535);
      var $238=$1;
      var $239=(($238+72)|0);
      var $240=HEAP32[(($239)>>2)];
      var $241=$1;
      var $242=(($241+68)|0);
      var $243=HEAP32[(($242)>>2)];
      var $244=(($243+($240<<1))|0);
      HEAP16[(($244)>>1)]=$237;
      var $245=$str;
      var $246=((($245)+(1))|0);
      $str=$246;
      var $247=$1;
      var $248=(($247+5812)|0);
      var $249=HEAP32[(($248)>>2)];
      var $250=((($249)-(1))|0);
      HEAP32[(($248)>>2)]=$250;
      var $251=$1;
      var $252=(($251+116)|0);
      var $253=HEAP32[(($252)>>2)];
      var $254=$1;
      var $255=(($254+5812)|0);
      var $256=HEAP32[(($255)>>2)];
      var $257=((($253)+($256))|0);
      var $258=(($257)>>>0) < 3;
      if ($258) { __label__ = 23; break; } else { __label__ = 24; break; }
    case 23: 
      __label__ = 25; break;
    case 24: 
      __label__ = 21; break;
    case 25: 
      __label__ = 26; break;
    case 26: 
      __label__ = 27; break;
    case 27: 
      var $264=$1;
      var $265=(($264+116)|0);
      var $266=HEAPU32[(($265)>>2)];
      var $267=(($266)>>>0) < 262;
      if ($267) { __label__ = 28; break; } else { var $276 = 0;__label__ = 29; break; }
    case 28: 
      var $269=$1;
      var $270=(($269)|0);
      var $271=HEAP32[(($270)>>2)];
      var $272=(($271+4)|0);
      var $273=HEAP32[(($272)>>2)];
      var $274=(($273)|0)!=0;
      var $276 = $274;__label__ = 29; break;
    case 29: 
      var $276;
      if ($276) { __label__ = 3; break; } else { __label__ = 30; break; }
    case 30: 
      var $278=$1;
      var $279=(($278+5824)|0);
      var $280=HEAPU32[(($279)>>2)];
      var $281=$1;
      var $282=(($281+60)|0);
      var $283=HEAPU32[(($282)>>2)];
      var $284=(($280)>>>0) < (($283)>>>0);
      if ($284) { __label__ = 31; break; } else { __label__ = 41; break; }
    case 31: 
      var $286=$1;
      var $287=(($286+108)|0);
      var $288=HEAP32[(($287)>>2)];
      var $289=$1;
      var $290=(($289+116)|0);
      var $291=HEAP32[(($290)>>2)];
      var $292=((($288)+($291))|0);
      $curr=$292;
      var $293=$1;
      var $294=(($293+5824)|0);
      var $295=HEAPU32[(($294)>>2)];
      var $296=$curr;
      var $297=(($295)>>>0) < (($296)>>>0);
      if ($297) { __label__ = 32; break; } else { __label__ = 35; break; }
    case 32: 
      var $299=$1;
      var $300=(($299+60)|0);
      var $301=HEAP32[(($300)>>2)];
      var $302=$curr;
      var $303=((($301)-($302))|0);
      $init=$303;
      var $304=$init;
      var $305=(($304)>>>0) > 258;
      if ($305) { __label__ = 33; break; } else { __label__ = 34; break; }
    case 33: 
      $init=258;
      __label__ = 34; break;
    case 34: 
      var $308=$1;
      var $309=(($308+56)|0);
      var $310=HEAP32[(($309)>>2)];
      var $311=$curr;
      var $312=(($310+$311)|0);
      var $313=$init;
      _memset($312, 0, $313, 1);
      var $314=$curr;
      var $315=$init;
      var $316=((($314)+($315))|0);
      var $317=$1;
      var $318=(($317+5824)|0);
      HEAP32[(($318)>>2)]=$316;
      __label__ = 40; break;
    case 35: 
      var $320=$1;
      var $321=(($320+5824)|0);
      var $322=HEAPU32[(($321)>>2)];
      var $323=$curr;
      var $324=((($323)+(258))|0);
      var $325=(($322)>>>0) < (($324)>>>0);
      if ($325) { __label__ = 36; break; } else { __label__ = 39; break; }
    case 36: 
      var $327=$curr;
      var $328=((($327)+(258))|0);
      var $329=$1;
      var $330=(($329+5824)|0);
      var $331=HEAP32[(($330)>>2)];
      var $332=((($328)-($331))|0);
      $init=$332;
      var $333=$init;
      var $334=$1;
      var $335=(($334+60)|0);
      var $336=HEAP32[(($335)>>2)];
      var $337=$1;
      var $338=(($337+5824)|0);
      var $339=HEAP32[(($338)>>2)];
      var $340=((($336)-($339))|0);
      var $341=(($333)>>>0) > (($340)>>>0);
      if ($341) { __label__ = 37; break; } else { __label__ = 38; break; }
    case 37: 
      var $343=$1;
      var $344=(($343+60)|0);
      var $345=HEAP32[(($344)>>2)];
      var $346=$1;
      var $347=(($346+5824)|0);
      var $348=HEAP32[(($347)>>2)];
      var $349=((($345)-($348))|0);
      $init=$349;
      __label__ = 38; break;
    case 38: 
      var $351=$1;
      var $352=(($351+56)|0);
      var $353=HEAP32[(($352)>>2)];
      var $354=$1;
      var $355=(($354+5824)|0);
      var $356=HEAP32[(($355)>>2)];
      var $357=(($353+$356)|0);
      var $358=$init;
      _memset($357, 0, $358, 1);
      var $359=$init;
      var $360=$1;
      var $361=(($360+5824)|0);
      var $362=HEAP32[(($361)>>2)];
      var $363=((($362)+($359))|0);
      HEAP32[(($361)>>2)]=$363;
      __label__ = 39; break;
    case 39: 
      __label__ = 40; break;
    case 40: 
      __label__ = 41; break;
    case 41: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_fill_window["X"]=1;

function _deflateResetKeep($strm) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $s;
      $2=$strm;
      var $3=$2;
      var $4=(($3)|0)==0;
      if ($4) { __label__ = 6; break; } else { __label__ = 3; break; }
    case 3: 
      var $6=$2;
      var $7=(($6+28)|0);
      var $8=HEAP32[(($7)>>2)];
      var $9=(($8)|0)==0;
      if ($9) { __label__ = 6; break; } else { __label__ = 4; break; }
    case 4: 
      var $11=$2;
      var $12=(($11+32)|0);
      var $13=HEAP32[(($12)>>2)];
      var $14=(($13)|0)==0;
      if ($14) { __label__ = 6; break; } else { __label__ = 5; break; }
    case 5: 
      var $16=$2;
      var $17=(($16+36)|0);
      var $18=HEAP32[(($17)>>2)];
      var $19=(($18)|0)==0;
      if ($19) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      $1=-2;
      __label__ = 13; break;
    case 7: 
      var $22=$2;
      var $23=(($22+20)|0);
      HEAP32[(($23)>>2)]=0;
      var $24=$2;
      var $25=(($24+8)|0);
      HEAP32[(($25)>>2)]=0;
      var $26=$2;
      var $27=(($26+24)|0);
      HEAP32[(($27)>>2)]=0;
      var $28=$2;
      var $29=(($28+44)|0);
      HEAP32[(($29)>>2)]=2;
      var $30=$2;
      var $31=(($30+28)|0);
      var $32=HEAP32[(($31)>>2)];
      $s=$32;
      var $33=$s;
      var $34=(($33+20)|0);
      HEAP32[(($34)>>2)]=0;
      var $35=$s;
      var $36=(($35+8)|0);
      var $37=HEAP32[(($36)>>2)];
      var $38=$s;
      var $39=(($38+16)|0);
      HEAP32[(($39)>>2)]=$37;
      var $40=$s;
      var $41=(($40+24)|0);
      var $42=HEAP32[(($41)>>2)];
      var $43=(($42)|0) < 0;
      if ($43) { __label__ = 8; break; } else { __label__ = 9; break; }
    case 8: 
      var $45=$s;
      var $46=(($45+24)|0);
      var $47=HEAP32[(($46)>>2)];
      var $48=(((-$47))|0);
      var $49=$s;
      var $50=(($49+24)|0);
      HEAP32[(($50)>>2)]=$48;
      __label__ = 9; break;
    case 9: 
      var $52=$s;
      var $53=(($52+24)|0);
      var $54=HEAP32[(($53)>>2)];
      var $55=(($54)|0)!=0;
      var $56=$55 ? 42 : 113;
      var $57=$s;
      var $58=(($57+4)|0);
      HEAP32[(($58)>>2)]=$56;
      var $59=$s;
      var $60=(($59+24)|0);
      var $61=HEAP32[(($60)>>2)];
      var $62=(($61)|0)==2;
      if ($62) { __label__ = 10; break; } else { __label__ = 11; break; }
    case 10: 
      var $64=_crc32(0, 0, 0);
      var $68 = $64;__label__ = 12; break;
    case 11: 
      var $66=_adler32(0, 0, 0);
      var $68 = $66;__label__ = 12; break;
    case 12: 
      var $68;
      var $69=$2;
      var $70=(($69+48)|0);
      HEAP32[(($70)>>2)]=$68;
      var $71=$s;
      var $72=(($71+40)|0);
      HEAP32[(($72)>>2)]=0;
      var $73=$s;
      __tr_init($73);
      $1=0;
      __label__ = 13; break;
    case 13: 
      var $75=$1;
      ;
      return $75;
    default: assert(0, "bad label: " + __label__);
  }
}
_deflateResetKeep["X"]=1;

function _lm_init($s) {
  ;
  var __label__;

  var $1;
  $1=$s;
  var $2=$1;
  var $3=(($2+44)|0);
  var $4=HEAP32[(($3)>>2)];
  var $5=((($4<<1))|0);
  var $6=$1;
  var $7=(($6+60)|0);
  HEAP32[(($7)>>2)]=$5;
  var $8=$1;
  var $9=(($8+76)|0);
  var $10=HEAP32[(($9)>>2)];
  var $11=((($10)-(1))|0);
  var $12=$1;
  var $13=(($12+68)|0);
  var $14=HEAP32[(($13)>>2)];
  var $15=(($14+($11<<1))|0);
  HEAP16[(($15)>>1)]=0;
  var $16=$1;
  var $17=(($16+68)|0);
  var $18=HEAP32[(($17)>>2)];
  var $19=$18;
  var $20=$1;
  var $21=(($20+76)|0);
  var $22=HEAP32[(($21)>>2)];
  var $23=((($22)-(1))|0);
  var $24=((($23<<1))|0);
  _memset($19, 0, $24, 1);
  var $25=$1;
  var $26=(($25+132)|0);
  var $27=HEAP32[(($26)>>2)];
  var $28=((_configuration_table+($27)*(12))|0);
  var $29=(($28+2)|0);
  var $30=HEAPU16[(($29)>>1)];
  var $31=(($30)&65535);
  var $32=$1;
  var $33=(($32+128)|0);
  HEAP32[(($33)>>2)]=$31;
  var $34=$1;
  var $35=(($34+132)|0);
  var $36=HEAP32[(($35)>>2)];
  var $37=((_configuration_table+($36)*(12))|0);
  var $38=(($37)|0);
  var $39=HEAPU16[(($38)>>1)];
  var $40=(($39)&65535);
  var $41=$1;
  var $42=(($41+140)|0);
  HEAP32[(($42)>>2)]=$40;
  var $43=$1;
  var $44=(($43+132)|0);
  var $45=HEAP32[(($44)>>2)];
  var $46=((_configuration_table+($45)*(12))|0);
  var $47=(($46+4)|0);
  var $48=HEAPU16[(($47)>>1)];
  var $49=(($48)&65535);
  var $50=$1;
  var $51=(($50+144)|0);
  HEAP32[(($51)>>2)]=$49;
  var $52=$1;
  var $53=(($52+132)|0);
  var $54=HEAP32[(($53)>>2)];
  var $55=((_configuration_table+($54)*(12))|0);
  var $56=(($55+6)|0);
  var $57=HEAPU16[(($56)>>1)];
  var $58=(($57)&65535);
  var $59=$1;
  var $60=(($59+124)|0);
  HEAP32[(($60)>>2)]=$58;
  var $61=$1;
  var $62=(($61+108)|0);
  HEAP32[(($62)>>2)]=0;
  var $63=$1;
  var $64=(($63+92)|0);
  HEAP32[(($64)>>2)]=0;
  var $65=$1;
  var $66=(($65+116)|0);
  HEAP32[(($66)>>2)]=0;
  var $67=$1;
  var $68=(($67+5812)|0);
  HEAP32[(($68)>>2)]=0;
  var $69=$1;
  var $70=(($69+120)|0);
  HEAP32[(($70)>>2)]=2;
  var $71=$1;
  var $72=(($71+96)|0);
  HEAP32[(($72)>>2)]=2;
  var $73=$1;
  var $74=(($73+104)|0);
  HEAP32[(($74)>>2)]=0;
  var $75=$1;
  var $76=(($75+72)|0);
  HEAP32[(($76)>>2)]=0;
  ;
  return;
}
_lm_init["X"]=1;

function _deflate($strm, $flush) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $old_flush;
      var $s;
      var $header;
      var $level_flags;
      var $beg;
      var $beg1;
      var $val;
      var $beg2;
      var $val3;
      var $bstate;
      $2=$strm;
      $3=$flush;
      var $4=$2;
      var $5=(($4)|0)==0;
      if ($5) { __label__ = 6; break; } else { __label__ = 3; break; }
    case 3: 
      var $7=$2;
      var $8=(($7+28)|0);
      var $9=HEAP32[(($8)>>2)];
      var $10=(($9)|0)==0;
      if ($10) { __label__ = 6; break; } else { __label__ = 4; break; }
    case 4: 
      var $12=$3;
      var $13=(($12)|0) > 5;
      if ($13) { __label__ = 6; break; } else { __label__ = 5; break; }
    case 5: 
      var $15=$3;
      var $16=(($15)|0) < 0;
      if ($16) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      $1=-2;
      __label__ = 174; break;
    case 7: 
      var $19=$2;
      var $20=(($19+28)|0);
      var $21=HEAP32[(($20)>>2)];
      $s=$21;
      var $22=$2;
      var $23=(($22+12)|0);
      var $24=HEAP32[(($23)>>2)];
      var $25=(($24)|0)==0;
      if ($25) { __label__ = 12; break; } else { __label__ = 8; break; }
    case 8: 
      var $27=$2;
      var $28=(($27)|0);
      var $29=HEAP32[(($28)>>2)];
      var $30=(($29)|0)==0;
      if ($30) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      var $32=$2;
      var $33=(($32+4)|0);
      var $34=HEAP32[(($33)>>2)];
      var $35=(($34)|0)!=0;
      if ($35) { __label__ = 12; break; } else { __label__ = 10; break; }
    case 10: 
      var $37=$s;
      var $38=(($37+4)|0);
      var $39=HEAP32[(($38)>>2)];
      var $40=(($39)|0)==666;
      if ($40) { __label__ = 11; break; } else { __label__ = 13; break; }
    case 11: 
      var $42=$3;
      var $43=(($42)|0)!=4;
      if ($43) { __label__ = 12; break; } else { __label__ = 13; break; }
    case 12: 
      var $45=HEAP32[((((_z_errmsg+16)|0))>>2)];
      var $46=$2;
      var $47=(($46+24)|0);
      HEAP32[(($47)>>2)]=$45;
      $1=-2;
      __label__ = 174; break;
    case 13: 
      var $49=$2;
      var $50=(($49+16)|0);
      var $51=HEAP32[(($50)>>2)];
      var $52=(($51)|0)==0;
      if ($52) { __label__ = 14; break; } else { __label__ = 15; break; }
    case 14: 
      var $54=HEAP32[((((_z_errmsg+28)|0))>>2)];
      var $55=$2;
      var $56=(($55+24)|0);
      HEAP32[(($56)>>2)]=$54;
      $1=-5;
      __label__ = 174; break;
    case 15: 
      var $58=$2;
      var $59=$s;
      var $60=(($59)|0);
      HEAP32[(($60)>>2)]=$58;
      var $61=$s;
      var $62=(($61+40)|0);
      var $63=HEAP32[(($62)>>2)];
      $old_flush=$63;
      var $64=$3;
      var $65=$s;
      var $66=(($65+40)|0);
      HEAP32[(($66)>>2)]=$64;
      var $67=$s;
      var $68=(($67+4)|0);
      var $69=HEAP32[(($68)>>2)];
      var $70=(($69)|0)==42;
      if ($70) { __label__ = 16; break; } else { __label__ = 51; break; }
    case 16: 
      var $72=$s;
      var $73=(($72+24)|0);
      var $74=HEAP32[(($73)>>2)];
      var $75=(($74)|0)==2;
      if ($75) { __label__ = 17; break; } else { __label__ = 35; break; }
    case 17: 
      var $77=_crc32(0, 0, 0);
      var $78=$2;
      var $79=(($78+48)|0);
      HEAP32[(($79)>>2)]=$77;
      var $80=$s;
      var $81=(($80+20)|0);
      var $82=HEAP32[(($81)>>2)];
      var $83=((($82)+(1))|0);
      HEAP32[(($81)>>2)]=$83;
      var $84=$s;
      var $85=(($84+8)|0);
      var $86=HEAP32[(($85)>>2)];
      var $87=(($86+$82)|0);
      HEAP8[($87)]=31;
      var $88=$s;
      var $89=(($88+20)|0);
      var $90=HEAP32[(($89)>>2)];
      var $91=((($90)+(1))|0);
      HEAP32[(($89)>>2)]=$91;
      var $92=$s;
      var $93=(($92+8)|0);
      var $94=HEAP32[(($93)>>2)];
      var $95=(($94+$90)|0);
      HEAP8[($95)]=-117;
      var $96=$s;
      var $97=(($96+20)|0);
      var $98=HEAP32[(($97)>>2)];
      var $99=((($98)+(1))|0);
      HEAP32[(($97)>>2)]=$99;
      var $100=$s;
      var $101=(($100+8)|0);
      var $102=HEAP32[(($101)>>2)];
      var $103=(($102+$98)|0);
      HEAP8[($103)]=8;
      var $104=$s;
      var $105=(($104+28)|0);
      var $106=HEAP32[(($105)>>2)];
      var $107=(($106)|0)==0;
      if ($107) { __label__ = 18; break; } else { __label__ = 24; break; }
    case 18: 
      var $109=$s;
      var $110=(($109+20)|0);
      var $111=HEAP32[(($110)>>2)];
      var $112=((($111)+(1))|0);
      HEAP32[(($110)>>2)]=$112;
      var $113=$s;
      var $114=(($113+8)|0);
      var $115=HEAP32[(($114)>>2)];
      var $116=(($115+$111)|0);
      HEAP8[($116)]=0;
      var $117=$s;
      var $118=(($117+20)|0);
      var $119=HEAP32[(($118)>>2)];
      var $120=((($119)+(1))|0);
      HEAP32[(($118)>>2)]=$120;
      var $121=$s;
      var $122=(($121+8)|0);
      var $123=HEAP32[(($122)>>2)];
      var $124=(($123+$119)|0);
      HEAP8[($124)]=0;
      var $125=$s;
      var $126=(($125+20)|0);
      var $127=HEAP32[(($126)>>2)];
      var $128=((($127)+(1))|0);
      HEAP32[(($126)>>2)]=$128;
      var $129=$s;
      var $130=(($129+8)|0);
      var $131=HEAP32[(($130)>>2)];
      var $132=(($131+$127)|0);
      HEAP8[($132)]=0;
      var $133=$s;
      var $134=(($133+20)|0);
      var $135=HEAP32[(($134)>>2)];
      var $136=((($135)+(1))|0);
      HEAP32[(($134)>>2)]=$136;
      var $137=$s;
      var $138=(($137+8)|0);
      var $139=HEAP32[(($138)>>2)];
      var $140=(($139+$135)|0);
      HEAP8[($140)]=0;
      var $141=$s;
      var $142=(($141+20)|0);
      var $143=HEAP32[(($142)>>2)];
      var $144=((($143)+(1))|0);
      HEAP32[(($142)>>2)]=$144;
      var $145=$s;
      var $146=(($145+8)|0);
      var $147=HEAP32[(($146)>>2)];
      var $148=(($147+$143)|0);
      HEAP8[($148)]=0;
      var $149=$s;
      var $150=(($149+132)|0);
      var $151=HEAP32[(($150)>>2)];
      var $152=(($151)|0)==9;
      if ($152) { __label__ = 19; break; } else { __label__ = 20; break; }
    case 19: 
      var $168 = 2;__label__ = 23; break;
    case 20: 
      var $155=$s;
      var $156=(($155+136)|0);
      var $157=HEAP32[(($156)>>2)];
      var $158=(($157)|0) >= 2;
      if ($158) { var $165 = 1;__label__ = 22; break; } else { __label__ = 21; break; }
    case 21: 
      var $160=$s;
      var $161=(($160+132)|0);
      var $162=HEAP32[(($161)>>2)];
      var $163=(($162)|0) < 2;
      var $165 = $163;__label__ = 22; break;
    case 22: 
      var $165;
      var $166=$165 ? 4 : 0;
      var $168 = $166;__label__ = 23; break;
    case 23: 
      var $168;
      var $169=(($168) & 255);
      var $170=$s;
      var $171=(($170+20)|0);
      var $172=HEAP32[(($171)>>2)];
      var $173=((($172)+(1))|0);
      HEAP32[(($171)>>2)]=$173;
      var $174=$s;
      var $175=(($174+8)|0);
      var $176=HEAP32[(($175)>>2)];
      var $177=(($176+$172)|0);
      HEAP8[($177)]=$169;
      var $178=$s;
      var $179=(($178+20)|0);
      var $180=HEAP32[(($179)>>2)];
      var $181=((($180)+(1))|0);
      HEAP32[(($179)>>2)]=$181;
      var $182=$s;
      var $183=(($182+8)|0);
      var $184=HEAP32[(($183)>>2)];
      var $185=(($184+$180)|0);
      HEAP8[($185)]=3;
      var $186=$s;
      var $187=(($186+4)|0);
      HEAP32[(($187)>>2)]=113;
      __label__ = 34; break;
    case 24: 
      var $189=$s;
      var $190=(($189+28)|0);
      var $191=HEAP32[(($190)>>2)];
      var $192=(($191)|0);
      var $193=HEAP32[(($192)>>2)];
      var $194=(($193)|0)!=0;
      var $195=$194 ? 1 : 0;
      var $196=$s;
      var $197=(($196+28)|0);
      var $198=HEAP32[(($197)>>2)];
      var $199=(($198+44)|0);
      var $200=HEAP32[(($199)>>2)];
      var $201=(($200)|0)!=0;
      var $202=$201 ? 2 : 0;
      var $203=((($195)+($202))|0);
      var $204=$s;
      var $205=(($204+28)|0);
      var $206=HEAP32[(($205)>>2)];
      var $207=(($206+16)|0);
      var $208=HEAP32[(($207)>>2)];
      var $209=(($208)|0)==0;
      var $210=$209 ? 0 : 4;
      var $211=((($203)+($210))|0);
      var $212=$s;
      var $213=(($212+28)|0);
      var $214=HEAP32[(($213)>>2)];
      var $215=(($214+28)|0);
      var $216=HEAP32[(($215)>>2)];
      var $217=(($216)|0)==0;
      var $218=$217 ? 0 : 8;
      var $219=((($211)+($218))|0);
      var $220=$s;
      var $221=(($220+28)|0);
      var $222=HEAP32[(($221)>>2)];
      var $223=(($222+36)|0);
      var $224=HEAP32[(($223)>>2)];
      var $225=(($224)|0)==0;
      var $226=$225 ? 0 : 16;
      var $227=((($219)+($226))|0);
      var $228=(($227) & 255);
      var $229=$s;
      var $230=(($229+20)|0);
      var $231=HEAP32[(($230)>>2)];
      var $232=((($231)+(1))|0);
      HEAP32[(($230)>>2)]=$232;
      var $233=$s;
      var $234=(($233+8)|0);
      var $235=HEAP32[(($234)>>2)];
      var $236=(($235+$231)|0);
      HEAP8[($236)]=$228;
      var $237=$s;
      var $238=(($237+28)|0);
      var $239=HEAP32[(($238)>>2)];
      var $240=(($239+4)|0);
      var $241=HEAP32[(($240)>>2)];
      var $242=$241 & 255;
      var $243=(($242) & 255);
      var $244=$s;
      var $245=(($244+20)|0);
      var $246=HEAP32[(($245)>>2)];
      var $247=((($246)+(1))|0);
      HEAP32[(($245)>>2)]=$247;
      var $248=$s;
      var $249=(($248+8)|0);
      var $250=HEAP32[(($249)>>2)];
      var $251=(($250+$246)|0);
      HEAP8[($251)]=$243;
      var $252=$s;
      var $253=(($252+28)|0);
      var $254=HEAP32[(($253)>>2)];
      var $255=(($254+4)|0);
      var $256=HEAPU32[(($255)>>2)];
      var $257=$256 >>> 8;
      var $258=$257 & 255;
      var $259=(($258) & 255);
      var $260=$s;
      var $261=(($260+20)|0);
      var $262=HEAPU32[(($261)>>2)];
      var $263=((($262)+(1))|0);
      HEAP32[(($261)>>2)]=$263;
      var $264=$s;
      var $265=(($264+8)|0);
      var $266=HEAP32[(($265)>>2)];
      var $267=(($266+$262)|0);
      HEAP8[($267)]=$259;
      var $268=$s;
      var $269=(($268+28)|0);
      var $270=HEAP32[(($269)>>2)];
      var $271=(($270+4)|0);
      var $272=HEAPU32[(($271)>>2)];
      var $273=$272 >>> 16;
      var $274=$273 & 255;
      var $275=(($274) & 255);
      var $276=$s;
      var $277=(($276+20)|0);
      var $278=HEAPU32[(($277)>>2)];
      var $279=((($278)+(1))|0);
      HEAP32[(($277)>>2)]=$279;
      var $280=$s;
      var $281=(($280+8)|0);
      var $282=HEAP32[(($281)>>2)];
      var $283=(($282+$278)|0);
      HEAP8[($283)]=$275;
      var $284=$s;
      var $285=(($284+28)|0);
      var $286=HEAP32[(($285)>>2)];
      var $287=(($286+4)|0);
      var $288=HEAPU32[(($287)>>2)];
      var $289=$288 >>> 24;
      var $290=$289 & 255;
      var $291=(($290) & 255);
      var $292=$s;
      var $293=(($292+20)|0);
      var $294=HEAPU32[(($293)>>2)];
      var $295=((($294)+(1))|0);
      HEAP32[(($293)>>2)]=$295;
      var $296=$s;
      var $297=(($296+8)|0);
      var $298=HEAP32[(($297)>>2)];
      var $299=(($298+$294)|0);
      HEAP8[($299)]=$291;
      var $300=$s;
      var $301=(($300+132)|0);
      var $302=HEAP32[(($301)>>2)];
      var $303=(($302)|0)==9;
      if ($303) { __label__ = 25; break; } else { __label__ = 26; break; }
    case 25: 
      var $319 = 2;__label__ = 29; break;
    case 26: 
      var $306=$s;
      var $307=(($306+136)|0);
      var $308=HEAP32[(($307)>>2)];
      var $309=(($308)|0) >= 2;
      if ($309) { var $316 = 1;__label__ = 28; break; } else { __label__ = 27; break; }
    case 27: 
      var $311=$s;
      var $312=(($311+132)|0);
      var $313=HEAP32[(($312)>>2)];
      var $314=(($313)|0) < 2;
      var $316 = $314;__label__ = 28; break;
    case 28: 
      var $316;
      var $317=$316 ? 4 : 0;
      var $319 = $317;__label__ = 29; break;
    case 29: 
      var $319;
      var $320=(($319) & 255);
      var $321=$s;
      var $322=(($321+20)|0);
      var $323=HEAP32[(($322)>>2)];
      var $324=((($323)+(1))|0);
      HEAP32[(($322)>>2)]=$324;
      var $325=$s;
      var $326=(($325+8)|0);
      var $327=HEAP32[(($326)>>2)];
      var $328=(($327+$323)|0);
      HEAP8[($328)]=$320;
      var $329=$s;
      var $330=(($329+28)|0);
      var $331=HEAP32[(($330)>>2)];
      var $332=(($331+12)|0);
      var $333=HEAP32[(($332)>>2)];
      var $334=$333 & 255;
      var $335=(($334) & 255);
      var $336=$s;
      var $337=(($336+20)|0);
      var $338=HEAP32[(($337)>>2)];
      var $339=((($338)+(1))|0);
      HEAP32[(($337)>>2)]=$339;
      var $340=$s;
      var $341=(($340+8)|0);
      var $342=HEAP32[(($341)>>2)];
      var $343=(($342+$338)|0);
      HEAP8[($343)]=$335;
      var $344=$s;
      var $345=(($344+28)|0);
      var $346=HEAP32[(($345)>>2)];
      var $347=(($346+16)|0);
      var $348=HEAP32[(($347)>>2)];
      var $349=(($348)|0)!=0;
      if ($349) { __label__ = 30; break; } else { __label__ = 31; break; }
    case 30: 
      var $351=$s;
      var $352=(($351+28)|0);
      var $353=HEAP32[(($352)>>2)];
      var $354=(($353+20)|0);
      var $355=HEAP32[(($354)>>2)];
      var $356=$355 & 255;
      var $357=(($356) & 255);
      var $358=$s;
      var $359=(($358+20)|0);
      var $360=HEAP32[(($359)>>2)];
      var $361=((($360)+(1))|0);
      HEAP32[(($359)>>2)]=$361;
      var $362=$s;
      var $363=(($362+8)|0);
      var $364=HEAP32[(($363)>>2)];
      var $365=(($364+$360)|0);
      HEAP8[($365)]=$357;
      var $366=$s;
      var $367=(($366+28)|0);
      var $368=HEAP32[(($367)>>2)];
      var $369=(($368+20)|0);
      var $370=HEAPU32[(($369)>>2)];
      var $371=$370 >>> 8;
      var $372=$371 & 255;
      var $373=(($372) & 255);
      var $374=$s;
      var $375=(($374+20)|0);
      var $376=HEAPU32[(($375)>>2)];
      var $377=((($376)+(1))|0);
      HEAP32[(($375)>>2)]=$377;
      var $378=$s;
      var $379=(($378+8)|0);
      var $380=HEAP32[(($379)>>2)];
      var $381=(($380+$376)|0);
      HEAP8[($381)]=$373;
      __label__ = 31; break;
    case 31: 
      var $383=$s;
      var $384=(($383+28)|0);
      var $385=HEAP32[(($384)>>2)];
      var $386=(($385+44)|0);
      var $387=HEAP32[(($386)>>2)];
      var $388=(($387)|0)!=0;
      if ($388) { __label__ = 32; break; } else { __label__ = 33; break; }
    case 32: 
      var $390=$2;
      var $391=(($390+48)|0);
      var $392=HEAP32[(($391)>>2)];
      var $393=$s;
      var $394=(($393+8)|0);
      var $395=HEAP32[(($394)>>2)];
      var $396=$s;
      var $397=(($396+20)|0);
      var $398=HEAP32[(($397)>>2)];
      var $399=_crc32($392, $395, $398);
      var $400=$2;
      var $401=(($400+48)|0);
      HEAP32[(($401)>>2)]=$399;
      __label__ = 33; break;
    case 33: 
      var $403=$s;
      var $404=(($403+32)|0);
      HEAP32[(($404)>>2)]=0;
      var $405=$s;
      var $406=(($405+4)|0);
      HEAP32[(($406)>>2)]=69;
      __label__ = 34; break;
    case 34: 
      __label__ = 50; break;
    case 35: 
      var $409=$s;
      var $410=(($409+48)|0);
      var $411=HEAP32[(($410)>>2)];
      var $412=((($411)-(8))|0);
      var $413=$412 << 4;
      var $414=((($413)+(8))|0);
      var $415=$414 << 8;
      $header=$415;
      var $416=$s;
      var $417=(($416+136)|0);
      var $418=HEAP32[(($417)>>2)];
      var $419=(($418)|0) >= 2;
      if ($419) { __label__ = 37; break; } else { __label__ = 36; break; }
    case 36: 
      var $421=$s;
      var $422=(($421+132)|0);
      var $423=HEAP32[(($422)>>2)];
      var $424=(($423)|0) < 2;
      if ($424) { __label__ = 37; break; } else { __label__ = 38; break; }
    case 37: 
      $level_flags=0;
      __label__ = 45; break;
    case 38: 
      var $427=$s;
      var $428=(($427+132)|0);
      var $429=HEAP32[(($428)>>2)];
      var $430=(($429)|0) < 6;
      if ($430) { __label__ = 39; break; } else { __label__ = 40; break; }
    case 39: 
      $level_flags=1;
      __label__ = 44; break;
    case 40: 
      var $433=$s;
      var $434=(($433+132)|0);
      var $435=HEAP32[(($434)>>2)];
      var $436=(($435)|0)==6;
      if ($436) { __label__ = 41; break; } else { __label__ = 42; break; }
    case 41: 
      $level_flags=2;
      __label__ = 43; break;
    case 42: 
      $level_flags=3;
      __label__ = 43; break;
    case 43: 
      __label__ = 44; break;
    case 44: 
      __label__ = 45; break;
    case 45: 
      var $442=$level_flags;
      var $443=$442 << 6;
      var $444=$header;
      var $445=$444 | $443;
      $header=$445;
      var $446=$s;
      var $447=(($446+108)|0);
      var $448=HEAP32[(($447)>>2)];
      var $449=(($448)|0)!=0;
      if ($449) { __label__ = 46; break; } else { __label__ = 47; break; }
    case 46: 
      var $451=$header;
      var $452=$451 | 32;
      $header=$452;
      __label__ = 47; break;
    case 47: 
      var $454=$header;
      var $455=((($454)>>>0))%(31);
      var $456=(((31)-($455))|0);
      var $457=$header;
      var $458=((($457)+($456))|0);
      $header=$458;
      var $459=$s;
      var $460=(($459+4)|0);
      HEAP32[(($460)>>2)]=113;
      var $461=$s;
      var $462=$header;
      _putShortMSB($461, $462);
      var $463=$s;
      var $464=(($463+108)|0);
      var $465=HEAP32[(($464)>>2)];
      var $466=(($465)|0)!=0;
      if ($466) { __label__ = 48; break; } else { __label__ = 49; break; }
    case 48: 
      var $468=$s;
      var $469=$2;
      var $470=(($469+48)|0);
      var $471=HEAPU32[(($470)>>2)];
      var $472=$471 >>> 16;
      _putShortMSB($468, $472);
      var $473=$s;
      var $474=$2;
      var $475=(($474+48)|0);
      var $476=HEAP32[(($475)>>2)];
      var $477=$476 & 65535;
      _putShortMSB($473, $477);
      __label__ = 49; break;
    case 49: 
      var $479=_adler32(0, 0, 0);
      var $480=$2;
      var $481=(($480+48)|0);
      HEAP32[(($481)>>2)]=$479;
      __label__ = 50; break;
    case 50: 
      __label__ = 51; break;
    case 51: 
      var $484=$s;
      var $485=(($484+4)|0);
      var $486=HEAP32[(($485)>>2)];
      var $487=(($486)|0)==69;
      if ($487) { __label__ = 52; break; } else { __label__ = 71; break; }
    case 52: 
      var $489=$s;
      var $490=(($489+28)|0);
      var $491=HEAP32[(($490)>>2)];
      var $492=(($491+16)|0);
      var $493=HEAP32[(($492)>>2)];
      var $494=(($493)|0)!=0;
      if ($494) { __label__ = 53; break; } else { __label__ = 69; break; }
    case 53: 
      var $496=$s;
      var $497=(($496+20)|0);
      var $498=HEAP32[(($497)>>2)];
      $beg=$498;
      __label__ = 54; break;
    case 54: 
      var $500=$s;
      var $501=(($500+32)|0);
      var $502=HEAPU32[(($501)>>2)];
      var $503=$s;
      var $504=(($503+28)|0);
      var $505=HEAP32[(($504)>>2)];
      var $506=(($505+20)|0);
      var $507=HEAP32[(($506)>>2)];
      var $508=$507 & 65535;
      var $509=(($502)>>>0) < (($508)>>>0);
      if ($509) { __label__ = 55; break; } else { __label__ = 63; break; }
    case 55: 
      var $511=$s;
      var $512=(($511+20)|0);
      var $513=HEAP32[(($512)>>2)];
      var $514=$s;
      var $515=(($514+12)|0);
      var $516=HEAP32[(($515)>>2)];
      var $517=(($513)|0)==(($516)|0);
      if ($517) { __label__ = 56; break; } else { __label__ = 62; break; }
    case 56: 
      var $519=$s;
      var $520=(($519+28)|0);
      var $521=HEAP32[(($520)>>2)];
      var $522=(($521+44)|0);
      var $523=HEAP32[(($522)>>2)];
      var $524=(($523)|0)!=0;
      if ($524) { __label__ = 57; break; } else { __label__ = 59; break; }
    case 57: 
      var $526=$s;
      var $527=(($526+20)|0);
      var $528=HEAPU32[(($527)>>2)];
      var $529=$beg;
      var $530=(($528)>>>0) > (($529)>>>0);
      if ($530) { __label__ = 58; break; } else { __label__ = 59; break; }
    case 58: 
      var $532=$2;
      var $533=(($532+48)|0);
      var $534=HEAP32[(($533)>>2)];
      var $535=$s;
      var $536=(($535+8)|0);
      var $537=HEAP32[(($536)>>2)];
      var $538=$beg;
      var $539=(($537+$538)|0);
      var $540=$s;
      var $541=(($540+20)|0);
      var $542=HEAP32[(($541)>>2)];
      var $543=$beg;
      var $544=((($542)-($543))|0);
      var $545=_crc32($534, $539, $544);
      var $546=$2;
      var $547=(($546+48)|0);
      HEAP32[(($547)>>2)]=$545;
      __label__ = 59; break;
    case 59: 
      var $549=$2;
      _flush_pending($549);
      var $550=$s;
      var $551=(($550+20)|0);
      var $552=HEAP32[(($551)>>2)];
      $beg=$552;
      var $553=$s;
      var $554=(($553+20)|0);
      var $555=HEAP32[(($554)>>2)];
      var $556=$s;
      var $557=(($556+12)|0);
      var $558=HEAP32[(($557)>>2)];
      var $559=(($555)|0)==(($558)|0);
      if ($559) { __label__ = 60; break; } else { __label__ = 61; break; }
    case 60: 
      __label__ = 63; break;
    case 61: 
      __label__ = 62; break;
    case 62: 
      var $563=$s;
      var $564=(($563+32)|0);
      var $565=HEAP32[(($564)>>2)];
      var $566=$s;
      var $567=(($566+28)|0);
      var $568=HEAP32[(($567)>>2)];
      var $569=(($568+16)|0);
      var $570=HEAP32[(($569)>>2)];
      var $571=(($570+$565)|0);
      var $572=HEAP8[($571)];
      var $573=$s;
      var $574=(($573+20)|0);
      var $575=HEAP32[(($574)>>2)];
      var $576=((($575)+(1))|0);
      HEAP32[(($574)>>2)]=$576;
      var $577=$s;
      var $578=(($577+8)|0);
      var $579=HEAP32[(($578)>>2)];
      var $580=(($579+$575)|0);
      HEAP8[($580)]=$572;
      var $581=$s;
      var $582=(($581+32)|0);
      var $583=HEAP32[(($582)>>2)];
      var $584=((($583)+(1))|0);
      HEAP32[(($582)>>2)]=$584;
      __label__ = 54; break;
    case 63: 
      var $586=$s;
      var $587=(($586+28)|0);
      var $588=HEAP32[(($587)>>2)];
      var $589=(($588+44)|0);
      var $590=HEAP32[(($589)>>2)];
      var $591=(($590)|0)!=0;
      if ($591) { __label__ = 64; break; } else { __label__ = 66; break; }
    case 64: 
      var $593=$s;
      var $594=(($593+20)|0);
      var $595=HEAPU32[(($594)>>2)];
      var $596=$beg;
      var $597=(($595)>>>0) > (($596)>>>0);
      if ($597) { __label__ = 65; break; } else { __label__ = 66; break; }
    case 65: 
      var $599=$2;
      var $600=(($599+48)|0);
      var $601=HEAP32[(($600)>>2)];
      var $602=$s;
      var $603=(($602+8)|0);
      var $604=HEAP32[(($603)>>2)];
      var $605=$beg;
      var $606=(($604+$605)|0);
      var $607=$s;
      var $608=(($607+20)|0);
      var $609=HEAP32[(($608)>>2)];
      var $610=$beg;
      var $611=((($609)-($610))|0);
      var $612=_crc32($601, $606, $611);
      var $613=$2;
      var $614=(($613+48)|0);
      HEAP32[(($614)>>2)]=$612;
      __label__ = 66; break;
    case 66: 
      var $616=$s;
      var $617=(($616+32)|0);
      var $618=HEAP32[(($617)>>2)];
      var $619=$s;
      var $620=(($619+28)|0);
      var $621=HEAP32[(($620)>>2)];
      var $622=(($621+20)|0);
      var $623=HEAP32[(($622)>>2)];
      var $624=(($618)|0)==(($623)|0);
      if ($624) { __label__ = 67; break; } else { __label__ = 68; break; }
    case 67: 
      var $626=$s;
      var $627=(($626+32)|0);
      HEAP32[(($627)>>2)]=0;
      var $628=$s;
      var $629=(($628+4)|0);
      HEAP32[(($629)>>2)]=73;
      __label__ = 68; break;
    case 68: 
      __label__ = 70; break;
    case 69: 
      var $632=$s;
      var $633=(($632+4)|0);
      HEAP32[(($633)>>2)]=73;
      __label__ = 70; break;
    case 70: 
      __label__ = 71; break;
    case 71: 
      var $636=$s;
      var $637=(($636+4)|0);
      var $638=HEAP32[(($637)>>2)];
      var $639=(($638)|0)==73;
      if ($639) { __label__ = 72; break; } else { __label__ = 91; break; }
    case 72: 
      var $641=$s;
      var $642=(($641+28)|0);
      var $643=HEAP32[(($642)>>2)];
      var $644=(($643+28)|0);
      var $645=HEAP32[(($644)>>2)];
      var $646=(($645)|0)!=0;
      if ($646) { __label__ = 73; break; } else { __label__ = 89; break; }
    case 73: 
      var $648=$s;
      var $649=(($648+20)|0);
      var $650=HEAP32[(($649)>>2)];
      $beg1=$650;
      __label__ = 74; break;
    case 74: 
      var $652=$s;
      var $653=(($652+20)|0);
      var $654=HEAP32[(($653)>>2)];
      var $655=$s;
      var $656=(($655+12)|0);
      var $657=HEAP32[(($656)>>2)];
      var $658=(($654)|0)==(($657)|0);
      if ($658) { __label__ = 75; break; } else { __label__ = 81; break; }
    case 75: 
      var $660=$s;
      var $661=(($660+28)|0);
      var $662=HEAP32[(($661)>>2)];
      var $663=(($662+44)|0);
      var $664=HEAP32[(($663)>>2)];
      var $665=(($664)|0)!=0;
      if ($665) { __label__ = 76; break; } else { __label__ = 78; break; }
    case 76: 
      var $667=$s;
      var $668=(($667+20)|0);
      var $669=HEAPU32[(($668)>>2)];
      var $670=$beg1;
      var $671=(($669)>>>0) > (($670)>>>0);
      if ($671) { __label__ = 77; break; } else { __label__ = 78; break; }
    case 77: 
      var $673=$2;
      var $674=(($673+48)|0);
      var $675=HEAP32[(($674)>>2)];
      var $676=$s;
      var $677=(($676+8)|0);
      var $678=HEAP32[(($677)>>2)];
      var $679=$beg1;
      var $680=(($678+$679)|0);
      var $681=$s;
      var $682=(($681+20)|0);
      var $683=HEAP32[(($682)>>2)];
      var $684=$beg1;
      var $685=((($683)-($684))|0);
      var $686=_crc32($675, $680, $685);
      var $687=$2;
      var $688=(($687+48)|0);
      HEAP32[(($688)>>2)]=$686;
      __label__ = 78; break;
    case 78: 
      var $690=$2;
      _flush_pending($690);
      var $691=$s;
      var $692=(($691+20)|0);
      var $693=HEAP32[(($692)>>2)];
      $beg1=$693;
      var $694=$s;
      var $695=(($694+20)|0);
      var $696=HEAP32[(($695)>>2)];
      var $697=$s;
      var $698=(($697+12)|0);
      var $699=HEAP32[(($698)>>2)];
      var $700=(($696)|0)==(($699)|0);
      if ($700) { __label__ = 79; break; } else { __label__ = 80; break; }
    case 79: 
      $val=1;
      __label__ = 83; break;
    case 80: 
      __label__ = 81; break;
    case 81: 
      var $704=$s;
      var $705=(($704+32)|0);
      var $706=HEAP32[(($705)>>2)];
      var $707=((($706)+(1))|0);
      HEAP32[(($705)>>2)]=$707;
      var $708=$s;
      var $709=(($708+28)|0);
      var $710=HEAP32[(($709)>>2)];
      var $711=(($710+28)|0);
      var $712=HEAP32[(($711)>>2)];
      var $713=(($712+$706)|0);
      var $714=HEAPU8[($713)];
      var $715=(($714)&255);
      $val=$715;
      var $716=$val;
      var $717=(($716) & 255);
      var $718=$s;
      var $719=(($718+20)|0);
      var $720=HEAPU32[(($719)>>2)];
      var $721=((($720)+(1))|0);
      HEAP32[(($719)>>2)]=$721;
      var $722=$s;
      var $723=(($722+8)|0);
      var $724=HEAP32[(($723)>>2)];
      var $725=(($724+$720)|0);
      HEAP8[($725)]=$717;
      __label__ = 82; break;
    case 82: 
      var $727=$val;
      var $728=(($727)|0)!=0;
      if ($728) { __label__ = 74; break; } else { __label__ = 83; break; }
    case 83: 
      var $730=$s;
      var $731=(($730+28)|0);
      var $732=HEAP32[(($731)>>2)];
      var $733=(($732+44)|0);
      var $734=HEAP32[(($733)>>2)];
      var $735=(($734)|0)!=0;
      if ($735) { __label__ = 84; break; } else { __label__ = 86; break; }
    case 84: 
      var $737=$s;
      var $738=(($737+20)|0);
      var $739=HEAPU32[(($738)>>2)];
      var $740=$beg1;
      var $741=(($739)>>>0) > (($740)>>>0);
      if ($741) { __label__ = 85; break; } else { __label__ = 86; break; }
    case 85: 
      var $743=$2;
      var $744=(($743+48)|0);
      var $745=HEAP32[(($744)>>2)];
      var $746=$s;
      var $747=(($746+8)|0);
      var $748=HEAP32[(($747)>>2)];
      var $749=$beg1;
      var $750=(($748+$749)|0);
      var $751=$s;
      var $752=(($751+20)|0);
      var $753=HEAP32[(($752)>>2)];
      var $754=$beg1;
      var $755=((($753)-($754))|0);
      var $756=_crc32($745, $750, $755);
      var $757=$2;
      var $758=(($757+48)|0);
      HEAP32[(($758)>>2)]=$756;
      __label__ = 86; break;
    case 86: 
      var $760=$val;
      var $761=(($760)|0)==0;
      if ($761) { __label__ = 87; break; } else { __label__ = 88; break; }
    case 87: 
      var $763=$s;
      var $764=(($763+32)|0);
      HEAP32[(($764)>>2)]=0;
      var $765=$s;
      var $766=(($765+4)|0);
      HEAP32[(($766)>>2)]=91;
      __label__ = 88; break;
    case 88: 
      __label__ = 90; break;
    case 89: 
      var $769=$s;
      var $770=(($769+4)|0);
      HEAP32[(($770)>>2)]=91;
      __label__ = 90; break;
    case 90: 
      __label__ = 91; break;
    case 91: 
      var $773=$s;
      var $774=(($773+4)|0);
      var $775=HEAP32[(($774)>>2)];
      var $776=(($775)|0)==91;
      if ($776) { __label__ = 92; break; } else { __label__ = 111; break; }
    case 92: 
      var $778=$s;
      var $779=(($778+28)|0);
      var $780=HEAP32[(($779)>>2)];
      var $781=(($780+36)|0);
      var $782=HEAP32[(($781)>>2)];
      var $783=(($782)|0)!=0;
      if ($783) { __label__ = 93; break; } else { __label__ = 109; break; }
    case 93: 
      var $785=$s;
      var $786=(($785+20)|0);
      var $787=HEAP32[(($786)>>2)];
      $beg2=$787;
      __label__ = 94; break;
    case 94: 
      var $789=$s;
      var $790=(($789+20)|0);
      var $791=HEAP32[(($790)>>2)];
      var $792=$s;
      var $793=(($792+12)|0);
      var $794=HEAP32[(($793)>>2)];
      var $795=(($791)|0)==(($794)|0);
      if ($795) { __label__ = 95; break; } else { __label__ = 101; break; }
    case 95: 
      var $797=$s;
      var $798=(($797+28)|0);
      var $799=HEAP32[(($798)>>2)];
      var $800=(($799+44)|0);
      var $801=HEAP32[(($800)>>2)];
      var $802=(($801)|0)!=0;
      if ($802) { __label__ = 96; break; } else { __label__ = 98; break; }
    case 96: 
      var $804=$s;
      var $805=(($804+20)|0);
      var $806=HEAPU32[(($805)>>2)];
      var $807=$beg2;
      var $808=(($806)>>>0) > (($807)>>>0);
      if ($808) { __label__ = 97; break; } else { __label__ = 98; break; }
    case 97: 
      var $810=$2;
      var $811=(($810+48)|0);
      var $812=HEAP32[(($811)>>2)];
      var $813=$s;
      var $814=(($813+8)|0);
      var $815=HEAP32[(($814)>>2)];
      var $816=$beg2;
      var $817=(($815+$816)|0);
      var $818=$s;
      var $819=(($818+20)|0);
      var $820=HEAP32[(($819)>>2)];
      var $821=$beg2;
      var $822=((($820)-($821))|0);
      var $823=_crc32($812, $817, $822);
      var $824=$2;
      var $825=(($824+48)|0);
      HEAP32[(($825)>>2)]=$823;
      __label__ = 98; break;
    case 98: 
      var $827=$2;
      _flush_pending($827);
      var $828=$s;
      var $829=(($828+20)|0);
      var $830=HEAP32[(($829)>>2)];
      $beg2=$830;
      var $831=$s;
      var $832=(($831+20)|0);
      var $833=HEAP32[(($832)>>2)];
      var $834=$s;
      var $835=(($834+12)|0);
      var $836=HEAP32[(($835)>>2)];
      var $837=(($833)|0)==(($836)|0);
      if ($837) { __label__ = 99; break; } else { __label__ = 100; break; }
    case 99: 
      $val3=1;
      __label__ = 103; break;
    case 100: 
      __label__ = 101; break;
    case 101: 
      var $841=$s;
      var $842=(($841+32)|0);
      var $843=HEAP32[(($842)>>2)];
      var $844=((($843)+(1))|0);
      HEAP32[(($842)>>2)]=$844;
      var $845=$s;
      var $846=(($845+28)|0);
      var $847=HEAP32[(($846)>>2)];
      var $848=(($847+36)|0);
      var $849=HEAP32[(($848)>>2)];
      var $850=(($849+$843)|0);
      var $851=HEAPU8[($850)];
      var $852=(($851)&255);
      $val3=$852;
      var $853=$val3;
      var $854=(($853) & 255);
      var $855=$s;
      var $856=(($855+20)|0);
      var $857=HEAPU32[(($856)>>2)];
      var $858=((($857)+(1))|0);
      HEAP32[(($856)>>2)]=$858;
      var $859=$s;
      var $860=(($859+8)|0);
      var $861=HEAP32[(($860)>>2)];
      var $862=(($861+$857)|0);
      HEAP8[($862)]=$854;
      __label__ = 102; break;
    case 102: 
      var $864=$val3;
      var $865=(($864)|0)!=0;
      if ($865) { __label__ = 94; break; } else { __label__ = 103; break; }
    case 103: 
      var $867=$s;
      var $868=(($867+28)|0);
      var $869=HEAP32[(($868)>>2)];
      var $870=(($869+44)|0);
      var $871=HEAP32[(($870)>>2)];
      var $872=(($871)|0)!=0;
      if ($872) { __label__ = 104; break; } else { __label__ = 106; break; }
    case 104: 
      var $874=$s;
      var $875=(($874+20)|0);
      var $876=HEAPU32[(($875)>>2)];
      var $877=$beg2;
      var $878=(($876)>>>0) > (($877)>>>0);
      if ($878) { __label__ = 105; break; } else { __label__ = 106; break; }
    case 105: 
      var $880=$2;
      var $881=(($880+48)|0);
      var $882=HEAP32[(($881)>>2)];
      var $883=$s;
      var $884=(($883+8)|0);
      var $885=HEAP32[(($884)>>2)];
      var $886=$beg2;
      var $887=(($885+$886)|0);
      var $888=$s;
      var $889=(($888+20)|0);
      var $890=HEAP32[(($889)>>2)];
      var $891=$beg2;
      var $892=((($890)-($891))|0);
      var $893=_crc32($882, $887, $892);
      var $894=$2;
      var $895=(($894+48)|0);
      HEAP32[(($895)>>2)]=$893;
      __label__ = 106; break;
    case 106: 
      var $897=$val3;
      var $898=(($897)|0)==0;
      if ($898) { __label__ = 107; break; } else { __label__ = 108; break; }
    case 107: 
      var $900=$s;
      var $901=(($900+4)|0);
      HEAP32[(($901)>>2)]=103;
      __label__ = 108; break;
    case 108: 
      __label__ = 110; break;
    case 109: 
      var $904=$s;
      var $905=(($904+4)|0);
      HEAP32[(($905)>>2)]=103;
      __label__ = 110; break;
    case 110: 
      __label__ = 111; break;
    case 111: 
      var $908=$s;
      var $909=(($908+4)|0);
      var $910=HEAP32[(($909)>>2)];
      var $911=(($910)|0)==103;
      if ($911) { __label__ = 112; break; } else { __label__ = 120; break; }
    case 112: 
      var $913=$s;
      var $914=(($913+28)|0);
      var $915=HEAP32[(($914)>>2)];
      var $916=(($915+44)|0);
      var $917=HEAP32[(($916)>>2)];
      var $918=(($917)|0)!=0;
      if ($918) { __label__ = 113; break; } else { __label__ = 118; break; }
    case 113: 
      var $920=$s;
      var $921=(($920+20)|0);
      var $922=HEAP32[(($921)>>2)];
      var $923=((($922)+(2))|0);
      var $924=$s;
      var $925=(($924+12)|0);
      var $926=HEAPU32[(($925)>>2)];
      var $927=(($923)>>>0) > (($926)>>>0);
      if ($927) { __label__ = 114; break; } else { __label__ = 115; break; }
    case 114: 
      var $929=$2;
      _flush_pending($929);
      __label__ = 115; break;
    case 115: 
      var $931=$s;
      var $932=(($931+20)|0);
      var $933=HEAP32[(($932)>>2)];
      var $934=((($933)+(2))|0);
      var $935=$s;
      var $936=(($935+12)|0);
      var $937=HEAPU32[(($936)>>2)];
      var $938=(($934)>>>0) <= (($937)>>>0);
      if ($938) { __label__ = 116; break; } else { __label__ = 117; break; }
    case 116: 
      var $940=$2;
      var $941=(($940+48)|0);
      var $942=HEAP32[(($941)>>2)];
      var $943=$942 & 255;
      var $944=(($943) & 255);
      var $945=$s;
      var $946=(($945+20)|0);
      var $947=HEAP32[(($946)>>2)];
      var $948=((($947)+(1))|0);
      HEAP32[(($946)>>2)]=$948;
      var $949=$s;
      var $950=(($949+8)|0);
      var $951=HEAP32[(($950)>>2)];
      var $952=(($951+$947)|0);
      HEAP8[($952)]=$944;
      var $953=$2;
      var $954=(($953+48)|0);
      var $955=HEAPU32[(($954)>>2)];
      var $956=$955 >>> 8;
      var $957=$956 & 255;
      var $958=(($957) & 255);
      var $959=$s;
      var $960=(($959+20)|0);
      var $961=HEAPU32[(($960)>>2)];
      var $962=((($961)+(1))|0);
      HEAP32[(($960)>>2)]=$962;
      var $963=$s;
      var $964=(($963+8)|0);
      var $965=HEAP32[(($964)>>2)];
      var $966=(($965+$961)|0);
      HEAP8[($966)]=$958;
      var $967=_crc32(0, 0, 0);
      var $968=$2;
      var $969=(($968+48)|0);
      HEAP32[(($969)>>2)]=$967;
      var $970=$s;
      var $971=(($970+4)|0);
      HEAP32[(($971)>>2)]=113;
      __label__ = 117; break;
    case 117: 
      __label__ = 119; break;
    case 118: 
      var $974=$s;
      var $975=(($974+4)|0);
      HEAP32[(($975)>>2)]=113;
      __label__ = 119; break;
    case 119: 
      __label__ = 120; break;
    case 120: 
      var $978=$s;
      var $979=(($978+20)|0);
      var $980=HEAP32[(($979)>>2)];
      var $981=(($980)|0)!=0;
      if ($981) { __label__ = 121; break; } else { __label__ = 124; break; }
    case 121: 
      var $983=$2;
      _flush_pending($983);
      var $984=$2;
      var $985=(($984+16)|0);
      var $986=HEAP32[(($985)>>2)];
      var $987=(($986)|0)==0;
      if ($987) { __label__ = 122; break; } else { __label__ = 123; break; }
    case 122: 
      var $989=$s;
      var $990=(($989+40)|0);
      HEAP32[(($990)>>2)]=-1;
      $1=0;
      __label__ = 174; break;
    case 123: 
      __label__ = 129; break;
    case 124: 
      var $993=$2;
      var $994=(($993+4)|0);
      var $995=HEAP32[(($994)>>2)];
      var $996=(($995)|0)==0;
      if ($996) { __label__ = 125; break; } else { __label__ = 128; break; }
    case 125: 
      var $998=$3;
      var $999=$998 << 1;
      var $1000=$3;
      var $1001=(($1000)|0) > 4;
      var $1002=$1001 ? 9 : 0;
      var $1003=((($999)-($1002))|0);
      var $1004=$old_flush;
      var $1005=$1004 << 1;
      var $1006=$old_flush;
      var $1007=(($1006)|0) > 4;
      var $1008=$1007 ? 9 : 0;
      var $1009=((($1005)-($1008))|0);
      var $1010=(($1003)|0) <= (($1009)|0);
      if ($1010) { __label__ = 126; break; } else { __label__ = 128; break; }
    case 126: 
      var $1012=$3;
      var $1013=(($1012)|0)!=4;
      if ($1013) { __label__ = 127; break; } else { __label__ = 128; break; }
    case 127: 
      var $1015=HEAP32[((((_z_errmsg+28)|0))>>2)];
      var $1016=$2;
      var $1017=(($1016+24)|0);
      HEAP32[(($1017)>>2)]=$1015;
      $1=-5;
      __label__ = 174; break;
    case 128: 
      __label__ = 129; break;
    case 129: 
      var $1020=$s;
      var $1021=(($1020+4)|0);
      var $1022=HEAP32[(($1021)>>2)];
      var $1023=(($1022)|0)==666;
      if ($1023) { __label__ = 130; break; } else { __label__ = 132; break; }
    case 130: 
      var $1025=$2;
      var $1026=(($1025+4)|0);
      var $1027=HEAP32[(($1026)>>2)];
      var $1028=(($1027)|0)!=0;
      if ($1028) { __label__ = 131; break; } else { __label__ = 132; break; }
    case 131: 
      var $1030=HEAP32[((((_z_errmsg+28)|0))>>2)];
      var $1031=$2;
      var $1032=(($1031+24)|0);
      HEAP32[(($1032)>>2)]=$1030;
      $1=-5;
      __label__ = 174; break;
    case 132: 
      var $1034=$2;
      var $1035=(($1034+4)|0);
      var $1036=HEAP32[(($1035)>>2)];
      var $1037=(($1036)|0)!=0;
      if ($1037) { __label__ = 136; break; } else { __label__ = 133; break; }
    case 133: 
      var $1039=$s;
      var $1040=(($1039+116)|0);
      var $1041=HEAP32[(($1040)>>2)];
      var $1042=(($1041)|0)!=0;
      if ($1042) { __label__ = 136; break; } else { __label__ = 134; break; }
    case 134: 
      var $1044=$3;
      var $1045=(($1044)|0)!=0;
      if ($1045) { __label__ = 135; break; } else { __label__ = 164; break; }
    case 135: 
      var $1047=$s;
      var $1048=(($1047+4)|0);
      var $1049=HEAP32[(($1048)>>2)];
      var $1050=(($1049)|0)!=666;
      if ($1050) { __label__ = 136; break; } else { __label__ = 164; break; }
    case 136: 
      var $1052=$s;
      var $1053=(($1052+136)|0);
      var $1054=HEAP32[(($1053)>>2)];
      var $1055=(($1054)|0)==2;
      if ($1055) { __label__ = 137; break; } else { __label__ = 138; break; }
    case 137: 
      var $1057=$s;
      var $1058=$3;
      var $1059=_deflate_huff($1057, $1058);
      var $1082 = $1059;__label__ = 142; break;
    case 138: 
      var $1061=$s;
      var $1062=(($1061+136)|0);
      var $1063=HEAP32[(($1062)>>2)];
      var $1064=(($1063)|0)==3;
      if ($1064) { __label__ = 139; break; } else { __label__ = 140; break; }
    case 139: 
      var $1066=$s;
      var $1067=$3;
      var $1068=_deflate_rle($1066, $1067);
      var $1080 = $1068;__label__ = 141; break;
    case 140: 
      var $1070=$s;
      var $1071=(($1070+132)|0);
      var $1072=HEAP32[(($1071)>>2)];
      var $1073=((_configuration_table+($1072)*(12))|0);
      var $1074=(($1073+8)|0);
      var $1075=HEAP32[(($1074)>>2)];
      var $1076=$s;
      var $1077=$3;
      var $1078=FUNCTION_TABLE[$1075]($1076, $1077);
      var $1080 = $1078;__label__ = 141; break;
    case 141: 
      var $1080;
      var $1082 = $1080;__label__ = 142; break;
    case 142: 
      var $1082;
      $bstate=$1082;
      var $1083=$bstate;
      var $1084=(($1083)|0)==2;
      if ($1084) { __label__ = 144; break; } else { __label__ = 143; break; }
    case 143: 
      var $1086=$bstate;
      var $1087=(($1086)|0)==3;
      if ($1087) { __label__ = 144; break; } else { __label__ = 145; break; }
    case 144: 
      var $1089=$s;
      var $1090=(($1089+4)|0);
      HEAP32[(($1090)>>2)]=666;
      __label__ = 145; break;
    case 145: 
      var $1092=$bstate;
      var $1093=(($1092)|0)==0;
      if ($1093) { __label__ = 147; break; } else { __label__ = 146; break; }
    case 146: 
      var $1095=$bstate;
      var $1096=(($1095)|0)==2;
      if ($1096) { __label__ = 147; break; } else { __label__ = 150; break; }
    case 147: 
      var $1098=$2;
      var $1099=(($1098+16)|0);
      var $1100=HEAP32[(($1099)>>2)];
      var $1101=(($1100)|0)==0;
      if ($1101) { __label__ = 148; break; } else { __label__ = 149; break; }
    case 148: 
      var $1103=$s;
      var $1104=(($1103+40)|0);
      HEAP32[(($1104)>>2)]=-1;
      __label__ = 149; break;
    case 149: 
      $1=0;
      __label__ = 174; break;
    case 150: 
      var $1107=$bstate;
      var $1108=(($1107)|0)==1;
      if ($1108) { __label__ = 151; break; } else { __label__ = 163; break; }
    case 151: 
      var $1110=$3;
      var $1111=(($1110)|0)==1;
      if ($1111) { __label__ = 152; break; } else { __label__ = 153; break; }
    case 152: 
      var $1113=$s;
      __tr_align($1113);
      __label__ = 160; break;
    case 153: 
      var $1115=$3;
      var $1116=(($1115)|0)!=5;
      if ($1116) { __label__ = 154; break; } else { __label__ = 159; break; }
    case 154: 
      var $1118=$s;
      __tr_stored_block($1118, 0, 0, 0);
      var $1119=$3;
      var $1120=(($1119)|0)==3;
      if ($1120) { __label__ = 155; break; } else { __label__ = 158; break; }
    case 155: 
      var $1122=$s;
      var $1123=(($1122+76)|0);
      var $1124=HEAP32[(($1123)>>2)];
      var $1125=((($1124)-(1))|0);
      var $1126=$s;
      var $1127=(($1126+68)|0);
      var $1128=HEAP32[(($1127)>>2)];
      var $1129=(($1128+($1125<<1))|0);
      HEAP16[(($1129)>>1)]=0;
      var $1130=$s;
      var $1131=(($1130+68)|0);
      var $1132=HEAP32[(($1131)>>2)];
      var $1133=$1132;
      var $1134=$s;
      var $1135=(($1134+76)|0);
      var $1136=HEAP32[(($1135)>>2)];
      var $1137=((($1136)-(1))|0);
      var $1138=((($1137<<1))|0);
      _memset($1133, 0, $1138, 1);
      var $1139=$s;
      var $1140=(($1139+116)|0);
      var $1141=HEAP32[(($1140)>>2)];
      var $1142=(($1141)|0)==0;
      if ($1142) { __label__ = 156; break; } else { __label__ = 157; break; }
    case 156: 
      var $1144=$s;
      var $1145=(($1144+108)|0);
      HEAP32[(($1145)>>2)]=0;
      var $1146=$s;
      var $1147=(($1146+92)|0);
      HEAP32[(($1147)>>2)]=0;
      var $1148=$s;
      var $1149=(($1148+5812)|0);
      HEAP32[(($1149)>>2)]=0;
      __label__ = 157; break;
    case 157: 
      __label__ = 158; break;
    case 158: 
      __label__ = 159; break;
    case 159: 
      __label__ = 160; break;
    case 160: 
      var $1154=$2;
      _flush_pending($1154);
      var $1155=$2;
      var $1156=(($1155+16)|0);
      var $1157=HEAP32[(($1156)>>2)];
      var $1158=(($1157)|0)==0;
      if ($1158) { __label__ = 161; break; } else { __label__ = 162; break; }
    case 161: 
      var $1160=$s;
      var $1161=(($1160+40)|0);
      HEAP32[(($1161)>>2)]=-1;
      $1=0;
      __label__ = 174; break;
    case 162: 
      __label__ = 163; break;
    case 163: 
      __label__ = 164; break;
    case 164: 
      var $1165=$3;
      var $1166=(($1165)|0)!=4;
      if ($1166) { __label__ = 165; break; } else { __label__ = 166; break; }
    case 165: 
      $1=0;
      __label__ = 174; break;
    case 166: 
      var $1169=$s;
      var $1170=(($1169+24)|0);
      var $1171=HEAP32[(($1170)>>2)];
      var $1172=(($1171)|0) <= 0;
      if ($1172) { __label__ = 167; break; } else { __label__ = 168; break; }
    case 167: 
      $1=1;
      __label__ = 174; break;
    case 168: 
      var $1175=$s;
      var $1176=(($1175+24)|0);
      var $1177=HEAP32[(($1176)>>2)];
      var $1178=(($1177)|0)==2;
      if ($1178) { __label__ = 169; break; } else { __label__ = 170; break; }
    case 169: 
      var $1180=$2;
      var $1181=(($1180+48)|0);
      var $1182=HEAP32[(($1181)>>2)];
      var $1183=$1182 & 255;
      var $1184=(($1183) & 255);
      var $1185=$s;
      var $1186=(($1185+20)|0);
      var $1187=HEAP32[(($1186)>>2)];
      var $1188=((($1187)+(1))|0);
      HEAP32[(($1186)>>2)]=$1188;
      var $1189=$s;
      var $1190=(($1189+8)|0);
      var $1191=HEAP32[(($1190)>>2)];
      var $1192=(($1191+$1187)|0);
      HEAP8[($1192)]=$1184;
      var $1193=$2;
      var $1194=(($1193+48)|0);
      var $1195=HEAPU32[(($1194)>>2)];
      var $1196=$1195 >>> 8;
      var $1197=$1196 & 255;
      var $1198=(($1197) & 255);
      var $1199=$s;
      var $1200=(($1199+20)|0);
      var $1201=HEAPU32[(($1200)>>2)];
      var $1202=((($1201)+(1))|0);
      HEAP32[(($1200)>>2)]=$1202;
      var $1203=$s;
      var $1204=(($1203+8)|0);
      var $1205=HEAP32[(($1204)>>2)];
      var $1206=(($1205+$1201)|0);
      HEAP8[($1206)]=$1198;
      var $1207=$2;
      var $1208=(($1207+48)|0);
      var $1209=HEAPU32[(($1208)>>2)];
      var $1210=$1209 >>> 16;
      var $1211=$1210 & 255;
      var $1212=(($1211) & 255);
      var $1213=$s;
      var $1214=(($1213+20)|0);
      var $1215=HEAPU32[(($1214)>>2)];
      var $1216=((($1215)+(1))|0);
      HEAP32[(($1214)>>2)]=$1216;
      var $1217=$s;
      var $1218=(($1217+8)|0);
      var $1219=HEAP32[(($1218)>>2)];
      var $1220=(($1219+$1215)|0);
      HEAP8[($1220)]=$1212;
      var $1221=$2;
      var $1222=(($1221+48)|0);
      var $1223=HEAPU32[(($1222)>>2)];
      var $1224=$1223 >>> 24;
      var $1225=$1224 & 255;
      var $1226=(($1225) & 255);
      var $1227=$s;
      var $1228=(($1227+20)|0);
      var $1229=HEAPU32[(($1228)>>2)];
      var $1230=((($1229)+(1))|0);
      HEAP32[(($1228)>>2)]=$1230;
      var $1231=$s;
      var $1232=(($1231+8)|0);
      var $1233=HEAP32[(($1232)>>2)];
      var $1234=(($1233+$1229)|0);
      HEAP8[($1234)]=$1226;
      var $1235=$2;
      var $1236=(($1235+8)|0);
      var $1237=HEAP32[(($1236)>>2)];
      var $1238=$1237 & 255;
      var $1239=(($1238) & 255);
      var $1240=$s;
      var $1241=(($1240+20)|0);
      var $1242=HEAP32[(($1241)>>2)];
      var $1243=((($1242)+(1))|0);
      HEAP32[(($1241)>>2)]=$1243;
      var $1244=$s;
      var $1245=(($1244+8)|0);
      var $1246=HEAP32[(($1245)>>2)];
      var $1247=(($1246+$1242)|0);
      HEAP8[($1247)]=$1239;
      var $1248=$2;
      var $1249=(($1248+8)|0);
      var $1250=HEAPU32[(($1249)>>2)];
      var $1251=$1250 >>> 8;
      var $1252=$1251 & 255;
      var $1253=(($1252) & 255);
      var $1254=$s;
      var $1255=(($1254+20)|0);
      var $1256=HEAPU32[(($1255)>>2)];
      var $1257=((($1256)+(1))|0);
      HEAP32[(($1255)>>2)]=$1257;
      var $1258=$s;
      var $1259=(($1258+8)|0);
      var $1260=HEAP32[(($1259)>>2)];
      var $1261=(($1260+$1256)|0);
      HEAP8[($1261)]=$1253;
      var $1262=$2;
      var $1263=(($1262+8)|0);
      var $1264=HEAPU32[(($1263)>>2)];
      var $1265=$1264 >>> 16;
      var $1266=$1265 & 255;
      var $1267=(($1266) & 255);
      var $1268=$s;
      var $1269=(($1268+20)|0);
      var $1270=HEAPU32[(($1269)>>2)];
      var $1271=((($1270)+(1))|0);
      HEAP32[(($1269)>>2)]=$1271;
      var $1272=$s;
      var $1273=(($1272+8)|0);
      var $1274=HEAP32[(($1273)>>2)];
      var $1275=(($1274+$1270)|0);
      HEAP8[($1275)]=$1267;
      var $1276=$2;
      var $1277=(($1276+8)|0);
      var $1278=HEAPU32[(($1277)>>2)];
      var $1279=$1278 >>> 24;
      var $1280=$1279 & 255;
      var $1281=(($1280) & 255);
      var $1282=$s;
      var $1283=(($1282+20)|0);
      var $1284=HEAPU32[(($1283)>>2)];
      var $1285=((($1284)+(1))|0);
      HEAP32[(($1283)>>2)]=$1285;
      var $1286=$s;
      var $1287=(($1286+8)|0);
      var $1288=HEAP32[(($1287)>>2)];
      var $1289=(($1288+$1284)|0);
      HEAP8[($1289)]=$1281;
      __label__ = 171; break;
    case 170: 
      var $1291=$s;
      var $1292=$2;
      var $1293=(($1292+48)|0);
      var $1294=HEAPU32[(($1293)>>2)];
      var $1295=$1294 >>> 16;
      _putShortMSB($1291, $1295);
      var $1296=$s;
      var $1297=$2;
      var $1298=(($1297+48)|0);
      var $1299=HEAP32[(($1298)>>2)];
      var $1300=$1299 & 65535;
      _putShortMSB($1296, $1300);
      __label__ = 171; break;
    case 171: 
      var $1302=$2;
      _flush_pending($1302);
      var $1303=$s;
      var $1304=(($1303+24)|0);
      var $1305=HEAP32[(($1304)>>2)];
      var $1306=(($1305)|0) > 0;
      if ($1306) { __label__ = 172; break; } else { __label__ = 173; break; }
    case 172: 
      var $1308=$s;
      var $1309=(($1308+24)|0);
      var $1310=HEAP32[(($1309)>>2)];
      var $1311=(((-$1310))|0);
      var $1312=$s;
      var $1313=(($1312+24)|0);
      HEAP32[(($1313)>>2)]=$1311;
      __label__ = 173; break;
    case 173: 
      var $1315=$s;
      var $1316=(($1315+20)|0);
      var $1317=HEAP32[(($1316)>>2)];
      var $1318=(($1317)|0)!=0;
      var $1319=$1318 ? 0 : 1;
      $1=$1319;
      __label__ = 174; break;
    case 174: 
      var $1321=$1;
      ;
      return $1321;
    default: assert(0, "bad label: " + __label__);
  }
}
_deflate["X"]=1;

function _putShortMSB($s, $b) {
  ;
  var __label__;

  var $1;
  var $2;
  $1=$s;
  $2=$b;
  var $3=$2;
  var $4=$3 >>> 8;
  var $5=(($4) & 255);
  var $6=$1;
  var $7=(($6+20)|0);
  var $8=HEAPU32[(($7)>>2)];
  var $9=((($8)+(1))|0);
  HEAP32[(($7)>>2)]=$9;
  var $10=$1;
  var $11=(($10+8)|0);
  var $12=HEAP32[(($11)>>2)];
  var $13=(($12+$8)|0);
  HEAP8[($13)]=$5;
  var $14=$2;
  var $15=$14 & 255;
  var $16=(($15) & 255);
  var $17=$1;
  var $18=(($17+20)|0);
  var $19=HEAP32[(($18)>>2)];
  var $20=((($19)+(1))|0);
  HEAP32[(($18)>>2)]=$20;
  var $21=$1;
  var $22=(($21+8)|0);
  var $23=HEAP32[(($22)>>2)];
  var $24=(($23+$19)|0);
  HEAP8[($24)]=$16;
  ;
  return;
}


function _flush_pending($strm) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $len;
      var $s;
      $1=$strm;
      var $2=$1;
      var $3=(($2+28)|0);
      var $4=HEAP32[(($3)>>2)];
      $s=$4;
      var $5=$s;
      __tr_flush_bits($5);
      var $6=$s;
      var $7=(($6+20)|0);
      var $8=HEAP32[(($7)>>2)];
      $len=$8;
      var $9=$len;
      var $10=$1;
      var $11=(($10+16)|0);
      var $12=HEAPU32[(($11)>>2)];
      var $13=(($9)>>>0) > (($12)>>>0);
      if ($13) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $15=$1;
      var $16=(($15+16)|0);
      var $17=HEAP32[(($16)>>2)];
      $len=$17;
      __label__ = 4; break;
    case 4: 
      var $19=$len;
      var $20=(($19)|0)==0;
      if ($20) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      __label__ = 8; break;
    case 6: 
      var $23=$1;
      var $24=(($23+12)|0);
      var $25=HEAP32[(($24)>>2)];
      var $26=$s;
      var $27=(($26+16)|0);
      var $28=HEAP32[(($27)>>2)];
      var $29=$len;
      assert($29 % 1 === 0, 'memcpy given ' + $29 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');_memcpy($25, $28, $29, 1);
      var $30=$len;
      var $31=$1;
      var $32=(($31+12)|0);
      var $33=HEAP32[(($32)>>2)];
      var $34=(($33+$30)|0);
      HEAP32[(($32)>>2)]=$34;
      var $35=$len;
      var $36=$s;
      var $37=(($36+16)|0);
      var $38=HEAP32[(($37)>>2)];
      var $39=(($38+$35)|0);
      HEAP32[(($37)>>2)]=$39;
      var $40=$len;
      var $41=$1;
      var $42=(($41+20)|0);
      var $43=HEAP32[(($42)>>2)];
      var $44=((($43)+($40))|0);
      HEAP32[(($42)>>2)]=$44;
      var $45=$len;
      var $46=$1;
      var $47=(($46+16)|0);
      var $48=HEAP32[(($47)>>2)];
      var $49=((($48)-($45))|0);
      HEAP32[(($47)>>2)]=$49;
      var $50=$len;
      var $51=$s;
      var $52=(($51+20)|0);
      var $53=HEAP32[(($52)>>2)];
      var $54=((($53)-($50))|0);
      HEAP32[(($52)>>2)]=$54;
      var $55=$s;
      var $56=(($55+20)|0);
      var $57=HEAP32[(($56)>>2)];
      var $58=(($57)|0)==0;
      if ($58) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $60=$s;
      var $61=(($60+8)|0);
      var $62=HEAP32[(($61)>>2)];
      var $63=$s;
      var $64=(($63+16)|0);
      HEAP32[(($64)>>2)]=$62;
      __label__ = 8; break;
    case 8: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_flush_pending["X"]=1;

function _deflate_huff($s, $flush) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $bflush;
      var $cc;
      $2=$s;
      $3=$flush;
      __label__ = 3; break;
    case 3: 
      var $5=$2;
      var $6=(($5+116)|0);
      var $7=HEAP32[(($6)>>2)];
      var $8=(($7)|0)==0;
      if ($8) { __label__ = 4; break; } else { __label__ = 9; break; }
    case 4: 
      var $10=$2;
      _fill_window($10);
      var $11=$2;
      var $12=(($11+116)|0);
      var $13=HEAP32[(($12)>>2)];
      var $14=(($13)|0)==0;
      if ($14) { __label__ = 5; break; } else { __label__ = 8; break; }
    case 5: 
      var $16=$3;
      var $17=(($16)|0)==0;
      if ($17) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      $1=0;
      __label__ = 32; break;
    case 7: 
      __label__ = 17; break;
    case 8: 
      __label__ = 9; break;
    case 9: 
      var $22=$2;
      var $23=(($22+96)|0);
      HEAP32[(($23)>>2)]=0;
      var $24=$2;
      var $25=(($24+108)|0);
      var $26=HEAP32[(($25)>>2)];
      var $27=$2;
      var $28=(($27+56)|0);
      var $29=HEAP32[(($28)>>2)];
      var $30=(($29+$26)|0);
      var $31=HEAP8[($30)];
      $cc=$31;
      var $32=$2;
      var $33=(($32+5792)|0);
      var $34=HEAP32[(($33)>>2)];
      var $35=$2;
      var $36=(($35+5796)|0);
      var $37=HEAP32[(($36)>>2)];
      var $38=(($37+($34<<1))|0);
      HEAP16[(($38)>>1)]=0;
      var $39=$cc;
      var $40=$2;
      var $41=(($40+5792)|0);
      var $42=HEAP32[(($41)>>2)];
      var $43=((($42)+(1))|0);
      HEAP32[(($41)>>2)]=$43;
      var $44=$2;
      var $45=(($44+5784)|0);
      var $46=HEAP32[(($45)>>2)];
      var $47=(($46+$42)|0);
      HEAP8[($47)]=$39;
      var $48=$cc;
      var $49=(($48)&255);
      var $50=$2;
      var $51=(($50+148)|0);
      var $52=(($51+($49<<2))|0);
      var $53=(($52)|0);
      var $54=$53;
      var $55=HEAP16[(($54)>>1)];
      var $56=((($55)+(1))&65535);
      HEAP16[(($54)>>1)]=$56;
      var $57=$2;
      var $58=(($57+5792)|0);
      var $59=HEAP32[(($58)>>2)];
      var $60=$2;
      var $61=(($60+5788)|0);
      var $62=HEAP32[(($61)>>2)];
      var $63=((($62)-(1))|0);
      var $64=(($59)|0)==(($63)|0);
      var $65=(($64)&1);
      $bflush=$65;
      var $66=$2;
      var $67=(($66+116)|0);
      var $68=HEAP32[(($67)>>2)];
      var $69=((($68)-(1))|0);
      HEAP32[(($67)>>2)]=$69;
      var $70=$2;
      var $71=(($70+108)|0);
      var $72=HEAP32[(($71)>>2)];
      var $73=((($72)+(1))|0);
      HEAP32[(($71)>>2)]=$73;
      var $74=$bflush;
      var $75=(($74)|0)!=0;
      if ($75) { __label__ = 10; break; } else { __label__ = 16; break; }
    case 10: 
      var $77=$2;
      var $78=$2;
      var $79=(($78+92)|0);
      var $80=HEAP32[(($79)>>2)];
      var $81=(($80)|0) >= 0;
      if ($81) { __label__ = 11; break; } else { __label__ = 12; break; }
    case 11: 
      var $83=$2;
      var $84=(($83+92)|0);
      var $85=HEAP32[(($84)>>2)];
      var $86=$2;
      var $87=(($86+56)|0);
      var $88=HEAP32[(($87)>>2)];
      var $89=(($88+$85)|0);
      var $92 = $89;__label__ = 13; break;
    case 12: 
      var $92 = 0;__label__ = 13; break;
    case 13: 
      var $92;
      var $93=$2;
      var $94=(($93+108)|0);
      var $95=HEAP32[(($94)>>2)];
      var $96=$2;
      var $97=(($96+92)|0);
      var $98=HEAP32[(($97)>>2)];
      var $99=((($95)-($98))|0);
      __tr_flush_block($77, $92, $99, 0);
      var $100=$2;
      var $101=(($100+108)|0);
      var $102=HEAP32[(($101)>>2)];
      var $103=$2;
      var $104=(($103+92)|0);
      HEAP32[(($104)>>2)]=$102;
      var $105=$2;
      var $106=(($105)|0);
      var $107=HEAP32[(($106)>>2)];
      _flush_pending($107);
      var $108=$2;
      var $109=(($108)|0);
      var $110=HEAP32[(($109)>>2)];
      var $111=(($110+16)|0);
      var $112=HEAP32[(($111)>>2)];
      var $113=(($112)|0)==0;
      if ($113) { __label__ = 14; break; } else { __label__ = 15; break; }
    case 14: 
      $1=0;
      __label__ = 32; break;
    case 15: 
      __label__ = 16; break;
    case 16: 
      __label__ = 3; break;
    case 17: 
      var $118=$2;
      var $119=(($118+5812)|0);
      HEAP32[(($119)>>2)]=0;
      var $120=$3;
      var $121=(($120)|0)==4;
      if ($121) { __label__ = 18; break; } else { __label__ = 24; break; }
    case 18: 
      var $123=$2;
      var $124=$2;
      var $125=(($124+92)|0);
      var $126=HEAP32[(($125)>>2)];
      var $127=(($126)|0) >= 0;
      if ($127) { __label__ = 19; break; } else { __label__ = 20; break; }
    case 19: 
      var $129=$2;
      var $130=(($129+92)|0);
      var $131=HEAP32[(($130)>>2)];
      var $132=$2;
      var $133=(($132+56)|0);
      var $134=HEAP32[(($133)>>2)];
      var $135=(($134+$131)|0);
      var $138 = $135;__label__ = 21; break;
    case 20: 
      var $138 = 0;__label__ = 21; break;
    case 21: 
      var $138;
      var $139=$2;
      var $140=(($139+108)|0);
      var $141=HEAP32[(($140)>>2)];
      var $142=$2;
      var $143=(($142+92)|0);
      var $144=HEAP32[(($143)>>2)];
      var $145=((($141)-($144))|0);
      __tr_flush_block($123, $138, $145, 1);
      var $146=$2;
      var $147=(($146+108)|0);
      var $148=HEAP32[(($147)>>2)];
      var $149=$2;
      var $150=(($149+92)|0);
      HEAP32[(($150)>>2)]=$148;
      var $151=$2;
      var $152=(($151)|0);
      var $153=HEAP32[(($152)>>2)];
      _flush_pending($153);
      var $154=$2;
      var $155=(($154)|0);
      var $156=HEAP32[(($155)>>2)];
      var $157=(($156+16)|0);
      var $158=HEAP32[(($157)>>2)];
      var $159=(($158)|0)==0;
      if ($159) { __label__ = 22; break; } else { __label__ = 23; break; }
    case 22: 
      $1=2;
      __label__ = 32; break;
    case 23: 
      $1=3;
      __label__ = 32; break;
    case 24: 
      var $163=$2;
      var $164=(($163+5792)|0);
      var $165=HEAP32[(($164)>>2)];
      var $166=(($165)|0)!=0;
      if ($166) { __label__ = 25; break; } else { __label__ = 31; break; }
    case 25: 
      var $168=$2;
      var $169=$2;
      var $170=(($169+92)|0);
      var $171=HEAP32[(($170)>>2)];
      var $172=(($171)|0) >= 0;
      if ($172) { __label__ = 26; break; } else { __label__ = 27; break; }
    case 26: 
      var $174=$2;
      var $175=(($174+92)|0);
      var $176=HEAP32[(($175)>>2)];
      var $177=$2;
      var $178=(($177+56)|0);
      var $179=HEAP32[(($178)>>2)];
      var $180=(($179+$176)|0);
      var $183 = $180;__label__ = 28; break;
    case 27: 
      var $183 = 0;__label__ = 28; break;
    case 28: 
      var $183;
      var $184=$2;
      var $185=(($184+108)|0);
      var $186=HEAP32[(($185)>>2)];
      var $187=$2;
      var $188=(($187+92)|0);
      var $189=HEAP32[(($188)>>2)];
      var $190=((($186)-($189))|0);
      __tr_flush_block($168, $183, $190, 0);
      var $191=$2;
      var $192=(($191+108)|0);
      var $193=HEAP32[(($192)>>2)];
      var $194=$2;
      var $195=(($194+92)|0);
      HEAP32[(($195)>>2)]=$193;
      var $196=$2;
      var $197=(($196)|0);
      var $198=HEAP32[(($197)>>2)];
      _flush_pending($198);
      var $199=$2;
      var $200=(($199)|0);
      var $201=HEAP32[(($200)>>2)];
      var $202=(($201+16)|0);
      var $203=HEAP32[(($202)>>2)];
      var $204=(($203)|0)==0;
      if ($204) { __label__ = 29; break; } else { __label__ = 30; break; }
    case 29: 
      $1=0;
      __label__ = 32; break;
    case 30: 
      __label__ = 31; break;
    case 31: 
      $1=1;
      __label__ = 32; break;
    case 32: 
      var $209=$1;
      ;
      return $209;
    default: assert(0, "bad label: " + __label__);
  }
}
_deflate_huff["X"]=1;

function _deflate_rle($s, $flush) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $bflush;
      var $prev;
      var $scan;
      var $strend;
      var $len;
      var $dist;
      var $cc;
      $2=$s;
      $3=$flush;
      __label__ = 3; break;
    case 3: 
      var $5=$2;
      var $6=(($5+116)|0);
      var $7=HEAPU32[(($6)>>2)];
      var $8=(($7)>>>0) <= 258;
      if ($8) { __label__ = 4; break; } else { __label__ = 10; break; }
    case 4: 
      var $10=$2;
      _fill_window($10);
      var $11=$2;
      var $12=(($11+116)|0);
      var $13=HEAPU32[(($12)>>2)];
      var $14=(($13)>>>0) <= 258;
      if ($14) { __label__ = 5; break; } else { __label__ = 7; break; }
    case 5: 
      var $16=$3;
      var $17=(($16)|0)==0;
      if ($17) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      $1=0;
      __label__ = 60; break;
    case 7: 
      var $20=$2;
      var $21=(($20+116)|0);
      var $22=HEAP32[(($21)>>2)];
      var $23=(($22)|0)==0;
      if ($23) { __label__ = 8; break; } else { __label__ = 9; break; }
    case 8: 
      __label__ = 45; break;
    case 9: 
      __label__ = 10; break;
    case 10: 
      var $27=$2;
      var $28=(($27+96)|0);
      HEAP32[(($28)>>2)]=0;
      var $29=$2;
      var $30=(($29+116)|0);
      var $31=HEAPU32[(($30)>>2)];
      var $32=(($31)>>>0) >= 3;
      if ($32) { __label__ = 11; break; } else { __label__ = 31; break; }
    case 11: 
      var $34=$2;
      var $35=(($34+108)|0);
      var $36=HEAPU32[(($35)>>2)];
      var $37=(($36)>>>0) > 0;
      if ($37) { __label__ = 12; break; } else { __label__ = 31; break; }
    case 12: 
      var $39=$2;
      var $40=(($39+56)|0);
      var $41=HEAP32[(($40)>>2)];
      var $42=$2;
      var $43=(($42+108)|0);
      var $44=HEAP32[(($43)>>2)];
      var $45=(($41+$44)|0);
      var $46=((($45)-(1))|0);
      $scan=$46;
      var $47=$scan;
      var $48=HEAPU8[($47)];
      var $49=(($48)&255);
      $prev=$49;
      var $50=$prev;
      var $51=$scan;
      var $52=(($51+1)|0);
      $scan=$52;
      var $53=HEAPU8[($52)];
      var $54=(($53)&255);
      var $55=(($50)|0)==(($54)|0);
      if ($55) { __label__ = 13; break; } else { __label__ = 30; break; }
    case 13: 
      var $57=$prev;
      var $58=$scan;
      var $59=(($58+1)|0);
      $scan=$59;
      var $60=HEAPU8[($59)];
      var $61=(($60)&255);
      var $62=(($57)|0)==(($61)|0);
      if ($62) { __label__ = 14; break; } else { __label__ = 30; break; }
    case 14: 
      var $64=$prev;
      var $65=$scan;
      var $66=(($65+1)|0);
      $scan=$66;
      var $67=HEAPU8[($66)];
      var $68=(($67)&255);
      var $69=(($64)|0)==(($68)|0);
      if ($69) { __label__ = 15; break; } else { __label__ = 30; break; }
    case 15: 
      var $71=$2;
      var $72=(($71+56)|0);
      var $73=HEAP32[(($72)>>2)];
      var $74=$2;
      var $75=(($74+108)|0);
      var $76=HEAP32[(($75)>>2)];
      var $77=(($73+$76)|0);
      var $78=(($77+258)|0);
      $strend=$78;
      __label__ = 16; break;
    case 16: 
      __label__ = 17; break;
    case 17: 
      var $81=$prev;
      var $82=$scan;
      var $83=(($82+1)|0);
      $scan=$83;
      var $84=HEAPU8[($83)];
      var $85=(($84)&255);
      var $86=(($81)|0)==(($85)|0);
      if ($86) { __label__ = 18; break; } else { var $141 = 0;__label__ = 26; break; }
    case 18: 
      var $88=$prev;
      var $89=$scan;
      var $90=(($89+1)|0);
      $scan=$90;
      var $91=HEAPU8[($90)];
      var $92=(($91)&255);
      var $93=(($88)|0)==(($92)|0);
      if ($93) { __label__ = 19; break; } else { var $141 = 0;__label__ = 26; break; }
    case 19: 
      var $95=$prev;
      var $96=$scan;
      var $97=(($96+1)|0);
      $scan=$97;
      var $98=HEAPU8[($97)];
      var $99=(($98)&255);
      var $100=(($95)|0)==(($99)|0);
      if ($100) { __label__ = 20; break; } else { var $141 = 0;__label__ = 26; break; }
    case 20: 
      var $102=$prev;
      var $103=$scan;
      var $104=(($103+1)|0);
      $scan=$104;
      var $105=HEAPU8[($104)];
      var $106=(($105)&255);
      var $107=(($102)|0)==(($106)|0);
      if ($107) { __label__ = 21; break; } else { var $141 = 0;__label__ = 26; break; }
    case 21: 
      var $109=$prev;
      var $110=$scan;
      var $111=(($110+1)|0);
      $scan=$111;
      var $112=HEAPU8[($111)];
      var $113=(($112)&255);
      var $114=(($109)|0)==(($113)|0);
      if ($114) { __label__ = 22; break; } else { var $141 = 0;__label__ = 26; break; }
    case 22: 
      var $116=$prev;
      var $117=$scan;
      var $118=(($117+1)|0);
      $scan=$118;
      var $119=HEAPU8[($118)];
      var $120=(($119)&255);
      var $121=(($116)|0)==(($120)|0);
      if ($121) { __label__ = 23; break; } else { var $141 = 0;__label__ = 26; break; }
    case 23: 
      var $123=$prev;
      var $124=$scan;
      var $125=(($124+1)|0);
      $scan=$125;
      var $126=HEAPU8[($125)];
      var $127=(($126)&255);
      var $128=(($123)|0)==(($127)|0);
      if ($128) { __label__ = 24; break; } else { var $141 = 0;__label__ = 26; break; }
    case 24: 
      var $130=$prev;
      var $131=$scan;
      var $132=(($131+1)|0);
      $scan=$132;
      var $133=HEAPU8[($132)];
      var $134=(($133)&255);
      var $135=(($130)|0)==(($134)|0);
      if ($135) { __label__ = 25; break; } else { var $141 = 0;__label__ = 26; break; }
    case 25: 
      var $137=$scan;
      var $138=$strend;
      var $139=(($137)>>>0) < (($138)>>>0);
      var $141 = $139;__label__ = 26; break;
    case 26: 
      var $141;
      if ($141) { __label__ = 16; break; } else { __label__ = 27; break; }
    case 27: 
      var $143=$strend;
      var $144=$scan;
      var $145=$143;
      var $146=$144;
      var $147=((($145)-($146))|0);
      var $148=(((258)-($147))|0);
      var $149=$2;
      var $150=(($149+96)|0);
      HEAP32[(($150)>>2)]=$148;
      var $151=$2;
      var $152=(($151+96)|0);
      var $153=HEAPU32[(($152)>>2)];
      var $154=$2;
      var $155=(($154+116)|0);
      var $156=HEAPU32[(($155)>>2)];
      var $157=(($153)>>>0) > (($156)>>>0);
      if ($157) { __label__ = 28; break; } else { __label__ = 29; break; }
    case 28: 
      var $159=$2;
      var $160=(($159+116)|0);
      var $161=HEAP32[(($160)>>2)];
      var $162=$2;
      var $163=(($162+96)|0);
      HEAP32[(($163)>>2)]=$161;
      __label__ = 29; break;
    case 29: 
      __label__ = 30; break;
    case 30: 
      __label__ = 31; break;
    case 31: 
      var $167=$2;
      var $168=(($167+96)|0);
      var $169=HEAPU32[(($168)>>2)];
      var $170=(($169)>>>0) >= 3;
      if ($170) { __label__ = 32; break; } else { __label__ = 36; break; }
    case 32: 
      var $172=$2;
      var $173=(($172+96)|0);
      var $174=HEAP32[(($173)>>2)];
      var $175=((($174)-(3))|0);
      var $176=(($175) & 255);
      $len=$176;
      $dist=1;
      var $177=$dist;
      var $178=$2;
      var $179=(($178+5792)|0);
      var $180=HEAP32[(($179)>>2)];
      var $181=$2;
      var $182=(($181+5796)|0);
      var $183=HEAP32[(($182)>>2)];
      var $184=(($183+($180<<1))|0);
      HEAP16[(($184)>>1)]=$177;
      var $185=$len;
      var $186=$2;
      var $187=(($186+5792)|0);
      var $188=HEAP32[(($187)>>2)];
      var $189=((($188)+(1))|0);
      HEAP32[(($187)>>2)]=$189;
      var $190=$2;
      var $191=(($190+5784)|0);
      var $192=HEAP32[(($191)>>2)];
      var $193=(($192+$188)|0);
      HEAP8[($193)]=$185;
      var $194=$dist;
      var $195=((($194)-(1))&65535);
      $dist=$195;
      var $196=$len;
      var $197=(($196)&255);
      var $198=(((STRING_TABLE.__length_code)+$197)|0);
      var $199=HEAPU8[($198)];
      var $200=(($199)&255);
      var $201=((($200)+(256))|0);
      var $202=((($201)+(1))|0);
      var $203=$2;
      var $204=(($203+148)|0);
      var $205=(($204+($202<<2))|0);
      var $206=(($205)|0);
      var $207=$206;
      var $208=HEAP16[(($207)>>1)];
      var $209=((($208)+(1))&65535);
      HEAP16[(($207)>>1)]=$209;
      var $210=$dist;
      var $211=(($210)&65535);
      var $212=(($211)|0) < 256;
      if ($212) { __label__ = 33; break; } else { __label__ = 34; break; }
    case 33: 
      var $214=$dist;
      var $215=(($214)&65535);
      var $216=(((STRING_TABLE.__dist_code)+$215)|0);
      var $217=HEAPU8[($216)];
      var $218=(($217)&255);
      var $228 = $218;__label__ = 35; break;
    case 34: 
      var $220=$dist;
      var $221=(($220)&65535);
      var $222=$221 >> 7;
      var $223=((($222)+(256))|0);
      var $224=(((STRING_TABLE.__dist_code)+$223)|0);
      var $225=HEAPU8[($224)];
      var $226=(($225)&255);
      var $228 = $226;__label__ = 35; break;
    case 35: 
      var $228;
      var $229=$2;
      var $230=(($229+2440)|0);
      var $231=(($230+($228<<2))|0);
      var $232=(($231)|0);
      var $233=$232;
      var $234=HEAP16[(($233)>>1)];
      var $235=((($234)+(1))&65535);
      HEAP16[(($233)>>1)]=$235;
      var $236=$2;
      var $237=(($236+5792)|0);
      var $238=HEAP32[(($237)>>2)];
      var $239=$2;
      var $240=(($239+5788)|0);
      var $241=HEAP32[(($240)>>2)];
      var $242=((($241)-(1))|0);
      var $243=(($238)|0)==(($242)|0);
      var $244=(($243)&1);
      $bflush=$244;
      var $245=$2;
      var $246=(($245+96)|0);
      var $247=HEAP32[(($246)>>2)];
      var $248=$2;
      var $249=(($248+116)|0);
      var $250=HEAP32[(($249)>>2)];
      var $251=((($250)-($247))|0);
      HEAP32[(($249)>>2)]=$251;
      var $252=$2;
      var $253=(($252+96)|0);
      var $254=HEAP32[(($253)>>2)];
      var $255=$2;
      var $256=(($255+108)|0);
      var $257=HEAP32[(($256)>>2)];
      var $258=((($257)+($254))|0);
      HEAP32[(($256)>>2)]=$258;
      var $259=$2;
      var $260=(($259+96)|0);
      HEAP32[(($260)>>2)]=0;
      __label__ = 37; break;
    case 36: 
      var $262=$2;
      var $263=(($262+108)|0);
      var $264=HEAP32[(($263)>>2)];
      var $265=$2;
      var $266=(($265+56)|0);
      var $267=HEAP32[(($266)>>2)];
      var $268=(($267+$264)|0);
      var $269=HEAP8[($268)];
      $cc=$269;
      var $270=$2;
      var $271=(($270+5792)|0);
      var $272=HEAP32[(($271)>>2)];
      var $273=$2;
      var $274=(($273+5796)|0);
      var $275=HEAP32[(($274)>>2)];
      var $276=(($275+($272<<1))|0);
      HEAP16[(($276)>>1)]=0;
      var $277=$cc;
      var $278=$2;
      var $279=(($278+5792)|0);
      var $280=HEAP32[(($279)>>2)];
      var $281=((($280)+(1))|0);
      HEAP32[(($279)>>2)]=$281;
      var $282=$2;
      var $283=(($282+5784)|0);
      var $284=HEAP32[(($283)>>2)];
      var $285=(($284+$280)|0);
      HEAP8[($285)]=$277;
      var $286=$cc;
      var $287=(($286)&255);
      var $288=$2;
      var $289=(($288+148)|0);
      var $290=(($289+($287<<2))|0);
      var $291=(($290)|0);
      var $292=$291;
      var $293=HEAP16[(($292)>>1)];
      var $294=((($293)+(1))&65535);
      HEAP16[(($292)>>1)]=$294;
      var $295=$2;
      var $296=(($295+5792)|0);
      var $297=HEAP32[(($296)>>2)];
      var $298=$2;
      var $299=(($298+5788)|0);
      var $300=HEAP32[(($299)>>2)];
      var $301=((($300)-(1))|0);
      var $302=(($297)|0)==(($301)|0);
      var $303=(($302)&1);
      $bflush=$303;
      var $304=$2;
      var $305=(($304+116)|0);
      var $306=HEAP32[(($305)>>2)];
      var $307=((($306)-(1))|0);
      HEAP32[(($305)>>2)]=$307;
      var $308=$2;
      var $309=(($308+108)|0);
      var $310=HEAP32[(($309)>>2)];
      var $311=((($310)+(1))|0);
      HEAP32[(($309)>>2)]=$311;
      __label__ = 37; break;
    case 37: 
      var $313=$bflush;
      var $314=(($313)|0)!=0;
      if ($314) { __label__ = 38; break; } else { __label__ = 44; break; }
    case 38: 
      var $316=$2;
      var $317=$2;
      var $318=(($317+92)|0);
      var $319=HEAP32[(($318)>>2)];
      var $320=(($319)|0) >= 0;
      if ($320) { __label__ = 39; break; } else { __label__ = 40; break; }
    case 39: 
      var $322=$2;
      var $323=(($322+92)|0);
      var $324=HEAP32[(($323)>>2)];
      var $325=$2;
      var $326=(($325+56)|0);
      var $327=HEAP32[(($326)>>2)];
      var $328=(($327+$324)|0);
      var $331 = $328;__label__ = 41; break;
    case 40: 
      var $331 = 0;__label__ = 41; break;
    case 41: 
      var $331;
      var $332=$2;
      var $333=(($332+108)|0);
      var $334=HEAP32[(($333)>>2)];
      var $335=$2;
      var $336=(($335+92)|0);
      var $337=HEAP32[(($336)>>2)];
      var $338=((($334)-($337))|0);
      __tr_flush_block($316, $331, $338, 0);
      var $339=$2;
      var $340=(($339+108)|0);
      var $341=HEAP32[(($340)>>2)];
      var $342=$2;
      var $343=(($342+92)|0);
      HEAP32[(($343)>>2)]=$341;
      var $344=$2;
      var $345=(($344)|0);
      var $346=HEAP32[(($345)>>2)];
      _flush_pending($346);
      var $347=$2;
      var $348=(($347)|0);
      var $349=HEAP32[(($348)>>2)];
      var $350=(($349+16)|0);
      var $351=HEAP32[(($350)>>2)];
      var $352=(($351)|0)==0;
      if ($352) { __label__ = 42; break; } else { __label__ = 43; break; }
    case 42: 
      $1=0;
      __label__ = 60; break;
    case 43: 
      __label__ = 44; break;
    case 44: 
      __label__ = 3; break;
    case 45: 
      var $357=$2;
      var $358=(($357+5812)|0);
      HEAP32[(($358)>>2)]=0;
      var $359=$3;
      var $360=(($359)|0)==4;
      if ($360) { __label__ = 46; break; } else { __label__ = 52; break; }
    case 46: 
      var $362=$2;
      var $363=$2;
      var $364=(($363+92)|0);
      var $365=HEAP32[(($364)>>2)];
      var $366=(($365)|0) >= 0;
      if ($366) { __label__ = 47; break; } else { __label__ = 48; break; }
    case 47: 
      var $368=$2;
      var $369=(($368+92)|0);
      var $370=HEAP32[(($369)>>2)];
      var $371=$2;
      var $372=(($371+56)|0);
      var $373=HEAP32[(($372)>>2)];
      var $374=(($373+$370)|0);
      var $377 = $374;__label__ = 49; break;
    case 48: 
      var $377 = 0;__label__ = 49; break;
    case 49: 
      var $377;
      var $378=$2;
      var $379=(($378+108)|0);
      var $380=HEAP32[(($379)>>2)];
      var $381=$2;
      var $382=(($381+92)|0);
      var $383=HEAP32[(($382)>>2)];
      var $384=((($380)-($383))|0);
      __tr_flush_block($362, $377, $384, 1);
      var $385=$2;
      var $386=(($385+108)|0);
      var $387=HEAP32[(($386)>>2)];
      var $388=$2;
      var $389=(($388+92)|0);
      HEAP32[(($389)>>2)]=$387;
      var $390=$2;
      var $391=(($390)|0);
      var $392=HEAP32[(($391)>>2)];
      _flush_pending($392);
      var $393=$2;
      var $394=(($393)|0);
      var $395=HEAP32[(($394)>>2)];
      var $396=(($395+16)|0);
      var $397=HEAP32[(($396)>>2)];
      var $398=(($397)|0)==0;
      if ($398) { __label__ = 50; break; } else { __label__ = 51; break; }
    case 50: 
      $1=2;
      __label__ = 60; break;
    case 51: 
      $1=3;
      __label__ = 60; break;
    case 52: 
      var $402=$2;
      var $403=(($402+5792)|0);
      var $404=HEAP32[(($403)>>2)];
      var $405=(($404)|0)!=0;
      if ($405) { __label__ = 53; break; } else { __label__ = 59; break; }
    case 53: 
      var $407=$2;
      var $408=$2;
      var $409=(($408+92)|0);
      var $410=HEAP32[(($409)>>2)];
      var $411=(($410)|0) >= 0;
      if ($411) { __label__ = 54; break; } else { __label__ = 55; break; }
    case 54: 
      var $413=$2;
      var $414=(($413+92)|0);
      var $415=HEAP32[(($414)>>2)];
      var $416=$2;
      var $417=(($416+56)|0);
      var $418=HEAP32[(($417)>>2)];
      var $419=(($418+$415)|0);
      var $422 = $419;__label__ = 56; break;
    case 55: 
      var $422 = 0;__label__ = 56; break;
    case 56: 
      var $422;
      var $423=$2;
      var $424=(($423+108)|0);
      var $425=HEAP32[(($424)>>2)];
      var $426=$2;
      var $427=(($426+92)|0);
      var $428=HEAP32[(($427)>>2)];
      var $429=((($425)-($428))|0);
      __tr_flush_block($407, $422, $429, 0);
      var $430=$2;
      var $431=(($430+108)|0);
      var $432=HEAP32[(($431)>>2)];
      var $433=$2;
      var $434=(($433+92)|0);
      HEAP32[(($434)>>2)]=$432;
      var $435=$2;
      var $436=(($435)|0);
      var $437=HEAP32[(($436)>>2)];
      _flush_pending($437);
      var $438=$2;
      var $439=(($438)|0);
      var $440=HEAP32[(($439)>>2)];
      var $441=(($440+16)|0);
      var $442=HEAP32[(($441)>>2)];
      var $443=(($442)|0)==0;
      if ($443) { __label__ = 57; break; } else { __label__ = 58; break; }
    case 57: 
      $1=0;
      __label__ = 60; break;
    case 58: 
      __label__ = 59; break;
    case 59: 
      $1=1;
      __label__ = 60; break;
    case 60: 
      var $448=$1;
      ;
      return $448;
    default: assert(0, "bad label: " + __label__);
  }
}
_deflate_rle["X"]=1;

function _read_buf($strm, $buf, $size) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $len;
      $2=$strm;
      $3=$buf;
      $4=$size;
      var $5=$2;
      var $6=(($5+4)|0);
      var $7=HEAP32[(($6)>>2)];
      $len=$7;
      var $8=$len;
      var $9=$4;
      var $10=(($8)>>>0) > (($9)>>>0);
      if ($10) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $12=$4;
      $len=$12;
      __label__ = 4; break;
    case 4: 
      var $14=$len;
      var $15=(($14)|0)==0;
      if ($15) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      $1=0;
      __label__ = 12; break;
    case 6: 
      var $18=$len;
      var $19=$2;
      var $20=(($19+4)|0);
      var $21=HEAP32[(($20)>>2)];
      var $22=((($21)-($18))|0);
      HEAP32[(($20)>>2)]=$22;
      var $23=$3;
      var $24=$2;
      var $25=(($24)|0);
      var $26=HEAP32[(($25)>>2)];
      var $27=$len;
      assert($27 % 1 === 0, 'memcpy given ' + $27 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');_memcpy($23, $26, $27, 1);
      var $28=$2;
      var $29=(($28+28)|0);
      var $30=HEAP32[(($29)>>2)];
      var $31=(($30+24)|0);
      var $32=HEAP32[(($31)>>2)];
      var $33=(($32)|0)==1;
      if ($33) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $35=$2;
      var $36=(($35+48)|0);
      var $37=HEAP32[(($36)>>2)];
      var $38=$3;
      var $39=$len;
      var $40=_adler32($37, $38, $39);
      var $41=$2;
      var $42=(($41+48)|0);
      HEAP32[(($42)>>2)]=$40;
      __label__ = 11; break;
    case 8: 
      var $44=$2;
      var $45=(($44+28)|0);
      var $46=HEAP32[(($45)>>2)];
      var $47=(($46+24)|0);
      var $48=HEAP32[(($47)>>2)];
      var $49=(($48)|0)==2;
      if ($49) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      var $51=$2;
      var $52=(($51+48)|0);
      var $53=HEAP32[(($52)>>2)];
      var $54=$3;
      var $55=$len;
      var $56=_crc32($53, $54, $55);
      var $57=$2;
      var $58=(($57+48)|0);
      HEAP32[(($58)>>2)]=$56;
      __label__ = 10; break;
    case 10: 
      __label__ = 11; break;
    case 11: 
      var $61=$len;
      var $62=$2;
      var $63=(($62)|0);
      var $64=HEAP32[(($63)>>2)];
      var $65=(($64+$61)|0);
      HEAP32[(($63)>>2)]=$65;
      var $66=$len;
      var $67=$2;
      var $68=(($67+8)|0);
      var $69=HEAP32[(($68)>>2)];
      var $70=((($69)+($66))|0);
      HEAP32[(($68)>>2)]=$70;
      var $71=$len;
      $1=$71;
      __label__ = 12; break;
    case 12: 
      var $73=$1;
      ;
      return $73;
    default: assert(0, "bad label: " + __label__);
  }
}
_read_buf["X"]=1;

function _deflate_stored($s, $flush) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $max_block_size;
      var $max_start;
      $2=$s;
      $3=$flush;
      $max_block_size=65535;
      var $4=$max_block_size;
      var $5=$2;
      var $6=(($5+12)|0);
      var $7=HEAP32[(($6)>>2)];
      var $8=((($7)-(5))|0);
      var $9=(($4)>>>0) > (($8)>>>0);
      if ($9) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $11=$2;
      var $12=(($11+12)|0);
      var $13=HEAP32[(($12)>>2)];
      var $14=((($13)-(5))|0);
      $max_block_size=$14;
      __label__ = 4; break;
    case 4: 
      __label__ = 5; break;
    case 5: 
      var $17=$2;
      var $18=(($17+116)|0);
      var $19=HEAPU32[(($18)>>2)];
      var $20=(($19)>>>0) <= 1;
      if ($20) { __label__ = 6; break; } else { __label__ = 12; break; }
    case 6: 
      var $22=$2;
      _fill_window($22);
      var $23=$2;
      var $24=(($23+116)|0);
      var $25=HEAP32[(($24)>>2)];
      var $26=(($25)|0)==0;
      if ($26) { __label__ = 7; break; } else { __label__ = 9; break; }
    case 7: 
      var $28=$3;
      var $29=(($28)|0)==0;
      if ($29) { __label__ = 8; break; } else { __label__ = 9; break; }
    case 8: 
      $1=0;
      __label__ = 43; break;
    case 9: 
      var $32=$2;
      var $33=(($32+116)|0);
      var $34=HEAP32[(($33)>>2)];
      var $35=(($34)|0)==0;
      if ($35) { __label__ = 10; break; } else { __label__ = 11; break; }
    case 10: 
      __label__ = 28; break;
    case 11: 
      __label__ = 12; break;
    case 12: 
      var $39=$2;
      var $40=(($39+116)|0);
      var $41=HEAP32[(($40)>>2)];
      var $42=$2;
      var $43=(($42+108)|0);
      var $44=HEAP32[(($43)>>2)];
      var $45=((($44)+($41))|0);
      HEAP32[(($43)>>2)]=$45;
      var $46=$2;
      var $47=(($46+116)|0);
      HEAP32[(($47)>>2)]=0;
      var $48=$2;
      var $49=(($48+92)|0);
      var $50=HEAP32[(($49)>>2)];
      var $51=$max_block_size;
      var $52=((($50)+($51))|0);
      $max_start=$52;
      var $53=$2;
      var $54=(($53+108)|0);
      var $55=HEAP32[(($54)>>2)];
      var $56=(($55)|0)==0;
      if ($56) { __label__ = 14; break; } else { __label__ = 13; break; }
    case 13: 
      var $58=$2;
      var $59=(($58+108)|0);
      var $60=HEAPU32[(($59)>>2)];
      var $61=$max_start;
      var $62=(($60)>>>0) >= (($61)>>>0);
      if ($62) { __label__ = 14; break; } else { __label__ = 20; break; }
    case 14: 
      var $64=$2;
      var $65=(($64+108)|0);
      var $66=HEAP32[(($65)>>2)];
      var $67=$max_start;
      var $68=((($66)-($67))|0);
      var $69=$2;
      var $70=(($69+116)|0);
      HEAP32[(($70)>>2)]=$68;
      var $71=$max_start;
      var $72=$2;
      var $73=(($72+108)|0);
      HEAP32[(($73)>>2)]=$71;
      var $74=$2;
      var $75=$2;
      var $76=(($75+92)|0);
      var $77=HEAP32[(($76)>>2)];
      var $78=(($77)|0) >= 0;
      if ($78) { __label__ = 15; break; } else { __label__ = 16; break; }
    case 15: 
      var $80=$2;
      var $81=(($80+92)|0);
      var $82=HEAP32[(($81)>>2)];
      var $83=$2;
      var $84=(($83+56)|0);
      var $85=HEAP32[(($84)>>2)];
      var $86=(($85+$82)|0);
      var $89 = $86;__label__ = 17; break;
    case 16: 
      var $89 = 0;__label__ = 17; break;
    case 17: 
      var $89;
      var $90=$2;
      var $91=(($90+108)|0);
      var $92=HEAP32[(($91)>>2)];
      var $93=$2;
      var $94=(($93+92)|0);
      var $95=HEAP32[(($94)>>2)];
      var $96=((($92)-($95))|0);
      __tr_flush_block($74, $89, $96, 0);
      var $97=$2;
      var $98=(($97+108)|0);
      var $99=HEAP32[(($98)>>2)];
      var $100=$2;
      var $101=(($100+92)|0);
      HEAP32[(($101)>>2)]=$99;
      var $102=$2;
      var $103=(($102)|0);
      var $104=HEAP32[(($103)>>2)];
      _flush_pending($104);
      var $105=$2;
      var $106=(($105)|0);
      var $107=HEAP32[(($106)>>2)];
      var $108=(($107+16)|0);
      var $109=HEAP32[(($108)>>2)];
      var $110=(($109)|0)==0;
      if ($110) { __label__ = 18; break; } else { __label__ = 19; break; }
    case 18: 
      $1=0;
      __label__ = 43; break;
    case 19: 
      __label__ = 20; break;
    case 20: 
      var $114=$2;
      var $115=(($114+108)|0);
      var $116=HEAP32[(($115)>>2)];
      var $117=$2;
      var $118=(($117+92)|0);
      var $119=HEAP32[(($118)>>2)];
      var $120=((($116)-($119))|0);
      var $121=$2;
      var $122=(($121+44)|0);
      var $123=HEAP32[(($122)>>2)];
      var $124=((($123)-(262))|0);
      var $125=(($120)>>>0) >= (($124)>>>0);
      if ($125) { __label__ = 21; break; } else { __label__ = 27; break; }
    case 21: 
      var $127=$2;
      var $128=$2;
      var $129=(($128+92)|0);
      var $130=HEAP32[(($129)>>2)];
      var $131=(($130)|0) >= 0;
      if ($131) { __label__ = 22; break; } else { __label__ = 23; break; }
    case 22: 
      var $133=$2;
      var $134=(($133+92)|0);
      var $135=HEAP32[(($134)>>2)];
      var $136=$2;
      var $137=(($136+56)|0);
      var $138=HEAP32[(($137)>>2)];
      var $139=(($138+$135)|0);
      var $142 = $139;__label__ = 24; break;
    case 23: 
      var $142 = 0;__label__ = 24; break;
    case 24: 
      var $142;
      var $143=$2;
      var $144=(($143+108)|0);
      var $145=HEAP32[(($144)>>2)];
      var $146=$2;
      var $147=(($146+92)|0);
      var $148=HEAP32[(($147)>>2)];
      var $149=((($145)-($148))|0);
      __tr_flush_block($127, $142, $149, 0);
      var $150=$2;
      var $151=(($150+108)|0);
      var $152=HEAP32[(($151)>>2)];
      var $153=$2;
      var $154=(($153+92)|0);
      HEAP32[(($154)>>2)]=$152;
      var $155=$2;
      var $156=(($155)|0);
      var $157=HEAP32[(($156)>>2)];
      _flush_pending($157);
      var $158=$2;
      var $159=(($158)|0);
      var $160=HEAP32[(($159)>>2)];
      var $161=(($160+16)|0);
      var $162=HEAP32[(($161)>>2)];
      var $163=(($162)|0)==0;
      if ($163) { __label__ = 25; break; } else { __label__ = 26; break; }
    case 25: 
      $1=0;
      __label__ = 43; break;
    case 26: 
      __label__ = 27; break;
    case 27: 
      __label__ = 5; break;
    case 28: 
      var $168=$2;
      var $169=(($168+5812)|0);
      HEAP32[(($169)>>2)]=0;
      var $170=$3;
      var $171=(($170)|0)==4;
      if ($171) { __label__ = 29; break; } else { __label__ = 35; break; }
    case 29: 
      var $173=$2;
      var $174=$2;
      var $175=(($174+92)|0);
      var $176=HEAP32[(($175)>>2)];
      var $177=(($176)|0) >= 0;
      if ($177) { __label__ = 30; break; } else { __label__ = 31; break; }
    case 30: 
      var $179=$2;
      var $180=(($179+92)|0);
      var $181=HEAP32[(($180)>>2)];
      var $182=$2;
      var $183=(($182+56)|0);
      var $184=HEAP32[(($183)>>2)];
      var $185=(($184+$181)|0);
      var $188 = $185;__label__ = 32; break;
    case 31: 
      var $188 = 0;__label__ = 32; break;
    case 32: 
      var $188;
      var $189=$2;
      var $190=(($189+108)|0);
      var $191=HEAP32[(($190)>>2)];
      var $192=$2;
      var $193=(($192+92)|0);
      var $194=HEAP32[(($193)>>2)];
      var $195=((($191)-($194))|0);
      __tr_flush_block($173, $188, $195, 1);
      var $196=$2;
      var $197=(($196+108)|0);
      var $198=HEAP32[(($197)>>2)];
      var $199=$2;
      var $200=(($199+92)|0);
      HEAP32[(($200)>>2)]=$198;
      var $201=$2;
      var $202=(($201)|0);
      var $203=HEAP32[(($202)>>2)];
      _flush_pending($203);
      var $204=$2;
      var $205=(($204)|0);
      var $206=HEAP32[(($205)>>2)];
      var $207=(($206+16)|0);
      var $208=HEAP32[(($207)>>2)];
      var $209=(($208)|0)==0;
      if ($209) { __label__ = 33; break; } else { __label__ = 34; break; }
    case 33: 
      $1=2;
      __label__ = 43; break;
    case 34: 
      $1=3;
      __label__ = 43; break;
    case 35: 
      var $213=$2;
      var $214=(($213+108)|0);
      var $215=HEAP32[(($214)>>2)];
      var $216=$2;
      var $217=(($216+92)|0);
      var $218=HEAP32[(($217)>>2)];
      var $219=(($215)|0) > (($218)|0);
      if ($219) { __label__ = 36; break; } else { __label__ = 42; break; }
    case 36: 
      var $221=$2;
      var $222=$2;
      var $223=(($222+92)|0);
      var $224=HEAP32[(($223)>>2)];
      var $225=(($224)|0) >= 0;
      if ($225) { __label__ = 37; break; } else { __label__ = 38; break; }
    case 37: 
      var $227=$2;
      var $228=(($227+92)|0);
      var $229=HEAP32[(($228)>>2)];
      var $230=$2;
      var $231=(($230+56)|0);
      var $232=HEAP32[(($231)>>2)];
      var $233=(($232+$229)|0);
      var $236 = $233;__label__ = 39; break;
    case 38: 
      var $236 = 0;__label__ = 39; break;
    case 39: 
      var $236;
      var $237=$2;
      var $238=(($237+108)|0);
      var $239=HEAP32[(($238)>>2)];
      var $240=$2;
      var $241=(($240+92)|0);
      var $242=HEAP32[(($241)>>2)];
      var $243=((($239)-($242))|0);
      __tr_flush_block($221, $236, $243, 0);
      var $244=$2;
      var $245=(($244+108)|0);
      var $246=HEAP32[(($245)>>2)];
      var $247=$2;
      var $248=(($247+92)|0);
      HEAP32[(($248)>>2)]=$246;
      var $249=$2;
      var $250=(($249)|0);
      var $251=HEAP32[(($250)>>2)];
      _flush_pending($251);
      var $252=$2;
      var $253=(($252)|0);
      var $254=HEAP32[(($253)>>2)];
      var $255=(($254+16)|0);
      var $256=HEAP32[(($255)>>2)];
      var $257=(($256)|0)==0;
      if ($257) { __label__ = 40; break; } else { __label__ = 41; break; }
    case 40: 
      $1=0;
      __label__ = 43; break;
    case 41: 
      __label__ = 42; break;
    case 42: 
      $1=1;
      __label__ = 43; break;
    case 43: 
      var $262=$1;
      ;
      return $262;
    default: assert(0, "bad label: " + __label__);
  }
}
_deflate_stored["X"]=1;

function _deflate_fast($s, $flush) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $hash_head;
      var $bflush;
      var $len;
      var $dist;
      var $cc;
      $2=$s;
      $3=$flush;
      __label__ = 3; break;
    case 3: 
      var $5=$2;
      var $6=(($5+116)|0);
      var $7=HEAPU32[(($6)>>2)];
      var $8=(($7)>>>0) < 262;
      if ($8) { __label__ = 4; break; } else { __label__ = 10; break; }
    case 4: 
      var $10=$2;
      _fill_window($10);
      var $11=$2;
      var $12=(($11+116)|0);
      var $13=HEAPU32[(($12)>>2)];
      var $14=(($13)>>>0) < 262;
      if ($14) { __label__ = 5; break; } else { __label__ = 7; break; }
    case 5: 
      var $16=$3;
      var $17=(($16)|0)==0;
      if ($17) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      $1=0;
      __label__ = 54; break;
    case 7: 
      var $20=$2;
      var $21=(($20+116)|0);
      var $22=HEAP32[(($21)>>2)];
      var $23=(($22)|0)==0;
      if ($23) { __label__ = 8; break; } else { __label__ = 9; break; }
    case 8: 
      __label__ = 36; break;
    case 9: 
      __label__ = 10; break;
    case 10: 
      $hash_head=0;
      var $27=$2;
      var $28=(($27+116)|0);
      var $29=HEAPU32[(($28)>>2)];
      var $30=(($29)>>>0) >= 3;
      if ($30) { __label__ = 11; break; } else { __label__ = 12; break; }
    case 11: 
      var $32=$2;
      var $33=(($32+72)|0);
      var $34=HEAP32[(($33)>>2)];
      var $35=$2;
      var $36=(($35+88)|0);
      var $37=HEAP32[(($36)>>2)];
      var $38=$34 << $37;
      var $39=$2;
      var $40=(($39+108)|0);
      var $41=HEAP32[(($40)>>2)];
      var $42=((($41)+(2))|0);
      var $43=$2;
      var $44=(($43+56)|0);
      var $45=HEAP32[(($44)>>2)];
      var $46=(($45+$42)|0);
      var $47=HEAPU8[($46)];
      var $48=(($47)&255);
      var $49=$38 ^ $48;
      var $50=$2;
      var $51=(($50+84)|0);
      var $52=HEAP32[(($51)>>2)];
      var $53=$49 & $52;
      var $54=$2;
      var $55=(($54+72)|0);
      HEAP32[(($55)>>2)]=$53;
      var $56=$2;
      var $57=(($56+72)|0);
      var $58=HEAP32[(($57)>>2)];
      var $59=$2;
      var $60=(($59+68)|0);
      var $61=HEAP32[(($60)>>2)];
      var $62=(($61+($58<<1))|0);
      var $63=HEAPU16[(($62)>>1)];
      var $64=$2;
      var $65=(($64+108)|0);
      var $66=HEAP32[(($65)>>2)];
      var $67=$2;
      var $68=(($67+52)|0);
      var $69=HEAP32[(($68)>>2)];
      var $70=$66 & $69;
      var $71=$2;
      var $72=(($71+64)|0);
      var $73=HEAP32[(($72)>>2)];
      var $74=(($73+($70<<1))|0);
      HEAP16[(($74)>>1)]=$63;
      var $75=(($63)&65535);
      $hash_head=$75;
      var $76=$2;
      var $77=(($76+108)|0);
      var $78=HEAP32[(($77)>>2)];
      var $79=(($78) & 65535);
      var $80=$2;
      var $81=(($80+72)|0);
      var $82=HEAP32[(($81)>>2)];
      var $83=$2;
      var $84=(($83+68)|0);
      var $85=HEAP32[(($84)>>2)];
      var $86=(($85+($82<<1))|0);
      HEAP16[(($86)>>1)]=$79;
      __label__ = 12; break;
    case 12: 
      var $88=$hash_head;
      var $89=(($88)|0)!=0;
      if ($89) { __label__ = 13; break; } else { __label__ = 15; break; }
    case 13: 
      var $91=$2;
      var $92=(($91+108)|0);
      var $93=HEAP32[(($92)>>2)];
      var $94=$hash_head;
      var $95=((($93)-($94))|0);
      var $96=$2;
      var $97=(($96+44)|0);
      var $98=HEAP32[(($97)>>2)];
      var $99=((($98)-(262))|0);
      var $100=(($95)>>>0) <= (($99)>>>0);
      if ($100) { __label__ = 14; break; } else { __label__ = 15; break; }
    case 14: 
      var $102=$2;
      var $103=$hash_head;
      var $104=_longest_match($102, $103);
      var $105=$2;
      var $106=(($105+96)|0);
      HEAP32[(($106)>>2)]=$104;
      __label__ = 15; break;
    case 15: 
      var $108=$2;
      var $109=(($108+96)|0);
      var $110=HEAPU32[(($109)>>2)];
      var $111=(($110)>>>0) >= 3;
      if ($111) { __label__ = 16; break; } else { __label__ = 27; break; }
    case 16: 
      var $113=$2;
      var $114=(($113+96)|0);
      var $115=HEAP32[(($114)>>2)];
      var $116=((($115)-(3))|0);
      var $117=(($116) & 255);
      $len=$117;
      var $118=$2;
      var $119=(($118+108)|0);
      var $120=HEAP32[(($119)>>2)];
      var $121=$2;
      var $122=(($121+112)|0);
      var $123=HEAP32[(($122)>>2)];
      var $124=((($120)-($123))|0);
      var $125=(($124) & 65535);
      $dist=$125;
      var $126=$dist;
      var $127=$2;
      var $128=(($127+5792)|0);
      var $129=HEAP32[(($128)>>2)];
      var $130=$2;
      var $131=(($130+5796)|0);
      var $132=HEAP32[(($131)>>2)];
      var $133=(($132+($129<<1))|0);
      HEAP16[(($133)>>1)]=$126;
      var $134=$len;
      var $135=$2;
      var $136=(($135+5792)|0);
      var $137=HEAP32[(($136)>>2)];
      var $138=((($137)+(1))|0);
      HEAP32[(($136)>>2)]=$138;
      var $139=$2;
      var $140=(($139+5784)|0);
      var $141=HEAP32[(($140)>>2)];
      var $142=(($141+$137)|0);
      HEAP8[($142)]=$134;
      var $143=$dist;
      var $144=((($143)-(1))&65535);
      $dist=$144;
      var $145=$len;
      var $146=(($145)&255);
      var $147=(((STRING_TABLE.__length_code)+$146)|0);
      var $148=HEAPU8[($147)];
      var $149=(($148)&255);
      var $150=((($149)+(256))|0);
      var $151=((($150)+(1))|0);
      var $152=$2;
      var $153=(($152+148)|0);
      var $154=(($153+($151<<2))|0);
      var $155=(($154)|0);
      var $156=$155;
      var $157=HEAP16[(($156)>>1)];
      var $158=((($157)+(1))&65535);
      HEAP16[(($156)>>1)]=$158;
      var $159=$dist;
      var $160=(($159)&65535);
      var $161=(($160)|0) < 256;
      if ($161) { __label__ = 17; break; } else { __label__ = 18; break; }
    case 17: 
      var $163=$dist;
      var $164=(($163)&65535);
      var $165=(((STRING_TABLE.__dist_code)+$164)|0);
      var $166=HEAPU8[($165)];
      var $167=(($166)&255);
      var $177 = $167;__label__ = 19; break;
    case 18: 
      var $169=$dist;
      var $170=(($169)&65535);
      var $171=$170 >> 7;
      var $172=((($171)+(256))|0);
      var $173=(((STRING_TABLE.__dist_code)+$172)|0);
      var $174=HEAPU8[($173)];
      var $175=(($174)&255);
      var $177 = $175;__label__ = 19; break;
    case 19: 
      var $177;
      var $178=$2;
      var $179=(($178+2440)|0);
      var $180=(($179+($177<<2))|0);
      var $181=(($180)|0);
      var $182=$181;
      var $183=HEAP16[(($182)>>1)];
      var $184=((($183)+(1))&65535);
      HEAP16[(($182)>>1)]=$184;
      var $185=$2;
      var $186=(($185+5792)|0);
      var $187=HEAP32[(($186)>>2)];
      var $188=$2;
      var $189=(($188+5788)|0);
      var $190=HEAP32[(($189)>>2)];
      var $191=((($190)-(1))|0);
      var $192=(($187)|0)==(($191)|0);
      var $193=(($192)&1);
      $bflush=$193;
      var $194=$2;
      var $195=(($194+96)|0);
      var $196=HEAP32[(($195)>>2)];
      var $197=$2;
      var $198=(($197+116)|0);
      var $199=HEAP32[(($198)>>2)];
      var $200=((($199)-($196))|0);
      HEAP32[(($198)>>2)]=$200;
      var $201=$2;
      var $202=(($201+96)|0);
      var $203=HEAPU32[(($202)>>2)];
      var $204=$2;
      var $205=(($204+128)|0);
      var $206=HEAPU32[(($205)>>2)];
      var $207=(($203)>>>0) <= (($206)>>>0);
      if ($207) { __label__ = 20; break; } else { __label__ = 25; break; }
    case 20: 
      var $209=$2;
      var $210=(($209+116)|0);
      var $211=HEAPU32[(($210)>>2)];
      var $212=(($211)>>>0) >= 3;
      if ($212) { __label__ = 21; break; } else { __label__ = 25; break; }
    case 21: 
      var $214=$2;
      var $215=(($214+96)|0);
      var $216=HEAP32[(($215)>>2)];
      var $217=((($216)-(1))|0);
      HEAP32[(($215)>>2)]=$217;
      __label__ = 22; break;
    case 22: 
      var $219=$2;
      var $220=(($219+108)|0);
      var $221=HEAP32[(($220)>>2)];
      var $222=((($221)+(1))|0);
      HEAP32[(($220)>>2)]=$222;
      var $223=$2;
      var $224=(($223+72)|0);
      var $225=HEAP32[(($224)>>2)];
      var $226=$2;
      var $227=(($226+88)|0);
      var $228=HEAP32[(($227)>>2)];
      var $229=$225 << $228;
      var $230=$2;
      var $231=(($230+108)|0);
      var $232=HEAP32[(($231)>>2)];
      var $233=((($232)+(2))|0);
      var $234=$2;
      var $235=(($234+56)|0);
      var $236=HEAP32[(($235)>>2)];
      var $237=(($236+$233)|0);
      var $238=HEAPU8[($237)];
      var $239=(($238)&255);
      var $240=$229 ^ $239;
      var $241=$2;
      var $242=(($241+84)|0);
      var $243=HEAP32[(($242)>>2)];
      var $244=$240 & $243;
      var $245=$2;
      var $246=(($245+72)|0);
      HEAP32[(($246)>>2)]=$244;
      var $247=$2;
      var $248=(($247+72)|0);
      var $249=HEAP32[(($248)>>2)];
      var $250=$2;
      var $251=(($250+68)|0);
      var $252=HEAP32[(($251)>>2)];
      var $253=(($252+($249<<1))|0);
      var $254=HEAPU16[(($253)>>1)];
      var $255=$2;
      var $256=(($255+108)|0);
      var $257=HEAP32[(($256)>>2)];
      var $258=$2;
      var $259=(($258+52)|0);
      var $260=HEAP32[(($259)>>2)];
      var $261=$257 & $260;
      var $262=$2;
      var $263=(($262+64)|0);
      var $264=HEAP32[(($263)>>2)];
      var $265=(($264+($261<<1))|0);
      HEAP16[(($265)>>1)]=$254;
      var $266=(($254)&65535);
      $hash_head=$266;
      var $267=$2;
      var $268=(($267+108)|0);
      var $269=HEAP32[(($268)>>2)];
      var $270=(($269) & 65535);
      var $271=$2;
      var $272=(($271+72)|0);
      var $273=HEAP32[(($272)>>2)];
      var $274=$2;
      var $275=(($274+68)|0);
      var $276=HEAP32[(($275)>>2)];
      var $277=(($276+($273<<1))|0);
      HEAP16[(($277)>>1)]=$270;
      __label__ = 23; break;
    case 23: 
      var $279=$2;
      var $280=(($279+96)|0);
      var $281=HEAP32[(($280)>>2)];
      var $282=((($281)-(1))|0);
      HEAP32[(($280)>>2)]=$282;
      var $283=(($282)|0)!=0;
      if ($283) { __label__ = 22; break; } else { __label__ = 24; break; }
    case 24: 
      var $285=$2;
      var $286=(($285+108)|0);
      var $287=HEAP32[(($286)>>2)];
      var $288=((($287)+(1))|0);
      HEAP32[(($286)>>2)]=$288;
      __label__ = 26; break;
    case 25: 
      var $290=$2;
      var $291=(($290+96)|0);
      var $292=HEAP32[(($291)>>2)];
      var $293=$2;
      var $294=(($293+108)|0);
      var $295=HEAP32[(($294)>>2)];
      var $296=((($295)+($292))|0);
      HEAP32[(($294)>>2)]=$296;
      var $297=$2;
      var $298=(($297+96)|0);
      HEAP32[(($298)>>2)]=0;
      var $299=$2;
      var $300=(($299+108)|0);
      var $301=HEAP32[(($300)>>2)];
      var $302=$2;
      var $303=(($302+56)|0);
      var $304=HEAP32[(($303)>>2)];
      var $305=(($304+$301)|0);
      var $306=HEAPU8[($305)];
      var $307=(($306)&255);
      var $308=$2;
      var $309=(($308+72)|0);
      HEAP32[(($309)>>2)]=$307;
      var $310=$2;
      var $311=(($310+72)|0);
      var $312=HEAP32[(($311)>>2)];
      var $313=$2;
      var $314=(($313+88)|0);
      var $315=HEAP32[(($314)>>2)];
      var $316=$312 << $315;
      var $317=$2;
      var $318=(($317+108)|0);
      var $319=HEAP32[(($318)>>2)];
      var $320=((($319)+(1))|0);
      var $321=$2;
      var $322=(($321+56)|0);
      var $323=HEAP32[(($322)>>2)];
      var $324=(($323+$320)|0);
      var $325=HEAPU8[($324)];
      var $326=(($325)&255);
      var $327=$316 ^ $326;
      var $328=$2;
      var $329=(($328+84)|0);
      var $330=HEAP32[(($329)>>2)];
      var $331=$327 & $330;
      var $332=$2;
      var $333=(($332+72)|0);
      HEAP32[(($333)>>2)]=$331;
      __label__ = 26; break;
    case 26: 
      __label__ = 28; break;
    case 27: 
      var $336=$2;
      var $337=(($336+108)|0);
      var $338=HEAP32[(($337)>>2)];
      var $339=$2;
      var $340=(($339+56)|0);
      var $341=HEAP32[(($340)>>2)];
      var $342=(($341+$338)|0);
      var $343=HEAP8[($342)];
      $cc=$343;
      var $344=$2;
      var $345=(($344+5792)|0);
      var $346=HEAP32[(($345)>>2)];
      var $347=$2;
      var $348=(($347+5796)|0);
      var $349=HEAP32[(($348)>>2)];
      var $350=(($349+($346<<1))|0);
      HEAP16[(($350)>>1)]=0;
      var $351=$cc;
      var $352=$2;
      var $353=(($352+5792)|0);
      var $354=HEAP32[(($353)>>2)];
      var $355=((($354)+(1))|0);
      HEAP32[(($353)>>2)]=$355;
      var $356=$2;
      var $357=(($356+5784)|0);
      var $358=HEAP32[(($357)>>2)];
      var $359=(($358+$354)|0);
      HEAP8[($359)]=$351;
      var $360=$cc;
      var $361=(($360)&255);
      var $362=$2;
      var $363=(($362+148)|0);
      var $364=(($363+($361<<2))|0);
      var $365=(($364)|0);
      var $366=$365;
      var $367=HEAP16[(($366)>>1)];
      var $368=((($367)+(1))&65535);
      HEAP16[(($366)>>1)]=$368;
      var $369=$2;
      var $370=(($369+5792)|0);
      var $371=HEAP32[(($370)>>2)];
      var $372=$2;
      var $373=(($372+5788)|0);
      var $374=HEAP32[(($373)>>2)];
      var $375=((($374)-(1))|0);
      var $376=(($371)|0)==(($375)|0);
      var $377=(($376)&1);
      $bflush=$377;
      var $378=$2;
      var $379=(($378+116)|0);
      var $380=HEAP32[(($379)>>2)];
      var $381=((($380)-(1))|0);
      HEAP32[(($379)>>2)]=$381;
      var $382=$2;
      var $383=(($382+108)|0);
      var $384=HEAP32[(($383)>>2)];
      var $385=((($384)+(1))|0);
      HEAP32[(($383)>>2)]=$385;
      __label__ = 28; break;
    case 28: 
      var $387=$bflush;
      var $388=(($387)|0)!=0;
      if ($388) { __label__ = 29; break; } else { __label__ = 35; break; }
    case 29: 
      var $390=$2;
      var $391=$2;
      var $392=(($391+92)|0);
      var $393=HEAP32[(($392)>>2)];
      var $394=(($393)|0) >= 0;
      if ($394) { __label__ = 30; break; } else { __label__ = 31; break; }
    case 30: 
      var $396=$2;
      var $397=(($396+92)|0);
      var $398=HEAP32[(($397)>>2)];
      var $399=$2;
      var $400=(($399+56)|0);
      var $401=HEAP32[(($400)>>2)];
      var $402=(($401+$398)|0);
      var $405 = $402;__label__ = 32; break;
    case 31: 
      var $405 = 0;__label__ = 32; break;
    case 32: 
      var $405;
      var $406=$2;
      var $407=(($406+108)|0);
      var $408=HEAP32[(($407)>>2)];
      var $409=$2;
      var $410=(($409+92)|0);
      var $411=HEAP32[(($410)>>2)];
      var $412=((($408)-($411))|0);
      __tr_flush_block($390, $405, $412, 0);
      var $413=$2;
      var $414=(($413+108)|0);
      var $415=HEAP32[(($414)>>2)];
      var $416=$2;
      var $417=(($416+92)|0);
      HEAP32[(($417)>>2)]=$415;
      var $418=$2;
      var $419=(($418)|0);
      var $420=HEAP32[(($419)>>2)];
      _flush_pending($420);
      var $421=$2;
      var $422=(($421)|0);
      var $423=HEAP32[(($422)>>2)];
      var $424=(($423+16)|0);
      var $425=HEAP32[(($424)>>2)];
      var $426=(($425)|0)==0;
      if ($426) { __label__ = 33; break; } else { __label__ = 34; break; }
    case 33: 
      $1=0;
      __label__ = 54; break;
    case 34: 
      __label__ = 35; break;
    case 35: 
      __label__ = 3; break;
    case 36: 
      var $431=$2;
      var $432=(($431+108)|0);
      var $433=HEAPU32[(($432)>>2)];
      var $434=(($433)>>>0) < 2;
      if ($434) { __label__ = 37; break; } else { __label__ = 38; break; }
    case 37: 
      var $436=$2;
      var $437=(($436+108)|0);
      var $438=HEAP32[(($437)>>2)];
      var $441 = $438;__label__ = 39; break;
    case 38: 
      var $441 = 2;__label__ = 39; break;
    case 39: 
      var $441;
      var $442=$2;
      var $443=(($442+5812)|0);
      HEAP32[(($443)>>2)]=$441;
      var $444=$3;
      var $445=(($444)|0)==4;
      if ($445) { __label__ = 40; break; } else { __label__ = 46; break; }
    case 40: 
      var $447=$2;
      var $448=$2;
      var $449=(($448+92)|0);
      var $450=HEAP32[(($449)>>2)];
      var $451=(($450)|0) >= 0;
      if ($451) { __label__ = 41; break; } else { __label__ = 42; break; }
    case 41: 
      var $453=$2;
      var $454=(($453+92)|0);
      var $455=HEAP32[(($454)>>2)];
      var $456=$2;
      var $457=(($456+56)|0);
      var $458=HEAP32[(($457)>>2)];
      var $459=(($458+$455)|0);
      var $462 = $459;__label__ = 43; break;
    case 42: 
      var $462 = 0;__label__ = 43; break;
    case 43: 
      var $462;
      var $463=$2;
      var $464=(($463+108)|0);
      var $465=HEAP32[(($464)>>2)];
      var $466=$2;
      var $467=(($466+92)|0);
      var $468=HEAP32[(($467)>>2)];
      var $469=((($465)-($468))|0);
      __tr_flush_block($447, $462, $469, 1);
      var $470=$2;
      var $471=(($470+108)|0);
      var $472=HEAP32[(($471)>>2)];
      var $473=$2;
      var $474=(($473+92)|0);
      HEAP32[(($474)>>2)]=$472;
      var $475=$2;
      var $476=(($475)|0);
      var $477=HEAP32[(($476)>>2)];
      _flush_pending($477);
      var $478=$2;
      var $479=(($478)|0);
      var $480=HEAP32[(($479)>>2)];
      var $481=(($480+16)|0);
      var $482=HEAP32[(($481)>>2)];
      var $483=(($482)|0)==0;
      if ($483) { __label__ = 44; break; } else { __label__ = 45; break; }
    case 44: 
      $1=2;
      __label__ = 54; break;
    case 45: 
      $1=3;
      __label__ = 54; break;
    case 46: 
      var $487=$2;
      var $488=(($487+5792)|0);
      var $489=HEAP32[(($488)>>2)];
      var $490=(($489)|0)!=0;
      if ($490) { __label__ = 47; break; } else { __label__ = 53; break; }
    case 47: 
      var $492=$2;
      var $493=$2;
      var $494=(($493+92)|0);
      var $495=HEAP32[(($494)>>2)];
      var $496=(($495)|0) >= 0;
      if ($496) { __label__ = 48; break; } else { __label__ = 49; break; }
    case 48: 
      var $498=$2;
      var $499=(($498+92)|0);
      var $500=HEAP32[(($499)>>2)];
      var $501=$2;
      var $502=(($501+56)|0);
      var $503=HEAP32[(($502)>>2)];
      var $504=(($503+$500)|0);
      var $507 = $504;__label__ = 50; break;
    case 49: 
      var $507 = 0;__label__ = 50; break;
    case 50: 
      var $507;
      var $508=$2;
      var $509=(($508+108)|0);
      var $510=HEAP32[(($509)>>2)];
      var $511=$2;
      var $512=(($511+92)|0);
      var $513=HEAP32[(($512)>>2)];
      var $514=((($510)-($513))|0);
      __tr_flush_block($492, $507, $514, 0);
      var $515=$2;
      var $516=(($515+108)|0);
      var $517=HEAP32[(($516)>>2)];
      var $518=$2;
      var $519=(($518+92)|0);
      HEAP32[(($519)>>2)]=$517;
      var $520=$2;
      var $521=(($520)|0);
      var $522=HEAP32[(($521)>>2)];
      _flush_pending($522);
      var $523=$2;
      var $524=(($523)|0);
      var $525=HEAP32[(($524)>>2)];
      var $526=(($525+16)|0);
      var $527=HEAP32[(($526)>>2)];
      var $528=(($527)|0)==0;
      if ($528) { __label__ = 51; break; } else { __label__ = 52; break; }
    case 51: 
      $1=0;
      __label__ = 54; break;
    case 52: 
      __label__ = 53; break;
    case 53: 
      $1=1;
      __label__ = 54; break;
    case 54: 
      var $533=$1;
      ;
      return $533;
    default: assert(0, "bad label: " + __label__);
  }
}
_deflate_fast["X"]=1;

function _deflate_slow($s, $flush) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $hash_head;
      var $bflush;
      var $max_insert;
      var $len;
      var $dist;
      var $cc;
      var $cc1;
      $2=$s;
      $3=$flush;
      __label__ = 3; break;
    case 3: 
      var $5=$2;
      var $6=(($5+116)|0);
      var $7=HEAPU32[(($6)>>2)];
      var $8=(($7)>>>0) < 262;
      if ($8) { __label__ = 4; break; } else { __label__ = 10; break; }
    case 4: 
      var $10=$2;
      _fill_window($10);
      var $11=$2;
      var $12=(($11+116)|0);
      var $13=HEAPU32[(($12)>>2)];
      var $14=(($13)>>>0) < 262;
      if ($14) { __label__ = 5; break; } else { __label__ = 7; break; }
    case 5: 
      var $16=$3;
      var $17=(($16)|0)==0;
      if ($17) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      $1=0;
      __label__ = 71; break;
    case 7: 
      var $20=$2;
      var $21=(($20+116)|0);
      var $22=HEAP32[(($21)>>2)];
      var $23=(($22)|0)==0;
      if ($23) { __label__ = 8; break; } else { __label__ = 9; break; }
    case 8: 
      __label__ = 51; break;
    case 9: 
      __label__ = 10; break;
    case 10: 
      $hash_head=0;
      var $27=$2;
      var $28=(($27+116)|0);
      var $29=HEAPU32[(($28)>>2)];
      var $30=(($29)>>>0) >= 3;
      if ($30) { __label__ = 11; break; } else { __label__ = 12; break; }
    case 11: 
      var $32=$2;
      var $33=(($32+72)|0);
      var $34=HEAP32[(($33)>>2)];
      var $35=$2;
      var $36=(($35+88)|0);
      var $37=HEAP32[(($36)>>2)];
      var $38=$34 << $37;
      var $39=$2;
      var $40=(($39+108)|0);
      var $41=HEAP32[(($40)>>2)];
      var $42=((($41)+(2))|0);
      var $43=$2;
      var $44=(($43+56)|0);
      var $45=HEAP32[(($44)>>2)];
      var $46=(($45+$42)|0);
      var $47=HEAPU8[($46)];
      var $48=(($47)&255);
      var $49=$38 ^ $48;
      var $50=$2;
      var $51=(($50+84)|0);
      var $52=HEAP32[(($51)>>2)];
      var $53=$49 & $52;
      var $54=$2;
      var $55=(($54+72)|0);
      HEAP32[(($55)>>2)]=$53;
      var $56=$2;
      var $57=(($56+72)|0);
      var $58=HEAP32[(($57)>>2)];
      var $59=$2;
      var $60=(($59+68)|0);
      var $61=HEAP32[(($60)>>2)];
      var $62=(($61+($58<<1))|0);
      var $63=HEAPU16[(($62)>>1)];
      var $64=$2;
      var $65=(($64+108)|0);
      var $66=HEAP32[(($65)>>2)];
      var $67=$2;
      var $68=(($67+52)|0);
      var $69=HEAP32[(($68)>>2)];
      var $70=$66 & $69;
      var $71=$2;
      var $72=(($71+64)|0);
      var $73=HEAP32[(($72)>>2)];
      var $74=(($73+($70<<1))|0);
      HEAP16[(($74)>>1)]=$63;
      var $75=(($63)&65535);
      $hash_head=$75;
      var $76=$2;
      var $77=(($76+108)|0);
      var $78=HEAP32[(($77)>>2)];
      var $79=(($78) & 65535);
      var $80=$2;
      var $81=(($80+72)|0);
      var $82=HEAP32[(($81)>>2)];
      var $83=$2;
      var $84=(($83+68)|0);
      var $85=HEAP32[(($84)>>2)];
      var $86=(($85+($82<<1))|0);
      HEAP16[(($86)>>1)]=$79;
      __label__ = 12; break;
    case 12: 
      var $88=$2;
      var $89=(($88+96)|0);
      var $90=HEAP32[(($89)>>2)];
      var $91=$2;
      var $92=(($91+120)|0);
      HEAP32[(($92)>>2)]=$90;
      var $93=$2;
      var $94=(($93+112)|0);
      var $95=HEAP32[(($94)>>2)];
      var $96=$2;
      var $97=(($96+100)|0);
      HEAP32[(($97)>>2)]=$95;
      var $98=$2;
      var $99=(($98+96)|0);
      HEAP32[(($99)>>2)]=2;
      var $100=$hash_head;
      var $101=(($100)|0)!=0;
      if ($101) { __label__ = 13; break; } else { __label__ = 21; break; }
    case 13: 
      var $103=$2;
      var $104=(($103+120)|0);
      var $105=HEAPU32[(($104)>>2)];
      var $106=$2;
      var $107=(($106+128)|0);
      var $108=HEAPU32[(($107)>>2)];
      var $109=(($105)>>>0) < (($108)>>>0);
      if ($109) { __label__ = 14; break; } else { __label__ = 21; break; }
    case 14: 
      var $111=$2;
      var $112=(($111+108)|0);
      var $113=HEAP32[(($112)>>2)];
      var $114=$hash_head;
      var $115=((($113)-($114))|0);
      var $116=$2;
      var $117=(($116+44)|0);
      var $118=HEAP32[(($117)>>2)];
      var $119=((($118)-(262))|0);
      var $120=(($115)>>>0) <= (($119)>>>0);
      if ($120) { __label__ = 15; break; } else { __label__ = 21; break; }
    case 15: 
      var $122=$2;
      var $123=$hash_head;
      var $124=_longest_match($122, $123);
      var $125=$2;
      var $126=(($125+96)|0);
      HEAP32[(($126)>>2)]=$124;
      var $127=$2;
      var $128=(($127+96)|0);
      var $129=HEAPU32[(($128)>>2)];
      var $130=(($129)>>>0) <= 5;
      if ($130) { __label__ = 16; break; } else { __label__ = 20; break; }
    case 16: 
      var $132=$2;
      var $133=(($132+136)|0);
      var $134=HEAP32[(($133)>>2)];
      var $135=(($134)|0)==1;
      if ($135) { __label__ = 19; break; } else { __label__ = 17; break; }
    case 17: 
      var $137=$2;
      var $138=(($137+96)|0);
      var $139=HEAP32[(($138)>>2)];
      var $140=(($139)|0)==3;
      if ($140) { __label__ = 18; break; } else { __label__ = 20; break; }
    case 18: 
      var $142=$2;
      var $143=(($142+108)|0);
      var $144=HEAP32[(($143)>>2)];
      var $145=$2;
      var $146=(($145+112)|0);
      var $147=HEAP32[(($146)>>2)];
      var $148=((($144)-($147))|0);
      var $149=(($148)>>>0) > 4096;
      if ($149) { __label__ = 19; break; } else { __label__ = 20; break; }
    case 19: 
      var $151=$2;
      var $152=(($151+96)|0);
      HEAP32[(($152)>>2)]=2;
      __label__ = 20; break;
    case 20: 
      __label__ = 21; break;
    case 21: 
      var $155=$2;
      var $156=(($155+120)|0);
      var $157=HEAPU32[(($156)>>2)];
      var $158=(($157)>>>0) >= 3;
      if ($158) { __label__ = 22; break; } else { __label__ = 39; break; }
    case 22: 
      var $160=$2;
      var $161=(($160+96)|0);
      var $162=HEAPU32[(($161)>>2)];
      var $163=$2;
      var $164=(($163+120)|0);
      var $165=HEAPU32[(($164)>>2)];
      var $166=(($162)>>>0) <= (($165)>>>0);
      if ($166) { __label__ = 23; break; } else { __label__ = 39; break; }
    case 23: 
      var $168=$2;
      var $169=(($168+108)|0);
      var $170=HEAP32[(($169)>>2)];
      var $171=$2;
      var $172=(($171+116)|0);
      var $173=HEAP32[(($172)>>2)];
      var $174=((($170)+($173))|0);
      var $175=((($174)-(3))|0);
      $max_insert=$175;
      var $176=$2;
      var $177=(($176+120)|0);
      var $178=HEAP32[(($177)>>2)];
      var $179=((($178)-(3))|0);
      var $180=(($179) & 255);
      $len=$180;
      var $181=$2;
      var $182=(($181+108)|0);
      var $183=HEAP32[(($182)>>2)];
      var $184=((($183)-(1))|0);
      var $185=$2;
      var $186=(($185+100)|0);
      var $187=HEAP32[(($186)>>2)];
      var $188=((($184)-($187))|0);
      var $189=(($188) & 65535);
      $dist=$189;
      var $190=$dist;
      var $191=$2;
      var $192=(($191+5792)|0);
      var $193=HEAP32[(($192)>>2)];
      var $194=$2;
      var $195=(($194+5796)|0);
      var $196=HEAP32[(($195)>>2)];
      var $197=(($196+($193<<1))|0);
      HEAP16[(($197)>>1)]=$190;
      var $198=$len;
      var $199=$2;
      var $200=(($199+5792)|0);
      var $201=HEAP32[(($200)>>2)];
      var $202=((($201)+(1))|0);
      HEAP32[(($200)>>2)]=$202;
      var $203=$2;
      var $204=(($203+5784)|0);
      var $205=HEAP32[(($204)>>2)];
      var $206=(($205+$201)|0);
      HEAP8[($206)]=$198;
      var $207=$dist;
      var $208=((($207)-(1))&65535);
      $dist=$208;
      var $209=$len;
      var $210=(($209)&255);
      var $211=(((STRING_TABLE.__length_code)+$210)|0);
      var $212=HEAPU8[($211)];
      var $213=(($212)&255);
      var $214=((($213)+(256))|0);
      var $215=((($214)+(1))|0);
      var $216=$2;
      var $217=(($216+148)|0);
      var $218=(($217+($215<<2))|0);
      var $219=(($218)|0);
      var $220=$219;
      var $221=HEAP16[(($220)>>1)];
      var $222=((($221)+(1))&65535);
      HEAP16[(($220)>>1)]=$222;
      var $223=$dist;
      var $224=(($223)&65535);
      var $225=(($224)|0) < 256;
      if ($225) { __label__ = 24; break; } else { __label__ = 25; break; }
    case 24: 
      var $227=$dist;
      var $228=(($227)&65535);
      var $229=(((STRING_TABLE.__dist_code)+$228)|0);
      var $230=HEAPU8[($229)];
      var $231=(($230)&255);
      var $241 = $231;__label__ = 26; break;
    case 25: 
      var $233=$dist;
      var $234=(($233)&65535);
      var $235=$234 >> 7;
      var $236=((($235)+(256))|0);
      var $237=(((STRING_TABLE.__dist_code)+$236)|0);
      var $238=HEAPU8[($237)];
      var $239=(($238)&255);
      var $241 = $239;__label__ = 26; break;
    case 26: 
      var $241;
      var $242=$2;
      var $243=(($242+2440)|0);
      var $244=(($243+($241<<2))|0);
      var $245=(($244)|0);
      var $246=$245;
      var $247=HEAP16[(($246)>>1)];
      var $248=((($247)+(1))&65535);
      HEAP16[(($246)>>1)]=$248;
      var $249=$2;
      var $250=(($249+5792)|0);
      var $251=HEAP32[(($250)>>2)];
      var $252=$2;
      var $253=(($252+5788)|0);
      var $254=HEAP32[(($253)>>2)];
      var $255=((($254)-(1))|0);
      var $256=(($251)|0)==(($255)|0);
      var $257=(($256)&1);
      $bflush=$257;
      var $258=$2;
      var $259=(($258+120)|0);
      var $260=HEAP32[(($259)>>2)];
      var $261=((($260)-(1))|0);
      var $262=$2;
      var $263=(($262+116)|0);
      var $264=HEAP32[(($263)>>2)];
      var $265=((($264)-($261))|0);
      HEAP32[(($263)>>2)]=$265;
      var $266=$2;
      var $267=(($266+120)|0);
      var $268=HEAP32[(($267)>>2)];
      var $269=((($268)-(2))|0);
      HEAP32[(($267)>>2)]=$269;
      __label__ = 27; break;
    case 27: 
      var $271=$2;
      var $272=(($271+108)|0);
      var $273=HEAP32[(($272)>>2)];
      var $274=((($273)+(1))|0);
      HEAP32[(($272)>>2)]=$274;
      var $275=$max_insert;
      var $276=(($274)>>>0) <= (($275)>>>0);
      if ($276) { __label__ = 28; break; } else { __label__ = 29; break; }
    case 28: 
      var $278=$2;
      var $279=(($278+72)|0);
      var $280=HEAP32[(($279)>>2)];
      var $281=$2;
      var $282=(($281+88)|0);
      var $283=HEAP32[(($282)>>2)];
      var $284=$280 << $283;
      var $285=$2;
      var $286=(($285+108)|0);
      var $287=HEAP32[(($286)>>2)];
      var $288=((($287)+(2))|0);
      var $289=$2;
      var $290=(($289+56)|0);
      var $291=HEAP32[(($290)>>2)];
      var $292=(($291+$288)|0);
      var $293=HEAPU8[($292)];
      var $294=(($293)&255);
      var $295=$284 ^ $294;
      var $296=$2;
      var $297=(($296+84)|0);
      var $298=HEAP32[(($297)>>2)];
      var $299=$295 & $298;
      var $300=$2;
      var $301=(($300+72)|0);
      HEAP32[(($301)>>2)]=$299;
      var $302=$2;
      var $303=(($302+72)|0);
      var $304=HEAP32[(($303)>>2)];
      var $305=$2;
      var $306=(($305+68)|0);
      var $307=HEAP32[(($306)>>2)];
      var $308=(($307+($304<<1))|0);
      var $309=HEAPU16[(($308)>>1)];
      var $310=$2;
      var $311=(($310+108)|0);
      var $312=HEAP32[(($311)>>2)];
      var $313=$2;
      var $314=(($313+52)|0);
      var $315=HEAP32[(($314)>>2)];
      var $316=$312 & $315;
      var $317=$2;
      var $318=(($317+64)|0);
      var $319=HEAP32[(($318)>>2)];
      var $320=(($319+($316<<1))|0);
      HEAP16[(($320)>>1)]=$309;
      var $321=(($309)&65535);
      $hash_head=$321;
      var $322=$2;
      var $323=(($322+108)|0);
      var $324=HEAP32[(($323)>>2)];
      var $325=(($324) & 65535);
      var $326=$2;
      var $327=(($326+72)|0);
      var $328=HEAP32[(($327)>>2)];
      var $329=$2;
      var $330=(($329+68)|0);
      var $331=HEAP32[(($330)>>2)];
      var $332=(($331+($328<<1))|0);
      HEAP16[(($332)>>1)]=$325;
      __label__ = 29; break;
    case 29: 
      __label__ = 30; break;
    case 30: 
      var $335=$2;
      var $336=(($335+120)|0);
      var $337=HEAP32[(($336)>>2)];
      var $338=((($337)-(1))|0);
      HEAP32[(($336)>>2)]=$338;
      var $339=(($338)|0)!=0;
      if ($339) { __label__ = 27; break; } else { __label__ = 31; break; }
    case 31: 
      var $341=$2;
      var $342=(($341+104)|0);
      HEAP32[(($342)>>2)]=0;
      var $343=$2;
      var $344=(($343+96)|0);
      HEAP32[(($344)>>2)]=2;
      var $345=$2;
      var $346=(($345+108)|0);
      var $347=HEAP32[(($346)>>2)];
      var $348=((($347)+(1))|0);
      HEAP32[(($346)>>2)]=$348;
      var $349=$bflush;
      var $350=(($349)|0)!=0;
      if ($350) { __label__ = 32; break; } else { __label__ = 38; break; }
    case 32: 
      var $352=$2;
      var $353=$2;
      var $354=(($353+92)|0);
      var $355=HEAP32[(($354)>>2)];
      var $356=(($355)|0) >= 0;
      if ($356) { __label__ = 33; break; } else { __label__ = 34; break; }
    case 33: 
      var $358=$2;
      var $359=(($358+92)|0);
      var $360=HEAP32[(($359)>>2)];
      var $361=$2;
      var $362=(($361+56)|0);
      var $363=HEAP32[(($362)>>2)];
      var $364=(($363+$360)|0);
      var $367 = $364;__label__ = 35; break;
    case 34: 
      var $367 = 0;__label__ = 35; break;
    case 35: 
      var $367;
      var $368=$2;
      var $369=(($368+108)|0);
      var $370=HEAP32[(($369)>>2)];
      var $371=$2;
      var $372=(($371+92)|0);
      var $373=HEAP32[(($372)>>2)];
      var $374=((($370)-($373))|0);
      __tr_flush_block($352, $367, $374, 0);
      var $375=$2;
      var $376=(($375+108)|0);
      var $377=HEAP32[(($376)>>2)];
      var $378=$2;
      var $379=(($378+92)|0);
      HEAP32[(($379)>>2)]=$377;
      var $380=$2;
      var $381=(($380)|0);
      var $382=HEAP32[(($381)>>2)];
      _flush_pending($382);
      var $383=$2;
      var $384=(($383)|0);
      var $385=HEAP32[(($384)>>2)];
      var $386=(($385+16)|0);
      var $387=HEAP32[(($386)>>2)];
      var $388=(($387)|0)==0;
      if ($388) { __label__ = 36; break; } else { __label__ = 37; break; }
    case 36: 
      $1=0;
      __label__ = 71; break;
    case 37: 
      __label__ = 38; break;
    case 38: 
      __label__ = 50; break;
    case 39: 
      var $393=$2;
      var $394=(($393+104)|0);
      var $395=HEAP32[(($394)>>2)];
      var $396=(($395)|0)!=0;
      if ($396) { __label__ = 40; break; } else { __label__ = 48; break; }
    case 40: 
      var $398=$2;
      var $399=(($398+108)|0);
      var $400=HEAP32[(($399)>>2)];
      var $401=((($400)-(1))|0);
      var $402=$2;
      var $403=(($402+56)|0);
      var $404=HEAP32[(($403)>>2)];
      var $405=(($404+$401)|0);
      var $406=HEAP8[($405)];
      $cc=$406;
      var $407=$2;
      var $408=(($407+5792)|0);
      var $409=HEAP32[(($408)>>2)];
      var $410=$2;
      var $411=(($410+5796)|0);
      var $412=HEAP32[(($411)>>2)];
      var $413=(($412+($409<<1))|0);
      HEAP16[(($413)>>1)]=0;
      var $414=$cc;
      var $415=$2;
      var $416=(($415+5792)|0);
      var $417=HEAP32[(($416)>>2)];
      var $418=((($417)+(1))|0);
      HEAP32[(($416)>>2)]=$418;
      var $419=$2;
      var $420=(($419+5784)|0);
      var $421=HEAP32[(($420)>>2)];
      var $422=(($421+$417)|0);
      HEAP8[($422)]=$414;
      var $423=$cc;
      var $424=(($423)&255);
      var $425=$2;
      var $426=(($425+148)|0);
      var $427=(($426+($424<<2))|0);
      var $428=(($427)|0);
      var $429=$428;
      var $430=HEAP16[(($429)>>1)];
      var $431=((($430)+(1))&65535);
      HEAP16[(($429)>>1)]=$431;
      var $432=$2;
      var $433=(($432+5792)|0);
      var $434=HEAP32[(($433)>>2)];
      var $435=$2;
      var $436=(($435+5788)|0);
      var $437=HEAP32[(($436)>>2)];
      var $438=((($437)-(1))|0);
      var $439=(($434)|0)==(($438)|0);
      var $440=(($439)&1);
      $bflush=$440;
      var $441=$bflush;
      var $442=(($441)|0)!=0;
      if ($442) { __label__ = 41; break; } else { __label__ = 45; break; }
    case 41: 
      var $444=$2;
      var $445=$2;
      var $446=(($445+92)|0);
      var $447=HEAP32[(($446)>>2)];
      var $448=(($447)|0) >= 0;
      if ($448) { __label__ = 42; break; } else { __label__ = 43; break; }
    case 42: 
      var $450=$2;
      var $451=(($450+92)|0);
      var $452=HEAP32[(($451)>>2)];
      var $453=$2;
      var $454=(($453+56)|0);
      var $455=HEAP32[(($454)>>2)];
      var $456=(($455+$452)|0);
      var $459 = $456;__label__ = 44; break;
    case 43: 
      var $459 = 0;__label__ = 44; break;
    case 44: 
      var $459;
      var $460=$2;
      var $461=(($460+108)|0);
      var $462=HEAP32[(($461)>>2)];
      var $463=$2;
      var $464=(($463+92)|0);
      var $465=HEAP32[(($464)>>2)];
      var $466=((($462)-($465))|0);
      __tr_flush_block($444, $459, $466, 0);
      var $467=$2;
      var $468=(($467+108)|0);
      var $469=HEAP32[(($468)>>2)];
      var $470=$2;
      var $471=(($470+92)|0);
      HEAP32[(($471)>>2)]=$469;
      var $472=$2;
      var $473=(($472)|0);
      var $474=HEAP32[(($473)>>2)];
      _flush_pending($474);
      __label__ = 45; break;
    case 45: 
      var $476=$2;
      var $477=(($476+108)|0);
      var $478=HEAP32[(($477)>>2)];
      var $479=((($478)+(1))|0);
      HEAP32[(($477)>>2)]=$479;
      var $480=$2;
      var $481=(($480+116)|0);
      var $482=HEAP32[(($481)>>2)];
      var $483=((($482)-(1))|0);
      HEAP32[(($481)>>2)]=$483;
      var $484=$2;
      var $485=(($484)|0);
      var $486=HEAP32[(($485)>>2)];
      var $487=(($486+16)|0);
      var $488=HEAP32[(($487)>>2)];
      var $489=(($488)|0)==0;
      if ($489) { __label__ = 46; break; } else { __label__ = 47; break; }
    case 46: 
      $1=0;
      __label__ = 71; break;
    case 47: 
      __label__ = 49; break;
    case 48: 
      var $493=$2;
      var $494=(($493+104)|0);
      HEAP32[(($494)>>2)]=1;
      var $495=$2;
      var $496=(($495+108)|0);
      var $497=HEAP32[(($496)>>2)];
      var $498=((($497)+(1))|0);
      HEAP32[(($496)>>2)]=$498;
      var $499=$2;
      var $500=(($499+116)|0);
      var $501=HEAP32[(($500)>>2)];
      var $502=((($501)-(1))|0);
      HEAP32[(($500)>>2)]=$502;
      __label__ = 49; break;
    case 49: 
      __label__ = 50; break;
    case 50: 
      __label__ = 3; break;
    case 51: 
      var $506=$2;
      var $507=(($506+104)|0);
      var $508=HEAP32[(($507)>>2)];
      var $509=(($508)|0)!=0;
      if ($509) { __label__ = 52; break; } else { __label__ = 53; break; }
    case 52: 
      var $511=$2;
      var $512=(($511+108)|0);
      var $513=HEAP32[(($512)>>2)];
      var $514=((($513)-(1))|0);
      var $515=$2;
      var $516=(($515+56)|0);
      var $517=HEAP32[(($516)>>2)];
      var $518=(($517+$514)|0);
      var $519=HEAP8[($518)];
      $cc1=$519;
      var $520=$2;
      var $521=(($520+5792)|0);
      var $522=HEAP32[(($521)>>2)];
      var $523=$2;
      var $524=(($523+5796)|0);
      var $525=HEAP32[(($524)>>2)];
      var $526=(($525+($522<<1))|0);
      HEAP16[(($526)>>1)]=0;
      var $527=$cc1;
      var $528=$2;
      var $529=(($528+5792)|0);
      var $530=HEAP32[(($529)>>2)];
      var $531=((($530)+(1))|0);
      HEAP32[(($529)>>2)]=$531;
      var $532=$2;
      var $533=(($532+5784)|0);
      var $534=HEAP32[(($533)>>2)];
      var $535=(($534+$530)|0);
      HEAP8[($535)]=$527;
      var $536=$cc1;
      var $537=(($536)&255);
      var $538=$2;
      var $539=(($538+148)|0);
      var $540=(($539+($537<<2))|0);
      var $541=(($540)|0);
      var $542=$541;
      var $543=HEAP16[(($542)>>1)];
      var $544=((($543)+(1))&65535);
      HEAP16[(($542)>>1)]=$544;
      var $545=$2;
      var $546=(($545+5792)|0);
      var $547=HEAP32[(($546)>>2)];
      var $548=$2;
      var $549=(($548+5788)|0);
      var $550=HEAP32[(($549)>>2)];
      var $551=((($550)-(1))|0);
      var $552=(($547)|0)==(($551)|0);
      var $553=(($552)&1);
      $bflush=$553;
      var $554=$2;
      var $555=(($554+104)|0);
      HEAP32[(($555)>>2)]=0;
      __label__ = 53; break;
    case 53: 
      var $557=$2;
      var $558=(($557+108)|0);
      var $559=HEAPU32[(($558)>>2)];
      var $560=(($559)>>>0) < 2;
      if ($560) { __label__ = 54; break; } else { __label__ = 55; break; }
    case 54: 
      var $562=$2;
      var $563=(($562+108)|0);
      var $564=HEAP32[(($563)>>2)];
      var $567 = $564;__label__ = 56; break;
    case 55: 
      var $567 = 2;__label__ = 56; break;
    case 56: 
      var $567;
      var $568=$2;
      var $569=(($568+5812)|0);
      HEAP32[(($569)>>2)]=$567;
      var $570=$3;
      var $571=(($570)|0)==4;
      if ($571) { __label__ = 57; break; } else { __label__ = 63; break; }
    case 57: 
      var $573=$2;
      var $574=$2;
      var $575=(($574+92)|0);
      var $576=HEAP32[(($575)>>2)];
      var $577=(($576)|0) >= 0;
      if ($577) { __label__ = 58; break; } else { __label__ = 59; break; }
    case 58: 
      var $579=$2;
      var $580=(($579+92)|0);
      var $581=HEAP32[(($580)>>2)];
      var $582=$2;
      var $583=(($582+56)|0);
      var $584=HEAP32[(($583)>>2)];
      var $585=(($584+$581)|0);
      var $588 = $585;__label__ = 60; break;
    case 59: 
      var $588 = 0;__label__ = 60; break;
    case 60: 
      var $588;
      var $589=$2;
      var $590=(($589+108)|0);
      var $591=HEAP32[(($590)>>2)];
      var $592=$2;
      var $593=(($592+92)|0);
      var $594=HEAP32[(($593)>>2)];
      var $595=((($591)-($594))|0);
      __tr_flush_block($573, $588, $595, 1);
      var $596=$2;
      var $597=(($596+108)|0);
      var $598=HEAP32[(($597)>>2)];
      var $599=$2;
      var $600=(($599+92)|0);
      HEAP32[(($600)>>2)]=$598;
      var $601=$2;
      var $602=(($601)|0);
      var $603=HEAP32[(($602)>>2)];
      _flush_pending($603);
      var $604=$2;
      var $605=(($604)|0);
      var $606=HEAP32[(($605)>>2)];
      var $607=(($606+16)|0);
      var $608=HEAP32[(($607)>>2)];
      var $609=(($608)|0)==0;
      if ($609) { __label__ = 61; break; } else { __label__ = 62; break; }
    case 61: 
      $1=2;
      __label__ = 71; break;
    case 62: 
      $1=3;
      __label__ = 71; break;
    case 63: 
      var $613=$2;
      var $614=(($613+5792)|0);
      var $615=HEAP32[(($614)>>2)];
      var $616=(($615)|0)!=0;
      if ($616) { __label__ = 64; break; } else { __label__ = 70; break; }
    case 64: 
      var $618=$2;
      var $619=$2;
      var $620=(($619+92)|0);
      var $621=HEAP32[(($620)>>2)];
      var $622=(($621)|0) >= 0;
      if ($622) { __label__ = 65; break; } else { __label__ = 66; break; }
    case 65: 
      var $624=$2;
      var $625=(($624+92)|0);
      var $626=HEAP32[(($625)>>2)];
      var $627=$2;
      var $628=(($627+56)|0);
      var $629=HEAP32[(($628)>>2)];
      var $630=(($629+$626)|0);
      var $633 = $630;__label__ = 67; break;
    case 66: 
      var $633 = 0;__label__ = 67; break;
    case 67: 
      var $633;
      var $634=$2;
      var $635=(($634+108)|0);
      var $636=HEAP32[(($635)>>2)];
      var $637=$2;
      var $638=(($637+92)|0);
      var $639=HEAP32[(($638)>>2)];
      var $640=((($636)-($639))|0);
      __tr_flush_block($618, $633, $640, 0);
      var $641=$2;
      var $642=(($641+108)|0);
      var $643=HEAP32[(($642)>>2)];
      var $644=$2;
      var $645=(($644+92)|0);
      HEAP32[(($645)>>2)]=$643;
      var $646=$2;
      var $647=(($646)|0);
      var $648=HEAP32[(($647)>>2)];
      _flush_pending($648);
      var $649=$2;
      var $650=(($649)|0);
      var $651=HEAP32[(($650)>>2)];
      var $652=(($651+16)|0);
      var $653=HEAP32[(($652)>>2)];
      var $654=(($653)|0)==0;
      if ($654) { __label__ = 68; break; } else { __label__ = 69; break; }
    case 68: 
      $1=0;
      __label__ = 71; break;
    case 69: 
      __label__ = 70; break;
    case 70: 
      $1=1;
      __label__ = 71; break;
    case 71: 
      var $659=$1;
      ;
      return $659;
    default: assert(0, "bad label: " + __label__);
  }
}
_deflate_slow["X"]=1;

function _longest_match($s, $cur_match) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $chain_length;
      var $scan;
      var $match;
      var $len;
      var $best_len;
      var $nice_match;
      var $limit;
      var $prev;
      var $wmask;
      var $strend;
      var $scan_end1;
      var $scan_end;
      $2=$s;
      $3=$cur_match;
      var $4=$2;
      var $5=(($4+124)|0);
      var $6=HEAP32[(($5)>>2)];
      $chain_length=$6;
      var $7=$2;
      var $8=(($7+56)|0);
      var $9=HEAP32[(($8)>>2)];
      var $10=$2;
      var $11=(($10+108)|0);
      var $12=HEAP32[(($11)>>2)];
      var $13=(($9+$12)|0);
      $scan=$13;
      var $14=$2;
      var $15=(($14+120)|0);
      var $16=HEAP32[(($15)>>2)];
      $best_len=$16;
      var $17=$2;
      var $18=(($17+144)|0);
      var $19=HEAP32[(($18)>>2)];
      $nice_match=$19;
      var $20=$2;
      var $21=(($20+108)|0);
      var $22=HEAPU32[(($21)>>2)];
      var $23=$2;
      var $24=(($23+44)|0);
      var $25=HEAP32[(($24)>>2)];
      var $26=((($25)-(262))|0);
      var $27=(($22)>>>0) > (($26)>>>0);
      if ($27) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $29=$2;
      var $30=(($29+108)|0);
      var $31=HEAP32[(($30)>>2)];
      var $32=$2;
      var $33=(($32+44)|0);
      var $34=HEAP32[(($33)>>2)];
      var $35=((($34)-(262))|0);
      var $36=((($31)-($35))|0);
      var $39 = $36;__label__ = 5; break;
    case 4: 
      var $39 = 0;__label__ = 5; break;
    case 5: 
      var $39;
      $limit=$39;
      var $40=$2;
      var $41=(($40+64)|0);
      var $42=HEAP32[(($41)>>2)];
      $prev=$42;
      var $43=$2;
      var $44=(($43+52)|0);
      var $45=HEAP32[(($44)>>2)];
      $wmask=$45;
      var $46=$2;
      var $47=(($46+56)|0);
      var $48=HEAP32[(($47)>>2)];
      var $49=$2;
      var $50=(($49+108)|0);
      var $51=HEAP32[(($50)>>2)];
      var $52=(($48+$51)|0);
      var $53=(($52+258)|0);
      $strend=$53;
      var $54=$best_len;
      var $55=((($54)-(1))|0);
      var $56=$scan;
      var $57=(($56+$55)|0);
      var $58=HEAP8[($57)];
      $scan_end1=$58;
      var $59=$best_len;
      var $60=$scan;
      var $61=(($60+$59)|0);
      var $62=HEAP8[($61)];
      $scan_end=$62;
      var $63=$2;
      var $64=(($63+120)|0);
      var $65=HEAPU32[(($64)>>2)];
      var $66=$2;
      var $67=(($66+140)|0);
      var $68=HEAPU32[(($67)>>2)];
      var $69=(($65)>>>0) >= (($68)>>>0);
      if ($69) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      var $71=$chain_length;
      var $72=$71 >>> 2;
      $chain_length=$72;
      __label__ = 7; break;
    case 7: 
      var $74=$nice_match;
      var $75=$2;
      var $76=(($75+116)|0);
      var $77=HEAPU32[(($76)>>2)];
      var $78=(($74)>>>0) > (($77)>>>0);
      if ($78) { __label__ = 8; break; } else { __label__ = 9; break; }
    case 8: 
      var $80=$2;
      var $81=(($80+116)|0);
      var $82=HEAP32[(($81)>>2)];
      $nice_match=$82;
      __label__ = 9; break;
    case 9: 
      __label__ = 10; break;
    case 10: 
      var $85=$2;
      var $86=(($85+56)|0);
      var $87=HEAP32[(($86)>>2)];
      var $88=$3;
      var $89=(($87+$88)|0);
      $match=$89;
      var $90=$best_len;
      var $91=$match;
      var $92=(($91+$90)|0);
      var $93=HEAPU8[($92)];
      var $94=(($93)&255);
      var $95=$scan_end;
      var $96=(($95)&255);
      var $97=(($94)|0)!=(($96)|0);
      if ($97) { __label__ = 14; break; } else { __label__ = 11; break; }
    case 11: 
      var $99=$best_len;
      var $100=((($99)-(1))|0);
      var $101=$match;
      var $102=(($101+$100)|0);
      var $103=HEAPU8[($102)];
      var $104=(($103)&255);
      var $105=$scan_end1;
      var $106=(($105)&255);
      var $107=(($104)|0)!=(($106)|0);
      if ($107) { __label__ = 14; break; } else { __label__ = 12; break; }
    case 12: 
      var $109=$match;
      var $110=HEAPU8[($109)];
      var $111=(($110)&255);
      var $112=$scan;
      var $113=HEAPU8[($112)];
      var $114=(($113)&255);
      var $115=(($111)|0)!=(($114)|0);
      if ($115) { __label__ = 14; break; } else { __label__ = 13; break; }
    case 13: 
      var $117=$match;
      var $118=(($117+1)|0);
      $match=$118;
      var $119=HEAPU8[($118)];
      var $120=(($119)&255);
      var $121=$scan;
      var $122=(($121+1)|0);
      var $123=HEAPU8[($122)];
      var $124=(($123)&255);
      var $125=(($120)|0)!=(($124)|0);
      if ($125) { __label__ = 14; break; } else { __label__ = 15; break; }
    case 14: 
      __label__ = 32; break;
    case 15: 
      var $128=$scan;
      var $129=(($128+2)|0);
      $scan=$129;
      var $130=$match;
      var $131=(($130+1)|0);
      $match=$131;
      __label__ = 16; break;
    case 16: 
      __label__ = 17; break;
    case 17: 
      var $134=$scan;
      var $135=(($134+1)|0);
      $scan=$135;
      var $136=HEAPU8[($135)];
      var $137=(($136)&255);
      var $138=$match;
      var $139=(($138+1)|0);
      $match=$139;
      var $140=HEAPU8[($139)];
      var $141=(($140)&255);
      var $142=(($137)|0)==(($141)|0);
      if ($142) { __label__ = 18; break; } else { var $218 = 0;__label__ = 26; break; }
    case 18: 
      var $144=$scan;
      var $145=(($144+1)|0);
      $scan=$145;
      var $146=HEAPU8[($145)];
      var $147=(($146)&255);
      var $148=$match;
      var $149=(($148+1)|0);
      $match=$149;
      var $150=HEAPU8[($149)];
      var $151=(($150)&255);
      var $152=(($147)|0)==(($151)|0);
      if ($152) { __label__ = 19; break; } else { var $218 = 0;__label__ = 26; break; }
    case 19: 
      var $154=$scan;
      var $155=(($154+1)|0);
      $scan=$155;
      var $156=HEAPU8[($155)];
      var $157=(($156)&255);
      var $158=$match;
      var $159=(($158+1)|0);
      $match=$159;
      var $160=HEAPU8[($159)];
      var $161=(($160)&255);
      var $162=(($157)|0)==(($161)|0);
      if ($162) { __label__ = 20; break; } else { var $218 = 0;__label__ = 26; break; }
    case 20: 
      var $164=$scan;
      var $165=(($164+1)|0);
      $scan=$165;
      var $166=HEAPU8[($165)];
      var $167=(($166)&255);
      var $168=$match;
      var $169=(($168+1)|0);
      $match=$169;
      var $170=HEAPU8[($169)];
      var $171=(($170)&255);
      var $172=(($167)|0)==(($171)|0);
      if ($172) { __label__ = 21; break; } else { var $218 = 0;__label__ = 26; break; }
    case 21: 
      var $174=$scan;
      var $175=(($174+1)|0);
      $scan=$175;
      var $176=HEAPU8[($175)];
      var $177=(($176)&255);
      var $178=$match;
      var $179=(($178+1)|0);
      $match=$179;
      var $180=HEAPU8[($179)];
      var $181=(($180)&255);
      var $182=(($177)|0)==(($181)|0);
      if ($182) { __label__ = 22; break; } else { var $218 = 0;__label__ = 26; break; }
    case 22: 
      var $184=$scan;
      var $185=(($184+1)|0);
      $scan=$185;
      var $186=HEAPU8[($185)];
      var $187=(($186)&255);
      var $188=$match;
      var $189=(($188+1)|0);
      $match=$189;
      var $190=HEAPU8[($189)];
      var $191=(($190)&255);
      var $192=(($187)|0)==(($191)|0);
      if ($192) { __label__ = 23; break; } else { var $218 = 0;__label__ = 26; break; }
    case 23: 
      var $194=$scan;
      var $195=(($194+1)|0);
      $scan=$195;
      var $196=HEAPU8[($195)];
      var $197=(($196)&255);
      var $198=$match;
      var $199=(($198+1)|0);
      $match=$199;
      var $200=HEAPU8[($199)];
      var $201=(($200)&255);
      var $202=(($197)|0)==(($201)|0);
      if ($202) { __label__ = 24; break; } else { var $218 = 0;__label__ = 26; break; }
    case 24: 
      var $204=$scan;
      var $205=(($204+1)|0);
      $scan=$205;
      var $206=HEAPU8[($205)];
      var $207=(($206)&255);
      var $208=$match;
      var $209=(($208+1)|0);
      $match=$209;
      var $210=HEAPU8[($209)];
      var $211=(($210)&255);
      var $212=(($207)|0)==(($211)|0);
      if ($212) { __label__ = 25; break; } else { var $218 = 0;__label__ = 26; break; }
    case 25: 
      var $214=$scan;
      var $215=$strend;
      var $216=(($214)>>>0) < (($215)>>>0);
      var $218 = $216;__label__ = 26; break;
    case 26: 
      var $218;
      if ($218) { __label__ = 16; break; } else { __label__ = 27; break; }
    case 27: 
      var $220=$strend;
      var $221=$scan;
      var $222=$220;
      var $223=$221;
      var $224=((($222)-($223))|0);
      var $225=(((258)-($224))|0);
      $len=$225;
      var $226=$strend;
      var $227=((($226)-(258))|0);
      $scan=$227;
      var $228=$len;
      var $229=$best_len;
      var $230=(($228)|0) > (($229)|0);
      if ($230) { __label__ = 28; break; } else { __label__ = 31; break; }
    case 28: 
      var $232=$3;
      var $233=$2;
      var $234=(($233+112)|0);
      HEAP32[(($234)>>2)]=$232;
      var $235=$len;
      $best_len=$235;
      var $236=$len;
      var $237=$nice_match;
      var $238=(($236)|0) >= (($237)|0);
      if ($238) { __label__ = 29; break; } else { __label__ = 30; break; }
    case 29: 
      __label__ = 35; break;
    case 30: 
      var $241=$best_len;
      var $242=((($241)-(1))|0);
      var $243=$scan;
      var $244=(($243+$242)|0);
      var $245=HEAP8[($244)];
      $scan_end1=$245;
      var $246=$best_len;
      var $247=$scan;
      var $248=(($247+$246)|0);
      var $249=HEAP8[($248)];
      $scan_end=$249;
      __label__ = 31; break;
    case 31: 
      __label__ = 32; break;
    case 32: 
      var $252=$3;
      var $253=$wmask;
      var $254=$252 & $253;
      var $255=$prev;
      var $256=(($255+($254<<1))|0);
      var $257=HEAPU16[(($256)>>1)];
      var $258=(($257)&65535);
      $3=$258;
      var $259=$limit;
      var $260=(($258)>>>0) > (($259)>>>0);
      if ($260) { __label__ = 33; break; } else { var $266 = 0;__label__ = 34; break; }
    case 33: 
      var $262=$chain_length;
      var $263=((($262)-(1))|0);
      $chain_length=$263;
      var $264=(($263)|0)!=0;
      var $266 = $264;__label__ = 34; break;
    case 34: 
      var $266;
      if ($266) { __label__ = 10; break; } else { __label__ = 35; break; }
    case 35: 
      var $268=$best_len;
      var $269=$2;
      var $270=(($269+116)|0);
      var $271=HEAPU32[(($270)>>2)];
      var $272=(($268)>>>0) <= (($271)>>>0);
      if ($272) { __label__ = 36; break; } else { __label__ = 37; break; }
    case 36: 
      var $274=$best_len;
      $1=$274;
      __label__ = 38; break;
    case 37: 
      var $276=$2;
      var $277=(($276+116)|0);
      var $278=HEAP32[(($277)>>2)];
      $1=$278;
      __label__ = 38; break;
    case 38: 
      var $280=$1;
      ;
      return $280;
    default: assert(0, "bad label: " + __label__);
  }
}
_longest_match["X"]=1;

function _inflate_fast($strm, $start) {
  var __stackBase__  = STACKTOP; STACKTOP += 4; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $state;
      var $in;
      var $last;
      var $out;
      var $beg;
      var $end;
      var $wsize;
      var $whave;
      var $wnext;
      var $window;
      var $hold;
      var $bits;
      var $lcode;
      var $dcode;
      var $lmask;
      var $dmask;
      var $here=__stackBase__;
      var $op;
      var $len;
      var $dist;
      var $from;
      $1=$strm;
      $2=$start;
      var $3=$1;
      var $4=(($3+28)|0);
      var $5=HEAP32[(($4)>>2)];
      var $6=$5;
      $state=$6;
      var $7=$1;
      var $8=(($7)|0);
      var $9=HEAP32[(($8)>>2)];
      var $10=((($9)-(1))|0);
      $in=$10;
      var $11=$in;
      var $12=$1;
      var $13=(($12+4)|0);
      var $14=HEAP32[(($13)>>2)];
      var $15=((($14)-(5))|0);
      var $16=(($11+$15)|0);
      $last=$16;
      var $17=$1;
      var $18=(($17+12)|0);
      var $19=HEAP32[(($18)>>2)];
      var $20=((($19)-(1))|0);
      $out=$20;
      var $21=$out;
      var $22=$2;
      var $23=$1;
      var $24=(($23+16)|0);
      var $25=HEAP32[(($24)>>2)];
      var $26=((($22)-($25))|0);
      var $27=(((-$26))|0);
      var $28=(($21+$27)|0);
      $beg=$28;
      var $29=$out;
      var $30=$1;
      var $31=(($30+16)|0);
      var $32=HEAP32[(($31)>>2)];
      var $33=((($32)-(257))|0);
      var $34=(($29+$33)|0);
      $end=$34;
      var $35=$state;
      var $36=(($35+40)|0);
      var $37=HEAP32[(($36)>>2)];
      $wsize=$37;
      var $38=$state;
      var $39=(($38+44)|0);
      var $40=HEAP32[(($39)>>2)];
      $whave=$40;
      var $41=$state;
      var $42=(($41+48)|0);
      var $43=HEAP32[(($42)>>2)];
      $wnext=$43;
      var $44=$state;
      var $45=(($44+52)|0);
      var $46=HEAP32[(($45)>>2)];
      $window=$46;
      var $47=$state;
      var $48=(($47+56)|0);
      var $49=HEAP32[(($48)>>2)];
      $hold=$49;
      var $50=$state;
      var $51=(($50+60)|0);
      var $52=HEAP32[(($51)>>2)];
      $bits=$52;
      var $53=$state;
      var $54=(($53+76)|0);
      var $55=HEAP32[(($54)>>2)];
      $lcode=$55;
      var $56=$state;
      var $57=(($56+80)|0);
      var $58=HEAP32[(($57)>>2)];
      $dcode=$58;
      var $59=$state;
      var $60=(($59+84)|0);
      var $61=HEAP32[(($60)>>2)];
      var $62=1 << $61;
      var $63=((($62)-(1))|0);
      $lmask=$63;
      var $64=$state;
      var $65=(($64+88)|0);
      var $66=HEAP32[(($65)>>2)];
      var $67=1 << $66;
      var $68=((($67)-(1))|0);
      $dmask=$68;
      __label__ = 3; break;
    case 3: 
      var $70=$bits;
      var $71=(($70)>>>0) < 15;
      if ($71) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      var $73=$in;
      var $74=(($73+1)|0);
      $in=$74;
      var $75=HEAPU8[($74)];
      var $76=(($75)&255);
      var $77=$bits;
      var $78=$76 << $77;
      var $79=$hold;
      var $80=((($79)+($78))|0);
      $hold=$80;
      var $81=$bits;
      var $82=((($81)+(8))|0);
      $bits=$82;
      var $83=$in;
      var $84=(($83+1)|0);
      $in=$84;
      var $85=HEAPU8[($84)];
      var $86=(($85)&255);
      var $87=$bits;
      var $88=$86 << $87;
      var $89=$hold;
      var $90=((($89)+($88))|0);
      $hold=$90;
      var $91=$bits;
      var $92=((($91)+(8))|0);
      $bits=$92;
      __label__ = 5; break;
    case 5: 
      var $94=$hold;
      var $95=$lmask;
      var $96=$94 & $95;
      var $97=$lcode;
      var $98=(($97+($96<<2))|0);
      var $99=$here;
      var $100=$98;
      assert(4 % 1 === 0, 'memcpy given ' + 4 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP16[(($99)>>1)]=HEAP16[(($100)>>1)];HEAP16[((($99)+(2))>>1)]=HEAP16[((($100)+(2))>>1)];
      __label__ = 6; break;
    case 6: 
      var $102=(($here+1)|0);
      var $103=HEAPU8[($102)];
      var $104=(($103)&255);
      $op=$104;
      var $105=$op;
      var $106=$hold;
      var $107=$106 >>> (($105)>>>0);
      $hold=$107;
      var $108=$op;
      var $109=$bits;
      var $110=((($109)-($108))|0);
      $bits=$110;
      var $111=(($here)|0);
      var $112=HEAPU8[($111)];
      var $113=(($112)&255);
      $op=$113;
      var $114=$op;
      var $115=(($114)|0)==0;
      if ($115) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $117=(($here+2)|0);
      var $118=HEAP16[(($117)>>1)];
      var $119=(($118) & 255);
      var $120=$out;
      var $121=(($120+1)|0);
      $out=$121;
      HEAP8[($121)]=$119;
      __label__ = 79; break;
    case 8: 
      var $123=$op;
      var $124=$123 & 16;
      var $125=(($124)|0)!=0;
      if ($125) { __label__ = 9; break; } else { __label__ = 73; break; }
    case 9: 
      var $127=(($here+2)|0);
      var $128=HEAPU16[(($127)>>1)];
      var $129=(($128)&65535);
      $len=$129;
      var $130=$op;
      var $131=$130 & 15;
      $op=$131;
      var $132=$op;
      var $133=(($132)|0)!=0;
      if ($133) { __label__ = 10; break; } else { __label__ = 13; break; }
    case 10: 
      var $135=$bits;
      var $136=$op;
      var $137=(($135)>>>0) < (($136)>>>0);
      if ($137) { __label__ = 11; break; } else { __label__ = 12; break; }
    case 11: 
      var $139=$in;
      var $140=(($139+1)|0);
      $in=$140;
      var $141=HEAPU8[($140)];
      var $142=(($141)&255);
      var $143=$bits;
      var $144=$142 << $143;
      var $145=$hold;
      var $146=((($145)+($144))|0);
      $hold=$146;
      var $147=$bits;
      var $148=((($147)+(8))|0);
      $bits=$148;
      __label__ = 12; break;
    case 12: 
      var $150=$hold;
      var $151=$op;
      var $152=1 << $151;
      var $153=((($152)-(1))|0);
      var $154=$150 & $153;
      var $155=$len;
      var $156=((($155)+($154))|0);
      $len=$156;
      var $157=$op;
      var $158=$hold;
      var $159=$158 >>> (($157)>>>0);
      $hold=$159;
      var $160=$op;
      var $161=$bits;
      var $162=((($161)-($160))|0);
      $bits=$162;
      __label__ = 13; break;
    case 13: 
      var $164=$bits;
      var $165=(($164)>>>0) < 15;
      if ($165) { __label__ = 14; break; } else { __label__ = 15; break; }
    case 14: 
      var $167=$in;
      var $168=(($167+1)|0);
      $in=$168;
      var $169=HEAPU8[($168)];
      var $170=(($169)&255);
      var $171=$bits;
      var $172=$170 << $171;
      var $173=$hold;
      var $174=((($173)+($172))|0);
      $hold=$174;
      var $175=$bits;
      var $176=((($175)+(8))|0);
      $bits=$176;
      var $177=$in;
      var $178=(($177+1)|0);
      $in=$178;
      var $179=HEAPU8[($178)];
      var $180=(($179)&255);
      var $181=$bits;
      var $182=$180 << $181;
      var $183=$hold;
      var $184=((($183)+($182))|0);
      $hold=$184;
      var $185=$bits;
      var $186=((($185)+(8))|0);
      $bits=$186;
      __label__ = 15; break;
    case 15: 
      var $188=$hold;
      var $189=$dmask;
      var $190=$188 & $189;
      var $191=$dcode;
      var $192=(($191+($190<<2))|0);
      var $193=$here;
      var $194=$192;
      assert(4 % 1 === 0, 'memcpy given ' + 4 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP16[(($193)>>1)]=HEAP16[(($194)>>1)];HEAP16[((($193)+(2))>>1)]=HEAP16[((($194)+(2))>>1)];
      __label__ = 16; break;
    case 16: 
      var $196=(($here+1)|0);
      var $197=HEAPU8[($196)];
      var $198=(($197)&255);
      $op=$198;
      var $199=$op;
      var $200=$hold;
      var $201=$200 >>> (($199)>>>0);
      $hold=$201;
      var $202=$op;
      var $203=$bits;
      var $204=((($203)-($202))|0);
      $bits=$204;
      var $205=(($here)|0);
      var $206=HEAPU8[($205)];
      var $207=(($206)&255);
      $op=$207;
      var $208=$op;
      var $209=$208 & 16;
      var $210=(($209)|0)!=0;
      if ($210) { __label__ = 17; break; } else { __label__ = 69; break; }
    case 17: 
      var $212=(($here+2)|0);
      var $213=HEAPU16[(($212)>>1)];
      var $214=(($213)&65535);
      $dist=$214;
      var $215=$op;
      var $216=$215 & 15;
      $op=$216;
      var $217=$bits;
      var $218=$op;
      var $219=(($217)>>>0) < (($218)>>>0);
      if ($219) { __label__ = 18; break; } else { __label__ = 21; break; }
    case 18: 
      var $221=$in;
      var $222=(($221+1)|0);
      $in=$222;
      var $223=HEAPU8[($222)];
      var $224=(($223)&255);
      var $225=$bits;
      var $226=$224 << $225;
      var $227=$hold;
      var $228=((($227)+($226))|0);
      $hold=$228;
      var $229=$bits;
      var $230=((($229)+(8))|0);
      $bits=$230;
      var $231=$bits;
      var $232=$op;
      var $233=(($231)>>>0) < (($232)>>>0);
      if ($233) { __label__ = 19; break; } else { __label__ = 20; break; }
    case 19: 
      var $235=$in;
      var $236=(($235+1)|0);
      $in=$236;
      var $237=HEAPU8[($236)];
      var $238=(($237)&255);
      var $239=$bits;
      var $240=$238 << $239;
      var $241=$hold;
      var $242=((($241)+($240))|0);
      $hold=$242;
      var $243=$bits;
      var $244=((($243)+(8))|0);
      $bits=$244;
      __label__ = 20; break;
    case 20: 
      __label__ = 21; break;
    case 21: 
      var $247=$hold;
      var $248=$op;
      var $249=1 << $248;
      var $250=((($249)-(1))|0);
      var $251=$247 & $250;
      var $252=$dist;
      var $253=((($252)+($251))|0);
      $dist=$253;
      var $254=$op;
      var $255=$hold;
      var $256=$255 >>> (($254)>>>0);
      $hold=$256;
      var $257=$op;
      var $258=$bits;
      var $259=((($258)-($257))|0);
      $bits=$259;
      var $260=$out;
      var $261=$beg;
      var $262=$260;
      var $263=$261;
      var $264=((($262)-($263))|0);
      $op=$264;
      var $265=$dist;
      var $266=$op;
      var $267=(($265)>>>0) > (($266)>>>0);
      if ($267) { __label__ = 22; break; } else { __label__ = 60; break; }
    case 22: 
      var $269=$dist;
      var $270=$op;
      var $271=((($269)-($270))|0);
      $op=$271;
      var $272=$op;
      var $273=$whave;
      var $274=(($272)>>>0) > (($273)>>>0);
      if ($274) { __label__ = 23; break; } else { __label__ = 26; break; }
    case 23: 
      var $276=$state;
      var $277=(($276+7104)|0);
      var $278=HEAP32[(($277)>>2)];
      var $279=(($278)|0)!=0;
      if ($279) { __label__ = 24; break; } else { __label__ = 25; break; }
    case 24: 
      var $281=$1;
      var $282=(($281+24)|0);
      HEAP32[(($282)>>2)]=((STRING_TABLE.__str29)|0);
      var $283=$state;
      var $284=(($283)|0);
      HEAP32[(($284)>>2)]=29;
      __label__ = 83; break;
    case 25: 
      __label__ = 26; break;
    case 26: 
      var $287=$window;
      var $288=((($287)-(1))|0);
      $from=$288;
      var $289=$wnext;
      var $290=(($289)|0)==0;
      if ($290) { __label__ = 27; break; } else { __label__ = 33; break; }
    case 27: 
      var $292=$wsize;
      var $293=$op;
      var $294=((($292)-($293))|0);
      var $295=$from;
      var $296=(($295+$294)|0);
      $from=$296;
      var $297=$op;
      var $298=$len;
      var $299=(($297)>>>0) < (($298)>>>0);
      if ($299) { __label__ = 28; break; } else { __label__ = 32; break; }
    case 28: 
      var $301=$op;
      var $302=$len;
      var $303=((($302)-($301))|0);
      $len=$303;
      __label__ = 29; break;
    case 29: 
      var $305=$from;
      var $306=(($305+1)|0);
      $from=$306;
      var $307=HEAP8[($306)];
      var $308=$out;
      var $309=(($308+1)|0);
      $out=$309;
      HEAP8[($309)]=$307;
      __label__ = 30; break;
    case 30: 
      var $311=$op;
      var $312=((($311)-(1))|0);
      $op=$312;
      var $313=(($312)|0)!=0;
      if ($313) { __label__ = 29; break; } else { __label__ = 31; break; }
    case 31: 
      var $315=$out;
      var $316=$dist;
      var $317=(((-$316))|0);
      var $318=(($315+$317)|0);
      $from=$318;
      __label__ = 32; break;
    case 32: 
      __label__ = 52; break;
    case 33: 
      var $321=$wnext;
      var $322=$op;
      var $323=(($321)>>>0) < (($322)>>>0);
      if ($323) { __label__ = 34; break; } else { __label__ = 45; break; }
    case 34: 
      var $325=$wsize;
      var $326=$wnext;
      var $327=((($325)+($326))|0);
      var $328=$op;
      var $329=((($327)-($328))|0);
      var $330=$from;
      var $331=(($330+$329)|0);
      $from=$331;
      var $332=$wnext;
      var $333=$op;
      var $334=((($333)-($332))|0);
      $op=$334;
      var $335=$op;
      var $336=$len;
      var $337=(($335)>>>0) < (($336)>>>0);
      if ($337) { __label__ = 35; break; } else { __label__ = 44; break; }
    case 35: 
      var $339=$op;
      var $340=$len;
      var $341=((($340)-($339))|0);
      $len=$341;
      __label__ = 36; break;
    case 36: 
      var $343=$from;
      var $344=(($343+1)|0);
      $from=$344;
      var $345=HEAP8[($344)];
      var $346=$out;
      var $347=(($346+1)|0);
      $out=$347;
      HEAP8[($347)]=$345;
      __label__ = 37; break;
    case 37: 
      var $349=$op;
      var $350=((($349)-(1))|0);
      $op=$350;
      var $351=(($350)|0)!=0;
      if ($351) { __label__ = 36; break; } else { __label__ = 38; break; }
    case 38: 
      var $353=$window;
      var $354=((($353)-(1))|0);
      $from=$354;
      var $355=$wnext;
      var $356=$len;
      var $357=(($355)>>>0) < (($356)>>>0);
      if ($357) { __label__ = 39; break; } else { __label__ = 43; break; }
    case 39: 
      var $359=$wnext;
      $op=$359;
      var $360=$op;
      var $361=$len;
      var $362=((($361)-($360))|0);
      $len=$362;
      __label__ = 40; break;
    case 40: 
      var $364=$from;
      var $365=(($364+1)|0);
      $from=$365;
      var $366=HEAP8[($365)];
      var $367=$out;
      var $368=(($367+1)|0);
      $out=$368;
      HEAP8[($368)]=$366;
      __label__ = 41; break;
    case 41: 
      var $370=$op;
      var $371=((($370)-(1))|0);
      $op=$371;
      var $372=(($371)|0)!=0;
      if ($372) { __label__ = 40; break; } else { __label__ = 42; break; }
    case 42: 
      var $374=$out;
      var $375=$dist;
      var $376=(((-$375))|0);
      var $377=(($374+$376)|0);
      $from=$377;
      __label__ = 43; break;
    case 43: 
      __label__ = 44; break;
    case 44: 
      __label__ = 51; break;
    case 45: 
      var $381=$wnext;
      var $382=$op;
      var $383=((($381)-($382))|0);
      var $384=$from;
      var $385=(($384+$383)|0);
      $from=$385;
      var $386=$op;
      var $387=$len;
      var $388=(($386)>>>0) < (($387)>>>0);
      if ($388) { __label__ = 46; break; } else { __label__ = 50; break; }
    case 46: 
      var $390=$op;
      var $391=$len;
      var $392=((($391)-($390))|0);
      $len=$392;
      __label__ = 47; break;
    case 47: 
      var $394=$from;
      var $395=(($394+1)|0);
      $from=$395;
      var $396=HEAP8[($395)];
      var $397=$out;
      var $398=(($397+1)|0);
      $out=$398;
      HEAP8[($398)]=$396;
      __label__ = 48; break;
    case 48: 
      var $400=$op;
      var $401=((($400)-(1))|0);
      $op=$401;
      var $402=(($401)|0)!=0;
      if ($402) { __label__ = 47; break; } else { __label__ = 49; break; }
    case 49: 
      var $404=$out;
      var $405=$dist;
      var $406=(((-$405))|0);
      var $407=(($404+$406)|0);
      $from=$407;
      __label__ = 50; break;
    case 50: 
      __label__ = 51; break;
    case 51: 
      __label__ = 52; break;
    case 52: 
      __label__ = 53; break;
    case 53: 
      var $412=$len;
      var $413=(($412)>>>0) > 2;
      if ($413) { __label__ = 54; break; } else { __label__ = 55; break; }
    case 54: 
      var $415=$from;
      var $416=(($415+1)|0);
      $from=$416;
      var $417=HEAP8[($416)];
      var $418=$out;
      var $419=(($418+1)|0);
      $out=$419;
      HEAP8[($419)]=$417;
      var $420=$from;
      var $421=(($420+1)|0);
      $from=$421;
      var $422=HEAP8[($421)];
      var $423=$out;
      var $424=(($423+1)|0);
      $out=$424;
      HEAP8[($424)]=$422;
      var $425=$from;
      var $426=(($425+1)|0);
      $from=$426;
      var $427=HEAP8[($426)];
      var $428=$out;
      var $429=(($428+1)|0);
      $out=$429;
      HEAP8[($429)]=$427;
      var $430=$len;
      var $431=((($430)-(3))|0);
      $len=$431;
      __label__ = 53; break;
    case 55: 
      var $433=$len;
      var $434=(($433)|0)!=0;
      if ($434) { __label__ = 56; break; } else { __label__ = 59; break; }
    case 56: 
      var $436=$from;
      var $437=(($436+1)|0);
      $from=$437;
      var $438=HEAP8[($437)];
      var $439=$out;
      var $440=(($439+1)|0);
      $out=$440;
      HEAP8[($440)]=$438;
      var $441=$len;
      var $442=(($441)>>>0) > 1;
      if ($442) { __label__ = 57; break; } else { __label__ = 58; break; }
    case 57: 
      var $444=$from;
      var $445=(($444+1)|0);
      $from=$445;
      var $446=HEAP8[($445)];
      var $447=$out;
      var $448=(($447+1)|0);
      $out=$448;
      HEAP8[($448)]=$446;
      __label__ = 58; break;
    case 58: 
      __label__ = 59; break;
    case 59: 
      __label__ = 68; break;
    case 60: 
      var $452=$out;
      var $453=$dist;
      var $454=(((-$453))|0);
      var $455=(($452+$454)|0);
      $from=$455;
      __label__ = 61; break;
    case 61: 
      var $457=$from;
      var $458=(($457+1)|0);
      $from=$458;
      var $459=HEAP8[($458)];
      var $460=$out;
      var $461=(($460+1)|0);
      $out=$461;
      HEAP8[($461)]=$459;
      var $462=$from;
      var $463=(($462+1)|0);
      $from=$463;
      var $464=HEAP8[($463)];
      var $465=$out;
      var $466=(($465+1)|0);
      $out=$466;
      HEAP8[($466)]=$464;
      var $467=$from;
      var $468=(($467+1)|0);
      $from=$468;
      var $469=HEAP8[($468)];
      var $470=$out;
      var $471=(($470+1)|0);
      $out=$471;
      HEAP8[($471)]=$469;
      var $472=$len;
      var $473=((($472)-(3))|0);
      $len=$473;
      __label__ = 62; break;
    case 62: 
      var $475=$len;
      var $476=(($475)>>>0) > 2;
      if ($476) { __label__ = 61; break; } else { __label__ = 63; break; }
    case 63: 
      var $478=$len;
      var $479=(($478)|0)!=0;
      if ($479) { __label__ = 64; break; } else { __label__ = 67; break; }
    case 64: 
      var $481=$from;
      var $482=(($481+1)|0);
      $from=$482;
      var $483=HEAP8[($482)];
      var $484=$out;
      var $485=(($484+1)|0);
      $out=$485;
      HEAP8[($485)]=$483;
      var $486=$len;
      var $487=(($486)>>>0) > 1;
      if ($487) { __label__ = 65; break; } else { __label__ = 66; break; }
    case 65: 
      var $489=$from;
      var $490=(($489+1)|0);
      $from=$490;
      var $491=HEAP8[($490)];
      var $492=$out;
      var $493=(($492+1)|0);
      $out=$493;
      HEAP8[($493)]=$491;
      __label__ = 66; break;
    case 66: 
      __label__ = 67; break;
    case 67: 
      __label__ = 68; break;
    case 68: 
      __label__ = 72; break;
    case 69: 
      var $498=$op;
      var $499=$498 & 64;
      var $500=(($499)|0)==0;
      if ($500) { __label__ = 70; break; } else { __label__ = 71; break; }
    case 70: 
      var $502=(($here+2)|0);
      var $503=HEAPU16[(($502)>>1)];
      var $504=(($503)&65535);
      var $505=$hold;
      var $506=$op;
      var $507=1 << $506;
      var $508=((($507)-(1))|0);
      var $509=$505 & $508;
      var $510=((($504)+($509))|0);
      var $511=$dcode;
      var $512=(($511+($510<<2))|0);
      var $513=$here;
      var $514=$512;
      assert(4 % 1 === 0, 'memcpy given ' + 4 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP16[(($513)>>1)]=HEAP16[(($514)>>1)];HEAP16[((($513)+(2))>>1)]=HEAP16[((($514)+(2))>>1)];
      __label__ = 16; break;
    case 71: 
      var $516=$1;
      var $517=(($516+24)|0);
      HEAP32[(($517)>>2)]=((STRING_TABLE.__str130)|0);
      var $518=$state;
      var $519=(($518)|0);
      HEAP32[(($519)>>2)]=29;
      __label__ = 83; break;
    case 72: 
      __label__ = 78; break;
    case 73: 
      var $522=$op;
      var $523=$522 & 64;
      var $524=(($523)|0)==0;
      if ($524) { __label__ = 74; break; } else { __label__ = 75; break; }
    case 74: 
      var $526=(($here+2)|0);
      var $527=HEAPU16[(($526)>>1)];
      var $528=(($527)&65535);
      var $529=$hold;
      var $530=$op;
      var $531=1 << $530;
      var $532=((($531)-(1))|0);
      var $533=$529 & $532;
      var $534=((($528)+($533))|0);
      var $535=$lcode;
      var $536=(($535+($534<<2))|0);
      var $537=$here;
      var $538=$536;
      assert(4 % 1 === 0, 'memcpy given ' + 4 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP16[(($537)>>1)]=HEAP16[(($538)>>1)];HEAP16[((($537)+(2))>>1)]=HEAP16[((($538)+(2))>>1)];
      __label__ = 6; break;
    case 75: 
      var $540=$op;
      var $541=$540 & 32;
      var $542=(($541)|0)!=0;
      if ($542) { __label__ = 76; break; } else { __label__ = 77; break; }
    case 76: 
      var $544=$state;
      var $545=(($544)|0);
      HEAP32[(($545)>>2)]=11;
      __label__ = 83; break;
    case 77: 
      var $547=$1;
      var $548=(($547+24)|0);
      HEAP32[(($548)>>2)]=((STRING_TABLE.__str231)|0);
      var $549=$state;
      var $550=(($549)|0);
      HEAP32[(($550)>>2)]=29;
      __label__ = 83; break;
    case 78: 
      __label__ = 79; break;
    case 79: 
      __label__ = 80; break;
    case 80: 
      var $554=$in;
      var $555=$last;
      var $556=(($554)>>>0) < (($555)>>>0);
      if ($556) { __label__ = 81; break; } else { var $562 = 0;__label__ = 82; break; }
    case 81: 
      var $558=$out;
      var $559=$end;
      var $560=(($558)>>>0) < (($559)>>>0);
      var $562 = $560;__label__ = 82; break;
    case 82: 
      var $562;
      if ($562) { __label__ = 3; break; } else { __label__ = 83; break; }
    case 83: 
      var $564=$bits;
      var $565=$564 >>> 3;
      $len=$565;
      var $566=$len;
      var $567=$in;
      var $568=(((-$566))|0);
      var $569=(($567+$568)|0);
      $in=$569;
      var $570=$len;
      var $571=$570 << 3;
      var $572=$bits;
      var $573=((($572)-($571))|0);
      $bits=$573;
      var $574=$bits;
      var $575=1 << $574;
      var $576=((($575)-(1))|0);
      var $577=$hold;
      var $578=$577 & $576;
      $hold=$578;
      var $579=$in;
      var $580=(($579+1)|0);
      var $581=$1;
      var $582=(($581)|0);
      HEAP32[(($582)>>2)]=$580;
      var $583=$out;
      var $584=(($583+1)|0);
      var $585=$1;
      var $586=(($585+12)|0);
      HEAP32[(($586)>>2)]=$584;
      var $587=$in;
      var $588=$last;
      var $589=(($587)>>>0) < (($588)>>>0);
      if ($589) { __label__ = 84; break; } else { __label__ = 85; break; }
    case 84: 
      var $591=$last;
      var $592=$in;
      var $593=$591;
      var $594=$592;
      var $595=((($593)-($594))|0);
      var $596=((($595)+(5))|0);
      var $605 = $596;__label__ = 86; break;
    case 85: 
      var $598=$in;
      var $599=$last;
      var $600=$598;
      var $601=$599;
      var $602=((($600)-($601))|0);
      var $603=(((5)-($602))|0);
      var $605 = $603;__label__ = 86; break;
    case 86: 
      var $605;
      var $606=$1;
      var $607=(($606+4)|0);
      HEAP32[(($607)>>2)]=$605;
      var $608=$out;
      var $609=$end;
      var $610=(($608)>>>0) < (($609)>>>0);
      if ($610) { __label__ = 87; break; } else { __label__ = 88; break; }
    case 87: 
      var $612=$end;
      var $613=$out;
      var $614=$612;
      var $615=$613;
      var $616=((($614)-($615))|0);
      var $617=((($616)+(257))|0);
      var $626 = $617;__label__ = 89; break;
    case 88: 
      var $619=$out;
      var $620=$end;
      var $621=$619;
      var $622=$620;
      var $623=((($621)-($622))|0);
      var $624=(((257)-($623))|0);
      var $626 = $624;__label__ = 89; break;
    case 89: 
      var $626;
      var $627=$1;
      var $628=(($627+16)|0);
      HEAP32[(($628)>>2)]=$626;
      var $629=$hold;
      var $630=$state;
      var $631=(($630+56)|0);
      HEAP32[(($631)>>2)]=$629;
      var $632=$bits;
      var $633=$state;
      var $634=(($633+60)|0);
      HEAP32[(($634)>>2)]=$632;
      STACKTOP = __stackBase__;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_inflate_fast["X"]=1;

function _inflateResetKeep($strm) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $state;
      $2=$strm;
      var $3=$2;
      var $4=(($3)|0)==0;
      if ($4) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      var $6=$2;
      var $7=(($6+28)|0);
      var $8=HEAP32[(($7)>>2)];
      var $9=(($8)|0)==0;
      if ($9) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      $1=-2;
      __label__ = 8; break;
    case 5: 
      var $12=$2;
      var $13=(($12+28)|0);
      var $14=HEAP32[(($13)>>2)];
      var $15=$14;
      $state=$15;
      var $16=$state;
      var $17=(($16+28)|0);
      HEAP32[(($17)>>2)]=0;
      var $18=$2;
      var $19=(($18+20)|0);
      HEAP32[(($19)>>2)]=0;
      var $20=$2;
      var $21=(($20+8)|0);
      HEAP32[(($21)>>2)]=0;
      var $22=$2;
      var $23=(($22+24)|0);
      HEAP32[(($23)>>2)]=0;
      var $24=$state;
      var $25=(($24+8)|0);
      var $26=HEAP32[(($25)>>2)];
      var $27=(($26)|0)!=0;
      if ($27) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      var $29=$state;
      var $30=(($29+8)|0);
      var $31=HEAP32[(($30)>>2)];
      var $32=$31 & 1;
      var $33=$2;
      var $34=(($33+48)|0);
      HEAP32[(($34)>>2)]=$32;
      __label__ = 7; break;
    case 7: 
      var $36=$state;
      var $37=(($36)|0);
      HEAP32[(($37)>>2)]=0;
      var $38=$state;
      var $39=(($38+4)|0);
      HEAP32[(($39)>>2)]=0;
      var $40=$state;
      var $41=(($40+12)|0);
      HEAP32[(($41)>>2)]=0;
      var $42=$state;
      var $43=(($42+20)|0);
      HEAP32[(($43)>>2)]=32768;
      var $44=$state;
      var $45=(($44+32)|0);
      HEAP32[(($45)>>2)]=0;
      var $46=$state;
      var $47=(($46+56)|0);
      HEAP32[(($47)>>2)]=0;
      var $48=$state;
      var $49=(($48+60)|0);
      HEAP32[(($49)>>2)]=0;
      var $50=$state;
      var $51=(($50+1328)|0);
      var $52=(($51)|0);
      var $53=$state;
      var $54=(($53+108)|0);
      HEAP32[(($54)>>2)]=$52;
      var $55=$state;
      var $56=(($55+80)|0);
      HEAP32[(($56)>>2)]=$52;
      var $57=$state;
      var $58=(($57+76)|0);
      HEAP32[(($58)>>2)]=$52;
      var $59=$state;
      var $60=(($59+7104)|0);
      HEAP32[(($60)>>2)]=1;
      var $61=$state;
      var $62=(($61+7108)|0);
      HEAP32[(($62)>>2)]=-1;
      $1=0;
      __label__ = 8; break;
    case 8: 
      var $64=$1;
      ;
      return $64;
    default: assert(0, "bad label: " + __label__);
  }
}
_inflateResetKeep["X"]=1;

function _inflateReset($strm) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $state;
      $2=$strm;
      var $3=$2;
      var $4=(($3)|0)==0;
      if ($4) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      var $6=$2;
      var $7=(($6+28)|0);
      var $8=HEAP32[(($7)>>2)];
      var $9=(($8)|0)==0;
      if ($9) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      $1=-2;
      __label__ = 6; break;
    case 5: 
      var $12=$2;
      var $13=(($12+28)|0);
      var $14=HEAP32[(($13)>>2)];
      var $15=$14;
      $state=$15;
      var $16=$state;
      var $17=(($16+40)|0);
      HEAP32[(($17)>>2)]=0;
      var $18=$state;
      var $19=(($18+44)|0);
      HEAP32[(($19)>>2)]=0;
      var $20=$state;
      var $21=(($20+48)|0);
      HEAP32[(($21)>>2)]=0;
      var $22=$2;
      var $23=_inflateResetKeep($22);
      $1=$23;
      __label__ = 6; break;
    case 6: 
      var $25=$1;
      ;
      return $25;
    default: assert(0, "bad label: " + __label__);
  }
}


function _inflateReset2($strm, $windowBits) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $wrap;
      var $state;
      $2=$strm;
      $3=$windowBits;
      var $4=$2;
      var $5=(($4)|0)==0;
      if ($5) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      var $7=$2;
      var $8=(($7+28)|0);
      var $9=HEAP32[(($8)>>2)];
      var $10=(($9)|0)==0;
      if ($10) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      $1=-2;
      __label__ = 18; break;
    case 5: 
      var $13=$2;
      var $14=(($13+28)|0);
      var $15=HEAP32[(($14)>>2)];
      var $16=$15;
      $state=$16;
      var $17=$3;
      var $18=(($17)|0) < 0;
      if ($18) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      $wrap=0;
      var $20=$3;
      var $21=(((-$20))|0);
      $3=$21;
      __label__ = 10; break;
    case 7: 
      var $23=$3;
      var $24=$23 >> 4;
      var $25=((($24)+(1))|0);
      $wrap=$25;
      var $26=$3;
      var $27=(($26)|0) < 48;
      if ($27) { __label__ = 8; break; } else { __label__ = 9; break; }
    case 8: 
      var $29=$3;
      var $30=$29 & 15;
      $3=$30;
      __label__ = 9; break;
    case 9: 
      __label__ = 10; break;
    case 10: 
      var $33=$3;
      var $34=(($33)|0)!=0;
      if ($34) { __label__ = 11; break; } else { __label__ = 14; break; }
    case 11: 
      var $36=$3;
      var $37=(($36)|0) < 8;
      if ($37) { __label__ = 13; break; } else { __label__ = 12; break; }
    case 12: 
      var $39=$3;
      var $40=(($39)|0) > 15;
      if ($40) { __label__ = 13; break; } else { __label__ = 14; break; }
    case 13: 
      $1=-2;
      __label__ = 18; break;
    case 14: 
      var $43=$state;
      var $44=(($43+52)|0);
      var $45=HEAP32[(($44)>>2)];
      var $46=(($45)|0)!=0;
      if ($46) { __label__ = 15; break; } else { __label__ = 17; break; }
    case 15: 
      var $48=$state;
      var $49=(($48+36)|0);
      var $50=HEAP32[(($49)>>2)];
      var $51=$3;
      var $52=(($50)|0)!=(($51)|0);
      if ($52) { __label__ = 16; break; } else { __label__ = 17; break; }
    case 16: 
      var $54=$2;
      var $55=(($54+36)|0);
      var $56=HEAP32[(($55)>>2)];
      var $57=$2;
      var $58=(($57+40)|0);
      var $59=HEAP32[(($58)>>2)];
      var $60=$state;
      var $61=(($60+52)|0);
      var $62=HEAP32[(($61)>>2)];
      FUNCTION_TABLE[$56]($59, $62);
      var $63=$state;
      var $64=(($63+52)|0);
      HEAP32[(($64)>>2)]=0;
      __label__ = 17; break;
    case 17: 
      var $66=$wrap;
      var $67=$state;
      var $68=(($67+8)|0);
      HEAP32[(($68)>>2)]=$66;
      var $69=$3;
      var $70=$state;
      var $71=(($70+36)|0);
      HEAP32[(($71)>>2)]=$69;
      var $72=$2;
      var $73=_inflateReset($72);
      $1=$73;
      __label__ = 18; break;
    case 18: 
      var $75=$1;
      ;
      return $75;
    default: assert(0, "bad label: " + __label__);
  }
}
_inflateReset2["X"]=1;

function _inflateInit2_($strm, $windowBits, $version, $stream_size) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $5;
      var $ret;
      var $state;
      $2=$strm;
      $3=$windowBits;
      $4=$version;
      $5=$stream_size;
      var $6=$4;
      var $7=(($6)|0)==0;
      if ($7) { __label__ = 5; break; } else { __label__ = 3; break; }
    case 3: 
      var $9=$4;
      var $10=(($9)|0);
      var $11=HEAP8[($10)];
      var $12=(($11 << 24) >> 24);
      var $13=HEAP8[(((STRING_TABLE.__str34)|0))];
      var $14=(($13 << 24) >> 24);
      var $15=(($12)|0)!=(($14)|0);
      if ($15) { __label__ = 5; break; } else { __label__ = 4; break; }
    case 4: 
      var $17=$5;
      var $18=(($17)|0)!=56;
      if ($18) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      $1=-6;
      __label__ = 17; break;
    case 6: 
      var $21=$2;
      var $22=(($21)|0)==0;
      if ($22) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      $1=-2;
      __label__ = 17; break;
    case 8: 
      var $25=$2;
      var $26=(($25+24)|0);
      HEAP32[(($26)>>2)]=0;
      var $27=$2;
      var $28=(($27+32)|0);
      var $29=HEAP32[(($28)>>2)];
      var $30=(($29)|0)==0;
      if ($30) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      var $32=$2;
      var $33=(($32+32)|0);
      HEAP32[(($33)>>2)]=2;
      var $34=$2;
      var $35=(($34+40)|0);
      HEAP32[(($35)>>2)]=0;
      __label__ = 10; break;
    case 10: 
      var $37=$2;
      var $38=(($37+36)|0);
      var $39=HEAP32[(($38)>>2)];
      var $40=(($39)|0)==0;
      if ($40) { __label__ = 11; break; } else { __label__ = 12; break; }
    case 11: 
      var $42=$2;
      var $43=(($42+36)|0);
      HEAP32[(($43)>>2)]=4;
      __label__ = 12; break;
    case 12: 
      var $45=$2;
      var $46=(($45+32)|0);
      var $47=HEAP32[(($46)>>2)];
      var $48=$2;
      var $49=(($48+40)|0);
      var $50=HEAP32[(($49)>>2)];
      var $51=FUNCTION_TABLE[$47]($50, 1, 7116);
      var $52=$51;
      $state=$52;
      var $53=$state;
      var $54=(($53)|0)==0;
      if ($54) { __label__ = 13; break; } else { __label__ = 14; break; }
    case 13: 
      $1=-4;
      __label__ = 17; break;
    case 14: 
      var $57=$state;
      var $58=$57;
      var $59=$2;
      var $60=(($59+28)|0);
      HEAP32[(($60)>>2)]=$58;
      var $61=$state;
      var $62=(($61+52)|0);
      HEAP32[(($62)>>2)]=0;
      var $63=$2;
      var $64=$3;
      var $65=_inflateReset2($63, $64);
      $ret=$65;
      var $66=$ret;
      var $67=(($66)|0)!=0;
      if ($67) { __label__ = 15; break; } else { __label__ = 16; break; }
    case 15: 
      var $69=$2;
      var $70=(($69+36)|0);
      var $71=HEAP32[(($70)>>2)];
      var $72=$2;
      var $73=(($72+40)|0);
      var $74=HEAP32[(($73)>>2)];
      var $75=$state;
      var $76=$75;
      FUNCTION_TABLE[$71]($74, $76);
      var $77=$2;
      var $78=(($77+28)|0);
      HEAP32[(($78)>>2)]=0;
      __label__ = 16; break;
    case 16: 
      var $80=$ret;
      $1=$80;
      __label__ = 17; break;
    case 17: 
      var $82=$1;
      ;
      return $82;
    default: assert(0, "bad label: " + __label__);
  }
}
_inflateInit2_["X"]=1;

function _inflateInit_($strm, $version, $stream_size) {
  ;
  var __label__;

  var $1;
  var $2;
  var $3;
  $1=$strm;
  $2=$version;
  $3=$stream_size;
  var $4=$1;
  var $5=$2;
  var $6=$3;
  var $7=_inflateInit2_($4, 15, $5, $6);
  ;
  return $7;
}


function _inflate($strm, $flush) {
  var __stackBase__  = STACKTOP; STACKTOP += 12; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $state;
      var $next;
      var $put;
      var $have;
      var $left;
      var $hold;
      var $bits;
      var $in;
      var $out;
      var $copy;
      var $from;
      var $here=__stackBase__;
      var $last=(__stackBase__)+(4);
      var $len;
      var $ret;
      var $hbuf=(__stackBase__)+(8);
      $2=$strm;
      $3=$flush;
      var $4=$2;
      var $5=(($4)|0)==0;
      if ($5) { __label__ = 7; break; } else { __label__ = 3; break; }
    case 3: 
      var $7=$2;
      var $8=(($7+28)|0);
      var $9=HEAP32[(($8)>>2)];
      var $10=(($9)|0)==0;
      if ($10) { __label__ = 7; break; } else { __label__ = 4; break; }
    case 4: 
      var $12=$2;
      var $13=(($12+12)|0);
      var $14=HEAP32[(($13)>>2)];
      var $15=(($14)|0)==0;
      if ($15) { __label__ = 7; break; } else { __label__ = 5; break; }
    case 5: 
      var $17=$2;
      var $18=(($17)|0);
      var $19=HEAP32[(($18)>>2)];
      var $20=(($19)|0)==0;
      if ($20) { __label__ = 6; break; } else { __label__ = 8; break; }
    case 6: 
      var $22=$2;
      var $23=(($22+4)|0);
      var $24=HEAP32[(($23)>>2)];
      var $25=(($24)|0)!=0;
      if ($25) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      $1=-2;
      __label__ = 590; break;
    case 8: 
      var $28=$2;
      var $29=(($28+28)|0);
      var $30=HEAP32[(($29)>>2)];
      var $31=$30;
      $state=$31;
      var $32=$state;
      var $33=(($32)|0);
      var $34=HEAP32[(($33)>>2)];
      var $35=(($34)|0)==11;
      if ($35) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      var $37=$state;
      var $38=(($37)|0);
      HEAP32[(($38)>>2)]=12;
      __label__ = 10; break;
    case 10: 
      __label__ = 11; break;
    case 11: 
      var $41=$2;
      var $42=(($41+12)|0);
      var $43=HEAP32[(($42)>>2)];
      $put=$43;
      var $44=$2;
      var $45=(($44+16)|0);
      var $46=HEAP32[(($45)>>2)];
      $left=$46;
      var $47=$2;
      var $48=(($47)|0);
      var $49=HEAP32[(($48)>>2)];
      $next=$49;
      var $50=$2;
      var $51=(($50+4)|0);
      var $52=HEAP32[(($51)>>2)];
      $have=$52;
      var $53=$state;
      var $54=(($53+56)|0);
      var $55=HEAP32[(($54)>>2)];
      $hold=$55;
      var $56=$state;
      var $57=(($56+60)|0);
      var $58=HEAP32[(($57)>>2)];
      $bits=$58;
      __label__ = 12; break;
    case 12: 
      var $60=$have;
      $in=$60;
      var $61=$left;
      $out=$61;
      $ret=0;
      __label__ = 13; break;
    case 13: 
      var $63=$state;
      var $64=(($63)|0);
      var $65=HEAP32[(($64)>>2)];
      if ((($65)|0) == 0) {
        __label__ = 14; break;
      }
      else if ((($65)|0) == 1) {
        __label__ = 49; break;
      }
      else if ((($65)|0) == 2) {
        __label__ = 71; break;
      }
      else if ((($65)|0) == 3) {
        __label__ = 89; break;
      }
      else if ((($65)|0) == 4) {
        __label__ = 107; break;
      }
      else if ((($65)|0) == 5) {
        __label__ = 130; break;
      }
      else if ((($65)|0) == 6) {
        __label__ = 147; break;
      }
      else if ((($65)|0) == 7) {
        __label__ = 168; break;
      }
      else if ((($65)|0) == 8) {
        __label__ = 189; break;
      }
      else if ((($65)|0) == 9) {
        __label__ = 207; break;
      }
      else if ((($65)|0) == 10) {
        __label__ = 219; break;
      }
      else if ((($65)|0) == 11) {
        __label__ = 224; break;
      }
      else if ((($65)|0) == 12) {
        __label__ = 228; break;
      }
      else if ((($65)|0) == 13) {
        __label__ = 255; break;
      }
      else if ((($65)|0) == 14) {
        __label__ = 273; break;
      }
      else if ((($65)|0) == 15) {
        __label__ = 274; break;
      }
      else if ((($65)|0) == 16) {
        __label__ = 283; break;
      }
      else if ((($65)|0) == 17) {
        __label__ = 302; break;
      }
      else if ((($65)|0) == 18) {
        __label__ = 322; break;
      }
      else if ((($65)|0) == 19) {
        __label__ = 401; break;
      }
      else if ((($65)|0) == 20) {
        __label__ = 402; break;
      }
      else if ((($65)|0) == 21) {
        __label__ = 441; break;
      }
      else if ((($65)|0) == 22) {
        __label__ = 455; break;
      }
      else if ((($65)|0) == 23) {
        __label__ = 480; break;
      }
      else if ((($65)|0) == 24) {
        __label__ = 494; break;
      }
      else if ((($65)|0) == 25) {
        __label__ = 516; break;
      }
      else if ((($65)|0) == 26) {
        __label__ = 519; break;
      }
      else if ((($65)|0) == 27) {
        __label__ = 543; break;
      }
      else if ((($65)|0) == 28) {
        __label__ = 560; break;
      }
      else if ((($65)|0) == 29) {
        __label__ = 561; break;
      }
      else if ((($65)|0) == 30) {
        __label__ = 562; break;
      }
      else if ((($65)|0) == 31) {
        __label__ = 563; break;
      }
      else {
      __label__ = 564; break;
      }
      
    case 14: 
      var $67=$state;
      var $68=(($67+8)|0);
      var $69=HEAP32[(($68)>>2)];
      var $70=(($69)|0)==0;
      if ($70) { __label__ = 15; break; } else { __label__ = 16; break; }
    case 15: 
      var $72=$state;
      var $73=(($72)|0);
      HEAP32[(($73)>>2)]=12;
      __label__ = 565; break;
    case 16: 
      __label__ = 17; break;
    case 17: 
      __label__ = 18; break;
    case 18: 
      var $77=$bits;
      var $78=(($77)>>>0) < 16;
      if ($78) { __label__ = 19; break; } else { __label__ = 24; break; }
    case 19: 
      __label__ = 20; break;
    case 20: 
      var $81=$have;
      var $82=(($81)|0)==0;
      if ($82) { __label__ = 21; break; } else { __label__ = 22; break; }
    case 21: 
      __label__ = 566; break;
    case 22: 
      var $85=$have;
      var $86=((($85)-(1))|0);
      $have=$86;
      var $87=$next;
      var $88=(($87+1)|0);
      $next=$88;
      var $89=HEAPU8[($87)];
      var $90=(($89)&255);
      var $91=$bits;
      var $92=$90 << $91;
      var $93=$hold;
      var $94=((($93)+($92))|0);
      $hold=$94;
      var $95=$bits;
      var $96=((($95)+(8))|0);
      $bits=$96;
      __label__ = 23; break;
    case 23: 
      __label__ = 18; break;
    case 24: 
      __label__ = 25; break;
    case 25: 
      var $100=$state;
      var $101=(($100+8)|0);
      var $102=HEAP32[(($101)>>2)];
      var $103=$102 & 2;
      var $104=(($103)|0)!=0;
      if ($104) { __label__ = 26; break; } else { __label__ = 32; break; }
    case 26: 
      var $106=$hold;
      var $107=(($106)|0)==35615;
      if ($107) { __label__ = 27; break; } else { __label__ = 32; break; }
    case 27: 
      var $109=_crc32(0, 0, 0);
      var $110=$state;
      var $111=(($110+24)|0);
      HEAP32[(($111)>>2)]=$109;
      __label__ = 28; break;
    case 28: 
      var $113=$hold;
      var $114=(($113) & 255);
      var $115=(($hbuf)|0);
      HEAP8[($115)]=$114;
      var $116=$hold;
      var $117=$116 >>> 8;
      var $118=(($117) & 255);
      var $119=(($hbuf+1)|0);
      HEAP8[($119)]=$118;
      var $120=$state;
      var $121=(($120+24)|0);
      var $122=HEAP32[(($121)>>2)];
      var $123=(($hbuf)|0);
      var $124=_crc32($122, $123, 2);
      var $125=$state;
      var $126=(($125+24)|0);
      HEAP32[(($126)>>2)]=$124;
      __label__ = 29; break;
    case 29: 
      __label__ = 30; break;
    case 30: 
      $hold=0;
      $bits=0;
      __label__ = 31; break;
    case 31: 
      var $130=$state;
      var $131=(($130)|0);
      HEAP32[(($131)>>2)]=1;
      __label__ = 565; break;
    case 32: 
      var $133=$state;
      var $134=(($133+16)|0);
      HEAP32[(($134)>>2)]=0;
      var $135=$state;
      var $136=(($135+32)|0);
      var $137=HEAP32[(($136)>>2)];
      var $138=(($137)|0)!=0;
      if ($138) { __label__ = 33; break; } else { __label__ = 34; break; }
    case 33: 
      var $140=$state;
      var $141=(($140+32)|0);
      var $142=HEAP32[(($141)>>2)];
      var $143=(($142+48)|0);
      HEAP32[(($143)>>2)]=-1;
      __label__ = 34; break;
    case 34: 
      var $145=$state;
      var $146=(($145+8)|0);
      var $147=HEAP32[(($146)>>2)];
      var $148=$147 & 1;
      var $149=(($148)|0)!=0;
      if ($149) { __label__ = 35; break; } else { __label__ = 36; break; }
    case 35: 
      var $151=$hold;
      var $152=$151 & 255;
      var $153=$152 << 8;
      var $154=$hold;
      var $155=$154 >>> 8;
      var $156=((($153)+($155))|0);
      var $157=((($156)>>>0))%(31);
      var $158=(($157)|0)!=0;
      if ($158) { __label__ = 36; break; } else { __label__ = 37; break; }
    case 36: 
      var $160=$2;
      var $161=(($160+24)|0);
      HEAP32[(($161)>>2)]=((STRING_TABLE.__str135)|0);
      var $162=$state;
      var $163=(($162)|0);
      HEAP32[(($163)>>2)]=29;
      __label__ = 565; break;
    case 37: 
      var $165=$hold;
      var $166=$165 & 15;
      var $167=(($166)|0)!=8;
      if ($167) { __label__ = 38; break; } else { __label__ = 39; break; }
    case 38: 
      var $169=$2;
      var $170=(($169+24)|0);
      HEAP32[(($170)>>2)]=((STRING_TABLE.__str236)|0);
      var $171=$state;
      var $172=(($171)|0);
      HEAP32[(($172)>>2)]=29;
      __label__ = 565; break;
    case 39: 
      __label__ = 40; break;
    case 40: 
      var $175=$hold;
      var $176=$175 >>> 4;
      $hold=$176;
      var $177=$bits;
      var $178=((($177)-(4))|0);
      $bits=$178;
      __label__ = 41; break;
    case 41: 
      var $180=$hold;
      var $181=$180 & 15;
      var $182=((($181)+(8))|0);
      $len=$182;
      var $183=$state;
      var $184=(($183+36)|0);
      var $185=HEAP32[(($184)>>2)];
      var $186=(($185)|0)==0;
      if ($186) { __label__ = 42; break; } else { __label__ = 43; break; }
    case 42: 
      var $188=$len;
      var $189=$state;
      var $190=(($189+36)|0);
      HEAP32[(($190)>>2)]=$188;
      __label__ = 46; break;
    case 43: 
      var $192=$len;
      var $193=$state;
      var $194=(($193+36)|0);
      var $195=HEAPU32[(($194)>>2)];
      var $196=(($192)>>>0) > (($195)>>>0);
      if ($196) { __label__ = 44; break; } else { __label__ = 45; break; }
    case 44: 
      var $198=$2;
      var $199=(($198+24)|0);
      HEAP32[(($199)>>2)]=((STRING_TABLE.__str337)|0);
      var $200=$state;
      var $201=(($200)|0);
      HEAP32[(($201)>>2)]=29;
      __label__ = 565; break;
    case 45: 
      __label__ = 46; break;
    case 46: 
      var $204=$len;
      var $205=1 << $204;
      var $206=$state;
      var $207=(($206+20)|0);
      HEAP32[(($207)>>2)]=$205;
      var $208=_adler32(0, 0, 0);
      var $209=$state;
      var $210=(($209+24)|0);
      HEAP32[(($210)>>2)]=$208;
      var $211=$2;
      var $212=(($211+48)|0);
      HEAP32[(($212)>>2)]=$208;
      var $213=$hold;
      var $214=$213 & 512;
      var $215=(($214)|0)!=0;
      var $216=$215 ? 9 : 11;
      var $217=$state;
      var $218=(($217)|0);
      HEAP32[(($218)>>2)]=$216;
      __label__ = 47; break;
    case 47: 
      $hold=0;
      $bits=0;
      __label__ = 48; break;
    case 48: 
      __label__ = 565; break;
    case 49: 
      __label__ = 50; break;
    case 50: 
      __label__ = 51; break;
    case 51: 
      var $224=$bits;
      var $225=(($224)>>>0) < 16;
      if ($225) { __label__ = 52; break; } else { __label__ = 57; break; }
    case 52: 
      __label__ = 53; break;
    case 53: 
      var $228=$have;
      var $229=(($228)|0)==0;
      if ($229) { __label__ = 54; break; } else { __label__ = 55; break; }
    case 54: 
      __label__ = 566; break;
    case 55: 
      var $232=$have;
      var $233=((($232)-(1))|0);
      $have=$233;
      var $234=$next;
      var $235=(($234+1)|0);
      $next=$235;
      var $236=HEAPU8[($234)];
      var $237=(($236)&255);
      var $238=$bits;
      var $239=$237 << $238;
      var $240=$hold;
      var $241=((($240)+($239))|0);
      $hold=$241;
      var $242=$bits;
      var $243=((($242)+(8))|0);
      $bits=$243;
      __label__ = 56; break;
    case 56: 
      __label__ = 51; break;
    case 57: 
      __label__ = 58; break;
    case 58: 
      var $247=$hold;
      var $248=$state;
      var $249=(($248+16)|0);
      HEAP32[(($249)>>2)]=$247;
      var $250=$state;
      var $251=(($250+16)|0);
      var $252=HEAP32[(($251)>>2)];
      var $253=$252 & 255;
      var $254=(($253)|0)!=8;
      if ($254) { __label__ = 59; break; } else { __label__ = 60; break; }
    case 59: 
      var $256=$2;
      var $257=(($256+24)|0);
      HEAP32[(($257)>>2)]=((STRING_TABLE.__str236)|0);
      var $258=$state;
      var $259=(($258)|0);
      HEAP32[(($259)>>2)]=29;
      __label__ = 565; break;
    case 60: 
      var $261=$state;
      var $262=(($261+16)|0);
      var $263=HEAP32[(($262)>>2)];
      var $264=$263 & 57344;
      var $265=(($264)|0)!=0;
      if ($265) { __label__ = 61; break; } else { __label__ = 62; break; }
    case 61: 
      var $267=$2;
      var $268=(($267+24)|0);
      HEAP32[(($268)>>2)]=((STRING_TABLE.__str438)|0);
      var $269=$state;
      var $270=(($269)|0);
      HEAP32[(($270)>>2)]=29;
      __label__ = 565; break;
    case 62: 
      var $272=$state;
      var $273=(($272+32)|0);
      var $274=HEAP32[(($273)>>2)];
      var $275=(($274)|0)!=0;
      if ($275) { __label__ = 63; break; } else { __label__ = 64; break; }
    case 63: 
      var $277=$hold;
      var $278=$277 >>> 8;
      var $279=$278 & 1;
      var $280=$state;
      var $281=(($280+32)|0);
      var $282=HEAP32[(($281)>>2)];
      var $283=(($282)|0);
      HEAP32[(($283)>>2)]=$279;
      __label__ = 64; break;
    case 64: 
      var $285=$state;
      var $286=(($285+16)|0);
      var $287=HEAP32[(($286)>>2)];
      var $288=$287 & 512;
      var $289=(($288)|0)!=0;
      if ($289) { __label__ = 65; break; } else { __label__ = 68; break; }
    case 65: 
      __label__ = 66; break;
    case 66: 
      var $292=$hold;
      var $293=(($292) & 255);
      var $294=(($hbuf)|0);
      HEAP8[($294)]=$293;
      var $295=$hold;
      var $296=$295 >>> 8;
      var $297=(($296) & 255);
      var $298=(($hbuf+1)|0);
      HEAP8[($298)]=$297;
      var $299=$state;
      var $300=(($299+24)|0);
      var $301=HEAP32[(($300)>>2)];
      var $302=(($hbuf)|0);
      var $303=_crc32($301, $302, 2);
      var $304=$state;
      var $305=(($304+24)|0);
      HEAP32[(($305)>>2)]=$303;
      __label__ = 67; break;
    case 67: 
      __label__ = 68; break;
    case 68: 
      __label__ = 69; break;
    case 69: 
      $hold=0;
      $bits=0;
      __label__ = 70; break;
    case 70: 
      var $310=$state;
      var $311=(($310)|0);
      HEAP32[(($311)>>2)]=2;
      __label__ = 71; break;
    case 71: 
      __label__ = 72; break;
    case 72: 
      __label__ = 73; break;
    case 73: 
      var $315=$bits;
      var $316=(($315)>>>0) < 32;
      if ($316) { __label__ = 74; break; } else { __label__ = 79; break; }
    case 74: 
      __label__ = 75; break;
    case 75: 
      var $319=$have;
      var $320=(($319)|0)==0;
      if ($320) { __label__ = 76; break; } else { __label__ = 77; break; }
    case 76: 
      __label__ = 566; break;
    case 77: 
      var $323=$have;
      var $324=((($323)-(1))|0);
      $have=$324;
      var $325=$next;
      var $326=(($325+1)|0);
      $next=$326;
      var $327=HEAPU8[($325)];
      var $328=(($327)&255);
      var $329=$bits;
      var $330=$328 << $329;
      var $331=$hold;
      var $332=((($331)+($330))|0);
      $hold=$332;
      var $333=$bits;
      var $334=((($333)+(8))|0);
      $bits=$334;
      __label__ = 78; break;
    case 78: 
      __label__ = 73; break;
    case 79: 
      __label__ = 80; break;
    case 80: 
      var $338=$state;
      var $339=(($338+32)|0);
      var $340=HEAP32[(($339)>>2)];
      var $341=(($340)|0)!=0;
      if ($341) { __label__ = 81; break; } else { __label__ = 82; break; }
    case 81: 
      var $343=$hold;
      var $344=$state;
      var $345=(($344+32)|0);
      var $346=HEAP32[(($345)>>2)];
      var $347=(($346+4)|0);
      HEAP32[(($347)>>2)]=$343;
      __label__ = 82; break;
    case 82: 
      var $349=$state;
      var $350=(($349+16)|0);
      var $351=HEAP32[(($350)>>2)];
      var $352=$351 & 512;
      var $353=(($352)|0)!=0;
      if ($353) { __label__ = 83; break; } else { __label__ = 86; break; }
    case 83: 
      __label__ = 84; break;
    case 84: 
      var $356=$hold;
      var $357=(($356) & 255);
      var $358=(($hbuf)|0);
      HEAP8[($358)]=$357;
      var $359=$hold;
      var $360=$359 >>> 8;
      var $361=(($360) & 255);
      var $362=(($hbuf+1)|0);
      HEAP8[($362)]=$361;
      var $363=$hold;
      var $364=$363 >>> 16;
      var $365=(($364) & 255);
      var $366=(($hbuf+2)|0);
      HEAP8[($366)]=$365;
      var $367=$hold;
      var $368=$367 >>> 24;
      var $369=(($368) & 255);
      var $370=(($hbuf+3)|0);
      HEAP8[($370)]=$369;
      var $371=$state;
      var $372=(($371+24)|0);
      var $373=HEAP32[(($372)>>2)];
      var $374=(($hbuf)|0);
      var $375=_crc32($373, $374, 4);
      var $376=$state;
      var $377=(($376+24)|0);
      HEAP32[(($377)>>2)]=$375;
      __label__ = 85; break;
    case 85: 
      __label__ = 86; break;
    case 86: 
      __label__ = 87; break;
    case 87: 
      $hold=0;
      $bits=0;
      __label__ = 88; break;
    case 88: 
      var $382=$state;
      var $383=(($382)|0);
      HEAP32[(($383)>>2)]=3;
      __label__ = 89; break;
    case 89: 
      __label__ = 90; break;
    case 90: 
      __label__ = 91; break;
    case 91: 
      var $387=$bits;
      var $388=(($387)>>>0) < 16;
      if ($388) { __label__ = 92; break; } else { __label__ = 97; break; }
    case 92: 
      __label__ = 93; break;
    case 93: 
      var $391=$have;
      var $392=(($391)|0)==0;
      if ($392) { __label__ = 94; break; } else { __label__ = 95; break; }
    case 94: 
      __label__ = 566; break;
    case 95: 
      var $395=$have;
      var $396=((($395)-(1))|0);
      $have=$396;
      var $397=$next;
      var $398=(($397+1)|0);
      $next=$398;
      var $399=HEAPU8[($397)];
      var $400=(($399)&255);
      var $401=$bits;
      var $402=$400 << $401;
      var $403=$hold;
      var $404=((($403)+($402))|0);
      $hold=$404;
      var $405=$bits;
      var $406=((($405)+(8))|0);
      $bits=$406;
      __label__ = 96; break;
    case 96: 
      __label__ = 91; break;
    case 97: 
      __label__ = 98; break;
    case 98: 
      var $410=$state;
      var $411=(($410+32)|0);
      var $412=HEAP32[(($411)>>2)];
      var $413=(($412)|0)!=0;
      if ($413) { __label__ = 99; break; } else { __label__ = 100; break; }
    case 99: 
      var $415=$hold;
      var $416=$415 & 255;
      var $417=$state;
      var $418=(($417+32)|0);
      var $419=HEAP32[(($418)>>2)];
      var $420=(($419+8)|0);
      HEAP32[(($420)>>2)]=$416;
      var $421=$hold;
      var $422=$421 >>> 8;
      var $423=$state;
      var $424=(($423+32)|0);
      var $425=HEAP32[(($424)>>2)];
      var $426=(($425+12)|0);
      HEAP32[(($426)>>2)]=$422;
      __label__ = 100; break;
    case 100: 
      var $428=$state;
      var $429=(($428+16)|0);
      var $430=HEAP32[(($429)>>2)];
      var $431=$430 & 512;
      var $432=(($431)|0)!=0;
      if ($432) { __label__ = 101; break; } else { __label__ = 104; break; }
    case 101: 
      __label__ = 102; break;
    case 102: 
      var $435=$hold;
      var $436=(($435) & 255);
      var $437=(($hbuf)|0);
      HEAP8[($437)]=$436;
      var $438=$hold;
      var $439=$438 >>> 8;
      var $440=(($439) & 255);
      var $441=(($hbuf+1)|0);
      HEAP8[($441)]=$440;
      var $442=$state;
      var $443=(($442+24)|0);
      var $444=HEAP32[(($443)>>2)];
      var $445=(($hbuf)|0);
      var $446=_crc32($444, $445, 2);
      var $447=$state;
      var $448=(($447+24)|0);
      HEAP32[(($448)>>2)]=$446;
      __label__ = 103; break;
    case 103: 
      __label__ = 104; break;
    case 104: 
      __label__ = 105; break;
    case 105: 
      $hold=0;
      $bits=0;
      __label__ = 106; break;
    case 106: 
      var $453=$state;
      var $454=(($453)|0);
      HEAP32[(($454)>>2)]=4;
      __label__ = 107; break;
    case 107: 
      var $456=$state;
      var $457=(($456+16)|0);
      var $458=HEAP32[(($457)>>2)];
      var $459=$458 & 1024;
      var $460=(($459)|0)!=0;
      if ($460) { __label__ = 108; break; } else { __label__ = 126; break; }
    case 108: 
      __label__ = 109; break;
    case 109: 
      __label__ = 110; break;
    case 110: 
      var $464=$bits;
      var $465=(($464)>>>0) < 16;
      if ($465) { __label__ = 111; break; } else { __label__ = 116; break; }
    case 111: 
      __label__ = 112; break;
    case 112: 
      var $468=$have;
      var $469=(($468)|0)==0;
      if ($469) { __label__ = 113; break; } else { __label__ = 114; break; }
    case 113: 
      __label__ = 566; break;
    case 114: 
      var $472=$have;
      var $473=((($472)-(1))|0);
      $have=$473;
      var $474=$next;
      var $475=(($474+1)|0);
      $next=$475;
      var $476=HEAPU8[($474)];
      var $477=(($476)&255);
      var $478=$bits;
      var $479=$477 << $478;
      var $480=$hold;
      var $481=((($480)+($479))|0);
      $hold=$481;
      var $482=$bits;
      var $483=((($482)+(8))|0);
      $bits=$483;
      __label__ = 115; break;
    case 115: 
      __label__ = 110; break;
    case 116: 
      __label__ = 117; break;
    case 117: 
      var $487=$hold;
      var $488=$state;
      var $489=(($488+64)|0);
      HEAP32[(($489)>>2)]=$487;
      var $490=$state;
      var $491=(($490+32)|0);
      var $492=HEAP32[(($491)>>2)];
      var $493=(($492)|0)!=0;
      if ($493) { __label__ = 118; break; } else { __label__ = 119; break; }
    case 118: 
      var $495=$hold;
      var $496=$state;
      var $497=(($496+32)|0);
      var $498=HEAP32[(($497)>>2)];
      var $499=(($498+20)|0);
      HEAP32[(($499)>>2)]=$495;
      __label__ = 119; break;
    case 119: 
      var $501=$state;
      var $502=(($501+16)|0);
      var $503=HEAP32[(($502)>>2)];
      var $504=$503 & 512;
      var $505=(($504)|0)!=0;
      if ($505) { __label__ = 120; break; } else { __label__ = 123; break; }
    case 120: 
      __label__ = 121; break;
    case 121: 
      var $508=$hold;
      var $509=(($508) & 255);
      var $510=(($hbuf)|0);
      HEAP8[($510)]=$509;
      var $511=$hold;
      var $512=$511 >>> 8;
      var $513=(($512) & 255);
      var $514=(($hbuf+1)|0);
      HEAP8[($514)]=$513;
      var $515=$state;
      var $516=(($515+24)|0);
      var $517=HEAP32[(($516)>>2)];
      var $518=(($hbuf)|0);
      var $519=_crc32($517, $518, 2);
      var $520=$state;
      var $521=(($520+24)|0);
      HEAP32[(($521)>>2)]=$519;
      __label__ = 122; break;
    case 122: 
      __label__ = 123; break;
    case 123: 
      __label__ = 124; break;
    case 124: 
      $hold=0;
      $bits=0;
      __label__ = 125; break;
    case 125: 
      __label__ = 129; break;
    case 126: 
      var $527=$state;
      var $528=(($527+32)|0);
      var $529=HEAP32[(($528)>>2)];
      var $530=(($529)|0)!=0;
      if ($530) { __label__ = 127; break; } else { __label__ = 128; break; }
    case 127: 
      var $532=$state;
      var $533=(($532+32)|0);
      var $534=HEAP32[(($533)>>2)];
      var $535=(($534+16)|0);
      HEAP32[(($535)>>2)]=0;
      __label__ = 128; break;
    case 128: 
      __label__ = 129; break;
    case 129: 
      var $538=$state;
      var $539=(($538)|0);
      HEAP32[(($539)>>2)]=5;
      __label__ = 130; break;
    case 130: 
      var $541=$state;
      var $542=(($541+16)|0);
      var $543=HEAP32[(($542)>>2)];
      var $544=$543 & 1024;
      var $545=(($544)|0)!=0;
      if ($545) { __label__ = 131; break; } else { __label__ = 146; break; }
    case 131: 
      var $547=$state;
      var $548=(($547+64)|0);
      var $549=HEAP32[(($548)>>2)];
      $copy=$549;
      var $550=$copy;
      var $551=$have;
      var $552=(($550)>>>0) > (($551)>>>0);
      if ($552) { __label__ = 132; break; } else { __label__ = 133; break; }
    case 132: 
      var $554=$have;
      $copy=$554;
      __label__ = 133; break;
    case 133: 
      var $556=$copy;
      var $557=(($556)|0)!=0;
      if ($557) { __label__ = 134; break; } else { __label__ = 143; break; }
    case 134: 
      var $559=$state;
      var $560=(($559+32)|0);
      var $561=HEAP32[(($560)>>2)];
      var $562=(($561)|0)!=0;
      if ($562) { __label__ = 135; break; } else { __label__ = 140; break; }
    case 135: 
      var $564=$state;
      var $565=(($564+32)|0);
      var $566=HEAP32[(($565)>>2)];
      var $567=(($566+16)|0);
      var $568=HEAP32[(($567)>>2)];
      var $569=(($568)|0)!=0;
      if ($569) { __label__ = 136; break; } else { __label__ = 140; break; }
    case 136: 
      var $571=$state;
      var $572=(($571+32)|0);
      var $573=HEAP32[(($572)>>2)];
      var $574=(($573+20)|0);
      var $575=HEAP32[(($574)>>2)];
      var $576=$state;
      var $577=(($576+64)|0);
      var $578=HEAP32[(($577)>>2)];
      var $579=((($575)-($578))|0);
      $len=$579;
      var $580=$state;
      var $581=(($580+32)|0);
      var $582=HEAP32[(($581)>>2)];
      var $583=(($582+16)|0);
      var $584=HEAP32[(($583)>>2)];
      var $585=$len;
      var $586=(($584+$585)|0);
      var $587=$next;
      var $588=$len;
      var $589=$copy;
      var $590=((($588)+($589))|0);
      var $591=$state;
      var $592=(($591+32)|0);
      var $593=HEAP32[(($592)>>2)];
      var $594=(($593+24)|0);
      var $595=HEAPU32[(($594)>>2)];
      var $596=(($590)>>>0) > (($595)>>>0);
      if ($596) { __label__ = 137; break; } else { __label__ = 138; break; }
    case 137: 
      var $598=$state;
      var $599=(($598+32)|0);
      var $600=HEAP32[(($599)>>2)];
      var $601=(($600+24)|0);
      var $602=HEAP32[(($601)>>2)];
      var $603=$len;
      var $604=((($602)-($603))|0);
      var $608 = $604;__label__ = 139; break;
    case 138: 
      var $606=$copy;
      var $608 = $606;__label__ = 139; break;
    case 139: 
      var $608;
      assert($608 % 1 === 0, 'memcpy given ' + $608 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');_memcpy($586, $587, $608, 1);
      __label__ = 140; break;
    case 140: 
      var $610=$state;
      var $611=(($610+16)|0);
      var $612=HEAP32[(($611)>>2)];
      var $613=$612 & 512;
      var $614=(($613)|0)!=0;
      if ($614) { __label__ = 141; break; } else { __label__ = 142; break; }
    case 141: 
      var $616=$state;
      var $617=(($616+24)|0);
      var $618=HEAP32[(($617)>>2)];
      var $619=$next;
      var $620=$copy;
      var $621=_crc32($618, $619, $620);
      var $622=$state;
      var $623=(($622+24)|0);
      HEAP32[(($623)>>2)]=$621;
      __label__ = 142; break;
    case 142: 
      var $625=$copy;
      var $626=$have;
      var $627=((($626)-($625))|0);
      $have=$627;
      var $628=$copy;
      var $629=$next;
      var $630=(($629+$628)|0);
      $next=$630;
      var $631=$copy;
      var $632=$state;
      var $633=(($632+64)|0);
      var $634=HEAP32[(($633)>>2)];
      var $635=((($634)-($631))|0);
      HEAP32[(($633)>>2)]=$635;
      __label__ = 143; break;
    case 143: 
      var $637=$state;
      var $638=(($637+64)|0);
      var $639=HEAP32[(($638)>>2)];
      var $640=(($639)|0)!=0;
      if ($640) { __label__ = 144; break; } else { __label__ = 145; break; }
    case 144: 
      __label__ = 566; break;
    case 145: 
      __label__ = 146; break;
    case 146: 
      var $644=$state;
      var $645=(($644+64)|0);
      HEAP32[(($645)>>2)]=0;
      var $646=$state;
      var $647=(($646)|0);
      HEAP32[(($647)>>2)]=6;
      __label__ = 147; break;
    case 147: 
      var $649=$state;
      var $650=(($649+16)|0);
      var $651=HEAP32[(($650)>>2)];
      var $652=$651 & 2048;
      var $653=(($652)|0)!=0;
      if ($653) { __label__ = 148; break; } else { __label__ = 164; break; }
    case 148: 
      var $655=$have;
      var $656=(($655)|0)==0;
      if ($656) { __label__ = 149; break; } else { __label__ = 150; break; }
    case 149: 
      __label__ = 566; break;
    case 150: 
      $copy=0;
      __label__ = 151; break;
    case 151: 
      var $660=$copy;
      var $661=((($660)+(1))|0);
      $copy=$661;
      var $662=$next;
      var $663=(($662+$660)|0);
      var $664=HEAPU8[($663)];
      var $665=(($664)&255);
      $len=$665;
      var $666=$state;
      var $667=(($666+32)|0);
      var $668=HEAP32[(($667)>>2)];
      var $669=(($668)|0)!=0;
      if ($669) { __label__ = 152; break; } else { __label__ = 155; break; }
    case 152: 
      var $671=$state;
      var $672=(($671+32)|0);
      var $673=HEAP32[(($672)>>2)];
      var $674=(($673+28)|0);
      var $675=HEAP32[(($674)>>2)];
      var $676=(($675)|0)!=0;
      if ($676) { __label__ = 153; break; } else { __label__ = 155; break; }
    case 153: 
      var $678=$state;
      var $679=(($678+64)|0);
      var $680=HEAPU32[(($679)>>2)];
      var $681=$state;
      var $682=(($681+32)|0);
      var $683=HEAP32[(($682)>>2)];
      var $684=(($683+32)|0);
      var $685=HEAPU32[(($684)>>2)];
      var $686=(($680)>>>0) < (($685)>>>0);
      if ($686) { __label__ = 154; break; } else { __label__ = 155; break; }
    case 154: 
      var $688=$len;
      var $689=(($688) & 255);
      var $690=$state;
      var $691=(($690+64)|0);
      var $692=HEAPU32[(($691)>>2)];
      var $693=((($692)+(1))|0);
      HEAP32[(($691)>>2)]=$693;
      var $694=$state;
      var $695=(($694+32)|0);
      var $696=HEAP32[(($695)>>2)];
      var $697=(($696+28)|0);
      var $698=HEAP32[(($697)>>2)];
      var $699=(($698+$692)|0);
      HEAP8[($699)]=$689;
      __label__ = 155; break;
    case 155: 
      __label__ = 156; break;
    case 156: 
      var $702=$len;
      var $703=(($702)|0)!=0;
      if ($703) { __label__ = 157; break; } else { var $709 = 0;__label__ = 158; break; }
    case 157: 
      var $705=$copy;
      var $706=$have;
      var $707=(($705)>>>0) < (($706)>>>0);
      var $709 = $707;__label__ = 158; break;
    case 158: 
      var $709;
      if ($709) { __label__ = 151; break; } else { __label__ = 159; break; }
    case 159: 
      var $711=$state;
      var $712=(($711+16)|0);
      var $713=HEAP32[(($712)>>2)];
      var $714=$713 & 512;
      var $715=(($714)|0)!=0;
      if ($715) { __label__ = 160; break; } else { __label__ = 161; break; }
    case 160: 
      var $717=$state;
      var $718=(($717+24)|0);
      var $719=HEAP32[(($718)>>2)];
      var $720=$next;
      var $721=$copy;
      var $722=_crc32($719, $720, $721);
      var $723=$state;
      var $724=(($723+24)|0);
      HEAP32[(($724)>>2)]=$722;
      __label__ = 161; break;
    case 161: 
      var $726=$copy;
      var $727=$have;
      var $728=((($727)-($726))|0);
      $have=$728;
      var $729=$copy;
      var $730=$next;
      var $731=(($730+$729)|0);
      $next=$731;
      var $732=$len;
      var $733=(($732)|0)!=0;
      if ($733) { __label__ = 162; break; } else { __label__ = 163; break; }
    case 162: 
      __label__ = 566; break;
    case 163: 
      __label__ = 167; break;
    case 164: 
      var $737=$state;
      var $738=(($737+32)|0);
      var $739=HEAP32[(($738)>>2)];
      var $740=(($739)|0)!=0;
      if ($740) { __label__ = 165; break; } else { __label__ = 166; break; }
    case 165: 
      var $742=$state;
      var $743=(($742+32)|0);
      var $744=HEAP32[(($743)>>2)];
      var $745=(($744+28)|0);
      HEAP32[(($745)>>2)]=0;
      __label__ = 166; break;
    case 166: 
      __label__ = 167; break;
    case 167: 
      var $748=$state;
      var $749=(($748+64)|0);
      HEAP32[(($749)>>2)]=0;
      var $750=$state;
      var $751=(($750)|0);
      HEAP32[(($751)>>2)]=7;
      __label__ = 168; break;
    case 168: 
      var $753=$state;
      var $754=(($753+16)|0);
      var $755=HEAP32[(($754)>>2)];
      var $756=$755 & 4096;
      var $757=(($756)|0)!=0;
      if ($757) { __label__ = 169; break; } else { __label__ = 185; break; }
    case 169: 
      var $759=$have;
      var $760=(($759)|0)==0;
      if ($760) { __label__ = 170; break; } else { __label__ = 171; break; }
    case 170: 
      __label__ = 566; break;
    case 171: 
      $copy=0;
      __label__ = 172; break;
    case 172: 
      var $764=$copy;
      var $765=((($764)+(1))|0);
      $copy=$765;
      var $766=$next;
      var $767=(($766+$764)|0);
      var $768=HEAPU8[($767)];
      var $769=(($768)&255);
      $len=$769;
      var $770=$state;
      var $771=(($770+32)|0);
      var $772=HEAP32[(($771)>>2)];
      var $773=(($772)|0)!=0;
      if ($773) { __label__ = 173; break; } else { __label__ = 176; break; }
    case 173: 
      var $775=$state;
      var $776=(($775+32)|0);
      var $777=HEAP32[(($776)>>2)];
      var $778=(($777+36)|0);
      var $779=HEAP32[(($778)>>2)];
      var $780=(($779)|0)!=0;
      if ($780) { __label__ = 174; break; } else { __label__ = 176; break; }
    case 174: 
      var $782=$state;
      var $783=(($782+64)|0);
      var $784=HEAPU32[(($783)>>2)];
      var $785=$state;
      var $786=(($785+32)|0);
      var $787=HEAP32[(($786)>>2)];
      var $788=(($787+40)|0);
      var $789=HEAPU32[(($788)>>2)];
      var $790=(($784)>>>0) < (($789)>>>0);
      if ($790) { __label__ = 175; break; } else { __label__ = 176; break; }
    case 175: 
      var $792=$len;
      var $793=(($792) & 255);
      var $794=$state;
      var $795=(($794+64)|0);
      var $796=HEAPU32[(($795)>>2)];
      var $797=((($796)+(1))|0);
      HEAP32[(($795)>>2)]=$797;
      var $798=$state;
      var $799=(($798+32)|0);
      var $800=HEAP32[(($799)>>2)];
      var $801=(($800+36)|0);
      var $802=HEAP32[(($801)>>2)];
      var $803=(($802+$796)|0);
      HEAP8[($803)]=$793;
      __label__ = 176; break;
    case 176: 
      __label__ = 177; break;
    case 177: 
      var $806=$len;
      var $807=(($806)|0)!=0;
      if ($807) { __label__ = 178; break; } else { var $813 = 0;__label__ = 179; break; }
    case 178: 
      var $809=$copy;
      var $810=$have;
      var $811=(($809)>>>0) < (($810)>>>0);
      var $813 = $811;__label__ = 179; break;
    case 179: 
      var $813;
      if ($813) { __label__ = 172; break; } else { __label__ = 180; break; }
    case 180: 
      var $815=$state;
      var $816=(($815+16)|0);
      var $817=HEAP32[(($816)>>2)];
      var $818=$817 & 512;
      var $819=(($818)|0)!=0;
      if ($819) { __label__ = 181; break; } else { __label__ = 182; break; }
    case 181: 
      var $821=$state;
      var $822=(($821+24)|0);
      var $823=HEAP32[(($822)>>2)];
      var $824=$next;
      var $825=$copy;
      var $826=_crc32($823, $824, $825);
      var $827=$state;
      var $828=(($827+24)|0);
      HEAP32[(($828)>>2)]=$826;
      __label__ = 182; break;
    case 182: 
      var $830=$copy;
      var $831=$have;
      var $832=((($831)-($830))|0);
      $have=$832;
      var $833=$copy;
      var $834=$next;
      var $835=(($834+$833)|0);
      $next=$835;
      var $836=$len;
      var $837=(($836)|0)!=0;
      if ($837) { __label__ = 183; break; } else { __label__ = 184; break; }
    case 183: 
      __label__ = 566; break;
    case 184: 
      __label__ = 188; break;
    case 185: 
      var $841=$state;
      var $842=(($841+32)|0);
      var $843=HEAP32[(($842)>>2)];
      var $844=(($843)|0)!=0;
      if ($844) { __label__ = 186; break; } else { __label__ = 187; break; }
    case 186: 
      var $846=$state;
      var $847=(($846+32)|0);
      var $848=HEAP32[(($847)>>2)];
      var $849=(($848+36)|0);
      HEAP32[(($849)>>2)]=0;
      __label__ = 187; break;
    case 187: 
      __label__ = 188; break;
    case 188: 
      var $852=$state;
      var $853=(($852)|0);
      HEAP32[(($853)>>2)]=8;
      __label__ = 189; break;
    case 189: 
      var $855=$state;
      var $856=(($855+16)|0);
      var $857=HEAP32[(($856)>>2)];
      var $858=$857 & 512;
      var $859=(($858)|0)!=0;
      if ($859) { __label__ = 190; break; } else { __label__ = 204; break; }
    case 190: 
      __label__ = 191; break;
    case 191: 
      __label__ = 192; break;
    case 192: 
      var $863=$bits;
      var $864=(($863)>>>0) < 16;
      if ($864) { __label__ = 193; break; } else { __label__ = 198; break; }
    case 193: 
      __label__ = 194; break;
    case 194: 
      var $867=$have;
      var $868=(($867)|0)==0;
      if ($868) { __label__ = 195; break; } else { __label__ = 196; break; }
    case 195: 
      __label__ = 566; break;
    case 196: 
      var $871=$have;
      var $872=((($871)-(1))|0);
      $have=$872;
      var $873=$next;
      var $874=(($873+1)|0);
      $next=$874;
      var $875=HEAPU8[($873)];
      var $876=(($875)&255);
      var $877=$bits;
      var $878=$876 << $877;
      var $879=$hold;
      var $880=((($879)+($878))|0);
      $hold=$880;
      var $881=$bits;
      var $882=((($881)+(8))|0);
      $bits=$882;
      __label__ = 197; break;
    case 197: 
      __label__ = 192; break;
    case 198: 
      __label__ = 199; break;
    case 199: 
      var $886=$hold;
      var $887=$state;
      var $888=(($887+24)|0);
      var $889=HEAP32[(($888)>>2)];
      var $890=$889 & 65535;
      var $891=(($886)|0)!=(($890)|0);
      if ($891) { __label__ = 200; break; } else { __label__ = 201; break; }
    case 200: 
      var $893=$2;
      var $894=(($893+24)|0);
      HEAP32[(($894)>>2)]=((STRING_TABLE.__str539)|0);
      var $895=$state;
      var $896=(($895)|0);
      HEAP32[(($896)>>2)]=29;
      __label__ = 565; break;
    case 201: 
      __label__ = 202; break;
    case 202: 
      $hold=0;
      $bits=0;
      __label__ = 203; break;
    case 203: 
      __label__ = 204; break;
    case 204: 
      var $901=$state;
      var $902=(($901+32)|0);
      var $903=HEAP32[(($902)>>2)];
      var $904=(($903)|0)!=0;
      if ($904) { __label__ = 205; break; } else { __label__ = 206; break; }
    case 205: 
      var $906=$state;
      var $907=(($906+16)|0);
      var $908=HEAP32[(($907)>>2)];
      var $909=$908 >> 9;
      var $910=$909 & 1;
      var $911=$state;
      var $912=(($911+32)|0);
      var $913=HEAP32[(($912)>>2)];
      var $914=(($913+44)|0);
      HEAP32[(($914)>>2)]=$910;
      var $915=$state;
      var $916=(($915+32)|0);
      var $917=HEAP32[(($916)>>2)];
      var $918=(($917+48)|0);
      HEAP32[(($918)>>2)]=1;
      __label__ = 206; break;
    case 206: 
      var $920=_crc32(0, 0, 0);
      var $921=$state;
      var $922=(($921+24)|0);
      HEAP32[(($922)>>2)]=$920;
      var $923=$2;
      var $924=(($923+48)|0);
      HEAP32[(($924)>>2)]=$920;
      var $925=$state;
      var $926=(($925)|0);
      HEAP32[(($926)>>2)]=11;
      __label__ = 565; break;
    case 207: 
      __label__ = 208; break;
    case 208: 
      __label__ = 209; break;
    case 209: 
      var $930=$bits;
      var $931=(($930)>>>0) < 32;
      if ($931) { __label__ = 210; break; } else { __label__ = 215; break; }
    case 210: 
      __label__ = 211; break;
    case 211: 
      var $934=$have;
      var $935=(($934)|0)==0;
      if ($935) { __label__ = 212; break; } else { __label__ = 213; break; }
    case 212: 
      __label__ = 566; break;
    case 213: 
      var $938=$have;
      var $939=((($938)-(1))|0);
      $have=$939;
      var $940=$next;
      var $941=(($940+1)|0);
      $next=$941;
      var $942=HEAPU8[($940)];
      var $943=(($942)&255);
      var $944=$bits;
      var $945=$943 << $944;
      var $946=$hold;
      var $947=((($946)+($945))|0);
      $hold=$947;
      var $948=$bits;
      var $949=((($948)+(8))|0);
      $bits=$949;
      __label__ = 214; break;
    case 214: 
      __label__ = 209; break;
    case 215: 
      __label__ = 216; break;
    case 216: 
      var $953=$hold;
      var $954=$953 >>> 24;
      var $955=$954 & 255;
      var $956=$hold;
      var $957=$956 >>> 8;
      var $958=$957 & 65280;
      var $959=((($955)+($958))|0);
      var $960=$hold;
      var $961=$960 & 65280;
      var $962=$961 << 8;
      var $963=((($959)+($962))|0);
      var $964=$hold;
      var $965=$964 & 255;
      var $966=$965 << 24;
      var $967=((($963)+($966))|0);
      var $968=$state;
      var $969=(($968+24)|0);
      HEAP32[(($969)>>2)]=$967;
      var $970=$2;
      var $971=(($970+48)|0);
      HEAP32[(($971)>>2)]=$967;
      __label__ = 217; break;
    case 217: 
      $hold=0;
      $bits=0;
      __label__ = 218; break;
    case 218: 
      var $974=$state;
      var $975=(($974)|0);
      HEAP32[(($975)>>2)]=10;
      __label__ = 219; break;
    case 219: 
      var $977=$state;
      var $978=(($977+12)|0);
      var $979=HEAP32[(($978)>>2)];
      var $980=(($979)|0)==0;
      if ($980) { __label__ = 220; break; } else { __label__ = 223; break; }
    case 220: 
      __label__ = 221; break;
    case 221: 
      var $983=$put;
      var $984=$2;
      var $985=(($984+12)|0);
      HEAP32[(($985)>>2)]=$983;
      var $986=$left;
      var $987=$2;
      var $988=(($987+16)|0);
      HEAP32[(($988)>>2)]=$986;
      var $989=$next;
      var $990=$2;
      var $991=(($990)|0);
      HEAP32[(($991)>>2)]=$989;
      var $992=$have;
      var $993=$2;
      var $994=(($993+4)|0);
      HEAP32[(($994)>>2)]=$992;
      var $995=$hold;
      var $996=$state;
      var $997=(($996+56)|0);
      HEAP32[(($997)>>2)]=$995;
      var $998=$bits;
      var $999=$state;
      var $1000=(($999+60)|0);
      HEAP32[(($1000)>>2)]=$998;
      __label__ = 222; break;
    case 222: 
      $1=2;
      __label__ = 590; break;
    case 223: 
      var $1003=_adler32(0, 0, 0);
      var $1004=$state;
      var $1005=(($1004+24)|0);
      HEAP32[(($1005)>>2)]=$1003;
      var $1006=$2;
      var $1007=(($1006+48)|0);
      HEAP32[(($1007)>>2)]=$1003;
      var $1008=$state;
      var $1009=(($1008)|0);
      HEAP32[(($1009)>>2)]=11;
      __label__ = 224; break;
    case 224: 
      var $1011=$3;
      var $1012=(($1011)|0)==5;
      if ($1012) { __label__ = 226; break; } else { __label__ = 225; break; }
    case 225: 
      var $1014=$3;
      var $1015=(($1014)|0)==6;
      if ($1015) { __label__ = 226; break; } else { __label__ = 227; break; }
    case 226: 
      __label__ = 566; break;
    case 227: 
      __label__ = 228; break;
    case 228: 
      var $1019=$state;
      var $1020=(($1019+4)|0);
      var $1021=HEAP32[(($1020)>>2)];
      var $1022=(($1021)|0)!=0;
      if ($1022) { __label__ = 229; break; } else { __label__ = 232; break; }
    case 229: 
      __label__ = 230; break;
    case 230: 
      var $1025=$bits;
      var $1026=$1025 & 7;
      var $1027=$hold;
      var $1028=$1027 >>> (($1026)>>>0);
      $hold=$1028;
      var $1029=$bits;
      var $1030=$1029 & 7;
      var $1031=$bits;
      var $1032=((($1031)-($1030))|0);
      $bits=$1032;
      __label__ = 231; break;
    case 231: 
      var $1034=$state;
      var $1035=(($1034)|0);
      HEAP32[(($1035)>>2)]=26;
      __label__ = 565; break;
    case 232: 
      __label__ = 233; break;
    case 233: 
      __label__ = 234; break;
    case 234: 
      var $1039=$bits;
      var $1040=(($1039)>>>0) < 3;
      if ($1040) { __label__ = 235; break; } else { __label__ = 240; break; }
    case 235: 
      __label__ = 236; break;
    case 236: 
      var $1043=$have;
      var $1044=(($1043)|0)==0;
      if ($1044) { __label__ = 237; break; } else { __label__ = 238; break; }
    case 237: 
      __label__ = 566; break;
    case 238: 
      var $1047=$have;
      var $1048=((($1047)-(1))|0);
      $have=$1048;
      var $1049=$next;
      var $1050=(($1049+1)|0);
      $next=$1050;
      var $1051=HEAPU8[($1049)];
      var $1052=(($1051)&255);
      var $1053=$bits;
      var $1054=$1052 << $1053;
      var $1055=$hold;
      var $1056=((($1055)+($1054))|0);
      $hold=$1056;
      var $1057=$bits;
      var $1058=((($1057)+(8))|0);
      $bits=$1058;
      __label__ = 239; break;
    case 239: 
      __label__ = 234; break;
    case 240: 
      __label__ = 241; break;
    case 241: 
      var $1062=$hold;
      var $1063=$1062 & 1;
      var $1064=$state;
      var $1065=(($1064+4)|0);
      HEAP32[(($1065)>>2)]=$1063;
      __label__ = 242; break;
    case 242: 
      var $1067=$hold;
      var $1068=$1067 >>> 1;
      $hold=$1068;
      var $1069=$bits;
      var $1070=((($1069)-(1))|0);
      $bits=$1070;
      __label__ = 243; break;
    case 243: 
      var $1072=$hold;
      var $1073=$1072 & 3;
      if ((($1073)|0) == 0) {
        __label__ = 244; break;
      }
      else if ((($1073)|0) == 1) {
        __label__ = 245; break;
      }
      else if ((($1073)|0) == 2) {
        __label__ = 250; break;
      }
      else if ((($1073)|0) == 3) {
        __label__ = 251; break;
      }
      else {
      __label__ = 252; break;
      }
      
    case 244: 
      var $1075=$state;
      var $1076=(($1075)|0);
      HEAP32[(($1076)>>2)]=13;
      __label__ = 252; break;
    case 245: 
      var $1078=$state;
      _fixedtables55($1078);
      var $1079=$state;
      var $1080=(($1079)|0);
      HEAP32[(($1080)>>2)]=19;
      var $1081=$3;
      var $1082=(($1081)|0)==6;
      if ($1082) { __label__ = 246; break; } else { __label__ = 249; break; }
    case 246: 
      __label__ = 247; break;
    case 247: 
      var $1085=$hold;
      var $1086=$1085 >>> 2;
      $hold=$1086;
      var $1087=$bits;
      var $1088=((($1087)-(2))|0);
      $bits=$1088;
      __label__ = 248; break;
    case 248: 
      __label__ = 566; break;
    case 249: 
      __label__ = 252; break;
    case 250: 
      var $1092=$state;
      var $1093=(($1092)|0);
      HEAP32[(($1093)>>2)]=16;
      __label__ = 252; break;
    case 251: 
      var $1095=$2;
      var $1096=(($1095+24)|0);
      HEAP32[(($1096)>>2)]=((STRING_TABLE.__str640)|0);
      var $1097=$state;
      var $1098=(($1097)|0);
      HEAP32[(($1098)>>2)]=29;
      __label__ = 252; break;
    case 252: 
      __label__ = 253; break;
    case 253: 
      var $1101=$hold;
      var $1102=$1101 >>> 2;
      $hold=$1102;
      var $1103=$bits;
      var $1104=((($1103)-(2))|0);
      $bits=$1104;
      __label__ = 254; break;
    case 254: 
      __label__ = 565; break;
    case 255: 
      __label__ = 256; break;
    case 256: 
      var $1108=$bits;
      var $1109=$1108 & 7;
      var $1110=$hold;
      var $1111=$1110 >>> (($1109)>>>0);
      $hold=$1111;
      var $1112=$bits;
      var $1113=$1112 & 7;
      var $1114=$bits;
      var $1115=((($1114)-($1113))|0);
      $bits=$1115;
      __label__ = 257; break;
    case 257: 
      __label__ = 258; break;
    case 258: 
      __label__ = 259; break;
    case 259: 
      var $1119=$bits;
      var $1120=(($1119)>>>0) < 32;
      if ($1120) { __label__ = 260; break; } else { __label__ = 265; break; }
    case 260: 
      __label__ = 261; break;
    case 261: 
      var $1123=$have;
      var $1124=(($1123)|0)==0;
      if ($1124) { __label__ = 262; break; } else { __label__ = 263; break; }
    case 262: 
      __label__ = 566; break;
    case 263: 
      var $1127=$have;
      var $1128=((($1127)-(1))|0);
      $have=$1128;
      var $1129=$next;
      var $1130=(($1129+1)|0);
      $next=$1130;
      var $1131=HEAPU8[($1129)];
      var $1132=(($1131)&255);
      var $1133=$bits;
      var $1134=$1132 << $1133;
      var $1135=$hold;
      var $1136=((($1135)+($1134))|0);
      $hold=$1136;
      var $1137=$bits;
      var $1138=((($1137)+(8))|0);
      $bits=$1138;
      __label__ = 264; break;
    case 264: 
      __label__ = 259; break;
    case 265: 
      __label__ = 266; break;
    case 266: 
      var $1142=$hold;
      var $1143=$1142 & 65535;
      var $1144=$hold;
      var $1145=$1144 >>> 16;
      var $1146=$1145 ^ 65535;
      var $1147=(($1143)|0)!=(($1146)|0);
      if ($1147) { __label__ = 267; break; } else { __label__ = 268; break; }
    case 267: 
      var $1149=$2;
      var $1150=(($1149+24)|0);
      HEAP32[(($1150)>>2)]=((STRING_TABLE.__str741)|0);
      var $1151=$state;
      var $1152=(($1151)|0);
      HEAP32[(($1152)>>2)]=29;
      __label__ = 565; break;
    case 268: 
      var $1154=$hold;
      var $1155=$1154 & 65535;
      var $1156=$state;
      var $1157=(($1156+64)|0);
      HEAP32[(($1157)>>2)]=$1155;
      __label__ = 269; break;
    case 269: 
      $hold=0;
      $bits=0;
      __label__ = 270; break;
    case 270: 
      var $1160=$state;
      var $1161=(($1160)|0);
      HEAP32[(($1161)>>2)]=14;
      var $1162=$3;
      var $1163=(($1162)|0)==6;
      if ($1163) { __label__ = 271; break; } else { __label__ = 272; break; }
    case 271: 
      __label__ = 566; break;
    case 272: 
      __label__ = 273; break;
    case 273: 
      var $1167=$state;
      var $1168=(($1167)|0);
      HEAP32[(($1168)>>2)]=15;
      __label__ = 274; break;
    case 274: 
      var $1170=$state;
      var $1171=(($1170+64)|0);
      var $1172=HEAP32[(($1171)>>2)];
      $copy=$1172;
      var $1173=$copy;
      var $1174=(($1173)|0)!=0;
      if ($1174) { __label__ = 275; break; } else { __label__ = 282; break; }
    case 275: 
      var $1176=$copy;
      var $1177=$have;
      var $1178=(($1176)>>>0) > (($1177)>>>0);
      if ($1178) { __label__ = 276; break; } else { __label__ = 277; break; }
    case 276: 
      var $1180=$have;
      $copy=$1180;
      __label__ = 277; break;
    case 277: 
      var $1182=$copy;
      var $1183=$left;
      var $1184=(($1182)>>>0) > (($1183)>>>0);
      if ($1184) { __label__ = 278; break; } else { __label__ = 279; break; }
    case 278: 
      var $1186=$left;
      $copy=$1186;
      __label__ = 279; break;
    case 279: 
      var $1188=$copy;
      var $1189=(($1188)|0)==0;
      if ($1189) { __label__ = 280; break; } else { __label__ = 281; break; }
    case 280: 
      __label__ = 566; break;
    case 281: 
      var $1192=$put;
      var $1193=$next;
      var $1194=$copy;
      assert($1194 % 1 === 0, 'memcpy given ' + $1194 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');_memcpy($1192, $1193, $1194, 1);
      var $1195=$copy;
      var $1196=$have;
      var $1197=((($1196)-($1195))|0);
      $have=$1197;
      var $1198=$copy;
      var $1199=$next;
      var $1200=(($1199+$1198)|0);
      $next=$1200;
      var $1201=$copy;
      var $1202=$left;
      var $1203=((($1202)-($1201))|0);
      $left=$1203;
      var $1204=$copy;
      var $1205=$put;
      var $1206=(($1205+$1204)|0);
      $put=$1206;
      var $1207=$copy;
      var $1208=$state;
      var $1209=(($1208+64)|0);
      var $1210=HEAP32[(($1209)>>2)];
      var $1211=((($1210)-($1207))|0);
      HEAP32[(($1209)>>2)]=$1211;
      __label__ = 565; break;
    case 282: 
      var $1213=$state;
      var $1214=(($1213)|0);
      HEAP32[(($1214)>>2)]=11;
      __label__ = 565; break;
    case 283: 
      __label__ = 284; break;
    case 284: 
      __label__ = 285; break;
    case 285: 
      var $1218=$bits;
      var $1219=(($1218)>>>0) < 14;
      if ($1219) { __label__ = 286; break; } else { __label__ = 291; break; }
    case 286: 
      __label__ = 287; break;
    case 287: 
      var $1222=$have;
      var $1223=(($1222)|0)==0;
      if ($1223) { __label__ = 288; break; } else { __label__ = 289; break; }
    case 288: 
      __label__ = 566; break;
    case 289: 
      var $1226=$have;
      var $1227=((($1226)-(1))|0);
      $have=$1227;
      var $1228=$next;
      var $1229=(($1228+1)|0);
      $next=$1229;
      var $1230=HEAPU8[($1228)];
      var $1231=(($1230)&255);
      var $1232=$bits;
      var $1233=$1231 << $1232;
      var $1234=$hold;
      var $1235=((($1234)+($1233))|0);
      $hold=$1235;
      var $1236=$bits;
      var $1237=((($1236)+(8))|0);
      $bits=$1237;
      __label__ = 290; break;
    case 290: 
      __label__ = 285; break;
    case 291: 
      __label__ = 292; break;
    case 292: 
      var $1241=$hold;
      var $1242=$1241 & 31;
      var $1243=((($1242)+(257))|0);
      var $1244=$state;
      var $1245=(($1244+96)|0);
      HEAP32[(($1245)>>2)]=$1243;
      __label__ = 293; break;
    case 293: 
      var $1247=$hold;
      var $1248=$1247 >>> 5;
      $hold=$1248;
      var $1249=$bits;
      var $1250=((($1249)-(5))|0);
      $bits=$1250;
      __label__ = 294; break;
    case 294: 
      var $1252=$hold;
      var $1253=$1252 & 31;
      var $1254=((($1253)+(1))|0);
      var $1255=$state;
      var $1256=(($1255+100)|0);
      HEAP32[(($1256)>>2)]=$1254;
      __label__ = 295; break;
    case 295: 
      var $1258=$hold;
      var $1259=$1258 >>> 5;
      $hold=$1259;
      var $1260=$bits;
      var $1261=((($1260)-(5))|0);
      $bits=$1261;
      __label__ = 296; break;
    case 296: 
      var $1263=$hold;
      var $1264=$1263 & 15;
      var $1265=((($1264)+(4))|0);
      var $1266=$state;
      var $1267=(($1266+92)|0);
      HEAP32[(($1267)>>2)]=$1265;
      __label__ = 297; break;
    case 297: 
      var $1269=$hold;
      var $1270=$1269 >>> 4;
      $hold=$1270;
      var $1271=$bits;
      var $1272=((($1271)-(4))|0);
      $bits=$1272;
      __label__ = 298; break;
    case 298: 
      var $1274=$state;
      var $1275=(($1274+96)|0);
      var $1276=HEAPU32[(($1275)>>2)];
      var $1277=(($1276)>>>0) > 286;
      if ($1277) { __label__ = 300; break; } else { __label__ = 299; break; }
    case 299: 
      var $1279=$state;
      var $1280=(($1279+100)|0);
      var $1281=HEAPU32[(($1280)>>2)];
      var $1282=(($1281)>>>0) > 30;
      if ($1282) { __label__ = 300; break; } else { __label__ = 301; break; }
    case 300: 
      var $1284=$2;
      var $1285=(($1284+24)|0);
      HEAP32[(($1285)>>2)]=((STRING_TABLE.__str842)|0);
      var $1286=$state;
      var $1287=(($1286)|0);
      HEAP32[(($1287)>>2)]=29;
      __label__ = 565; break;
    case 301: 
      var $1289=$state;
      var $1290=(($1289+104)|0);
      HEAP32[(($1290)>>2)]=0;
      var $1291=$state;
      var $1292=(($1291)|0);
      HEAP32[(($1292)>>2)]=17;
      __label__ = 302; break;
    case 302: 
      __label__ = 303; break;
    case 303: 
      var $1295=$state;
      var $1296=(($1295+104)|0);
      var $1297=HEAPU32[(($1296)>>2)];
      var $1298=$state;
      var $1299=(($1298+92)|0);
      var $1300=HEAPU32[(($1299)>>2)];
      var $1301=(($1297)>>>0) < (($1300)>>>0);
      if ($1301) { __label__ = 304; break; } else { __label__ = 316; break; }
    case 304: 
      __label__ = 305; break;
    case 305: 
      __label__ = 306; break;
    case 306: 
      var $1305=$bits;
      var $1306=(($1305)>>>0) < 3;
      if ($1306) { __label__ = 307; break; } else { __label__ = 312; break; }
    case 307: 
      __label__ = 308; break;
    case 308: 
      var $1309=$have;
      var $1310=(($1309)|0)==0;
      if ($1310) { __label__ = 309; break; } else { __label__ = 310; break; }
    case 309: 
      __label__ = 566; break;
    case 310: 
      var $1313=$have;
      var $1314=((($1313)-(1))|0);
      $have=$1314;
      var $1315=$next;
      var $1316=(($1315+1)|0);
      $next=$1316;
      var $1317=HEAPU8[($1315)];
      var $1318=(($1317)&255);
      var $1319=$bits;
      var $1320=$1318 << $1319;
      var $1321=$hold;
      var $1322=((($1321)+($1320))|0);
      $hold=$1322;
      var $1323=$bits;
      var $1324=((($1323)+(8))|0);
      $bits=$1324;
      __label__ = 311; break;
    case 311: 
      __label__ = 306; break;
    case 312: 
      __label__ = 313; break;
    case 313: 
      var $1328=$hold;
      var $1329=$1328 & 7;
      var $1330=(($1329) & 65535);
      var $1331=$state;
      var $1332=(($1331+104)|0);
      var $1333=HEAP32[(($1332)>>2)];
      var $1334=((($1333)+(1))|0);
      HEAP32[(($1332)>>2)]=$1334;
      var $1335=((_inflate_order+($1333<<1))|0);
      var $1336=HEAPU16[(($1335)>>1)];
      var $1337=(($1336)&65535);
      var $1338=$state;
      var $1339=(($1338+112)|0);
      var $1340=(($1339+($1337<<1))|0);
      HEAP16[(($1340)>>1)]=$1330;
      __label__ = 314; break;
    case 314: 
      var $1342=$hold;
      var $1343=$1342 >>> 3;
      $hold=$1343;
      var $1344=$bits;
      var $1345=((($1344)-(3))|0);
      $bits=$1345;
      __label__ = 315; break;
    case 315: 
      __label__ = 303; break;
    case 316: 
      __label__ = 317; break;
    case 317: 
      var $1349=$state;
      var $1350=(($1349+104)|0);
      var $1351=HEAPU32[(($1350)>>2)];
      var $1352=(($1351)>>>0) < 19;
      if ($1352) { __label__ = 318; break; } else { __label__ = 319; break; }
    case 318: 
      var $1354=$state;
      var $1355=(($1354+104)|0);
      var $1356=HEAP32[(($1355)>>2)];
      var $1357=((($1356)+(1))|0);
      HEAP32[(($1355)>>2)]=$1357;
      var $1358=((_inflate_order+($1356<<1))|0);
      var $1359=HEAPU16[(($1358)>>1)];
      var $1360=(($1359)&65535);
      var $1361=$state;
      var $1362=(($1361+112)|0);
      var $1363=(($1362+($1360<<1))|0);
      HEAP16[(($1363)>>1)]=0;
      __label__ = 317; break;
    case 319: 
      var $1365=$state;
      var $1366=(($1365+1328)|0);
      var $1367=(($1366)|0);
      var $1368=$state;
      var $1369=(($1368+108)|0);
      HEAP32[(($1369)>>2)]=$1367;
      var $1370=$state;
      var $1371=(($1370+108)|0);
      var $1372=HEAP32[(($1371)>>2)];
      var $1373=$state;
      var $1374=(($1373+76)|0);
      HEAP32[(($1374)>>2)]=$1372;
      var $1375=$state;
      var $1376=(($1375+84)|0);
      HEAP32[(($1376)>>2)]=7;
      var $1377=$state;
      var $1378=(($1377+112)|0);
      var $1379=(($1378)|0);
      var $1380=$state;
      var $1381=(($1380+108)|0);
      var $1382=$state;
      var $1383=(($1382+84)|0);
      var $1384=$state;
      var $1385=(($1384+752)|0);
      var $1386=(($1385)|0);
      var $1387=_inflate_table(0, $1379, 19, $1381, $1383, $1386);
      $ret=$1387;
      var $1388=$ret;
      var $1389=(($1388)|0)!=0;
      if ($1389) { __label__ = 320; break; } else { __label__ = 321; break; }
    case 320: 
      var $1391=$2;
      var $1392=(($1391+24)|0);
      HEAP32[(($1392)>>2)]=((STRING_TABLE.__str943)|0);
      var $1393=$state;
      var $1394=(($1393)|0);
      HEAP32[(($1394)>>2)]=29;
      __label__ = 565; break;
    case 321: 
      var $1396=$state;
      var $1397=(($1396+104)|0);
      HEAP32[(($1397)>>2)]=0;
      var $1398=$state;
      var $1399=(($1398)|0);
      HEAP32[(($1399)>>2)]=18;
      __label__ = 322; break;
    case 322: 
      __label__ = 323; break;
    case 323: 
      var $1402=$state;
      var $1403=(($1402+104)|0);
      var $1404=HEAPU32[(($1403)>>2)];
      var $1405=$state;
      var $1406=(($1405+96)|0);
      var $1407=HEAP32[(($1406)>>2)];
      var $1408=$state;
      var $1409=(($1408+100)|0);
      var $1410=HEAP32[(($1409)>>2)];
      var $1411=((($1407)+($1410))|0);
      var $1412=(($1404)>>>0) < (($1411)>>>0);
      if ($1412) { __label__ = 324; break; } else { __label__ = 390; break; }
    case 324: 
      __label__ = 325; break;
    case 325: 
      var $1415=$hold;
      var $1416=$state;
      var $1417=(($1416+84)|0);
      var $1418=HEAP32[(($1417)>>2)];
      var $1419=1 << $1418;
      var $1420=((($1419)-(1))|0);
      var $1421=$1415 & $1420;
      var $1422=$state;
      var $1423=(($1422+76)|0);
      var $1424=HEAP32[(($1423)>>2)];
      var $1425=(($1424+($1421<<2))|0);
      var $1426=$here;
      var $1427=$1425;
      assert(4 % 1 === 0, 'memcpy given ' + 4 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP16[(($1426)>>1)]=HEAP16[(($1427)>>1)];HEAP16[((($1426)+(2))>>1)]=HEAP16[((($1427)+(2))>>1)];
      var $1428=(($here+1)|0);
      var $1429=HEAPU8[($1428)];
      var $1430=(($1429)&255);
      var $1431=$bits;
      var $1432=(($1430)>>>0) <= (($1431)>>>0);
      if ($1432) { __label__ = 326; break; } else { __label__ = 327; break; }
    case 326: 
      __label__ = 332; break;
    case 327: 
      __label__ = 328; break;
    case 328: 
      var $1436=$have;
      var $1437=(($1436)|0)==0;
      if ($1437) { __label__ = 329; break; } else { __label__ = 330; break; }
    case 329: 
      __label__ = 566; break;
    case 330: 
      var $1440=$have;
      var $1441=((($1440)-(1))|0);
      $have=$1441;
      var $1442=$next;
      var $1443=(($1442+1)|0);
      $next=$1443;
      var $1444=HEAPU8[($1442)];
      var $1445=(($1444)&255);
      var $1446=$bits;
      var $1447=$1445 << $1446;
      var $1448=$hold;
      var $1449=((($1448)+($1447))|0);
      $hold=$1449;
      var $1450=$bits;
      var $1451=((($1450)+(8))|0);
      $bits=$1451;
      __label__ = 331; break;
    case 331: 
      __label__ = 325; break;
    case 332: 
      var $1454=(($here+2)|0);
      var $1455=HEAPU16[(($1454)>>1)];
      var $1456=(($1455)&65535);
      var $1457=(($1456)|0) < 16;
      if ($1457) { __label__ = 333; break; } else { __label__ = 336; break; }
    case 333: 
      __label__ = 334; break;
    case 334: 
      var $1460=(($here+1)|0);
      var $1461=HEAPU8[($1460)];
      var $1462=(($1461)&255);
      var $1463=$hold;
      var $1464=$1463 >>> (($1462)>>>0);
      $hold=$1464;
      var $1465=(($here+1)|0);
      var $1466=HEAPU8[($1465)];
      var $1467=(($1466)&255);
      var $1468=$bits;
      var $1469=((($1468)-($1467))|0);
      $bits=$1469;
      __label__ = 335; break;
    case 335: 
      var $1471=(($here+2)|0);
      var $1472=HEAP16[(($1471)>>1)];
      var $1473=$state;
      var $1474=(($1473+104)|0);
      var $1475=HEAP32[(($1474)>>2)];
      var $1476=((($1475)+(1))|0);
      HEAP32[(($1474)>>2)]=$1476;
      var $1477=$state;
      var $1478=(($1477+112)|0);
      var $1479=(($1478+($1475<<1))|0);
      HEAP16[(($1479)>>1)]=$1472;
      __label__ = 389; break;
    case 336: 
      var $1481=(($here+2)|0);
      var $1482=HEAPU16[(($1481)>>1)];
      var $1483=(($1482)&65535);
      var $1484=(($1483)|0)==16;
      if ($1484) { __label__ = 337; break; } else { __label__ = 353; break; }
    case 337: 
      __label__ = 338; break;
    case 338: 
      __label__ = 339; break;
    case 339: 
      var $1488=$bits;
      var $1489=(($here+1)|0);
      var $1490=HEAPU8[($1489)];
      var $1491=(($1490)&255);
      var $1492=((($1491)+(2))|0);
      var $1493=(($1488)>>>0) < (($1492)>>>0);
      if ($1493) { __label__ = 340; break; } else { __label__ = 345; break; }
    case 340: 
      __label__ = 341; break;
    case 341: 
      var $1496=$have;
      var $1497=(($1496)|0)==0;
      if ($1497) { __label__ = 342; break; } else { __label__ = 343; break; }
    case 342: 
      __label__ = 566; break;
    case 343: 
      var $1500=$have;
      var $1501=((($1500)-(1))|0);
      $have=$1501;
      var $1502=$next;
      var $1503=(($1502+1)|0);
      $next=$1503;
      var $1504=HEAPU8[($1502)];
      var $1505=(($1504)&255);
      var $1506=$bits;
      var $1507=$1505 << $1506;
      var $1508=$hold;
      var $1509=((($1508)+($1507))|0);
      $hold=$1509;
      var $1510=$bits;
      var $1511=((($1510)+(8))|0);
      $bits=$1511;
      __label__ = 344; break;
    case 344: 
      __label__ = 339; break;
    case 345: 
      __label__ = 346; break;
    case 346: 
      __label__ = 347; break;
    case 347: 
      var $1516=(($here+1)|0);
      var $1517=HEAPU8[($1516)];
      var $1518=(($1517)&255);
      var $1519=$hold;
      var $1520=$1519 >>> (($1518)>>>0);
      $hold=$1520;
      var $1521=(($here+1)|0);
      var $1522=HEAPU8[($1521)];
      var $1523=(($1522)&255);
      var $1524=$bits;
      var $1525=((($1524)-($1523))|0);
      $bits=$1525;
      __label__ = 348; break;
    case 348: 
      var $1527=$state;
      var $1528=(($1527+104)|0);
      var $1529=HEAP32[(($1528)>>2)];
      var $1530=(($1529)|0)==0;
      if ($1530) { __label__ = 349; break; } else { __label__ = 350; break; }
    case 349: 
      var $1532=$2;
      var $1533=(($1532+24)|0);
      HEAP32[(($1533)>>2)]=((STRING_TABLE.__str1044)|0);
      var $1534=$state;
      var $1535=(($1534)|0);
      HEAP32[(($1535)>>2)]=29;
      __label__ = 390; break;
    case 350: 
      var $1537=$state;
      var $1538=(($1537+104)|0);
      var $1539=HEAP32[(($1538)>>2)];
      var $1540=((($1539)-(1))|0);
      var $1541=$state;
      var $1542=(($1541+112)|0);
      var $1543=(($1542+($1540<<1))|0);
      var $1544=HEAPU16[(($1543)>>1)];
      var $1545=(($1544)&65535);
      $len=$1545;
      var $1546=$hold;
      var $1547=$1546 & 3;
      var $1548=((($1547)+(3))|0);
      $copy=$1548;
      __label__ = 351; break;
    case 351: 
      var $1550=$hold;
      var $1551=$1550 >>> 2;
      $hold=$1551;
      var $1552=$bits;
      var $1553=((($1552)-(2))|0);
      $bits=$1553;
      __label__ = 352; break;
    case 352: 
      __label__ = 383; break;
    case 353: 
      var $1556=(($here+2)|0);
      var $1557=HEAPU16[(($1556)>>1)];
      var $1558=(($1557)&65535);
      var $1559=(($1558)|0)==17;
      if ($1559) { __label__ = 354; break; } else { __label__ = 368; break; }
    case 354: 
      __label__ = 355; break;
    case 355: 
      __label__ = 356; break;
    case 356: 
      var $1563=$bits;
      var $1564=(($here+1)|0);
      var $1565=HEAPU8[($1564)];
      var $1566=(($1565)&255);
      var $1567=((($1566)+(3))|0);
      var $1568=(($1563)>>>0) < (($1567)>>>0);
      if ($1568) { __label__ = 357; break; } else { __label__ = 362; break; }
    case 357: 
      __label__ = 358; break;
    case 358: 
      var $1571=$have;
      var $1572=(($1571)|0)==0;
      if ($1572) { __label__ = 359; break; } else { __label__ = 360; break; }
    case 359: 
      __label__ = 566; break;
    case 360: 
      var $1575=$have;
      var $1576=((($1575)-(1))|0);
      $have=$1576;
      var $1577=$next;
      var $1578=(($1577+1)|0);
      $next=$1578;
      var $1579=HEAPU8[($1577)];
      var $1580=(($1579)&255);
      var $1581=$bits;
      var $1582=$1580 << $1581;
      var $1583=$hold;
      var $1584=((($1583)+($1582))|0);
      $hold=$1584;
      var $1585=$bits;
      var $1586=((($1585)+(8))|0);
      $bits=$1586;
      __label__ = 361; break;
    case 361: 
      __label__ = 356; break;
    case 362: 
      __label__ = 363; break;
    case 363: 
      __label__ = 364; break;
    case 364: 
      var $1591=(($here+1)|0);
      var $1592=HEAPU8[($1591)];
      var $1593=(($1592)&255);
      var $1594=$hold;
      var $1595=$1594 >>> (($1593)>>>0);
      $hold=$1595;
      var $1596=(($here+1)|0);
      var $1597=HEAPU8[($1596)];
      var $1598=(($1597)&255);
      var $1599=$bits;
      var $1600=((($1599)-($1598))|0);
      $bits=$1600;
      __label__ = 365; break;
    case 365: 
      $len=0;
      var $1602=$hold;
      var $1603=$1602 & 7;
      var $1604=((($1603)+(3))|0);
      $copy=$1604;
      __label__ = 366; break;
    case 366: 
      var $1606=$hold;
      var $1607=$1606 >>> 3;
      $hold=$1607;
      var $1608=$bits;
      var $1609=((($1608)-(3))|0);
      $bits=$1609;
      __label__ = 367; break;
    case 367: 
      __label__ = 382; break;
    case 368: 
      __label__ = 369; break;
    case 369: 
      __label__ = 370; break;
    case 370: 
      var $1614=$bits;
      var $1615=(($here+1)|0);
      var $1616=HEAPU8[($1615)];
      var $1617=(($1616)&255);
      var $1618=((($1617)+(7))|0);
      var $1619=(($1614)>>>0) < (($1618)>>>0);
      if ($1619) { __label__ = 371; break; } else { __label__ = 376; break; }
    case 371: 
      __label__ = 372; break;
    case 372: 
      var $1622=$have;
      var $1623=(($1622)|0)==0;
      if ($1623) { __label__ = 373; break; } else { __label__ = 374; break; }
    case 373: 
      __label__ = 566; break;
    case 374: 
      var $1626=$have;
      var $1627=((($1626)-(1))|0);
      $have=$1627;
      var $1628=$next;
      var $1629=(($1628+1)|0);
      $next=$1629;
      var $1630=HEAPU8[($1628)];
      var $1631=(($1630)&255);
      var $1632=$bits;
      var $1633=$1631 << $1632;
      var $1634=$hold;
      var $1635=((($1634)+($1633))|0);
      $hold=$1635;
      var $1636=$bits;
      var $1637=((($1636)+(8))|0);
      $bits=$1637;
      __label__ = 375; break;
    case 375: 
      __label__ = 370; break;
    case 376: 
      __label__ = 377; break;
    case 377: 
      __label__ = 378; break;
    case 378: 
      var $1642=(($here+1)|0);
      var $1643=HEAPU8[($1642)];
      var $1644=(($1643)&255);
      var $1645=$hold;
      var $1646=$1645 >>> (($1644)>>>0);
      $hold=$1646;
      var $1647=(($here+1)|0);
      var $1648=HEAPU8[($1647)];
      var $1649=(($1648)&255);
      var $1650=$bits;
      var $1651=((($1650)-($1649))|0);
      $bits=$1651;
      __label__ = 379; break;
    case 379: 
      $len=0;
      var $1653=$hold;
      var $1654=$1653 & 127;
      var $1655=((($1654)+(11))|0);
      $copy=$1655;
      __label__ = 380; break;
    case 380: 
      var $1657=$hold;
      var $1658=$1657 >>> 7;
      $hold=$1658;
      var $1659=$bits;
      var $1660=((($1659)-(7))|0);
      $bits=$1660;
      __label__ = 381; break;
    case 381: 
      __label__ = 382; break;
    case 382: 
      __label__ = 383; break;
    case 383: 
      var $1664=$state;
      var $1665=(($1664+104)|0);
      var $1666=HEAP32[(($1665)>>2)];
      var $1667=$copy;
      var $1668=((($1666)+($1667))|0);
      var $1669=$state;
      var $1670=(($1669+96)|0);
      var $1671=HEAP32[(($1670)>>2)];
      var $1672=$state;
      var $1673=(($1672+100)|0);
      var $1674=HEAP32[(($1673)>>2)];
      var $1675=((($1671)+($1674))|0);
      var $1676=(($1668)>>>0) > (($1675)>>>0);
      if ($1676) { __label__ = 384; break; } else { __label__ = 385; break; }
    case 384: 
      var $1678=$2;
      var $1679=(($1678+24)|0);
      HEAP32[(($1679)>>2)]=((STRING_TABLE.__str1044)|0);
      var $1680=$state;
      var $1681=(($1680)|0);
      HEAP32[(($1681)>>2)]=29;
      __label__ = 390; break;
    case 385: 
      __label__ = 386; break;
    case 386: 
      var $1684=$copy;
      var $1685=((($1684)-(1))|0);
      $copy=$1685;
      var $1686=(($1684)|0)!=0;
      if ($1686) { __label__ = 387; break; } else { __label__ = 388; break; }
    case 387: 
      var $1688=$len;
      var $1689=(($1688) & 65535);
      var $1690=$state;
      var $1691=(($1690+104)|0);
      var $1692=HEAP32[(($1691)>>2)];
      var $1693=((($1692)+(1))|0);
      HEAP32[(($1691)>>2)]=$1693;
      var $1694=$state;
      var $1695=(($1694+112)|0);
      var $1696=(($1695+($1692<<1))|0);
      HEAP16[(($1696)>>1)]=$1689;
      __label__ = 386; break;
    case 388: 
      __label__ = 389; break;
    case 389: 
      __label__ = 323; break;
    case 390: 
      var $1700=$state;
      var $1701=(($1700)|0);
      var $1702=HEAP32[(($1701)>>2)];
      var $1703=(($1702)|0)==29;
      if ($1703) { __label__ = 391; break; } else { __label__ = 392; break; }
    case 391: 
      __label__ = 565; break;
    case 392: 
      var $1706=$state;
      var $1707=(($1706+112)|0);
      var $1708=(($1707+512)|0);
      var $1709=HEAPU16[(($1708)>>1)];
      var $1710=(($1709)&65535);
      var $1711=(($1710)|0)==0;
      if ($1711) { __label__ = 393; break; } else { __label__ = 394; break; }
    case 393: 
      var $1713=$2;
      var $1714=(($1713+24)|0);
      HEAP32[(($1714)>>2)]=((STRING_TABLE.__str1145)|0);
      var $1715=$state;
      var $1716=(($1715)|0);
      HEAP32[(($1716)>>2)]=29;
      __label__ = 565; break;
    case 394: 
      var $1718=$state;
      var $1719=(($1718+1328)|0);
      var $1720=(($1719)|0);
      var $1721=$state;
      var $1722=(($1721+108)|0);
      HEAP32[(($1722)>>2)]=$1720;
      var $1723=$state;
      var $1724=(($1723+108)|0);
      var $1725=HEAP32[(($1724)>>2)];
      var $1726=$state;
      var $1727=(($1726+76)|0);
      HEAP32[(($1727)>>2)]=$1725;
      var $1728=$state;
      var $1729=(($1728+84)|0);
      HEAP32[(($1729)>>2)]=9;
      var $1730=$state;
      var $1731=(($1730+112)|0);
      var $1732=(($1731)|0);
      var $1733=$state;
      var $1734=(($1733+96)|0);
      var $1735=HEAP32[(($1734)>>2)];
      var $1736=$state;
      var $1737=(($1736+108)|0);
      var $1738=$state;
      var $1739=(($1738+84)|0);
      var $1740=$state;
      var $1741=(($1740+752)|0);
      var $1742=(($1741)|0);
      var $1743=_inflate_table(1, $1732, $1735, $1737, $1739, $1742);
      $ret=$1743;
      var $1744=$ret;
      var $1745=(($1744)|0)!=0;
      if ($1745) { __label__ = 395; break; } else { __label__ = 396; break; }
    case 395: 
      var $1747=$2;
      var $1748=(($1747+24)|0);
      HEAP32[(($1748)>>2)]=((STRING_TABLE.__str12)|0);
      var $1749=$state;
      var $1750=(($1749)|0);
      HEAP32[(($1750)>>2)]=29;
      __label__ = 565; break;
    case 396: 
      var $1752=$state;
      var $1753=(($1752+108)|0);
      var $1754=HEAP32[(($1753)>>2)];
      var $1755=$state;
      var $1756=(($1755+80)|0);
      HEAP32[(($1756)>>2)]=$1754;
      var $1757=$state;
      var $1758=(($1757+88)|0);
      HEAP32[(($1758)>>2)]=6;
      var $1759=$state;
      var $1760=(($1759+112)|0);
      var $1761=(($1760)|0);
      var $1762=$state;
      var $1763=(($1762+96)|0);
      var $1764=HEAP32[(($1763)>>2)];
      var $1765=(($1761+($1764<<1))|0);
      var $1766=$state;
      var $1767=(($1766+100)|0);
      var $1768=HEAP32[(($1767)>>2)];
      var $1769=$state;
      var $1770=(($1769+108)|0);
      var $1771=$state;
      var $1772=(($1771+88)|0);
      var $1773=$state;
      var $1774=(($1773+752)|0);
      var $1775=(($1774)|0);
      var $1776=_inflate_table(2, $1765, $1768, $1770, $1772, $1775);
      $ret=$1776;
      var $1777=$ret;
      var $1778=(($1777)|0)!=0;
      if ($1778) { __label__ = 397; break; } else { __label__ = 398; break; }
    case 397: 
      var $1780=$2;
      var $1781=(($1780+24)|0);
      HEAP32[(($1781)>>2)]=((STRING_TABLE.__str13)|0);
      var $1782=$state;
      var $1783=(($1782)|0);
      HEAP32[(($1783)>>2)]=29;
      __label__ = 565; break;
    case 398: 
      var $1785=$state;
      var $1786=(($1785)|0);
      HEAP32[(($1786)>>2)]=19;
      var $1787=$3;
      var $1788=(($1787)|0)==6;
      if ($1788) { __label__ = 399; break; } else { __label__ = 400; break; }
    case 399: 
      __label__ = 566; break;
    case 400: 
      __label__ = 401; break;
    case 401: 
      var $1792=$state;
      var $1793=(($1792)|0);
      HEAP32[(($1793)>>2)]=20;
      __label__ = 402; break;
    case 402: 
      var $1795=$have;
      var $1796=(($1795)>>>0) >= 6;
      if ($1796) { __label__ = 403; break; } else { __label__ = 411; break; }
    case 403: 
      var $1798=$left;
      var $1799=(($1798)>>>0) >= 258;
      if ($1799) { __label__ = 404; break; } else { __label__ = 411; break; }
    case 404: 
      __label__ = 405; break;
    case 405: 
      var $1802=$put;
      var $1803=$2;
      var $1804=(($1803+12)|0);
      HEAP32[(($1804)>>2)]=$1802;
      var $1805=$left;
      var $1806=$2;
      var $1807=(($1806+16)|0);
      HEAP32[(($1807)>>2)]=$1805;
      var $1808=$next;
      var $1809=$2;
      var $1810=(($1809)|0);
      HEAP32[(($1810)>>2)]=$1808;
      var $1811=$have;
      var $1812=$2;
      var $1813=(($1812+4)|0);
      HEAP32[(($1813)>>2)]=$1811;
      var $1814=$hold;
      var $1815=$state;
      var $1816=(($1815+56)|0);
      HEAP32[(($1816)>>2)]=$1814;
      var $1817=$bits;
      var $1818=$state;
      var $1819=(($1818+60)|0);
      HEAP32[(($1819)>>2)]=$1817;
      __label__ = 406; break;
    case 406: 
      var $1821=$2;
      var $1822=$out;
      _inflate_fast($1821, $1822);
      __label__ = 407; break;
    case 407: 
      var $1824=$2;
      var $1825=(($1824+12)|0);
      var $1826=HEAP32[(($1825)>>2)];
      $put=$1826;
      var $1827=$2;
      var $1828=(($1827+16)|0);
      var $1829=HEAP32[(($1828)>>2)];
      $left=$1829;
      var $1830=$2;
      var $1831=(($1830)|0);
      var $1832=HEAP32[(($1831)>>2)];
      $next=$1832;
      var $1833=$2;
      var $1834=(($1833+4)|0);
      var $1835=HEAP32[(($1834)>>2)];
      $have=$1835;
      var $1836=$state;
      var $1837=(($1836+56)|0);
      var $1838=HEAP32[(($1837)>>2)];
      $hold=$1838;
      var $1839=$state;
      var $1840=(($1839+60)|0);
      var $1841=HEAP32[(($1840)>>2)];
      $bits=$1841;
      __label__ = 408; break;
    case 408: 
      var $1843=$state;
      var $1844=(($1843)|0);
      var $1845=HEAP32[(($1844)>>2)];
      var $1846=(($1845)|0)==11;
      if ($1846) { __label__ = 409; break; } else { __label__ = 410; break; }
    case 409: 
      var $1848=$state;
      var $1849=(($1848+7108)|0);
      HEAP32[(($1849)>>2)]=-1;
      __label__ = 410; break;
    case 410: 
      __label__ = 565; break;
    case 411: 
      var $1852=$state;
      var $1853=(($1852+7108)|0);
      HEAP32[(($1853)>>2)]=0;
      __label__ = 412; break;
    case 412: 
      var $1855=$hold;
      var $1856=$state;
      var $1857=(($1856+84)|0);
      var $1858=HEAP32[(($1857)>>2)];
      var $1859=1 << $1858;
      var $1860=((($1859)-(1))|0);
      var $1861=$1855 & $1860;
      var $1862=$state;
      var $1863=(($1862+76)|0);
      var $1864=HEAP32[(($1863)>>2)];
      var $1865=(($1864+($1861<<2))|0);
      var $1866=$here;
      var $1867=$1865;
      assert(4 % 1 === 0, 'memcpy given ' + 4 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP16[(($1866)>>1)]=HEAP16[(($1867)>>1)];HEAP16[((($1866)+(2))>>1)]=HEAP16[((($1867)+(2))>>1)];
      var $1868=(($here+1)|0);
      var $1869=HEAPU8[($1868)];
      var $1870=(($1869)&255);
      var $1871=$bits;
      var $1872=(($1870)>>>0) <= (($1871)>>>0);
      if ($1872) { __label__ = 413; break; } else { __label__ = 414; break; }
    case 413: 
      __label__ = 419; break;
    case 414: 
      __label__ = 415; break;
    case 415: 
      var $1876=$have;
      var $1877=(($1876)|0)==0;
      if ($1877) { __label__ = 416; break; } else { __label__ = 417; break; }
    case 416: 
      __label__ = 566; break;
    case 417: 
      var $1880=$have;
      var $1881=((($1880)-(1))|0);
      $have=$1881;
      var $1882=$next;
      var $1883=(($1882+1)|0);
      $next=$1883;
      var $1884=HEAPU8[($1882)];
      var $1885=(($1884)&255);
      var $1886=$bits;
      var $1887=$1885 << $1886;
      var $1888=$hold;
      var $1889=((($1888)+($1887))|0);
      $hold=$1889;
      var $1890=$bits;
      var $1891=((($1890)+(8))|0);
      $bits=$1891;
      __label__ = 418; break;
    case 418: 
      __label__ = 412; break;
    case 419: 
      var $1894=(($here)|0);
      var $1895=HEAPU8[($1894)];
      var $1896=(($1895)&255);
      var $1897=(($1896)|0)!=0;
      if ($1897) { __label__ = 420; break; } else { __label__ = 432; break; }
    case 420: 
      var $1899=(($here)|0);
      var $1900=HEAPU8[($1899)];
      var $1901=(($1900)&255);
      var $1902=$1901 & 240;
      var $1903=(($1902)|0)==0;
      if ($1903) { __label__ = 421; break; } else { __label__ = 432; break; }
    case 421: 
      var $1905=$last;
      var $1906=$here;
      assert(4 % 1 === 0, 'memcpy given ' + 4 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP16[(($1905)>>1)]=HEAP16[(($1906)>>1)];HEAP16[((($1905)+(2))>>1)]=HEAP16[((($1906)+(2))>>1)];
      __label__ = 422; break;
    case 422: 
      var $1908=(($last+2)|0);
      var $1909=HEAPU16[(($1908)>>1)];
      var $1910=(($1909)&65535);
      var $1911=$hold;
      var $1912=(($last+1)|0);
      var $1913=HEAPU8[($1912)];
      var $1914=(($1913)&255);
      var $1915=(($last)|0);
      var $1916=HEAPU8[($1915)];
      var $1917=(($1916)&255);
      var $1918=((($1914)+($1917))|0);
      var $1919=1 << $1918;
      var $1920=((($1919)-(1))|0);
      var $1921=$1911 & $1920;
      var $1922=(($last+1)|0);
      var $1923=HEAPU8[($1922)];
      var $1924=(($1923)&255);
      var $1925=$1921 >>> (($1924)>>>0);
      var $1926=((($1910)+($1925))|0);
      var $1927=$state;
      var $1928=(($1927+76)|0);
      var $1929=HEAP32[(($1928)>>2)];
      var $1930=(($1929+($1926<<2))|0);
      var $1931=$here;
      var $1932=$1930;
      assert(4 % 1 === 0, 'memcpy given ' + 4 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP16[(($1931)>>1)]=HEAP16[(($1932)>>1)];HEAP16[((($1931)+(2))>>1)]=HEAP16[((($1932)+(2))>>1)];
      var $1933=(($last+1)|0);
      var $1934=HEAPU8[($1933)];
      var $1935=(($1934)&255);
      var $1936=(($here+1)|0);
      var $1937=HEAPU8[($1936)];
      var $1938=(($1937)&255);
      var $1939=((($1935)+($1938))|0);
      var $1940=$bits;
      var $1941=(($1939)>>>0) <= (($1940)>>>0);
      if ($1941) { __label__ = 423; break; } else { __label__ = 424; break; }
    case 423: 
      __label__ = 429; break;
    case 424: 
      __label__ = 425; break;
    case 425: 
      var $1945=$have;
      var $1946=(($1945)|0)==0;
      if ($1946) { __label__ = 426; break; } else { __label__ = 427; break; }
    case 426: 
      __label__ = 566; break;
    case 427: 
      var $1949=$have;
      var $1950=((($1949)-(1))|0);
      $have=$1950;
      var $1951=$next;
      var $1952=(($1951+1)|0);
      $next=$1952;
      var $1953=HEAPU8[($1951)];
      var $1954=(($1953)&255);
      var $1955=$bits;
      var $1956=$1954 << $1955;
      var $1957=$hold;
      var $1958=((($1957)+($1956))|0);
      $hold=$1958;
      var $1959=$bits;
      var $1960=((($1959)+(8))|0);
      $bits=$1960;
      __label__ = 428; break;
    case 428: 
      __label__ = 422; break;
    case 429: 
      __label__ = 430; break;
    case 430: 
      var $1964=(($last+1)|0);
      var $1965=HEAPU8[($1964)];
      var $1966=(($1965)&255);
      var $1967=$hold;
      var $1968=$1967 >>> (($1966)>>>0);
      $hold=$1968;
      var $1969=(($last+1)|0);
      var $1970=HEAPU8[($1969)];
      var $1971=(($1970)&255);
      var $1972=$bits;
      var $1973=((($1972)-($1971))|0);
      $bits=$1973;
      __label__ = 431; break;
    case 431: 
      var $1975=(($last+1)|0);
      var $1976=HEAPU8[($1975)];
      var $1977=(($1976)&255);
      var $1978=$state;
      var $1979=(($1978+7108)|0);
      var $1980=HEAP32[(($1979)>>2)];
      var $1981=((($1980)+($1977))|0);
      HEAP32[(($1979)>>2)]=$1981;
      __label__ = 432; break;
    case 432: 
      __label__ = 433; break;
    case 433: 
      var $1984=(($here+1)|0);
      var $1985=HEAPU8[($1984)];
      var $1986=(($1985)&255);
      var $1987=$hold;
      var $1988=$1987 >>> (($1986)>>>0);
      $hold=$1988;
      var $1989=(($here+1)|0);
      var $1990=HEAPU8[($1989)];
      var $1991=(($1990)&255);
      var $1992=$bits;
      var $1993=((($1992)-($1991))|0);
      $bits=$1993;
      __label__ = 434; break;
    case 434: 
      var $1995=(($here+1)|0);
      var $1996=HEAPU8[($1995)];
      var $1997=(($1996)&255);
      var $1998=$state;
      var $1999=(($1998+7108)|0);
      var $2000=HEAP32[(($1999)>>2)];
      var $2001=((($2000)+($1997))|0);
      HEAP32[(($1999)>>2)]=$2001;
      var $2002=(($here+2)|0);
      var $2003=HEAPU16[(($2002)>>1)];
      var $2004=(($2003)&65535);
      var $2005=$state;
      var $2006=(($2005+64)|0);
      HEAP32[(($2006)>>2)]=$2004;
      var $2007=(($here)|0);
      var $2008=HEAPU8[($2007)];
      var $2009=(($2008)&255);
      var $2010=(($2009)|0)==0;
      if ($2010) { __label__ = 435; break; } else { __label__ = 436; break; }
    case 435: 
      var $2012=$state;
      var $2013=(($2012)|0);
      HEAP32[(($2013)>>2)]=25;
      __label__ = 565; break;
    case 436: 
      var $2015=(($here)|0);
      var $2016=HEAPU8[($2015)];
      var $2017=(($2016)&255);
      var $2018=$2017 & 32;
      var $2019=(($2018)|0)!=0;
      if ($2019) { __label__ = 437; break; } else { __label__ = 438; break; }
    case 437: 
      var $2021=$state;
      var $2022=(($2021+7108)|0);
      HEAP32[(($2022)>>2)]=-1;
      var $2023=$state;
      var $2024=(($2023)|0);
      HEAP32[(($2024)>>2)]=11;
      __label__ = 565; break;
    case 438: 
      var $2026=(($here)|0);
      var $2027=HEAPU8[($2026)];
      var $2028=(($2027)&255);
      var $2029=$2028 & 64;
      var $2030=(($2029)|0)!=0;
      if ($2030) { __label__ = 439; break; } else { __label__ = 440; break; }
    case 439: 
      var $2032=$2;
      var $2033=(($2032+24)|0);
      HEAP32[(($2033)>>2)]=((STRING_TABLE.__str1446)|0);
      var $2034=$state;
      var $2035=(($2034)|0);
      HEAP32[(($2035)>>2)]=29;
      __label__ = 565; break;
    case 440: 
      var $2037=(($here)|0);
      var $2038=HEAPU8[($2037)];
      var $2039=(($2038)&255);
      var $2040=$2039 & 15;
      var $2041=$state;
      var $2042=(($2041+72)|0);
      HEAP32[(($2042)>>2)]=$2040;
      var $2043=$state;
      var $2044=(($2043)|0);
      HEAP32[(($2044)>>2)]=21;
      __label__ = 441; break;
    case 441: 
      var $2046=$state;
      var $2047=(($2046+72)|0);
      var $2048=HEAP32[(($2047)>>2)];
      var $2049=(($2048)|0)!=0;
      if ($2049) { __label__ = 442; break; } else { __label__ = 454; break; }
    case 442: 
      __label__ = 443; break;
    case 443: 
      __label__ = 444; break;
    case 444: 
      var $2053=$bits;
      var $2054=$state;
      var $2055=(($2054+72)|0);
      var $2056=HEAPU32[(($2055)>>2)];
      var $2057=(($2053)>>>0) < (($2056)>>>0);
      if ($2057) { __label__ = 445; break; } else { __label__ = 450; break; }
    case 445: 
      __label__ = 446; break;
    case 446: 
      var $2060=$have;
      var $2061=(($2060)|0)==0;
      if ($2061) { __label__ = 447; break; } else { __label__ = 448; break; }
    case 447: 
      __label__ = 566; break;
    case 448: 
      var $2064=$have;
      var $2065=((($2064)-(1))|0);
      $have=$2065;
      var $2066=$next;
      var $2067=(($2066+1)|0);
      $next=$2067;
      var $2068=HEAPU8[($2066)];
      var $2069=(($2068)&255);
      var $2070=$bits;
      var $2071=$2069 << $2070;
      var $2072=$hold;
      var $2073=((($2072)+($2071))|0);
      $hold=$2073;
      var $2074=$bits;
      var $2075=((($2074)+(8))|0);
      $bits=$2075;
      __label__ = 449; break;
    case 449: 
      __label__ = 444; break;
    case 450: 
      __label__ = 451; break;
    case 451: 
      var $2079=$hold;
      var $2080=$state;
      var $2081=(($2080+72)|0);
      var $2082=HEAP32[(($2081)>>2)];
      var $2083=1 << $2082;
      var $2084=((($2083)-(1))|0);
      var $2085=$2079 & $2084;
      var $2086=$state;
      var $2087=(($2086+64)|0);
      var $2088=HEAP32[(($2087)>>2)];
      var $2089=((($2088)+($2085))|0);
      HEAP32[(($2087)>>2)]=$2089;
      __label__ = 452; break;
    case 452: 
      var $2091=$state;
      var $2092=(($2091+72)|0);
      var $2093=HEAPU32[(($2092)>>2)];
      var $2094=$hold;
      var $2095=$2094 >>> (($2093)>>>0);
      $hold=$2095;
      var $2096=$state;
      var $2097=(($2096+72)|0);
      var $2098=HEAP32[(($2097)>>2)];
      var $2099=$bits;
      var $2100=((($2099)-($2098))|0);
      $bits=$2100;
      __label__ = 453; break;
    case 453: 
      var $2102=$state;
      var $2103=(($2102+72)|0);
      var $2104=HEAP32[(($2103)>>2)];
      var $2105=$state;
      var $2106=(($2105+7108)|0);
      var $2107=HEAP32[(($2106)>>2)];
      var $2108=((($2107)+($2104))|0);
      HEAP32[(($2106)>>2)]=$2108;
      __label__ = 454; break;
    case 454: 
      var $2110=$state;
      var $2111=(($2110+64)|0);
      var $2112=HEAP32[(($2111)>>2)];
      var $2113=$state;
      var $2114=(($2113+7112)|0);
      HEAP32[(($2114)>>2)]=$2112;
      var $2115=$state;
      var $2116=(($2115)|0);
      HEAP32[(($2116)>>2)]=22;
      __label__ = 455; break;
    case 455: 
      __label__ = 456; break;
    case 456: 
      var $2119=$hold;
      var $2120=$state;
      var $2121=(($2120+88)|0);
      var $2122=HEAP32[(($2121)>>2)];
      var $2123=1 << $2122;
      var $2124=((($2123)-(1))|0);
      var $2125=$2119 & $2124;
      var $2126=$state;
      var $2127=(($2126+80)|0);
      var $2128=HEAP32[(($2127)>>2)];
      var $2129=(($2128+($2125<<2))|0);
      var $2130=$here;
      var $2131=$2129;
      assert(4 % 1 === 0, 'memcpy given ' + 4 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP16[(($2130)>>1)]=HEAP16[(($2131)>>1)];HEAP16[((($2130)+(2))>>1)]=HEAP16[((($2131)+(2))>>1)];
      var $2132=(($here+1)|0);
      var $2133=HEAPU8[($2132)];
      var $2134=(($2133)&255);
      var $2135=$bits;
      var $2136=(($2134)>>>0) <= (($2135)>>>0);
      if ($2136) { __label__ = 457; break; } else { __label__ = 458; break; }
    case 457: 
      __label__ = 463; break;
    case 458: 
      __label__ = 459; break;
    case 459: 
      var $2140=$have;
      var $2141=(($2140)|0)==0;
      if ($2141) { __label__ = 460; break; } else { __label__ = 461; break; }
    case 460: 
      __label__ = 566; break;
    case 461: 
      var $2144=$have;
      var $2145=((($2144)-(1))|0);
      $have=$2145;
      var $2146=$next;
      var $2147=(($2146+1)|0);
      $next=$2147;
      var $2148=HEAPU8[($2146)];
      var $2149=(($2148)&255);
      var $2150=$bits;
      var $2151=$2149 << $2150;
      var $2152=$hold;
      var $2153=((($2152)+($2151))|0);
      $hold=$2153;
      var $2154=$bits;
      var $2155=((($2154)+(8))|0);
      $bits=$2155;
      __label__ = 462; break;
    case 462: 
      __label__ = 456; break;
    case 463: 
      var $2158=(($here)|0);
      var $2159=HEAPU8[($2158)];
      var $2160=(($2159)&255);
      var $2161=$2160 & 240;
      var $2162=(($2161)|0)==0;
      if ($2162) { __label__ = 464; break; } else { __label__ = 475; break; }
    case 464: 
      var $2164=$last;
      var $2165=$here;
      assert(4 % 1 === 0, 'memcpy given ' + 4 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP16[(($2164)>>1)]=HEAP16[(($2165)>>1)];HEAP16[((($2164)+(2))>>1)]=HEAP16[((($2165)+(2))>>1)];
      __label__ = 465; break;
    case 465: 
      var $2167=(($last+2)|0);
      var $2168=HEAPU16[(($2167)>>1)];
      var $2169=(($2168)&65535);
      var $2170=$hold;
      var $2171=(($last+1)|0);
      var $2172=HEAPU8[($2171)];
      var $2173=(($2172)&255);
      var $2174=(($last)|0);
      var $2175=HEAPU8[($2174)];
      var $2176=(($2175)&255);
      var $2177=((($2173)+($2176))|0);
      var $2178=1 << $2177;
      var $2179=((($2178)-(1))|0);
      var $2180=$2170 & $2179;
      var $2181=(($last+1)|0);
      var $2182=HEAPU8[($2181)];
      var $2183=(($2182)&255);
      var $2184=$2180 >>> (($2183)>>>0);
      var $2185=((($2169)+($2184))|0);
      var $2186=$state;
      var $2187=(($2186+80)|0);
      var $2188=HEAP32[(($2187)>>2)];
      var $2189=(($2188+($2185<<2))|0);
      var $2190=$here;
      var $2191=$2189;
      assert(4 % 1 === 0, 'memcpy given ' + 4 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP16[(($2190)>>1)]=HEAP16[(($2191)>>1)];HEAP16[((($2190)+(2))>>1)]=HEAP16[((($2191)+(2))>>1)];
      var $2192=(($last+1)|0);
      var $2193=HEAPU8[($2192)];
      var $2194=(($2193)&255);
      var $2195=(($here+1)|0);
      var $2196=HEAPU8[($2195)];
      var $2197=(($2196)&255);
      var $2198=((($2194)+($2197))|0);
      var $2199=$bits;
      var $2200=(($2198)>>>0) <= (($2199)>>>0);
      if ($2200) { __label__ = 466; break; } else { __label__ = 467; break; }
    case 466: 
      __label__ = 472; break;
    case 467: 
      __label__ = 468; break;
    case 468: 
      var $2204=$have;
      var $2205=(($2204)|0)==0;
      if ($2205) { __label__ = 469; break; } else { __label__ = 470; break; }
    case 469: 
      __label__ = 566; break;
    case 470: 
      var $2208=$have;
      var $2209=((($2208)-(1))|0);
      $have=$2209;
      var $2210=$next;
      var $2211=(($2210+1)|0);
      $next=$2211;
      var $2212=HEAPU8[($2210)];
      var $2213=(($2212)&255);
      var $2214=$bits;
      var $2215=$2213 << $2214;
      var $2216=$hold;
      var $2217=((($2216)+($2215))|0);
      $hold=$2217;
      var $2218=$bits;
      var $2219=((($2218)+(8))|0);
      $bits=$2219;
      __label__ = 471; break;
    case 471: 
      __label__ = 465; break;
    case 472: 
      __label__ = 473; break;
    case 473: 
      var $2223=(($last+1)|0);
      var $2224=HEAPU8[($2223)];
      var $2225=(($2224)&255);
      var $2226=$hold;
      var $2227=$2226 >>> (($2225)>>>0);
      $hold=$2227;
      var $2228=(($last+1)|0);
      var $2229=HEAPU8[($2228)];
      var $2230=(($2229)&255);
      var $2231=$bits;
      var $2232=((($2231)-($2230))|0);
      $bits=$2232;
      __label__ = 474; break;
    case 474: 
      var $2234=(($last+1)|0);
      var $2235=HEAPU8[($2234)];
      var $2236=(($2235)&255);
      var $2237=$state;
      var $2238=(($2237+7108)|0);
      var $2239=HEAP32[(($2238)>>2)];
      var $2240=((($2239)+($2236))|0);
      HEAP32[(($2238)>>2)]=$2240;
      __label__ = 475; break;
    case 475: 
      __label__ = 476; break;
    case 476: 
      var $2243=(($here+1)|0);
      var $2244=HEAPU8[($2243)];
      var $2245=(($2244)&255);
      var $2246=$hold;
      var $2247=$2246 >>> (($2245)>>>0);
      $hold=$2247;
      var $2248=(($here+1)|0);
      var $2249=HEAPU8[($2248)];
      var $2250=(($2249)&255);
      var $2251=$bits;
      var $2252=((($2251)-($2250))|0);
      $bits=$2252;
      __label__ = 477; break;
    case 477: 
      var $2254=(($here+1)|0);
      var $2255=HEAPU8[($2254)];
      var $2256=(($2255)&255);
      var $2257=$state;
      var $2258=(($2257+7108)|0);
      var $2259=HEAP32[(($2258)>>2)];
      var $2260=((($2259)+($2256))|0);
      HEAP32[(($2258)>>2)]=$2260;
      var $2261=(($here)|0);
      var $2262=HEAPU8[($2261)];
      var $2263=(($2262)&255);
      var $2264=$2263 & 64;
      var $2265=(($2264)|0)!=0;
      if ($2265) { __label__ = 478; break; } else { __label__ = 479; break; }
    case 478: 
      var $2267=$2;
      var $2268=(($2267+24)|0);
      HEAP32[(($2268)>>2)]=((STRING_TABLE.__str15)|0);
      var $2269=$state;
      var $2270=(($2269)|0);
      HEAP32[(($2270)>>2)]=29;
      __label__ = 565; break;
    case 479: 
      var $2272=(($here+2)|0);
      var $2273=HEAPU16[(($2272)>>1)];
      var $2274=(($2273)&65535);
      var $2275=$state;
      var $2276=(($2275+68)|0);
      HEAP32[(($2276)>>2)]=$2274;
      var $2277=(($here)|0);
      var $2278=HEAPU8[($2277)];
      var $2279=(($2278)&255);
      var $2280=$2279 & 15;
      var $2281=$state;
      var $2282=(($2281+72)|0);
      HEAP32[(($2282)>>2)]=$2280;
      var $2283=$state;
      var $2284=(($2283)|0);
      HEAP32[(($2284)>>2)]=23;
      __label__ = 480; break;
    case 480: 
      var $2286=$state;
      var $2287=(($2286+72)|0);
      var $2288=HEAP32[(($2287)>>2)];
      var $2289=(($2288)|0)!=0;
      if ($2289) { __label__ = 481; break; } else { __label__ = 493; break; }
    case 481: 
      __label__ = 482; break;
    case 482: 
      __label__ = 483; break;
    case 483: 
      var $2293=$bits;
      var $2294=$state;
      var $2295=(($2294+72)|0);
      var $2296=HEAPU32[(($2295)>>2)];
      var $2297=(($2293)>>>0) < (($2296)>>>0);
      if ($2297) { __label__ = 484; break; } else { __label__ = 489; break; }
    case 484: 
      __label__ = 485; break;
    case 485: 
      var $2300=$have;
      var $2301=(($2300)|0)==0;
      if ($2301) { __label__ = 486; break; } else { __label__ = 487; break; }
    case 486: 
      __label__ = 566; break;
    case 487: 
      var $2304=$have;
      var $2305=((($2304)-(1))|0);
      $have=$2305;
      var $2306=$next;
      var $2307=(($2306+1)|0);
      $next=$2307;
      var $2308=HEAPU8[($2306)];
      var $2309=(($2308)&255);
      var $2310=$bits;
      var $2311=$2309 << $2310;
      var $2312=$hold;
      var $2313=((($2312)+($2311))|0);
      $hold=$2313;
      var $2314=$bits;
      var $2315=((($2314)+(8))|0);
      $bits=$2315;
      __label__ = 488; break;
    case 488: 
      __label__ = 483; break;
    case 489: 
      __label__ = 490; break;
    case 490: 
      var $2319=$hold;
      var $2320=$state;
      var $2321=(($2320+72)|0);
      var $2322=HEAP32[(($2321)>>2)];
      var $2323=1 << $2322;
      var $2324=((($2323)-(1))|0);
      var $2325=$2319 & $2324;
      var $2326=$state;
      var $2327=(($2326+68)|0);
      var $2328=HEAP32[(($2327)>>2)];
      var $2329=((($2328)+($2325))|0);
      HEAP32[(($2327)>>2)]=$2329;
      __label__ = 491; break;
    case 491: 
      var $2331=$state;
      var $2332=(($2331+72)|0);
      var $2333=HEAPU32[(($2332)>>2)];
      var $2334=$hold;
      var $2335=$2334 >>> (($2333)>>>0);
      $hold=$2335;
      var $2336=$state;
      var $2337=(($2336+72)|0);
      var $2338=HEAP32[(($2337)>>2)];
      var $2339=$bits;
      var $2340=((($2339)-($2338))|0);
      $bits=$2340;
      __label__ = 492; break;
    case 492: 
      var $2342=$state;
      var $2343=(($2342+72)|0);
      var $2344=HEAP32[(($2343)>>2)];
      var $2345=$state;
      var $2346=(($2345+7108)|0);
      var $2347=HEAP32[(($2346)>>2)];
      var $2348=((($2347)+($2344))|0);
      HEAP32[(($2346)>>2)]=$2348;
      __label__ = 493; break;
    case 493: 
      var $2350=$state;
      var $2351=(($2350)|0);
      HEAP32[(($2351)>>2)]=24;
      __label__ = 494; break;
    case 494: 
      var $2353=$left;
      var $2354=(($2353)|0)==0;
      if ($2354) { __label__ = 495; break; } else { __label__ = 496; break; }
    case 495: 
      __label__ = 566; break;
    case 496: 
      var $2357=$out;
      var $2358=$left;
      var $2359=((($2357)-($2358))|0);
      $copy=$2359;
      var $2360=$state;
      var $2361=(($2360+68)|0);
      var $2362=HEAPU32[(($2361)>>2)];
      var $2363=$copy;
      var $2364=(($2362)>>>0) > (($2363)>>>0);
      if ($2364) { __label__ = 497; break; } else { __label__ = 507; break; }
    case 497: 
      var $2366=$state;
      var $2367=(($2366+68)|0);
      var $2368=HEAP32[(($2367)>>2)];
      var $2369=$copy;
      var $2370=((($2368)-($2369))|0);
      $copy=$2370;
      var $2371=$copy;
      var $2372=$state;
      var $2373=(($2372+44)|0);
      var $2374=HEAPU32[(($2373)>>2)];
      var $2375=(($2371)>>>0) > (($2374)>>>0);
      if ($2375) { __label__ = 498; break; } else { __label__ = 501; break; }
    case 498: 
      var $2377=$state;
      var $2378=(($2377+7104)|0);
      var $2379=HEAP32[(($2378)>>2)];
      var $2380=(($2379)|0)!=0;
      if ($2380) { __label__ = 499; break; } else { __label__ = 500; break; }
    case 499: 
      var $2382=$2;
      var $2383=(($2382+24)|0);
      HEAP32[(($2383)>>2)]=((STRING_TABLE.__str16)|0);
      var $2384=$state;
      var $2385=(($2384)|0);
      HEAP32[(($2385)>>2)]=29;
      __label__ = 565; break;
    case 500: 
      __label__ = 501; break;
    case 501: 
      var $2388=$copy;
      var $2389=$state;
      var $2390=(($2389+48)|0);
      var $2391=HEAPU32[(($2390)>>2)];
      var $2392=(($2388)>>>0) > (($2391)>>>0);
      if ($2392) { __label__ = 502; break; } else { __label__ = 503; break; }
    case 502: 
      var $2394=$state;
      var $2395=(($2394+48)|0);
      var $2396=HEAP32[(($2395)>>2)];
      var $2397=$copy;
      var $2398=((($2397)-($2396))|0);
      $copy=$2398;
      var $2399=$state;
      var $2400=(($2399+52)|0);
      var $2401=HEAP32[(($2400)>>2)];
      var $2402=$state;
      var $2403=(($2402+40)|0);
      var $2404=HEAP32[(($2403)>>2)];
      var $2405=$copy;
      var $2406=((($2404)-($2405))|0);
      var $2407=(($2401+$2406)|0);
      $from=$2407;
      __label__ = 504; break;
    case 503: 
      var $2409=$state;
      var $2410=(($2409+52)|0);
      var $2411=HEAP32[(($2410)>>2)];
      var $2412=$state;
      var $2413=(($2412+48)|0);
      var $2414=HEAP32[(($2413)>>2)];
      var $2415=$copy;
      var $2416=((($2414)-($2415))|0);
      var $2417=(($2411+$2416)|0);
      $from=$2417;
      __label__ = 504; break;
    case 504: 
      var $2419=$copy;
      var $2420=$state;
      var $2421=(($2420+64)|0);
      var $2422=HEAPU32[(($2421)>>2)];
      var $2423=(($2419)>>>0) > (($2422)>>>0);
      if ($2423) { __label__ = 505; break; } else { __label__ = 506; break; }
    case 505: 
      var $2425=$state;
      var $2426=(($2425+64)|0);
      var $2427=HEAP32[(($2426)>>2)];
      $copy=$2427;
      __label__ = 506; break;
    case 506: 
      __label__ = 508; break;
    case 507: 
      var $2430=$put;
      var $2431=$state;
      var $2432=(($2431+68)|0);
      var $2433=HEAP32[(($2432)>>2)];
      var $2434=(((-$2433))|0);
      var $2435=(($2430+$2434)|0);
      $from=$2435;
      var $2436=$state;
      var $2437=(($2436+64)|0);
      var $2438=HEAP32[(($2437)>>2)];
      $copy=$2438;
      __label__ = 508; break;
    case 508: 
      var $2440=$copy;
      var $2441=$left;
      var $2442=(($2440)>>>0) > (($2441)>>>0);
      if ($2442) { __label__ = 509; break; } else { __label__ = 510; break; }
    case 509: 
      var $2444=$left;
      $copy=$2444;
      __label__ = 510; break;
    case 510: 
      var $2446=$copy;
      var $2447=$left;
      var $2448=((($2447)-($2446))|0);
      $left=$2448;
      var $2449=$copy;
      var $2450=$state;
      var $2451=(($2450+64)|0);
      var $2452=HEAP32[(($2451)>>2)];
      var $2453=((($2452)-($2449))|0);
      HEAP32[(($2451)>>2)]=$2453;
      __label__ = 511; break;
    case 511: 
      var $2455=$from;
      var $2456=(($2455+1)|0);
      $from=$2456;
      var $2457=HEAP8[($2455)];
      var $2458=$put;
      var $2459=(($2458+1)|0);
      $put=$2459;
      HEAP8[($2458)]=$2457;
      __label__ = 512; break;
    case 512: 
      var $2461=$copy;
      var $2462=((($2461)-(1))|0);
      $copy=$2462;
      var $2463=(($2462)|0)!=0;
      if ($2463) { __label__ = 511; break; } else { __label__ = 513; break; }
    case 513: 
      var $2465=$state;
      var $2466=(($2465+64)|0);
      var $2467=HEAP32[(($2466)>>2)];
      var $2468=(($2467)|0)==0;
      if ($2468) { __label__ = 514; break; } else { __label__ = 515; break; }
    case 514: 
      var $2470=$state;
      var $2471=(($2470)|0);
      HEAP32[(($2471)>>2)]=20;
      __label__ = 515; break;
    case 515: 
      __label__ = 565; break;
    case 516: 
      var $2474=$left;
      var $2475=(($2474)|0)==0;
      if ($2475) { __label__ = 517; break; } else { __label__ = 518; break; }
    case 517: 
      __label__ = 566; break;
    case 518: 
      var $2478=$state;
      var $2479=(($2478+64)|0);
      var $2480=HEAP32[(($2479)>>2)];
      var $2481=(($2480) & 255);
      var $2482=$put;
      var $2483=(($2482+1)|0);
      $put=$2483;
      HEAP8[($2482)]=$2481;
      var $2484=$left;
      var $2485=((($2484)-(1))|0);
      $left=$2485;
      var $2486=$state;
      var $2487=(($2486)|0);
      HEAP32[(($2487)>>2)]=20;
      __label__ = 565; break;
    case 519: 
      var $2489=$state;
      var $2490=(($2489+8)|0);
      var $2491=HEAP32[(($2490)>>2)];
      var $2492=(($2491)|0)!=0;
      if ($2492) { __label__ = 520; break; } else { __label__ = 542; break; }
    case 520: 
      __label__ = 521; break;
    case 521: 
      __label__ = 522; break;
    case 522: 
      var $2496=$bits;
      var $2497=(($2496)>>>0) < 32;
      if ($2497) { __label__ = 523; break; } else { __label__ = 528; break; }
    case 523: 
      __label__ = 524; break;
    case 524: 
      var $2500=$have;
      var $2501=(($2500)|0)==0;
      if ($2501) { __label__ = 525; break; } else { __label__ = 526; break; }
    case 525: 
      __label__ = 566; break;
    case 526: 
      var $2504=$have;
      var $2505=((($2504)-(1))|0);
      $have=$2505;
      var $2506=$next;
      var $2507=(($2506+1)|0);
      $next=$2507;
      var $2508=HEAPU8[($2506)];
      var $2509=(($2508)&255);
      var $2510=$bits;
      var $2511=$2509 << $2510;
      var $2512=$hold;
      var $2513=((($2512)+($2511))|0);
      $hold=$2513;
      var $2514=$bits;
      var $2515=((($2514)+(8))|0);
      $bits=$2515;
      __label__ = 527; break;
    case 527: 
      __label__ = 522; break;
    case 528: 
      __label__ = 529; break;
    case 529: 
      var $2519=$left;
      var $2520=$out;
      var $2521=((($2520)-($2519))|0);
      $out=$2521;
      var $2522=$out;
      var $2523=$2;
      var $2524=(($2523+20)|0);
      var $2525=HEAP32[(($2524)>>2)];
      var $2526=((($2525)+($2522))|0);
      HEAP32[(($2524)>>2)]=$2526;
      var $2527=$out;
      var $2528=$state;
      var $2529=(($2528+28)|0);
      var $2530=HEAP32[(($2529)>>2)];
      var $2531=((($2530)+($2527))|0);
      HEAP32[(($2529)>>2)]=$2531;
      var $2532=$out;
      var $2533=(($2532)|0)!=0;
      if ($2533) { __label__ = 530; break; } else { __label__ = 534; break; }
    case 530: 
      var $2535=$state;
      var $2536=(($2535+16)|0);
      var $2537=HEAP32[(($2536)>>2)];
      var $2538=(($2537)|0)!=0;
      if ($2538) { __label__ = 531; break; } else { __label__ = 532; break; }
    case 531: 
      var $2540=$state;
      var $2541=(($2540+24)|0);
      var $2542=HEAP32[(($2541)>>2)];
      var $2543=$put;
      var $2544=$out;
      var $2545=(((-$2544))|0);
      var $2546=(($2543+$2545)|0);
      var $2547=$out;
      var $2548=_crc32($2542, $2546, $2547);
      var $2560 = $2548;__label__ = 533; break;
    case 532: 
      var $2550=$state;
      var $2551=(($2550+24)|0);
      var $2552=HEAP32[(($2551)>>2)];
      var $2553=$put;
      var $2554=$out;
      var $2555=(((-$2554))|0);
      var $2556=(($2553+$2555)|0);
      var $2557=$out;
      var $2558=_adler32($2552, $2556, $2557);
      var $2560 = $2558;__label__ = 533; break;
    case 533: 
      var $2560;
      var $2561=$state;
      var $2562=(($2561+24)|0);
      HEAP32[(($2562)>>2)]=$2560;
      var $2563=$2;
      var $2564=(($2563+48)|0);
      HEAP32[(($2564)>>2)]=$2560;
      __label__ = 534; break;
    case 534: 
      var $2566=$left;
      $out=$2566;
      var $2567=$state;
      var $2568=(($2567+16)|0);
      var $2569=HEAP32[(($2568)>>2)];
      var $2570=(($2569)|0)!=0;
      if ($2570) { __label__ = 535; break; } else { __label__ = 536; break; }
    case 535: 
      var $2572=$hold;
      var $2590 = $2572;__label__ = 537; break;
    case 536: 
      var $2574=$hold;
      var $2575=$2574 >>> 24;
      var $2576=$2575 & 255;
      var $2577=$hold;
      var $2578=$2577 >>> 8;
      var $2579=$2578 & 65280;
      var $2580=((($2576)+($2579))|0);
      var $2581=$hold;
      var $2582=$2581 & 65280;
      var $2583=$2582 << 8;
      var $2584=((($2580)+($2583))|0);
      var $2585=$hold;
      var $2586=$2585 & 255;
      var $2587=$2586 << 24;
      var $2588=((($2584)+($2587))|0);
      var $2590 = $2588;__label__ = 537; break;
    case 537: 
      var $2590;
      var $2591=$state;
      var $2592=(($2591+24)|0);
      var $2593=HEAP32[(($2592)>>2)];
      var $2594=(($2590)|0)!=(($2593)|0);
      if ($2594) { __label__ = 538; break; } else { __label__ = 539; break; }
    case 538: 
      var $2596=$2;
      var $2597=(($2596+24)|0);
      HEAP32[(($2597)>>2)]=((STRING_TABLE.__str17)|0);
      var $2598=$state;
      var $2599=(($2598)|0);
      HEAP32[(($2599)>>2)]=29;
      __label__ = 565; break;
    case 539: 
      __label__ = 540; break;
    case 540: 
      $hold=0;
      $bits=0;
      __label__ = 541; break;
    case 541: 
      __label__ = 542; break;
    case 542: 
      var $2604=$state;
      var $2605=(($2604)|0);
      HEAP32[(($2605)>>2)]=27;
      __label__ = 543; break;
    case 543: 
      var $2607=$state;
      var $2608=(($2607+8)|0);
      var $2609=HEAP32[(($2608)>>2)];
      var $2610=(($2609)|0)!=0;
      if ($2610) { __label__ = 544; break; } else { __label__ = 559; break; }
    case 544: 
      var $2612=$state;
      var $2613=(($2612+16)|0);
      var $2614=HEAP32[(($2613)>>2)];
      var $2615=(($2614)|0)!=0;
      if ($2615) { __label__ = 545; break; } else { __label__ = 559; break; }
    case 545: 
      __label__ = 546; break;
    case 546: 
      __label__ = 547; break;
    case 547: 
      var $2619=$bits;
      var $2620=(($2619)>>>0) < 32;
      if ($2620) { __label__ = 548; break; } else { __label__ = 553; break; }
    case 548: 
      __label__ = 549; break;
    case 549: 
      var $2623=$have;
      var $2624=(($2623)|0)==0;
      if ($2624) { __label__ = 550; break; } else { __label__ = 551; break; }
    case 550: 
      __label__ = 566; break;
    case 551: 
      var $2627=$have;
      var $2628=((($2627)-(1))|0);
      $have=$2628;
      var $2629=$next;
      var $2630=(($2629+1)|0);
      $next=$2630;
      var $2631=HEAPU8[($2629)];
      var $2632=(($2631)&255);
      var $2633=$bits;
      var $2634=$2632 << $2633;
      var $2635=$hold;
      var $2636=((($2635)+($2634))|0);
      $hold=$2636;
      var $2637=$bits;
      var $2638=((($2637)+(8))|0);
      $bits=$2638;
      __label__ = 552; break;
    case 552: 
      __label__ = 547; break;
    case 553: 
      __label__ = 554; break;
    case 554: 
      var $2642=$hold;
      var $2643=$state;
      var $2644=(($2643+28)|0);
      var $2645=HEAP32[(($2644)>>2)];
      var $2646=(($2642)|0)!=(($2645)|0);
      if ($2646) { __label__ = 555; break; } else { __label__ = 556; break; }
    case 555: 
      var $2648=$2;
      var $2649=(($2648+24)|0);
      HEAP32[(($2649)>>2)]=((STRING_TABLE.__str18)|0);
      var $2650=$state;
      var $2651=(($2650)|0);
      HEAP32[(($2651)>>2)]=29;
      __label__ = 565; break;
    case 556: 
      __label__ = 557; break;
    case 557: 
      $hold=0;
      $bits=0;
      __label__ = 558; break;
    case 558: 
      __label__ = 559; break;
    case 559: 
      var $2656=$state;
      var $2657=(($2656)|0);
      HEAP32[(($2657)>>2)]=28;
      __label__ = 560; break;
    case 560: 
      $ret=1;
      __label__ = 566; break;
    case 561: 
      $ret=-3;
      __label__ = 566; break;
    case 562: 
      $1=-4;
      __label__ = 590; break;
    case 563: 
      __label__ = 564; break;
    case 564: 
      $1=-2;
      __label__ = 590; break;
    case 565: 
      __label__ = 13; break;
    case 566: 
      __label__ = 567; break;
    case 567: 
      var $2666=$put;
      var $2667=$2;
      var $2668=(($2667+12)|0);
      HEAP32[(($2668)>>2)]=$2666;
      var $2669=$left;
      var $2670=$2;
      var $2671=(($2670+16)|0);
      HEAP32[(($2671)>>2)]=$2669;
      var $2672=$next;
      var $2673=$2;
      var $2674=(($2673)|0);
      HEAP32[(($2674)>>2)]=$2672;
      var $2675=$have;
      var $2676=$2;
      var $2677=(($2676+4)|0);
      HEAP32[(($2677)>>2)]=$2675;
      var $2678=$hold;
      var $2679=$state;
      var $2680=(($2679+56)|0);
      HEAP32[(($2680)>>2)]=$2678;
      var $2681=$bits;
      var $2682=$state;
      var $2683=(($2682+60)|0);
      HEAP32[(($2683)>>2)]=$2681;
      __label__ = 568; break;
    case 568: 
      var $2685=$state;
      var $2686=(($2685+40)|0);
      var $2687=HEAP32[(($2686)>>2)];
      var $2688=(($2687)|0)!=0;
      if ($2688) { __label__ = 573; break; } else { __label__ = 569; break; }
    case 569: 
      var $2690=$out;
      var $2691=$2;
      var $2692=(($2691+16)|0);
      var $2693=HEAP32[(($2692)>>2)];
      var $2694=(($2690)|0)!=(($2693)|0);
      if ($2694) { __label__ = 570; break; } else { __label__ = 576; break; }
    case 570: 
      var $2696=$state;
      var $2697=(($2696)|0);
      var $2698=HEAPU32[(($2697)>>2)];
      var $2699=(($2698)>>>0) < 29;
      if ($2699) { __label__ = 571; break; } else { __label__ = 576; break; }
    case 571: 
      var $2701=$state;
      var $2702=(($2701)|0);
      var $2703=HEAPU32[(($2702)>>2)];
      var $2704=(($2703)>>>0) < 26;
      if ($2704) { __label__ = 573; break; } else { __label__ = 572; break; }
    case 572: 
      var $2706=$3;
      var $2707=(($2706)|0)!=4;
      if ($2707) { __label__ = 573; break; } else { __label__ = 576; break; }
    case 573: 
      var $2709=$2;
      var $2710=$out;
      var $2711=_updatewindow($2709, $2710);
      var $2712=(($2711)|0)!=0;
      if ($2712) { __label__ = 574; break; } else { __label__ = 575; break; }
    case 574: 
      var $2714=$state;
      var $2715=(($2714)|0);
      HEAP32[(($2715)>>2)]=30;
      $1=-4;
      __label__ = 590; break;
    case 575: 
      __label__ = 576; break;
    case 576: 
      var $2718=$2;
      var $2719=(($2718+4)|0);
      var $2720=HEAP32[(($2719)>>2)];
      var $2721=$in;
      var $2722=((($2721)-($2720))|0);
      $in=$2722;
      var $2723=$2;
      var $2724=(($2723+16)|0);
      var $2725=HEAP32[(($2724)>>2)];
      var $2726=$out;
      var $2727=((($2726)-($2725))|0);
      $out=$2727;
      var $2728=$in;
      var $2729=$2;
      var $2730=(($2729+8)|0);
      var $2731=HEAP32[(($2730)>>2)];
      var $2732=((($2731)+($2728))|0);
      HEAP32[(($2730)>>2)]=$2732;
      var $2733=$out;
      var $2734=$2;
      var $2735=(($2734+20)|0);
      var $2736=HEAP32[(($2735)>>2)];
      var $2737=((($2736)+($2733))|0);
      HEAP32[(($2735)>>2)]=$2737;
      var $2738=$out;
      var $2739=$state;
      var $2740=(($2739+28)|0);
      var $2741=HEAP32[(($2740)>>2)];
      var $2742=((($2741)+($2738))|0);
      HEAP32[(($2740)>>2)]=$2742;
      var $2743=$state;
      var $2744=(($2743+8)|0);
      var $2745=HEAP32[(($2744)>>2)];
      var $2746=(($2745)|0)!=0;
      if ($2746) { __label__ = 577; break; } else { __label__ = 582; break; }
    case 577: 
      var $2748=$out;
      var $2749=(($2748)|0)!=0;
      if ($2749) { __label__ = 578; break; } else { __label__ = 582; break; }
    case 578: 
      var $2751=$state;
      var $2752=(($2751+16)|0);
      var $2753=HEAP32[(($2752)>>2)];
      var $2754=(($2753)|0)!=0;
      if ($2754) { __label__ = 579; break; } else { __label__ = 580; break; }
    case 579: 
      var $2756=$state;
      var $2757=(($2756+24)|0);
      var $2758=HEAP32[(($2757)>>2)];
      var $2759=$2;
      var $2760=(($2759+12)|0);
      var $2761=HEAP32[(($2760)>>2)];
      var $2762=$out;
      var $2763=(((-$2762))|0);
      var $2764=(($2761+$2763)|0);
      var $2765=$out;
      var $2766=_crc32($2758, $2764, $2765);
      var $2780 = $2766;__label__ = 581; break;
    case 580: 
      var $2768=$state;
      var $2769=(($2768+24)|0);
      var $2770=HEAP32[(($2769)>>2)];
      var $2771=$2;
      var $2772=(($2771+12)|0);
      var $2773=HEAP32[(($2772)>>2)];
      var $2774=$out;
      var $2775=(((-$2774))|0);
      var $2776=(($2773+$2775)|0);
      var $2777=$out;
      var $2778=_adler32($2770, $2776, $2777);
      var $2780 = $2778;__label__ = 581; break;
    case 581: 
      var $2780;
      var $2781=$state;
      var $2782=(($2781+24)|0);
      HEAP32[(($2782)>>2)]=$2780;
      var $2783=$2;
      var $2784=(($2783+48)|0);
      HEAP32[(($2784)>>2)]=$2780;
      __label__ = 582; break;
    case 582: 
      var $2786=$state;
      var $2787=(($2786+60)|0);
      var $2788=HEAP32[(($2787)>>2)];
      var $2789=$state;
      var $2790=(($2789+4)|0);
      var $2791=HEAP32[(($2790)>>2)];
      var $2792=(($2791)|0)!=0;
      var $2793=$2792 ? 64 : 0;
      var $2794=((($2788)+($2793))|0);
      var $2795=$state;
      var $2796=(($2795)|0);
      var $2797=HEAP32[(($2796)>>2)];
      var $2798=(($2797)|0)==11;
      var $2799=$2798 ? 128 : 0;
      var $2800=((($2794)+($2799))|0);
      var $2801=$state;
      var $2802=(($2801)|0);
      var $2803=HEAP32[(($2802)>>2)];
      var $2804=(($2803)|0)==19;
      if ($2804) { var $2811 = 1;__label__ = 584; break; } else { __label__ = 583; break; }
    case 583: 
      var $2806=$state;
      var $2807=(($2806)|0);
      var $2808=HEAP32[(($2807)>>2)];
      var $2809=(($2808)|0)==14;
      var $2811 = $2809;__label__ = 584; break;
    case 584: 
      var $2811;
      var $2812=$2811 ? 256 : 0;
      var $2813=((($2800)+($2812))|0);
      var $2814=$2;
      var $2815=(($2814+44)|0);
      HEAP32[(($2815)>>2)]=$2813;
      var $2816=$in;
      var $2817=(($2816)|0)==0;
      if ($2817) { __label__ = 585; break; } else { __label__ = 586; break; }
    case 585: 
      var $2819=$out;
      var $2820=(($2819)|0)==0;
      if ($2820) { __label__ = 587; break; } else { __label__ = 586; break; }
    case 586: 
      var $2822=$3;
      var $2823=(($2822)|0)==4;
      if ($2823) { __label__ = 587; break; } else { __label__ = 589; break; }
    case 587: 
      var $2825=$ret;
      var $2826=(($2825)|0)==0;
      if ($2826) { __label__ = 588; break; } else { __label__ = 589; break; }
    case 588: 
      $ret=-5;
      __label__ = 589; break;
    case 589: 
      var $2829=$ret;
      $1=$2829;
      __label__ = 590; break;
    case 590: 
      var $2831=$1;
      STACKTOP = __stackBase__;
      return $2831;
    default: assert(0, "bad label: " + __label__);
  }
}
_inflate["X"]=1;

function _fixedtables55($state) {
  ;
  var __label__;

  var $1;
  $1=$state;
  var $2=$1;
  var $3=(($2+76)|0);
  HEAP32[(($3)>>2)]=((_fixedtables_lenfix47)|0);
  var $4=$1;
  var $5=(($4+84)|0);
  HEAP32[(($5)>>2)]=9;
  var $6=$1;
  var $7=(($6+80)|0);
  HEAP32[(($7)>>2)]=((_fixedtables_distfix48)|0);
  var $8=$1;
  var $9=(($8+88)|0);
  HEAP32[(($9)>>2)]=5;
  ;
  return;
}


function _updatewindow($strm, $out) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $state;
      var $copy;
      var $dist;
      $2=$strm;
      $3=$out;
      var $4=$2;
      var $5=(($4+28)|0);
      var $6=HEAP32[(($5)>>2)];
      var $7=$6;
      $state=$7;
      var $8=$state;
      var $9=(($8+52)|0);
      var $10=HEAP32[(($9)>>2)];
      var $11=(($10)|0)==0;
      if ($11) { __label__ = 3; break; } else { __label__ = 6; break; }
    case 3: 
      var $13=$2;
      var $14=(($13+32)|0);
      var $15=HEAP32[(($14)>>2)];
      var $16=$2;
      var $17=(($16+40)|0);
      var $18=HEAP32[(($17)>>2)];
      var $19=$state;
      var $20=(($19+36)|0);
      var $21=HEAP32[(($20)>>2)];
      var $22=1 << $21;
      var $23=FUNCTION_TABLE[$15]($18, $22, 1);
      var $24=$state;
      var $25=(($24+52)|0);
      HEAP32[(($25)>>2)]=$23;
      var $26=$state;
      var $27=(($26+52)|0);
      var $28=HEAP32[(($27)>>2)];
      var $29=(($28)|0)==0;
      if ($29) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      $1=1;
      __label__ = 21; break;
    case 5: 
      __label__ = 6; break;
    case 6: 
      var $33=$state;
      var $34=(($33+40)|0);
      var $35=HEAP32[(($34)>>2)];
      var $36=(($35)|0)==0;
      if ($36) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $38=$state;
      var $39=(($38+36)|0);
      var $40=HEAP32[(($39)>>2)];
      var $41=1 << $40;
      var $42=$state;
      var $43=(($42+40)|0);
      HEAP32[(($43)>>2)]=$41;
      var $44=$state;
      var $45=(($44+48)|0);
      HEAP32[(($45)>>2)]=0;
      var $46=$state;
      var $47=(($46+44)|0);
      HEAP32[(($47)>>2)]=0;
      __label__ = 8; break;
    case 8: 
      var $49=$3;
      var $50=$2;
      var $51=(($50+16)|0);
      var $52=HEAP32[(($51)>>2)];
      var $53=((($49)-($52))|0);
      $copy=$53;
      var $54=$copy;
      var $55=$state;
      var $56=(($55+40)|0);
      var $57=HEAPU32[(($56)>>2)];
      var $58=(($54)>>>0) >= (($57)>>>0);
      if ($58) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      var $60=$state;
      var $61=(($60+52)|0);
      var $62=HEAP32[(($61)>>2)];
      var $63=$2;
      var $64=(($63+12)|0);
      var $65=HEAP32[(($64)>>2)];
      var $66=$state;
      var $67=(($66+40)|0);
      var $68=HEAP32[(($67)>>2)];
      var $69=(((-$68))|0);
      var $70=(($65+$69)|0);
      var $71=$state;
      var $72=(($71+40)|0);
      var $73=HEAP32[(($72)>>2)];
      assert($73 % 1 === 0, 'memcpy given ' + $73 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');_memcpy($62, $70, $73, 1);
      var $74=$state;
      var $75=(($74+48)|0);
      HEAP32[(($75)>>2)]=0;
      var $76=$state;
      var $77=(($76+40)|0);
      var $78=HEAP32[(($77)>>2)];
      var $79=$state;
      var $80=(($79+44)|0);
      HEAP32[(($80)>>2)]=$78;
      __label__ = 20; break;
    case 10: 
      var $82=$state;
      var $83=(($82+40)|0);
      var $84=HEAP32[(($83)>>2)];
      var $85=$state;
      var $86=(($85+48)|0);
      var $87=HEAP32[(($86)>>2)];
      var $88=((($84)-($87))|0);
      $dist=$88;
      var $89=$dist;
      var $90=$copy;
      var $91=(($89)>>>0) > (($90)>>>0);
      if ($91) { __label__ = 11; break; } else { __label__ = 12; break; }
    case 11: 
      var $93=$copy;
      $dist=$93;
      __label__ = 12; break;
    case 12: 
      var $95=$state;
      var $96=(($95+52)|0);
      var $97=HEAP32[(($96)>>2)];
      var $98=$state;
      var $99=(($98+48)|0);
      var $100=HEAP32[(($99)>>2)];
      var $101=(($97+$100)|0);
      var $102=$2;
      var $103=(($102+12)|0);
      var $104=HEAP32[(($103)>>2)];
      var $105=$copy;
      var $106=(((-$105))|0);
      var $107=(($104+$106)|0);
      var $108=$dist;
      assert($108 % 1 === 0, 'memcpy given ' + $108 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');_memcpy($101, $107, $108, 1);
      var $109=$dist;
      var $110=$copy;
      var $111=((($110)-($109))|0);
      $copy=$111;
      var $112=$copy;
      var $113=(($112)|0)!=0;
      if ($113) { __label__ = 13; break; } else { __label__ = 14; break; }
    case 13: 
      var $115=$state;
      var $116=(($115+52)|0);
      var $117=HEAP32[(($116)>>2)];
      var $118=$2;
      var $119=(($118+12)|0);
      var $120=HEAP32[(($119)>>2)];
      var $121=$copy;
      var $122=(((-$121))|0);
      var $123=(($120+$122)|0);
      var $124=$copy;
      assert($124 % 1 === 0, 'memcpy given ' + $124 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');_memcpy($117, $123, $124, 1);
      var $125=$copy;
      var $126=$state;
      var $127=(($126+48)|0);
      HEAP32[(($127)>>2)]=$125;
      var $128=$state;
      var $129=(($128+40)|0);
      var $130=HEAP32[(($129)>>2)];
      var $131=$state;
      var $132=(($131+44)|0);
      HEAP32[(($132)>>2)]=$130;
      __label__ = 19; break;
    case 14: 
      var $134=$dist;
      var $135=$state;
      var $136=(($135+48)|0);
      var $137=HEAP32[(($136)>>2)];
      var $138=((($137)+($134))|0);
      HEAP32[(($136)>>2)]=$138;
      var $139=$state;
      var $140=(($139+48)|0);
      var $141=HEAP32[(($140)>>2)];
      var $142=$state;
      var $143=(($142+40)|0);
      var $144=HEAP32[(($143)>>2)];
      var $145=(($141)|0)==(($144)|0);
      if ($145) { __label__ = 15; break; } else { __label__ = 16; break; }
    case 15: 
      var $147=$state;
      var $148=(($147+48)|0);
      HEAP32[(($148)>>2)]=0;
      __label__ = 16; break;
    case 16: 
      var $150=$state;
      var $151=(($150+44)|0);
      var $152=HEAPU32[(($151)>>2)];
      var $153=$state;
      var $154=(($153+40)|0);
      var $155=HEAPU32[(($154)>>2)];
      var $156=(($152)>>>0) < (($155)>>>0);
      if ($156) { __label__ = 17; break; } else { __label__ = 18; break; }
    case 17: 
      var $158=$dist;
      var $159=$state;
      var $160=(($159+44)|0);
      var $161=HEAP32[(($160)>>2)];
      var $162=((($161)+($158))|0);
      HEAP32[(($160)>>2)]=$162;
      __label__ = 18; break;
    case 18: 
      __label__ = 19; break;
    case 19: 
      __label__ = 20; break;
    case 20: 
      $1=0;
      __label__ = 21; break;
    case 21: 
      var $167=$1;
      ;
      return $167;
    default: assert(0, "bad label: " + __label__);
  }
}
_updatewindow["X"]=1;

function _inflateEnd($strm) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $state;
      $2=$strm;
      var $3=$2;
      var $4=(($3)|0)==0;
      if ($4) { __label__ = 5; break; } else { __label__ = 3; break; }
    case 3: 
      var $6=$2;
      var $7=(($6+28)|0);
      var $8=HEAP32[(($7)>>2)];
      var $9=(($8)|0)==0;
      if ($9) { __label__ = 5; break; } else { __label__ = 4; break; }
    case 4: 
      var $11=$2;
      var $12=(($11+36)|0);
      var $13=HEAP32[(($12)>>2)];
      var $14=(($13)|0)==0;
      if ($14) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      $1=-2;
      __label__ = 9; break;
    case 6: 
      var $17=$2;
      var $18=(($17+28)|0);
      var $19=HEAP32[(($18)>>2)];
      var $20=$19;
      $state=$20;
      var $21=$state;
      var $22=(($21+52)|0);
      var $23=HEAP32[(($22)>>2)];
      var $24=(($23)|0)!=0;
      if ($24) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $26=$2;
      var $27=(($26+36)|0);
      var $28=HEAP32[(($27)>>2)];
      var $29=$2;
      var $30=(($29+40)|0);
      var $31=HEAP32[(($30)>>2)];
      var $32=$state;
      var $33=(($32+52)|0);
      var $34=HEAP32[(($33)>>2)];
      FUNCTION_TABLE[$28]($31, $34);
      __label__ = 8; break;
    case 8: 
      var $36=$2;
      var $37=(($36+36)|0);
      var $38=HEAP32[(($37)>>2)];
      var $39=$2;
      var $40=(($39+40)|0);
      var $41=HEAP32[(($40)>>2)];
      var $42=$2;
      var $43=(($42+28)|0);
      var $44=HEAP32[(($43)>>2)];
      var $45=$44;
      FUNCTION_TABLE[$38]($41, $45);
      var $46=$2;
      var $47=(($46+28)|0);
      HEAP32[(($47)>>2)]=0;
      $1=0;
      __label__ = 9; break;
    case 9: 
      var $49=$1;
      ;
      return $49;
    default: assert(0, "bad label: " + __label__);
  }
}
_inflateEnd["X"]=1;

function _tr_static_init() {
  ;
  var __label__;

  ;
  return;
}


function _init_block($s) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $n;
      $1=$s;
      $n=0;
      __label__ = 3; break;
    case 3: 
      var $3=$n;
      var $4=(($3)|0) < 286;
      if ($4) { __label__ = 4; break; } else { __label__ = 6; break; }
    case 4: 
      var $6=$n;
      var $7=$1;
      var $8=(($7+148)|0);
      var $9=(($8+($6<<2))|0);
      var $10=(($9)|0);
      var $11=$10;
      HEAP16[(($11)>>1)]=0;
      __label__ = 5; break;
    case 5: 
      var $13=$n;
      var $14=((($13)+(1))|0);
      $n=$14;
      __label__ = 3; break;
    case 6: 
      $n=0;
      __label__ = 7; break;
    case 7: 
      var $17=$n;
      var $18=(($17)|0) < 30;
      if ($18) { __label__ = 8; break; } else { __label__ = 10; break; }
    case 8: 
      var $20=$n;
      var $21=$1;
      var $22=(($21+2440)|0);
      var $23=(($22+($20<<2))|0);
      var $24=(($23)|0);
      var $25=$24;
      HEAP16[(($25)>>1)]=0;
      __label__ = 9; break;
    case 9: 
      var $27=$n;
      var $28=((($27)+(1))|0);
      $n=$28;
      __label__ = 7; break;
    case 10: 
      $n=0;
      __label__ = 11; break;
    case 11: 
      var $31=$n;
      var $32=(($31)|0) < 19;
      if ($32) { __label__ = 12; break; } else { __label__ = 14; break; }
    case 12: 
      var $34=$n;
      var $35=$1;
      var $36=(($35+2684)|0);
      var $37=(($36+($34<<2))|0);
      var $38=(($37)|0);
      var $39=$38;
      HEAP16[(($39)>>1)]=0;
      __label__ = 13; break;
    case 13: 
      var $41=$n;
      var $42=((($41)+(1))|0);
      $n=$42;
      __label__ = 11; break;
    case 14: 
      var $44=$1;
      var $45=(($44+148)|0);
      var $46=(($45+1024)|0);
      var $47=(($46)|0);
      var $48=$47;
      HEAP16[(($48)>>1)]=1;
      var $49=$1;
      var $50=(($49+5804)|0);
      HEAP32[(($50)>>2)]=0;
      var $51=$1;
      var $52=(($51+5800)|0);
      HEAP32[(($52)>>2)]=0;
      var $53=$1;
      var $54=(($53+5808)|0);
      HEAP32[(($54)>>2)]=0;
      var $55=$1;
      var $56=(($55+5792)|0);
      HEAP32[(($56)>>2)]=0;
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_init_block["X"]=1;

function _inflate_table($type, $lens, $codes, $table, $bits, $work) {
  var __stackBase__  = STACKTOP; STACKTOP += 68; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $5;
      var $6;
      var $7;
      var $len;
      var $sym;
      var $min;
      var $max;
      var $root;
      var $curr;
      var $drop;
      var $left;
      var $used;
      var $huff;
      var $incr;
      var $fill;
      var $low;
      var $mask;
      var $here=__stackBase__;
      var $next;
      var $base;
      var $extra;
      var $end;
      var $count=(__stackBase__)+(4);
      var $offs=(__stackBase__)+(36);
      $2=$type;
      $3=$lens;
      $4=$codes;
      $5=$table;
      $6=$bits;
      $7=$work;
      $len=0;
      __label__ = 3; break;
    case 3: 
      var $9=$len;
      var $10=(($9)>>>0) <= 15;
      if ($10) { __label__ = 4; break; } else { __label__ = 6; break; }
    case 4: 
      var $12=$len;
      var $13=(($count+($12<<1))|0);
      HEAP16[(($13)>>1)]=0;
      __label__ = 5; break;
    case 5: 
      var $15=$len;
      var $16=((($15)+(1))|0);
      $len=$16;
      __label__ = 3; break;
    case 6: 
      $sym=0;
      __label__ = 7; break;
    case 7: 
      var $19=$sym;
      var $20=$4;
      var $21=(($19)>>>0) < (($20)>>>0);
      if ($21) { __label__ = 8; break; } else { __label__ = 10; break; }
    case 8: 
      var $23=$sym;
      var $24=$3;
      var $25=(($24+($23<<1))|0);
      var $26=HEAPU16[(($25)>>1)];
      var $27=(($26)&65535);
      var $28=(($count+($27<<1))|0);
      var $29=HEAP16[(($28)>>1)];
      var $30=((($29)+(1))&65535);
      HEAP16[(($28)>>1)]=$30;
      __label__ = 9; break;
    case 9: 
      var $32=$sym;
      var $33=((($32)+(1))|0);
      $sym=$33;
      __label__ = 7; break;
    case 10: 
      var $35=$6;
      var $36=HEAP32[(($35)>>2)];
      $root=$36;
      $max=15;
      __label__ = 11; break;
    case 11: 
      var $38=$max;
      var $39=(($38)>>>0) >= 1;
      if ($39) { __label__ = 12; break; } else { __label__ = 16; break; }
    case 12: 
      var $41=$max;
      var $42=(($count+($41<<1))|0);
      var $43=HEAPU16[(($42)>>1)];
      var $44=(($43)&65535);
      var $45=(($44)|0)!=0;
      if ($45) { __label__ = 13; break; } else { __label__ = 14; break; }
    case 13: 
      __label__ = 16; break;
    case 14: 
      __label__ = 15; break;
    case 15: 
      var $49=$max;
      var $50=((($49)-(1))|0);
      $max=$50;
      __label__ = 11; break;
    case 16: 
      var $52=$root;
      var $53=$max;
      var $54=(($52)>>>0) > (($53)>>>0);
      if ($54) { __label__ = 17; break; } else { __label__ = 18; break; }
    case 17: 
      var $56=$max;
      $root=$56;
      __label__ = 18; break;
    case 18: 
      var $58=$max;
      var $59=(($58)|0)==0;
      if ($59) { __label__ = 19; break; } else { __label__ = 20; break; }
    case 19: 
      var $61=(($here)|0);
      HEAP8[($61)]=64;
      var $62=(($here+1)|0);
      HEAP8[($62)]=1;
      var $63=(($here+2)|0);
      HEAP16[(($63)>>1)]=0;
      var $64=$5;
      var $65=HEAP32[(($64)>>2)];
      var $66=(($65+4)|0);
      HEAP32[(($64)>>2)]=$66;
      var $67=$65;
      var $68=$here;
      assert(4 % 1 === 0, 'memcpy given ' + 4 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP16[(($67)>>1)]=HEAP16[(($68)>>1)];HEAP16[((($67)+(2))>>1)]=HEAP16[((($68)+(2))>>1)];
      var $69=$5;
      var $70=HEAP32[(($69)>>2)];
      var $71=(($70+4)|0);
      HEAP32[(($69)>>2)]=$71;
      var $72=$70;
      var $73=$here;
      assert(4 % 1 === 0, 'memcpy given ' + 4 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP16[(($72)>>1)]=HEAP16[(($73)>>1)];HEAP16[((($72)+(2))>>1)]=HEAP16[((($73)+(2))>>1)];
      var $74=$6;
      HEAP32[(($74)>>2)]=1;
      $1=0;
      __label__ = 96; break;
    case 20: 
      $min=1;
      __label__ = 21; break;
    case 21: 
      var $77=$min;
      var $78=$max;
      var $79=(($77)>>>0) < (($78)>>>0);
      if ($79) { __label__ = 22; break; } else { __label__ = 26; break; }
    case 22: 
      var $81=$min;
      var $82=(($count+($81<<1))|0);
      var $83=HEAPU16[(($82)>>1)];
      var $84=(($83)&65535);
      var $85=(($84)|0)!=0;
      if ($85) { __label__ = 23; break; } else { __label__ = 24; break; }
    case 23: 
      __label__ = 26; break;
    case 24: 
      __label__ = 25; break;
    case 25: 
      var $89=$min;
      var $90=((($89)+(1))|0);
      $min=$90;
      __label__ = 21; break;
    case 26: 
      var $92=$root;
      var $93=$min;
      var $94=(($92)>>>0) < (($93)>>>0);
      if ($94) { __label__ = 27; break; } else { __label__ = 28; break; }
    case 27: 
      var $96=$min;
      $root=$96;
      __label__ = 28; break;
    case 28: 
      $left=1;
      $len=1;
      __label__ = 29; break;
    case 29: 
      var $99=$len;
      var $100=(($99)>>>0) <= 15;
      if ($100) { __label__ = 30; break; } else { __label__ = 34; break; }
    case 30: 
      var $102=$left;
      var $103=$102 << 1;
      $left=$103;
      var $104=$len;
      var $105=(($count+($104<<1))|0);
      var $106=HEAPU16[(($105)>>1)];
      var $107=(($106)&65535);
      var $108=$left;
      var $109=((($108)-($107))|0);
      $left=$109;
      var $110=$left;
      var $111=(($110)|0) < 0;
      if ($111) { __label__ = 31; break; } else { __label__ = 32; break; }
    case 31: 
      $1=-1;
      __label__ = 96; break;
    case 32: 
      __label__ = 33; break;
    case 33: 
      var $115=$len;
      var $116=((($115)+(1))|0);
      $len=$116;
      __label__ = 29; break;
    case 34: 
      var $118=$left;
      var $119=(($118)|0) > 0;
      if ($119) { __label__ = 35; break; } else { __label__ = 38; break; }
    case 35: 
      var $121=$2;
      var $122=(($121)|0)==0;
      if ($122) { __label__ = 37; break; } else { __label__ = 36; break; }
    case 36: 
      var $124=$max;
      var $125=(($124)|0)!=1;
      if ($125) { __label__ = 37; break; } else { __label__ = 38; break; }
    case 37: 
      $1=-1;
      __label__ = 96; break;
    case 38: 
      var $128=(($offs+2)|0);
      HEAP16[(($128)>>1)]=0;
      $len=1;
      __label__ = 39; break;
    case 39: 
      var $130=$len;
      var $131=(($130)>>>0) < 15;
      if ($131) { __label__ = 40; break; } else { __label__ = 42; break; }
    case 40: 
      var $133=$len;
      var $134=(($offs+($133<<1))|0);
      var $135=HEAPU16[(($134)>>1)];
      var $136=(($135)&65535);
      var $137=$len;
      var $138=(($count+($137<<1))|0);
      var $139=HEAPU16[(($138)>>1)];
      var $140=(($139)&65535);
      var $141=((($136)+($140))|0);
      var $142=(($141) & 65535);
      var $143=$len;
      var $144=((($143)+(1))|0);
      var $145=(($offs+($144<<1))|0);
      HEAP16[(($145)>>1)]=$142;
      __label__ = 41; break;
    case 41: 
      var $147=$len;
      var $148=((($147)+(1))|0);
      $len=$148;
      __label__ = 39; break;
    case 42: 
      $sym=0;
      __label__ = 43; break;
    case 43: 
      var $151=$sym;
      var $152=$4;
      var $153=(($151)>>>0) < (($152)>>>0);
      if ($153) { __label__ = 44; break; } else { __label__ = 48; break; }
    case 44: 
      var $155=$sym;
      var $156=$3;
      var $157=(($156+($155<<1))|0);
      var $158=HEAPU16[(($157)>>1)];
      var $159=(($158)&65535);
      var $160=(($159)|0)!=0;
      if ($160) { __label__ = 45; break; } else { __label__ = 46; break; }
    case 45: 
      var $162=$sym;
      var $163=(($162) & 65535);
      var $164=$sym;
      var $165=$3;
      var $166=(($165+($164<<1))|0);
      var $167=HEAPU16[(($166)>>1)];
      var $168=(($167)&65535);
      var $169=(($offs+($168<<1))|0);
      var $170=HEAPU16[(($169)>>1)];
      var $171=((($170)+(1))&65535);
      HEAP16[(($169)>>1)]=$171;
      var $172=(($170)&65535);
      var $173=$7;
      var $174=(($173+($172<<1))|0);
      HEAP16[(($174)>>1)]=$163;
      __label__ = 46; break;
    case 46: 
      __label__ = 47; break;
    case 47: 
      var $177=$sym;
      var $178=((($177)+(1))|0);
      $sym=$178;
      __label__ = 43; break;
    case 48: 
      var $180=$2;
      if ((($180)|0) == 0) {
        __label__ = 49; break;
      }
      else if ((($180)|0) == 1) {
        __label__ = 50; break;
      }
      else {
      __label__ = 51; break;
      }
      
    case 49: 
      var $182=$7;
      $extra=$182;
      $base=$182;
      $end=19;
      __label__ = 52; break;
    case 50: 
      $base=((_inflate_table_lbase)|0);
      var $184=$base;
      var $185=((($184)-(514))|0);
      $base=$185;
      $extra=((_inflate_table_lext)|0);
      var $186=$extra;
      var $187=((($186)-(514))|0);
      $extra=$187;
      $end=256;
      __label__ = 52; break;
    case 51: 
      $base=((_inflate_table_dbase)|0);
      $extra=((_inflate_table_dext)|0);
      $end=-1;
      __label__ = 52; break;
    case 52: 
      $huff=0;
      $sym=0;
      var $190=$min;
      $len=$190;
      var $191=$5;
      var $192=HEAP32[(($191)>>2)];
      $next=$192;
      var $193=$root;
      $curr=$193;
      $drop=0;
      $low=-1;
      var $194=$root;
      var $195=1 << $194;
      $used=$195;
      var $196=$used;
      var $197=((($196)-(1))|0);
      $mask=$197;
      var $198=$2;
      var $199=(($198)|0)==1;
      if ($199) { __label__ = 53; break; } else { __label__ = 54; break; }
    case 53: 
      var $201=$used;
      var $202=(($201)>>>0) >= 852;
      if ($202) { __label__ = 56; break; } else { __label__ = 54; break; }
    case 54: 
      var $204=$2;
      var $205=(($204)|0)==2;
      if ($205) { __label__ = 55; break; } else { __label__ = 57; break; }
    case 55: 
      var $207=$used;
      var $208=(($207)>>>0) >= 592;
      if ($208) { __label__ = 56; break; } else { __label__ = 57; break; }
    case 56: 
      $1=1;
      __label__ = 96; break;
    case 57: 
      __label__ = 58; break;
    case 58: 
      var $212=$len;
      var $213=$drop;
      var $214=((($212)-($213))|0);
      var $215=(($214) & 255);
      var $216=(($here+1)|0);
      HEAP8[($216)]=$215;
      var $217=$sym;
      var $218=$7;
      var $219=(($218+($217<<1))|0);
      var $220=HEAPU16[(($219)>>1)];
      var $221=(($220)&65535);
      var $222=$end;
      var $223=(($221)|0) < (($222)|0);
      if ($223) { __label__ = 59; break; } else { __label__ = 60; break; }
    case 59: 
      var $225=(($here)|0);
      HEAP8[($225)]=0;
      var $226=$sym;
      var $227=$7;
      var $228=(($227+($226<<1))|0);
      var $229=HEAP16[(($228)>>1)];
      var $230=(($here+2)|0);
      HEAP16[(($230)>>1)]=$229;
      __label__ = 64; break;
    case 60: 
      var $232=$sym;
      var $233=$7;
      var $234=(($233+($232<<1))|0);
      var $235=HEAPU16[(($234)>>1)];
      var $236=(($235)&65535);
      var $237=$end;
      var $238=(($236)|0) > (($237)|0);
      if ($238) { __label__ = 61; break; } else { __label__ = 62; break; }
    case 61: 
      var $240=$sym;
      var $241=$7;
      var $242=(($241+($240<<1))|0);
      var $243=HEAPU16[(($242)>>1)];
      var $244=(($243)&65535);
      var $245=$extra;
      var $246=(($245+($244<<1))|0);
      var $247=HEAP16[(($246)>>1)];
      var $248=(($247) & 255);
      var $249=(($here)|0);
      HEAP8[($249)]=$248;
      var $250=$sym;
      var $251=$7;
      var $252=(($251+($250<<1))|0);
      var $253=HEAPU16[(($252)>>1)];
      var $254=(($253)&65535);
      var $255=$base;
      var $256=(($255+($254<<1))|0);
      var $257=HEAP16[(($256)>>1)];
      var $258=(($here+2)|0);
      HEAP16[(($258)>>1)]=$257;
      __label__ = 63; break;
    case 62: 
      var $260=(($here)|0);
      HEAP8[($260)]=96;
      var $261=(($here+2)|0);
      HEAP16[(($261)>>1)]=0;
      __label__ = 63; break;
    case 63: 
      __label__ = 64; break;
    case 64: 
      var $264=$len;
      var $265=$drop;
      var $266=((($264)-($265))|0);
      var $267=1 << $266;
      $incr=$267;
      var $268=$curr;
      var $269=1 << $268;
      $fill=$269;
      var $270=$fill;
      $min=$270;
      __label__ = 65; break;
    case 65: 
      var $272=$incr;
      var $273=$fill;
      var $274=((($273)-($272))|0);
      $fill=$274;
      var $275=$huff;
      var $276=$drop;
      var $277=$275 >>> (($276)>>>0);
      var $278=$fill;
      var $279=((($277)+($278))|0);
      var $280=$next;
      var $281=(($280+($279<<2))|0);
      var $282=$281;
      var $283=$here;
      assert(4 % 1 === 0, 'memcpy given ' + 4 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP16[(($282)>>1)]=HEAP16[(($283)>>1)];HEAP16[((($282)+(2))>>1)]=HEAP16[((($283)+(2))>>1)];
      __label__ = 66; break;
    case 66: 
      var $285=$fill;
      var $286=(($285)|0)!=0;
      if ($286) { __label__ = 65; break; } else { __label__ = 67; break; }
    case 67: 
      var $288=$len;
      var $289=((($288)-(1))|0);
      var $290=1 << $289;
      $incr=$290;
      __label__ = 68; break;
    case 68: 
      var $292=$huff;
      var $293=$incr;
      var $294=$292 & $293;
      var $295=(($294)|0)!=0;
      if ($295) { __label__ = 69; break; } else { __label__ = 70; break; }
    case 69: 
      var $297=$incr;
      var $298=$297 >>> 1;
      $incr=$298;
      __label__ = 68; break;
    case 70: 
      var $300=$incr;
      var $301=(($300)|0)!=0;
      if ($301) { __label__ = 71; break; } else { __label__ = 72; break; }
    case 71: 
      var $303=$incr;
      var $304=((($303)-(1))|0);
      var $305=$huff;
      var $306=$305 & $304;
      $huff=$306;
      var $307=$incr;
      var $308=$huff;
      var $309=((($308)+($307))|0);
      $huff=$309;
      __label__ = 73; break;
    case 72: 
      $huff=0;
      __label__ = 73; break;
    case 73: 
      var $312=$sym;
      var $313=((($312)+(1))|0);
      $sym=$313;
      var $314=$len;
      var $315=(($count+($314<<1))|0);
      var $316=HEAP16[(($315)>>1)];
      var $317=((($316)-(1))&65535);
      HEAP16[(($315)>>1)]=$317;
      var $318=(($317)&65535);
      var $319=(($318)|0)==0;
      if ($319) { __label__ = 74; break; } else { __label__ = 77; break; }
    case 74: 
      var $321=$len;
      var $322=$max;
      var $323=(($321)|0)==(($322)|0);
      if ($323) { __label__ = 75; break; } else { __label__ = 76; break; }
    case 75: 
      __label__ = 93; break;
    case 76: 
      var $326=$sym;
      var $327=$7;
      var $328=(($327+($326<<1))|0);
      var $329=HEAPU16[(($328)>>1)];
      var $330=(($329)&65535);
      var $331=$3;
      var $332=(($331+($330<<1))|0);
      var $333=HEAPU16[(($332)>>1)];
      var $334=(($333)&65535);
      $len=$334;
      __label__ = 77; break;
    case 77: 
      var $336=$len;
      var $337=$root;
      var $338=(($336)>>>0) > (($337)>>>0);
      if ($338) { __label__ = 78; break; } else { __label__ = 92; break; }
    case 78: 
      var $340=$huff;
      var $341=$mask;
      var $342=$340 & $341;
      var $343=$low;
      var $344=(($342)|0)!=(($343)|0);
      if ($344) { __label__ = 79; break; } else { __label__ = 92; break; }
    case 79: 
      var $346=$drop;
      var $347=(($346)|0)==0;
      if ($347) { __label__ = 80; break; } else { __label__ = 81; break; }
    case 80: 
      var $349=$root;
      $drop=$349;
      __label__ = 81; break;
    case 81: 
      var $351=$min;
      var $352=$next;
      var $353=(($352+($351<<2))|0);
      $next=$353;
      var $354=$len;
      var $355=$drop;
      var $356=((($354)-($355))|0);
      $curr=$356;
      var $357=$curr;
      var $358=1 << $357;
      $left=$358;
      __label__ = 82; break;
    case 82: 
      var $360=$curr;
      var $361=$drop;
      var $362=((($360)+($361))|0);
      var $363=$max;
      var $364=(($362)>>>0) < (($363)>>>0);
      if ($364) { __label__ = 83; break; } else { __label__ = 86; break; }
    case 83: 
      var $366=$curr;
      var $367=$drop;
      var $368=((($366)+($367))|0);
      var $369=(($count+($368<<1))|0);
      var $370=HEAPU16[(($369)>>1)];
      var $371=(($370)&65535);
      var $372=$left;
      var $373=((($372)-($371))|0);
      $left=$373;
      var $374=$left;
      var $375=(($374)|0) <= 0;
      if ($375) { __label__ = 84; break; } else { __label__ = 85; break; }
    case 84: 
      __label__ = 86; break;
    case 85: 
      var $378=$curr;
      var $379=((($378)+(1))|0);
      $curr=$379;
      var $380=$left;
      var $381=$380 << 1;
      $left=$381;
      __label__ = 82; break;
    case 86: 
      var $383=$curr;
      var $384=1 << $383;
      var $385=$used;
      var $386=((($385)+($384))|0);
      $used=$386;
      var $387=$2;
      var $388=(($387)|0)==1;
      if ($388) { __label__ = 87; break; } else { __label__ = 88; break; }
    case 87: 
      var $390=$used;
      var $391=(($390)>>>0) >= 852;
      if ($391) { __label__ = 90; break; } else { __label__ = 88; break; }
    case 88: 
      var $393=$2;
      var $394=(($393)|0)==2;
      if ($394) { __label__ = 89; break; } else { __label__ = 91; break; }
    case 89: 
      var $396=$used;
      var $397=(($396)>>>0) >= 592;
      if ($397) { __label__ = 90; break; } else { __label__ = 91; break; }
    case 90: 
      $1=1;
      __label__ = 96; break;
    case 91: 
      var $400=$huff;
      var $401=$mask;
      var $402=$400 & $401;
      $low=$402;
      var $403=$curr;
      var $404=(($403) & 255);
      var $405=$low;
      var $406=$5;
      var $407=HEAP32[(($406)>>2)];
      var $408=(($407+($405<<2))|0);
      var $409=(($408)|0);
      HEAP8[($409)]=$404;
      var $410=$root;
      var $411=(($410) & 255);
      var $412=$low;
      var $413=$5;
      var $414=HEAP32[(($413)>>2)];
      var $415=(($414+($412<<2))|0);
      var $416=(($415+1)|0);
      HEAP8[($416)]=$411;
      var $417=$next;
      var $418=$5;
      var $419=HEAP32[(($418)>>2)];
      var $420=$417;
      var $421=$419;
      var $422=((($420)-($421))|0);
      var $423=((((($422)|0))/(4))&-1);
      var $424=(($423) & 65535);
      var $425=$low;
      var $426=$5;
      var $427=HEAP32[(($426)>>2)];
      var $428=(($427+($425<<2))|0);
      var $429=(($428+2)|0);
      HEAP16[(($429)>>1)]=$424;
      __label__ = 92; break;
    case 92: 
      __label__ = 58; break;
    case 93: 
      var $432=$huff;
      var $433=(($432)|0)!=0;
      if ($433) { __label__ = 94; break; } else { __label__ = 95; break; }
    case 94: 
      var $435=(($here)|0);
      HEAP8[($435)]=64;
      var $436=$len;
      var $437=$drop;
      var $438=((($436)-($437))|0);
      var $439=(($438) & 255);
      var $440=(($here+1)|0);
      HEAP8[($440)]=$439;
      var $441=(($here+2)|0);
      HEAP16[(($441)>>1)]=0;
      var $442=$huff;
      var $443=$next;
      var $444=(($443+($442<<2))|0);
      var $445=$444;
      var $446=$here;
      assert(4 % 1 === 0, 'memcpy given ' + 4 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP16[(($445)>>1)]=HEAP16[(($446)>>1)];HEAP16[((($445)+(2))>>1)]=HEAP16[((($446)+(2))>>1)];
      __label__ = 95; break;
    case 95: 
      var $448=$used;
      var $449=$5;
      var $450=HEAP32[(($449)>>2)];
      var $451=(($450+($448<<2))|0);
      HEAP32[(($449)>>2)]=$451;
      var $452=$root;
      var $453=$6;
      HEAP32[(($453)>>2)]=$452;
      $1=0;
      __label__ = 96; break;
    case 96: 
      var $455=$1;
      STACKTOP = __stackBase__;
      return $455;
    default: assert(0, "bad label: " + __label__);
  }
}
_inflate_table["X"]=1;

function __tr_init($s) {
  ;
  var __label__;

  var $1;
  $1=$s;
  _tr_static_init();
  var $2=$1;
  var $3=(($2+148)|0);
  var $4=(($3)|0);
  var $5=$1;
  var $6=(($5+2840)|0);
  var $7=(($6)|0);
  HEAP32[(($7)>>2)]=$4;
  var $8=$1;
  var $9=(($8+2840)|0);
  var $10=(($9+8)|0);
  HEAP32[(($10)>>2)]=_static_l_desc;
  var $11=$1;
  var $12=(($11+2440)|0);
  var $13=(($12)|0);
  var $14=$1;
  var $15=(($14+2852)|0);
  var $16=(($15)|0);
  HEAP32[(($16)>>2)]=$13;
  var $17=$1;
  var $18=(($17+2852)|0);
  var $19=(($18+8)|0);
  HEAP32[(($19)>>2)]=_static_d_desc;
  var $20=$1;
  var $21=(($20+2684)|0);
  var $22=(($21)|0);
  var $23=$1;
  var $24=(($23+2864)|0);
  var $25=(($24)|0);
  HEAP32[(($25)>>2)]=$22;
  var $26=$1;
  var $27=(($26+2864)|0);
  var $28=(($27+8)|0);
  HEAP32[(($28)>>2)]=_static_bl_desc;
  var $29=$1;
  var $30=(($29+5816)|0);
  HEAP16[(($30)>>1)]=0;
  var $31=$1;
  var $32=(($31+5820)|0);
  HEAP32[(($32)>>2)]=0;
  var $33=$1;
  _init_block($33);
  ;
  return;
}


function _bi_flush($s) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      $1=$s;
      var $2=$1;
      var $3=(($2+5820)|0);
      var $4=HEAP32[(($3)>>2)];
      var $5=(($4)|0)==16;
      if ($5) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $7=$1;
      var $8=(($7+5816)|0);
      var $9=HEAPU16[(($8)>>1)];
      var $10=(($9)&65535);
      var $11=$10 & 255;
      var $12=(($11) & 255);
      var $13=$1;
      var $14=(($13+20)|0);
      var $15=HEAPU32[(($14)>>2)];
      var $16=((($15)+(1))|0);
      HEAP32[(($14)>>2)]=$16;
      var $17=$1;
      var $18=(($17+8)|0);
      var $19=HEAP32[(($18)>>2)];
      var $20=(($19+$15)|0);
      HEAP8[($20)]=$12;
      var $21=$1;
      var $22=(($21+5816)|0);
      var $23=HEAPU16[(($22)>>1)];
      var $24=(($23)&65535);
      var $25=$24 >> 8;
      var $26=(($25) & 255);
      var $27=$1;
      var $28=(($27+20)|0);
      var $29=HEAPU32[(($28)>>2)];
      var $30=((($29)+(1))|0);
      HEAP32[(($28)>>2)]=$30;
      var $31=$1;
      var $32=(($31+8)|0);
      var $33=HEAP32[(($32)>>2)];
      var $34=(($33+$29)|0);
      HEAP8[($34)]=$26;
      var $35=$1;
      var $36=(($35+5816)|0);
      HEAP16[(($36)>>1)]=0;
      var $37=$1;
      var $38=(($37+5820)|0);
      HEAP32[(($38)>>2)]=0;
      __label__ = 7; break;
    case 4: 
      var $40=$1;
      var $41=(($40+5820)|0);
      var $42=HEAP32[(($41)>>2)];
      var $43=(($42)|0) >= 8;
      if ($43) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $45=$1;
      var $46=(($45+5816)|0);
      var $47=HEAP16[(($46)>>1)];
      var $48=(($47) & 255);
      var $49=$1;
      var $50=(($49+20)|0);
      var $51=HEAP32[(($50)>>2)];
      var $52=((($51)+(1))|0);
      HEAP32[(($50)>>2)]=$52;
      var $53=$1;
      var $54=(($53+8)|0);
      var $55=HEAP32[(($54)>>2)];
      var $56=(($55+$51)|0);
      HEAP8[($56)]=$48;
      var $57=$1;
      var $58=(($57+5816)|0);
      var $59=HEAPU16[(($58)>>1)];
      var $60=(($59)&65535);
      var $61=$60 >> 8;
      var $62=(($61) & 65535);
      HEAP16[(($58)>>1)]=$62;
      var $63=$1;
      var $64=(($63+5820)|0);
      var $65=HEAP32[(($64)>>2)];
      var $66=((($65)-(8))|0);
      HEAP32[(($64)>>2)]=$66;
      __label__ = 6; break;
    case 6: 
      __label__ = 7; break;
    case 7: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_bi_flush["X"]=1;

function __tr_stored_block($s, $buf, $stored_len, $last) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $len;
      var $val;
      $1=$s;
      $2=$buf;
      $3=$stored_len;
      $4=$last;
      $len=3;
      var $5=$1;
      var $6=(($5+5820)|0);
      var $7=HEAP32[(($6)>>2)];
      var $8=$len;
      var $9=(((16)-($8))|0);
      var $10=(($7)|0) > (($9)|0);
      if ($10) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $12=$4;
      var $13=(($12)|0);
      $val=$13;
      var $14=$val;
      var $15=(($14) & 65535);
      var $16=(($15)&65535);
      var $17=$1;
      var $18=(($17+5820)|0);
      var $19=HEAP32[(($18)>>2)];
      var $20=$16 << $19;
      var $21=$1;
      var $22=(($21+5816)|0);
      var $23=HEAPU16[(($22)>>1)];
      var $24=(($23)&65535);
      var $25=$24 | $20;
      var $26=(($25) & 65535);
      HEAP16[(($22)>>1)]=$26;
      var $27=$1;
      var $28=(($27+5816)|0);
      var $29=HEAPU16[(($28)>>1)];
      var $30=(($29)&65535);
      var $31=$30 & 255;
      var $32=(($31) & 255);
      var $33=$1;
      var $34=(($33+20)|0);
      var $35=HEAPU32[(($34)>>2)];
      var $36=((($35)+(1))|0);
      HEAP32[(($34)>>2)]=$36;
      var $37=$1;
      var $38=(($37+8)|0);
      var $39=HEAP32[(($38)>>2)];
      var $40=(($39+$35)|0);
      HEAP8[($40)]=$32;
      var $41=$1;
      var $42=(($41+5816)|0);
      var $43=HEAPU16[(($42)>>1)];
      var $44=(($43)&65535);
      var $45=$44 >> 8;
      var $46=(($45) & 255);
      var $47=$1;
      var $48=(($47+20)|0);
      var $49=HEAPU32[(($48)>>2)];
      var $50=((($49)+(1))|0);
      HEAP32[(($48)>>2)]=$50;
      var $51=$1;
      var $52=(($51+8)|0);
      var $53=HEAP32[(($52)>>2)];
      var $54=(($53+$49)|0);
      HEAP8[($54)]=$46;
      var $55=$val;
      var $56=(($55) & 65535);
      var $57=(($56)&65535);
      var $58=$1;
      var $59=(($58+5820)|0);
      var $60=HEAP32[(($59)>>2)];
      var $61=(((16)-($60))|0);
      var $62=$57 >> (($61)|0);
      var $63=(($62) & 65535);
      var $64=$1;
      var $65=(($64+5816)|0);
      HEAP16[(($65)>>1)]=$63;
      var $66=$len;
      var $67=((($66)-(16))|0);
      var $68=$1;
      var $69=(($68+5820)|0);
      var $70=HEAP32[(($69)>>2)];
      var $71=((($70)+($67))|0);
      HEAP32[(($69)>>2)]=$71;
      __label__ = 5; break;
    case 4: 
      var $73=$4;
      var $74=(($73)|0);
      var $75=(($74) & 65535);
      var $76=(($75)&65535);
      var $77=$1;
      var $78=(($77+5820)|0);
      var $79=HEAP32[(($78)>>2)];
      var $80=$76 << $79;
      var $81=$1;
      var $82=(($81+5816)|0);
      var $83=HEAPU16[(($82)>>1)];
      var $84=(($83)&65535);
      var $85=$84 | $80;
      var $86=(($85) & 65535);
      HEAP16[(($82)>>1)]=$86;
      var $87=$len;
      var $88=$1;
      var $89=(($88+5820)|0);
      var $90=HEAP32[(($89)>>2)];
      var $91=((($90)+($87))|0);
      HEAP32[(($89)>>2)]=$91;
      __label__ = 5; break;
    case 5: 
      var $93=$1;
      var $94=$2;
      var $95=$3;
      _copy_block($93, $94, $95, 1);
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
__tr_stored_block["X"]=1;

function _copy_block($s, $buf, $len, $header) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      $1=$s;
      $2=$buf;
      $3=$len;
      $4=$header;
      var $5=$1;
      _bi_windup($5);
      var $6=$4;
      var $7=(($6)|0)!=0;
      if ($7) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $9=$3;
      var $10=(($9) & 65535);
      var $11=(($10)&65535);
      var $12=$11 & 255;
      var $13=(($12) & 255);
      var $14=$1;
      var $15=(($14+20)|0);
      var $16=HEAPU32[(($15)>>2)];
      var $17=((($16)+(1))|0);
      HEAP32[(($15)>>2)]=$17;
      var $18=$1;
      var $19=(($18+8)|0);
      var $20=HEAP32[(($19)>>2)];
      var $21=(($20+$16)|0);
      HEAP8[($21)]=$13;
      var $22=$3;
      var $23=(($22) & 65535);
      var $24=(($23)&65535);
      var $25=$24 >> 8;
      var $26=(($25) & 255);
      var $27=$1;
      var $28=(($27+20)|0);
      var $29=HEAPU32[(($28)>>2)];
      var $30=((($29)+(1))|0);
      HEAP32[(($28)>>2)]=$30;
      var $31=$1;
      var $32=(($31+8)|0);
      var $33=HEAP32[(($32)>>2)];
      var $34=(($33+$29)|0);
      HEAP8[($34)]=$26;
      var $35=$3;
      var $36=$35 ^ -1;
      var $37=(($36) & 65535);
      var $38=(($37)&65535);
      var $39=$38 & 255;
      var $40=(($39) & 255);
      var $41=$1;
      var $42=(($41+20)|0);
      var $43=HEAPU32[(($42)>>2)];
      var $44=((($43)+(1))|0);
      HEAP32[(($42)>>2)]=$44;
      var $45=$1;
      var $46=(($45+8)|0);
      var $47=HEAP32[(($46)>>2)];
      var $48=(($47+$43)|0);
      HEAP8[($48)]=$40;
      var $49=$3;
      var $50=$49 ^ -1;
      var $51=(($50) & 65535);
      var $52=(($51)&65535);
      var $53=$52 >> 8;
      var $54=(($53) & 255);
      var $55=$1;
      var $56=(($55+20)|0);
      var $57=HEAPU32[(($56)>>2)];
      var $58=((($57)+(1))|0);
      HEAP32[(($56)>>2)]=$58;
      var $59=$1;
      var $60=(($59+8)|0);
      var $61=HEAP32[(($60)>>2)];
      var $62=(($61+$57)|0);
      HEAP8[($62)]=$54;
      __label__ = 4; break;
    case 4: 
      __label__ = 5; break;
    case 5: 
      var $65=$3;
      var $66=((($65)-(1))|0);
      $3=$66;
      var $67=(($65)|0)!=0;
      if ($67) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      var $69=$2;
      var $70=(($69+1)|0);
      $2=$70;
      var $71=HEAP8[($69)];
      var $72=$1;
      var $73=(($72+20)|0);
      var $74=HEAP32[(($73)>>2)];
      var $75=((($74)+(1))|0);
      HEAP32[(($73)>>2)]=$75;
      var $76=$1;
      var $77=(($76+8)|0);
      var $78=HEAP32[(($77)>>2)];
      var $79=(($78+$74)|0);
      HEAP8[($79)]=$71;
      __label__ = 5; break;
    case 7: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_copy_block["X"]=1;

function __tr_flush_bits($s) {
  ;
  var __label__;

  var $1;
  $1=$s;
  var $2=$1;
  _bi_flush($2);
  ;
  return;
}


function __tr_align($s) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $len;
      var $val;
      var $len1;
      var $val2;
      $1=$s;
      $len=3;
      var $2=$1;
      var $3=(($2+5820)|0);
      var $4=HEAP32[(($3)>>2)];
      var $5=$len;
      var $6=(((16)-($5))|0);
      var $7=(($4)|0) > (($6)|0);
      if ($7) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      $val=2;
      var $9=$val;
      var $10=(($9) & 65535);
      var $11=(($10)&65535);
      var $12=$1;
      var $13=(($12+5820)|0);
      var $14=HEAP32[(($13)>>2)];
      var $15=$11 << $14;
      var $16=$1;
      var $17=(($16+5816)|0);
      var $18=HEAPU16[(($17)>>1)];
      var $19=(($18)&65535);
      var $20=$19 | $15;
      var $21=(($20) & 65535);
      HEAP16[(($17)>>1)]=$21;
      var $22=$1;
      var $23=(($22+5816)|0);
      var $24=HEAPU16[(($23)>>1)];
      var $25=(($24)&65535);
      var $26=$25 & 255;
      var $27=(($26) & 255);
      var $28=$1;
      var $29=(($28+20)|0);
      var $30=HEAPU32[(($29)>>2)];
      var $31=((($30)+(1))|0);
      HEAP32[(($29)>>2)]=$31;
      var $32=$1;
      var $33=(($32+8)|0);
      var $34=HEAP32[(($33)>>2)];
      var $35=(($34+$30)|0);
      HEAP8[($35)]=$27;
      var $36=$1;
      var $37=(($36+5816)|0);
      var $38=HEAPU16[(($37)>>1)];
      var $39=(($38)&65535);
      var $40=$39 >> 8;
      var $41=(($40) & 255);
      var $42=$1;
      var $43=(($42+20)|0);
      var $44=HEAPU32[(($43)>>2)];
      var $45=((($44)+(1))|0);
      HEAP32[(($43)>>2)]=$45;
      var $46=$1;
      var $47=(($46+8)|0);
      var $48=HEAP32[(($47)>>2)];
      var $49=(($48+$44)|0);
      HEAP8[($49)]=$41;
      var $50=$val;
      var $51=(($50) & 65535);
      var $52=(($51)&65535);
      var $53=$1;
      var $54=(($53+5820)|0);
      var $55=HEAP32[(($54)>>2)];
      var $56=(((16)-($55))|0);
      var $57=$52 >> (($56)|0);
      var $58=(($57) & 65535);
      var $59=$1;
      var $60=(($59+5816)|0);
      HEAP16[(($60)>>1)]=$58;
      var $61=$len;
      var $62=((($61)-(16))|0);
      var $63=$1;
      var $64=(($63+5820)|0);
      var $65=HEAP32[(($64)>>2)];
      var $66=((($65)+($62))|0);
      HEAP32[(($64)>>2)]=$66;
      __label__ = 5; break;
    case 4: 
      var $68=$1;
      var $69=(($68+5820)|0);
      var $70=HEAP32[(($69)>>2)];
      var $71=2 << $70;
      var $72=$1;
      var $73=(($72+5816)|0);
      var $74=HEAPU16[(($73)>>1)];
      var $75=(($74)&65535);
      var $76=$75 | $71;
      var $77=(($76) & 65535);
      HEAP16[(($73)>>1)]=$77;
      var $78=$len;
      var $79=$1;
      var $80=(($79+5820)|0);
      var $81=HEAP32[(($80)>>2)];
      var $82=((($81)+($78))|0);
      HEAP32[(($80)>>2)]=$82;
      __label__ = 5; break;
    case 5: 
      var $84=HEAPU16[((((_static_ltree+1026)|0))>>1)];
      var $85=(($84)&65535);
      $len1=$85;
      var $86=$1;
      var $87=(($86+5820)|0);
      var $88=HEAP32[(($87)>>2)];
      var $89=$len1;
      var $90=(((16)-($89))|0);
      var $91=(($88)|0) > (($90)|0);
      if ($91) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      var $93=HEAPU16[((((_static_ltree+1024)|0))>>1)];
      var $94=(($93)&65535);
      $val2=$94;
      var $95=$val2;
      var $96=(($95) & 65535);
      var $97=(($96)&65535);
      var $98=$1;
      var $99=(($98+5820)|0);
      var $100=HEAP32[(($99)>>2)];
      var $101=$97 << $100;
      var $102=$1;
      var $103=(($102+5816)|0);
      var $104=HEAPU16[(($103)>>1)];
      var $105=(($104)&65535);
      var $106=$105 | $101;
      var $107=(($106) & 65535);
      HEAP16[(($103)>>1)]=$107;
      var $108=$1;
      var $109=(($108+5816)|0);
      var $110=HEAPU16[(($109)>>1)];
      var $111=(($110)&65535);
      var $112=$111 & 255;
      var $113=(($112) & 255);
      var $114=$1;
      var $115=(($114+20)|0);
      var $116=HEAPU32[(($115)>>2)];
      var $117=((($116)+(1))|0);
      HEAP32[(($115)>>2)]=$117;
      var $118=$1;
      var $119=(($118+8)|0);
      var $120=HEAP32[(($119)>>2)];
      var $121=(($120+$116)|0);
      HEAP8[($121)]=$113;
      var $122=$1;
      var $123=(($122+5816)|0);
      var $124=HEAPU16[(($123)>>1)];
      var $125=(($124)&65535);
      var $126=$125 >> 8;
      var $127=(($126) & 255);
      var $128=$1;
      var $129=(($128+20)|0);
      var $130=HEAPU32[(($129)>>2)];
      var $131=((($130)+(1))|0);
      HEAP32[(($129)>>2)]=$131;
      var $132=$1;
      var $133=(($132+8)|0);
      var $134=HEAP32[(($133)>>2)];
      var $135=(($134+$130)|0);
      HEAP8[($135)]=$127;
      var $136=$val2;
      var $137=(($136) & 65535);
      var $138=(($137)&65535);
      var $139=$1;
      var $140=(($139+5820)|0);
      var $141=HEAP32[(($140)>>2)];
      var $142=(((16)-($141))|0);
      var $143=$138 >> (($142)|0);
      var $144=(($143) & 65535);
      var $145=$1;
      var $146=(($145+5816)|0);
      HEAP16[(($146)>>1)]=$144;
      var $147=$len1;
      var $148=((($147)-(16))|0);
      var $149=$1;
      var $150=(($149+5820)|0);
      var $151=HEAP32[(($150)>>2)];
      var $152=((($151)+($148))|0);
      HEAP32[(($150)>>2)]=$152;
      __label__ = 8; break;
    case 7: 
      var $154=HEAPU16[((((_static_ltree+1024)|0))>>1)];
      var $155=(($154)&65535);
      var $156=$1;
      var $157=(($156+5820)|0);
      var $158=HEAP32[(($157)>>2)];
      var $159=$155 << $158;
      var $160=$1;
      var $161=(($160+5816)|0);
      var $162=HEAPU16[(($161)>>1)];
      var $163=(($162)&65535);
      var $164=$163 | $159;
      var $165=(($164) & 65535);
      HEAP16[(($161)>>1)]=$165;
      var $166=$len1;
      var $167=$1;
      var $168=(($167+5820)|0);
      var $169=HEAP32[(($168)>>2)];
      var $170=((($169)+($166))|0);
      HEAP32[(($168)>>2)]=$170;
      __label__ = 8; break;
    case 8: 
      var $172=$1;
      _bi_flush($172);
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
__tr_align["X"]=1;

function __tr_flush_block($s, $buf, $stored_len, $last) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $opt_lenb;
      var $static_lenb;
      var $max_blindex;
      var $len;
      var $val;
      var $len1;
      var $val2;
      $1=$s;
      $2=$buf;
      $3=$stored_len;
      $4=$last;
      $max_blindex=0;
      var $5=$1;
      var $6=(($5+132)|0);
      var $7=HEAP32[(($6)>>2)];
      var $8=(($7)|0) > 0;
      if ($8) { __label__ = 3; break; } else { __label__ = 8; break; }
    case 3: 
      var $10=$1;
      var $11=(($10)|0);
      var $12=HEAP32[(($11)>>2)];
      var $13=(($12+44)|0);
      var $14=HEAP32[(($13)>>2)];
      var $15=(($14)|0)==2;
      if ($15) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      var $17=$1;
      var $18=_detect_data_type($17);
      var $19=$1;
      var $20=(($19)|0);
      var $21=HEAP32[(($20)>>2)];
      var $22=(($21+44)|0);
      HEAP32[(($22)>>2)]=$18;
      __label__ = 5; break;
    case 5: 
      var $24=$1;
      var $25=$1;
      var $26=(($25+2840)|0);
      _build_tree($24, $26);
      var $27=$1;
      var $28=$1;
      var $29=(($28+2852)|0);
      _build_tree($27, $29);
      var $30=$1;
      var $31=_build_bl_tree($30);
      $max_blindex=$31;
      var $32=$1;
      var $33=(($32+5800)|0);
      var $34=HEAP32[(($33)>>2)];
      var $35=((($34)+(3))|0);
      var $36=((($35)+(7))|0);
      var $37=$36 >>> 3;
      $opt_lenb=$37;
      var $38=$1;
      var $39=(($38+5804)|0);
      var $40=HEAP32[(($39)>>2)];
      var $41=((($40)+(3))|0);
      var $42=((($41)+(7))|0);
      var $43=$42 >>> 3;
      $static_lenb=$43;
      var $44=$static_lenb;
      var $45=$opt_lenb;
      var $46=(($44)>>>0) <= (($45)>>>0);
      if ($46) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      var $48=$static_lenb;
      $opt_lenb=$48;
      __label__ = 7; break;
    case 7: 
      __label__ = 9; break;
    case 8: 
      var $51=$3;
      var $52=((($51)+(5))|0);
      $static_lenb=$52;
      $opt_lenb=$52;
      __label__ = 9; break;
    case 9: 
      var $54=$3;
      var $55=((($54)+(4))|0);
      var $56=$opt_lenb;
      var $57=(($55)>>>0) <= (($56)>>>0);
      if ($57) { __label__ = 10; break; } else { __label__ = 12; break; }
    case 10: 
      var $59=$2;
      var $60=(($59)|0)!=0;
      if ($60) { __label__ = 11; break; } else { __label__ = 12; break; }
    case 11: 
      var $62=$1;
      var $63=$2;
      var $64=$3;
      var $65=$4;
      __tr_stored_block($62, $63, $64, $65);
      __label__ = 23; break;
    case 12: 
      var $67=$1;
      var $68=(($67+136)|0);
      var $69=HEAP32[(($68)>>2)];
      var $70=(($69)|0)==4;
      if ($70) { __label__ = 14; break; } else { __label__ = 13; break; }
    case 13: 
      var $72=$static_lenb;
      var $73=$opt_lenb;
      var $74=(($72)|0)==(($73)|0);
      if ($74) { __label__ = 14; break; } else { __label__ = 18; break; }
    case 14: 
      $len=3;
      var $76=$1;
      var $77=(($76+5820)|0);
      var $78=HEAP32[(($77)>>2)];
      var $79=$len;
      var $80=(((16)-($79))|0);
      var $81=(($78)|0) > (($80)|0);
      if ($81) { __label__ = 15; break; } else { __label__ = 16; break; }
    case 15: 
      var $83=$4;
      var $84=((($83)+(2))|0);
      $val=$84;
      var $85=$val;
      var $86=(($85) & 65535);
      var $87=(($86)&65535);
      var $88=$1;
      var $89=(($88+5820)|0);
      var $90=HEAP32[(($89)>>2)];
      var $91=$87 << $90;
      var $92=$1;
      var $93=(($92+5816)|0);
      var $94=HEAPU16[(($93)>>1)];
      var $95=(($94)&65535);
      var $96=$95 | $91;
      var $97=(($96) & 65535);
      HEAP16[(($93)>>1)]=$97;
      var $98=$1;
      var $99=(($98+5816)|0);
      var $100=HEAPU16[(($99)>>1)];
      var $101=(($100)&65535);
      var $102=$101 & 255;
      var $103=(($102) & 255);
      var $104=$1;
      var $105=(($104+20)|0);
      var $106=HEAPU32[(($105)>>2)];
      var $107=((($106)+(1))|0);
      HEAP32[(($105)>>2)]=$107;
      var $108=$1;
      var $109=(($108+8)|0);
      var $110=HEAP32[(($109)>>2)];
      var $111=(($110+$106)|0);
      HEAP8[($111)]=$103;
      var $112=$1;
      var $113=(($112+5816)|0);
      var $114=HEAPU16[(($113)>>1)];
      var $115=(($114)&65535);
      var $116=$115 >> 8;
      var $117=(($116) & 255);
      var $118=$1;
      var $119=(($118+20)|0);
      var $120=HEAPU32[(($119)>>2)];
      var $121=((($120)+(1))|0);
      HEAP32[(($119)>>2)]=$121;
      var $122=$1;
      var $123=(($122+8)|0);
      var $124=HEAP32[(($123)>>2)];
      var $125=(($124+$120)|0);
      HEAP8[($125)]=$117;
      var $126=$val;
      var $127=(($126) & 65535);
      var $128=(($127)&65535);
      var $129=$1;
      var $130=(($129+5820)|0);
      var $131=HEAP32[(($130)>>2)];
      var $132=(((16)-($131))|0);
      var $133=$128 >> (($132)|0);
      var $134=(($133) & 65535);
      var $135=$1;
      var $136=(($135+5816)|0);
      HEAP16[(($136)>>1)]=$134;
      var $137=$len;
      var $138=((($137)-(16))|0);
      var $139=$1;
      var $140=(($139+5820)|0);
      var $141=HEAP32[(($140)>>2)];
      var $142=((($141)+($138))|0);
      HEAP32[(($140)>>2)]=$142;
      __label__ = 17; break;
    case 16: 
      var $144=$4;
      var $145=((($144)+(2))|0);
      var $146=(($145) & 65535);
      var $147=(($146)&65535);
      var $148=$1;
      var $149=(($148+5820)|0);
      var $150=HEAP32[(($149)>>2)];
      var $151=$147 << $150;
      var $152=$1;
      var $153=(($152+5816)|0);
      var $154=HEAPU16[(($153)>>1)];
      var $155=(($154)&65535);
      var $156=$155 | $151;
      var $157=(($156) & 65535);
      HEAP16[(($153)>>1)]=$157;
      var $158=$len;
      var $159=$1;
      var $160=(($159+5820)|0);
      var $161=HEAP32[(($160)>>2)];
      var $162=((($161)+($158))|0);
      HEAP32[(($160)>>2)]=$162;
      __label__ = 17; break;
    case 17: 
      var $164=$1;
      _compress_block($164, ((_static_ltree)|0), ((_static_dtree)|0));
      __label__ = 22; break;
    case 18: 
      $len1=3;
      var $166=$1;
      var $167=(($166+5820)|0);
      var $168=HEAP32[(($167)>>2)];
      var $169=$len1;
      var $170=(((16)-($169))|0);
      var $171=(($168)|0) > (($170)|0);
      if ($171) { __label__ = 19; break; } else { __label__ = 20; break; }
    case 19: 
      var $173=$4;
      var $174=((($173)+(4))|0);
      $val2=$174;
      var $175=$val2;
      var $176=(($175) & 65535);
      var $177=(($176)&65535);
      var $178=$1;
      var $179=(($178+5820)|0);
      var $180=HEAP32[(($179)>>2)];
      var $181=$177 << $180;
      var $182=$1;
      var $183=(($182+5816)|0);
      var $184=HEAPU16[(($183)>>1)];
      var $185=(($184)&65535);
      var $186=$185 | $181;
      var $187=(($186) & 65535);
      HEAP16[(($183)>>1)]=$187;
      var $188=$1;
      var $189=(($188+5816)|0);
      var $190=HEAPU16[(($189)>>1)];
      var $191=(($190)&65535);
      var $192=$191 & 255;
      var $193=(($192) & 255);
      var $194=$1;
      var $195=(($194+20)|0);
      var $196=HEAPU32[(($195)>>2)];
      var $197=((($196)+(1))|0);
      HEAP32[(($195)>>2)]=$197;
      var $198=$1;
      var $199=(($198+8)|0);
      var $200=HEAP32[(($199)>>2)];
      var $201=(($200+$196)|0);
      HEAP8[($201)]=$193;
      var $202=$1;
      var $203=(($202+5816)|0);
      var $204=HEAPU16[(($203)>>1)];
      var $205=(($204)&65535);
      var $206=$205 >> 8;
      var $207=(($206) & 255);
      var $208=$1;
      var $209=(($208+20)|0);
      var $210=HEAPU32[(($209)>>2)];
      var $211=((($210)+(1))|0);
      HEAP32[(($209)>>2)]=$211;
      var $212=$1;
      var $213=(($212+8)|0);
      var $214=HEAP32[(($213)>>2)];
      var $215=(($214+$210)|0);
      HEAP8[($215)]=$207;
      var $216=$val2;
      var $217=(($216) & 65535);
      var $218=(($217)&65535);
      var $219=$1;
      var $220=(($219+5820)|0);
      var $221=HEAP32[(($220)>>2)];
      var $222=(((16)-($221))|0);
      var $223=$218 >> (($222)|0);
      var $224=(($223) & 65535);
      var $225=$1;
      var $226=(($225+5816)|0);
      HEAP16[(($226)>>1)]=$224;
      var $227=$len1;
      var $228=((($227)-(16))|0);
      var $229=$1;
      var $230=(($229+5820)|0);
      var $231=HEAP32[(($230)>>2)];
      var $232=((($231)+($228))|0);
      HEAP32[(($230)>>2)]=$232;
      __label__ = 21; break;
    case 20: 
      var $234=$4;
      var $235=((($234)+(4))|0);
      var $236=(($235) & 65535);
      var $237=(($236)&65535);
      var $238=$1;
      var $239=(($238+5820)|0);
      var $240=HEAP32[(($239)>>2)];
      var $241=$237 << $240;
      var $242=$1;
      var $243=(($242+5816)|0);
      var $244=HEAPU16[(($243)>>1)];
      var $245=(($244)&65535);
      var $246=$245 | $241;
      var $247=(($246) & 65535);
      HEAP16[(($243)>>1)]=$247;
      var $248=$len1;
      var $249=$1;
      var $250=(($249+5820)|0);
      var $251=HEAP32[(($250)>>2)];
      var $252=((($251)+($248))|0);
      HEAP32[(($250)>>2)]=$252;
      __label__ = 21; break;
    case 21: 
      var $254=$1;
      var $255=$1;
      var $256=(($255+2840)|0);
      var $257=(($256+4)|0);
      var $258=HEAP32[(($257)>>2)];
      var $259=((($258)+(1))|0);
      var $260=$1;
      var $261=(($260+2852)|0);
      var $262=(($261+4)|0);
      var $263=HEAP32[(($262)>>2)];
      var $264=((($263)+(1))|0);
      var $265=$max_blindex;
      var $266=((($265)+(1))|0);
      _send_all_trees($254, $259, $264, $266);
      var $267=$1;
      var $268=$1;
      var $269=(($268+148)|0);
      var $270=(($269)|0);
      var $271=$1;
      var $272=(($271+2440)|0);
      var $273=(($272)|0);
      _compress_block($267, $270, $273);
      __label__ = 22; break;
    case 22: 
      __label__ = 23; break;
    case 23: 
      var $276=$1;
      _init_block($276);
      var $277=$4;
      var $278=(($277)|0)!=0;
      if ($278) { __label__ = 24; break; } else { __label__ = 25; break; }
    case 24: 
      var $280=$1;
      _bi_windup($280);
      __label__ = 25; break;
    case 25: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
__tr_flush_block["X"]=1;

function _detect_data_type($s) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $black_mask;
      var $n;
      $2=$s;
      $black_mask=-201342849;
      $n=0;
      __label__ = 3; break;
    case 3: 
      var $4=$n;
      var $5=(($4)|0) <= 31;
      if ($5) { __label__ = 4; break; } else { __label__ = 9; break; }
    case 4: 
      var $7=$black_mask;
      var $8=$7 & 1;
      var $9=(($8)|0)!=0;
      if ($9) { __label__ = 5; break; } else { __label__ = 7; break; }
    case 5: 
      var $11=$n;
      var $12=$2;
      var $13=(($12+148)|0);
      var $14=(($13+($11<<2))|0);
      var $15=(($14)|0);
      var $16=$15;
      var $17=HEAPU16[(($16)>>1)];
      var $18=(($17)&65535);
      var $19=(($18)|0)!=0;
      if ($19) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      $1=0;
      __label__ = 20; break;
    case 7: 
      __label__ = 8; break;
    case 8: 
      var $23=$n;
      var $24=((($23)+(1))|0);
      $n=$24;
      var $25=$black_mask;
      var $26=$25 >>> 1;
      $black_mask=$26;
      __label__ = 3; break;
    case 9: 
      var $28=$2;
      var $29=(($28+148)|0);
      var $30=(($29+36)|0);
      var $31=(($30)|0);
      var $32=$31;
      var $33=HEAPU16[(($32)>>1)];
      var $34=(($33)&65535);
      var $35=(($34)|0)!=0;
      if ($35) { __label__ = 12; break; } else { __label__ = 10; break; }
    case 10: 
      var $37=$2;
      var $38=(($37+148)|0);
      var $39=(($38+40)|0);
      var $40=(($39)|0);
      var $41=$40;
      var $42=HEAPU16[(($41)>>1)];
      var $43=(($42)&65535);
      var $44=(($43)|0)!=0;
      if ($44) { __label__ = 12; break; } else { __label__ = 11; break; }
    case 11: 
      var $46=$2;
      var $47=(($46+148)|0);
      var $48=(($47+52)|0);
      var $49=(($48)|0);
      var $50=$49;
      var $51=HEAPU16[(($50)>>1)];
      var $52=(($51)&65535);
      var $53=(($52)|0)!=0;
      if ($53) { __label__ = 12; break; } else { __label__ = 13; break; }
    case 12: 
      $1=1;
      __label__ = 20; break;
    case 13: 
      $n=32;
      __label__ = 14; break;
    case 14: 
      var $57=$n;
      var $58=(($57)|0) < 256;
      if ($58) { __label__ = 15; break; } else { __label__ = 19; break; }
    case 15: 
      var $60=$n;
      var $61=$2;
      var $62=(($61+148)|0);
      var $63=(($62+($60<<2))|0);
      var $64=(($63)|0);
      var $65=$64;
      var $66=HEAPU16[(($65)>>1)];
      var $67=(($66)&65535);
      var $68=(($67)|0)!=0;
      if ($68) { __label__ = 16; break; } else { __label__ = 17; break; }
    case 16: 
      $1=1;
      __label__ = 20; break;
    case 17: 
      __label__ = 18; break;
    case 18: 
      var $72=$n;
      var $73=((($72)+(1))|0);
      $n=$73;
      __label__ = 14; break;
    case 19: 
      $1=0;
      __label__ = 20; break;
    case 20: 
      var $76=$1;
      ;
      return $76;
    default: assert(0, "bad label: " + __label__);
  }
}
_detect_data_type["X"]=1;

function _build_tree($s, $desc) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $tree;
      var $stree;
      var $elems;
      var $n;
      var $m;
      var $max_code;
      var $node;
      $1=$s;
      $2=$desc;
      var $3=$2;
      var $4=(($3)|0);
      var $5=HEAP32[(($4)>>2)];
      $tree=$5;
      var $6=$2;
      var $7=(($6+8)|0);
      var $8=HEAP32[(($7)>>2)];
      var $9=(($8)|0);
      var $10=HEAP32[(($9)>>2)];
      $stree=$10;
      var $11=$2;
      var $12=(($11+8)|0);
      var $13=HEAP32[(($12)>>2)];
      var $14=(($13+12)|0);
      var $15=HEAP32[(($14)>>2)];
      $elems=$15;
      $max_code=-1;
      var $16=$1;
      var $17=(($16+5200)|0);
      HEAP32[(($17)>>2)]=0;
      var $18=$1;
      var $19=(($18+5204)|0);
      HEAP32[(($19)>>2)]=573;
      $n=0;
      __label__ = 3; break;
    case 3: 
      var $21=$n;
      var $22=$elems;
      var $23=(($21)|0) < (($22)|0);
      if ($23) { __label__ = 4; break; } else { __label__ = 9; break; }
    case 4: 
      var $25=$n;
      var $26=$tree;
      var $27=(($26+($25<<2))|0);
      var $28=(($27)|0);
      var $29=$28;
      var $30=HEAPU16[(($29)>>1)];
      var $31=(($30)&65535);
      var $32=(($31)|0)!=0;
      if ($32) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $34=$n;
      $max_code=$34;
      var $35=$1;
      var $36=(($35+5200)|0);
      var $37=HEAP32[(($36)>>2)];
      var $38=((($37)+(1))|0);
      HEAP32[(($36)>>2)]=$38;
      var $39=$1;
      var $40=(($39+2908)|0);
      var $41=(($40+($38<<2))|0);
      HEAP32[(($41)>>2)]=$34;
      var $42=$n;
      var $43=$1;
      var $44=(($43+5208)|0);
      var $45=(($44+$42)|0);
      HEAP8[($45)]=0;
      __label__ = 7; break;
    case 6: 
      var $47=$n;
      var $48=$tree;
      var $49=(($48+($47<<2))|0);
      var $50=(($49+2)|0);
      var $51=$50;
      HEAP16[(($51)>>1)]=0;
      __label__ = 7; break;
    case 7: 
      __label__ = 8; break;
    case 8: 
      var $54=$n;
      var $55=((($54)+(1))|0);
      $n=$55;
      __label__ = 3; break;
    case 9: 
      __label__ = 10; break;
    case 10: 
      var $58=$1;
      var $59=(($58+5200)|0);
      var $60=HEAP32[(($59)>>2)];
      var $61=(($60)|0) < 2;
      if ($61) { __label__ = 11; break; } else { __label__ = 17; break; }
    case 11: 
      var $63=$max_code;
      var $64=(($63)|0) < 2;
      if ($64) { __label__ = 12; break; } else { __label__ = 13; break; }
    case 12: 
      var $66=$max_code;
      var $67=((($66)+(1))|0);
      $max_code=$67;
      var $70 = $67;__label__ = 14; break;
    case 13: 
      var $70 = 0;__label__ = 14; break;
    case 14: 
      var $70;
      var $71=$1;
      var $72=(($71+5200)|0);
      var $73=HEAP32[(($72)>>2)];
      var $74=((($73)+(1))|0);
      HEAP32[(($72)>>2)]=$74;
      var $75=$1;
      var $76=(($75+2908)|0);
      var $77=(($76+($74<<2))|0);
      HEAP32[(($77)>>2)]=$70;
      $node=$70;
      var $78=$node;
      var $79=$tree;
      var $80=(($79+($78<<2))|0);
      var $81=(($80)|0);
      var $82=$81;
      HEAP16[(($82)>>1)]=1;
      var $83=$node;
      var $84=$1;
      var $85=(($84+5208)|0);
      var $86=(($85+$83)|0);
      HEAP8[($86)]=0;
      var $87=$1;
      var $88=(($87+5800)|0);
      var $89=HEAP32[(($88)>>2)];
      var $90=((($89)-(1))|0);
      HEAP32[(($88)>>2)]=$90;
      var $91=$stree;
      var $92=(($91)|0)!=0;
      if ($92) { __label__ = 15; break; } else { __label__ = 16; break; }
    case 15: 
      var $94=$node;
      var $95=$stree;
      var $96=(($95+($94<<2))|0);
      var $97=(($96+2)|0);
      var $98=$97;
      var $99=HEAPU16[(($98)>>1)];
      var $100=(($99)&65535);
      var $101=$1;
      var $102=(($101+5804)|0);
      var $103=HEAP32[(($102)>>2)];
      var $104=((($103)-($100))|0);
      HEAP32[(($102)>>2)]=$104;
      __label__ = 16; break;
    case 16: 
      __label__ = 10; break;
    case 17: 
      var $107=$max_code;
      var $108=$2;
      var $109=(($108+4)|0);
      HEAP32[(($109)>>2)]=$107;
      var $110=$1;
      var $111=(($110+5200)|0);
      var $112=HEAP32[(($111)>>2)];
      var $113=((((($112)|0))/(2))&-1);
      $n=$113;
      __label__ = 18; break;
    case 18: 
      var $115=$n;
      var $116=(($115)|0) >= 1;
      if ($116) { __label__ = 19; break; } else { __label__ = 21; break; }
    case 19: 
      var $118=$1;
      var $119=$tree;
      var $120=$n;
      _pqdownheap($118, $119, $120);
      __label__ = 20; break;
    case 20: 
      var $122=$n;
      var $123=((($122)-(1))|0);
      $n=$123;
      __label__ = 18; break;
    case 21: 
      var $125=$elems;
      $node=$125;
      __label__ = 22; break;
    case 22: 
      var $127=$1;
      var $128=(($127+2908)|0);
      var $129=(($128+4)|0);
      var $130=HEAP32[(($129)>>2)];
      $n=$130;
      var $131=$1;
      var $132=(($131+5200)|0);
      var $133=HEAP32[(($132)>>2)];
      var $134=((($133)-(1))|0);
      HEAP32[(($132)>>2)]=$134;
      var $135=$1;
      var $136=(($135+2908)|0);
      var $137=(($136+($133<<2))|0);
      var $138=HEAP32[(($137)>>2)];
      var $139=$1;
      var $140=(($139+2908)|0);
      var $141=(($140+4)|0);
      HEAP32[(($141)>>2)]=$138;
      var $142=$1;
      var $143=$tree;
      _pqdownheap($142, $143, 1);
      var $144=$1;
      var $145=(($144+2908)|0);
      var $146=(($145+4)|0);
      var $147=HEAP32[(($146)>>2)];
      $m=$147;
      var $148=$n;
      var $149=$1;
      var $150=(($149+5204)|0);
      var $151=HEAP32[(($150)>>2)];
      var $152=((($151)-(1))|0);
      HEAP32[(($150)>>2)]=$152;
      var $153=$1;
      var $154=(($153+2908)|0);
      var $155=(($154+($152<<2))|0);
      HEAP32[(($155)>>2)]=$148;
      var $156=$m;
      var $157=$1;
      var $158=(($157+5204)|0);
      var $159=HEAP32[(($158)>>2)];
      var $160=((($159)-(1))|0);
      HEAP32[(($158)>>2)]=$160;
      var $161=$1;
      var $162=(($161+2908)|0);
      var $163=(($162+($160<<2))|0);
      HEAP32[(($163)>>2)]=$156;
      var $164=$n;
      var $165=$tree;
      var $166=(($165+($164<<2))|0);
      var $167=(($166)|0);
      var $168=$167;
      var $169=HEAPU16[(($168)>>1)];
      var $170=(($169)&65535);
      var $171=$m;
      var $172=$tree;
      var $173=(($172+($171<<2))|0);
      var $174=(($173)|0);
      var $175=$174;
      var $176=HEAPU16[(($175)>>1)];
      var $177=(($176)&65535);
      var $178=((($170)+($177))|0);
      var $179=(($178) & 65535);
      var $180=$node;
      var $181=$tree;
      var $182=(($181+($180<<2))|0);
      var $183=(($182)|0);
      var $184=$183;
      HEAP16[(($184)>>1)]=$179;
      var $185=$n;
      var $186=$1;
      var $187=(($186+5208)|0);
      var $188=(($187+$185)|0);
      var $189=HEAPU8[($188)];
      var $190=(($189)&255);
      var $191=$m;
      var $192=$1;
      var $193=(($192+5208)|0);
      var $194=(($193+$191)|0);
      var $195=HEAPU8[($194)];
      var $196=(($195)&255);
      var $197=(($190)|0) >= (($196)|0);
      if ($197) { __label__ = 23; break; } else { __label__ = 24; break; }
    case 23: 
      var $199=$n;
      var $200=$1;
      var $201=(($200+5208)|0);
      var $202=(($201+$199)|0);
      var $203=HEAPU8[($202)];
      var $204=(($203)&255);
      var $213 = $204;__label__ = 25; break;
    case 24: 
      var $206=$m;
      var $207=$1;
      var $208=(($207+5208)|0);
      var $209=(($208+$206)|0);
      var $210=HEAPU8[($209)];
      var $211=(($210)&255);
      var $213 = $211;__label__ = 25; break;
    case 25: 
      var $213;
      var $214=((($213)+(1))|0);
      var $215=(($214) & 255);
      var $216=$node;
      var $217=$1;
      var $218=(($217+5208)|0);
      var $219=(($218+$216)|0);
      HEAP8[($219)]=$215;
      var $220=$node;
      var $221=(($220) & 65535);
      var $222=$m;
      var $223=$tree;
      var $224=(($223+($222<<2))|0);
      var $225=(($224+2)|0);
      var $226=$225;
      HEAP16[(($226)>>1)]=$221;
      var $227=$n;
      var $228=$tree;
      var $229=(($228+($227<<2))|0);
      var $230=(($229+2)|0);
      var $231=$230;
      HEAP16[(($231)>>1)]=$221;
      var $232=$node;
      var $233=((($232)+(1))|0);
      $node=$233;
      var $234=$1;
      var $235=(($234+2908)|0);
      var $236=(($235+4)|0);
      HEAP32[(($236)>>2)]=$232;
      var $237=$1;
      var $238=$tree;
      _pqdownheap($237, $238, 1);
      __label__ = 26; break;
    case 26: 
      var $240=$1;
      var $241=(($240+5200)|0);
      var $242=HEAP32[(($241)>>2)];
      var $243=(($242)|0) >= 2;
      if ($243) { __label__ = 22; break; } else { __label__ = 27; break; }
    case 27: 
      var $245=$1;
      var $246=(($245+2908)|0);
      var $247=(($246+4)|0);
      var $248=HEAP32[(($247)>>2)];
      var $249=$1;
      var $250=(($249+5204)|0);
      var $251=HEAP32[(($250)>>2)];
      var $252=((($251)-(1))|0);
      HEAP32[(($250)>>2)]=$252;
      var $253=$1;
      var $254=(($253+2908)|0);
      var $255=(($254+($252<<2))|0);
      HEAP32[(($255)>>2)]=$248;
      var $256=$1;
      var $257=$2;
      _gen_bitlen($256, $257);
      var $258=$tree;
      var $259=$max_code;
      var $260=$1;
      var $261=(($260+2876)|0);
      var $262=(($261)|0);
      _gen_codes($258, $259, $262);
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_build_tree["X"]=1;

function _build_bl_tree($s) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $max_blindex;
      $1=$s;
      var $2=$1;
      var $3=$1;
      var $4=(($3+148)|0);
      var $5=(($4)|0);
      var $6=$1;
      var $7=(($6+2840)|0);
      var $8=(($7+4)|0);
      var $9=HEAP32[(($8)>>2)];
      _scan_tree($2, $5, $9);
      var $10=$1;
      var $11=$1;
      var $12=(($11+2440)|0);
      var $13=(($12)|0);
      var $14=$1;
      var $15=(($14+2852)|0);
      var $16=(($15+4)|0);
      var $17=HEAP32[(($16)>>2)];
      _scan_tree($10, $13, $17);
      var $18=$1;
      var $19=$1;
      var $20=(($19+2864)|0);
      _build_tree($18, $20);
      $max_blindex=18;
      __label__ = 3; break;
    case 3: 
      var $22=$max_blindex;
      var $23=(($22)|0) >= 3;
      if ($23) { __label__ = 4; break; } else { __label__ = 8; break; }
    case 4: 
      var $25=$max_blindex;
      var $26=((STRING_TABLE._bl_order+$25)|0);
      var $27=HEAPU8[($26)];
      var $28=(($27)&255);
      var $29=$1;
      var $30=(($29+2684)|0);
      var $31=(($30+($28<<2))|0);
      var $32=(($31+2)|0);
      var $33=$32;
      var $34=HEAPU16[(($33)>>1)];
      var $35=(($34)&65535);
      var $36=(($35)|0)!=0;
      if ($36) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      __label__ = 8; break;
    case 6: 
      __label__ = 7; break;
    case 7: 
      var $40=$max_blindex;
      var $41=((($40)-(1))|0);
      $max_blindex=$41;
      __label__ = 3; break;
    case 8: 
      var $43=$max_blindex;
      var $44=((($43)+(1))|0);
      var $45=((($44)*(3))|0);
      var $46=((($45)+(5))|0);
      var $47=((($46)+(5))|0);
      var $48=((($47)+(4))|0);
      var $49=$1;
      var $50=(($49+5800)|0);
      var $51=HEAP32[(($50)>>2)];
      var $52=((($51)+($48))|0);
      HEAP32[(($50)>>2)]=$52;
      var $53=$max_blindex;
      ;
      return $53;
    default: assert(0, "bad label: " + __label__);
  }
}
_build_bl_tree["X"]=1;

function _compress_block($s, $ltree, $dtree) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $dist;
      var $lc;
      var $lx;
      var $code;
      var $extra;
      var $len;
      var $val;
      var $len1;
      var $val2;
      var $len3;
      var $val4;
      var $len5;
      var $val6;
      var $len7;
      var $val8;
      var $len9;
      var $val10;
      $1=$s;
      $2=$ltree;
      $3=$dtree;
      $lx=0;
      var $4=$1;
      var $5=(($4+5792)|0);
      var $6=HEAP32[(($5)>>2)];
      var $7=(($6)|0)!=0;
      if ($7) { __label__ = 3; break; } else { __label__ = 32; break; }
    case 3: 
      __label__ = 4; break;
    case 4: 
      var $10=$lx;
      var $11=$1;
      var $12=(($11+5796)|0);
      var $13=HEAP32[(($12)>>2)];
      var $14=(($13+($10<<1))|0);
      var $15=HEAPU16[(($14)>>1)];
      var $16=(($15)&65535);
      $dist=$16;
      var $17=$lx;
      var $18=((($17)+(1))|0);
      $lx=$18;
      var $19=$1;
      var $20=(($19+5784)|0);
      var $21=HEAP32[(($20)>>2)];
      var $22=(($21+$17)|0);
      var $23=HEAPU8[($22)];
      var $24=(($23)&255);
      $lc=$24;
      var $25=$dist;
      var $26=(($25)|0)==0;
      if ($26) { __label__ = 5; break; } else { __label__ = 9; break; }
    case 5: 
      var $28=$lc;
      var $29=$2;
      var $30=(($29+($28<<2))|0);
      var $31=(($30+2)|0);
      var $32=$31;
      var $33=HEAPU16[(($32)>>1)];
      var $34=(($33)&65535);
      $len=$34;
      var $35=$1;
      var $36=(($35+5820)|0);
      var $37=HEAP32[(($36)>>2)];
      var $38=$len;
      var $39=(((16)-($38))|0);
      var $40=(($37)|0) > (($39)|0);
      if ($40) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      var $42=$lc;
      var $43=$2;
      var $44=(($43+($42<<2))|0);
      var $45=(($44)|0);
      var $46=$45;
      var $47=HEAPU16[(($46)>>1)];
      var $48=(($47)&65535);
      $val=$48;
      var $49=$val;
      var $50=(($49) & 65535);
      var $51=(($50)&65535);
      var $52=$1;
      var $53=(($52+5820)|0);
      var $54=HEAP32[(($53)>>2)];
      var $55=$51 << $54;
      var $56=$1;
      var $57=(($56+5816)|0);
      var $58=HEAPU16[(($57)>>1)];
      var $59=(($58)&65535);
      var $60=$59 | $55;
      var $61=(($60) & 65535);
      HEAP16[(($57)>>1)]=$61;
      var $62=$1;
      var $63=(($62+5816)|0);
      var $64=HEAPU16[(($63)>>1)];
      var $65=(($64)&65535);
      var $66=$65 & 255;
      var $67=(($66) & 255);
      var $68=$1;
      var $69=(($68+20)|0);
      var $70=HEAPU32[(($69)>>2)];
      var $71=((($70)+(1))|0);
      HEAP32[(($69)>>2)]=$71;
      var $72=$1;
      var $73=(($72+8)|0);
      var $74=HEAP32[(($73)>>2)];
      var $75=(($74+$70)|0);
      HEAP8[($75)]=$67;
      var $76=$1;
      var $77=(($76+5816)|0);
      var $78=HEAPU16[(($77)>>1)];
      var $79=(($78)&65535);
      var $80=$79 >> 8;
      var $81=(($80) & 255);
      var $82=$1;
      var $83=(($82+20)|0);
      var $84=HEAPU32[(($83)>>2)];
      var $85=((($84)+(1))|0);
      HEAP32[(($83)>>2)]=$85;
      var $86=$1;
      var $87=(($86+8)|0);
      var $88=HEAP32[(($87)>>2)];
      var $89=(($88+$84)|0);
      HEAP8[($89)]=$81;
      var $90=$val;
      var $91=(($90) & 65535);
      var $92=(($91)&65535);
      var $93=$1;
      var $94=(($93+5820)|0);
      var $95=HEAP32[(($94)>>2)];
      var $96=(((16)-($95))|0);
      var $97=$92 >> (($96)|0);
      var $98=(($97) & 65535);
      var $99=$1;
      var $100=(($99+5816)|0);
      HEAP16[(($100)>>1)]=$98;
      var $101=$len;
      var $102=((($101)-(16))|0);
      var $103=$1;
      var $104=(($103+5820)|0);
      var $105=HEAP32[(($104)>>2)];
      var $106=((($105)+($102))|0);
      HEAP32[(($104)>>2)]=$106;
      __label__ = 8; break;
    case 7: 
      var $108=$lc;
      var $109=$2;
      var $110=(($109+($108<<2))|0);
      var $111=(($110)|0);
      var $112=$111;
      var $113=HEAPU16[(($112)>>1)];
      var $114=(($113)&65535);
      var $115=$1;
      var $116=(($115+5820)|0);
      var $117=HEAP32[(($116)>>2)];
      var $118=$114 << $117;
      var $119=$1;
      var $120=(($119+5816)|0);
      var $121=HEAPU16[(($120)>>1)];
      var $122=(($121)&65535);
      var $123=$122 | $118;
      var $124=(($123) & 65535);
      HEAP16[(($120)>>1)]=$124;
      var $125=$len;
      var $126=$1;
      var $127=(($126+5820)|0);
      var $128=HEAP32[(($127)>>2)];
      var $129=((($128)+($125))|0);
      HEAP32[(($127)>>2)]=$129;
      __label__ = 8; break;
    case 8: 
      __label__ = 29; break;
    case 9: 
      var $132=$lc;
      var $133=((STRING_TABLE.__length_code+$132)|0);
      var $134=HEAPU8[($133)];
      var $135=(($134)&255);
      $code=$135;
      var $136=$code;
      var $137=((($136)+(256))|0);
      var $138=((($137)+(1))|0);
      var $139=$2;
      var $140=(($139+($138<<2))|0);
      var $141=(($140+2)|0);
      var $142=$141;
      var $143=HEAPU16[(($142)>>1)];
      var $144=(($143)&65535);
      $len1=$144;
      var $145=$1;
      var $146=(($145+5820)|0);
      var $147=HEAP32[(($146)>>2)];
      var $148=$len1;
      var $149=(((16)-($148))|0);
      var $150=(($147)|0) > (($149)|0);
      if ($150) { __label__ = 10; break; } else { __label__ = 11; break; }
    case 10: 
      var $152=$code;
      var $153=((($152)+(256))|0);
      var $154=((($153)+(1))|0);
      var $155=$2;
      var $156=(($155+($154<<2))|0);
      var $157=(($156)|0);
      var $158=$157;
      var $159=HEAPU16[(($158)>>1)];
      var $160=(($159)&65535);
      $val2=$160;
      var $161=$val2;
      var $162=(($161) & 65535);
      var $163=(($162)&65535);
      var $164=$1;
      var $165=(($164+5820)|0);
      var $166=HEAP32[(($165)>>2)];
      var $167=$163 << $166;
      var $168=$1;
      var $169=(($168+5816)|0);
      var $170=HEAPU16[(($169)>>1)];
      var $171=(($170)&65535);
      var $172=$171 | $167;
      var $173=(($172) & 65535);
      HEAP16[(($169)>>1)]=$173;
      var $174=$1;
      var $175=(($174+5816)|0);
      var $176=HEAPU16[(($175)>>1)];
      var $177=(($176)&65535);
      var $178=$177 & 255;
      var $179=(($178) & 255);
      var $180=$1;
      var $181=(($180+20)|0);
      var $182=HEAPU32[(($181)>>2)];
      var $183=((($182)+(1))|0);
      HEAP32[(($181)>>2)]=$183;
      var $184=$1;
      var $185=(($184+8)|0);
      var $186=HEAP32[(($185)>>2)];
      var $187=(($186+$182)|0);
      HEAP8[($187)]=$179;
      var $188=$1;
      var $189=(($188+5816)|0);
      var $190=HEAPU16[(($189)>>1)];
      var $191=(($190)&65535);
      var $192=$191 >> 8;
      var $193=(($192) & 255);
      var $194=$1;
      var $195=(($194+20)|0);
      var $196=HEAPU32[(($195)>>2)];
      var $197=((($196)+(1))|0);
      HEAP32[(($195)>>2)]=$197;
      var $198=$1;
      var $199=(($198+8)|0);
      var $200=HEAP32[(($199)>>2)];
      var $201=(($200+$196)|0);
      HEAP8[($201)]=$193;
      var $202=$val2;
      var $203=(($202) & 65535);
      var $204=(($203)&65535);
      var $205=$1;
      var $206=(($205+5820)|0);
      var $207=HEAP32[(($206)>>2)];
      var $208=(((16)-($207))|0);
      var $209=$204 >> (($208)|0);
      var $210=(($209) & 65535);
      var $211=$1;
      var $212=(($211+5816)|0);
      HEAP16[(($212)>>1)]=$210;
      var $213=$len1;
      var $214=((($213)-(16))|0);
      var $215=$1;
      var $216=(($215+5820)|0);
      var $217=HEAP32[(($216)>>2)];
      var $218=((($217)+($214))|0);
      HEAP32[(($216)>>2)]=$218;
      __label__ = 12; break;
    case 11: 
      var $220=$code;
      var $221=((($220)+(256))|0);
      var $222=((($221)+(1))|0);
      var $223=$2;
      var $224=(($223+($222<<2))|0);
      var $225=(($224)|0);
      var $226=$225;
      var $227=HEAPU16[(($226)>>1)];
      var $228=(($227)&65535);
      var $229=$1;
      var $230=(($229+5820)|0);
      var $231=HEAP32[(($230)>>2)];
      var $232=$228 << $231;
      var $233=$1;
      var $234=(($233+5816)|0);
      var $235=HEAPU16[(($234)>>1)];
      var $236=(($235)&65535);
      var $237=$236 | $232;
      var $238=(($237) & 65535);
      HEAP16[(($234)>>1)]=$238;
      var $239=$len1;
      var $240=$1;
      var $241=(($240+5820)|0);
      var $242=HEAP32[(($241)>>2)];
      var $243=((($242)+($239))|0);
      HEAP32[(($241)>>2)]=$243;
      __label__ = 12; break;
    case 12: 
      var $245=$code;
      var $246=((_extra_lbits+($245<<2))|0);
      var $247=HEAP32[(($246)>>2)];
      $extra=$247;
      var $248=$extra;
      var $249=(($248)|0)!=0;
      if ($249) { __label__ = 13; break; } else { __label__ = 17; break; }
    case 13: 
      var $251=$code;
      var $252=((_base_length+($251<<2))|0);
      var $253=HEAP32[(($252)>>2)];
      var $254=$lc;
      var $255=((($254)-($253))|0);
      $lc=$255;
      var $256=$extra;
      $len3=$256;
      var $257=$1;
      var $258=(($257+5820)|0);
      var $259=HEAP32[(($258)>>2)];
      var $260=$len3;
      var $261=(((16)-($260))|0);
      var $262=(($259)|0) > (($261)|0);
      if ($262) { __label__ = 14; break; } else { __label__ = 15; break; }
    case 14: 
      var $264=$lc;
      $val4=$264;
      var $265=$val4;
      var $266=(($265) & 65535);
      var $267=(($266)&65535);
      var $268=$1;
      var $269=(($268+5820)|0);
      var $270=HEAP32[(($269)>>2)];
      var $271=$267 << $270;
      var $272=$1;
      var $273=(($272+5816)|0);
      var $274=HEAPU16[(($273)>>1)];
      var $275=(($274)&65535);
      var $276=$275 | $271;
      var $277=(($276) & 65535);
      HEAP16[(($273)>>1)]=$277;
      var $278=$1;
      var $279=(($278+5816)|0);
      var $280=HEAPU16[(($279)>>1)];
      var $281=(($280)&65535);
      var $282=$281 & 255;
      var $283=(($282) & 255);
      var $284=$1;
      var $285=(($284+20)|0);
      var $286=HEAPU32[(($285)>>2)];
      var $287=((($286)+(1))|0);
      HEAP32[(($285)>>2)]=$287;
      var $288=$1;
      var $289=(($288+8)|0);
      var $290=HEAP32[(($289)>>2)];
      var $291=(($290+$286)|0);
      HEAP8[($291)]=$283;
      var $292=$1;
      var $293=(($292+5816)|0);
      var $294=HEAPU16[(($293)>>1)];
      var $295=(($294)&65535);
      var $296=$295 >> 8;
      var $297=(($296) & 255);
      var $298=$1;
      var $299=(($298+20)|0);
      var $300=HEAPU32[(($299)>>2)];
      var $301=((($300)+(1))|0);
      HEAP32[(($299)>>2)]=$301;
      var $302=$1;
      var $303=(($302+8)|0);
      var $304=HEAP32[(($303)>>2)];
      var $305=(($304+$300)|0);
      HEAP8[($305)]=$297;
      var $306=$val4;
      var $307=(($306) & 65535);
      var $308=(($307)&65535);
      var $309=$1;
      var $310=(($309+5820)|0);
      var $311=HEAP32[(($310)>>2)];
      var $312=(((16)-($311))|0);
      var $313=$308 >> (($312)|0);
      var $314=(($313) & 65535);
      var $315=$1;
      var $316=(($315+5816)|0);
      HEAP16[(($316)>>1)]=$314;
      var $317=$len3;
      var $318=((($317)-(16))|0);
      var $319=$1;
      var $320=(($319+5820)|0);
      var $321=HEAP32[(($320)>>2)];
      var $322=((($321)+($318))|0);
      HEAP32[(($320)>>2)]=$322;
      __label__ = 16; break;
    case 15: 
      var $324=$lc;
      var $325=(($324) & 65535);
      var $326=(($325)&65535);
      var $327=$1;
      var $328=(($327+5820)|0);
      var $329=HEAP32[(($328)>>2)];
      var $330=$326 << $329;
      var $331=$1;
      var $332=(($331+5816)|0);
      var $333=HEAPU16[(($332)>>1)];
      var $334=(($333)&65535);
      var $335=$334 | $330;
      var $336=(($335) & 65535);
      HEAP16[(($332)>>1)]=$336;
      var $337=$len3;
      var $338=$1;
      var $339=(($338+5820)|0);
      var $340=HEAP32[(($339)>>2)];
      var $341=((($340)+($337))|0);
      HEAP32[(($339)>>2)]=$341;
      __label__ = 16; break;
    case 16: 
      __label__ = 17; break;
    case 17: 
      var $344=$dist;
      var $345=((($344)-(1))|0);
      $dist=$345;
      var $346=$dist;
      var $347=(($346)>>>0) < 256;
      if ($347) { __label__ = 18; break; } else { __label__ = 19; break; }
    case 18: 
      var $349=$dist;
      var $350=((STRING_TABLE.__dist_code+$349)|0);
      var $351=HEAPU8[($350)];
      var $352=(($351)&255);
      var $361 = $352;__label__ = 20; break;
    case 19: 
      var $354=$dist;
      var $355=$354 >>> 7;
      var $356=((($355)+(256))|0);
      var $357=((STRING_TABLE.__dist_code+$356)|0);
      var $358=HEAPU8[($357)];
      var $359=(($358)&255);
      var $361 = $359;__label__ = 20; break;
    case 20: 
      var $361;
      $code=$361;
      var $362=$code;
      var $363=$3;
      var $364=(($363+($362<<2))|0);
      var $365=(($364+2)|0);
      var $366=$365;
      var $367=HEAPU16[(($366)>>1)];
      var $368=(($367)&65535);
      $len5=$368;
      var $369=$1;
      var $370=(($369+5820)|0);
      var $371=HEAP32[(($370)>>2)];
      var $372=$len5;
      var $373=(((16)-($372))|0);
      var $374=(($371)|0) > (($373)|0);
      if ($374) { __label__ = 21; break; } else { __label__ = 22; break; }
    case 21: 
      var $376=$code;
      var $377=$3;
      var $378=(($377+($376<<2))|0);
      var $379=(($378)|0);
      var $380=$379;
      var $381=HEAPU16[(($380)>>1)];
      var $382=(($381)&65535);
      $val6=$382;
      var $383=$val6;
      var $384=(($383) & 65535);
      var $385=(($384)&65535);
      var $386=$1;
      var $387=(($386+5820)|0);
      var $388=HEAP32[(($387)>>2)];
      var $389=$385 << $388;
      var $390=$1;
      var $391=(($390+5816)|0);
      var $392=HEAPU16[(($391)>>1)];
      var $393=(($392)&65535);
      var $394=$393 | $389;
      var $395=(($394) & 65535);
      HEAP16[(($391)>>1)]=$395;
      var $396=$1;
      var $397=(($396+5816)|0);
      var $398=HEAPU16[(($397)>>1)];
      var $399=(($398)&65535);
      var $400=$399 & 255;
      var $401=(($400) & 255);
      var $402=$1;
      var $403=(($402+20)|0);
      var $404=HEAPU32[(($403)>>2)];
      var $405=((($404)+(1))|0);
      HEAP32[(($403)>>2)]=$405;
      var $406=$1;
      var $407=(($406+8)|0);
      var $408=HEAP32[(($407)>>2)];
      var $409=(($408+$404)|0);
      HEAP8[($409)]=$401;
      var $410=$1;
      var $411=(($410+5816)|0);
      var $412=HEAPU16[(($411)>>1)];
      var $413=(($412)&65535);
      var $414=$413 >> 8;
      var $415=(($414) & 255);
      var $416=$1;
      var $417=(($416+20)|0);
      var $418=HEAPU32[(($417)>>2)];
      var $419=((($418)+(1))|0);
      HEAP32[(($417)>>2)]=$419;
      var $420=$1;
      var $421=(($420+8)|0);
      var $422=HEAP32[(($421)>>2)];
      var $423=(($422+$418)|0);
      HEAP8[($423)]=$415;
      var $424=$val6;
      var $425=(($424) & 65535);
      var $426=(($425)&65535);
      var $427=$1;
      var $428=(($427+5820)|0);
      var $429=HEAP32[(($428)>>2)];
      var $430=(((16)-($429))|0);
      var $431=$426 >> (($430)|0);
      var $432=(($431) & 65535);
      var $433=$1;
      var $434=(($433+5816)|0);
      HEAP16[(($434)>>1)]=$432;
      var $435=$len5;
      var $436=((($435)-(16))|0);
      var $437=$1;
      var $438=(($437+5820)|0);
      var $439=HEAP32[(($438)>>2)];
      var $440=((($439)+($436))|0);
      HEAP32[(($438)>>2)]=$440;
      __label__ = 23; break;
    case 22: 
      var $442=$code;
      var $443=$3;
      var $444=(($443+($442<<2))|0);
      var $445=(($444)|0);
      var $446=$445;
      var $447=HEAPU16[(($446)>>1)];
      var $448=(($447)&65535);
      var $449=$1;
      var $450=(($449+5820)|0);
      var $451=HEAP32[(($450)>>2)];
      var $452=$448 << $451;
      var $453=$1;
      var $454=(($453+5816)|0);
      var $455=HEAPU16[(($454)>>1)];
      var $456=(($455)&65535);
      var $457=$456 | $452;
      var $458=(($457) & 65535);
      HEAP16[(($454)>>1)]=$458;
      var $459=$len5;
      var $460=$1;
      var $461=(($460+5820)|0);
      var $462=HEAP32[(($461)>>2)];
      var $463=((($462)+($459))|0);
      HEAP32[(($461)>>2)]=$463;
      __label__ = 23; break;
    case 23: 
      var $465=$code;
      var $466=((_extra_dbits+($465<<2))|0);
      var $467=HEAP32[(($466)>>2)];
      $extra=$467;
      var $468=$extra;
      var $469=(($468)|0)!=0;
      if ($469) { __label__ = 24; break; } else { __label__ = 28; break; }
    case 24: 
      var $471=$code;
      var $472=((_base_dist+($471<<2))|0);
      var $473=HEAP32[(($472)>>2)];
      var $474=$dist;
      var $475=((($474)-($473))|0);
      $dist=$475;
      var $476=$extra;
      $len7=$476;
      var $477=$1;
      var $478=(($477+5820)|0);
      var $479=HEAP32[(($478)>>2)];
      var $480=$len7;
      var $481=(((16)-($480))|0);
      var $482=(($479)|0) > (($481)|0);
      if ($482) { __label__ = 25; break; } else { __label__ = 26; break; }
    case 25: 
      var $484=$dist;
      $val8=$484;
      var $485=$val8;
      var $486=(($485) & 65535);
      var $487=(($486)&65535);
      var $488=$1;
      var $489=(($488+5820)|0);
      var $490=HEAP32[(($489)>>2)];
      var $491=$487 << $490;
      var $492=$1;
      var $493=(($492+5816)|0);
      var $494=HEAPU16[(($493)>>1)];
      var $495=(($494)&65535);
      var $496=$495 | $491;
      var $497=(($496) & 65535);
      HEAP16[(($493)>>1)]=$497;
      var $498=$1;
      var $499=(($498+5816)|0);
      var $500=HEAPU16[(($499)>>1)];
      var $501=(($500)&65535);
      var $502=$501 & 255;
      var $503=(($502) & 255);
      var $504=$1;
      var $505=(($504+20)|0);
      var $506=HEAPU32[(($505)>>2)];
      var $507=((($506)+(1))|0);
      HEAP32[(($505)>>2)]=$507;
      var $508=$1;
      var $509=(($508+8)|0);
      var $510=HEAP32[(($509)>>2)];
      var $511=(($510+$506)|0);
      HEAP8[($511)]=$503;
      var $512=$1;
      var $513=(($512+5816)|0);
      var $514=HEAPU16[(($513)>>1)];
      var $515=(($514)&65535);
      var $516=$515 >> 8;
      var $517=(($516) & 255);
      var $518=$1;
      var $519=(($518+20)|0);
      var $520=HEAPU32[(($519)>>2)];
      var $521=((($520)+(1))|0);
      HEAP32[(($519)>>2)]=$521;
      var $522=$1;
      var $523=(($522+8)|0);
      var $524=HEAP32[(($523)>>2)];
      var $525=(($524+$520)|0);
      HEAP8[($525)]=$517;
      var $526=$val8;
      var $527=(($526) & 65535);
      var $528=(($527)&65535);
      var $529=$1;
      var $530=(($529+5820)|0);
      var $531=HEAP32[(($530)>>2)];
      var $532=(((16)-($531))|0);
      var $533=$528 >> (($532)|0);
      var $534=(($533) & 65535);
      var $535=$1;
      var $536=(($535+5816)|0);
      HEAP16[(($536)>>1)]=$534;
      var $537=$len7;
      var $538=((($537)-(16))|0);
      var $539=$1;
      var $540=(($539+5820)|0);
      var $541=HEAP32[(($540)>>2)];
      var $542=((($541)+($538))|0);
      HEAP32[(($540)>>2)]=$542;
      __label__ = 27; break;
    case 26: 
      var $544=$dist;
      var $545=(($544) & 65535);
      var $546=(($545)&65535);
      var $547=$1;
      var $548=(($547+5820)|0);
      var $549=HEAP32[(($548)>>2)];
      var $550=$546 << $549;
      var $551=$1;
      var $552=(($551+5816)|0);
      var $553=HEAPU16[(($552)>>1)];
      var $554=(($553)&65535);
      var $555=$554 | $550;
      var $556=(($555) & 65535);
      HEAP16[(($552)>>1)]=$556;
      var $557=$len7;
      var $558=$1;
      var $559=(($558+5820)|0);
      var $560=HEAP32[(($559)>>2)];
      var $561=((($560)+($557))|0);
      HEAP32[(($559)>>2)]=$561;
      __label__ = 27; break;
    case 27: 
      __label__ = 28; break;
    case 28: 
      __label__ = 29; break;
    case 29: 
      __label__ = 30; break;
    case 30: 
      var $566=$lx;
      var $567=$1;
      var $568=(($567+5792)|0);
      var $569=HEAPU32[(($568)>>2)];
      var $570=(($566)>>>0) < (($569)>>>0);
      if ($570) { __label__ = 4; break; } else { __label__ = 31; break; }
    case 31: 
      __label__ = 32; break;
    case 32: 
      var $573=$2;
      var $574=(($573+1024)|0);
      var $575=(($574+2)|0);
      var $576=$575;
      var $577=HEAPU16[(($576)>>1)];
      var $578=(($577)&65535);
      $len9=$578;
      var $579=$1;
      var $580=(($579+5820)|0);
      var $581=HEAP32[(($580)>>2)];
      var $582=$len9;
      var $583=(((16)-($582))|0);
      var $584=(($581)|0) > (($583)|0);
      if ($584) { __label__ = 33; break; } else { __label__ = 34; break; }
    case 33: 
      var $586=$2;
      var $587=(($586+1024)|0);
      var $588=(($587)|0);
      var $589=$588;
      var $590=HEAPU16[(($589)>>1)];
      var $591=(($590)&65535);
      $val10=$591;
      var $592=$val10;
      var $593=(($592) & 65535);
      var $594=(($593)&65535);
      var $595=$1;
      var $596=(($595+5820)|0);
      var $597=HEAP32[(($596)>>2)];
      var $598=$594 << $597;
      var $599=$1;
      var $600=(($599+5816)|0);
      var $601=HEAPU16[(($600)>>1)];
      var $602=(($601)&65535);
      var $603=$602 | $598;
      var $604=(($603) & 65535);
      HEAP16[(($600)>>1)]=$604;
      var $605=$1;
      var $606=(($605+5816)|0);
      var $607=HEAPU16[(($606)>>1)];
      var $608=(($607)&65535);
      var $609=$608 & 255;
      var $610=(($609) & 255);
      var $611=$1;
      var $612=(($611+20)|0);
      var $613=HEAPU32[(($612)>>2)];
      var $614=((($613)+(1))|0);
      HEAP32[(($612)>>2)]=$614;
      var $615=$1;
      var $616=(($615+8)|0);
      var $617=HEAP32[(($616)>>2)];
      var $618=(($617+$613)|0);
      HEAP8[($618)]=$610;
      var $619=$1;
      var $620=(($619+5816)|0);
      var $621=HEAPU16[(($620)>>1)];
      var $622=(($621)&65535);
      var $623=$622 >> 8;
      var $624=(($623) & 255);
      var $625=$1;
      var $626=(($625+20)|0);
      var $627=HEAPU32[(($626)>>2)];
      var $628=((($627)+(1))|0);
      HEAP32[(($626)>>2)]=$628;
      var $629=$1;
      var $630=(($629+8)|0);
      var $631=HEAP32[(($630)>>2)];
      var $632=(($631+$627)|0);
      HEAP8[($632)]=$624;
      var $633=$val10;
      var $634=(($633) & 65535);
      var $635=(($634)&65535);
      var $636=$1;
      var $637=(($636+5820)|0);
      var $638=HEAP32[(($637)>>2)];
      var $639=(((16)-($638))|0);
      var $640=$635 >> (($639)|0);
      var $641=(($640) & 65535);
      var $642=$1;
      var $643=(($642+5816)|0);
      HEAP16[(($643)>>1)]=$641;
      var $644=$len9;
      var $645=((($644)-(16))|0);
      var $646=$1;
      var $647=(($646+5820)|0);
      var $648=HEAP32[(($647)>>2)];
      var $649=((($648)+($645))|0);
      HEAP32[(($647)>>2)]=$649;
      __label__ = 35; break;
    case 34: 
      var $651=$2;
      var $652=(($651+1024)|0);
      var $653=(($652)|0);
      var $654=$653;
      var $655=HEAPU16[(($654)>>1)];
      var $656=(($655)&65535);
      var $657=$1;
      var $658=(($657+5820)|0);
      var $659=HEAP32[(($658)>>2)];
      var $660=$656 << $659;
      var $661=$1;
      var $662=(($661+5816)|0);
      var $663=HEAPU16[(($662)>>1)];
      var $664=(($663)&65535);
      var $665=$664 | $660;
      var $666=(($665) & 65535);
      HEAP16[(($662)>>1)]=$666;
      var $667=$len9;
      var $668=$1;
      var $669=(($668+5820)|0);
      var $670=HEAP32[(($669)>>2)];
      var $671=((($670)+($667))|0);
      HEAP32[(($669)>>2)]=$671;
      __label__ = 35; break;
    case 35: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_compress_block["X"]=1;

function _bi_windup($s) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      $1=$s;
      var $2=$1;
      var $3=(($2+5820)|0);
      var $4=HEAP32[(($3)>>2)];
      var $5=(($4)|0) > 8;
      if ($5) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $7=$1;
      var $8=(($7+5816)|0);
      var $9=HEAPU16[(($8)>>1)];
      var $10=(($9)&65535);
      var $11=$10 & 255;
      var $12=(($11) & 255);
      var $13=$1;
      var $14=(($13+20)|0);
      var $15=HEAPU32[(($14)>>2)];
      var $16=((($15)+(1))|0);
      HEAP32[(($14)>>2)]=$16;
      var $17=$1;
      var $18=(($17+8)|0);
      var $19=HEAP32[(($18)>>2)];
      var $20=(($19+$15)|0);
      HEAP8[($20)]=$12;
      var $21=$1;
      var $22=(($21+5816)|0);
      var $23=HEAPU16[(($22)>>1)];
      var $24=(($23)&65535);
      var $25=$24 >> 8;
      var $26=(($25) & 255);
      var $27=$1;
      var $28=(($27+20)|0);
      var $29=HEAPU32[(($28)>>2)];
      var $30=((($29)+(1))|0);
      HEAP32[(($28)>>2)]=$30;
      var $31=$1;
      var $32=(($31+8)|0);
      var $33=HEAP32[(($32)>>2)];
      var $34=(($33+$29)|0);
      HEAP8[($34)]=$26;
      __label__ = 7; break;
    case 4: 
      var $36=$1;
      var $37=(($36+5820)|0);
      var $38=HEAP32[(($37)>>2)];
      var $39=(($38)|0) > 0;
      if ($39) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $41=$1;
      var $42=(($41+5816)|0);
      var $43=HEAP16[(($42)>>1)];
      var $44=(($43) & 255);
      var $45=$1;
      var $46=(($45+20)|0);
      var $47=HEAP32[(($46)>>2)];
      var $48=((($47)+(1))|0);
      HEAP32[(($46)>>2)]=$48;
      var $49=$1;
      var $50=(($49+8)|0);
      var $51=HEAP32[(($50)>>2)];
      var $52=(($51+$47)|0);
      HEAP8[($52)]=$44;
      __label__ = 6; break;
    case 6: 
      __label__ = 7; break;
    case 7: 
      var $55=$1;
      var $56=(($55+5816)|0);
      HEAP16[(($56)>>1)]=0;
      var $57=$1;
      var $58=(($57+5820)|0);
      HEAP32[(($58)>>2)]=0;
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_bi_windup["X"]=1;

function _send_all_trees($s, $lcodes, $dcodes, $blcodes) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $rank;
      var $len;
      var $val;
      var $len1;
      var $val2;
      var $len3;
      var $val4;
      var $len5;
      var $val6;
      $1=$s;
      $2=$lcodes;
      $3=$dcodes;
      $4=$blcodes;
      $len=5;
      var $5=$1;
      var $6=(($5+5820)|0);
      var $7=HEAP32[(($6)>>2)];
      var $8=$len;
      var $9=(((16)-($8))|0);
      var $10=(($7)|0) > (($9)|0);
      if ($10) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $12=$2;
      var $13=((($12)-(257))|0);
      $val=$13;
      var $14=$val;
      var $15=(($14) & 65535);
      var $16=(($15)&65535);
      var $17=$1;
      var $18=(($17+5820)|0);
      var $19=HEAP32[(($18)>>2)];
      var $20=$16 << $19;
      var $21=$1;
      var $22=(($21+5816)|0);
      var $23=HEAPU16[(($22)>>1)];
      var $24=(($23)&65535);
      var $25=$24 | $20;
      var $26=(($25) & 65535);
      HEAP16[(($22)>>1)]=$26;
      var $27=$1;
      var $28=(($27+5816)|0);
      var $29=HEAPU16[(($28)>>1)];
      var $30=(($29)&65535);
      var $31=$30 & 255;
      var $32=(($31) & 255);
      var $33=$1;
      var $34=(($33+20)|0);
      var $35=HEAPU32[(($34)>>2)];
      var $36=((($35)+(1))|0);
      HEAP32[(($34)>>2)]=$36;
      var $37=$1;
      var $38=(($37+8)|0);
      var $39=HEAP32[(($38)>>2)];
      var $40=(($39+$35)|0);
      HEAP8[($40)]=$32;
      var $41=$1;
      var $42=(($41+5816)|0);
      var $43=HEAPU16[(($42)>>1)];
      var $44=(($43)&65535);
      var $45=$44 >> 8;
      var $46=(($45) & 255);
      var $47=$1;
      var $48=(($47+20)|0);
      var $49=HEAPU32[(($48)>>2)];
      var $50=((($49)+(1))|0);
      HEAP32[(($48)>>2)]=$50;
      var $51=$1;
      var $52=(($51+8)|0);
      var $53=HEAP32[(($52)>>2)];
      var $54=(($53+$49)|0);
      HEAP8[($54)]=$46;
      var $55=$val;
      var $56=(($55) & 65535);
      var $57=(($56)&65535);
      var $58=$1;
      var $59=(($58+5820)|0);
      var $60=HEAP32[(($59)>>2)];
      var $61=(((16)-($60))|0);
      var $62=$57 >> (($61)|0);
      var $63=(($62) & 65535);
      var $64=$1;
      var $65=(($64+5816)|0);
      HEAP16[(($65)>>1)]=$63;
      var $66=$len;
      var $67=((($66)-(16))|0);
      var $68=$1;
      var $69=(($68+5820)|0);
      var $70=HEAP32[(($69)>>2)];
      var $71=((($70)+($67))|0);
      HEAP32[(($69)>>2)]=$71;
      __label__ = 5; break;
    case 4: 
      var $73=$2;
      var $74=((($73)-(257))|0);
      var $75=(($74) & 65535);
      var $76=(($75)&65535);
      var $77=$1;
      var $78=(($77+5820)|0);
      var $79=HEAP32[(($78)>>2)];
      var $80=$76 << $79;
      var $81=$1;
      var $82=(($81+5816)|0);
      var $83=HEAPU16[(($82)>>1)];
      var $84=(($83)&65535);
      var $85=$84 | $80;
      var $86=(($85) & 65535);
      HEAP16[(($82)>>1)]=$86;
      var $87=$len;
      var $88=$1;
      var $89=(($88+5820)|0);
      var $90=HEAP32[(($89)>>2)];
      var $91=((($90)+($87))|0);
      HEAP32[(($89)>>2)]=$91;
      __label__ = 5; break;
    case 5: 
      $len1=5;
      var $93=$1;
      var $94=(($93+5820)|0);
      var $95=HEAP32[(($94)>>2)];
      var $96=$len1;
      var $97=(((16)-($96))|0);
      var $98=(($95)|0) > (($97)|0);
      if ($98) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      var $100=$3;
      var $101=((($100)-(1))|0);
      $val2=$101;
      var $102=$val2;
      var $103=(($102) & 65535);
      var $104=(($103)&65535);
      var $105=$1;
      var $106=(($105+5820)|0);
      var $107=HEAP32[(($106)>>2)];
      var $108=$104 << $107;
      var $109=$1;
      var $110=(($109+5816)|0);
      var $111=HEAPU16[(($110)>>1)];
      var $112=(($111)&65535);
      var $113=$112 | $108;
      var $114=(($113) & 65535);
      HEAP16[(($110)>>1)]=$114;
      var $115=$1;
      var $116=(($115+5816)|0);
      var $117=HEAPU16[(($116)>>1)];
      var $118=(($117)&65535);
      var $119=$118 & 255;
      var $120=(($119) & 255);
      var $121=$1;
      var $122=(($121+20)|0);
      var $123=HEAPU32[(($122)>>2)];
      var $124=((($123)+(1))|0);
      HEAP32[(($122)>>2)]=$124;
      var $125=$1;
      var $126=(($125+8)|0);
      var $127=HEAP32[(($126)>>2)];
      var $128=(($127+$123)|0);
      HEAP8[($128)]=$120;
      var $129=$1;
      var $130=(($129+5816)|0);
      var $131=HEAPU16[(($130)>>1)];
      var $132=(($131)&65535);
      var $133=$132 >> 8;
      var $134=(($133) & 255);
      var $135=$1;
      var $136=(($135+20)|0);
      var $137=HEAPU32[(($136)>>2)];
      var $138=((($137)+(1))|0);
      HEAP32[(($136)>>2)]=$138;
      var $139=$1;
      var $140=(($139+8)|0);
      var $141=HEAP32[(($140)>>2)];
      var $142=(($141+$137)|0);
      HEAP8[($142)]=$134;
      var $143=$val2;
      var $144=(($143) & 65535);
      var $145=(($144)&65535);
      var $146=$1;
      var $147=(($146+5820)|0);
      var $148=HEAP32[(($147)>>2)];
      var $149=(((16)-($148))|0);
      var $150=$145 >> (($149)|0);
      var $151=(($150) & 65535);
      var $152=$1;
      var $153=(($152+5816)|0);
      HEAP16[(($153)>>1)]=$151;
      var $154=$len1;
      var $155=((($154)-(16))|0);
      var $156=$1;
      var $157=(($156+5820)|0);
      var $158=HEAP32[(($157)>>2)];
      var $159=((($158)+($155))|0);
      HEAP32[(($157)>>2)]=$159;
      __label__ = 8; break;
    case 7: 
      var $161=$3;
      var $162=((($161)-(1))|0);
      var $163=(($162) & 65535);
      var $164=(($163)&65535);
      var $165=$1;
      var $166=(($165+5820)|0);
      var $167=HEAP32[(($166)>>2)];
      var $168=$164 << $167;
      var $169=$1;
      var $170=(($169+5816)|0);
      var $171=HEAPU16[(($170)>>1)];
      var $172=(($171)&65535);
      var $173=$172 | $168;
      var $174=(($173) & 65535);
      HEAP16[(($170)>>1)]=$174;
      var $175=$len1;
      var $176=$1;
      var $177=(($176+5820)|0);
      var $178=HEAP32[(($177)>>2)];
      var $179=((($178)+($175))|0);
      HEAP32[(($177)>>2)]=$179;
      __label__ = 8; break;
    case 8: 
      $len3=4;
      var $181=$1;
      var $182=(($181+5820)|0);
      var $183=HEAP32[(($182)>>2)];
      var $184=$len3;
      var $185=(((16)-($184))|0);
      var $186=(($183)|0) > (($185)|0);
      if ($186) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      var $188=$4;
      var $189=((($188)-(4))|0);
      $val4=$189;
      var $190=$val4;
      var $191=(($190) & 65535);
      var $192=(($191)&65535);
      var $193=$1;
      var $194=(($193+5820)|0);
      var $195=HEAP32[(($194)>>2)];
      var $196=$192 << $195;
      var $197=$1;
      var $198=(($197+5816)|0);
      var $199=HEAPU16[(($198)>>1)];
      var $200=(($199)&65535);
      var $201=$200 | $196;
      var $202=(($201) & 65535);
      HEAP16[(($198)>>1)]=$202;
      var $203=$1;
      var $204=(($203+5816)|0);
      var $205=HEAPU16[(($204)>>1)];
      var $206=(($205)&65535);
      var $207=$206 & 255;
      var $208=(($207) & 255);
      var $209=$1;
      var $210=(($209+20)|0);
      var $211=HEAPU32[(($210)>>2)];
      var $212=((($211)+(1))|0);
      HEAP32[(($210)>>2)]=$212;
      var $213=$1;
      var $214=(($213+8)|0);
      var $215=HEAP32[(($214)>>2)];
      var $216=(($215+$211)|0);
      HEAP8[($216)]=$208;
      var $217=$1;
      var $218=(($217+5816)|0);
      var $219=HEAPU16[(($218)>>1)];
      var $220=(($219)&65535);
      var $221=$220 >> 8;
      var $222=(($221) & 255);
      var $223=$1;
      var $224=(($223+20)|0);
      var $225=HEAPU32[(($224)>>2)];
      var $226=((($225)+(1))|0);
      HEAP32[(($224)>>2)]=$226;
      var $227=$1;
      var $228=(($227+8)|0);
      var $229=HEAP32[(($228)>>2)];
      var $230=(($229+$225)|0);
      HEAP8[($230)]=$222;
      var $231=$val4;
      var $232=(($231) & 65535);
      var $233=(($232)&65535);
      var $234=$1;
      var $235=(($234+5820)|0);
      var $236=HEAP32[(($235)>>2)];
      var $237=(((16)-($236))|0);
      var $238=$233 >> (($237)|0);
      var $239=(($238) & 65535);
      var $240=$1;
      var $241=(($240+5816)|0);
      HEAP16[(($241)>>1)]=$239;
      var $242=$len3;
      var $243=((($242)-(16))|0);
      var $244=$1;
      var $245=(($244+5820)|0);
      var $246=HEAP32[(($245)>>2)];
      var $247=((($246)+($243))|0);
      HEAP32[(($245)>>2)]=$247;
      __label__ = 11; break;
    case 10: 
      var $249=$4;
      var $250=((($249)-(4))|0);
      var $251=(($250) & 65535);
      var $252=(($251)&65535);
      var $253=$1;
      var $254=(($253+5820)|0);
      var $255=HEAP32[(($254)>>2)];
      var $256=$252 << $255;
      var $257=$1;
      var $258=(($257+5816)|0);
      var $259=HEAPU16[(($258)>>1)];
      var $260=(($259)&65535);
      var $261=$260 | $256;
      var $262=(($261) & 65535);
      HEAP16[(($258)>>1)]=$262;
      var $263=$len3;
      var $264=$1;
      var $265=(($264+5820)|0);
      var $266=HEAP32[(($265)>>2)];
      var $267=((($266)+($263))|0);
      HEAP32[(($265)>>2)]=$267;
      __label__ = 11; break;
    case 11: 
      $rank=0;
      __label__ = 12; break;
    case 12: 
      var $270=$rank;
      var $271=$4;
      var $272=(($270)|0) < (($271)|0);
      if ($272) { __label__ = 13; break; } else { __label__ = 18; break; }
    case 13: 
      $len5=3;
      var $274=$1;
      var $275=(($274+5820)|0);
      var $276=HEAP32[(($275)>>2)];
      var $277=$len5;
      var $278=(((16)-($277))|0);
      var $279=(($276)|0) > (($278)|0);
      if ($279) { __label__ = 14; break; } else { __label__ = 15; break; }
    case 14: 
      var $281=$rank;
      var $282=((STRING_TABLE._bl_order+$281)|0);
      var $283=HEAPU8[($282)];
      var $284=(($283)&255);
      var $285=$1;
      var $286=(($285+2684)|0);
      var $287=(($286+($284<<2))|0);
      var $288=(($287+2)|0);
      var $289=$288;
      var $290=HEAPU16[(($289)>>1)];
      var $291=(($290)&65535);
      $val6=$291;
      var $292=$val6;
      var $293=(($292) & 65535);
      var $294=(($293)&65535);
      var $295=$1;
      var $296=(($295+5820)|0);
      var $297=HEAP32[(($296)>>2)];
      var $298=$294 << $297;
      var $299=$1;
      var $300=(($299+5816)|0);
      var $301=HEAPU16[(($300)>>1)];
      var $302=(($301)&65535);
      var $303=$302 | $298;
      var $304=(($303) & 65535);
      HEAP16[(($300)>>1)]=$304;
      var $305=$1;
      var $306=(($305+5816)|0);
      var $307=HEAPU16[(($306)>>1)];
      var $308=(($307)&65535);
      var $309=$308 & 255;
      var $310=(($309) & 255);
      var $311=$1;
      var $312=(($311+20)|0);
      var $313=HEAPU32[(($312)>>2)];
      var $314=((($313)+(1))|0);
      HEAP32[(($312)>>2)]=$314;
      var $315=$1;
      var $316=(($315+8)|0);
      var $317=HEAP32[(($316)>>2)];
      var $318=(($317+$313)|0);
      HEAP8[($318)]=$310;
      var $319=$1;
      var $320=(($319+5816)|0);
      var $321=HEAPU16[(($320)>>1)];
      var $322=(($321)&65535);
      var $323=$322 >> 8;
      var $324=(($323) & 255);
      var $325=$1;
      var $326=(($325+20)|0);
      var $327=HEAPU32[(($326)>>2)];
      var $328=((($327)+(1))|0);
      HEAP32[(($326)>>2)]=$328;
      var $329=$1;
      var $330=(($329+8)|0);
      var $331=HEAP32[(($330)>>2)];
      var $332=(($331+$327)|0);
      HEAP8[($332)]=$324;
      var $333=$val6;
      var $334=(($333) & 65535);
      var $335=(($334)&65535);
      var $336=$1;
      var $337=(($336+5820)|0);
      var $338=HEAP32[(($337)>>2)];
      var $339=(((16)-($338))|0);
      var $340=$335 >> (($339)|0);
      var $341=(($340) & 65535);
      var $342=$1;
      var $343=(($342+5816)|0);
      HEAP16[(($343)>>1)]=$341;
      var $344=$len5;
      var $345=((($344)-(16))|0);
      var $346=$1;
      var $347=(($346+5820)|0);
      var $348=HEAP32[(($347)>>2)];
      var $349=((($348)+($345))|0);
      HEAP32[(($347)>>2)]=$349;
      __label__ = 16; break;
    case 15: 
      var $351=$rank;
      var $352=((STRING_TABLE._bl_order+$351)|0);
      var $353=HEAPU8[($352)];
      var $354=(($353)&255);
      var $355=$1;
      var $356=(($355+2684)|0);
      var $357=(($356+($354<<2))|0);
      var $358=(($357+2)|0);
      var $359=$358;
      var $360=HEAPU16[(($359)>>1)];
      var $361=(($360)&65535);
      var $362=$1;
      var $363=(($362+5820)|0);
      var $364=HEAP32[(($363)>>2)];
      var $365=$361 << $364;
      var $366=$1;
      var $367=(($366+5816)|0);
      var $368=HEAPU16[(($367)>>1)];
      var $369=(($368)&65535);
      var $370=$369 | $365;
      var $371=(($370) & 65535);
      HEAP16[(($367)>>1)]=$371;
      var $372=$len5;
      var $373=$1;
      var $374=(($373+5820)|0);
      var $375=HEAP32[(($374)>>2)];
      var $376=((($375)+($372))|0);
      HEAP32[(($374)>>2)]=$376;
      __label__ = 16; break;
    case 16: 
      __label__ = 17; break;
    case 17: 
      var $379=$rank;
      var $380=((($379)+(1))|0);
      $rank=$380;
      __label__ = 12; break;
    case 18: 
      var $382=$1;
      var $383=$1;
      var $384=(($383+148)|0);
      var $385=(($384)|0);
      var $386=$2;
      var $387=((($386)-(1))|0);
      _send_tree($382, $385, $387);
      var $388=$1;
      var $389=$1;
      var $390=(($389+2440)|0);
      var $391=(($390)|0);
      var $392=$3;
      var $393=((($392)-(1))|0);
      _send_tree($388, $391, $393);
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_send_all_trees["X"]=1;

function _send_tree($s, $tree, $max_code) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $n;
      var $prevlen;
      var $curlen;
      var $nextlen;
      var $count;
      var $max_count;
      var $min_count;
      var $len;
      var $val;
      var $len1;
      var $val2;
      var $len3;
      var $val4;
      var $len5;
      var $val6;
      var $len7;
      var $val8;
      var $len9;
      var $val10;
      var $len11;
      var $val12;
      var $len13;
      var $val14;
      $1=$s;
      $2=$tree;
      $3=$max_code;
      $prevlen=-1;
      var $4=$2;
      var $5=(($4)|0);
      var $6=(($5+2)|0);
      var $7=$6;
      var $8=HEAPU16[(($7)>>1)];
      var $9=(($8)&65535);
      $nextlen=$9;
      $count=0;
      $max_count=7;
      $min_count=4;
      var $10=$nextlen;
      var $11=(($10)|0)==0;
      if ($11) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      $max_count=138;
      $min_count=3;
      __label__ = 4; break;
    case 4: 
      $n=0;
      __label__ = 5; break;
    case 5: 
      var $15=$n;
      var $16=$3;
      var $17=(($15)|0) <= (($16)|0);
      if ($17) { __label__ = 6; break; } else { __label__ = 56; break; }
    case 6: 
      var $19=$nextlen;
      $curlen=$19;
      var $20=$n;
      var $21=((($20)+(1))|0);
      var $22=$2;
      var $23=(($22+($21<<2))|0);
      var $24=(($23+2)|0);
      var $25=$24;
      var $26=HEAPU16[(($25)>>1)];
      var $27=(($26)&65535);
      $nextlen=$27;
      var $28=$count;
      var $29=((($28)+(1))|0);
      $count=$29;
      var $30=$max_count;
      var $31=(($29)|0) < (($30)|0);
      if ($31) { __label__ = 7; break; } else { __label__ = 9; break; }
    case 7: 
      var $33=$curlen;
      var $34=$nextlen;
      var $35=(($33)|0)==(($34)|0);
      if ($35) { __label__ = 8; break; } else { __label__ = 9; break; }
    case 8: 
      __label__ = 55; break;
    case 9: 
      var $38=$count;
      var $39=$min_count;
      var $40=(($38)|0) < (($39)|0);
      if ($40) { __label__ = 10; break; } else { __label__ = 17; break; }
    case 10: 
      __label__ = 11; break;
    case 11: 
      var $43=$curlen;
      var $44=$1;
      var $45=(($44+2684)|0);
      var $46=(($45+($43<<2))|0);
      var $47=(($46+2)|0);
      var $48=$47;
      var $49=HEAPU16[(($48)>>1)];
      var $50=(($49)&65535);
      $len=$50;
      var $51=$1;
      var $52=(($51+5820)|0);
      var $53=HEAP32[(($52)>>2)];
      var $54=$len;
      var $55=(((16)-($54))|0);
      var $56=(($53)|0) > (($55)|0);
      if ($56) { __label__ = 12; break; } else { __label__ = 13; break; }
    case 12: 
      var $58=$curlen;
      var $59=$1;
      var $60=(($59+2684)|0);
      var $61=(($60+($58<<2))|0);
      var $62=(($61)|0);
      var $63=$62;
      var $64=HEAPU16[(($63)>>1)];
      var $65=(($64)&65535);
      $val=$65;
      var $66=$val;
      var $67=(($66) & 65535);
      var $68=(($67)&65535);
      var $69=$1;
      var $70=(($69+5820)|0);
      var $71=HEAP32[(($70)>>2)];
      var $72=$68 << $71;
      var $73=$1;
      var $74=(($73+5816)|0);
      var $75=HEAPU16[(($74)>>1)];
      var $76=(($75)&65535);
      var $77=$76 | $72;
      var $78=(($77) & 65535);
      HEAP16[(($74)>>1)]=$78;
      var $79=$1;
      var $80=(($79+5816)|0);
      var $81=HEAPU16[(($80)>>1)];
      var $82=(($81)&65535);
      var $83=$82 & 255;
      var $84=(($83) & 255);
      var $85=$1;
      var $86=(($85+20)|0);
      var $87=HEAPU32[(($86)>>2)];
      var $88=((($87)+(1))|0);
      HEAP32[(($86)>>2)]=$88;
      var $89=$1;
      var $90=(($89+8)|0);
      var $91=HEAP32[(($90)>>2)];
      var $92=(($91+$87)|0);
      HEAP8[($92)]=$84;
      var $93=$1;
      var $94=(($93+5816)|0);
      var $95=HEAPU16[(($94)>>1)];
      var $96=(($95)&65535);
      var $97=$96 >> 8;
      var $98=(($97) & 255);
      var $99=$1;
      var $100=(($99+20)|0);
      var $101=HEAPU32[(($100)>>2)];
      var $102=((($101)+(1))|0);
      HEAP32[(($100)>>2)]=$102;
      var $103=$1;
      var $104=(($103+8)|0);
      var $105=HEAP32[(($104)>>2)];
      var $106=(($105+$101)|0);
      HEAP8[($106)]=$98;
      var $107=$val;
      var $108=(($107) & 65535);
      var $109=(($108)&65535);
      var $110=$1;
      var $111=(($110+5820)|0);
      var $112=HEAP32[(($111)>>2)];
      var $113=(((16)-($112))|0);
      var $114=$109 >> (($113)|0);
      var $115=(($114) & 65535);
      var $116=$1;
      var $117=(($116+5816)|0);
      HEAP16[(($117)>>1)]=$115;
      var $118=$len;
      var $119=((($118)-(16))|0);
      var $120=$1;
      var $121=(($120+5820)|0);
      var $122=HEAP32[(($121)>>2)];
      var $123=((($122)+($119))|0);
      HEAP32[(($121)>>2)]=$123;
      __label__ = 14; break;
    case 13: 
      var $125=$curlen;
      var $126=$1;
      var $127=(($126+2684)|0);
      var $128=(($127+($125<<2))|0);
      var $129=(($128)|0);
      var $130=$129;
      var $131=HEAPU16[(($130)>>1)];
      var $132=(($131)&65535);
      var $133=$1;
      var $134=(($133+5820)|0);
      var $135=HEAP32[(($134)>>2)];
      var $136=$132 << $135;
      var $137=$1;
      var $138=(($137+5816)|0);
      var $139=HEAPU16[(($138)>>1)];
      var $140=(($139)&65535);
      var $141=$140 | $136;
      var $142=(($141) & 65535);
      HEAP16[(($138)>>1)]=$142;
      var $143=$len;
      var $144=$1;
      var $145=(($144+5820)|0);
      var $146=HEAP32[(($145)>>2)];
      var $147=((($146)+($143))|0);
      HEAP32[(($145)>>2)]=$147;
      __label__ = 14; break;
    case 14: 
      __label__ = 15; break;
    case 15: 
      var $150=$count;
      var $151=((($150)-(1))|0);
      $count=$151;
      var $152=(($151)|0)!=0;
      if ($152) { __label__ = 11; break; } else { __label__ = 16; break; }
    case 16: 
      __label__ = 47; break;
    case 17: 
      var $155=$curlen;
      var $156=(($155)|0)!=0;
      if ($156) { __label__ = 18; break; } else { __label__ = 30; break; }
    case 18: 
      var $158=$curlen;
      var $159=$prevlen;
      var $160=(($158)|0)!=(($159)|0);
      if ($160) { __label__ = 19; break; } else { __label__ = 23; break; }
    case 19: 
      var $162=$curlen;
      var $163=$1;
      var $164=(($163+2684)|0);
      var $165=(($164+($162<<2))|0);
      var $166=(($165+2)|0);
      var $167=$166;
      var $168=HEAPU16[(($167)>>1)];
      var $169=(($168)&65535);
      $len1=$169;
      var $170=$1;
      var $171=(($170+5820)|0);
      var $172=HEAP32[(($171)>>2)];
      var $173=$len1;
      var $174=(((16)-($173))|0);
      var $175=(($172)|0) > (($174)|0);
      if ($175) { __label__ = 20; break; } else { __label__ = 21; break; }
    case 20: 
      var $177=$curlen;
      var $178=$1;
      var $179=(($178+2684)|0);
      var $180=(($179+($177<<2))|0);
      var $181=(($180)|0);
      var $182=$181;
      var $183=HEAPU16[(($182)>>1)];
      var $184=(($183)&65535);
      $val2=$184;
      var $185=$val2;
      var $186=(($185) & 65535);
      var $187=(($186)&65535);
      var $188=$1;
      var $189=(($188+5820)|0);
      var $190=HEAP32[(($189)>>2)];
      var $191=$187 << $190;
      var $192=$1;
      var $193=(($192+5816)|0);
      var $194=HEAPU16[(($193)>>1)];
      var $195=(($194)&65535);
      var $196=$195 | $191;
      var $197=(($196) & 65535);
      HEAP16[(($193)>>1)]=$197;
      var $198=$1;
      var $199=(($198+5816)|0);
      var $200=HEAPU16[(($199)>>1)];
      var $201=(($200)&65535);
      var $202=$201 & 255;
      var $203=(($202) & 255);
      var $204=$1;
      var $205=(($204+20)|0);
      var $206=HEAPU32[(($205)>>2)];
      var $207=((($206)+(1))|0);
      HEAP32[(($205)>>2)]=$207;
      var $208=$1;
      var $209=(($208+8)|0);
      var $210=HEAP32[(($209)>>2)];
      var $211=(($210+$206)|0);
      HEAP8[($211)]=$203;
      var $212=$1;
      var $213=(($212+5816)|0);
      var $214=HEAPU16[(($213)>>1)];
      var $215=(($214)&65535);
      var $216=$215 >> 8;
      var $217=(($216) & 255);
      var $218=$1;
      var $219=(($218+20)|0);
      var $220=HEAPU32[(($219)>>2)];
      var $221=((($220)+(1))|0);
      HEAP32[(($219)>>2)]=$221;
      var $222=$1;
      var $223=(($222+8)|0);
      var $224=HEAP32[(($223)>>2)];
      var $225=(($224+$220)|0);
      HEAP8[($225)]=$217;
      var $226=$val2;
      var $227=(($226) & 65535);
      var $228=(($227)&65535);
      var $229=$1;
      var $230=(($229+5820)|0);
      var $231=HEAP32[(($230)>>2)];
      var $232=(((16)-($231))|0);
      var $233=$228 >> (($232)|0);
      var $234=(($233) & 65535);
      var $235=$1;
      var $236=(($235+5816)|0);
      HEAP16[(($236)>>1)]=$234;
      var $237=$len1;
      var $238=((($237)-(16))|0);
      var $239=$1;
      var $240=(($239+5820)|0);
      var $241=HEAP32[(($240)>>2)];
      var $242=((($241)+($238))|0);
      HEAP32[(($240)>>2)]=$242;
      __label__ = 22; break;
    case 21: 
      var $244=$curlen;
      var $245=$1;
      var $246=(($245+2684)|0);
      var $247=(($246+($244<<2))|0);
      var $248=(($247)|0);
      var $249=$248;
      var $250=HEAPU16[(($249)>>1)];
      var $251=(($250)&65535);
      var $252=$1;
      var $253=(($252+5820)|0);
      var $254=HEAP32[(($253)>>2)];
      var $255=$251 << $254;
      var $256=$1;
      var $257=(($256+5816)|0);
      var $258=HEAPU16[(($257)>>1)];
      var $259=(($258)&65535);
      var $260=$259 | $255;
      var $261=(($260) & 65535);
      HEAP16[(($257)>>1)]=$261;
      var $262=$len1;
      var $263=$1;
      var $264=(($263+5820)|0);
      var $265=HEAP32[(($264)>>2)];
      var $266=((($265)+($262))|0);
      HEAP32[(($264)>>2)]=$266;
      __label__ = 22; break;
    case 22: 
      var $268=$count;
      var $269=((($268)-(1))|0);
      $count=$269;
      __label__ = 23; break;
    case 23: 
      var $271=$1;
      var $272=(($271+2684)|0);
      var $273=(($272+64)|0);
      var $274=(($273+2)|0);
      var $275=$274;
      var $276=HEAPU16[(($275)>>1)];
      var $277=(($276)&65535);
      $len3=$277;
      var $278=$1;
      var $279=(($278+5820)|0);
      var $280=HEAP32[(($279)>>2)];
      var $281=$len3;
      var $282=(((16)-($281))|0);
      var $283=(($280)|0) > (($282)|0);
      if ($283) { __label__ = 24; break; } else { __label__ = 25; break; }
    case 24: 
      var $285=$1;
      var $286=(($285+2684)|0);
      var $287=(($286+64)|0);
      var $288=(($287)|0);
      var $289=$288;
      var $290=HEAPU16[(($289)>>1)];
      var $291=(($290)&65535);
      $val4=$291;
      var $292=$val4;
      var $293=(($292) & 65535);
      var $294=(($293)&65535);
      var $295=$1;
      var $296=(($295+5820)|0);
      var $297=HEAP32[(($296)>>2)];
      var $298=$294 << $297;
      var $299=$1;
      var $300=(($299+5816)|0);
      var $301=HEAPU16[(($300)>>1)];
      var $302=(($301)&65535);
      var $303=$302 | $298;
      var $304=(($303) & 65535);
      HEAP16[(($300)>>1)]=$304;
      var $305=$1;
      var $306=(($305+5816)|0);
      var $307=HEAPU16[(($306)>>1)];
      var $308=(($307)&65535);
      var $309=$308 & 255;
      var $310=(($309) & 255);
      var $311=$1;
      var $312=(($311+20)|0);
      var $313=HEAPU32[(($312)>>2)];
      var $314=((($313)+(1))|0);
      HEAP32[(($312)>>2)]=$314;
      var $315=$1;
      var $316=(($315+8)|0);
      var $317=HEAP32[(($316)>>2)];
      var $318=(($317+$313)|0);
      HEAP8[($318)]=$310;
      var $319=$1;
      var $320=(($319+5816)|0);
      var $321=HEAPU16[(($320)>>1)];
      var $322=(($321)&65535);
      var $323=$322 >> 8;
      var $324=(($323) & 255);
      var $325=$1;
      var $326=(($325+20)|0);
      var $327=HEAPU32[(($326)>>2)];
      var $328=((($327)+(1))|0);
      HEAP32[(($326)>>2)]=$328;
      var $329=$1;
      var $330=(($329+8)|0);
      var $331=HEAP32[(($330)>>2)];
      var $332=(($331+$327)|0);
      HEAP8[($332)]=$324;
      var $333=$val4;
      var $334=(($333) & 65535);
      var $335=(($334)&65535);
      var $336=$1;
      var $337=(($336+5820)|0);
      var $338=HEAP32[(($337)>>2)];
      var $339=(((16)-($338))|0);
      var $340=$335 >> (($339)|0);
      var $341=(($340) & 65535);
      var $342=$1;
      var $343=(($342+5816)|0);
      HEAP16[(($343)>>1)]=$341;
      var $344=$len3;
      var $345=((($344)-(16))|0);
      var $346=$1;
      var $347=(($346+5820)|0);
      var $348=HEAP32[(($347)>>2)];
      var $349=((($348)+($345))|0);
      HEAP32[(($347)>>2)]=$349;
      __label__ = 26; break;
    case 25: 
      var $351=$1;
      var $352=(($351+2684)|0);
      var $353=(($352+64)|0);
      var $354=(($353)|0);
      var $355=$354;
      var $356=HEAPU16[(($355)>>1)];
      var $357=(($356)&65535);
      var $358=$1;
      var $359=(($358+5820)|0);
      var $360=HEAP32[(($359)>>2)];
      var $361=$357 << $360;
      var $362=$1;
      var $363=(($362+5816)|0);
      var $364=HEAPU16[(($363)>>1)];
      var $365=(($364)&65535);
      var $366=$365 | $361;
      var $367=(($366) & 65535);
      HEAP16[(($363)>>1)]=$367;
      var $368=$len3;
      var $369=$1;
      var $370=(($369+5820)|0);
      var $371=HEAP32[(($370)>>2)];
      var $372=((($371)+($368))|0);
      HEAP32[(($370)>>2)]=$372;
      __label__ = 26; break;
    case 26: 
      $len5=2;
      var $374=$1;
      var $375=(($374+5820)|0);
      var $376=HEAP32[(($375)>>2)];
      var $377=$len5;
      var $378=(((16)-($377))|0);
      var $379=(($376)|0) > (($378)|0);
      if ($379) { __label__ = 27; break; } else { __label__ = 28; break; }
    case 27: 
      var $381=$count;
      var $382=((($381)-(3))|0);
      $val6=$382;
      var $383=$val6;
      var $384=(($383) & 65535);
      var $385=(($384)&65535);
      var $386=$1;
      var $387=(($386+5820)|0);
      var $388=HEAP32[(($387)>>2)];
      var $389=$385 << $388;
      var $390=$1;
      var $391=(($390+5816)|0);
      var $392=HEAPU16[(($391)>>1)];
      var $393=(($392)&65535);
      var $394=$393 | $389;
      var $395=(($394) & 65535);
      HEAP16[(($391)>>1)]=$395;
      var $396=$1;
      var $397=(($396+5816)|0);
      var $398=HEAPU16[(($397)>>1)];
      var $399=(($398)&65535);
      var $400=$399 & 255;
      var $401=(($400) & 255);
      var $402=$1;
      var $403=(($402+20)|0);
      var $404=HEAPU32[(($403)>>2)];
      var $405=((($404)+(1))|0);
      HEAP32[(($403)>>2)]=$405;
      var $406=$1;
      var $407=(($406+8)|0);
      var $408=HEAP32[(($407)>>2)];
      var $409=(($408+$404)|0);
      HEAP8[($409)]=$401;
      var $410=$1;
      var $411=(($410+5816)|0);
      var $412=HEAPU16[(($411)>>1)];
      var $413=(($412)&65535);
      var $414=$413 >> 8;
      var $415=(($414) & 255);
      var $416=$1;
      var $417=(($416+20)|0);
      var $418=HEAPU32[(($417)>>2)];
      var $419=((($418)+(1))|0);
      HEAP32[(($417)>>2)]=$419;
      var $420=$1;
      var $421=(($420+8)|0);
      var $422=HEAP32[(($421)>>2)];
      var $423=(($422+$418)|0);
      HEAP8[($423)]=$415;
      var $424=$val6;
      var $425=(($424) & 65535);
      var $426=(($425)&65535);
      var $427=$1;
      var $428=(($427+5820)|0);
      var $429=HEAP32[(($428)>>2)];
      var $430=(((16)-($429))|0);
      var $431=$426 >> (($430)|0);
      var $432=(($431) & 65535);
      var $433=$1;
      var $434=(($433+5816)|0);
      HEAP16[(($434)>>1)]=$432;
      var $435=$len5;
      var $436=((($435)-(16))|0);
      var $437=$1;
      var $438=(($437+5820)|0);
      var $439=HEAP32[(($438)>>2)];
      var $440=((($439)+($436))|0);
      HEAP32[(($438)>>2)]=$440;
      __label__ = 29; break;
    case 28: 
      var $442=$count;
      var $443=((($442)-(3))|0);
      var $444=(($443) & 65535);
      var $445=(($444)&65535);
      var $446=$1;
      var $447=(($446+5820)|0);
      var $448=HEAP32[(($447)>>2)];
      var $449=$445 << $448;
      var $450=$1;
      var $451=(($450+5816)|0);
      var $452=HEAPU16[(($451)>>1)];
      var $453=(($452)&65535);
      var $454=$453 | $449;
      var $455=(($454) & 65535);
      HEAP16[(($451)>>1)]=$455;
      var $456=$len5;
      var $457=$1;
      var $458=(($457+5820)|0);
      var $459=HEAP32[(($458)>>2)];
      var $460=((($459)+($456))|0);
      HEAP32[(($458)>>2)]=$460;
      __label__ = 29; break;
    case 29: 
      __label__ = 46; break;
    case 30: 
      var $463=$count;
      var $464=(($463)|0) <= 10;
      if ($464) { __label__ = 31; break; } else { __label__ = 38; break; }
    case 31: 
      var $466=$1;
      var $467=(($466+2684)|0);
      var $468=(($467+68)|0);
      var $469=(($468+2)|0);
      var $470=$469;
      var $471=HEAPU16[(($470)>>1)];
      var $472=(($471)&65535);
      $len7=$472;
      var $473=$1;
      var $474=(($473+5820)|0);
      var $475=HEAP32[(($474)>>2)];
      var $476=$len7;
      var $477=(((16)-($476))|0);
      var $478=(($475)|0) > (($477)|0);
      if ($478) { __label__ = 32; break; } else { __label__ = 33; break; }
    case 32: 
      var $480=$1;
      var $481=(($480+2684)|0);
      var $482=(($481+68)|0);
      var $483=(($482)|0);
      var $484=$483;
      var $485=HEAPU16[(($484)>>1)];
      var $486=(($485)&65535);
      $val8=$486;
      var $487=$val8;
      var $488=(($487) & 65535);
      var $489=(($488)&65535);
      var $490=$1;
      var $491=(($490+5820)|0);
      var $492=HEAP32[(($491)>>2)];
      var $493=$489 << $492;
      var $494=$1;
      var $495=(($494+5816)|0);
      var $496=HEAPU16[(($495)>>1)];
      var $497=(($496)&65535);
      var $498=$497 | $493;
      var $499=(($498) & 65535);
      HEAP16[(($495)>>1)]=$499;
      var $500=$1;
      var $501=(($500+5816)|0);
      var $502=HEAPU16[(($501)>>1)];
      var $503=(($502)&65535);
      var $504=$503 & 255;
      var $505=(($504) & 255);
      var $506=$1;
      var $507=(($506+20)|0);
      var $508=HEAPU32[(($507)>>2)];
      var $509=((($508)+(1))|0);
      HEAP32[(($507)>>2)]=$509;
      var $510=$1;
      var $511=(($510+8)|0);
      var $512=HEAP32[(($511)>>2)];
      var $513=(($512+$508)|0);
      HEAP8[($513)]=$505;
      var $514=$1;
      var $515=(($514+5816)|0);
      var $516=HEAPU16[(($515)>>1)];
      var $517=(($516)&65535);
      var $518=$517 >> 8;
      var $519=(($518) & 255);
      var $520=$1;
      var $521=(($520+20)|0);
      var $522=HEAPU32[(($521)>>2)];
      var $523=((($522)+(1))|0);
      HEAP32[(($521)>>2)]=$523;
      var $524=$1;
      var $525=(($524+8)|0);
      var $526=HEAP32[(($525)>>2)];
      var $527=(($526+$522)|0);
      HEAP8[($527)]=$519;
      var $528=$val8;
      var $529=(($528) & 65535);
      var $530=(($529)&65535);
      var $531=$1;
      var $532=(($531+5820)|0);
      var $533=HEAP32[(($532)>>2)];
      var $534=(((16)-($533))|0);
      var $535=$530 >> (($534)|0);
      var $536=(($535) & 65535);
      var $537=$1;
      var $538=(($537+5816)|0);
      HEAP16[(($538)>>1)]=$536;
      var $539=$len7;
      var $540=((($539)-(16))|0);
      var $541=$1;
      var $542=(($541+5820)|0);
      var $543=HEAP32[(($542)>>2)];
      var $544=((($543)+($540))|0);
      HEAP32[(($542)>>2)]=$544;
      __label__ = 34; break;
    case 33: 
      var $546=$1;
      var $547=(($546+2684)|0);
      var $548=(($547+68)|0);
      var $549=(($548)|0);
      var $550=$549;
      var $551=HEAPU16[(($550)>>1)];
      var $552=(($551)&65535);
      var $553=$1;
      var $554=(($553+5820)|0);
      var $555=HEAP32[(($554)>>2)];
      var $556=$552 << $555;
      var $557=$1;
      var $558=(($557+5816)|0);
      var $559=HEAPU16[(($558)>>1)];
      var $560=(($559)&65535);
      var $561=$560 | $556;
      var $562=(($561) & 65535);
      HEAP16[(($558)>>1)]=$562;
      var $563=$len7;
      var $564=$1;
      var $565=(($564+5820)|0);
      var $566=HEAP32[(($565)>>2)];
      var $567=((($566)+($563))|0);
      HEAP32[(($565)>>2)]=$567;
      __label__ = 34; break;
    case 34: 
      $len9=3;
      var $569=$1;
      var $570=(($569+5820)|0);
      var $571=HEAP32[(($570)>>2)];
      var $572=$len9;
      var $573=(((16)-($572))|0);
      var $574=(($571)|0) > (($573)|0);
      if ($574) { __label__ = 35; break; } else { __label__ = 36; break; }
    case 35: 
      var $576=$count;
      var $577=((($576)-(3))|0);
      $val10=$577;
      var $578=$val10;
      var $579=(($578) & 65535);
      var $580=(($579)&65535);
      var $581=$1;
      var $582=(($581+5820)|0);
      var $583=HEAP32[(($582)>>2)];
      var $584=$580 << $583;
      var $585=$1;
      var $586=(($585+5816)|0);
      var $587=HEAPU16[(($586)>>1)];
      var $588=(($587)&65535);
      var $589=$588 | $584;
      var $590=(($589) & 65535);
      HEAP16[(($586)>>1)]=$590;
      var $591=$1;
      var $592=(($591+5816)|0);
      var $593=HEAPU16[(($592)>>1)];
      var $594=(($593)&65535);
      var $595=$594 & 255;
      var $596=(($595) & 255);
      var $597=$1;
      var $598=(($597+20)|0);
      var $599=HEAPU32[(($598)>>2)];
      var $600=((($599)+(1))|0);
      HEAP32[(($598)>>2)]=$600;
      var $601=$1;
      var $602=(($601+8)|0);
      var $603=HEAP32[(($602)>>2)];
      var $604=(($603+$599)|0);
      HEAP8[($604)]=$596;
      var $605=$1;
      var $606=(($605+5816)|0);
      var $607=HEAPU16[(($606)>>1)];
      var $608=(($607)&65535);
      var $609=$608 >> 8;
      var $610=(($609) & 255);
      var $611=$1;
      var $612=(($611+20)|0);
      var $613=HEAPU32[(($612)>>2)];
      var $614=((($613)+(1))|0);
      HEAP32[(($612)>>2)]=$614;
      var $615=$1;
      var $616=(($615+8)|0);
      var $617=HEAP32[(($616)>>2)];
      var $618=(($617+$613)|0);
      HEAP8[($618)]=$610;
      var $619=$val10;
      var $620=(($619) & 65535);
      var $621=(($620)&65535);
      var $622=$1;
      var $623=(($622+5820)|0);
      var $624=HEAP32[(($623)>>2)];
      var $625=(((16)-($624))|0);
      var $626=$621 >> (($625)|0);
      var $627=(($626) & 65535);
      var $628=$1;
      var $629=(($628+5816)|0);
      HEAP16[(($629)>>1)]=$627;
      var $630=$len9;
      var $631=((($630)-(16))|0);
      var $632=$1;
      var $633=(($632+5820)|0);
      var $634=HEAP32[(($633)>>2)];
      var $635=((($634)+($631))|0);
      HEAP32[(($633)>>2)]=$635;
      __label__ = 37; break;
    case 36: 
      var $637=$count;
      var $638=((($637)-(3))|0);
      var $639=(($638) & 65535);
      var $640=(($639)&65535);
      var $641=$1;
      var $642=(($641+5820)|0);
      var $643=HEAP32[(($642)>>2)];
      var $644=$640 << $643;
      var $645=$1;
      var $646=(($645+5816)|0);
      var $647=HEAPU16[(($646)>>1)];
      var $648=(($647)&65535);
      var $649=$648 | $644;
      var $650=(($649) & 65535);
      HEAP16[(($646)>>1)]=$650;
      var $651=$len9;
      var $652=$1;
      var $653=(($652+5820)|0);
      var $654=HEAP32[(($653)>>2)];
      var $655=((($654)+($651))|0);
      HEAP32[(($653)>>2)]=$655;
      __label__ = 37; break;
    case 37: 
      __label__ = 45; break;
    case 38: 
      var $658=$1;
      var $659=(($658+2684)|0);
      var $660=(($659+72)|0);
      var $661=(($660+2)|0);
      var $662=$661;
      var $663=HEAPU16[(($662)>>1)];
      var $664=(($663)&65535);
      $len11=$664;
      var $665=$1;
      var $666=(($665+5820)|0);
      var $667=HEAP32[(($666)>>2)];
      var $668=$len11;
      var $669=(((16)-($668))|0);
      var $670=(($667)|0) > (($669)|0);
      if ($670) { __label__ = 39; break; } else { __label__ = 40; break; }
    case 39: 
      var $672=$1;
      var $673=(($672+2684)|0);
      var $674=(($673+72)|0);
      var $675=(($674)|0);
      var $676=$675;
      var $677=HEAPU16[(($676)>>1)];
      var $678=(($677)&65535);
      $val12=$678;
      var $679=$val12;
      var $680=(($679) & 65535);
      var $681=(($680)&65535);
      var $682=$1;
      var $683=(($682+5820)|0);
      var $684=HEAP32[(($683)>>2)];
      var $685=$681 << $684;
      var $686=$1;
      var $687=(($686+5816)|0);
      var $688=HEAPU16[(($687)>>1)];
      var $689=(($688)&65535);
      var $690=$689 | $685;
      var $691=(($690) & 65535);
      HEAP16[(($687)>>1)]=$691;
      var $692=$1;
      var $693=(($692+5816)|0);
      var $694=HEAPU16[(($693)>>1)];
      var $695=(($694)&65535);
      var $696=$695 & 255;
      var $697=(($696) & 255);
      var $698=$1;
      var $699=(($698+20)|0);
      var $700=HEAPU32[(($699)>>2)];
      var $701=((($700)+(1))|0);
      HEAP32[(($699)>>2)]=$701;
      var $702=$1;
      var $703=(($702+8)|0);
      var $704=HEAP32[(($703)>>2)];
      var $705=(($704+$700)|0);
      HEAP8[($705)]=$697;
      var $706=$1;
      var $707=(($706+5816)|0);
      var $708=HEAPU16[(($707)>>1)];
      var $709=(($708)&65535);
      var $710=$709 >> 8;
      var $711=(($710) & 255);
      var $712=$1;
      var $713=(($712+20)|0);
      var $714=HEAPU32[(($713)>>2)];
      var $715=((($714)+(1))|0);
      HEAP32[(($713)>>2)]=$715;
      var $716=$1;
      var $717=(($716+8)|0);
      var $718=HEAP32[(($717)>>2)];
      var $719=(($718+$714)|0);
      HEAP8[($719)]=$711;
      var $720=$val12;
      var $721=(($720) & 65535);
      var $722=(($721)&65535);
      var $723=$1;
      var $724=(($723+5820)|0);
      var $725=HEAP32[(($724)>>2)];
      var $726=(((16)-($725))|0);
      var $727=$722 >> (($726)|0);
      var $728=(($727) & 65535);
      var $729=$1;
      var $730=(($729+5816)|0);
      HEAP16[(($730)>>1)]=$728;
      var $731=$len11;
      var $732=((($731)-(16))|0);
      var $733=$1;
      var $734=(($733+5820)|0);
      var $735=HEAP32[(($734)>>2)];
      var $736=((($735)+($732))|0);
      HEAP32[(($734)>>2)]=$736;
      __label__ = 41; break;
    case 40: 
      var $738=$1;
      var $739=(($738+2684)|0);
      var $740=(($739+72)|0);
      var $741=(($740)|0);
      var $742=$741;
      var $743=HEAPU16[(($742)>>1)];
      var $744=(($743)&65535);
      var $745=$1;
      var $746=(($745+5820)|0);
      var $747=HEAP32[(($746)>>2)];
      var $748=$744 << $747;
      var $749=$1;
      var $750=(($749+5816)|0);
      var $751=HEAPU16[(($750)>>1)];
      var $752=(($751)&65535);
      var $753=$752 | $748;
      var $754=(($753) & 65535);
      HEAP16[(($750)>>1)]=$754;
      var $755=$len11;
      var $756=$1;
      var $757=(($756+5820)|0);
      var $758=HEAP32[(($757)>>2)];
      var $759=((($758)+($755))|0);
      HEAP32[(($757)>>2)]=$759;
      __label__ = 41; break;
    case 41: 
      $len13=7;
      var $761=$1;
      var $762=(($761+5820)|0);
      var $763=HEAP32[(($762)>>2)];
      var $764=$len13;
      var $765=(((16)-($764))|0);
      var $766=(($763)|0) > (($765)|0);
      if ($766) { __label__ = 42; break; } else { __label__ = 43; break; }
    case 42: 
      var $768=$count;
      var $769=((($768)-(11))|0);
      $val14=$769;
      var $770=$val14;
      var $771=(($770) & 65535);
      var $772=(($771)&65535);
      var $773=$1;
      var $774=(($773+5820)|0);
      var $775=HEAP32[(($774)>>2)];
      var $776=$772 << $775;
      var $777=$1;
      var $778=(($777+5816)|0);
      var $779=HEAPU16[(($778)>>1)];
      var $780=(($779)&65535);
      var $781=$780 | $776;
      var $782=(($781) & 65535);
      HEAP16[(($778)>>1)]=$782;
      var $783=$1;
      var $784=(($783+5816)|0);
      var $785=HEAPU16[(($784)>>1)];
      var $786=(($785)&65535);
      var $787=$786 & 255;
      var $788=(($787) & 255);
      var $789=$1;
      var $790=(($789+20)|0);
      var $791=HEAPU32[(($790)>>2)];
      var $792=((($791)+(1))|0);
      HEAP32[(($790)>>2)]=$792;
      var $793=$1;
      var $794=(($793+8)|0);
      var $795=HEAP32[(($794)>>2)];
      var $796=(($795+$791)|0);
      HEAP8[($796)]=$788;
      var $797=$1;
      var $798=(($797+5816)|0);
      var $799=HEAPU16[(($798)>>1)];
      var $800=(($799)&65535);
      var $801=$800 >> 8;
      var $802=(($801) & 255);
      var $803=$1;
      var $804=(($803+20)|0);
      var $805=HEAPU32[(($804)>>2)];
      var $806=((($805)+(1))|0);
      HEAP32[(($804)>>2)]=$806;
      var $807=$1;
      var $808=(($807+8)|0);
      var $809=HEAP32[(($808)>>2)];
      var $810=(($809+$805)|0);
      HEAP8[($810)]=$802;
      var $811=$val14;
      var $812=(($811) & 65535);
      var $813=(($812)&65535);
      var $814=$1;
      var $815=(($814+5820)|0);
      var $816=HEAP32[(($815)>>2)];
      var $817=(((16)-($816))|0);
      var $818=$813 >> (($817)|0);
      var $819=(($818) & 65535);
      var $820=$1;
      var $821=(($820+5816)|0);
      HEAP16[(($821)>>1)]=$819;
      var $822=$len13;
      var $823=((($822)-(16))|0);
      var $824=$1;
      var $825=(($824+5820)|0);
      var $826=HEAP32[(($825)>>2)];
      var $827=((($826)+($823))|0);
      HEAP32[(($825)>>2)]=$827;
      __label__ = 44; break;
    case 43: 
      var $829=$count;
      var $830=((($829)-(11))|0);
      var $831=(($830) & 65535);
      var $832=(($831)&65535);
      var $833=$1;
      var $834=(($833+5820)|0);
      var $835=HEAP32[(($834)>>2)];
      var $836=$832 << $835;
      var $837=$1;
      var $838=(($837+5816)|0);
      var $839=HEAPU16[(($838)>>1)];
      var $840=(($839)&65535);
      var $841=$840 | $836;
      var $842=(($841) & 65535);
      HEAP16[(($838)>>1)]=$842;
      var $843=$len13;
      var $844=$1;
      var $845=(($844+5820)|0);
      var $846=HEAP32[(($845)>>2)];
      var $847=((($846)+($843))|0);
      HEAP32[(($845)>>2)]=$847;
      __label__ = 44; break;
    case 44: 
      __label__ = 45; break;
    case 45: 
      __label__ = 46; break;
    case 46: 
      __label__ = 47; break;
    case 47: 
      __label__ = 48; break;
    case 48: 
      $count=0;
      var $853=$curlen;
      $prevlen=$853;
      var $854=$nextlen;
      var $855=(($854)|0)==0;
      if ($855) { __label__ = 49; break; } else { __label__ = 50; break; }
    case 49: 
      $max_count=138;
      $min_count=3;
      __label__ = 54; break;
    case 50: 
      var $858=$curlen;
      var $859=$nextlen;
      var $860=(($858)|0)==(($859)|0);
      if ($860) { __label__ = 51; break; } else { __label__ = 52; break; }
    case 51: 
      $max_count=6;
      $min_count=3;
      __label__ = 53; break;
    case 52: 
      $max_count=7;
      $min_count=4;
      __label__ = 53; break;
    case 53: 
      __label__ = 54; break;
    case 54: 
      __label__ = 55; break;
    case 55: 
      var $866=$n;
      var $867=((($866)+(1))|0);
      $n=$867;
      __label__ = 5; break;
    case 56: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_send_tree["X"]=1;

function _bi_reverse($code, $len) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $res;
      $1=$code;
      $2=$len;
      $res=0;
      __label__ = 3; break;
    case 3: 
      var $4=$1;
      var $5=$4 & 1;
      var $6=$res;
      var $7=$6 | $5;
      $res=$7;
      var $8=$1;
      var $9=$8 >>> 1;
      $1=$9;
      var $10=$res;
      var $11=$10 << 1;
      $res=$11;
      __label__ = 4; break;
    case 4: 
      var $13=$2;
      var $14=((($13)-(1))|0);
      $2=$14;
      var $15=(($14)|0) > 0;
      if ($15) { __label__ = 3; break; } else { __label__ = 5; break; }
    case 5: 
      var $17=$res;
      var $18=$17 >>> 1;
      ;
      return $18;
    default: assert(0, "bad label: " + __label__);
  }
}


function _scan_tree($s, $tree, $max_code) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $n;
      var $prevlen;
      var $curlen;
      var $nextlen;
      var $count;
      var $max_count;
      var $min_count;
      $1=$s;
      $2=$tree;
      $3=$max_code;
      $prevlen=-1;
      var $4=$2;
      var $5=(($4)|0);
      var $6=(($5+2)|0);
      var $7=$6;
      var $8=HEAPU16[(($7)>>1)];
      var $9=(($8)&65535);
      $nextlen=$9;
      $count=0;
      $max_count=7;
      $min_count=4;
      var $10=$nextlen;
      var $11=(($10)|0)==0;
      if ($11) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      $max_count=138;
      $min_count=3;
      __label__ = 4; break;
    case 4: 
      var $14=$3;
      var $15=((($14)+(1))|0);
      var $16=$2;
      var $17=(($16+($15<<2))|0);
      var $18=(($17+2)|0);
      var $19=$18;
      HEAP16[(($19)>>1)]=-1;
      $n=0;
      __label__ = 5; break;
    case 5: 
      var $21=$n;
      var $22=$3;
      var $23=(($21)|0) <= (($22)|0);
      if ($23) { __label__ = 6; break; } else { __label__ = 29; break; }
    case 6: 
      var $25=$nextlen;
      $curlen=$25;
      var $26=$n;
      var $27=((($26)+(1))|0);
      var $28=$2;
      var $29=(($28+($27<<2))|0);
      var $30=(($29+2)|0);
      var $31=$30;
      var $32=HEAPU16[(($31)>>1)];
      var $33=(($32)&65535);
      $nextlen=$33;
      var $34=$count;
      var $35=((($34)+(1))|0);
      $count=$35;
      var $36=$max_count;
      var $37=(($35)|0) < (($36)|0);
      if ($37) { __label__ = 7; break; } else { __label__ = 9; break; }
    case 7: 
      var $39=$curlen;
      var $40=$nextlen;
      var $41=(($39)|0)==(($40)|0);
      if ($41) { __label__ = 8; break; } else { __label__ = 9; break; }
    case 8: 
      __label__ = 28; break;
    case 9: 
      var $44=$count;
      var $45=$min_count;
      var $46=(($44)|0) < (($45)|0);
      if ($46) { __label__ = 10; break; } else { __label__ = 11; break; }
    case 10: 
      var $48=$count;
      var $49=$curlen;
      var $50=$1;
      var $51=(($50+2684)|0);
      var $52=(($51+($49<<2))|0);
      var $53=(($52)|0);
      var $54=$53;
      var $55=HEAPU16[(($54)>>1)];
      var $56=(($55)&65535);
      var $57=((($56)+($48))|0);
      var $58=(($57) & 65535);
      HEAP16[(($54)>>1)]=$58;
      __label__ = 20; break;
    case 11: 
      var $60=$curlen;
      var $61=(($60)|0)!=0;
      if ($61) { __label__ = 12; break; } else { __label__ = 15; break; }
    case 12: 
      var $63=$curlen;
      var $64=$prevlen;
      var $65=(($63)|0)!=(($64)|0);
      if ($65) { __label__ = 13; break; } else { __label__ = 14; break; }
    case 13: 
      var $67=$curlen;
      var $68=$1;
      var $69=(($68+2684)|0);
      var $70=(($69+($67<<2))|0);
      var $71=(($70)|0);
      var $72=$71;
      var $73=HEAP16[(($72)>>1)];
      var $74=((($73)+(1))&65535);
      HEAP16[(($72)>>1)]=$74;
      __label__ = 14; break;
    case 14: 
      var $76=$1;
      var $77=(($76+2684)|0);
      var $78=(($77+64)|0);
      var $79=(($78)|0);
      var $80=$79;
      var $81=HEAP16[(($80)>>1)];
      var $82=((($81)+(1))&65535);
      HEAP16[(($80)>>1)]=$82;
      __label__ = 19; break;
    case 15: 
      var $84=$count;
      var $85=(($84)|0) <= 10;
      if ($85) { __label__ = 16; break; } else { __label__ = 17; break; }
    case 16: 
      var $87=$1;
      var $88=(($87+2684)|0);
      var $89=(($88+68)|0);
      var $90=(($89)|0);
      var $91=$90;
      var $92=HEAP16[(($91)>>1)];
      var $93=((($92)+(1))&65535);
      HEAP16[(($91)>>1)]=$93;
      __label__ = 18; break;
    case 17: 
      var $95=$1;
      var $96=(($95+2684)|0);
      var $97=(($96+72)|0);
      var $98=(($97)|0);
      var $99=$98;
      var $100=HEAP16[(($99)>>1)];
      var $101=((($100)+(1))&65535);
      HEAP16[(($99)>>1)]=$101;
      __label__ = 18; break;
    case 18: 
      __label__ = 19; break;
    case 19: 
      __label__ = 20; break;
    case 20: 
      __label__ = 21; break;
    case 21: 
      $count=0;
      var $106=$curlen;
      $prevlen=$106;
      var $107=$nextlen;
      var $108=(($107)|0)==0;
      if ($108) { __label__ = 22; break; } else { __label__ = 23; break; }
    case 22: 
      $max_count=138;
      $min_count=3;
      __label__ = 27; break;
    case 23: 
      var $111=$curlen;
      var $112=$nextlen;
      var $113=(($111)|0)==(($112)|0);
      if ($113) { __label__ = 24; break; } else { __label__ = 25; break; }
    case 24: 
      $max_count=6;
      $min_count=3;
      __label__ = 26; break;
    case 25: 
      $max_count=7;
      $min_count=4;
      __label__ = 26; break;
    case 26: 
      __label__ = 27; break;
    case 27: 
      __label__ = 28; break;
    case 28: 
      var $119=$n;
      var $120=((($119)+(1))|0);
      $n=$120;
      __label__ = 5; break;
    case 29: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_scan_tree["X"]=1;

function _pqdownheap($s, $tree, $k) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $v;
      var $j;
      $1=$s;
      $2=$tree;
      $3=$k;
      var $4=$3;
      var $5=$1;
      var $6=(($5+2908)|0);
      var $7=(($6+($4<<2))|0);
      var $8=HEAP32[(($7)>>2)];
      $v=$8;
      var $9=$3;
      var $10=$9 << 1;
      $j=$10;
      __label__ = 3; break;
    case 3: 
      var $12=$j;
      var $13=$1;
      var $14=(($13+5200)|0);
      var $15=HEAP32[(($14)>>2)];
      var $16=(($12)|0) <= (($15)|0);
      if ($16) { __label__ = 4; break; } else { __label__ = 14; break; }
    case 4: 
      var $18=$j;
      var $19=$1;
      var $20=(($19+5200)|0);
      var $21=HEAP32[(($20)>>2)];
      var $22=(($18)|0) < (($21)|0);
      if ($22) { __label__ = 5; break; } else { __label__ = 9; break; }
    case 5: 
      var $24=$j;
      var $25=((($24)+(1))|0);
      var $26=$1;
      var $27=(($26+2908)|0);
      var $28=(($27+($25<<2))|0);
      var $29=HEAP32[(($28)>>2)];
      var $30=$2;
      var $31=(($30+($29<<2))|0);
      var $32=(($31)|0);
      var $33=$32;
      var $34=HEAPU16[(($33)>>1)];
      var $35=(($34)&65535);
      var $36=$j;
      var $37=$1;
      var $38=(($37+2908)|0);
      var $39=(($38+($36<<2))|0);
      var $40=HEAP32[(($39)>>2)];
      var $41=$2;
      var $42=(($41+($40<<2))|0);
      var $43=(($42)|0);
      var $44=$43;
      var $45=HEAPU16[(($44)>>1)];
      var $46=(($45)&65535);
      var $47=(($35)|0) < (($46)|0);
      if ($47) { __label__ = 8; break; } else { __label__ = 6; break; }
    case 6: 
      var $49=$j;
      var $50=((($49)+(1))|0);
      var $51=$1;
      var $52=(($51+2908)|0);
      var $53=(($52+($50<<2))|0);
      var $54=HEAP32[(($53)>>2)];
      var $55=$2;
      var $56=(($55+($54<<2))|0);
      var $57=(($56)|0);
      var $58=$57;
      var $59=HEAPU16[(($58)>>1)];
      var $60=(($59)&65535);
      var $61=$j;
      var $62=$1;
      var $63=(($62+2908)|0);
      var $64=(($63+($61<<2))|0);
      var $65=HEAP32[(($64)>>2)];
      var $66=$2;
      var $67=(($66+($65<<2))|0);
      var $68=(($67)|0);
      var $69=$68;
      var $70=HEAPU16[(($69)>>1)];
      var $71=(($70)&65535);
      var $72=(($60)|0)==(($71)|0);
      if ($72) { __label__ = 7; break; } else { __label__ = 9; break; }
    case 7: 
      var $74=$j;
      var $75=((($74)+(1))|0);
      var $76=$1;
      var $77=(($76+2908)|0);
      var $78=(($77+($75<<2))|0);
      var $79=HEAP32[(($78)>>2)];
      var $80=$1;
      var $81=(($80+5208)|0);
      var $82=(($81+$79)|0);
      var $83=HEAPU8[($82)];
      var $84=(($83)&255);
      var $85=$j;
      var $86=$1;
      var $87=(($86+2908)|0);
      var $88=(($87+($85<<2))|0);
      var $89=HEAP32[(($88)>>2)];
      var $90=$1;
      var $91=(($90+5208)|0);
      var $92=(($91+$89)|0);
      var $93=HEAPU8[($92)];
      var $94=(($93)&255);
      var $95=(($84)|0) <= (($94)|0);
      if ($95) { __label__ = 8; break; } else { __label__ = 9; break; }
    case 8: 
      var $97=$j;
      var $98=((($97)+(1))|0);
      $j=$98;
      __label__ = 9; break;
    case 9: 
      var $100=$v;
      var $101=$2;
      var $102=(($101+($100<<2))|0);
      var $103=(($102)|0);
      var $104=$103;
      var $105=HEAPU16[(($104)>>1)];
      var $106=(($105)&65535);
      var $107=$j;
      var $108=$1;
      var $109=(($108+2908)|0);
      var $110=(($109+($107<<2))|0);
      var $111=HEAP32[(($110)>>2)];
      var $112=$2;
      var $113=(($112+($111<<2))|0);
      var $114=(($113)|0);
      var $115=$114;
      var $116=HEAPU16[(($115)>>1)];
      var $117=(($116)&65535);
      var $118=(($106)|0) < (($117)|0);
      if ($118) { __label__ = 12; break; } else { __label__ = 10; break; }
    case 10: 
      var $120=$v;
      var $121=$2;
      var $122=(($121+($120<<2))|0);
      var $123=(($122)|0);
      var $124=$123;
      var $125=HEAPU16[(($124)>>1)];
      var $126=(($125)&65535);
      var $127=$j;
      var $128=$1;
      var $129=(($128+2908)|0);
      var $130=(($129+($127<<2))|0);
      var $131=HEAP32[(($130)>>2)];
      var $132=$2;
      var $133=(($132+($131<<2))|0);
      var $134=(($133)|0);
      var $135=$134;
      var $136=HEAPU16[(($135)>>1)];
      var $137=(($136)&65535);
      var $138=(($126)|0)==(($137)|0);
      if ($138) { __label__ = 11; break; } else { __label__ = 13; break; }
    case 11: 
      var $140=$v;
      var $141=$1;
      var $142=(($141+5208)|0);
      var $143=(($142+$140)|0);
      var $144=HEAPU8[($143)];
      var $145=(($144)&255);
      var $146=$j;
      var $147=$1;
      var $148=(($147+2908)|0);
      var $149=(($148+($146<<2))|0);
      var $150=HEAP32[(($149)>>2)];
      var $151=$1;
      var $152=(($151+5208)|0);
      var $153=(($152+$150)|0);
      var $154=HEAPU8[($153)];
      var $155=(($154)&255);
      var $156=(($145)|0) <= (($155)|0);
      if ($156) { __label__ = 12; break; } else { __label__ = 13; break; }
    case 12: 
      __label__ = 14; break;
    case 13: 
      var $159=$j;
      var $160=$1;
      var $161=(($160+2908)|0);
      var $162=(($161+($159<<2))|0);
      var $163=HEAP32[(($162)>>2)];
      var $164=$3;
      var $165=$1;
      var $166=(($165+2908)|0);
      var $167=(($166+($164<<2))|0);
      HEAP32[(($167)>>2)]=$163;
      var $168=$j;
      $3=$168;
      var $169=$j;
      var $170=$169 << 1;
      $j=$170;
      __label__ = 3; break;
    case 14: 
      var $172=$v;
      var $173=$3;
      var $174=$1;
      var $175=(($174+2908)|0);
      var $176=(($175+($173<<2))|0);
      HEAP32[(($176)>>2)]=$172;
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_pqdownheap["X"]=1;

function _gen_bitlen($s, $desc) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $tree;
      var $max_code;
      var $stree;
      var $extra;
      var $base;
      var $max_length;
      var $h;
      var $n;
      var $m;
      var $bits;
      var $xbits;
      var $f;
      var $overflow;
      $1=$s;
      $2=$desc;
      var $3=$2;
      var $4=(($3)|0);
      var $5=HEAP32[(($4)>>2)];
      $tree=$5;
      var $6=$2;
      var $7=(($6+4)|0);
      var $8=HEAP32[(($7)>>2)];
      $max_code=$8;
      var $9=$2;
      var $10=(($9+8)|0);
      var $11=HEAP32[(($10)>>2)];
      var $12=(($11)|0);
      var $13=HEAP32[(($12)>>2)];
      $stree=$13;
      var $14=$2;
      var $15=(($14+8)|0);
      var $16=HEAP32[(($15)>>2)];
      var $17=(($16+4)|0);
      var $18=HEAP32[(($17)>>2)];
      $extra=$18;
      var $19=$2;
      var $20=(($19+8)|0);
      var $21=HEAP32[(($20)>>2)];
      var $22=(($21+8)|0);
      var $23=HEAP32[(($22)>>2)];
      $base=$23;
      var $24=$2;
      var $25=(($24+8)|0);
      var $26=HEAP32[(($25)>>2)];
      var $27=(($26+16)|0);
      var $28=HEAP32[(($27)>>2)];
      $max_length=$28;
      $overflow=0;
      $bits=0;
      __label__ = 3; break;
    case 3: 
      var $30=$bits;
      var $31=(($30)|0) <= 15;
      if ($31) { __label__ = 4; break; } else { __label__ = 6; break; }
    case 4: 
      var $33=$bits;
      var $34=$1;
      var $35=(($34+2876)|0);
      var $36=(($35+($33<<1))|0);
      HEAP16[(($36)>>1)]=0;
      __label__ = 5; break;
    case 5: 
      var $38=$bits;
      var $39=((($38)+(1))|0);
      $bits=$39;
      __label__ = 3; break;
    case 6: 
      var $41=$1;
      var $42=(($41+5204)|0);
      var $43=HEAP32[(($42)>>2)];
      var $44=$1;
      var $45=(($44+2908)|0);
      var $46=(($45+($43<<2))|0);
      var $47=HEAP32[(($46)>>2)];
      var $48=$tree;
      var $49=(($48+($47<<2))|0);
      var $50=(($49+2)|0);
      var $51=$50;
      HEAP16[(($51)>>1)]=0;
      var $52=$1;
      var $53=(($52+5204)|0);
      var $54=HEAP32[(($53)>>2)];
      var $55=((($54)+(1))|0);
      $h=$55;
      __label__ = 7; break;
    case 7: 
      var $57=$h;
      var $58=(($57)|0) < 573;
      if ($58) { __label__ = 8; break; } else { __label__ = 18; break; }
    case 8: 
      var $60=$h;
      var $61=$1;
      var $62=(($61+2908)|0);
      var $63=(($62+($60<<2))|0);
      var $64=HEAP32[(($63)>>2)];
      $n=$64;
      var $65=$n;
      var $66=$tree;
      var $67=(($66+($65<<2))|0);
      var $68=(($67+2)|0);
      var $69=$68;
      var $70=HEAPU16[(($69)>>1)];
      var $71=(($70)&65535);
      var $72=$tree;
      var $73=(($72+($71<<2))|0);
      var $74=(($73+2)|0);
      var $75=$74;
      var $76=HEAPU16[(($75)>>1)];
      var $77=(($76)&65535);
      var $78=((($77)+(1))|0);
      $bits=$78;
      var $79=$bits;
      var $80=$max_length;
      var $81=(($79)|0) > (($80)|0);
      if ($81) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      var $83=$max_length;
      $bits=$83;
      var $84=$overflow;
      var $85=((($84)+(1))|0);
      $overflow=$85;
      __label__ = 10; break;
    case 10: 
      var $87=$bits;
      var $88=(($87) & 65535);
      var $89=$n;
      var $90=$tree;
      var $91=(($90+($89<<2))|0);
      var $92=(($91+2)|0);
      var $93=$92;
      HEAP16[(($93)>>1)]=$88;
      var $94=$n;
      var $95=$max_code;
      var $96=(($94)|0) > (($95)|0);
      if ($96) { __label__ = 11; break; } else { __label__ = 12; break; }
    case 11: 
      __label__ = 17; break;
    case 12: 
      var $99=$bits;
      var $100=$1;
      var $101=(($100+2876)|0);
      var $102=(($101+($99<<1))|0);
      var $103=HEAP16[(($102)>>1)];
      var $104=((($103)+(1))&65535);
      HEAP16[(($102)>>1)]=$104;
      $xbits=0;
      var $105=$n;
      var $106=$base;
      var $107=(($105)|0) >= (($106)|0);
      if ($107) { __label__ = 13; break; } else { __label__ = 14; break; }
    case 13: 
      var $109=$n;
      var $110=$base;
      var $111=((($109)-($110))|0);
      var $112=$extra;
      var $113=(($112+($111<<2))|0);
      var $114=HEAP32[(($113)>>2)];
      $xbits=$114;
      __label__ = 14; break;
    case 14: 
      var $116=$n;
      var $117=$tree;
      var $118=(($117+($116<<2))|0);
      var $119=(($118)|0);
      var $120=$119;
      var $121=HEAP16[(($120)>>1)];
      $f=$121;
      var $122=$f;
      var $123=(($122)&65535);
      var $124=$bits;
      var $125=$xbits;
      var $126=((($124)+($125))|0);
      var $127=((($123)*($126))|0);
      var $128=$1;
      var $129=(($128+5800)|0);
      var $130=HEAP32[(($129)>>2)];
      var $131=((($130)+($127))|0);
      HEAP32[(($129)>>2)]=$131;
      var $132=$stree;
      var $133=(($132)|0)!=0;
      if ($133) { __label__ = 15; break; } else { __label__ = 16; break; }
    case 15: 
      var $135=$f;
      var $136=(($135)&65535);
      var $137=$n;
      var $138=$stree;
      var $139=(($138+($137<<2))|0);
      var $140=(($139+2)|0);
      var $141=$140;
      var $142=HEAPU16[(($141)>>1)];
      var $143=(($142)&65535);
      var $144=$xbits;
      var $145=((($143)+($144))|0);
      var $146=((($136)*($145))|0);
      var $147=$1;
      var $148=(($147+5804)|0);
      var $149=HEAP32[(($148)>>2)];
      var $150=((($149)+($146))|0);
      HEAP32[(($148)>>2)]=$150;
      __label__ = 16; break;
    case 16: 
      __label__ = 17; break;
    case 17: 
      var $153=$h;
      var $154=((($153)+(1))|0);
      $h=$154;
      __label__ = 7; break;
    case 18: 
      var $156=$overflow;
      var $157=(($156)|0)==0;
      if ($157) { __label__ = 19; break; } else { __label__ = 20; break; }
    case 19: 
      __label__ = 37; break;
    case 20: 
      __label__ = 21; break;
    case 21: 
      var $161=$max_length;
      var $162=((($161)-(1))|0);
      $bits=$162;
      __label__ = 22; break;
    case 22: 
      var $164=$bits;
      var $165=$1;
      var $166=(($165+2876)|0);
      var $167=(($166+($164<<1))|0);
      var $168=HEAPU16[(($167)>>1)];
      var $169=(($168)&65535);
      var $170=(($169)|0)==0;
      if ($170) { __label__ = 23; break; } else { __label__ = 24; break; }
    case 23: 
      var $172=$bits;
      var $173=((($172)-(1))|0);
      $bits=$173;
      __label__ = 22; break;
    case 24: 
      var $175=$bits;
      var $176=$1;
      var $177=(($176+2876)|0);
      var $178=(($177+($175<<1))|0);
      var $179=HEAP16[(($178)>>1)];
      var $180=((($179)-(1))&65535);
      HEAP16[(($178)>>1)]=$180;
      var $181=$bits;
      var $182=((($181)+(1))|0);
      var $183=$1;
      var $184=(($183+2876)|0);
      var $185=(($184+($182<<1))|0);
      var $186=HEAPU16[(($185)>>1)];
      var $187=(($186)&65535);
      var $188=((($187)+(2))|0);
      var $189=(($188) & 65535);
      HEAP16[(($185)>>1)]=$189;
      var $190=$max_length;
      var $191=$1;
      var $192=(($191+2876)|0);
      var $193=(($192+($190<<1))|0);
      var $194=HEAP16[(($193)>>1)];
      var $195=((($194)-(1))&65535);
      HEAP16[(($193)>>1)]=$195;
      var $196=$overflow;
      var $197=((($196)-(2))|0);
      $overflow=$197;
      __label__ = 25; break;
    case 25: 
      var $199=$overflow;
      var $200=(($199)|0) > 0;
      if ($200) { __label__ = 21; break; } else { __label__ = 26; break; }
    case 26: 
      var $202=$max_length;
      $bits=$202;
      __label__ = 27; break;
    case 27: 
      var $204=$bits;
      var $205=(($204)|0)!=0;
      if ($205) { __label__ = 28; break; } else { __label__ = 37; break; }
    case 28: 
      var $207=$bits;
      var $208=$1;
      var $209=(($208+2876)|0);
      var $210=(($209+($207<<1))|0);
      var $211=HEAPU16[(($210)>>1)];
      var $212=(($211)&65535);
      $n=$212;
      __label__ = 29; break;
    case 29: 
      var $214=$n;
      var $215=(($214)|0)!=0;
      if ($215) { __label__ = 30; break; } else { __label__ = 35; break; }
    case 30: 
      var $217=$h;
      var $218=((($217)-(1))|0);
      $h=$218;
      var $219=$1;
      var $220=(($219+2908)|0);
      var $221=(($220+($218<<2))|0);
      var $222=HEAP32[(($221)>>2)];
      $m=$222;
      var $223=$m;
      var $224=$max_code;
      var $225=(($223)|0) > (($224)|0);
      if ($225) { __label__ = 31; break; } else { __label__ = 32; break; }
    case 31: 
      __label__ = 29; break;
    case 32: 
      var $228=$m;
      var $229=$tree;
      var $230=(($229+($228<<2))|0);
      var $231=(($230+2)|0);
      var $232=$231;
      var $233=HEAPU16[(($232)>>1)];
      var $234=(($233)&65535);
      var $235=$bits;
      var $236=(($234)|0)!=(($235)|0);
      if ($236) { __label__ = 33; break; } else { __label__ = 34; break; }
    case 33: 
      var $238=$bits;
      var $239=$m;
      var $240=$tree;
      var $241=(($240+($239<<2))|0);
      var $242=(($241+2)|0);
      var $243=$242;
      var $244=HEAPU16[(($243)>>1)];
      var $245=(($244)&65535);
      var $246=((($238)-($245))|0);
      var $247=$m;
      var $248=$tree;
      var $249=(($248+($247<<2))|0);
      var $250=(($249)|0);
      var $251=$250;
      var $252=HEAPU16[(($251)>>1)];
      var $253=(($252)&65535);
      var $254=((($246)*($253))|0);
      var $255=$1;
      var $256=(($255+5800)|0);
      var $257=HEAP32[(($256)>>2)];
      var $258=((($257)+($254))|0);
      HEAP32[(($256)>>2)]=$258;
      var $259=$bits;
      var $260=(($259) & 65535);
      var $261=$m;
      var $262=$tree;
      var $263=(($262+($261<<2))|0);
      var $264=(($263+2)|0);
      var $265=$264;
      HEAP16[(($265)>>1)]=$260;
      __label__ = 34; break;
    case 34: 
      var $267=$n;
      var $268=((($267)-(1))|0);
      $n=$268;
      __label__ = 29; break;
    case 35: 
      __label__ = 36; break;
    case 36: 
      var $271=$bits;
      var $272=((($271)-(1))|0);
      $bits=$272;
      __label__ = 27; break;
    case 37: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_gen_bitlen["X"]=1;

function _gen_codes($tree, $max_code, $bl_count) {
  var __stackBase__  = STACKTOP; STACKTOP += 32; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $next_code=__stackBase__;
      var $code;
      var $bits;
      var $n;
      var $len;
      $1=$tree;
      $2=$max_code;
      $3=$bl_count;
      $code=0;
      $bits=1;
      __label__ = 3; break;
    case 3: 
      var $5=$bits;
      var $6=(($5)|0) <= 15;
      if ($6) { __label__ = 4; break; } else { __label__ = 6; break; }
    case 4: 
      var $8=$code;
      var $9=(($8)&65535);
      var $10=$bits;
      var $11=((($10)-(1))|0);
      var $12=$3;
      var $13=(($12+($11<<1))|0);
      var $14=HEAPU16[(($13)>>1)];
      var $15=(($14)&65535);
      var $16=((($9)+($15))|0);
      var $17=$16 << 1;
      var $18=(($17) & 65535);
      $code=$18;
      var $19=$bits;
      var $20=(($next_code+($19<<1))|0);
      HEAP16[(($20)>>1)]=$18;
      __label__ = 5; break;
    case 5: 
      var $22=$bits;
      var $23=((($22)+(1))|0);
      $bits=$23;
      __label__ = 3; break;
    case 6: 
      $n=0;
      __label__ = 7; break;
    case 7: 
      var $26=$n;
      var $27=$2;
      var $28=(($26)|0) <= (($27)|0);
      if ($28) { __label__ = 8; break; } else { __label__ = 12; break; }
    case 8: 
      var $30=$n;
      var $31=$1;
      var $32=(($31+($30<<2))|0);
      var $33=(($32+2)|0);
      var $34=$33;
      var $35=HEAPU16[(($34)>>1)];
      var $36=(($35)&65535);
      $len=$36;
      var $37=$len;
      var $38=(($37)|0)==0;
      if ($38) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      __label__ = 11; break;
    case 10: 
      var $41=$len;
      var $42=(($next_code+($41<<1))|0);
      var $43=HEAPU16[(($42)>>1)];
      var $44=((($43)+(1))&65535);
      HEAP16[(($42)>>1)]=$44;
      var $45=(($43)&65535);
      var $46=$len;
      var $47=_bi_reverse($45, $46);
      var $48=(($47) & 65535);
      var $49=$n;
      var $50=$1;
      var $51=(($50+($49<<2))|0);
      var $52=(($51)|0);
      var $53=$52;
      HEAP16[(($53)>>1)]=$48;
      __label__ = 11; break;
    case 11: 
      var $55=$n;
      var $56=((($55)+(1))|0);
      $n=$56;
      __label__ = 7; break;
    case 12: 
      STACKTOP = __stackBase__;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_gen_codes["X"]=1;

function _zcalloc($opaque, $items, $size) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      $1=$opaque;
      $2=$items;
      $3=$size;
      var $4=$1;
      var $5=(($4)|0)!=0;
      if ($5) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $7=$3;
      var $8=$3;
      var $9=((($7)-($8))|0);
      var $10=$2;
      var $11=((($10)+($9))|0);
      $2=$11;
      __label__ = 4; break;
    case 4: 
      var $13=$2;
      var $14=$3;
      var $15=((($13)*($14))|0);
      var $16=_malloc($15);
      ;
      return $16;
    default: assert(0, "bad label: " + __label__);
  }
}


function _zcfree($opaque, $ptr) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      $1=$opaque;
      $2=$ptr;
      var $3=$2;
      _free($3);
      var $4=$1;
      var $5=(($4)|0)!=0;
      if ($5) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      __label__ = 4; break;
    case 4: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}


function _png_set_sig_bytes($png_ptr, $num_bytes) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      $1=$png_ptr;
      $2=$num_bytes;
      var $3=$1;
      var $4=(($3)|0)==0;
      if ($4) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      __label__ = 10; break;
    case 4: 
      var $7=$2;
      var $8=(($7)|0) > 8;
      if ($8) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $10=$1;
      _png_error($10, ((STRING_TABLE.__str91)|0));
      __label__ = 6; break;
    case 6: 
      var $12=$2;
      var $13=(($12)|0) < 0;
      if ($13) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $18 = 0;__label__ = 9; break;
    case 8: 
      var $16=$2;
      var $18 = $16;__label__ = 9; break;
    case 9: 
      var $18;
      var $19=(($18) & 255);
      var $20=$1;
      var $21=(($20+280)|0);
      HEAP8[($21)]=$19;
      __label__ = 10; break;
    case 10: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}


function _png_sig_cmp($sig, $start, $num_to_check) {
  var __stackBase__  = STACKTOP; STACKTOP += 8; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $png_signature=__stackBase__;
      $2=$sig;
      $3=$start;
      $4=$num_to_check;
      var $5=$png_signature;
      assert(8 % 1 === 0, 'memcpy given ' + 8 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP8[($5)]=HEAP8[(((STRING_TABLE._png_sig_cmp_png_signature)|0))];HEAP8[(($5)+(1))]=HEAP8[((((STRING_TABLE._png_sig_cmp_png_signature)|0))+(1))];HEAP8[(($5)+(2))]=HEAP8[((((STRING_TABLE._png_sig_cmp_png_signature)|0))+(2))];HEAP8[(($5)+(3))]=HEAP8[((((STRING_TABLE._png_sig_cmp_png_signature)|0))+(3))];HEAP8[(($5)+(4))]=HEAP8[((((STRING_TABLE._png_sig_cmp_png_signature)|0))+(4))];HEAP8[(($5)+(5))]=HEAP8[((((STRING_TABLE._png_sig_cmp_png_signature)|0))+(5))];HEAP8[(($5)+(6))]=HEAP8[((((STRING_TABLE._png_sig_cmp_png_signature)|0))+(6))];HEAP8[(($5)+(7))]=HEAP8[((((STRING_TABLE._png_sig_cmp_png_signature)|0))+(7))];
      var $6=$4;
      var $7=(($6)>>>0) > 8;
      if ($7) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      $4=8;
      __label__ = 7; break;
    case 4: 
      var $10=$4;
      var $11=(($10)>>>0) < 1;
      if ($11) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      $1=-1;
      __label__ = 12; break;
    case 6: 
      __label__ = 7; break;
    case 7: 
      var $15=$3;
      var $16=(($15)>>>0) > 7;
      if ($16) { __label__ = 8; break; } else { __label__ = 9; break; }
    case 8: 
      $1=-1;
      __label__ = 12; break;
    case 9: 
      var $19=$3;
      var $20=$4;
      var $21=((($19)+($20))|0);
      var $22=(($21)>>>0) > 8;
      if ($22) { __label__ = 10; break; } else { __label__ = 11; break; }
    case 10: 
      var $24=$3;
      var $25=(((8)-($24))|0);
      $4=$25;
      __label__ = 11; break;
    case 11: 
      var $27=$3;
      var $28=$2;
      var $29=(($28+$27)|0);
      var $30=$3;
      var $31=(($png_signature+$30)|0);
      var $32=$4;
      var $33=_memcmp($29, $31, $32);
      $1=$33;
      __label__ = 12; break;
    case 12: 
      var $35=$1;
      STACKTOP = __stackBase__;
      return $35;
    default: assert(0, "bad label: " + __label__);
  }
}


function _png_zalloc($png_ptr, $items, $size) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $ptr;
      var $p;
      var $save_flags;
      var $num_bytes;
      $2=$png_ptr;
      $3=$items;
      $4=$size;
      var $5=$2;
      var $6=$5;
      $p=$6;
      var $7=$p;
      var $8=(($7+88)|0);
      var $9=HEAP32[(($8)>>2)];
      $save_flags=$9;
      var $10=$2;
      var $11=(($10)|0)==0;
      if ($11) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      $1=0;
      __label__ = 7; break;
    case 4: 
      var $14=$3;
      var $15=$4;
      var $16=Math.floor((4294967295)/((($15)>>>0)));
      var $17=(($14)>>>0) > (($16)>>>0);
      if ($17) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $19=$p;
      _png_warning($19, ((STRING_TABLE.__str192)|0));
      $1=0;
      __label__ = 7; break;
    case 6: 
      var $21=$3;
      var $22=$4;
      var $23=((($21)*($22))|0);
      $num_bytes=$23;
      var $24=$p;
      var $25=(($24+88)|0);
      var $26=HEAP32[(($25)>>2)];
      var $27=$26 | 1048576;
      HEAP32[(($25)>>2)]=$27;
      var $28=$2;
      var $29=$28;
      var $30=$num_bytes;
      var $31=_png_malloc($29, $30);
      $ptr=$31;
      var $32=$save_flags;
      var $33=$p;
      var $34=(($33+88)|0);
      HEAP32[(($34)>>2)]=$32;
      var $35=$ptr;
      $1=$35;
      __label__ = 7; break;
    case 7: 
      var $37=$1;
      ;
      return $37;
    default: assert(0, "bad label: " + __label__);
  }
}
_png_zalloc["X"]=1;

function _png_zfree($png_ptr, $ptr) {
  ;
  var __label__;

  var $1;
  var $2;
  $1=$png_ptr;
  $2=$ptr;
  var $3=$1;
  var $4=$3;
  var $5=$2;
  _png_free($4, $5);
  ;
  return;
}


function _png_reset_crc($png_ptr) {
  ;
  var __label__;

  var $1;
  $1=$png_ptr;
  var $2=_crc32(0, 0, 0);
  var $3=$1;
  var $4=(($3+252)|0);
  HEAP32[(($4)>>2)]=$2;
  ;
  return;
}


function _png_calculate_crc($png_ptr, $ptr, $length) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $need_crc;
      $1=$png_ptr;
      $2=$ptr;
      $3=$length;
      $need_crc=1;
      var $4=$1;
      var $5=(($4+264)|0);
      var $6=(($5)|0);
      var $7=HEAPU8[($6)];
      var $8=(($7)&255);
      var $9=$8 & 32;
      var $10=(($9)|0)!=0;
      if ($10) { __label__ = 3; break; } else { __label__ = 6; break; }
    case 3: 
      var $12=$1;
      var $13=(($12+88)|0);
      var $14=HEAP32[(($13)>>2)];
      var $15=$14 & 768;
      var $16=(($15)|0)==768;
      if ($16) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      $need_crc=0;
      __label__ = 5; break;
    case 5: 
      __label__ = 9; break;
    case 6: 
      var $20=$1;
      var $21=(($20+88)|0);
      var $22=HEAP32[(($21)>>2)];
      var $23=$22 & 2048;
      var $24=(($23)|0)!=0;
      if ($24) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      $need_crc=0;
      __label__ = 8; break;
    case 8: 
      __label__ = 9; break;
    case 9: 
      var $28=$need_crc;
      var $29=(($28)|0)!=0;
      if ($29) { __label__ = 10; break; } else { __label__ = 11; break; }
    case 10: 
      var $31=$1;
      var $32=(($31+252)|0);
      var $33=HEAP32[(($32)>>2)];
      var $34=$2;
      var $35=$3;
      var $36=_crc32($33, $34, $35);
      var $37=$1;
      var $38=(($37+252)|0);
      HEAP32[(($38)>>2)]=$36;
      __label__ = 11; break;
    case 11: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}


function _png_create_info_struct($png_ptr) {
  var __stackBase__  = STACKTOP; STACKTOP += 4; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $info_ptr=__stackBase__;
      $2=$png_ptr;
      var $3=$2;
      var $4=(($3)|0)==0;
      if ($4) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      $1=0;
      __label__ = 7; break;
    case 4: 
      var $7=$2;
      var $8=(($7+556)|0);
      var $9=HEAP32[(($8)>>2)];
      var $10=$2;
      var $11=(($10+552)|0);
      var $12=HEAP32[(($11)>>2)];
      var $13=_png_create_struct_2(2, $9, $12);
      var $14=$13;
      HEAP32[(($info_ptr)>>2)]=$14;
      var $15=HEAP32[(($info_ptr)>>2)];
      var $16=(($15)|0)!=0;
      if ($16) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      _png_info_init_3($info_ptr, 288);
      __label__ = 6; break;
    case 6: 
      var $19=HEAP32[(($info_ptr)>>2)];
      $1=$19;
      __label__ = 7; break;
    case 7: 
      var $21=$1;
      STACKTOP = __stackBase__;
      return $21;
    default: assert(0, "bad label: " + __label__);
  }
}


function _png_info_init_3($ptr_ptr, $png_info_struct_size) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $info_ptr;
      $1=$ptr_ptr;
      $2=$png_info_struct_size;
      var $3=$1;
      var $4=HEAP32[(($3)>>2)];
      $info_ptr=$4;
      var $5=$info_ptr;
      var $6=(($5)|0)==0;
      if ($6) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      __label__ = 7; break;
    case 4: 
      var $9=$2;
      var $10=288 > (($9)>>>0);
      if ($10) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $12=$info_ptr;
      var $13=$12;
      _png_destroy_struct($13);
      var $14=_png_create_struct(2);
      var $15=$14;
      $info_ptr=$15;
      var $16=$info_ptr;
      var $17=$1;
      HEAP32[(($17)>>2)]=$16;
      __label__ = 6; break;
    case 6: 
      var $19=$info_ptr;
      var $20=$19;
      _memset($20, 0, 288, 1);
      __label__ = 7; break;
    case 7: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}


function _png_info_destroy($png_ptr, $info_ptr) {
  var __stackBase__  = STACKTOP; STACKTOP += 4; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2=__stackBase__;
      $1=$png_ptr;
      HEAP32[(($2)>>2)]=$info_ptr;
      var $3=$1;
      var $4=HEAP32[(($2)>>2)];
      _png_free_data($3, $4, 32767, -1);
      var $5=$1;
      var $6=(($5+524)|0);
      var $7=HEAP32[(($6)>>2)];
      var $8=(($7)|0)!=0;
      if ($8) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $10=$1;
      var $11=$1;
      var $12=(($11+528)|0);
      var $13=HEAP32[(($12)>>2)];
      _png_free($10, $13);
      var $14=$1;
      var $15=(($14+528)|0);
      HEAP32[(($15)>>2)]=0;
      var $16=$1;
      var $17=(($16+524)|0);
      HEAP32[(($17)>>2)]=0;
      __label__ = 4; break;
    case 4: 
      _png_info_init_3($2, 288);
      STACKTOP = __stackBase__;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}


function _png_get_header_ver($png_ptr) {
  ;
  var __label__;

  var $1;
  $1=$png_ptr;
  var $2=$1;
  ;
  return ((STRING_TABLE.__str596)|0);
}


function _png_64bit_product($v1, $v2, $hi_product, $lo_product) {
  ;
  var __label__;

  var $1;
  var $2;
  var $3;
  var $4;
  var $a;
  var $b;
  var $c;
  var $d;
  var $lo;
  var $hi;
  var $x;
  var $y;
  $1=$v1;
  $2=$v2;
  $3=$hi_product;
  $4=$lo_product;
  var $5=$1;
  var $6=$5 >> 16;
  var $7=$6 & 65535;
  $a=$7;
  var $8=$1;
  var $9=$8 & 65535;
  $b=$9;
  var $10=$2;
  var $11=$10 >> 16;
  var $12=$11 & 65535;
  $c=$12;
  var $13=$2;
  var $14=$13 & 65535;
  $d=$14;
  var $15=$b;
  var $16=$d;
  var $17=((($15)*($16))|0);
  $lo=$17;
  var $18=$a;
  var $19=$d;
  var $20=((($18)*($19))|0);
  var $21=$c;
  var $22=$b;
  var $23=((($21)*($22))|0);
  var $24=((($20)+($23))|0);
  $x=$24;
  var $25=$lo;
  var $26=$25 >> 16;
  var $27=$26 & 65535;
  var $28=$x;
  var $29=((($27)+($28))|0);
  $y=$29;
  var $30=$lo;
  var $31=$30 & 65535;
  var $32=$y;
  var $33=$32 & 65535;
  var $34=$33 << 16;
  var $35=$31 | $34;
  $lo=$35;
  var $36=$y;
  var $37=$36 >> 16;
  var $38=$37 & 65535;
  $hi=$38;
  var $39=$a;
  var $40=$c;
  var $41=((($39)*($40))|0);
  var $42=$hi;
  var $43=((($42)+($41))|0);
  $hi=$43;
  var $44=$hi;
  var $45=$3;
  HEAP32[(($45)>>2)]=$44;
  var $46=$lo;
  var $47=$4;
  HEAP32[(($47)>>2)]=$46;
  ;
  return;
}
_png_64bit_product["X"]=1;

function _png_get_io_ptr($png_ptr) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      $2=$png_ptr;
      var $3=$2;
      var $4=(($3)|0)==0;
      if ($4) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      $1=0;
      __label__ = 5; break;
    case 4: 
      var $7=$2;
      var $8=(($7+64)|0);
      var $9=HEAP32[(($8)>>2)];
      $1=$9;
      __label__ = 5; break;
    case 5: 
      var $11=$1;
      ;
      return $11;
    default: assert(0, "bad label: " + __label__);
  }
}


function _png_free_data($png_ptr, $info_ptr, $mask, $num) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $i;
      var $i1;
      var $i2;
      var $i3;
      var $row;
      $1=$png_ptr;
      $2=$info_ptr;
      $3=$mask;
      $4=$num;
      var $5=$1;
      var $6=(($5)|0)==0;
      if ($6) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      var $8=$2;
      var $9=(($8)|0)==0;
      if ($9) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      __label__ = 74; break;
    case 5: 
      var $12=$3;
      var $13=$12 & 16384;
      var $14=$2;
      var $15=(($14+184)|0);
      var $16=HEAP32[(($15)>>2)];
      var $17=$13 & $16;
      var $18=(($17)|0)!=0;
      if ($18) { __label__ = 6; break; } else { __label__ = 17; break; }
    case 6: 
      var $20=$4;
      var $21=(($20)|0)!=-1;
      if ($21) { __label__ = 7; break; } else { __label__ = 11; break; }
    case 7: 
      var $23=$2;
      var $24=(($23+56)|0);
      var $25=HEAP32[(($24)>>2)];
      var $26=(($25)|0)!=0;
      if ($26) { __label__ = 8; break; } else { __label__ = 10; break; }
    case 8: 
      var $28=$4;
      var $29=$2;
      var $30=(($29+56)|0);
      var $31=HEAP32[(($30)>>2)];
      var $32=(($31+($28)*(28))|0);
      var $33=(($32+4)|0);
      var $34=HEAP32[(($33)>>2)];
      var $35=(($34)|0)!=0;
      if ($35) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      var $37=$1;
      var $38=$4;
      var $39=$2;
      var $40=(($39+56)|0);
      var $41=HEAP32[(($40)>>2)];
      var $42=(($41+($38)*(28))|0);
      var $43=(($42+4)|0);
      var $44=HEAP32[(($43)>>2)];
      _png_free($37, $44);
      var $45=$4;
      var $46=$2;
      var $47=(($46+56)|0);
      var $48=HEAP32[(($47)>>2)];
      var $49=(($48+($45)*(28))|0);
      var $50=(($49+4)|0);
      HEAP32[(($50)>>2)]=0;
      __label__ = 10; break;
    case 10: 
      __label__ = 16; break;
    case 11: 
      $i=0;
      __label__ = 12; break;
    case 12: 
      var $54=$i;
      var $55=$2;
      var $56=(($55+48)|0);
      var $57=HEAP32[(($56)>>2)];
      var $58=(($54)|0) < (($57)|0);
      if ($58) { __label__ = 13; break; } else { __label__ = 15; break; }
    case 13: 
      var $60=$1;
      var $61=$2;
      var $62=$i;
      _png_free_data($60, $61, 16384, $62);
      __label__ = 14; break;
    case 14: 
      var $64=$i;
      var $65=((($64)+(1))|0);
      $i=$65;
      __label__ = 12; break;
    case 15: 
      var $67=$1;
      var $68=$2;
      var $69=(($68+56)|0);
      var $70=HEAP32[(($69)>>2)];
      var $71=$70;
      _png_free($67, $71);
      var $72=$2;
      var $73=(($72+56)|0);
      HEAP32[(($73)>>2)]=0;
      var $74=$2;
      var $75=(($74+48)|0);
      HEAP32[(($75)>>2)]=0;
      __label__ = 16; break;
    case 16: 
      __label__ = 17; break;
    case 17: 
      var $78=$3;
      var $79=$78 & 8192;
      var $80=$2;
      var $81=(($80+184)|0);
      var $82=HEAP32[(($81)>>2)];
      var $83=$79 & $82;
      var $84=(($83)|0)!=0;
      if ($84) { __label__ = 18; break; } else { __label__ = 19; break; }
    case 18: 
      var $86=$1;
      var $87=$2;
      var $88=(($87+76)|0);
      var $89=HEAP32[(($88)>>2)];
      _png_free($86, $89);
      var $90=$2;
      var $91=(($90+76)|0);
      HEAP32[(($91)>>2)]=0;
      var $92=$2;
      var $93=(($92+8)|0);
      var $94=HEAP32[(($93)>>2)];
      var $95=$94 & -17;
      HEAP32[(($93)>>2)]=$95;
      __label__ = 19; break;
    case 19: 
      var $97=$3;
      var $98=$97 & 256;
      var $99=$2;
      var $100=(($99+184)|0);
      var $101=HEAP32[(($100)>>2)];
      var $102=$98 & $101;
      var $103=(($102)|0)!=0;
      if ($103) { __label__ = 20; break; } else { __label__ = 21; break; }
    case 20: 
      var $105=$2;
      var $106=(($105+8)|0);
      var $107=HEAP32[(($106)>>2)];
      var $108=$107 & -16385;
      HEAP32[(($106)>>2)]=$108;
      __label__ = 21; break;
    case 21: 
      var $110=$3;
      var $111=$110 & 128;
      var $112=$2;
      var $113=(($112+184)|0);
      var $114=HEAP32[(($113)>>2)];
      var $115=$111 & $114;
      var $116=(($115)|0)!=0;
      if ($116) { __label__ = 22; break; } else { __label__ = 29; break; }
    case 22: 
      var $118=$1;
      var $119=$2;
      var $120=(($119+160)|0);
      var $121=HEAP32[(($120)>>2)];
      _png_free($118, $121);
      var $122=$1;
      var $123=$2;
      var $124=(($123+172)|0);
      var $125=HEAP32[(($124)>>2)];
      _png_free($122, $125);
      var $126=$2;
      var $127=(($126+160)|0);
      HEAP32[(($127)>>2)]=0;
      var $128=$2;
      var $129=(($128+172)|0);
      HEAP32[(($129)>>2)]=0;
      var $130=$2;
      var $131=(($130+176)|0);
      var $132=HEAP32[(($131)>>2)];
      var $133=(($132)|0)!=0;
      if ($133) { __label__ = 23; break; } else { __label__ = 28; break; }
    case 23: 
      $i1=0;
      __label__ = 24; break;
    case 24: 
      var $136=$i1;
      var $137=$2;
      var $138=(($137+181)|0);
      var $139=HEAPU8[($138)];
      var $140=(($139)&255);
      var $141=(($136)|0) < (($140)|0);
      if ($141) { __label__ = 25; break; } else { __label__ = 27; break; }
    case 25: 
      var $143=$1;
      var $144=$i1;
      var $145=$2;
      var $146=(($145+176)|0);
      var $147=HEAP32[(($146)>>2)];
      var $148=(($147+($144<<2))|0);
      var $149=HEAP32[(($148)>>2)];
      _png_free($143, $149);
      var $150=$i1;
      var $151=$2;
      var $152=(($151+176)|0);
      var $153=HEAP32[(($152)>>2)];
      var $154=(($153+($150<<2))|0);
      HEAP32[(($154)>>2)]=0;
      __label__ = 26; break;
    case 26: 
      var $156=$i1;
      var $157=((($156)+(1))|0);
      $i1=$157;
      __label__ = 24; break;
    case 27: 
      var $159=$1;
      var $160=$2;
      var $161=(($160+176)|0);
      var $162=HEAP32[(($161)>>2)];
      var $163=$162;
      _png_free($159, $163);
      var $164=$2;
      var $165=(($164+176)|0);
      HEAP32[(($165)>>2)]=0;
      __label__ = 28; break;
    case 28: 
      var $167=$2;
      var $168=(($167+8)|0);
      var $169=HEAP32[(($168)>>2)];
      var $170=$169 & -1025;
      HEAP32[(($168)>>2)]=$170;
      __label__ = 29; break;
    case 29: 
      var $172=$3;
      var $173=$172 & 16;
      var $174=$2;
      var $175=(($174+184)|0);
      var $176=HEAP32[(($175)>>2)];
      var $177=$173 & $176;
      var $178=(($177)|0)!=0;
      if ($178) { __label__ = 30; break; } else { __label__ = 31; break; }
    case 30: 
      var $180=$1;
      var $181=$2;
      var $182=(($181+196)|0);
      var $183=HEAP32[(($182)>>2)];
      _png_free($180, $183);
      var $184=$1;
      var $185=$2;
      var $186=(($185+200)|0);
      var $187=HEAP32[(($186)>>2)];
      _png_free($184, $187);
      var $188=$2;
      var $189=(($188+196)|0);
      HEAP32[(($189)>>2)]=0;
      var $190=$2;
      var $191=(($190+200)|0);
      HEAP32[(($191)>>2)]=0;
      var $192=$2;
      var $193=(($192+8)|0);
      var $194=HEAP32[(($193)>>2)];
      var $195=$194 & -4097;
      HEAP32[(($193)>>2)]=$195;
      __label__ = 31; break;
    case 31: 
      var $197=$3;
      var $198=$197 & 32;
      var $199=$2;
      var $200=(($199+184)|0);
      var $201=HEAP32[(($200)>>2)];
      var $202=$198 & $201;
      var $203=(($202)|0)!=0;
      if ($203) { __label__ = 32; break; } else { __label__ = 44; break; }
    case 32: 
      var $205=$4;
      var $206=(($205)|0)!=-1;
      if ($206) { __label__ = 33; break; } else { __label__ = 36; break; }
    case 33: 
      var $208=$2;
      var $209=(($208+212)|0);
      var $210=HEAP32[(($209)>>2)];
      var $211=(($210)|0)!=0;
      if ($211) { __label__ = 34; break; } else { __label__ = 35; break; }
    case 34: 
      var $213=$1;
      var $214=$4;
      var $215=$2;
      var $216=(($215+212)|0);
      var $217=HEAP32[(($216)>>2)];
      var $218=(($217+($214<<4))|0);
      var $219=(($218)|0);
      var $220=HEAP32[(($219)>>2)];
      _png_free($213, $220);
      var $221=$1;
      var $222=$4;
      var $223=$2;
      var $224=(($223+212)|0);
      var $225=HEAP32[(($224)>>2)];
      var $226=(($225+($222<<4))|0);
      var $227=(($226+8)|0);
      var $228=HEAP32[(($227)>>2)];
      var $229=$228;
      _png_free($221, $229);
      var $230=$4;
      var $231=$2;
      var $232=(($231+212)|0);
      var $233=HEAP32[(($232)>>2)];
      var $234=(($233+($230<<4))|0);
      var $235=(($234)|0);
      HEAP32[(($235)>>2)]=0;
      var $236=$4;
      var $237=$2;
      var $238=(($237+212)|0);
      var $239=HEAP32[(($238)>>2)];
      var $240=(($239+($236<<4))|0);
      var $241=(($240+8)|0);
      HEAP32[(($241)>>2)]=0;
      __label__ = 35; break;
    case 35: 
      __label__ = 43; break;
    case 36: 
      var $244=$2;
      var $245=(($244+216)|0);
      var $246=HEAP32[(($245)>>2)];
      var $247=(($246)|0)!=0;
      if ($247) { __label__ = 37; break; } else { __label__ = 42; break; }
    case 37: 
      $i2=0;
      __label__ = 38; break;
    case 38: 
      var $250=$i2;
      var $251=$2;
      var $252=(($251+216)|0);
      var $253=HEAP32[(($252)>>2)];
      var $254=(($250)|0) < (($253)|0);
      if ($254) { __label__ = 39; break; } else { __label__ = 41; break; }
    case 39: 
      var $256=$1;
      var $257=$2;
      var $258=$i2;
      _png_free_data($256, $257, 32, $258);
      __label__ = 40; break;
    case 40: 
      var $260=$i2;
      var $261=((($260)+(1))|0);
      $i2=$261;
      __label__ = 38; break;
    case 41: 
      var $263=$1;
      var $264=$2;
      var $265=(($264+212)|0);
      var $266=HEAP32[(($265)>>2)];
      var $267=$266;
      _png_free($263, $267);
      var $268=$2;
      var $269=(($268+212)|0);
      HEAP32[(($269)>>2)]=0;
      var $270=$2;
      var $271=(($270+216)|0);
      HEAP32[(($271)>>2)]=0;
      __label__ = 42; break;
    case 42: 
      var $273=$2;
      var $274=(($273+8)|0);
      var $275=HEAP32[(($274)>>2)];
      var $276=$275 & -8193;
      HEAP32[(($274)>>2)]=$276;
      __label__ = 43; break;
    case 43: 
      __label__ = 44; break;
    case 44: 
      var $279=$1;
      var $280=(($279+596)|0);
      var $281=(($280+8)|0);
      var $282=HEAP32[(($281)>>2)];
      var $283=(($282)|0)!=0;
      if ($283) { __label__ = 45; break; } else { __label__ = 46; break; }
    case 45: 
      var $285=$1;
      var $286=$1;
      var $287=(($286+596)|0);
      var $288=(($287+8)|0);
      var $289=HEAP32[(($288)>>2)];
      _png_free($285, $289);
      var $290=$1;
      var $291=(($290+596)|0);
      var $292=(($291+8)|0);
      HEAP32[(($292)>>2)]=0;
      __label__ = 46; break;
    case 46: 
      var $294=$3;
      var $295=$294 & 512;
      var $296=$2;
      var $297=(($296+184)|0);
      var $298=HEAP32[(($297)>>2)];
      var $299=$295 & $298;
      var $300=(($299)|0)!=0;
      if ($300) { __label__ = 47; break; } else { __label__ = 59; break; }
    case 47: 
      var $302=$4;
      var $303=(($302)|0)!=-1;
      if ($303) { __label__ = 48; break; } else { __label__ = 51; break; }
    case 48: 
      var $305=$2;
      var $306=(($305+188)|0);
      var $307=HEAP32[(($306)>>2)];
      var $308=(($307)|0)!=0;
      if ($308) { __label__ = 49; break; } else { __label__ = 50; break; }
    case 49: 
      var $310=$1;
      var $311=$4;
      var $312=$2;
      var $313=(($312+188)|0);
      var $314=HEAP32[(($313)>>2)];
      var $315=(($314+($311)*(20))|0);
      var $316=(($315+8)|0);
      var $317=HEAP32[(($316)>>2)];
      _png_free($310, $317);
      var $318=$4;
      var $319=$2;
      var $320=(($319+188)|0);
      var $321=HEAP32[(($320)>>2)];
      var $322=(($321+($318)*(20))|0);
      var $323=(($322+8)|0);
      HEAP32[(($323)>>2)]=0;
      __label__ = 50; break;
    case 50: 
      __label__ = 58; break;
    case 51: 
      var $326=$2;
      var $327=(($326+192)|0);
      var $328=HEAP32[(($327)>>2)];
      var $329=(($328)|0)!=0;
      if ($329) { __label__ = 52; break; } else { __label__ = 57; break; }
    case 52: 
      $i3=0;
      __label__ = 53; break;
    case 53: 
      var $332=$i3;
      var $333=$2;
      var $334=(($333+192)|0);
      var $335=HEAP32[(($334)>>2)];
      var $336=(($332)|0) < (($335)|0);
      if ($336) { __label__ = 54; break; } else { __label__ = 56; break; }
    case 54: 
      var $338=$1;
      var $339=$2;
      var $340=$i3;
      _png_free_data($338, $339, 512, $340);
      __label__ = 55; break;
    case 55: 
      var $342=$i3;
      var $343=((($342)+(1))|0);
      $i3=$343;
      __label__ = 53; break;
    case 56: 
      var $345=$1;
      var $346=$2;
      var $347=(($346+188)|0);
      var $348=HEAP32[(($347)>>2)];
      var $349=$348;
      _png_free($345, $349);
      var $350=$2;
      var $351=(($350+188)|0);
      HEAP32[(($351)>>2)]=0;
      var $352=$2;
      var $353=(($352+192)|0);
      HEAP32[(($353)>>2)]=0;
      __label__ = 57; break;
    case 57: 
      __label__ = 58; break;
    case 58: 
      __label__ = 59; break;
    case 59: 
      var $357=$3;
      var $358=$357 & 8;
      var $359=$2;
      var $360=(($359+184)|0);
      var $361=HEAP32[(($360)>>2)];
      var $362=$358 & $361;
      var $363=(($362)|0)!=0;
      if ($363) { __label__ = 60; break; } else { __label__ = 61; break; }
    case 60: 
      var $365=$1;
      var $366=$2;
      var $367=(($366+124)|0);
      var $368=HEAP32[(($367)>>2)];
      var $369=$368;
      _png_free($365, $369);
      var $370=$2;
      var $371=(($370+124)|0);
      HEAP32[(($371)>>2)]=0;
      var $372=$2;
      var $373=(($372+8)|0);
      var $374=HEAP32[(($373)>>2)];
      var $375=$374 & -65;
      HEAP32[(($373)>>2)]=$375;
      __label__ = 61; break;
    case 61: 
      var $377=$3;
      var $378=$377 & 4096;
      var $379=$2;
      var $380=(($379+184)|0);
      var $381=HEAP32[(($380)>>2)];
      var $382=$378 & $381;
      var $383=(($382)|0)!=0;
      if ($383) { __label__ = 62; break; } else { __label__ = 63; break; }
    case 62: 
      var $385=$1;
      var $386=$385;
      var $387=$2;
      var $388=(($387+16)|0);
      var $389=HEAP32[(($388)>>2)];
      var $390=$389;
      _png_zfree($386, $390);
      var $391=$2;
      var $392=(($391+16)|0);
      HEAP32[(($392)>>2)]=0;
      var $393=$2;
      var $394=(($393+8)|0);
      var $395=HEAP32[(($394)>>2)];
      var $396=$395 & -9;
      HEAP32[(($394)>>2)]=$396;
      var $397=$2;
      var $398=(($397+20)|0);
      HEAP16[(($398)>>1)]=0;
      __label__ = 63; break;
    case 63: 
      var $400=$3;
      var $401=$400 & 64;
      var $402=$2;
      var $403=(($402+184)|0);
      var $404=HEAP32[(($403)>>2)];
      var $405=$401 & $404;
      var $406=(($405)|0)!=0;
      if ($406) { __label__ = 64; break; } else { __label__ = 71; break; }
    case 64: 
      var $408=$2;
      var $409=(($408+248)|0);
      var $410=HEAP32[(($409)>>2)];
      var $411=(($410)|0)!=0;
      if ($411) { __label__ = 65; break; } else { __label__ = 70; break; }
    case 65: 
      $row=0;
      __label__ = 66; break;
    case 66: 
      var $414=$row;
      var $415=$2;
      var $416=(($415+4)|0);
      var $417=HEAP32[(($416)>>2)];
      var $418=(($414)|0) < (($417)|0);
      if ($418) { __label__ = 67; break; } else { __label__ = 69; break; }
    case 67: 
      var $420=$1;
      var $421=$row;
      var $422=$2;
      var $423=(($422+248)|0);
      var $424=HEAP32[(($423)>>2)];
      var $425=(($424+($421<<2))|0);
      var $426=HEAP32[(($425)>>2)];
      _png_free($420, $426);
      var $427=$row;
      var $428=$2;
      var $429=(($428+248)|0);
      var $430=HEAP32[(($429)>>2)];
      var $431=(($430+($427<<2))|0);
      HEAP32[(($431)>>2)]=0;
      __label__ = 68; break;
    case 68: 
      var $433=$row;
      var $434=((($433)+(1))|0);
      $row=$434;
      __label__ = 66; break;
    case 69: 
      var $436=$1;
      var $437=$2;
      var $438=(($437+248)|0);
      var $439=HEAP32[(($438)>>2)];
      var $440=$439;
      _png_free($436, $440);
      var $441=$2;
      var $442=(($441+248)|0);
      HEAP32[(($442)>>2)]=0;
      __label__ = 70; break;
    case 70: 
      var $444=$2;
      var $445=(($444+8)|0);
      var $446=HEAP32[(($445)>>2)];
      var $447=$446 & -32769;
      HEAP32[(($445)>>2)]=$447;
      __label__ = 71; break;
    case 71: 
      var $449=$4;
      var $450=(($449)|0)==-1;
      if ($450) { __label__ = 72; break; } else { __label__ = 73; break; }
    case 72: 
      var $452=$3;
      var $453=$452 ^ -1;
      var $454=$2;
      var $455=(($454+184)|0);
      var $456=HEAP32[(($455)>>2)];
      var $457=$456 & $453;
      HEAP32[(($455)>>2)]=$457;
      __label__ = 74; break;
    case 73: 
      var $459=$3;
      var $460=$459 & -16929;
      var $461=$460 ^ -1;
      var $462=$2;
      var $463=(($462+184)|0);
      var $464=HEAP32[(($463)>>2)];
      var $465=$464 & $461;
      HEAP32[(($463)>>2)]=$465;
      __label__ = 74; break;
    case 74: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_png_free_data["X"]=1;

function _png_handle_as_unknown($png_ptr, $chunk_name) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $i;
      var $p;
      $2=$png_ptr;
      $3=$chunk_name;
      var $4=$2;
      var $5=(($4)|0)==0;
      if ($5) { __label__ = 5; break; } else { __label__ = 3; break; }
    case 3: 
      var $7=$3;
      var $8=(($7)|0)==0;
      if ($8) { __label__ = 5; break; } else { __label__ = 4; break; }
    case 4: 
      var $10=$2;
      var $11=(($10+524)|0);
      var $12=HEAP32[(($11)>>2)];
      var $13=(($12)|0) <= 0;
      if ($13) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      $1=0;
      __label__ = 13; break;
    case 6: 
      var $16=$2;
      var $17=(($16+528)|0);
      var $18=HEAP32[(($17)>>2)];
      var $19=$2;
      var $20=(($19+524)|0);
      var $21=HEAP32[(($20)>>2)];
      var $22=((($21)*(5))|0);
      var $23=(($18+$22)|0);
      var $24=((($23)-(5))|0);
      $p=$24;
      var $25=$2;
      var $26=(($25+524)|0);
      var $27=HEAP32[(($26)>>2)];
      $i=$27;
      __label__ = 7; break;
    case 7: 
      var $29=$i;
      var $30=(($29)|0)!=0;
      if ($30) { __label__ = 8; break; } else { __label__ = 12; break; }
    case 8: 
      var $32=$3;
      var $33=$p;
      var $34=_memcmp($32, $33, 4);
      var $35=(($34)|0)!=0;
      if ($35) { __label__ = 10; break; } else { __label__ = 9; break; }
    case 9: 
      var $37=$p;
      var $38=(($37+4)|0);
      var $39=HEAPU8[($38)];
      var $40=(($39)&255);
      $1=$40;
      __label__ = 13; break;
    case 10: 
      __label__ = 11; break;
    case 11: 
      var $43=$i;
      var $44=((($43)-(1))|0);
      $i=$44;
      var $45=$p;
      var $46=((($45)-(5))|0);
      $p=$46;
      __label__ = 7; break;
    case 12: 
      $1=0;
      __label__ = 13; break;
    case 13: 
      var $49=$1;
      ;
      return $49;
    default: assert(0, "bad label: " + __label__);
  }
}
_png_handle_as_unknown["X"]=1;

function _png_format_buffer($png_ptr, $buffer, $error_message) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $iout;
      var $iin;
      var $c;
      $1=$png_ptr;
      $2=$buffer;
      $3=$error_message;
      $iout=0;
      $iin=0;
      __label__ = 3; break;
    case 3: 
      var $5=$iin;
      var $6=(($5)|0) < 4;
      if ($6) { __label__ = 4; break; } else { __label__ = 11; break; }
    case 4: 
      var $8=$iin;
      var $9=((($8)+(1))|0);
      $iin=$9;
      var $10=$1;
      var $11=(($10+264)|0);
      var $12=(($11+$8)|0);
      var $13=HEAPU8[($12)];
      var $14=(($13)&255);
      $c=$14;
      var $15=$c;
      var $16=(($15)|0) < 65;
      if ($16) { __label__ = 8; break; } else { __label__ = 5; break; }
    case 5: 
      var $18=$c;
      var $19=(($18)|0) > 122;
      if ($19) { __label__ = 8; break; } else { __label__ = 6; break; }
    case 6: 
      var $21=$c;
      var $22=(($21)|0) > 90;
      if ($22) { __label__ = 7; break; } else { __label__ = 9; break; }
    case 7: 
      var $24=$c;
      var $25=(($24)|0) < 97;
      if ($25) { __label__ = 8; break; } else { __label__ = 9; break; }
    case 8: 
      var $27=$iout;
      var $28=((($27)+(1))|0);
      $iout=$28;
      var $29=$2;
      var $30=(($29+$27)|0);
      HEAP8[($30)]=91;
      var $31=$c;
      var $32=$31 & 240;
      var $33=$32 >> 4;
      var $34=((STRING_TABLE._png_digit+$33)|0);
      var $35=HEAP8[($34)];
      var $36=$iout;
      var $37=((($36)+(1))|0);
      $iout=$37;
      var $38=$2;
      var $39=(($38+$36)|0);
      HEAP8[($39)]=$35;
      var $40=$c;
      var $41=$40 & 15;
      var $42=((STRING_TABLE._png_digit+$41)|0);
      var $43=HEAP8[($42)];
      var $44=$iout;
      var $45=((($44)+(1))|0);
      $iout=$45;
      var $46=$2;
      var $47=(($46+$44)|0);
      HEAP8[($47)]=$43;
      var $48=$iout;
      var $49=((($48)+(1))|0);
      $iout=$49;
      var $50=$2;
      var $51=(($50+$48)|0);
      HEAP8[($51)]=93;
      __label__ = 10; break;
    case 9: 
      var $53=$c;
      var $54=(($53) & 255);
      var $55=$iout;
      var $56=((($55)+(1))|0);
      $iout=$56;
      var $57=$2;
      var $58=(($57+$55)|0);
      HEAP8[($58)]=$54;
      __label__ = 10; break;
    case 10: 
      __label__ = 3; break;
    case 11: 
      var $61=$3;
      var $62=(($61)|0)==0;
      if ($62) { __label__ = 12; break; } else { __label__ = 13; break; }
    case 12: 
      var $64=$iout;
      var $65=$2;
      var $66=(($65+$64)|0);
      HEAP8[($66)]=0;
      __label__ = 19; break;
    case 13: 
      var $68=$iout;
      var $69=((($68)+(1))|0);
      $iout=$69;
      var $70=$2;
      var $71=(($70+$68)|0);
      HEAP8[($71)]=58;
      var $72=$iout;
      var $73=((($72)+(1))|0);
      $iout=$73;
      var $74=$2;
      var $75=(($74+$72)|0);
      HEAP8[($75)]=32;
      $iin=0;
      __label__ = 14; break;
    case 14: 
      var $77=$iin;
      var $78=(($77)|0) < 63;
      if ($78) { __label__ = 15; break; } else { var $87 = 0;__label__ = 16; break; }
    case 15: 
      var $80=$iin;
      var $81=$3;
      var $82=(($81+$80)|0);
      var $83=HEAP8[($82)];
      var $84=(($83 << 24) >> 24);
      var $85=(($84)|0)!=0;
      var $87 = $85;__label__ = 16; break;
    case 16: 
      var $87;
      if ($87) { __label__ = 17; break; } else { __label__ = 18; break; }
    case 17: 
      var $89=$iin;
      var $90=((($89)+(1))|0);
      $iin=$90;
      var $91=$3;
      var $92=(($91+$89)|0);
      var $93=HEAP8[($92)];
      var $94=$iout;
      var $95=((($94)+(1))|0);
      $iout=$95;
      var $96=$2;
      var $97=(($96+$94)|0);
      HEAP8[($97)]=$93;
      __label__ = 14; break;
    case 18: 
      var $99=$iout;
      var $100=$2;
      var $101=(($100+$99)|0);
      HEAP8[($101)]=0;
      __label__ = 19; break;
    case 19: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_png_format_buffer["X"]=1;

function _png_set_longjmp_fn($png_ptr, $longjmp_fn, $jmp_buf_size) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      $2=$png_ptr;
      $3=$longjmp_fn;
      $4=$jmp_buf_size;
      var $5=$2;
      var $6=(($5)|0)==0;
      if ($6) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      var $8=$4;
      var $9=(($8)|0)!=40;
      if ($9) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      $1=0;
      __label__ = 6; break;
    case 5: 
      var $12=$3;
      var $13=$2;
      var $14=(($13+40)|0);
      HEAP32[(($14)>>2)]=$12;
      var $15=$2;
      var $16=(($15)|0);
      $1=$16;
      __label__ = 6; break;
    case 6: 
      var $18=$1;
      ;
      return $18;
    default: assert(0, "bad label: " + __label__);
  }
}


function _png_check_cHRM_fixed($png_ptr, $white_x, $white_y, $red_x, $red_y, $green_x, $green_y, $blue_x, $blue_y) {
  var __stackBase__  = STACKTOP; STACKTOP += 16; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $5;
      var $6;
      var $7;
      var $8;
      var $9;
      var $10;
      var $ret;
      var $xy_hi=__stackBase__;
      var $xy_lo=(__stackBase__)+(4);
      var $yx_hi=(__stackBase__)+(8);
      var $yx_lo=(__stackBase__)+(12);
      $2=$png_ptr;
      $3=$white_x;
      $4=$white_y;
      $5=$red_x;
      $6=$red_y;
      $7=$green_x;
      $8=$green_y;
      $9=$blue_x;
      $10=$blue_y;
      $ret=1;
      var $11=$2;
      var $12=(($11)|0)==0;
      if ($12) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      $1=0;
      __label__ = 34; break;
    case 4: 
      var $15=$3;
      var $16=(($15)|0) < 0;
      if ($16) { __label__ = 12; break; } else { __label__ = 5; break; }
    case 5: 
      var $18=$4;
      var $19=(($18)|0) <= 0;
      if ($19) { __label__ = 12; break; } else { __label__ = 6; break; }
    case 6: 
      var $21=$5;
      var $22=(($21)|0) < 0;
      if ($22) { __label__ = 12; break; } else { __label__ = 7; break; }
    case 7: 
      var $24=$6;
      var $25=(($24)|0) < 0;
      if ($25) { __label__ = 12; break; } else { __label__ = 8; break; }
    case 8: 
      var $27=$7;
      var $28=(($27)|0) < 0;
      if ($28) { __label__ = 12; break; } else { __label__ = 9; break; }
    case 9: 
      var $30=$8;
      var $31=(($30)|0) < 0;
      if ($31) { __label__ = 12; break; } else { __label__ = 10; break; }
    case 10: 
      var $33=$9;
      var $34=(($33)|0) < 0;
      if ($34) { __label__ = 12; break; } else { __label__ = 11; break; }
    case 11: 
      var $36=$10;
      var $37=(($36)|0) < 0;
      if ($37) { __label__ = 12; break; } else { __label__ = 13; break; }
    case 12: 
      var $39=$2;
      _png_warning($39, ((STRING_TABLE.__str798)|0));
      $ret=0;
      __label__ = 13; break;
    case 13: 
      var $41=$3;
      var $42=(($41)|0) > 2147483647;
      if ($42) { __label__ = 21; break; } else { __label__ = 14; break; }
    case 14: 
      var $44=$4;
      var $45=(($44)|0) > 2147483647;
      if ($45) { __label__ = 21; break; } else { __label__ = 15; break; }
    case 15: 
      var $47=$5;
      var $48=(($47)|0) > 2147483647;
      if ($48) { __label__ = 21; break; } else { __label__ = 16; break; }
    case 16: 
      var $50=$6;
      var $51=(($50)|0) > 2147483647;
      if ($51) { __label__ = 21; break; } else { __label__ = 17; break; }
    case 17: 
      var $53=$7;
      var $54=(($53)|0) > 2147483647;
      if ($54) { __label__ = 21; break; } else { __label__ = 18; break; }
    case 18: 
      var $56=$8;
      var $57=(($56)|0) > 2147483647;
      if ($57) { __label__ = 21; break; } else { __label__ = 19; break; }
    case 19: 
      var $59=$9;
      var $60=(($59)|0) > 2147483647;
      if ($60) { __label__ = 21; break; } else { __label__ = 20; break; }
    case 20: 
      var $62=$10;
      var $63=(($62)|0) > 2147483647;
      if ($63) { __label__ = 21; break; } else { __label__ = 22; break; }
    case 21: 
      var $65=$2;
      _png_warning($65, ((STRING_TABLE.__str899)|0));
      $ret=0;
      __label__ = 22; break;
    case 22: 
      var $67=$3;
      var $68=$4;
      var $69=(((100000)-($68))|0);
      var $70=(($67)|0) > (($69)|0);
      if ($70) { __label__ = 23; break; } else { __label__ = 24; break; }
    case 23: 
      var $72=$2;
      _png_warning($72, ((STRING_TABLE.__str9100)|0));
      $ret=0;
      __label__ = 24; break;
    case 24: 
      var $74=$5;
      var $75=$6;
      var $76=(((100000)-($75))|0);
      var $77=(($74)|0) > (($76)|0);
      if ($77) { __label__ = 25; break; } else { __label__ = 26; break; }
    case 25: 
      var $79=$2;
      _png_warning($79, ((STRING_TABLE.__str10101)|0));
      $ret=0;
      __label__ = 26; break;
    case 26: 
      var $81=$7;
      var $82=$8;
      var $83=(((100000)-($82))|0);
      var $84=(($81)|0) > (($83)|0);
      if ($84) { __label__ = 27; break; } else { __label__ = 28; break; }
    case 27: 
      var $86=$2;
      _png_warning($86, ((STRING_TABLE.__str11102)|0));
      $ret=0;
      __label__ = 28; break;
    case 28: 
      var $88=$9;
      var $89=$10;
      var $90=(((100000)-($89))|0);
      var $91=(($88)|0) > (($90)|0);
      if ($91) { __label__ = 29; break; } else { __label__ = 30; break; }
    case 29: 
      var $93=$2;
      _png_warning($93, ((STRING_TABLE.__str12103)|0));
      $ret=0;
      __label__ = 30; break;
    case 30: 
      var $95=$7;
      var $96=$5;
      var $97=((($95)-($96))|0);
      var $98=$10;
      var $99=$6;
      var $100=((($98)-($99))|0);
      _png_64bit_product($97, $100, $xy_hi, $xy_lo);
      var $101=$8;
      var $102=$6;
      var $103=((($101)-($102))|0);
      var $104=$9;
      var $105=$5;
      var $106=((($104)-($105))|0);
      _png_64bit_product($103, $106, $yx_hi, $yx_lo);
      var $107=HEAP32[(($xy_hi)>>2)];
      var $108=HEAP32[(($yx_hi)>>2)];
      var $109=(($107)|0)==(($108)|0);
      if ($109) { __label__ = 31; break; } else { __label__ = 33; break; }
    case 31: 
      var $111=HEAP32[(($xy_lo)>>2)];
      var $112=HEAP32[(($yx_lo)>>2)];
      var $113=(($111)|0)==(($112)|0);
      if ($113) { __label__ = 32; break; } else { __label__ = 33; break; }
    case 32: 
      var $115=$2;
      _png_warning($115, ((STRING_TABLE.__str13104)|0));
      $ret=0;
      __label__ = 33; break;
    case 33: 
      var $117=$ret;
      $1=$117;
      __label__ = 34; break;
    case 34: 
      var $119=$1;
      STACKTOP = __stackBase__;
      return $119;
    default: assert(0, "bad label: " + __label__);
  }
}
_png_check_cHRM_fixed["X"]=1;

function _png_check_IHDR($png_ptr, $width, $height, $bit_depth, $color_type, $interlace_type, $compression_type, $filter_type) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $5;
      var $6;
      var $7;
      var $8;
      var $error;
      $1=$png_ptr;
      $2=$width;
      $3=$height;
      $4=$bit_depth;
      $5=$color_type;
      $6=$interlace_type;
      $7=$compression_type;
      $8=$filter_type;
      $error=0;
      var $9=$2;
      var $10=(($9)|0)==0;
      if ($10) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $12=$1;
      _png_warning($12, ((STRING_TABLE.__str14105)|0));
      $error=1;
      __label__ = 4; break;
    case 4: 
      var $14=$3;
      var $15=(($14)|0)==0;
      if ($15) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $17=$1;
      _png_warning($17, ((STRING_TABLE.__str15106)|0));
      $error=1;
      __label__ = 6; break;
    case 6: 
      var $19=$2;
      var $20=$1;
      var $21=(($20+584)|0);
      var $22=HEAPU32[(($21)>>2)];
      var $23=(($19)>>>0) > (($22)>>>0);
      if ($23) { __label__ = 8; break; } else { __label__ = 7; break; }
    case 7: 
      var $25=$2;
      var $26=(($25)>>>0) > 1000000;
      if ($26) { __label__ = 8; break; } else { __label__ = 9; break; }
    case 8: 
      var $28=$1;
      _png_warning($28, ((STRING_TABLE.__str16107)|0));
      $error=1;
      __label__ = 9; break;
    case 9: 
      var $30=$3;
      var $31=$1;
      var $32=(($31+588)|0);
      var $33=HEAPU32[(($32)>>2)];
      var $34=(($30)>>>0) > (($33)>>>0);
      if ($34) { __label__ = 11; break; } else { __label__ = 10; break; }
    case 10: 
      var $36=$3;
      var $37=(($36)>>>0) > 1000000;
      if ($37) { __label__ = 11; break; } else { __label__ = 12; break; }
    case 11: 
      var $39=$1;
      _png_warning($39, ((STRING_TABLE.__str17108)|0));
      $error=1;
      __label__ = 12; break;
    case 12: 
      var $41=$2;
      var $42=(($41)>>>0) > 2147483647;
      if ($42) { __label__ = 13; break; } else { __label__ = 14; break; }
    case 13: 
      var $44=$1;
      _png_warning($44, ((STRING_TABLE.__str18109)|0));
      $error=1;
      __label__ = 14; break;
    case 14: 
      var $46=$3;
      var $47=(($46)>>>0) > 2147483647;
      if ($47) { __label__ = 15; break; } else { __label__ = 16; break; }
    case 15: 
      var $49=$1;
      _png_warning($49, ((STRING_TABLE.__str19110)|0));
      $error=1;
      __label__ = 16; break;
    case 16: 
      var $51=$2;
      var $52=(($51)>>>0) > 536870782;
      if ($52) { __label__ = 17; break; } else { __label__ = 18; break; }
    case 17: 
      var $54=$1;
      _png_warning($54, ((STRING_TABLE.__str20111)|0));
      __label__ = 18; break;
    case 18: 
      var $56=$4;
      var $57=(($56)|0)!=1;
      if ($57) { __label__ = 19; break; } else { __label__ = 24; break; }
    case 19: 
      var $59=$4;
      var $60=(($59)|0)!=2;
      if ($60) { __label__ = 20; break; } else { __label__ = 24; break; }
    case 20: 
      var $62=$4;
      var $63=(($62)|0)!=4;
      if ($63) { __label__ = 21; break; } else { __label__ = 24; break; }
    case 21: 
      var $65=$4;
      var $66=(($65)|0)!=8;
      if ($66) { __label__ = 22; break; } else { __label__ = 24; break; }
    case 22: 
      var $68=$4;
      var $69=(($68)|0)!=16;
      if ($69) { __label__ = 23; break; } else { __label__ = 24; break; }
    case 23: 
      var $71=$1;
      _png_warning($71, ((STRING_TABLE.__str21)|0));
      $error=1;
      __label__ = 24; break;
    case 24: 
      var $73=$5;
      var $74=(($73)|0) < 0;
      if ($74) { __label__ = 28; break; } else { __label__ = 25; break; }
    case 25: 
      var $76=$5;
      var $77=(($76)|0)==1;
      if ($77) { __label__ = 28; break; } else { __label__ = 26; break; }
    case 26: 
      var $79=$5;
      var $80=(($79)|0)==5;
      if ($80) { __label__ = 28; break; } else { __label__ = 27; break; }
    case 27: 
      var $82=$5;
      var $83=(($82)|0) > 6;
      if ($83) { __label__ = 28; break; } else { __label__ = 29; break; }
    case 28: 
      var $85=$1;
      _png_warning($85, ((STRING_TABLE.__str22)|0));
      $error=1;
      __label__ = 29; break;
    case 29: 
      var $87=$5;
      var $88=(($87)|0)==3;
      if ($88) { __label__ = 30; break; } else { __label__ = 31; break; }
    case 30: 
      var $90=$4;
      var $91=(($90)|0) > 8;
      if ($91) { __label__ = 35; break; } else { __label__ = 31; break; }
    case 31: 
      var $93=$5;
      var $94=(($93)|0)==2;
      if ($94) { __label__ = 34; break; } else { __label__ = 32; break; }
    case 32: 
      var $96=$5;
      var $97=(($96)|0)==4;
      if ($97) { __label__ = 34; break; } else { __label__ = 33; break; }
    case 33: 
      var $99=$5;
      var $100=(($99)|0)==6;
      if ($100) { __label__ = 34; break; } else { __label__ = 36; break; }
    case 34: 
      var $102=$4;
      var $103=(($102)|0) < 8;
      if ($103) { __label__ = 35; break; } else { __label__ = 36; break; }
    case 35: 
      var $105=$1;
      _png_warning($105, ((STRING_TABLE.__str23)|0));
      $error=1;
      __label__ = 36; break;
    case 36: 
      var $107=$6;
      var $108=(($107)|0) >= 2;
      if ($108) { __label__ = 37; break; } else { __label__ = 38; break; }
    case 37: 
      var $110=$1;
      _png_warning($110, ((STRING_TABLE.__str24)|0));
      $error=1;
      __label__ = 38; break;
    case 38: 
      var $112=$7;
      var $113=(($112)|0)!=0;
      if ($113) { __label__ = 39; break; } else { __label__ = 40; break; }
    case 39: 
      var $115=$1;
      _png_warning($115, ((STRING_TABLE.__str25)|0));
      $error=1;
      __label__ = 40; break;
    case 40: 
      var $117=$1;
      var $118=(($117+84)|0);
      var $119=HEAP32[(($118)>>2)];
      var $120=$119 & 4096;
      var $121=(($120)|0)!=0;
      if ($121) { __label__ = 41; break; } else { __label__ = 43; break; }
    case 41: 
      var $123=$1;
      var $124=(($123+540)|0);
      var $125=HEAP32[(($124)>>2)];
      var $126=(($125)|0)!=0;
      if ($126) { __label__ = 42; break; } else { __label__ = 43; break; }
    case 42: 
      var $128=$1;
      _png_warning($128, ((STRING_TABLE.__str26)|0));
      __label__ = 43; break;
    case 43: 
      var $130=$8;
      var $131=(($130)|0)!=0;
      if ($131) { __label__ = 44; break; } else { __label__ = 53; break; }
    case 44: 
      var $133=$1;
      var $134=(($133+540)|0);
      var $135=HEAP32[(($134)>>2)];
      var $136=$135 & 4;
      var $137=(($136)|0)!=0;
      if ($137) { __label__ = 45; break; } else { __label__ = 49; break; }
    case 45: 
      var $139=$8;
      var $140=(($139)|0)==64;
      if ($140) { __label__ = 46; break; } else { __label__ = 49; break; }
    case 46: 
      var $142=$1;
      var $143=(($142+84)|0);
      var $144=HEAP32[(($143)>>2)];
      var $145=$144 & 4096;
      var $146=(($145)|0)==0;
      if ($146) { __label__ = 47; break; } else { __label__ = 49; break; }
    case 47: 
      var $148=$5;
      var $149=(($148)|0)==2;
      if ($149) { __label__ = 50; break; } else { __label__ = 48; break; }
    case 48: 
      var $151=$5;
      var $152=(($151)|0)==6;
      if ($152) { __label__ = 50; break; } else { __label__ = 49; break; }
    case 49: 
      var $154=$1;
      _png_warning($154, ((STRING_TABLE.__str27)|0));
      $error=1;
      __label__ = 50; break;
    case 50: 
      var $156=$1;
      var $157=(($156+84)|0);
      var $158=HEAP32[(($157)>>2)];
      var $159=$158 & 4096;
      var $160=(($159)|0)!=0;
      if ($160) { __label__ = 51; break; } else { __label__ = 52; break; }
    case 51: 
      var $162=$1;
      _png_warning($162, ((STRING_TABLE.__str28)|0));
      $error=1;
      __label__ = 52; break;
    case 52: 
      __label__ = 53; break;
    case 53: 
      var $165=$error;
      var $166=(($165)|0)==1;
      if ($166) { __label__ = 54; break; } else { __label__ = 55; break; }
    case 54: 
      var $168=$1;
      _png_error($168, ((STRING_TABLE.__str29112)|0));
      __label__ = 55; break;
    case 55: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_png_check_IHDR["X"]=1;

function _png_error($png_ptr, $error_message) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      $1=$png_ptr;
      $2=$error_message;
      var $3=$1;
      var $4=(($3)|0)!=0;
      if ($4) { __label__ = 3; break; } else { __label__ = 5; break; }
    case 3: 
      var $6=$1;
      var $7=(($6+44)|0);
      var $8=$7;
      var $9=HEAP32[(($8)>>2)];
      var $10=(($9)|0)!=0;
      if ($10) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      var $12=$1;
      var $13=(($12+44)|0);
      var $14=$13;
      var $15=HEAP32[(($14)>>2)];
      var $16=$1;
      var $17=$2;
      FUNCTION_TABLE[$15]($16, $17);
      __label__ = 5; break;
    case 5: 
      var $19=$1;
      var $20=$2;
      _png_default_error($19, $20);
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}


function _png_warning($png_ptr, $warning_message) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $offset;
      $1=$png_ptr;
      $2=$warning_message;
      $offset=0;
      var $3=$1;
      var $4=(($3)|0)!=0;
      if ($4) { __label__ = 3; break; } else { __label__ = 12; break; }
    case 3: 
      var $6=$2;
      var $7=HEAP8[($6)];
      var $8=(($7 << 24) >> 24);
      var $9=(($8)|0)==35;
      if ($9) { __label__ = 4; break; } else { __label__ = 11; break; }
    case 4: 
      $offset=1;
      __label__ = 5; break;
    case 5: 
      var $12=$offset;
      var $13=(($12)|0) < 15;
      if ($13) { __label__ = 6; break; } else { __label__ = 10; break; }
    case 6: 
      var $15=$offset;
      var $16=$2;
      var $17=(($16+$15)|0);
      var $18=HEAP8[($17)];
      var $19=(($18 << 24) >> 24);
      var $20=(($19)|0)==32;
      if ($20) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      __label__ = 10; break;
    case 8: 
      __label__ = 9; break;
    case 9: 
      var $24=$offset;
      var $25=((($24)+(1))|0);
      $offset=$25;
      __label__ = 5; break;
    case 10: 
      __label__ = 11; break;
    case 11: 
      __label__ = 12; break;
    case 12: 
      var $29=$1;
      var $30=(($29)|0)!=0;
      if ($30) { __label__ = 13; break; } else { __label__ = 15; break; }
    case 13: 
      var $32=$1;
      var $33=(($32+48)|0);
      var $34=$33;
      var $35=HEAP32[(($34)>>2)];
      var $36=(($35)|0)!=0;
      if ($36) { __label__ = 14; break; } else { __label__ = 15; break; }
    case 14: 
      var $38=$1;
      var $39=(($38+48)|0);
      var $40=$39;
      var $41=HEAP32[(($40)>>2)];
      var $42=$1;
      var $43=$2;
      var $44=$offset;
      var $45=(($43+$44)|0);
      FUNCTION_TABLE[$41]($42, $45);
      __label__ = 16; break;
    case 15: 
      var $47=$1;
      var $48=$2;
      var $49=$offset;
      var $50=(($48+$49)|0);
      _png_default_warning($47, $50);
      __label__ = 16; break;
    case 16: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_png_warning["X"]=1;

function _png_default_warning($png_ptr, $warning_message) {
  var __stackBase__  = STACKTOP; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;

  var $1;
  var $2;
  $1=$png_ptr;
  $2=$warning_message;
  var $3=HEAP32[((_stderr)>>2)];
  var $4=$2;
  var $5=_fprintf($3, ((STRING_TABLE.__str113)|0), (tempInt=STACKTOP,STACKTOP += 4,assert(STACKTOP < STACK_ROOT + STACK_MAX, "Ran out of stack"),HEAP32[((tempInt)>>2)]=$4,tempInt));
  var $6=HEAP32[((_stderr)>>2)];
  var $7=_fprintf($6, ((STRING_TABLE.__str1114)|0), (tempInt=STACKTOP,STACKTOP += 1,STACKTOP = ((((STACKTOP)+3)>>2)<<2),assert(STACKTOP < STACK_ROOT + STACK_MAX, "Ran out of stack"),HEAP32[((tempInt)>>2)]=0,tempInt));
  var $8=$1;
  STACKTOP = __stackBase__;
  return;
}


function _png_chunk_error($png_ptr, $error_message) {
  var __stackBase__  = STACKTOP; STACKTOP += 84; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $msg=__stackBase__;
      $1=$png_ptr;
      $2=$error_message;
      var $3=$1;
      var $4=(($3)|0)==0;
      if ($4) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $6=$1;
      var $7=$2;
      _png_error($6, $7);
      __label__ = 5; break;
    case 4: 
      var $9=$1;
      var $10=(($msg)|0);
      var $11=$2;
      _png_format_buffer($9, $10, $11);
      var $12=$1;
      var $13=(($msg)|0);
      _png_error($12, $13);
      __label__ = 5; break;
    case 5: 
      STACKTOP = __stackBase__;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}


function _png_chunk_warning($png_ptr, $warning_message) {
  var __stackBase__  = STACKTOP; STACKTOP += 84; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $msg=__stackBase__;
      $1=$png_ptr;
      $2=$warning_message;
      var $3=$1;
      var $4=(($3)|0)==0;
      if ($4) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $6=$1;
      var $7=$2;
      _png_warning($6, $7);
      __label__ = 5; break;
    case 4: 
      var $9=$1;
      var $10=(($msg)|0);
      var $11=$2;
      _png_format_buffer($9, $10, $11);
      var $12=$1;
      var $13=(($msg)|0);
      _png_warning($12, $13);
      __label__ = 5; break;
    case 5: 
      STACKTOP = __stackBase__;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}


function _png_default_error($png_ptr, $error_message) {
  var __stackBase__  = STACKTOP; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      $1=$png_ptr;
      $2=$error_message;
      var $3=HEAP32[((_stderr)>>2)];
      var $4=$2;
      var $5=_fprintf($3, ((STRING_TABLE.__str2115)|0), (tempInt=STACKTOP,STACKTOP += 4,assert(STACKTOP < STACK_ROOT + STACK_MAX, "Ran out of stack"),HEAP32[((tempInt)>>2)]=$4,tempInt));
      var $6=HEAP32[((_stderr)>>2)];
      var $7=_fprintf($6, ((STRING_TABLE.__str1114)|0), (tempInt=STACKTOP,STACKTOP += 1,STACKTOP = ((((STACKTOP)+3)>>2)<<2),assert(STACKTOP < STACK_ROOT + STACK_MAX, "Ran out of stack"),HEAP32[((tempInt)>>2)]=0,tempInt));
      var $8=$1;
      var $9=(($8)|0)!=0;
      if ($9) { __label__ = 3; break; } else { __label__ = 5; break; }
    case 3: 
      var $11=$1;
      var $12=(($11+40)|0);
      var $13=HEAP32[(($12)>>2)];
      var $14=(($13)|0)!=0;
      if ($14) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      var $16=$1;
      var $17=(($16+40)|0);
      var $18=HEAP32[(($17)>>2)];
      var $19=$1;
      var $20=(($19)|0);
      var $21=(($20)|0);
      FUNCTION_TABLE[$18]($21, 1);
      __label__ = 5; break;
    case 5: 
      _abort();
      throw "Reached an unreachable!"
      STACKTOP = __stackBase__;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}


function _png_set_error_fn($png_ptr, $error_ptr, $error_fn, $warning_fn) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      $1=$png_ptr;
      $2=$error_ptr;
      $3=$error_fn;
      $4=$warning_fn;
      var $5=$1;
      var $6=(($5)|0)==0;
      if ($6) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      __label__ = 5; break;
    case 4: 
      var $9=$2;
      var $10=$1;
      var $11=(($10+52)|0);
      HEAP32[(($11)>>2)]=$9;
      var $12=$3;
      var $13=$1;
      var $14=(($13+44)|0);
      var $15=$14;
      HEAP32[(($15)>>2)]=$12;
      var $16=$4;
      var $17=$1;
      var $18=(($17+48)|0);
      var $19=$18;
      HEAP32[(($19)>>2)]=$16;
      __label__ = 5; break;
    case 5: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}


function _png_get_error_ptr($png_ptr) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      $2=$png_ptr;
      var $3=$2;
      var $4=(($3)|0)==0;
      if ($4) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      $1=0;
      __label__ = 5; break;
    case 4: 
      var $7=$2;
      var $8=(($7+52)|0);
      var $9=HEAP32[(($8)>>2)];
      $1=$9;
      __label__ = 5; break;
    case 5: 
      var $11=$1;
      ;
      return $11;
    default: assert(0, "bad label: " + __label__);
  }
}


function _png_get_valid($png_ptr, $info_ptr, $flag) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      $2=$png_ptr;
      $3=$info_ptr;
      $4=$flag;
      var $5=$2;
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 3; break; } else { __label__ = 5; break; }
    case 3: 
      var $8=$3;
      var $9=(($8)|0)!=0;
      if ($9) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      var $11=$3;
      var $12=(($11+8)|0);
      var $13=HEAP32[(($12)>>2)];
      var $14=$4;
      var $15=$13 & $14;
      $1=$15;
      __label__ = 6; break;
    case 5: 
      $1=0;
      __label__ = 6; break;
    case 6: 
      var $18=$1;
      ;
      return $18;
    default: assert(0, "bad label: " + __label__);
  }
}


function _png_get_rowbytes($png_ptr, $info_ptr) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      $2=$png_ptr;
      $3=$info_ptr;
      var $4=$2;
      var $5=(($4)|0)!=0;
      if ($5) { __label__ = 3; break; } else { __label__ = 5; break; }
    case 3: 
      var $7=$3;
      var $8=(($7)|0)!=0;
      if ($8) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      var $10=$3;
      var $11=(($10+12)|0);
      var $12=HEAP32[(($11)>>2)];
      $1=$12;
      __label__ = 6; break;
    case 5: 
      $1=0;
      __label__ = 6; break;
    case 6: 
      var $15=$1;
      ;
      return $15;
    default: assert(0, "bad label: " + __label__);
  }
}


function _png_get_color_type($png_ptr, $info_ptr) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      $2=$png_ptr;
      $3=$info_ptr;
      var $4=$2;
      var $5=(($4)|0)!=0;
      if ($5) { __label__ = 3; break; } else { __label__ = 5; break; }
    case 3: 
      var $7=$3;
      var $8=(($7)|0)!=0;
      if ($8) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      var $10=$3;
      var $11=(($10+25)|0);
      var $12=HEAP8[($11)];
      $1=$12;
      __label__ = 6; break;
    case 5: 
      $1=0;
      __label__ = 6; break;
    case 6: 
      var $15=$1;
      ;
      return $15;
    default: assert(0, "bad label: " + __label__);
  }
}


function _png_get_interlace_type($png_ptr, $info_ptr) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      $2=$png_ptr;
      $3=$info_ptr;
      var $4=$2;
      var $5=(($4)|0)!=0;
      if ($5) { __label__ = 3; break; } else { __label__ = 5; break; }
    case 3: 
      var $7=$3;
      var $8=(($7)|0)!=0;
      if ($8) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      var $10=$3;
      var $11=(($10+28)|0);
      var $12=HEAP8[($11)];
      $1=$12;
      __label__ = 6; break;
    case 5: 
      $1=0;
      __label__ = 6; break;
    case 6: 
      var $15=$1;
      ;
      return $15;
    default: assert(0, "bad label: " + __label__);
  }
}


function _png_get_PLTE($png_ptr, $info_ptr, $palette, $num_palette) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $5;
      $2=$png_ptr;
      $3=$info_ptr;
      $4=$palette;
      $5=$num_palette;
      var $6=$2;
      var $7=(($6)|0)!=0;
      if ($7) { __label__ = 3; break; } else { __label__ = 7; break; }
    case 3: 
      var $9=$3;
      var $10=(($9)|0)!=0;
      if ($10) { __label__ = 4; break; } else { __label__ = 7; break; }
    case 4: 
      var $12=$3;
      var $13=(($12+8)|0);
      var $14=HEAP32[(($13)>>2)];
      var $15=$14 & 8;
      var $16=(($15)|0)!=0;
      if ($16) { __label__ = 5; break; } else { __label__ = 7; break; }
    case 5: 
      var $18=$4;
      var $19=(($18)|0)!=0;
      if ($19) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      var $21=$3;
      var $22=(($21+16)|0);
      var $23=HEAP32[(($22)>>2)];
      var $24=$4;
      HEAP32[(($24)>>2)]=$23;
      var $25=$3;
      var $26=(($25+20)|0);
      var $27=HEAPU16[(($26)>>1)];
      var $28=(($27)&65535);
      var $29=$5;
      HEAP32[(($29)>>2)]=$28;
      $1=8;
      __label__ = 8; break;
    case 7: 
      $1=0;
      __label__ = 8; break;
    case 8: 
      var $32=$1;
      ;
      return $32;
    default: assert(0, "bad label: " + __label__);
  }
}


function _png_get_tRNS($png_ptr, $info_ptr, $trans_alpha, $num_trans, $trans_color) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $5;
      var $retval;
      $1=$png_ptr;
      $2=$info_ptr;
      $3=$trans_alpha;
      $4=$num_trans;
      $5=$trans_color;
      $retval=0;
      var $6=$1;
      var $7=(($6)|0)!=0;
      if ($7) { __label__ = 3; break; } else { __label__ = 19; break; }
    case 3: 
      var $9=$2;
      var $10=(($9)|0)!=0;
      if ($10) { __label__ = 4; break; } else { __label__ = 19; break; }
    case 4: 
      var $12=$2;
      var $13=(($12+8)|0);
      var $14=HEAP32[(($13)>>2)];
      var $15=$14 & 16;
      var $16=(($15)|0)!=0;
      if ($16) { __label__ = 5; break; } else { __label__ = 19; break; }
    case 5: 
      var $18=$2;
      var $19=(($18+25)|0);
      var $20=HEAPU8[($19)];
      var $21=(($20)&255);
      var $22=(($21)|0)==3;
      if ($22) { __label__ = 6; break; } else { __label__ = 11; break; }
    case 6: 
      var $24=$3;
      var $25=(($24)|0)!=0;
      if ($25) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $27=$2;
      var $28=(($27+76)|0);
      var $29=HEAP32[(($28)>>2)];
      var $30=$3;
      HEAP32[(($30)>>2)]=$29;
      var $31=$retval;
      var $32=$31 | 16;
      $retval=$32;
      __label__ = 8; break;
    case 8: 
      var $34=$5;
      var $35=(($34)|0)!=0;
      if ($35) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      var $37=$2;
      var $38=(($37+80)|0);
      var $39=$5;
      HEAP32[(($39)>>2)]=$38;
      __label__ = 10; break;
    case 10: 
      __label__ = 16; break;
    case 11: 
      var $42=$5;
      var $43=(($42)|0)!=0;
      if ($43) { __label__ = 12; break; } else { __label__ = 13; break; }
    case 12: 
      var $45=$2;
      var $46=(($45+80)|0);
      var $47=$5;
      HEAP32[(($47)>>2)]=$46;
      var $48=$retval;
      var $49=$48 | 16;
      $retval=$49;
      __label__ = 13; break;
    case 13: 
      var $51=$3;
      var $52=(($51)|0)!=0;
      if ($52) { __label__ = 14; break; } else { __label__ = 15; break; }
    case 14: 
      var $54=$3;
      HEAP32[(($54)>>2)]=0;
      __label__ = 15; break;
    case 15: 
      __label__ = 16; break;
    case 16: 
      var $57=$4;
      var $58=(($57)|0)!=0;
      if ($58) { __label__ = 17; break; } else { __label__ = 18; break; }
    case 17: 
      var $60=$2;
      var $61=(($60+22)|0);
      var $62=HEAPU16[(($61)>>1)];
      var $63=(($62)&65535);
      var $64=$4;
      HEAP32[(($64)>>2)]=$63;
      var $65=$retval;
      var $66=$65 | 16;
      $retval=$66;
      __label__ = 18; break;
    case 18: 
      __label__ = 19; break;
    case 19: 
      var $69=$retval;
      ;
      return $69;
    default: assert(0, "bad label: " + __label__);
  }
}
_png_get_tRNS["X"]=1;

function _png_set_mem_fn($png_ptr, $mem_ptr, $malloc_fn, $free_fn) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      $1=$png_ptr;
      $2=$mem_ptr;
      $3=$malloc_fn;
      $4=$free_fn;
      var $5=$1;
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $8=$2;
      var $9=$1;
      var $10=(($9+552)|0);
      HEAP32[(($10)>>2)]=$8;
      var $11=$3;
      var $12=$1;
      var $13=(($12+556)|0);
      var $14=$13;
      HEAP32[(($14)>>2)]=$11;
      var $15=$4;
      var $16=$1;
      var $17=(($16+560)|0);
      HEAP32[(($17)>>2)]=$15;
      __label__ = 4; break;
    case 4: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}


function _png_create_struct($type) {
  ;
  var __label__;

  var $1;
  $1=$type;
  var $2=$1;
  var $3=_png_create_struct_2($2, 0, 0);
  ;
  return $3;
}


function _png_create_struct_2($type, $malloc_fn, $mem_ptr) {
  var __stackBase__  = STACKTOP; STACKTOP += 632; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $size;
      var $struct_ptr;
      var $dummy_struct=__stackBase__;
      var $png_ptr;
      $2=$type;
      $3=$malloc_fn;
      $4=$mem_ptr;
      var $5=$2;
      var $6=(($5)|0)==2;
      if ($6) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      $size=288;
      __label__ = 8; break;
    case 4: 
      var $9=$2;
      var $10=(($9)|0)==1;
      if ($10) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      $size=632;
      __label__ = 7; break;
    case 6: 
      $1=0;
      __label__ = 15; break;
    case 7: 
      __label__ = 8; break;
    case 8: 
      var $15=$3;
      var $16=(($15)|0)!=0;
      if ($16) { __label__ = 9; break; } else { __label__ = 12; break; }
    case 9: 
      $png_ptr=$dummy_struct;
      var $18=$4;
      var $19=$png_ptr;
      var $20=(($19+552)|0);
      HEAP32[(($20)>>2)]=$18;
      var $21=$3;
      var $22=$png_ptr;
      var $23=$size;
      var $24=FUNCTION_TABLE[$21]($22, $23);
      $struct_ptr=$24;
      var $25=$struct_ptr;
      var $26=(($25)|0)!=0;
      if ($26) { __label__ = 10; break; } else { __label__ = 11; break; }
    case 10: 
      var $28=$struct_ptr;
      var $29=$size;
      _memset($28, 0, $29, 1);
      __label__ = 11; break;
    case 11: 
      var $31=$struct_ptr;
      $1=$31;
      __label__ = 15; break;
    case 12: 
      var $33=$size;
      var $34=_malloc($33);
      $struct_ptr=$34;
      var $35=$struct_ptr;
      var $36=(($35)|0)!=0;
      if ($36) { __label__ = 13; break; } else { __label__ = 14; break; }
    case 13: 
      var $38=$struct_ptr;
      var $39=$size;
      _memset($38, 0, $39, 1);
      __label__ = 14; break;
    case 14: 
      var $41=$struct_ptr;
      $1=$41;
      __label__ = 15; break;
    case 15: 
      var $43=$1;
      STACKTOP = __stackBase__;
      return $43;
    default: assert(0, "bad label: " + __label__);
  }
}
_png_create_struct_2["X"]=1;

function _png_destroy_struct($struct_ptr) {
  ;
  var __label__;

  var $1;
  $1=$struct_ptr;
  var $2=$1;
  _png_destroy_struct_2($2, 0, 0);
  ;
  return;
}


function _png_destroy_struct_2($struct_ptr, $free_fn, $mem_ptr) {
  var __stackBase__  = STACKTOP; STACKTOP += 632; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $dummy_struct=__stackBase__;
      var $png_ptr;
      $1=$struct_ptr;
      $2=$free_fn;
      $3=$mem_ptr;
      var $4=$1;
      var $5=(($4)|0)!=0;
      if ($5) { __label__ = 3; break; } else { __label__ = 6; break; }
    case 3: 
      var $7=$2;
      var $8=(($7)|0)!=0;
      if ($8) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      $png_ptr=$dummy_struct;
      var $10=$3;
      var $11=$png_ptr;
      var $12=(($11+552)|0);
      HEAP32[(($12)>>2)]=$10;
      var $13=$2;
      var $14=$png_ptr;
      var $15=$1;
      FUNCTION_TABLE[$13]($14, $15);
      __label__ = 6; break;
    case 5: 
      var $17=$1;
      _free($17);
      __label__ = 6; break;
    case 6: 
      STACKTOP = __stackBase__;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}


function _png_calloc($png_ptr, $size) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $ret;
      $1=$png_ptr;
      $2=$size;
      var $3=$1;
      var $4=$2;
      var $5=_png_malloc($3, $4);
      $ret=$5;
      var $6=$ret;
      var $7=(($6)|0)!=0;
      if ($7) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $9=$ret;
      var $10=$2;
      _memset($9, 0, $10, 1);
      __label__ = 4; break;
    case 4: 
      var $12=$ret;
      ;
      return $12;
    default: assert(0, "bad label: " + __label__);
  }
}


function _png_malloc($png_ptr, $size) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $ret;
      $2=$png_ptr;
      $3=$size;
      var $4=$2;
      var $5=(($4)|0)==0;
      if ($5) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      var $7=$3;
      var $8=(($7)|0)==0;
      if ($8) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      $1=0;
      __label__ = 12; break;
    case 5: 
      var $11=$2;
      var $12=(($11+556)|0);
      var $13=$12;
      var $14=HEAP32[(($13)>>2)];
      var $15=(($14)|0)!=0;
      if ($15) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      var $17=$2;
      var $18=(($17+556)|0);
      var $19=$18;
      var $20=HEAP32[(($19)>>2)];
      var $21=$2;
      var $22=$3;
      var $23=FUNCTION_TABLE[$20]($21, $22);
      $ret=$23;
      __label__ = 8; break;
    case 7: 
      var $25=$2;
      var $26=$3;
      var $27=_png_malloc_default($25, $26);
      $ret=$27;
      __label__ = 8; break;
    case 8: 
      var $29=$ret;
      var $30=(($29)|0)==0;
      if ($30) { __label__ = 9; break; } else { __label__ = 11; break; }
    case 9: 
      var $32=$2;
      var $33=(($32+88)|0);
      var $34=HEAP32[(($33)>>2)];
      var $35=$34 & 1048576;
      var $36=(($35)|0)==0;
      if ($36) { __label__ = 10; break; } else { __label__ = 11; break; }
    case 10: 
      var $38=$2;
      _png_error($38, ((STRING_TABLE.__str120)|0));
      __label__ = 11; break;
    case 11: 
      var $40=$ret;
      $1=$40;
      __label__ = 12; break;
    case 12: 
      var $42=$1;
      ;
      return $42;
    default: assert(0, "bad label: " + __label__);
  }
}
_png_malloc["X"]=1;

function _png_malloc_default($png_ptr, $size) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $ret;
      $2=$png_ptr;
      $3=$size;
      var $4=$2;
      var $5=(($4)|0)==0;
      if ($5) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      var $7=$3;
      var $8=(($7)|0)==0;
      if ($8) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      $1=0;
      __label__ = 9; break;
    case 5: 
      var $11=$3;
      var $12=$3;
      var $13=(($11)|0)!=(($12)|0);
      if ($13) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      $ret=0;
      __label__ = 8; break;
    case 7: 
      var $16=$3;
      var $17=_malloc($16);
      $ret=$17;
      __label__ = 8; break;
    case 8: 
      var $19=$ret;
      $1=$19;
      __label__ = 9; break;
    case 9: 
      var $21=$1;
      ;
      return $21;
    default: assert(0, "bad label: " + __label__);
  }
}


function _png_free($png_ptr, $ptr) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      $1=$png_ptr;
      $2=$ptr;
      var $3=$1;
      var $4=(($3)|0)==0;
      if ($4) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      var $6=$2;
      var $7=(($6)|0)==0;
      if ($7) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      __label__ = 8; break;
    case 5: 
      var $10=$1;
      var $11=(($10+560)|0);
      var $12=HEAP32[(($11)>>2)];
      var $13=(($12)|0)!=0;
      if ($13) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      var $15=$1;
      var $16=(($15+560)|0);
      var $17=HEAP32[(($16)>>2)];
      var $18=$1;
      var $19=$2;
      FUNCTION_TABLE[$17]($18, $19);
      __label__ = 8; break;
    case 7: 
      var $21=$1;
      var $22=$2;
      _png_free_default($21, $22);
      __label__ = 8; break;
    case 8: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}


function _png_free_default($png_ptr, $ptr) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      $1=$png_ptr;
      $2=$ptr;
      var $3=$1;
      var $4=(($3)|0)==0;
      if ($4) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      var $6=$2;
      var $7=(($6)|0)==0;
      if ($7) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      __label__ = 6; break;
    case 5: 
      var $10=$2;
      _free($10);
      __label__ = 6; break;
    case 6: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}


function _png_malloc_warn($png_ptr, $size) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $ptr;
      var $save_flags;
      $2=$png_ptr;
      $3=$size;
      var $4=$2;
      var $5=(($4)|0)==0;
      if ($5) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      $1=0;
      __label__ = 5; break;
    case 4: 
      var $8=$2;
      var $9=(($8+88)|0);
      var $10=HEAP32[(($9)>>2)];
      $save_flags=$10;
      var $11=$2;
      var $12=(($11+88)|0);
      var $13=HEAP32[(($12)>>2)];
      var $14=$13 | 1048576;
      HEAP32[(($12)>>2)]=$14;
      var $15=$2;
      var $16=$3;
      var $17=_png_malloc($15, $16);
      $ptr=$17;
      var $18=$save_flags;
      var $19=$2;
      var $20=(($19+88)|0);
      HEAP32[(($20)>>2)]=$18;
      var $21=$ptr;
      $1=$21;
      __label__ = 5; break;
    case 5: 
      var $23=$1;
      ;
      return $23;
    default: assert(0, "bad label: " + __label__);
  }
}


function _png_create_read_struct($user_png_ver, $error_ptr, $error_fn, $warn_fn) {
  ;
  var __label__;

  var $1;
  var $2;
  var $3;
  var $4;
  $1=$user_png_ver;
  $2=$error_ptr;
  $3=$error_fn;
  $4=$warn_fn;
  var $5=$1;
  var $6=$2;
  var $7=$3;
  var $8=$4;
  var $9=_png_create_read_struct_2($5, $6, $7, $8, 0, 0, 0);
  ;
  return $9;
}


function _png_read_info($png_ptr, $info_ptr) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $length;
      var $chunk_name;
      $1=$png_ptr;
      $2=$info_ptr;
      var $3=$1;
      var $4=(($3)|0)==0;
      if ($4) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      var $6=$2;
      var $7=(($6)|0)==0;
      if ($7) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      __label__ = 96; break;
    case 5: 
      var $10=$1;
      var $11=$2;
      _png_read_sig($10, $11);
      __label__ = 6; break;
    case 6: 
      var $13=$1;
      var $14=_png_read_chunk_header($13);
      $length=$14;
      var $15=$1;
      var $16=(($15+264)|0);
      var $17=(($16)|0);
      $chunk_name=$17;
      var $18=$chunk_name;
      var $19=_memcmp($18, ((STRING_TABLE._png_read_info_png_IDAT)|0), 4);
      var $20=(($19)|0)!=0;
      if ($20) { __label__ = 10; break; } else { __label__ = 7; break; }
    case 7: 
      var $22=$1;
      var $23=(($22+84)|0);
      var $24=HEAP32[(($23)>>2)];
      var $25=$24 & 8;
      var $26=(($25)|0)!=0;
      if ($26) { __label__ = 8; break; } else { __label__ = 9; break; }
    case 8: 
      var $28=$1;
      var $29=(($28+84)|0);
      var $30=HEAP32[(($29)>>2)];
      var $31=$30 | 8192;
      HEAP32[(($29)>>2)]=$31;
      __label__ = 9; break;
    case 9: 
      __label__ = 10; break;
    case 10: 
      var $34=$chunk_name;
      var $35=_memcmp($34, ((STRING_TABLE._png_read_info_png_IHDR)|0), 4);
      var $36=(($35)|0)!=0;
      if ($36) { __label__ = 12; break; } else { __label__ = 11; break; }
    case 11: 
      var $38=$1;
      var $39=$2;
      var $40=$length;
      _png_handle_IHDR($38, $39, $40);
      __label__ = 95; break;
    case 12: 
      var $42=$chunk_name;
      var $43=_memcmp($42, ((STRING_TABLE._png_read_info_png_IEND)|0), 4);
      var $44=(($43)|0)!=0;
      if ($44) { __label__ = 14; break; } else { __label__ = 13; break; }
    case 13: 
      var $46=$1;
      var $47=$2;
      var $48=$length;
      _png_handle_IEND($46, $47, $48);
      __label__ = 94; break;
    case 14: 
      var $50=$1;
      var $51=$chunk_name;
      var $52=_png_handle_as_unknown($50, $51);
      var $53=(($52)|0)!=0;
      if ($53) { __label__ = 15; break; } else { __label__ = 29; break; }
    case 15: 
      var $55=$chunk_name;
      var $56=_memcmp($55, ((STRING_TABLE._png_read_info_png_IDAT)|0), 4);
      var $57=(($56)|0)!=0;
      if ($57) { __label__ = 17; break; } else { __label__ = 16; break; }
    case 16: 
      var $59=$1;
      var $60=(($59+84)|0);
      var $61=HEAP32[(($60)>>2)];
      var $62=$61 | 4;
      HEAP32[(($60)>>2)]=$62;
      __label__ = 17; break;
    case 17: 
      var $64=$1;
      var $65=$2;
      var $66=$length;
      _png_handle_unknown($64, $65, $66);
      var $67=$chunk_name;
      var $68=_memcmp($67, ((STRING_TABLE._png_read_info_png_PLTE)|0), 4);
      var $69=(($68)|0)!=0;
      if ($69) { __label__ = 19; break; } else { __label__ = 18; break; }
    case 18: 
      var $71=$1;
      var $72=(($71+84)|0);
      var $73=HEAP32[(($72)>>2)];
      var $74=$73 | 2;
      HEAP32[(($72)>>2)]=$74;
      __label__ = 28; break;
    case 19: 
      var $76=$chunk_name;
      var $77=_memcmp($76, ((STRING_TABLE._png_read_info_png_IDAT)|0), 4);
      var $78=(($77)|0)!=0;
      if ($78) { __label__ = 27; break; } else { __label__ = 20; break; }
    case 20: 
      var $80=$1;
      var $81=(($80+84)|0);
      var $82=HEAP32[(($81)>>2)];
      var $83=$82 & 1;
      var $84=(($83)|0)!=0;
      if ($84) { __label__ = 22; break; } else { __label__ = 21; break; }
    case 21: 
      var $86=$1;
      _png_error($86, ((STRING_TABLE.__str7155)|0));
      __label__ = 26; break;
    case 22: 
      var $88=$1;
      var $89=(($88+274)|0);
      var $90=HEAPU8[($89)];
      var $91=(($90)&255);
      var $92=(($91)|0)==3;
      if ($92) { __label__ = 23; break; } else { __label__ = 25; break; }
    case 23: 
      var $94=$1;
      var $95=(($94+84)|0);
      var $96=HEAP32[(($95)>>2)];
      var $97=$96 & 2;
      var $98=(($97)|0)!=0;
      if ($98) { __label__ = 25; break; } else { __label__ = 24; break; }
    case 24: 
      var $100=$1;
      _png_error($100, ((STRING_TABLE.__str8156)|0));
      __label__ = 25; break;
    case 25: 
      __label__ = 26; break;
    case 26: 
      __label__ = 96; break;
    case 27: 
      __label__ = 28; break;
    case 28: 
      __label__ = 93; break;
    case 29: 
      var $106=$chunk_name;
      var $107=_memcmp($106, ((STRING_TABLE._png_read_info_png_PLTE)|0), 4);
      var $108=(($107)|0)!=0;
      if ($108) { __label__ = 31; break; } else { __label__ = 30; break; }
    case 30: 
      var $110=$1;
      var $111=$2;
      var $112=$length;
      _png_handle_PLTE($110, $111, $112);
      __label__ = 92; break;
    case 31: 
      var $114=$chunk_name;
      var $115=_memcmp($114, ((STRING_TABLE._png_read_info_png_IDAT)|0), 4);
      var $116=(($115)|0)!=0;
      if ($116) { __label__ = 39; break; } else { __label__ = 32; break; }
    case 32: 
      var $118=$1;
      var $119=(($118+84)|0);
      var $120=HEAP32[(($119)>>2)];
      var $121=$120 & 1;
      var $122=(($121)|0)!=0;
      if ($122) { __label__ = 34; break; } else { __label__ = 33; break; }
    case 33: 
      var $124=$1;
      _png_error($124, ((STRING_TABLE.__str7155)|0));
      __label__ = 38; break;
    case 34: 
      var $126=$1;
      var $127=(($126+274)|0);
      var $128=HEAPU8[($127)];
      var $129=(($128)&255);
      var $130=(($129)|0)==3;
      if ($130) { __label__ = 35; break; } else { __label__ = 37; break; }
    case 35: 
      var $132=$1;
      var $133=(($132+84)|0);
      var $134=HEAP32[(($133)>>2)];
      var $135=$134 & 2;
      var $136=(($135)|0)!=0;
      if ($136) { __label__ = 37; break; } else { __label__ = 36; break; }
    case 36: 
      var $138=$1;
      _png_error($138, ((STRING_TABLE.__str8156)|0));
      __label__ = 37; break;
    case 37: 
      __label__ = 38; break;
    case 38: 
      var $141=$length;
      var $142=$1;
      var $143=(($142+248)|0);
      HEAP32[(($143)>>2)]=$141;
      var $144=$1;
      var $145=(($144+84)|0);
      var $146=HEAP32[(($145)>>2)];
      var $147=$146 | 4;
      HEAP32[(($145)>>2)]=$147;
      __label__ = 96; break;
    case 39: 
      var $149=$chunk_name;
      var $150=_memcmp($149, ((STRING_TABLE._png_read_info_png_bKGD)|0), 4);
      var $151=(($150)|0)!=0;
      if ($151) { __label__ = 41; break; } else { __label__ = 40; break; }
    case 40: 
      var $153=$1;
      var $154=$2;
      var $155=$length;
      _png_handle_bKGD($153, $154, $155);
      __label__ = 90; break;
    case 41: 
      var $157=$chunk_name;
      var $158=_memcmp($157, ((STRING_TABLE._png_read_info_png_cHRM)|0), 4);
      var $159=(($158)|0)!=0;
      if ($159) { __label__ = 43; break; } else { __label__ = 42; break; }
    case 42: 
      var $161=$1;
      var $162=$2;
      var $163=$length;
      _png_handle_cHRM($161, $162, $163);
      __label__ = 89; break;
    case 43: 
      var $165=$chunk_name;
      var $166=_memcmp($165, ((STRING_TABLE._png_read_info_png_gAMA)|0), 4);
      var $167=(($166)|0)!=0;
      if ($167) { __label__ = 45; break; } else { __label__ = 44; break; }
    case 44: 
      var $169=$1;
      var $170=$2;
      var $171=$length;
      _png_handle_gAMA($169, $170, $171);
      __label__ = 88; break;
    case 45: 
      var $173=$chunk_name;
      var $174=_memcmp($173, ((STRING_TABLE._png_read_info_png_hIST)|0), 4);
      var $175=(($174)|0)!=0;
      if ($175) { __label__ = 47; break; } else { __label__ = 46; break; }
    case 46: 
      var $177=$1;
      var $178=$2;
      var $179=$length;
      _png_handle_hIST($177, $178, $179);
      __label__ = 87; break;
    case 47: 
      var $181=$chunk_name;
      var $182=_memcmp($181, ((STRING_TABLE._png_read_info_png_oFFs)|0), 4);
      var $183=(($182)|0)!=0;
      if ($183) { __label__ = 49; break; } else { __label__ = 48; break; }
    case 48: 
      var $185=$1;
      var $186=$2;
      var $187=$length;
      _png_handle_oFFs($185, $186, $187);
      __label__ = 86; break;
    case 49: 
      var $189=$chunk_name;
      var $190=_memcmp($189, ((STRING_TABLE._png_read_info_png_pCAL)|0), 4);
      var $191=(($190)|0)!=0;
      if ($191) { __label__ = 51; break; } else { __label__ = 50; break; }
    case 50: 
      var $193=$1;
      var $194=$2;
      var $195=$length;
      _png_handle_pCAL($193, $194, $195);
      __label__ = 85; break;
    case 51: 
      var $197=$chunk_name;
      var $198=_memcmp($197, ((STRING_TABLE._png_read_info_png_sCAL)|0), 4);
      var $199=(($198)|0)!=0;
      if ($199) { __label__ = 53; break; } else { __label__ = 52; break; }
    case 52: 
      var $201=$1;
      var $202=$2;
      var $203=$length;
      _png_handle_sCAL($201, $202, $203);
      __label__ = 84; break;
    case 53: 
      var $205=$chunk_name;
      var $206=_memcmp($205, ((STRING_TABLE._png_read_info_png_pHYs)|0), 4);
      var $207=(($206)|0)!=0;
      if ($207) { __label__ = 55; break; } else { __label__ = 54; break; }
    case 54: 
      var $209=$1;
      var $210=$2;
      var $211=$length;
      _png_handle_pHYs($209, $210, $211);
      __label__ = 83; break;
    case 55: 
      var $213=$chunk_name;
      var $214=_memcmp($213, ((STRING_TABLE._png_read_info_png_sBIT)|0), 4);
      var $215=(($214)|0)!=0;
      if ($215) { __label__ = 57; break; } else { __label__ = 56; break; }
    case 56: 
      var $217=$1;
      var $218=$2;
      var $219=$length;
      _png_handle_sBIT($217, $218, $219);
      __label__ = 82; break;
    case 57: 
      var $221=$chunk_name;
      var $222=_memcmp($221, ((STRING_TABLE._png_read_info_png_sRGB)|0), 4);
      var $223=(($222)|0)!=0;
      if ($223) { __label__ = 59; break; } else { __label__ = 58; break; }
    case 58: 
      var $225=$1;
      var $226=$2;
      var $227=$length;
      _png_handle_sRGB($225, $226, $227);
      __label__ = 81; break;
    case 59: 
      var $229=$chunk_name;
      var $230=_memcmp($229, ((STRING_TABLE._png_read_info_png_iCCP)|0), 4);
      var $231=(($230)|0)!=0;
      if ($231) { __label__ = 61; break; } else { __label__ = 60; break; }
    case 60: 
      var $233=$1;
      var $234=$2;
      var $235=$length;
      _png_handle_iCCP($233, $234, $235);
      __label__ = 80; break;
    case 61: 
      var $237=$chunk_name;
      var $238=_memcmp($237, ((STRING_TABLE._png_read_info_png_sPLT)|0), 4);
      var $239=(($238)|0)!=0;
      if ($239) { __label__ = 63; break; } else { __label__ = 62; break; }
    case 62: 
      var $241=$1;
      var $242=$2;
      var $243=$length;
      _png_handle_sPLT($241, $242, $243);
      __label__ = 79; break;
    case 63: 
      var $245=$chunk_name;
      var $246=_memcmp($245, ((STRING_TABLE._png_read_info_png_tEXt)|0), 4);
      var $247=(($246)|0)!=0;
      if ($247) { __label__ = 65; break; } else { __label__ = 64; break; }
    case 64: 
      var $249=$1;
      var $250=$2;
      var $251=$length;
      _png_handle_tEXt($249, $250, $251);
      __label__ = 78; break;
    case 65: 
      var $253=$chunk_name;
      var $254=_memcmp($253, ((STRING_TABLE._png_read_info_png_tIME)|0), 4);
      var $255=(($254)|0)!=0;
      if ($255) { __label__ = 67; break; } else { __label__ = 66; break; }
    case 66: 
      var $257=$1;
      var $258=$2;
      var $259=$length;
      _png_handle_tIME($257, $258, $259);
      __label__ = 77; break;
    case 67: 
      var $261=$chunk_name;
      var $262=_memcmp($261, ((STRING_TABLE._png_read_info_png_tRNS)|0), 4);
      var $263=(($262)|0)!=0;
      if ($263) { __label__ = 69; break; } else { __label__ = 68; break; }
    case 68: 
      var $265=$1;
      var $266=$2;
      var $267=$length;
      _png_handle_tRNS($265, $266, $267);
      __label__ = 76; break;
    case 69: 
      var $269=$chunk_name;
      var $270=_memcmp($269, ((STRING_TABLE._png_read_info_png_zTXt)|0), 4);
      var $271=(($270)|0)!=0;
      if ($271) { __label__ = 71; break; } else { __label__ = 70; break; }
    case 70: 
      var $273=$1;
      var $274=$2;
      var $275=$length;
      _png_handle_zTXt($273, $274, $275);
      __label__ = 75; break;
    case 71: 
      var $277=$chunk_name;
      var $278=_memcmp($277, ((STRING_TABLE._png_read_info_png_iTXt)|0), 4);
      var $279=(($278)|0)!=0;
      if ($279) { __label__ = 73; break; } else { __label__ = 72; break; }
    case 72: 
      var $281=$1;
      var $282=$2;
      var $283=$length;
      _png_handle_iTXt($281, $282, $283);
      __label__ = 74; break;
    case 73: 
      var $285=$1;
      var $286=$2;
      var $287=$length;
      _png_handle_unknown($285, $286, $287);
      __label__ = 74; break;
    case 74: 
      __label__ = 75; break;
    case 75: 
      __label__ = 76; break;
    case 76: 
      __label__ = 77; break;
    case 77: 
      __label__ = 78; break;
    case 78: 
      __label__ = 79; break;
    case 79: 
      __label__ = 80; break;
    case 80: 
      __label__ = 81; break;
    case 81: 
      __label__ = 82; break;
    case 82: 
      __label__ = 83; break;
    case 83: 
      __label__ = 84; break;
    case 84: 
      __label__ = 85; break;
    case 85: 
      __label__ = 86; break;
    case 86: 
      __label__ = 87; break;
    case 87: 
      __label__ = 88; break;
    case 88: 
      __label__ = 89; break;
    case 89: 
      __label__ = 90; break;
    case 90: 
      __label__ = 91; break;
    case 91: 
      __label__ = 92; break;
    case 92: 
      __label__ = 93; break;
    case 93: 
      __label__ = 94; break;
    case 94: 
      __label__ = 95; break;
    case 95: 
      __label__ = 6; break;
    case 96: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_png_read_info["X"]=1;

function _png_read_update_info($png_ptr, $info_ptr) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      $1=$png_ptr;
      $2=$info_ptr;
      var $3=$1;
      var $4=(($3)|0)==0;
      if ($4) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      __label__ = 8; break;
    case 4: 
      var $7=$1;
      var $8=(($7+88)|0);
      var $9=HEAP32[(($8)>>2)];
      var $10=$9 & 64;
      var $11=(($10)|0)!=0;
      if ($11) { __label__ = 6; break; } else { __label__ = 5; break; }
    case 5: 
      var $13=$1;
      _png_read_start_row($13);
      __label__ = 7; break;
    case 6: 
      var $15=$1;
      _png_warning($15, ((STRING_TABLE.__str9157)|0));
      __label__ = 7; break;
    case 7: 
      var $17=$1;
      var $18=$2;
      _png_read_transform_info($17, $18);
      __label__ = 8; break;
    case 8: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}


function _png_create_read_struct_2($user_png_ver, $error_ptr, $error_fn, $warn_fn, $mem_ptr, $malloc_fn, $free_fn) {
  var __stackBase__  = STACKTOP; STACKTOP += 80; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  var setjmpTable = {"4": function(value) { __label__ = 39; $28 = value },dummy: 0};
  while(1) try { switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $5;
      var $6;
      var $7;
      var $8;
      var $png_ptr;
      var $png_cleanup_needed;
      var $i;
      var $msg=__stackBase__;
      $2=$user_png_ver;
      $3=$error_ptr;
      $4=$error_fn;
      $5=$warn_fn;
      $6=$mem_ptr;
      $7=$malloc_fn;
      $8=$free_fn;
      $png_cleanup_needed=0;
      var $9=$7;
      var $10=$6;
      var $11=_png_create_struct_2(1, $9, $10);
      var $12=$11;
      $png_ptr=$12;
      var $13=$png_ptr;
      var $14=(($13)|0)==0;
      if ($14) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      $1=0;
      __label__ = 38; break;
    case 4: 
      var $17=$png_ptr;
      var $18=(($17+584)|0);
      HEAP32[(($18)>>2)]=1000000;
      var $19=$png_ptr;
      var $20=(($19+588)|0);
      HEAP32[(($20)>>2)]=1000000;
      var $21=$png_ptr;
      var $22=(($21+592)|0);
      HEAP32[(($22)>>2)]=0;
      var $23=$png_ptr;
      var $24=(($23+200)|0);
      HEAP32[(($24)>>2)]=0;
      var $25=$png_ptr;
      var $26=_png_set_longjmp_fn($25, 10, 40);
      var $27=(($26)|0);
      var $28=(HEAP32[(($27)>>2)]=__label__, 0);
      __label__ = 39; break;
    case 39: 
      var $29=(($28)|0)!=0;
      if ($29) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      _abort();
      throw "Reached an unreachable!"
    case 6: 
      var $32=$png_ptr;
      var $33=$6;
      var $34=$7;
      var $35=$8;
      _png_set_mem_fn($32, $33, $34, $35);
      var $36=$png_ptr;
      var $37=$3;
      var $38=$4;
      var $39=$5;
      _png_set_error_fn($36, $37, $38, $39);
      var $40=$2;
      var $41=(($40)|0)!=0;
      if ($41) { __label__ = 7; break; } else { __label__ = 13; break; }
    case 7: 
      $i=0;
      __label__ = 8; break;
    case 8: 
      var $44=$i;
      var $45=$2;
      var $46=(($45+$44)|0);
      var $47=HEAP8[($46)];
      var $48=(($47 << 24) >> 24);
      var $49=$i;
      var $50=_png_get_header_ver(0);
      var $51=(($50+$49)|0);
      var $52=HEAP8[($51)];
      var $53=(($52 << 24) >> 24);
      var $54=(($48)|0)!=(($53)|0);
      if ($54) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      var $56=$png_ptr;
      var $57=(($56+88)|0);
      var $58=HEAP32[(($57)>>2)];
      var $59=$58 | 131072;
      HEAP32[(($57)>>2)]=$59;
      __label__ = 10; break;
    case 10: 
      __label__ = 11; break;
    case 11: 
      var $62=$i;
      var $63=((($62)+(1))|0);
      $i=$63;
      var $64=_png_get_header_ver(0);
      var $65=(($64+$62)|0);
      var $66=HEAP8[($65)];
      var $67=(($66 << 24) >> 24)!=0;
      if ($67) { __label__ = 8; break; } else { __label__ = 12; break; }
    case 12: 
      __label__ = 14; break;
    case 13: 
      var $70=$png_ptr;
      var $71=(($70+88)|0);
      var $72=HEAP32[(($71)>>2)];
      var $73=$72 | 131072;
      HEAP32[(($71)>>2)]=$73;
      __label__ = 14; break;
    case 14: 
      var $75=$png_ptr;
      var $76=(($75+88)|0);
      var $77=HEAP32[(($76)>>2)];
      var $78=$77 & 131072;
      var $79=(($78)|0)!=0;
      if ($79) { __label__ = 15; break; } else { __label__ = 25; break; }
    case 15: 
      var $81=$2;
      var $82=(($81)|0)==0;
      if ($82) { __label__ = 21; break; } else { __label__ = 16; break; }
    case 16: 
      var $84=$2;
      var $85=(($84)|0);
      var $86=HEAP8[($85)];
      var $87=(($86 << 24) >> 24);
      var $88=_png_get_header_ver(0);
      var $89=(($88)|0);
      var $90=HEAP8[($89)];
      var $91=(($90 << 24) >> 24);
      var $92=(($87)|0)!=(($91)|0);
      if ($92) { __label__ = 21; break; } else { __label__ = 17; break; }
    case 17: 
      var $94=$2;
      var $95=(($94)|0);
      var $96=HEAP8[($95)];
      var $97=(($96 << 24) >> 24);
      var $98=(($97)|0)==49;
      if ($98) { __label__ = 18; break; } else { __label__ = 19; break; }
    case 18: 
      var $100=$2;
      var $101=(($100+2)|0);
      var $102=HEAP8[($101)];
      var $103=(($102 << 24) >> 24);
      var $104=_png_get_header_ver(0);
      var $105=(($104+2)|0);
      var $106=HEAP8[($105)];
      var $107=(($106 << 24) >> 24);
      var $108=(($103)|0)!=(($107)|0);
      if ($108) { __label__ = 21; break; } else { __label__ = 19; break; }
    case 19: 
      var $110=$2;
      var $111=(($110)|0);
      var $112=HEAP8[($111)];
      var $113=(($112 << 24) >> 24);
      var $114=(($113)|0)==48;
      if ($114) { __label__ = 20; break; } else { __label__ = 24; break; }
    case 20: 
      var $116=$2;
      var $117=(($116+2)|0);
      var $118=HEAP8[($117)];
      var $119=(($118 << 24) >> 24);
      var $120=(($119)|0) < 57;
      if ($120) { __label__ = 21; break; } else { __label__ = 24; break; }
    case 21: 
      var $122=$2;
      var $123=(($122)|0)!=0;
      if ($123) { __label__ = 22; break; } else { __label__ = 23; break; }
    case 22: 
      var $125=(($msg)|0);
      var $126=$2;
      var $127=_snprintf($125, 80, ((STRING_TABLE.__str148)|0), (tempInt=STACKTOP,STACKTOP += 4,assert(STACKTOP < STACK_ROOT + STACK_MAX, "Ran out of stack"),HEAP32[((tempInt)>>2)]=$126,tempInt));
      var $128=$png_ptr;
      var $129=(($msg)|0);
      _png_warning($128, $129);
      __label__ = 23; break;
    case 23: 
      var $131=(($msg)|0);
      var $132=_png_get_header_ver(0);
      var $133=_snprintf($131, 80, ((STRING_TABLE.__str1149)|0), (tempInt=STACKTOP,STACKTOP += 4,assert(STACKTOP < STACK_ROOT + STACK_MAX, "Ran out of stack"),HEAP32[((tempInt)>>2)]=$132,tempInt));
      var $134=$png_ptr;
      var $135=(($msg)|0);
      _png_warning($134, $135);
      var $136=$png_ptr;
      _png_warning($136, ((STRING_TABLE.__str2150)|0));
      $png_cleanup_needed=1;
      __label__ = 24; break;
    case 24: 
      __label__ = 25; break;
    case 25: 
      var $139=$png_cleanup_needed;
      var $140=(($139)|0)!=0;
      if ($140) { __label__ = 29; break; } else { __label__ = 26; break; }
    case 26: 
      var $142=$png_ptr;
      var $143=(($142+156)|0);
      HEAP32[(($143)>>2)]=8192;
      var $144=$png_ptr;
      var $145=$png_ptr;
      var $146=(($145+156)|0);
      var $147=HEAP32[(($146)>>2)];
      var $148=_png_malloc_warn($144, $147);
      var $149=$png_ptr;
      var $150=(($149+152)|0);
      HEAP32[(($150)>>2)]=$148;
      var $151=$png_ptr;
      var $152=(($151+152)|0);
      var $153=HEAP32[(($152)>>2)];
      var $154=(($153)|0)==0;
      if ($154) { __label__ = 27; break; } else { __label__ = 28; break; }
    case 27: 
      $png_cleanup_needed=1;
      __label__ = 28; break;
    case 28: 
      __label__ = 29; break;
    case 29: 
      var $158=$png_ptr;
      var $159=(($158+96)|0);
      var $160=(($159+32)|0);
      HEAP32[(($160)>>2)]=6;
      var $161=$png_ptr;
      var $162=(($161+96)|0);
      var $163=(($162+36)|0);
      HEAP32[(($163)>>2)]=8;
      var $164=$png_ptr;
      var $165=$164;
      var $166=$png_ptr;
      var $167=(($166+96)|0);
      var $168=(($167+40)|0);
      HEAP32[(($168)>>2)]=$165;
      var $169=$png_cleanup_needed;
      var $170=(($169)|0)!=0;
      if ($170) { __label__ = 35; break; } else { __label__ = 30; break; }
    case 30: 
      var $172=$png_ptr;
      var $173=(($172+96)|0);
      var $174=_inflateInit_($173, ((STRING_TABLE.__str3151)|0), 56);
      if ((($174)|0) == -4 || (($174)|0) == -2) {
        __label__ = 31; break;
      }
      else if ((($174)|0) == -6) {
        __label__ = 32; break;
      }
      else if ((($174)|0) == 0) {
        __label__ = 34; break;
      }
      else {
      __label__ = 33; break;
      }
      
    case 31: 
      var $176=$png_ptr;
      _png_warning($176, ((STRING_TABLE.__str4152)|0));
      $png_cleanup_needed=1;
      __label__ = 34; break;
    case 32: 
      var $178=$png_ptr;
      _png_warning($178, ((STRING_TABLE.__str5153)|0));
      $png_cleanup_needed=1;
      __label__ = 34; break;
    case 33: 
      var $180=$png_ptr;
      _png_warning($180, ((STRING_TABLE.__str6154)|0));
      $png_cleanup_needed=1;
      __label__ = 34; break;
    case 34: 
      __label__ = 35; break;
    case 35: 
      var $183=$png_cleanup_needed;
      var $184=(($183)|0)!=0;
      if ($184) { __label__ = 36; break; } else { __label__ = 37; break; }
    case 36: 
      var $186=$png_ptr;
      var $187=$png_ptr;
      var $188=(($187+152)|0);
      var $189=HEAP32[(($188)>>2)];
      _png_free($186, $189);
      var $190=$png_ptr;
      var $191=(($190+152)|0);
      HEAP32[(($191)>>2)]=0;
      var $192=$png_ptr;
      var $193=$192;
      var $194=$8;
      var $195=$6;
      _png_destroy_struct_2($193, $194, $195);
      $1=0;
      __label__ = 38; break;
    case 37: 
      var $197=$png_ptr;
      var $198=(($197+152)|0);
      var $199=HEAP32[(($198)>>2)];
      var $200=$png_ptr;
      var $201=(($200+96)|0);
      var $202=(($201+12)|0);
      HEAP32[(($202)>>2)]=$199;
      var $203=$png_ptr;
      var $204=(($203+156)|0);
      var $205=HEAP32[(($204)>>2)];
      var $206=$png_ptr;
      var $207=(($206+96)|0);
      var $208=(($207+16)|0);
      HEAP32[(($208)>>2)]=$205;
      var $209=$png_ptr;
      _png_set_read_fn($209, 0, 0);
      var $210=$png_ptr;
      $1=$210;
      __label__ = 38; break;
    case 38: 
      var $212=$1;
      STACKTOP = __stackBase__;
      return $212;
    default: assert(0, "bad label: " + __label__);
  } } catch(e) { if (!e.longjmp) throw(e); setjmpTable[e.label](e.value) }
}
_png_create_read_struct_2["X"]=1;

function _png_read_row($png_ptr, $row, $dsp_row) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $ret;
      $1=$png_ptr;
      $2=$row;
      $3=$dsp_row;
      var $4=$1;
      var $5=(($4)|0)==0;
      if ($5) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      __label__ = 107; break;
    case 4: 
      var $8=$1;
      var $9=(($8+88)|0);
      var $10=HEAP32[(($9)>>2)];
      var $11=$10 & 64;
      var $12=(($11)|0)!=0;
      if ($12) { __label__ = 6; break; } else { __label__ = 5; break; }
    case 5: 
      var $14=$1;
      _png_read_start_row($14);
      __label__ = 6; break;
    case 6: 
      var $16=$1;
      var $17=(($16+208)|0);
      var $18=HEAP32[(($17)>>2)];
      var $19=(($18)|0)==0;
      if ($19) { __label__ = 7; break; } else { __label__ = 9; break; }
    case 7: 
      var $21=$1;
      var $22=(($21+272)|0);
      var $23=HEAPU8[($22)];
      var $24=(($23)&255);
      var $25=(($24)|0)==0;
      if ($25) { __label__ = 8; break; } else { __label__ = 9; break; }
    case 8: 
      __label__ = 9; break;
    case 9: 
      var $28=$1;
      var $29=(($28+271)|0);
      var $30=HEAPU8[($29)];
      var $31=(($30)&255);
      var $32=(($31)|0)!=0;
      if ($32) { __label__ = 10; break; } else { __label__ = 52; break; }
    case 10: 
      var $34=$1;
      var $35=(($34+92)|0);
      var $36=HEAP32[(($35)>>2)];
      var $37=$36 & 2;
      var $38=(($37)|0)!=0;
      if ($38) { __label__ = 11; break; } else { __label__ = 52; break; }
    case 11: 
      var $40=$1;
      var $41=(($40+272)|0);
      var $42=HEAPU8[($41)];
      var $43=(($42)&255);
      if ((($43)|0) == 0) {
        __label__ = 12; break;
      }
      else if ((($43)|0) == 1) {
        __label__ = 17; break;
      }
      else if ((($43)|0) == 2) {
        __label__ = 23; break;
      }
      else if ((($43)|0) == 3) {
        __label__ = 29; break;
      }
      else if ((($43)|0) == 4) {
        __label__ = 35; break;
      }
      else if ((($43)|0) == 5) {
        __label__ = 41; break;
      }
      else if ((($43)|0) == 6) {
        __label__ = 48; break;
      }
      else {
      __label__ = 47; break;
      }
      
    case 12: 
      var $45=$1;
      var $46=(($45+208)|0);
      var $47=HEAP32[(($46)>>2)];
      var $48=$47 & 7;
      var $49=(($48)|0)!=0;
      if ($49) { __label__ = 13; break; } else { __label__ = 16; break; }
    case 13: 
      var $51=$3;
      var $52=(($51)|0)!=0;
      if ($52) { __label__ = 14; break; } else { __label__ = 15; break; }
    case 14: 
      var $54=$1;
      var $55=$3;
      var $56=$1;
      var $57=(($56+272)|0);
      var $58=HEAPU8[($57)];
      var $59=(($58)&255);
      var $60=((_png_read_row_png_pass_dsp_mask+($59<<2))|0);
      var $61=HEAP32[(($60)>>2)];
      _png_combine_row($54, $55, $61);
      __label__ = 15; break;
    case 15: 
      var $63=$1;
      _png_read_finish_row($63);
      __label__ = 107; break;
    case 16: 
      __label__ = 51; break;
    case 17: 
      var $66=$1;
      var $67=(($66+208)|0);
      var $68=HEAP32[(($67)>>2)];
      var $69=$68 & 7;
      var $70=(($69)|0)!=0;
      if ($70) { __label__ = 19; break; } else { __label__ = 18; break; }
    case 18: 
      var $72=$1;
      var $73=(($72+180)|0);
      var $74=HEAPU32[(($73)>>2)];
      var $75=(($74)>>>0) < 5;
      if ($75) { __label__ = 19; break; } else { __label__ = 22; break; }
    case 19: 
      var $77=$3;
      var $78=(($77)|0)!=0;
      if ($78) { __label__ = 20; break; } else { __label__ = 21; break; }
    case 20: 
      var $80=$1;
      var $81=$3;
      var $82=$1;
      var $83=(($82+272)|0);
      var $84=HEAPU8[($83)];
      var $85=(($84)&255);
      var $86=((_png_read_row_png_pass_dsp_mask+($85<<2))|0);
      var $87=HEAP32[(($86)>>2)];
      _png_combine_row($80, $81, $87);
      __label__ = 21; break;
    case 21: 
      var $89=$1;
      _png_read_finish_row($89);
      __label__ = 107; break;
    case 22: 
      __label__ = 51; break;
    case 23: 
      var $92=$1;
      var $93=(($92+208)|0);
      var $94=HEAP32[(($93)>>2)];
      var $95=$94 & 7;
      var $96=(($95)|0)!=4;
      if ($96) { __label__ = 24; break; } else { __label__ = 28; break; }
    case 24: 
      var $98=$3;
      var $99=(($98)|0)!=0;
      if ($99) { __label__ = 25; break; } else { __label__ = 27; break; }
    case 25: 
      var $101=$1;
      var $102=(($101+208)|0);
      var $103=HEAP32[(($102)>>2)];
      var $104=$103 & 4;
      var $105=(($104)|0)!=0;
      if ($105) { __label__ = 26; break; } else { __label__ = 27; break; }
    case 26: 
      var $107=$1;
      var $108=$3;
      var $109=$1;
      var $110=(($109+272)|0);
      var $111=HEAPU8[($110)];
      var $112=(($111)&255);
      var $113=((_png_read_row_png_pass_dsp_mask+($112<<2))|0);
      var $114=HEAP32[(($113)>>2)];
      _png_combine_row($107, $108, $114);
      __label__ = 27; break;
    case 27: 
      var $116=$1;
      _png_read_finish_row($116);
      __label__ = 107; break;
    case 28: 
      __label__ = 51; break;
    case 29: 
      var $119=$1;
      var $120=(($119+208)|0);
      var $121=HEAP32[(($120)>>2)];
      var $122=$121 & 3;
      var $123=(($122)|0)!=0;
      if ($123) { __label__ = 31; break; } else { __label__ = 30; break; }
    case 30: 
      var $125=$1;
      var $126=(($125+180)|0);
      var $127=HEAPU32[(($126)>>2)];
      var $128=(($127)>>>0) < 3;
      if ($128) { __label__ = 31; break; } else { __label__ = 34; break; }
    case 31: 
      var $130=$3;
      var $131=(($130)|0)!=0;
      if ($131) { __label__ = 32; break; } else { __label__ = 33; break; }
    case 32: 
      var $133=$1;
      var $134=$3;
      var $135=$1;
      var $136=(($135+272)|0);
      var $137=HEAPU8[($136)];
      var $138=(($137)&255);
      var $139=((_png_read_row_png_pass_dsp_mask+($138<<2))|0);
      var $140=HEAP32[(($139)>>2)];
      _png_combine_row($133, $134, $140);
      __label__ = 33; break;
    case 33: 
      var $142=$1;
      _png_read_finish_row($142);
      __label__ = 107; break;
    case 34: 
      __label__ = 51; break;
    case 35: 
      var $145=$1;
      var $146=(($145+208)|0);
      var $147=HEAP32[(($146)>>2)];
      var $148=$147 & 3;
      var $149=(($148)|0)!=2;
      if ($149) { __label__ = 36; break; } else { __label__ = 40; break; }
    case 36: 
      var $151=$3;
      var $152=(($151)|0)!=0;
      if ($152) { __label__ = 37; break; } else { __label__ = 39; break; }
    case 37: 
      var $154=$1;
      var $155=(($154+208)|0);
      var $156=HEAP32[(($155)>>2)];
      var $157=$156 & 2;
      var $158=(($157)|0)!=0;
      if ($158) { __label__ = 38; break; } else { __label__ = 39; break; }
    case 38: 
      var $160=$1;
      var $161=$3;
      var $162=$1;
      var $163=(($162+272)|0);
      var $164=HEAPU8[($163)];
      var $165=(($164)&255);
      var $166=((_png_read_row_png_pass_dsp_mask+($165<<2))|0);
      var $167=HEAP32[(($166)>>2)];
      _png_combine_row($160, $161, $167);
      __label__ = 39; break;
    case 39: 
      var $169=$1;
      _png_read_finish_row($169);
      __label__ = 107; break;
    case 40: 
      __label__ = 51; break;
    case 41: 
      var $172=$1;
      var $173=(($172+208)|0);
      var $174=HEAP32[(($173)>>2)];
      var $175=$174 & 1;
      var $176=(($175)|0)!=0;
      if ($176) { __label__ = 43; break; } else { __label__ = 42; break; }
    case 42: 
      var $178=$1;
      var $179=(($178+180)|0);
      var $180=HEAPU32[(($179)>>2)];
      var $181=(($180)>>>0) < 2;
      if ($181) { __label__ = 43; break; } else { __label__ = 46; break; }
    case 43: 
      var $183=$3;
      var $184=(($183)|0)!=0;
      if ($184) { __label__ = 44; break; } else { __label__ = 45; break; }
    case 44: 
      var $186=$1;
      var $187=$3;
      var $188=$1;
      var $189=(($188+272)|0);
      var $190=HEAPU8[($189)];
      var $191=(($190)&255);
      var $192=((_png_read_row_png_pass_dsp_mask+($191<<2))|0);
      var $193=HEAP32[(($192)>>2)];
      _png_combine_row($186, $187, $193);
      __label__ = 45; break;
    case 45: 
      var $195=$1;
      _png_read_finish_row($195);
      __label__ = 107; break;
    case 46: 
      __label__ = 51; break;
    case 47: 
      __label__ = 48; break;
    case 48: 
      var $199=$1;
      var $200=(($199+208)|0);
      var $201=HEAP32[(($200)>>2)];
      var $202=$201 & 1;
      var $203=(($202)|0)!=0;
      if ($203) { __label__ = 50; break; } else { __label__ = 49; break; }
    case 49: 
      var $205=$1;
      _png_read_finish_row($205);
      __label__ = 107; break;
    case 50: 
      __label__ = 51; break;
    case 51: 
      __label__ = 52; break;
    case 52: 
      var $209=$1;
      var $210=(($209+84)|0);
      var $211=HEAP32[(($210)>>2)];
      var $212=$211 & 4;
      var $213=(($212)|0)!=0;
      if ($213) { __label__ = 54; break; } else { __label__ = 53; break; }
    case 53: 
      var $215=$1;
      _png_error($215, ((STRING_TABLE.__str10158)|0));
      __label__ = 54; break;
    case 54: 
      var $217=$1;
      var $218=(($217+216)|0);
      var $219=HEAP32[(($218)>>2)];
      var $220=$1;
      var $221=(($220+96)|0);
      var $222=(($221+12)|0);
      HEAP32[(($222)>>2)]=$219;
      var $223=$1;
      var $224=(($223+277)|0);
      var $225=HEAPU8[($224)];
      var $226=(($225)&255);
      var $227=(($226)|0) >= 8;
      if ($227) { __label__ = 55; break; } else { __label__ = 56; break; }
    case 55: 
      var $229=$1;
      var $230=(($229+204)|0);
      var $231=HEAP32[(($230)>>2)];
      var $232=$1;
      var $233=(($232+277)|0);
      var $234=HEAPU8[($233)];
      var $235=(($234)&255);
      var $236=$235 >>> 3;
      var $237=((($231)*($236))|0);
      var $250 = $237;__label__ = 57; break;
    case 56: 
      var $239=$1;
      var $240=(($239+204)|0);
      var $241=HEAP32[(($240)>>2)];
      var $242=$1;
      var $243=(($242+277)|0);
      var $244=HEAPU8[($243)];
      var $245=(($244)&255);
      var $246=((($241)*($245))|0);
      var $247=((($246)+(7))|0);
      var $248=$247 >>> 3;
      var $250 = $248;__label__ = 57; break;
    case 57: 
      var $250;
      var $251=((($250)+(1))|0);
      var $252=$1;
      var $253=(($252+96)|0);
      var $254=(($253+16)|0);
      HEAP32[(($254)>>2)]=$251;
      __label__ = 58; break;
    case 58: 
      var $256=$1;
      var $257=(($256+96)|0);
      var $258=(($257+4)|0);
      var $259=HEAP32[(($258)>>2)];
      var $260=(($259)|0)!=0;
      if ($260) { __label__ = 67; break; } else { __label__ = 59; break; }
    case 59: 
      __label__ = 60; break;
    case 60: 
      var $263=$1;
      var $264=(($263+248)|0);
      var $265=HEAP32[(($264)>>2)];
      var $266=(($265)|0)!=0;
      var $267=$266 ^ 1;
      if ($267) { __label__ = 61; break; } else { __label__ = 64; break; }
    case 61: 
      var $269=$1;
      var $270=_png_crc_finish($269, 0);
      var $271=$1;
      var $272=_png_read_chunk_header($271);
      var $273=$1;
      var $274=(($273+248)|0);
      HEAP32[(($274)>>2)]=$272;
      var $275=$1;
      var $276=(($275+264)|0);
      var $277=(($276)|0);
      var $278=_memcmp($277, ((STRING_TABLE._png_read_row_png_IDAT)|0), 4);
      var $279=(($278)|0)!=0;
      if ($279) { __label__ = 62; break; } else { __label__ = 63; break; }
    case 62: 
      var $281=$1;
      _png_error($281, ((STRING_TABLE.__str11159)|0));
      __label__ = 63; break;
    case 63: 
      __label__ = 60; break;
    case 64: 
      var $284=$1;
      var $285=(($284+156)|0);
      var $286=HEAP32[(($285)>>2)];
      var $287=$1;
      var $288=(($287+96)|0);
      var $289=(($288+4)|0);
      HEAP32[(($289)>>2)]=$286;
      var $290=$1;
      var $291=(($290+152)|0);
      var $292=HEAP32[(($291)>>2)];
      var $293=$1;
      var $294=(($293+96)|0);
      var $295=(($294)|0);
      HEAP32[(($295)>>2)]=$292;
      var $296=$1;
      var $297=(($296+156)|0);
      var $298=HEAPU32[(($297)>>2)];
      var $299=$1;
      var $300=(($299+248)|0);
      var $301=HEAPU32[(($300)>>2)];
      var $302=(($298)>>>0) > (($301)>>>0);
      if ($302) { __label__ = 65; break; } else { __label__ = 66; break; }
    case 65: 
      var $304=$1;
      var $305=(($304+248)|0);
      var $306=HEAP32[(($305)>>2)];
      var $307=$1;
      var $308=(($307+96)|0);
      var $309=(($308+4)|0);
      HEAP32[(($309)>>2)]=$306;
      __label__ = 66; break;
    case 66: 
      var $311=$1;
      var $312=$1;
      var $313=(($312+152)|0);
      var $314=HEAP32[(($313)>>2)];
      var $315=$1;
      var $316=(($315+96)|0);
      var $317=(($316+4)|0);
      var $318=HEAP32[(($317)>>2)];
      _png_crc_read($311, $314, $318);
      var $319=$1;
      var $320=(($319+96)|0);
      var $321=(($320+4)|0);
      var $322=HEAP32[(($321)>>2)];
      var $323=$1;
      var $324=(($323+248)|0);
      var $325=HEAP32[(($324)>>2)];
      var $326=((($325)-($322))|0);
      HEAP32[(($324)>>2)]=$326;
      __label__ = 67; break;
    case 67: 
      var $328=$1;
      var $329=(($328+96)|0);
      var $330=_inflate($329, 1);
      $ret=$330;
      var $331=$ret;
      var $332=(($331)|0)==1;
      if ($332) { __label__ = 68; break; } else { __label__ = 73; break; }
    case 68: 
      var $334=$1;
      var $335=(($334+96)|0);
      var $336=(($335+16)|0);
      var $337=HEAP32[(($336)>>2)];
      var $338=(($337)|0)!=0;
      if ($338) { __label__ = 71; break; } else { __label__ = 69; break; }
    case 69: 
      var $340=$1;
      var $341=(($340+96)|0);
      var $342=(($341+4)|0);
      var $343=HEAP32[(($342)>>2)];
      var $344=(($343)|0)!=0;
      if ($344) { __label__ = 71; break; } else { __label__ = 70; break; }
    case 70: 
      var $346=$1;
      var $347=(($346+248)|0);
      var $348=HEAP32[(($347)>>2)];
      var $349=(($348)|0)!=0;
      if ($349) { __label__ = 71; break; } else { __label__ = 72; break; }
    case 71: 
      var $351=$1;
      _png_error($351, ((STRING_TABLE.__str12160)|0));
      __label__ = 72; break;
    case 72: 
      var $353=$1;
      var $354=(($353+84)|0);
      var $355=HEAP32[(($354)>>2)];
      var $356=$355 | 8;
      HEAP32[(($354)>>2)]=$356;
      var $357=$1;
      var $358=(($357+88)|0);
      var $359=HEAP32[(($358)>>2)];
      var $360=$359 | 32;
      HEAP32[(($358)>>2)]=$360;
      __label__ = 80; break;
    case 73: 
      var $362=$ret;
      var $363=(($362)|0)!=0;
      if ($363) { __label__ = 74; break; } else { __label__ = 78; break; }
    case 74: 
      var $365=$1;
      var $366=$1;
      var $367=(($366+96)|0);
      var $368=(($367+24)|0);
      var $369=HEAP32[(($368)>>2)];
      var $370=(($369)|0)!=0;
      if ($370) { __label__ = 75; break; } else { __label__ = 76; break; }
    case 75: 
      var $372=$1;
      var $373=(($372+96)|0);
      var $374=(($373+24)|0);
      var $375=HEAP32[(($374)>>2)];
      var $378 = $375;__label__ = 77; break;
    case 76: 
      var $378 = ((STRING_TABLE.__str13161)|0);__label__ = 77; break;
    case 77: 
      var $378;
      _png_error($365, $378);
      __label__ = 78; break;
    case 78: 
      __label__ = 79; break;
    case 79: 
      var $381=$1;
      var $382=(($381+96)|0);
      var $383=(($382+16)|0);
      var $384=HEAP32[(($383)>>2)];
      var $385=(($384)|0)!=0;
      if ($385) { __label__ = 58; break; } else { __label__ = 80; break; }
    case 80: 
      var $387=$1;
      var $388=(($387+274)|0);
      var $389=HEAP8[($388)];
      var $390=$1;
      var $391=(($390+236)|0);
      var $392=(($391+8)|0);
      HEAP8[($392)]=$389;
      var $393=$1;
      var $394=(($393+204)|0);
      var $395=HEAP32[(($394)>>2)];
      var $396=$1;
      var $397=(($396+236)|0);
      var $398=(($397)|0);
      HEAP32[(($398)>>2)]=$395;
      var $399=$1;
      var $400=(($399+278)|0);
      var $401=HEAP8[($400)];
      var $402=$1;
      var $403=(($402+236)|0);
      var $404=(($403+10)|0);
      HEAP8[($404)]=$401;
      var $405=$1;
      var $406=(($405+275)|0);
      var $407=HEAP8[($406)];
      var $408=$1;
      var $409=(($408+236)|0);
      var $410=(($409+9)|0);
      HEAP8[($410)]=$407;
      var $411=$1;
      var $412=(($411+277)|0);
      var $413=HEAP8[($412)];
      var $414=$1;
      var $415=(($414+236)|0);
      var $416=(($415+11)|0);
      HEAP8[($416)]=$413;
      var $417=$1;
      var $418=(($417+236)|0);
      var $419=(($418+11)|0);
      var $420=HEAPU8[($419)];
      var $421=(($420)&255);
      var $422=(($421)|0) >= 8;
      if ($422) { __label__ = 81; break; } else { __label__ = 82; break; }
    case 81: 
      var $424=$1;
      var $425=(($424+236)|0);
      var $426=(($425)|0);
      var $427=HEAP32[(($426)>>2)];
      var $428=$1;
      var $429=(($428+236)|0);
      var $430=(($429+11)|0);
      var $431=HEAPU8[($430)];
      var $432=(($431)&255);
      var $433=$432 >>> 3;
      var $434=((($427)*($433))|0);
      var $449 = $434;__label__ = 83; break;
    case 82: 
      var $436=$1;
      var $437=(($436+236)|0);
      var $438=(($437)|0);
      var $439=HEAP32[(($438)>>2)];
      var $440=$1;
      var $441=(($440+236)|0);
      var $442=(($441+11)|0);
      var $443=HEAPU8[($442)];
      var $444=(($443)&255);
      var $445=((($439)*($444))|0);
      var $446=((($445)+(7))|0);
      var $447=$446 >>> 3;
      var $449 = $447;__label__ = 83; break;
    case 83: 
      var $449;
      var $450=$1;
      var $451=(($450+236)|0);
      var $452=(($451+4)|0);
      HEAP32[(($452)>>2)]=$449;
      var $453=$1;
      var $454=(($453+216)|0);
      var $455=HEAP32[(($454)>>2)];
      var $456=(($455)|0);
      var $457=HEAP8[($456)];
      var $458=(($457 << 24) >> 24)!=0;
      if ($458) { __label__ = 84; break; } else { __label__ = 85; break; }
    case 84: 
      var $460=$1;
      var $461=$1;
      var $462=(($461+236)|0);
      var $463=$1;
      var $464=(($463+216)|0);
      var $465=HEAP32[(($464)>>2)];
      var $466=(($465+1)|0);
      var $467=$1;
      var $468=(($467+212)|0);
      var $469=HEAP32[(($468)>>2)];
      var $470=(($469+1)|0);
      var $471=$1;
      var $472=(($471+216)|0);
      var $473=HEAP32[(($472)>>2)];
      var $474=(($473)|0);
      var $475=HEAPU8[($474)];
      var $476=(($475)&255);
      _png_read_filter_row($460, $462, $466, $470, $476);
      __label__ = 85; break;
    case 85: 
      var $478=$1;
      var $479=(($478+212)|0);
      var $480=HEAP32[(($479)>>2)];
      var $481=$1;
      var $482=(($481+216)|0);
      var $483=HEAP32[(($482)>>2)];
      var $484=$1;
      var $485=(($484+196)|0);
      var $486=HEAP32[(($485)>>2)];
      var $487=((($486)+(1))|0);
      assert($487 % 1 === 0, 'memcpy given ' + $487 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');_memcpy($480, $483, $487, 1);
      var $488=$1;
      var $489=(($488+540)|0);
      var $490=HEAP32[(($489)>>2)];
      var $491=$490 & 4;
      var $492=(($491)|0)!=0;
      if ($492) { __label__ = 86; break; } else { __label__ = 88; break; }
    case 86: 
      var $494=$1;
      var $495=(($494+548)|0);
      var $496=HEAPU8[($495)];
      var $497=(($496)&255);
      var $498=(($497)|0)==64;
      if ($498) { __label__ = 87; break; } else { __label__ = 88; break; }
    case 87: 
      var $500=$1;
      var $501=(($500+236)|0);
      var $502=$1;
      var $503=(($502+216)|0);
      var $504=HEAP32[(($503)>>2)];
      var $505=(($504+1)|0);
      _png_do_read_intrapixel($501, $505);
      __label__ = 88; break;
    case 88: 
      var $507=$1;
      var $508=(($507+92)|0);
      var $509=HEAP32[(($508)>>2)];
      var $510=(($509)|0)!=0;
      if ($510) { __label__ = 90; break; } else { __label__ = 89; break; }
    case 89: 
      var $512=$1;
      var $513=(($512+88)|0);
      var $514=HEAP32[(($513)>>2)];
      var $515=$514 & 4194304;
      var $516=(($515)|0)!=0;
      if ($516) { __label__ = 90; break; } else { __label__ = 91; break; }
    case 90: 
      var $518=$1;
      _png_do_read_transformations($518);
      __label__ = 91; break;
    case 91: 
      var $520=$1;
      var $521=(($520+271)|0);
      var $522=HEAPU8[($521)];
      var $523=(($522)&255);
      var $524=(($523)|0)!=0;
      if ($524) { __label__ = 92; break; } else { __label__ = 100; break; }
    case 92: 
      var $526=$1;
      var $527=(($526+92)|0);
      var $528=HEAP32[(($527)>>2)];
      var $529=$528 & 2;
      var $530=(($529)|0)!=0;
      if ($530) { __label__ = 93; break; } else { __label__ = 100; break; }
    case 93: 
      var $532=$1;
      var $533=(($532+272)|0);
      var $534=HEAPU8[($533)];
      var $535=(($534)&255);
      var $536=(($535)|0) < 6;
      if ($536) { __label__ = 94; break; } else { __label__ = 95; break; }
    case 94: 
      var $538=$1;
      _png_do_read_interlace($538);
      __label__ = 95; break;
    case 95: 
      var $540=$3;
      var $541=(($540)|0)!=0;
      if ($541) { __label__ = 96; break; } else { __label__ = 97; break; }
    case 96: 
      var $543=$1;
      var $544=$3;
      var $545=$1;
      var $546=(($545+272)|0);
      var $547=HEAPU8[($546)];
      var $548=(($547)&255);
      var $549=((_png_read_row_png_pass_dsp_mask+($548<<2))|0);
      var $550=HEAP32[(($549)>>2)];
      _png_combine_row($543, $544, $550);
      __label__ = 97; break;
    case 97: 
      var $552=$2;
      var $553=(($552)|0)!=0;
      if ($553) { __label__ = 98; break; } else { __label__ = 99; break; }
    case 98: 
      var $555=$1;
      var $556=$2;
      var $557=$1;
      var $558=(($557+272)|0);
      var $559=HEAPU8[($558)];
      var $560=(($559)&255);
      var $561=((_png_read_row_png_pass_mask+($560<<2))|0);
      var $562=HEAP32[(($561)>>2)];
      _png_combine_row($555, $556, $562);
      __label__ = 99; break;
    case 99: 
      __label__ = 105; break;
    case 100: 
      var $565=$2;
      var $566=(($565)|0)!=0;
      if ($566) { __label__ = 101; break; } else { __label__ = 102; break; }
    case 101: 
      var $568=$1;
      var $569=$2;
      _png_combine_row($568, $569, 255);
      __label__ = 102; break;
    case 102: 
      var $571=$3;
      var $572=(($571)|0)!=0;
      if ($572) { __label__ = 103; break; } else { __label__ = 104; break; }
    case 103: 
      var $574=$1;
      var $575=$3;
      _png_combine_row($574, $575, 255);
      __label__ = 104; break;
    case 104: 
      __label__ = 105; break;
    case 105: 
      var $578=$1;
      _png_read_finish_row($578);
      var $579=$1;
      var $580=(($579+388)|0);
      var $581=HEAP32[(($580)>>2)];
      var $582=(($581)|0)!=0;
      if ($582) { __label__ = 106; break; } else { __label__ = 107; break; }
    case 106: 
      var $584=$1;
      var $585=(($584+388)|0);
      var $586=HEAP32[(($585)>>2)];
      var $587=$1;
      var $588=$1;
      var $589=(($588+208)|0);
      var $590=HEAP32[(($589)>>2)];
      var $591=$1;
      var $592=(($591+272)|0);
      var $593=HEAPU8[($592)];
      var $594=(($593)&255);
      FUNCTION_TABLE[$586]($587, $590, $594);
      __label__ = 107; break;
    case 107: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_png_read_row["X"]=1;

function _png_set_strip_16($png_ptr) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      $1=$png_ptr;
      var $2=$1;
      var $3=(($2)|0)==0;
      if ($3) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      __label__ = 5; break;
    case 4: 
      var $6=$1;
      var $7=(($6+92)|0);
      var $8=HEAP32[(($7)>>2)];
      var $9=$8 | 1024;
      HEAP32[(($7)>>2)]=$9;
      __label__ = 5; break;
    case 5: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}


function _png_read_rows($png_ptr, $row, $display_row, $num_rows) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $i;
      var $rp;
      var $dp;
      var $rptr;
      var $dptr;
      var $rptr1;
      var $dptr2;
      $1=$png_ptr;
      $2=$row;
      $3=$display_row;
      $4=$num_rows;
      var $5=$1;
      var $6=(($5)|0)==0;
      if ($6) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      __label__ = 25; break;
    case 4: 
      var $9=$2;
      $rp=$9;
      var $10=$3;
      $dp=$10;
      var $11=$rp;
      var $12=(($11)|0)!=0;
      if ($12) { __label__ = 5; break; } else { __label__ = 11; break; }
    case 5: 
      var $14=$dp;
      var $15=(($14)|0)!=0;
      if ($15) { __label__ = 6; break; } else { __label__ = 11; break; }
    case 6: 
      $i=0;
      __label__ = 7; break;
    case 7: 
      var $18=$i;
      var $19=$4;
      var $20=(($18)>>>0) < (($19)>>>0);
      if ($20) { __label__ = 8; break; } else { __label__ = 10; break; }
    case 8: 
      var $22=$rp;
      var $23=(($22+4)|0);
      $rp=$23;
      var $24=HEAP32[(($22)>>2)];
      $rptr=$24;
      var $25=$dp;
      var $26=(($25+4)|0);
      $dp=$26;
      var $27=HEAP32[(($25)>>2)];
      $dptr=$27;
      var $28=$1;
      var $29=$rptr;
      var $30=$dptr;
      _png_read_row($28, $29, $30);
      __label__ = 9; break;
    case 9: 
      var $32=$i;
      var $33=((($32)+(1))|0);
      $i=$33;
      __label__ = 7; break;
    case 10: 
      __label__ = 25; break;
    case 11: 
      var $36=$rp;
      var $37=(($36)|0)!=0;
      if ($37) { __label__ = 12; break; } else { __label__ = 17; break; }
    case 12: 
      $i=0;
      __label__ = 13; break;
    case 13: 
      var $40=$i;
      var $41=$4;
      var $42=(($40)>>>0) < (($41)>>>0);
      if ($42) { __label__ = 14; break; } else { __label__ = 16; break; }
    case 14: 
      var $44=$rp;
      var $45=HEAP32[(($44)>>2)];
      $rptr1=$45;
      var $46=$1;
      var $47=$rptr1;
      _png_read_row($46, $47, 0);
      var $48=$rp;
      var $49=(($48+4)|0);
      $rp=$49;
      __label__ = 15; break;
    case 15: 
      var $51=$i;
      var $52=((($51)+(1))|0);
      $i=$52;
      __label__ = 13; break;
    case 16: 
      __label__ = 24; break;
    case 17: 
      var $55=$dp;
      var $56=(($55)|0)!=0;
      if ($56) { __label__ = 18; break; } else { __label__ = 23; break; }
    case 18: 
      $i=0;
      __label__ = 19; break;
    case 19: 
      var $59=$i;
      var $60=$4;
      var $61=(($59)>>>0) < (($60)>>>0);
      if ($61) { __label__ = 20; break; } else { __label__ = 22; break; }
    case 20: 
      var $63=$dp;
      var $64=HEAP32[(($63)>>2)];
      $dptr2=$64;
      var $65=$1;
      var $66=$dptr2;
      _png_read_row($65, 0, $66);
      var $67=$dp;
      var $68=(($67+4)|0);
      $dp=$68;
      __label__ = 21; break;
    case 21: 
      var $70=$i;
      var $71=((($70)+(1))|0);
      $i=$71;
      __label__ = 19; break;
    case 22: 
      __label__ = 23; break;
    case 23: 
      __label__ = 24; break;
    case 24: 
      __label__ = 25; break;
    case 25: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_png_read_rows["X"]=1;

function _png_read_image($png_ptr, $image) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $i;
      var $image_height;
      var $pass;
      var $j;
      var $rp;
      $1=$png_ptr;
      $2=$image;
      var $3=$1;
      var $4=(($3)|0)==0;
      if ($4) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      __label__ = 12; break;
    case 4: 
      var $7=$1;
      var $8=_png_set_interlace_handling($7);
      $pass=$8;
      var $9=$1;
      var $10=(($9+184)|0);
      var $11=HEAP32[(($10)>>2)];
      $image_height=$11;
      var $12=$image_height;
      var $13=$1;
      var $14=(($13+188)|0);
      HEAP32[(($14)>>2)]=$12;
      $j=0;
      __label__ = 5; break;
    case 5: 
      var $16=$j;
      var $17=$pass;
      var $18=(($16)|0) < (($17)|0);
      if ($18) { __label__ = 6; break; } else { __label__ = 12; break; }
    case 6: 
      var $20=$2;
      $rp=$20;
      $i=0;
      __label__ = 7; break;
    case 7: 
      var $22=$i;
      var $23=$image_height;
      var $24=(($22)>>>0) < (($23)>>>0);
      if ($24) { __label__ = 8; break; } else { __label__ = 10; break; }
    case 8: 
      var $26=$1;
      var $27=$rp;
      var $28=HEAP32[(($27)>>2)];
      _png_read_row($26, $28, 0);
      var $29=$rp;
      var $30=(($29+4)|0);
      $rp=$30;
      __label__ = 9; break;
    case 9: 
      var $32=$i;
      var $33=((($32)+(1))|0);
      $i=$33;
      __label__ = 7; break;
    case 10: 
      __label__ = 11; break;
    case 11: 
      var $36=$j;
      var $37=((($36)+(1))|0);
      $j=$37;
      __label__ = 5; break;
    case 12: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_png_read_image["X"]=1;

function _png_destroy_read_struct($png_ptr_ptr, $info_ptr_ptr, $end_info_ptr_ptr) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $png_ptr;
      var $info_ptr;
      var $end_info_ptr;
      var $free_fn;
      var $mem_ptr;
      $1=$png_ptr_ptr;
      $2=$info_ptr_ptr;
      $3=$end_info_ptr_ptr;
      $png_ptr=0;
      $info_ptr=0;
      $end_info_ptr=0;
      $free_fn=0;
      $mem_ptr=0;
      var $4=$1;
      var $5=(($4)|0)!=0;
      if ($5) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $7=$1;
      var $8=HEAP32[(($7)>>2)];
      $png_ptr=$8;
      __label__ = 4; break;
    case 4: 
      var $10=$png_ptr;
      var $11=(($10)|0)==0;
      if ($11) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      __label__ = 16; break;
    case 6: 
      var $14=$png_ptr;
      var $15=(($14+560)|0);
      var $16=HEAP32[(($15)>>2)];
      $free_fn=$16;
      var $17=$png_ptr;
      var $18=(($17+552)|0);
      var $19=HEAP32[(($18)>>2)];
      $mem_ptr=$19;
      var $20=$2;
      var $21=(($20)|0)!=0;
      if ($21) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $23=$2;
      var $24=HEAP32[(($23)>>2)];
      $info_ptr=$24;
      __label__ = 8; break;
    case 8: 
      var $26=$3;
      var $27=(($26)|0)!=0;
      if ($27) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      var $29=$3;
      var $30=HEAP32[(($29)>>2)];
      $end_info_ptr=$30;
      __label__ = 10; break;
    case 10: 
      var $32=$png_ptr;
      var $33=$info_ptr;
      var $34=$end_info_ptr;
      _png_read_destroy($32, $33, $34);
      var $35=$info_ptr;
      var $36=(($35)|0)!=0;
      if ($36) { __label__ = 11; break; } else { __label__ = 12; break; }
    case 11: 
      var $38=$png_ptr;
      var $39=$info_ptr;
      _png_free_data($38, $39, 16384, -1);
      var $40=$info_ptr;
      var $41=$40;
      var $42=$free_fn;
      var $43=$mem_ptr;
      _png_destroy_struct_2($41, $42, $43);
      var $44=$2;
      HEAP32[(($44)>>2)]=0;
      __label__ = 12; break;
    case 12: 
      var $46=$end_info_ptr;
      var $47=(($46)|0)!=0;
      if ($47) { __label__ = 13; break; } else { __label__ = 14; break; }
    case 13: 
      var $49=$png_ptr;
      var $50=$end_info_ptr;
      _png_free_data($49, $50, 16384, -1);
      var $51=$end_info_ptr;
      var $52=$51;
      var $53=$free_fn;
      var $54=$mem_ptr;
      _png_destroy_struct_2($52, $53, $54);
      var $55=$3;
      HEAP32[(($55)>>2)]=0;
      __label__ = 14; break;
    case 14: 
      var $57=$png_ptr;
      var $58=(($57)|0)!=0;
      if ($58) { __label__ = 15; break; } else { __label__ = 16; break; }
    case 15: 
      var $60=$png_ptr;
      var $61=$60;
      var $62=$free_fn;
      var $63=$mem_ptr;
      _png_destroy_struct_2($61, $62, $63);
      var $64=$1;
      HEAP32[(($64)>>2)]=0;
      __label__ = 16; break;
    case 16: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_png_destroy_read_struct["X"]=1;

function _png_read_destroy($png_ptr, $info_ptr, $end_info_ptr) {
  var __stackBase__  = STACKTOP; STACKTOP += 40; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $tmp_jmp=__stackBase__;
      var $error_fn;
      var $warning_fn;
      var $error_ptr;
      var $free_fn;
      var $i;
      var $istop;
      var $i1;
      var $istop2;
      var $i3;
      var $istop4;
      $1=$png_ptr;
      $2=$info_ptr;
      $3=$end_info_ptr;
      var $4=$2;
      var $5=(($4)|0)!=0;
      if ($5) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $7=$1;
      var $8=$2;
      _png_info_destroy($7, $8);
      __label__ = 4; break;
    case 4: 
      var $10=$3;
      var $11=(($10)|0)!=0;
      if ($11) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $13=$1;
      var $14=$3;
      _png_info_destroy($13, $14);
      __label__ = 6; break;
    case 6: 
      var $16=$1;
      var $17=$1;
      var $18=(($17+152)|0);
      var $19=HEAP32[(($18)>>2)];
      _png_free($16, $19);
      var $20=$1;
      var $21=$1;
      var $22=(($21+564)|0);
      var $23=HEAP32[(($22)>>2)];
      _png_free($20, $23);
      var $24=$1;
      var $25=$1;
      var $26=(($25+212)|0);
      var $27=HEAP32[(($26)>>2)];
      _png_free($24, $27);
      var $28=$1;
      var $29=$1;
      var $30=(($29+624)|0);
      var $31=HEAP32[(($30)>>2)];
      _png_free($28, $31);
      var $32=$1;
      var $33=$1;
      var $34=(($33+472)|0);
      var $35=HEAP32[(($34)>>2)];
      _png_free($32, $35);
      var $36=$1;
      var $37=$1;
      var $38=(($37+476)|0);
      var $39=HEAP32[(($38)>>2)];
      _png_free($36, $39);
      var $40=$1;
      var $41=$1;
      var $42=(($41+336)|0);
      var $43=HEAP32[(($42)>>2)];
      _png_free($40, $43);
      var $44=$1;
      var $45=$1;
      var $46=(($45+340)|0);
      var $47=HEAP32[(($46)>>2)];
      _png_free($44, $47);
      var $48=$1;
      var $49=$1;
      var $50=(($49+344)|0);
      var $51=HEAP32[(($50)>>2)];
      _png_free($48, $51);
      var $52=$1;
      var $53=(($52+512)|0);
      var $54=HEAP32[(($53)>>2)];
      var $55=$54 & 4096;
      var $56=(($55)|0)!=0;
      if ($56) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $58=$1;
      var $59=$58;
      var $60=$1;
      var $61=(($60+256)|0);
      var $62=HEAP32[(($61)>>2)];
      var $63=$62;
      _png_zfree($59, $63);
      __label__ = 8; break;
    case 8: 
      var $65=$1;
      var $66=(($65+512)|0);
      var $67=HEAP32[(($66)>>2)];
      var $68=$67 & -4097;
      HEAP32[(($66)>>2)]=$68;
      var $69=$1;
      var $70=(($69+512)|0);
      var $71=HEAP32[(($70)>>2)];
      var $72=$71 & 8192;
      var $73=(($72)|0)!=0;
      if ($73) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      var $75=$1;
      var $76=$1;
      var $77=(($76+372)|0);
      var $78=HEAP32[(($77)>>2)];
      _png_free($75, $78);
      __label__ = 10; break;
    case 10: 
      var $80=$1;
      var $81=(($80+512)|0);
      var $82=HEAP32[(($81)>>2)];
      var $83=$82 & -8193;
      HEAP32[(($81)>>2)]=$83;
      var $84=$1;
      var $85=(($84+512)|0);
      var $86=HEAP32[(($85)>>2)];
      var $87=$86 & 8;
      var $88=(($87)|0)!=0;
      if ($88) { __label__ = 11; break; } else { __label__ = 12; break; }
    case 11: 
      var $90=$1;
      var $91=$1;
      var $92=(($91+480)|0);
      var $93=HEAP32[(($92)>>2)];
      var $94=$93;
      _png_free($90, $94);
      __label__ = 12; break;
    case 12: 
      var $96=$1;
      var $97=(($96+512)|0);
      var $98=HEAP32[(($97)>>2)];
      var $99=$98 & -9;
      HEAP32[(($97)>>2)]=$99;
      var $100=$1;
      var $101=(($100+348)|0);
      var $102=HEAP32[(($101)>>2)];
      var $103=(($102)|0)!=0;
      if ($103) { __label__ = 13; break; } else { __label__ = 18; break; }
    case 13: 
      var $105=$1;
      var $106=(($105+324)|0);
      var $107=HEAP32[(($106)>>2)];
      var $108=(((8)-($107))|0);
      var $109=1 << $108;
      $istop=$109;
      $i=0;
      __label__ = 14; break;
    case 14: 
      var $111=$i;
      var $112=$istop;
      var $113=(($111)|0) < (($112)|0);
      if ($113) { __label__ = 15; break; } else { __label__ = 17; break; }
    case 15: 
      var $115=$1;
      var $116=$i;
      var $117=$1;
      var $118=(($117+348)|0);
      var $119=HEAP32[(($118)>>2)];
      var $120=(($119+($116<<2))|0);
      var $121=HEAP32[(($120)>>2)];
      var $122=$121;
      _png_free($115, $122);
      __label__ = 16; break;
    case 16: 
      var $124=$i;
      var $125=((($124)+(1))|0);
      $i=$125;
      __label__ = 14; break;
    case 17: 
      var $127=$1;
      var $128=$1;
      var $129=(($128+348)|0);
      var $130=HEAP32[(($129)>>2)];
      var $131=$130;
      _png_free($127, $131);
      __label__ = 18; break;
    case 18: 
      var $133=$1;
      var $134=(($133+352)|0);
      var $135=HEAP32[(($134)>>2)];
      var $136=(($135)|0)!=0;
      if ($136) { __label__ = 19; break; } else { __label__ = 24; break; }
    case 19: 
      var $138=$1;
      var $139=(($138+324)|0);
      var $140=HEAP32[(($139)>>2)];
      var $141=(((8)-($140))|0);
      var $142=1 << $141;
      $istop2=$142;
      $i1=0;
      __label__ = 20; break;
    case 20: 
      var $144=$i1;
      var $145=$istop2;
      var $146=(($144)|0) < (($145)|0);
      if ($146) { __label__ = 21; break; } else { __label__ = 23; break; }
    case 21: 
      var $148=$1;
      var $149=$i1;
      var $150=$1;
      var $151=(($150+352)|0);
      var $152=HEAP32[(($151)>>2)];
      var $153=(($152+($149<<2))|0);
      var $154=HEAP32[(($153)>>2)];
      var $155=$154;
      _png_free($148, $155);
      __label__ = 22; break;
    case 22: 
      var $157=$i1;
      var $158=((($157)+(1))|0);
      $i1=$158;
      __label__ = 20; break;
    case 23: 
      var $160=$1;
      var $161=$1;
      var $162=(($161+352)|0);
      var $163=HEAP32[(($162)>>2)];
      var $164=$163;
      _png_free($160, $164);
      __label__ = 24; break;
    case 24: 
      var $166=$1;
      var $167=(($166+356)|0);
      var $168=HEAP32[(($167)>>2)];
      var $169=(($168)|0)!=0;
      if ($169) { __label__ = 25; break; } else { __label__ = 30; break; }
    case 25: 
      var $171=$1;
      var $172=(($171+324)|0);
      var $173=HEAP32[(($172)>>2)];
      var $174=(((8)-($173))|0);
      var $175=1 << $174;
      $istop4=$175;
      $i3=0;
      __label__ = 26; break;
    case 26: 
      var $177=$i3;
      var $178=$istop4;
      var $179=(($177)|0) < (($178)|0);
      if ($179) { __label__ = 27; break; } else { __label__ = 29; break; }
    case 27: 
      var $181=$1;
      var $182=$i3;
      var $183=$1;
      var $184=(($183+356)|0);
      var $185=HEAP32[(($184)>>2)];
      var $186=(($185+($182<<2))|0);
      var $187=HEAP32[(($186)>>2)];
      var $188=$187;
      _png_free($181, $188);
      __label__ = 28; break;
    case 28: 
      var $190=$i3;
      var $191=((($190)+(1))|0);
      $i3=$191;
      __label__ = 26; break;
    case 29: 
      var $193=$1;
      var $194=$1;
      var $195=(($194+356)|0);
      var $196=HEAP32[(($195)>>2)];
      var $197=$196;
      _png_free($193, $197);
      __label__ = 30; break;
    case 30: 
      var $199=$1;
      var $200=$1;
      var $201=(($200+508)|0);
      var $202=HEAP32[(($201)>>2)];
      _png_free($199, $202);
      var $203=$1;
      var $204=(($203+96)|0);
      var $205=_inflateEnd($204);
      var $206=$1;
      var $207=$1;
      var $208=(($207+412)|0);
      var $209=HEAP32[(($208)>>2)];
      _png_free($206, $209);
      var $210=(($tmp_jmp)|0);
      var $211=$210;
      var $212=$1;
      var $213=(($212)|0);
      var $214=(($213)|0);
      var $215=$214;
      assert(40 % 1 === 0, 'memcpy given ' + 40 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');_memcpy($211, $215, 40, 1);
      var $216=$1;
      var $217=(($216+44)|0);
      var $218=HEAP32[(($217)>>2)];
      $error_fn=$218;
      var $219=$1;
      var $220=(($219+48)|0);
      var $221=HEAP32[(($220)>>2)];
      $warning_fn=$221;
      var $222=$1;
      var $223=(($222+52)|0);
      var $224=HEAP32[(($223)>>2)];
      $error_ptr=$224;
      var $225=$1;
      var $226=(($225+560)|0);
      var $227=HEAP32[(($226)>>2)];
      $free_fn=$227;
      var $228=$1;
      var $229=$228;
      _memset($229, 0, 632, 1);
      var $230=$error_fn;
      var $231=$1;
      var $232=(($231+44)|0);
      HEAP32[(($232)>>2)]=$230;
      var $233=$warning_fn;
      var $234=$1;
      var $235=(($234+48)|0);
      HEAP32[(($235)>>2)]=$233;
      var $236=$error_ptr;
      var $237=$1;
      var $238=(($237+52)|0);
      HEAP32[(($238)>>2)]=$236;
      var $239=$free_fn;
      var $240=$1;
      var $241=(($240+560)|0);
      HEAP32[(($241)>>2)]=$239;
      var $242=$1;
      var $243=(($242)|0);
      var $244=(($243)|0);
      var $245=$244;
      var $246=(($tmp_jmp)|0);
      var $247=$246;
      assert(40 % 1 === 0, 'memcpy given ' + 40 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');_memcpy($245, $247, 40, 1);
      STACKTOP = __stackBase__;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_png_read_destroy["X"]=1;

function _png_read_data($png_ptr, $data, $length) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      $1=$png_ptr;
      $2=$data;
      $3=$length;
      var $4=$1;
      var $5=(($4+60)|0);
      var $6=$5;
      var $7=HEAP32[(($6)>>2)];
      var $8=(($7)|0)!=0;
      if ($8) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $10=$1;
      var $11=(($10+60)|0);
      var $12=$11;
      var $13=HEAP32[(($12)>>2)];
      var $14=$1;
      var $15=$2;
      var $16=$3;
      FUNCTION_TABLE[$13]($14, $15, $16);
      __label__ = 5; break;
    case 4: 
      var $18=$1;
      _png_error($18, ((STRING_TABLE.__str164)|0));
      __label__ = 5; break;
    case 5: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}


function _png_default_read_data($png_ptr, $data, $length) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $check;
      $1=$png_ptr;
      $2=$data;
      $3=$length;
      var $4=$1;
      var $5=(($4)|0)==0;
      if ($5) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      __label__ = 6; break;
    case 4: 
      var $8=$2;
      var $9=$3;
      var $10=$1;
      var $11=(($10+64)|0);
      var $12=HEAP32[(($11)>>2)];
      var $13=$12;
      var $14=_fread($8, 1, $9, $13);
      $check=$14;
      var $15=$check;
      var $16=$3;
      var $17=(($15)|0)!=(($16)|0);
      if ($17) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $19=$1;
      _png_error($19, ((STRING_TABLE.__str1165)|0));
      __label__ = 6; break;
    case 6: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}


function _png_set_read_fn($png_ptr, $io_ptr, $read_data_fn) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      $1=$png_ptr;
      $2=$io_ptr;
      $3=$read_data_fn;
      var $4=$1;
      var $5=(($4)|0)==0;
      if ($5) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      __label__ = 10; break;
    case 4: 
      var $8=$2;
      var $9=$1;
      var $10=(($9+64)|0);
      HEAP32[(($10)>>2)]=$8;
      var $11=$3;
      var $12=(($11)|0)!=0;
      if ($12) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $14=$3;
      var $15=$1;
      var $16=(($15+60)|0);
      var $17=$16;
      HEAP32[(($17)>>2)]=$14;
      __label__ = 7; break;
    case 6: 
      var $19=$1;
      var $20=(($19+60)|0);
      var $21=$20;
      HEAP32[(($21)>>2)]=12;
      __label__ = 7; break;
    case 7: 
      var $23=$1;
      var $24=(($23+56)|0);
      var $25=$24;
      var $26=HEAP32[(($25)>>2)];
      var $27=(($26)|0)!=0;
      if ($27) { __label__ = 8; break; } else { __label__ = 9; break; }
    case 8: 
      var $29=$1;
      var $30=(($29+56)|0);
      var $31=$30;
      HEAP32[(($31)>>2)]=0;
      var $32=$1;
      _png_warning($32, ((STRING_TABLE.__str2166)|0));
      var $33=$1;
      _png_warning($33, ((STRING_TABLE.__str3167)|0));
      __label__ = 9; break;
    case 9: 
      var $35=$1;
      var $36=(($35+312)|0);
      HEAP32[(($36)>>2)]=0;
      __label__ = 10; break;
    case 10: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}


function _png_init_read_transformations($png_ptr) {
  var __stackBase__  = STACKTOP; STACKTOP += 12; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $color_type;
      var $i;
      var $istop;
      var $i1;
      var $k;
      var $back=__stackBase__;
      var $back_1=(__stackBase__)+(4);
      var $palette;
      var $num_palette;
      var $i2;
      var $g;
      var $gs;
      var $v;
      var $w;
      var $temp;
      var $temp3;
      var $temp4;
      var $m;
      var $g5;
      var $gs6;
      var $palette7;
      var $num_palette8;
      var $i9;
      var $i10;
      var $istop11;
      var $back12=(__stackBase__)+(8);
      var $palette13;
      var $temp14;
      var $temp15;
      var $temp16;
      var $i17;
      var $istop18;
      var $sr;
      var $sg;
      var $sb;
      $1=$png_ptr;
      var $2=$1;
      var $3=(($2+274)|0);
      var $4=HEAPU8[($3)];
      var $5=(($4)&255);
      $color_type=$5;
      var $6=$1;
      var $7=(($6+92)|0);
      var $8=HEAP32[(($7)>>2)];
      var $9=$8 & 256;
      var $10=(($9)|0)!=0;
      if ($10) { __label__ = 3; break; } else { __label__ = 5; break; }
    case 3: 
      var $12=$color_type;
      var $13=$12 & 2;
      var $14=(($13)|0)!=0;
      if ($14) { __label__ = 5; break; } else { __label__ = 4; break; }
    case 4: 
      var $16=$1;
      var $17=(($16+84)|0);
      var $18=HEAP32[(($17)>>2)];
      var $19=$18 | 2048;
      HEAP32[(($17)>>2)]=$19;
      __label__ = 12; break;
    case 5: 
      var $21=$1;
      var $22=(($21+92)|0);
      var $23=HEAP32[(($22)>>2)];
      var $24=$23 & 128;
      var $25=(($24)|0)!=0;
      if ($25) { __label__ = 6; break; } else { __label__ = 11; break; }
    case 6: 
      var $27=$1;
      var $28=(($27+92)|0);
      var $29=HEAP32[(($28)>>2)];
      var $30=$29 & 256;
      var $31=(($30)|0)!=0;
      if ($31) { __label__ = 11; break; } else { __label__ = 7; break; }
    case 7: 
      var $33=$1;
      var $34=(($33+92)|0);
      var $35=HEAP32[(($34)>>2)];
      var $36=$35 & 16384;
      var $37=(($36)|0)!=0;
      if ($37) { __label__ = 8; break; } else { __label__ = 11; break; }
    case 8: 
      var $39=$1;
      var $40=(($39+292)|0);
      var $41=(($40+2)|0);
      var $42=HEAPU16[(($41)>>1)];
      var $43=(($42)&65535);
      var $44=$1;
      var $45=(($44+292)|0);
      var $46=(($45+4)|0);
      var $47=HEAPU16[(($46)>>1)];
      var $48=(($47)&65535);
      var $49=(($43)|0)==(($48)|0);
      if ($49) { __label__ = 9; break; } else { __label__ = 11; break; }
    case 9: 
      var $51=$1;
      var $52=(($51+292)|0);
      var $53=(($52+2)|0);
      var $54=HEAPU16[(($53)>>1)];
      var $55=(($54)&65535);
      var $56=$1;
      var $57=(($56+292)|0);
      var $58=(($57+6)|0);
      var $59=HEAPU16[(($58)>>1)];
      var $60=(($59)&65535);
      var $61=(($55)|0)==(($60)|0);
      if ($61) { __label__ = 10; break; } else { __label__ = 11; break; }
    case 10: 
      var $63=$1;
      var $64=(($63+84)|0);
      var $65=HEAP32[(($64)>>2)];
      var $66=$65 | 2048;
      HEAP32[(($64)>>2)]=$66;
      var $67=$1;
      var $68=(($67+292)|0);
      var $69=(($68+2)|0);
      var $70=HEAP16[(($69)>>1)];
      var $71=$1;
      var $72=(($71+292)|0);
      var $73=(($72+8)|0);
      HEAP16[(($73)>>1)]=$70;
      __label__ = 11; break;
    case 11: 
      __label__ = 12; break;
    case 12: 
      var $76=$1;
      var $77=(($76+92)|0);
      var $78=HEAP32[(($77)>>2)];
      var $79=$78 & 256;
      var $80=(($79)|0)!=0;
      if ($80) { __label__ = 13; break; } else { __label__ = 40; break; }
    case 13: 
      var $82=$1;
      var $83=(($82+92)|0);
      var $84=HEAP32[(($83)>>2)];
      var $85=$84 & 4096;
      var $86=(($85)|0)!=0;
      if ($86) { __label__ = 14; break; } else { __label__ = 40; break; }
    case 14: 
      var $88=$color_type;
      var $89=$88 & 2;
      var $90=(($89)|0)!=0;
      if ($90) { __label__ = 28; break; } else { __label__ = 15; break; }
    case 15: 
      var $92=$1;
      var $93=(($92+275)|0);
      var $94=HEAPU8[($93)];
      var $95=(($94)&255);
      if ((($95)|0) == 1) {
        __label__ = 16; break;
      }
      else if ((($95)|0) == 2) {
        __label__ = 19; break;
      }
      else if ((($95)|0) == 4) {
        __label__ = 22; break;
      }
      else if ((($95)|0) == 8 || (($95)|0) == 16) {
        __label__ = 26; break;
      }
      else {
      __label__ = 25; break;
      }
      
    case 16: 
      var $97=$1;
      var $98=(($97+292)|0);
      var $99=(($98+8)|0);
      var $100=HEAPU16[(($99)>>1)];
      var $101=(($100)&65535);
      var $102=((($101)*(255))|0);
      var $103=(($102) & 65535);
      HEAP16[(($99)>>1)]=$103;
      var $104=$1;
      var $105=(($104+292)|0);
      var $106=(($105+8)|0);
      var $107=HEAPU16[(($106)>>1)];
      var $108=$1;
      var $109=(($108+292)|0);
      var $110=(($109+6)|0);
      HEAP16[(($110)>>1)]=$107;
      var $111=$1;
      var $112=(($111+292)|0);
      var $113=(($112+4)|0);
      HEAP16[(($113)>>1)]=$107;
      var $114=$1;
      var $115=(($114+292)|0);
      var $116=(($115+2)|0);
      HEAP16[(($116)>>1)]=$107;
      var $117=$1;
      var $118=(($117+92)|0);
      var $119=HEAP32[(($118)>>2)];
      var $120=$119 & 33554432;
      var $121=(($120)|0)!=0;
      if ($121) { __label__ = 18; break; } else { __label__ = 17; break; }
    case 17: 
      var $123=$1;
      var $124=(($123+376)|0);
      var $125=(($124+8)|0);
      var $126=HEAPU16[(($125)>>1)];
      var $127=(($126)&65535);
      var $128=((($127)*(255))|0);
      var $129=(($128) & 65535);
      HEAP16[(($125)>>1)]=$129;
      var $130=$1;
      var $131=(($130+376)|0);
      var $132=(($131+8)|0);
      var $133=HEAPU16[(($132)>>1)];
      var $134=$1;
      var $135=(($134+376)|0);
      var $136=(($135+6)|0);
      HEAP16[(($136)>>1)]=$133;
      var $137=$1;
      var $138=(($137+376)|0);
      var $139=(($138+4)|0);
      HEAP16[(($139)>>1)]=$133;
      var $140=$1;
      var $141=(($140+376)|0);
      var $142=(($141+2)|0);
      HEAP16[(($142)>>1)]=$133;
      __label__ = 18; break;
    case 18: 
      __label__ = 27; break;
    case 19: 
      var $145=$1;
      var $146=(($145+292)|0);
      var $147=(($146+8)|0);
      var $148=HEAPU16[(($147)>>1)];
      var $149=(($148)&65535);
      var $150=((($149)*(85))|0);
      var $151=(($150) & 65535);
      HEAP16[(($147)>>1)]=$151;
      var $152=$1;
      var $153=(($152+292)|0);
      var $154=(($153+8)|0);
      var $155=HEAPU16[(($154)>>1)];
      var $156=$1;
      var $157=(($156+292)|0);
      var $158=(($157+6)|0);
      HEAP16[(($158)>>1)]=$155;
      var $159=$1;
      var $160=(($159+292)|0);
      var $161=(($160+4)|0);
      HEAP16[(($161)>>1)]=$155;
      var $162=$1;
      var $163=(($162+292)|0);
      var $164=(($163+2)|0);
      HEAP16[(($164)>>1)]=$155;
      var $165=$1;
      var $166=(($165+92)|0);
      var $167=HEAP32[(($166)>>2)];
      var $168=$167 & 33554432;
      var $169=(($168)|0)!=0;
      if ($169) { __label__ = 21; break; } else { __label__ = 20; break; }
    case 20: 
      var $171=$1;
      var $172=(($171+376)|0);
      var $173=(($172+8)|0);
      var $174=HEAPU16[(($173)>>1)];
      var $175=(($174)&65535);
      var $176=((($175)*(85))|0);
      var $177=(($176) & 65535);
      HEAP16[(($173)>>1)]=$177;
      var $178=$1;
      var $179=(($178+376)|0);
      var $180=(($179+8)|0);
      var $181=HEAPU16[(($180)>>1)];
      var $182=$1;
      var $183=(($182+376)|0);
      var $184=(($183+6)|0);
      HEAP16[(($184)>>1)]=$181;
      var $185=$1;
      var $186=(($185+376)|0);
      var $187=(($186+4)|0);
      HEAP16[(($187)>>1)]=$181;
      var $188=$1;
      var $189=(($188+376)|0);
      var $190=(($189+2)|0);
      HEAP16[(($190)>>1)]=$181;
      __label__ = 21; break;
    case 21: 
      __label__ = 27; break;
    case 22: 
      var $193=$1;
      var $194=(($193+292)|0);
      var $195=(($194+8)|0);
      var $196=HEAPU16[(($195)>>1)];
      var $197=(($196)&65535);
      var $198=((($197)*(17))|0);
      var $199=(($198) & 65535);
      HEAP16[(($195)>>1)]=$199;
      var $200=$1;
      var $201=(($200+292)|0);
      var $202=(($201+8)|0);
      var $203=HEAPU16[(($202)>>1)];
      var $204=$1;
      var $205=(($204+292)|0);
      var $206=(($205+6)|0);
      HEAP16[(($206)>>1)]=$203;
      var $207=$1;
      var $208=(($207+292)|0);
      var $209=(($208+4)|0);
      HEAP16[(($209)>>1)]=$203;
      var $210=$1;
      var $211=(($210+292)|0);
      var $212=(($211+2)|0);
      HEAP16[(($212)>>1)]=$203;
      var $213=$1;
      var $214=(($213+92)|0);
      var $215=HEAP32[(($214)>>2)];
      var $216=$215 & 33554432;
      var $217=(($216)|0)!=0;
      if ($217) { __label__ = 24; break; } else { __label__ = 23; break; }
    case 23: 
      var $219=$1;
      var $220=(($219+376)|0);
      var $221=(($220+8)|0);
      var $222=HEAPU16[(($221)>>1)];
      var $223=(($222)&65535);
      var $224=((($223)*(17))|0);
      var $225=(($224) & 65535);
      HEAP16[(($221)>>1)]=$225;
      var $226=$1;
      var $227=(($226+376)|0);
      var $228=(($227+8)|0);
      var $229=HEAPU16[(($228)>>1)];
      var $230=$1;
      var $231=(($230+376)|0);
      var $232=(($231+6)|0);
      HEAP16[(($232)>>1)]=$229;
      var $233=$1;
      var $234=(($233+376)|0);
      var $235=(($234+4)|0);
      HEAP16[(($235)>>1)]=$229;
      var $236=$1;
      var $237=(($236+376)|0);
      var $238=(($237+2)|0);
      HEAP16[(($238)>>1)]=$229;
      __label__ = 24; break;
    case 24: 
      __label__ = 27; break;
    case 25: 
      __label__ = 26; break;
    case 26: 
      var $242=$1;
      var $243=(($242+292)|0);
      var $244=(($243+8)|0);
      var $245=HEAP16[(($244)>>1)];
      var $246=$1;
      var $247=(($246+292)|0);
      var $248=(($247+6)|0);
      HEAP16[(($248)>>1)]=$245;
      var $249=$1;
      var $250=(($249+292)|0);
      var $251=(($250+4)|0);
      HEAP16[(($251)>>1)]=$245;
      var $252=$1;
      var $253=(($252+292)|0);
      var $254=(($253+2)|0);
      HEAP16[(($254)>>1)]=$245;
      __label__ = 27; break;
    case 27: 
      __label__ = 39; break;
    case 28: 
      var $257=$color_type;
      var $258=(($257)|0)==3;
      if ($258) { __label__ = 29; break; } else { __label__ = 38; break; }
    case 29: 
      var $260=$1;
      var $261=(($260+292)|0);
      var $262=(($261)|0);
      var $263=HEAPU8[($262)];
      var $264=(($263)&255);
      var $265=$1;
      var $266=(($265+256)|0);
      var $267=HEAP32[(($266)>>2)];
      var $268=(($267+($264)*(3))|0);
      var $269=(($268)|0);
      var $270=HEAPU8[($269)];
      var $271=(($270)&255);
      var $272=$1;
      var $273=(($272+292)|0);
      var $274=(($273+2)|0);
      HEAP16[(($274)>>1)]=$271;
      var $275=$1;
      var $276=(($275+292)|0);
      var $277=(($276)|0);
      var $278=HEAPU8[($277)];
      var $279=(($278)&255);
      var $280=$1;
      var $281=(($280+256)|0);
      var $282=HEAP32[(($281)>>2)];
      var $283=(($282+($279)*(3))|0);
      var $284=(($283+1)|0);
      var $285=HEAPU8[($284)];
      var $286=(($285)&255);
      var $287=$1;
      var $288=(($287+292)|0);
      var $289=(($288+4)|0);
      HEAP16[(($289)>>1)]=$286;
      var $290=$1;
      var $291=(($290+292)|0);
      var $292=(($291)|0);
      var $293=HEAPU8[($292)];
      var $294=(($293)&255);
      var $295=$1;
      var $296=(($295+256)|0);
      var $297=HEAP32[(($296)>>2)];
      var $298=(($297+($294)*(3))|0);
      var $299=(($298+2)|0);
      var $300=HEAPU8[($299)];
      var $301=(($300)&255);
      var $302=$1;
      var $303=(($302+292)|0);
      var $304=(($303+6)|0);
      HEAP16[(($304)>>1)]=$301;
      var $305=$1;
      var $306=(($305+92)|0);
      var $307=HEAP32[(($306)>>2)];
      var $308=$307 & 524288;
      var $309=(($308)|0)!=0;
      if ($309) { __label__ = 30; break; } else { __label__ = 37; break; }
    case 30: 
      var $311=$1;
      var $312=(($311+92)|0);
      var $313=HEAP32[(($312)>>2)];
      var $314=$313 & 33554432;
      var $315=(($314)|0)!=0;
      if ($315) { __label__ = 36; break; } else { __label__ = 31; break; }
    case 31: 
      var $317=$1;
      var $318=(($317+262)|0);
      var $319=HEAPU16[(($318)>>1)];
      var $320=(($319)&65535);
      $istop=$320;
      $i=0;
      __label__ = 32; break;
    case 32: 
      var $322=$i;
      var $323=$istop;
      var $324=(($322)|0) < (($323)|0);
      if ($324) { __label__ = 33; break; } else { __label__ = 35; break; }
    case 33: 
      var $326=$i;
      var $327=$1;
      var $328=(($327+372)|0);
      var $329=HEAP32[(($328)>>2)];
      var $330=(($329+$326)|0);
      var $331=HEAPU8[($330)];
      var $332=(($331)&255);
      var $333=(((255)-($332))|0);
      var $334=(($333) & 255);
      var $335=$i;
      var $336=$1;
      var $337=(($336+372)|0);
      var $338=HEAP32[(($337)>>2)];
      var $339=(($338+$335)|0);
      HEAP8[($339)]=$334;
      __label__ = 34; break;
    case 34: 
      var $341=$i;
      var $342=((($341)+(1))|0);
      $i=$342;
      __label__ = 32; break;
    case 35: 
      __label__ = 36; break;
    case 36: 
      __label__ = 37; break;
    case 37: 
      __label__ = 38; break;
    case 38: 
      __label__ = 39; break;
    case 39: 
      __label__ = 40; break;
    case 40: 
      var $349=$1;
      var $350=(($349+302)|0);
      var $351=$1;
      var $352=(($351+292)|0);
      var $353=$350;
      var $354=$352;
      assert(10 % 1 === 0, 'memcpy given ' + 10 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP16[(($353)>>1)]=HEAP16[(($354)>>1)];HEAP16[((($353)+(2))>>1)]=HEAP16[((($354)+(2))>>1)];HEAP16[((($353)+(4))>>1)]=HEAP16[((($354)+(4))>>1)];HEAP16[((($353)+(6))>>1)]=HEAP16[((($354)+(6))>>1)];HEAP16[((($353)+(8))>>1)]=HEAP16[((($354)+(8))>>1)];
      var $355=$color_type;
      var $356=(($355)|0)==3;
      if ($356) { __label__ = 41; break; } else { __label__ = 53; break; }
    case 41: 
      var $358=$1;
      var $359=(($358+262)|0);
      var $360=HEAPU16[(($359)>>1)];
      var $361=(($360)&65535);
      var $362=(($361)|0)!=0;
      if ($362) { __label__ = 42; break; } else { __label__ = 53; break; }
    case 42: 
      var $364=$1;
      var $365=(($364+332)|0);
      var $366=HEAPF32[(($365)>>2)];
      var $367=$1;
      var $368=(($367+328)|0);
      var $369=HEAPF32[(($368)>>2)];
      var $370=($366)*($369);
      var $371=$370;
      var $372=($371)-(1);
      var $373=_fabs($372);
      var $374=$373 < 0.05;
      if ($374) { __label__ = 43; break; } else { __label__ = 53; break; }
    case 43: 
      $k=0;
      $i1=0;
      __label__ = 44; break;
    case 44: 
      var $377=$i1;
      var $378=$1;
      var $379=(($378+262)|0);
      var $380=HEAPU16[(($379)>>1)];
      var $381=(($380)&65535);
      var $382=(($377)|0) < (($381)|0);
      if ($382) { __label__ = 45; break; } else { __label__ = 50; break; }
    case 45: 
      var $384=$i1;
      var $385=$1;
      var $386=(($385+372)|0);
      var $387=HEAP32[(($386)>>2)];
      var $388=(($387+$384)|0);
      var $389=HEAPU8[($388)];
      var $390=(($389)&255);
      var $391=(($390)|0)!=0;
      if ($391) { __label__ = 46; break; } else { __label__ = 48; break; }
    case 46: 
      var $393=$i1;
      var $394=$1;
      var $395=(($394+372)|0);
      var $396=HEAP32[(($395)>>2)];
      var $397=(($396+$393)|0);
      var $398=HEAPU8[($397)];
      var $399=(($398)&255);
      var $400=(($399)|0)!=255;
      if ($400) { __label__ = 47; break; } else { __label__ = 48; break; }
    case 47: 
      $k=1;
      __label__ = 48; break;
    case 48: 
      __label__ = 49; break;
    case 49: 
      var $404=$i1;
      var $405=((($404)+(1))|0);
      $i1=$405;
      __label__ = 44; break;
    case 50: 
      var $407=$k;
      var $408=(($407)|0)==0;
      if ($408) { __label__ = 51; break; } else { __label__ = 52; break; }
    case 51: 
      var $410=$1;
      var $411=(($410+92)|0);
      var $412=HEAP32[(($411)>>2)];
      var $413=$412 & -8193;
      HEAP32[(($411)>>2)]=$413;
      __label__ = 52; break;
    case 52: 
      __label__ = 53; break;
    case 53: 
      var $416=$1;
      var $417=(($416+92)|0);
      var $418=HEAP32[(($417)>>2)];
      var $419=$418 & 6299648;
      var $420=(($419)|0)!=0;
      if ($420) { __label__ = 54; break; } else { __label__ = 100; break; }
    case 54: 
      var $422=$1;
      var $423=(($422+328)|0);
      var $424=HEAPF32[(($423)>>2)];
      var $425=$424;
      var $426=$425 != 0;
      if ($426) { __label__ = 55; break; } else { __label__ = 100; break; }
    case 55: 
      var $428=$1;
      var $429=$1;
      var $430=(($429+275)|0);
      var $431=HEAP8[($430)];
      _png_build_gamma_table($428, $431);
      var $432=$1;
      var $433=(($432+92)|0);
      var $434=HEAP32[(($433)>>2)];
      var $435=$434 & 128;
      var $436=(($435)|0)!=0;
      if ($436) { __label__ = 56; break; } else { __label__ = 92; break; }
    case 56: 
      var $438=$color_type;
      var $439=(($438)|0)==3;
      if ($439) { __label__ = 57; break; } else { __label__ = 80; break; }
    case 57: 
      var $441=$1;
      var $442=(($441+256)|0);
      var $443=HEAP32[(($442)>>2)];
      $palette=$443;
      var $444=$1;
      var $445=(($444+260)|0);
      var $446=HEAPU16[(($445)>>1)];
      var $447=(($446)&65535);
      $num_palette=$447;
      var $448=$1;
      var $449=(($448+284)|0);
      var $450=HEAPU8[($449)];
      var $451=(($450)&255);
      var $452=(($451)|0)==2;
      if ($452) { __label__ = 58; break; } else { __label__ = 59; break; }
    case 58: 
      var $454=$1;
      var $455=(($454+292)|0);
      var $456=(($455+2)|0);
      var $457=HEAPU16[(($456)>>1)];
      var $458=(($457)&65535);
      var $459=$1;
      var $460=(($459+336)|0);
      var $461=HEAP32[(($460)>>2)];
      var $462=(($461+$458)|0);
      var $463=HEAP8[($462)];
      var $464=(($back)|0);
      HEAP8[($464)]=$463;
      var $465=$1;
      var $466=(($465+292)|0);
      var $467=(($466+4)|0);
      var $468=HEAPU16[(($467)>>1)];
      var $469=(($468)&65535);
      var $470=$1;
      var $471=(($470+336)|0);
      var $472=HEAP32[(($471)>>2)];
      var $473=(($472+$469)|0);
      var $474=HEAP8[($473)];
      var $475=(($back+1)|0);
      HEAP8[($475)]=$474;
      var $476=$1;
      var $477=(($476+292)|0);
      var $478=(($477+6)|0);
      var $479=HEAPU16[(($478)>>1)];
      var $480=(($479)&65535);
      var $481=$1;
      var $482=(($481+336)|0);
      var $483=HEAP32[(($482)>>2)];
      var $484=(($483+$480)|0);
      var $485=HEAP8[($484)];
      var $486=(($back+2)|0);
      HEAP8[($486)]=$485;
      var $487=$1;
      var $488=(($487+292)|0);
      var $489=(($488+2)|0);
      var $490=HEAPU16[(($489)>>1)];
      var $491=(($490)&65535);
      var $492=$1;
      var $493=(($492+344)|0);
      var $494=HEAP32[(($493)>>2)];
      var $495=(($494+$491)|0);
      var $496=HEAP8[($495)];
      var $497=(($back_1)|0);
      HEAP8[($497)]=$496;
      var $498=$1;
      var $499=(($498+292)|0);
      var $500=(($499+4)|0);
      var $501=HEAPU16[(($500)>>1)];
      var $502=(($501)&65535);
      var $503=$1;
      var $504=(($503+344)|0);
      var $505=HEAP32[(($504)>>2)];
      var $506=(($505+$502)|0);
      var $507=HEAP8[($506)];
      var $508=(($back_1+1)|0);
      HEAP8[($508)]=$507;
      var $509=$1;
      var $510=(($509+292)|0);
      var $511=(($510+6)|0);
      var $512=HEAPU16[(($511)>>1)];
      var $513=(($512)&65535);
      var $514=$1;
      var $515=(($514+344)|0);
      var $516=HEAP32[(($515)>>2)];
      var $517=(($516+$513)|0);
      var $518=HEAP8[($517)];
      var $519=(($back_1+2)|0);
      HEAP8[($519)]=$518;
      __label__ = 68; break;
    case 59: 
      var $521=$1;
      var $522=(($521+284)|0);
      var $523=HEAPU8[($522)];
      var $524=(($523)&255);
      if ((($524)|0) == 1) {
        __label__ = 60; break;
      }
      else if ((($524)|0) == 2) {
        __label__ = 61; break;
      }
      else if ((($524)|0) == 3) {
        __label__ = 62; break;
      }
      else {
      __label__ = 63; break;
      }
      
    case 60: 
      var $526=$1;
      var $527=(($526+332)|0);
      var $528=HEAPF32[(($527)>>2)];
      var $529=$528;
      $g=$529;
      $gs=1;
      __label__ = 64; break;
    case 61: 
      var $531=$1;
      var $532=(($531+328)|0);
      var $533=HEAPF32[(($532)>>2)];
      var $534=$533;
      var $535=(1)/($534);
      $g=$535;
      var $536=$1;
      var $537=(($536+328)|0);
      var $538=HEAPF32[(($537)>>2)];
      var $539=$1;
      var $540=(($539+332)|0);
      var $541=HEAPF32[(($540)>>2)];
      var $542=($538)*($541);
      var $543=$542;
      var $544=(1)/($543);
      $gs=$544;
      __label__ = 64; break;
    case 62: 
      var $546=$1;
      var $547=(($546+288)|0);
      var $548=HEAPF32[(($547)>>2)];
      var $549=$548;
      var $550=(1)/($549);
      $g=$550;
      var $551=$1;
      var $552=(($551+288)|0);
      var $553=HEAPF32[(($552)>>2)];
      var $554=$1;
      var $555=(($554+332)|0);
      var $556=HEAPF32[(($555)>>2)];
      var $557=($553)*($556);
      var $558=$557;
      var $559=(1)/($558);
      $gs=$559;
      __label__ = 64; break;
    case 63: 
      $g=1;
      $gs=1;
      __label__ = 64; break;
    case 64: 
      var $562=$gs;
      var $563=($562)-(1);
      var $564=_fabs($563);
      var $565=$564 < 0.05;
      if ($565) { __label__ = 65; break; } else { __label__ = 66; break; }
    case 65: 
      var $567=$1;
      var $568=(($567+292)|0);
      var $569=(($568+2)|0);
      var $570=HEAP16[(($569)>>1)];
      var $571=(($570) & 255);
      var $572=(($back)|0);
      HEAP8[($572)]=$571;
      var $573=$1;
      var $574=(($573+292)|0);
      var $575=(($574+4)|0);
      var $576=HEAP16[(($575)>>1)];
      var $577=(($576) & 255);
      var $578=(($back+1)|0);
      HEAP8[($578)]=$577;
      var $579=$1;
      var $580=(($579+292)|0);
      var $581=(($580+6)|0);
      var $582=HEAP16[(($581)>>1)];
      var $583=(($582) & 255);
      var $584=(($back+2)|0);
      HEAP8[($584)]=$583;
      __label__ = 67; break;
    case 66: 
      var $586=$1;
      var $587=(($586+292)|0);
      var $588=(($587+2)|0);
      var $589=HEAPU16[(($588)>>1)];
      var $590=(($589)&65535);
      var $591=($590)/(255);
      var $592=$gs;
      var $593=_llvm_pow_f64($591, $592);
      var $594=($593)*(255);
      var $595=($594)+(0.5);
      var $596=($595 >= 0 ? Math.floor($595) : Math.ceil($595));
      var $597=(($back)|0);
      HEAP8[($597)]=$596;
      var $598=$1;
      var $599=(($598+292)|0);
      var $600=(($599+4)|0);
      var $601=HEAPU16[(($600)>>1)];
      var $602=(($601)&65535);
      var $603=($602)/(255);
      var $604=$gs;
      var $605=_llvm_pow_f64($603, $604);
      var $606=($605)*(255);
      var $607=($606)+(0.5);
      var $608=($607 >= 0 ? Math.floor($607) : Math.ceil($607));
      var $609=(($back+1)|0);
      HEAP8[($609)]=$608;
      var $610=$1;
      var $611=(($610+292)|0);
      var $612=(($611+6)|0);
      var $613=HEAPU16[(($612)>>1)];
      var $614=(($613)&65535);
      var $615=($614)/(255);
      var $616=$gs;
      var $617=_llvm_pow_f64($615, $616);
      var $618=($617)*(255);
      var $619=($618)+(0.5);
      var $620=($619 >= 0 ? Math.floor($619) : Math.ceil($619));
      var $621=(($back+2)|0);
      HEAP8[($621)]=$620;
      __label__ = 67; break;
    case 67: 
      var $623=$1;
      var $624=(($623+292)|0);
      var $625=(($624+2)|0);
      var $626=HEAPU16[(($625)>>1)];
      var $627=(($626)&65535);
      var $628=($627)/(255);
      var $629=$g;
      var $630=_llvm_pow_f64($628, $629);
      var $631=($630)*(255);
      var $632=($631)+(0.5);
      var $633=($632 >= 0 ? Math.floor($632) : Math.ceil($632));
      var $634=(($back_1)|0);
      HEAP8[($634)]=$633;
      var $635=$1;
      var $636=(($635+292)|0);
      var $637=(($636+4)|0);
      var $638=HEAPU16[(($637)>>1)];
      var $639=(($638)&65535);
      var $640=($639)/(255);
      var $641=$g;
      var $642=_llvm_pow_f64($640, $641);
      var $643=($642)*(255);
      var $644=($643)+(0.5);
      var $645=($644 >= 0 ? Math.floor($644) : Math.ceil($644));
      var $646=(($back_1+1)|0);
      HEAP8[($646)]=$645;
      var $647=$1;
      var $648=(($647+292)|0);
      var $649=(($648+6)|0);
      var $650=HEAPU16[(($649)>>1)];
      var $651=(($650)&65535);
      var $652=($651)/(255);
      var $653=$g;
      var $654=_llvm_pow_f64($652, $653);
      var $655=($654)*(255);
      var $656=($655)+(0.5);
      var $657=($656 >= 0 ? Math.floor($656) : Math.ceil($656));
      var $658=(($back_1+2)|0);
      HEAP8[($658)]=$657;
      __label__ = 68; break;
    case 68: 
      $i2=0;
      __label__ = 69; break;
    case 69: 
      var $661=$i2;
      var $662=$num_palette;
      var $663=(($661)|0) < (($662)|0);
      if ($663) { __label__ = 70; break; } else { __label__ = 79; break; }
    case 70: 
      var $665=$i2;
      var $666=$1;
      var $667=(($666+262)|0);
      var $668=HEAPU16[(($667)>>1)];
      var $669=(($668)&65535);
      var $670=(($665)|0) < (($669)|0);
      if ($670) { __label__ = 71; break; } else { __label__ = 76; break; }
    case 71: 
      var $672=$i2;
      var $673=$1;
      var $674=(($673+372)|0);
      var $675=HEAP32[(($674)>>2)];
      var $676=(($675+$672)|0);
      var $677=HEAPU8[($676)];
      var $678=(($677)&255);
      var $679=(($678)|0)!=255;
      if ($679) { __label__ = 72; break; } else { __label__ = 76; break; }
    case 72: 
      var $681=$i2;
      var $682=$1;
      var $683=(($682+372)|0);
      var $684=HEAP32[(($683)>>2)];
      var $685=(($684+$681)|0);
      var $686=HEAPU8[($685)];
      var $687=(($686)&255);
      var $688=(($687)|0)==0;
      if ($688) { __label__ = 73; break; } else { __label__ = 74; break; }
    case 73: 
      var $690=$i2;
      var $691=$palette;
      var $692=(($691+($690)*(3))|0);
      var $693=$692;
      var $694=$back;
      assert(3 % 1 === 0, 'memcpy given ' + 3 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP8[($693)]=HEAP8[($694)];HEAP8[(($693)+(1))]=HEAP8[(($694)+(1))];HEAP8[(($693)+(2))]=HEAP8[(($694)+(2))];
      __label__ = 75; break;
    case 74: 
      var $696=$i2;
      var $697=$palette;
      var $698=(($697+($696)*(3))|0);
      var $699=(($698)|0);
      var $700=HEAPU8[($699)];
      var $701=(($700)&255);
      var $702=$1;
      var $703=(($702+344)|0);
      var $704=HEAP32[(($703)>>2)];
      var $705=(($704+$701)|0);
      var $706=HEAP8[($705)];
      $v=$706;
      var $707=$v;
      var $708=(($707)&255);
      var $709=(($708)&65535);
      var $710=$i2;
      var $711=$1;
      var $712=(($711+372)|0);
      var $713=HEAP32[(($712)>>2)];
      var $714=(($713+$710)|0);
      var $715=HEAPU8[($714)];
      var $716=(($715)&255);
      var $717=(($716)&65535);
      var $718=((($709)*($717))|0);
      var $719=(($back_1)|0);
      var $720=HEAPU8[($719)];
      var $721=(($720)&255);
      var $722=(($721)&65535);
      var $723=$i2;
      var $724=$1;
      var $725=(($724+372)|0);
      var $726=HEAP32[(($725)>>2)];
      var $727=(($726+$723)|0);
      var $728=HEAPU8[($727)];
      var $729=(($728)&255);
      var $730=(($729)&65535);
      var $731=(((255)-($730))|0);
      var $732=(($731) & 65535);
      var $733=(($732)&65535);
      var $734=((($722)*($733))|0);
      var $735=((($718)+($734))|0);
      var $736=((($735)+(128))|0);
      var $737=(($736) & 65535);
      $temp=$737;
      var $738=$temp;
      var $739=(($738)&65535);
      var $740=$temp;
      var $741=(($740)&65535);
      var $742=$741 >> 8;
      var $743=((($739)+($742))|0);
      var $744=$743 >> 8;
      var $745=(($744) & 255);
      $w=$745;
      var $746=$w;
      var $747=(($746)&255);
      var $748=$1;
      var $749=(($748+340)|0);
      var $750=HEAP32[(($749)>>2)];
      var $751=(($750+$747)|0);
      var $752=HEAP8[($751)];
      var $753=$i2;
      var $754=$palette;
      var $755=(($754+($753)*(3))|0);
      var $756=(($755)|0);
      HEAP8[($756)]=$752;
      var $757=$i2;
      var $758=$palette;
      var $759=(($758+($757)*(3))|0);
      var $760=(($759+1)|0);
      var $761=HEAPU8[($760)];
      var $762=(($761)&255);
      var $763=$1;
      var $764=(($763+344)|0);
      var $765=HEAP32[(($764)>>2)];
      var $766=(($765+$762)|0);
      var $767=HEAP8[($766)];
      $v=$767;
      var $768=$v;
      var $769=(($768)&255);
      var $770=(($769)&65535);
      var $771=$i2;
      var $772=$1;
      var $773=(($772+372)|0);
      var $774=HEAP32[(($773)>>2)];
      var $775=(($774+$771)|0);
      var $776=HEAPU8[($775)];
      var $777=(($776)&255);
      var $778=(($777)&65535);
      var $779=((($770)*($778))|0);
      var $780=(($back_1+1)|0);
      var $781=HEAPU8[($780)];
      var $782=(($781)&255);
      var $783=(($782)&65535);
      var $784=$i2;
      var $785=$1;
      var $786=(($785+372)|0);
      var $787=HEAP32[(($786)>>2)];
      var $788=(($787+$784)|0);
      var $789=HEAPU8[($788)];
      var $790=(($789)&255);
      var $791=(($790)&65535);
      var $792=(((255)-($791))|0);
      var $793=(($792) & 65535);
      var $794=(($793)&65535);
      var $795=((($783)*($794))|0);
      var $796=((($779)+($795))|0);
      var $797=((($796)+(128))|0);
      var $798=(($797) & 65535);
      $temp3=$798;
      var $799=$temp3;
      var $800=(($799)&65535);
      var $801=$temp3;
      var $802=(($801)&65535);
      var $803=$802 >> 8;
      var $804=((($800)+($803))|0);
      var $805=$804 >> 8;
      var $806=(($805) & 255);
      $w=$806;
      var $807=$w;
      var $808=(($807)&255);
      var $809=$1;
      var $810=(($809+340)|0);
      var $811=HEAP32[(($810)>>2)];
      var $812=(($811+$808)|0);
      var $813=HEAP8[($812)];
      var $814=$i2;
      var $815=$palette;
      var $816=(($815+($814)*(3))|0);
      var $817=(($816+1)|0);
      HEAP8[($817)]=$813;
      var $818=$i2;
      var $819=$palette;
      var $820=(($819+($818)*(3))|0);
      var $821=(($820+2)|0);
      var $822=HEAPU8[($821)];
      var $823=(($822)&255);
      var $824=$1;
      var $825=(($824+344)|0);
      var $826=HEAP32[(($825)>>2)];
      var $827=(($826+$823)|0);
      var $828=HEAP8[($827)];
      $v=$828;
      var $829=$v;
      var $830=(($829)&255);
      var $831=(($830)&65535);
      var $832=$i2;
      var $833=$1;
      var $834=(($833+372)|0);
      var $835=HEAP32[(($834)>>2)];
      var $836=(($835+$832)|0);
      var $837=HEAPU8[($836)];
      var $838=(($837)&255);
      var $839=(($838)&65535);
      var $840=((($831)*($839))|0);
      var $841=(($back_1+2)|0);
      var $842=HEAPU8[($841)];
      var $843=(($842)&255);
      var $844=(($843)&65535);
      var $845=$i2;
      var $846=$1;
      var $847=(($846+372)|0);
      var $848=HEAP32[(($847)>>2)];
      var $849=(($848+$845)|0);
      var $850=HEAPU8[($849)];
      var $851=(($850)&255);
      var $852=(($851)&65535);
      var $853=(((255)-($852))|0);
      var $854=(($853) & 65535);
      var $855=(($854)&65535);
      var $856=((($844)*($855))|0);
      var $857=((($840)+($856))|0);
      var $858=((($857)+(128))|0);
      var $859=(($858) & 65535);
      $temp4=$859;
      var $860=$temp4;
      var $861=(($860)&65535);
      var $862=$temp4;
      var $863=(($862)&65535);
      var $864=$863 >> 8;
      var $865=((($861)+($864))|0);
      var $866=$865 >> 8;
      var $867=(($866) & 255);
      $w=$867;
      var $868=$w;
      var $869=(($868)&255);
      var $870=$1;
      var $871=(($870+340)|0);
      var $872=HEAP32[(($871)>>2)];
      var $873=(($872+$869)|0);
      var $874=HEAP8[($873)];
      var $875=$i2;
      var $876=$palette;
      var $877=(($876+($875)*(3))|0);
      var $878=(($877+2)|0);
      HEAP8[($878)]=$874;
      __label__ = 75; break;
    case 75: 
      __label__ = 77; break;
    case 76: 
      var $881=$i2;
      var $882=$palette;
      var $883=(($882+($881)*(3))|0);
      var $884=(($883)|0);
      var $885=HEAPU8[($884)];
      var $886=(($885)&255);
      var $887=$1;
      var $888=(($887+336)|0);
      var $889=HEAP32[(($888)>>2)];
      var $890=(($889+$886)|0);
      var $891=HEAP8[($890)];
      var $892=$i2;
      var $893=$palette;
      var $894=(($893+($892)*(3))|0);
      var $895=(($894)|0);
      HEAP8[($895)]=$891;
      var $896=$i2;
      var $897=$palette;
      var $898=(($897+($896)*(3))|0);
      var $899=(($898+1)|0);
      var $900=HEAPU8[($899)];
      var $901=(($900)&255);
      var $902=$1;
      var $903=(($902+336)|0);
      var $904=HEAP32[(($903)>>2)];
      var $905=(($904+$901)|0);
      var $906=HEAP8[($905)];
      var $907=$i2;
      var $908=$palette;
      var $909=(($908+($907)*(3))|0);
      var $910=(($909+1)|0);
      HEAP8[($910)]=$906;
      var $911=$i2;
      var $912=$palette;
      var $913=(($912+($911)*(3))|0);
      var $914=(($913+2)|0);
      var $915=HEAPU8[($914)];
      var $916=(($915)&255);
      var $917=$1;
      var $918=(($917+336)|0);
      var $919=HEAP32[(($918)>>2)];
      var $920=(($919+$916)|0);
      var $921=HEAP8[($920)];
      var $922=$i2;
      var $923=$palette;
      var $924=(($923+($922)*(3))|0);
      var $925=(($924+2)|0);
      HEAP8[($925)]=$921;
      __label__ = 77; break;
    case 77: 
      __label__ = 78; break;
    case 78: 
      var $928=$i2;
      var $929=((($928)+(1))|0);
      $i2=$929;
      __label__ = 69; break;
    case 79: 
      var $931=$1;
      var $932=(($931+92)|0);
      var $933=HEAP32[(($932)>>2)];
      var $934=$933 & -129;
      HEAP32[(($932)>>2)]=$934;
      var $935=$1;
      var $936=(($935+92)|0);
      var $937=HEAP32[(($936)>>2)];
      var $938=$937 & -8193;
      HEAP32[(($936)>>2)]=$938;
      var $939=$1;
      var $940=(($939+88)|0);
      var $941=HEAP32[(($940)>>2)];
      var $942=$941 | 4194304;
      HEAP32[(($940)>>2)]=$942;
      __label__ = 91; break;
    case 80: 
      var $944=$1;
      var $945=(($944+275)|0);
      var $946=HEAPU8[($945)];
      var $947=(($946)&255);
      var $948=1 << $947;
      var $949=((($948)-(1))|0);
      var $950=(($949)>>>0);
      $m=$950;
      $g5=1;
      $gs6=1;
      var $951=$1;
      var $952=(($951+284)|0);
      var $953=HEAPU8[($952)];
      var $954=(($953)&255);
      if ((($954)|0) == 1) {
        __label__ = 81; break;
      }
      else if ((($954)|0) == 2) {
        __label__ = 82; break;
      }
      else if ((($954)|0) == 3) {
        __label__ = 83; break;
      }
      else {
      __label__ = 84; break;
      }
      
    case 81: 
      var $956=$1;
      var $957=(($956+332)|0);
      var $958=HEAPF32[(($957)>>2)];
      var $959=$958;
      $g5=$959;
      $gs6=1;
      __label__ = 85; break;
    case 82: 
      var $961=$1;
      var $962=(($961+328)|0);
      var $963=HEAPF32[(($962)>>2)];
      var $964=$963;
      var $965=(1)/($964);
      $g5=$965;
      var $966=$1;
      var $967=(($966+328)|0);
      var $968=HEAPF32[(($967)>>2)];
      var $969=$1;
      var $970=(($969+332)|0);
      var $971=HEAPF32[(($970)>>2)];
      var $972=($968)*($971);
      var $973=$972;
      var $974=(1)/($973);
      $gs6=$974;
      __label__ = 85; break;
    case 83: 
      var $976=$1;
      var $977=(($976+288)|0);
      var $978=HEAPF32[(($977)>>2)];
      var $979=$978;
      var $980=(1)/($979);
      $g5=$980;
      var $981=$1;
      var $982=(($981+288)|0);
      var $983=HEAPF32[(($982)>>2)];
      var $984=$1;
      var $985=(($984+332)|0);
      var $986=HEAPF32[(($985)>>2)];
      var $987=($983)*($986);
      var $988=$987;
      var $989=(1)/($988);
      $gs6=$989;
      __label__ = 85; break;
    case 84: 
      var $991=$1;
      _png_error($991, ((STRING_TABLE.__str4174)|0));
      __label__ = 85; break;
    case 85: 
      var $993=$1;
      var $994=(($993+292)|0);
      var $995=(($994+8)|0);
      var $996=HEAPU16[(($995)>>1)];
      var $997=(($996)&65535);
      var $998=$m;
      var $999=($997)/($998);
      var $1000=$g5;
      var $1001=_llvm_pow_f64($999, $1000);
      var $1002=$m;
      var $1003=($1001)*($1002);
      var $1004=($1003)+(0.5);
      var $1005=($1004 >= 0 ? Math.floor($1004) : Math.ceil($1004));
      var $1006=$1;
      var $1007=(($1006+302)|0);
      var $1008=(($1007+8)|0);
      HEAP16[(($1008)>>1)]=$1005;
      var $1009=$1;
      var $1010=(($1009+292)|0);
      var $1011=(($1010+8)|0);
      var $1012=HEAPU16[(($1011)>>1)];
      var $1013=(($1012)&65535);
      var $1014=$m;
      var $1015=($1013)/($1014);
      var $1016=$gs6;
      var $1017=_llvm_pow_f64($1015, $1016);
      var $1018=$m;
      var $1019=($1017)*($1018);
      var $1020=($1019)+(0.5);
      var $1021=($1020 >= 0 ? Math.floor($1020) : Math.ceil($1020));
      var $1022=$1;
      var $1023=(($1022+292)|0);
      var $1024=(($1023+8)|0);
      HEAP16[(($1024)>>1)]=$1021;
      var $1025=$1;
      var $1026=(($1025+292)|0);
      var $1027=(($1026+2)|0);
      var $1028=HEAPU16[(($1027)>>1)];
      var $1029=(($1028)&65535);
      var $1030=$1;
      var $1031=(($1030+292)|0);
      var $1032=(($1031+4)|0);
      var $1033=HEAPU16[(($1032)>>1)];
      var $1034=(($1033)&65535);
      var $1035=(($1029)|0)!=(($1034)|0);
      if ($1035) { __label__ = 88; break; } else { __label__ = 86; break; }
    case 86: 
      var $1037=$1;
      var $1038=(($1037+292)|0);
      var $1039=(($1038+2)|0);
      var $1040=HEAPU16[(($1039)>>1)];
      var $1041=(($1040)&65535);
      var $1042=$1;
      var $1043=(($1042+292)|0);
      var $1044=(($1043+6)|0);
      var $1045=HEAPU16[(($1044)>>1)];
      var $1046=(($1045)&65535);
      var $1047=(($1041)|0)!=(($1046)|0);
      if ($1047) { __label__ = 88; break; } else { __label__ = 87; break; }
    case 87: 
      var $1049=$1;
      var $1050=(($1049+292)|0);
      var $1051=(($1050+2)|0);
      var $1052=HEAPU16[(($1051)>>1)];
      var $1053=(($1052)&65535);
      var $1054=$1;
      var $1055=(($1054+292)|0);
      var $1056=(($1055+8)|0);
      var $1057=HEAPU16[(($1056)>>1)];
      var $1058=(($1057)&65535);
      var $1059=(($1053)|0)!=(($1058)|0);
      if ($1059) { __label__ = 88; break; } else { __label__ = 89; break; }
    case 88: 
      var $1061=$1;
      var $1062=(($1061+292)|0);
      var $1063=(($1062+2)|0);
      var $1064=HEAPU16[(($1063)>>1)];
      var $1065=(($1064)&65535);
      var $1066=$m;
      var $1067=($1065)/($1066);
      var $1068=$g5;
      var $1069=_llvm_pow_f64($1067, $1068);
      var $1070=$m;
      var $1071=($1069)*($1070);
      var $1072=($1071)+(0.5);
      var $1073=($1072 >= 0 ? Math.floor($1072) : Math.ceil($1072));
      var $1074=$1;
      var $1075=(($1074+302)|0);
      var $1076=(($1075+2)|0);
      HEAP16[(($1076)>>1)]=$1073;
      var $1077=$1;
      var $1078=(($1077+292)|0);
      var $1079=(($1078+4)|0);
      var $1080=HEAPU16[(($1079)>>1)];
      var $1081=(($1080)&65535);
      var $1082=$m;
      var $1083=($1081)/($1082);
      var $1084=$g5;
      var $1085=_llvm_pow_f64($1083, $1084);
      var $1086=$m;
      var $1087=($1085)*($1086);
      var $1088=($1087)+(0.5);
      var $1089=($1088 >= 0 ? Math.floor($1088) : Math.ceil($1088));
      var $1090=$1;
      var $1091=(($1090+302)|0);
      var $1092=(($1091+4)|0);
      HEAP16[(($1092)>>1)]=$1089;
      var $1093=$1;
      var $1094=(($1093+292)|0);
      var $1095=(($1094+6)|0);
      var $1096=HEAPU16[(($1095)>>1)];
      var $1097=(($1096)&65535);
      var $1098=$m;
      var $1099=($1097)/($1098);
      var $1100=$g5;
      var $1101=_llvm_pow_f64($1099, $1100);
      var $1102=$m;
      var $1103=($1101)*($1102);
      var $1104=($1103)+(0.5);
      var $1105=($1104 >= 0 ? Math.floor($1104) : Math.ceil($1104));
      var $1106=$1;
      var $1107=(($1106+302)|0);
      var $1108=(($1107+6)|0);
      HEAP16[(($1108)>>1)]=$1105;
      var $1109=$1;
      var $1110=(($1109+292)|0);
      var $1111=(($1110+2)|0);
      var $1112=HEAPU16[(($1111)>>1)];
      var $1113=(($1112)&65535);
      var $1114=$m;
      var $1115=($1113)/($1114);
      var $1116=$gs6;
      var $1117=_llvm_pow_f64($1115, $1116);
      var $1118=$m;
      var $1119=($1117)*($1118);
      var $1120=($1119)+(0.5);
      var $1121=($1120 >= 0 ? Math.floor($1120) : Math.ceil($1120));
      var $1122=$1;
      var $1123=(($1122+292)|0);
      var $1124=(($1123+2)|0);
      HEAP16[(($1124)>>1)]=$1121;
      var $1125=$1;
      var $1126=(($1125+292)|0);
      var $1127=(($1126+4)|0);
      var $1128=HEAPU16[(($1127)>>1)];
      var $1129=(($1128)&65535);
      var $1130=$m;
      var $1131=($1129)/($1130);
      var $1132=$gs6;
      var $1133=_llvm_pow_f64($1131, $1132);
      var $1134=$m;
      var $1135=($1133)*($1134);
      var $1136=($1135)+(0.5);
      var $1137=($1136 >= 0 ? Math.floor($1136) : Math.ceil($1136));
      var $1138=$1;
      var $1139=(($1138+292)|0);
      var $1140=(($1139+4)|0);
      HEAP16[(($1140)>>1)]=$1137;
      var $1141=$1;
      var $1142=(($1141+292)|0);
      var $1143=(($1142+6)|0);
      var $1144=HEAPU16[(($1143)>>1)];
      var $1145=(($1144)&65535);
      var $1146=$m;
      var $1147=($1145)/($1146);
      var $1148=$gs6;
      var $1149=_llvm_pow_f64($1147, $1148);
      var $1150=$m;
      var $1151=($1149)*($1150);
      var $1152=($1151)+(0.5);
      var $1153=($1152 >= 0 ? Math.floor($1152) : Math.ceil($1152));
      var $1154=$1;
      var $1155=(($1154+292)|0);
      var $1156=(($1155+6)|0);
      HEAP16[(($1156)>>1)]=$1153;
      __label__ = 90; break;
    case 89: 
      var $1158=$1;
      var $1159=(($1158+302)|0);
      var $1160=(($1159+8)|0);
      var $1161=HEAP16[(($1160)>>1)];
      var $1162=$1;
      var $1163=(($1162+302)|0);
      var $1164=(($1163+6)|0);
      HEAP16[(($1164)>>1)]=$1161;
      var $1165=$1;
      var $1166=(($1165+302)|0);
      var $1167=(($1166+4)|0);
      HEAP16[(($1167)>>1)]=$1161;
      var $1168=$1;
      var $1169=(($1168+302)|0);
      var $1170=(($1169+2)|0);
      HEAP16[(($1170)>>1)]=$1161;
      var $1171=$1;
      var $1172=(($1171+292)|0);
      var $1173=(($1172+8)|0);
      var $1174=HEAP16[(($1173)>>1)];
      var $1175=$1;
      var $1176=(($1175+292)|0);
      var $1177=(($1176+6)|0);
      HEAP16[(($1177)>>1)]=$1174;
      var $1178=$1;
      var $1179=(($1178+292)|0);
      var $1180=(($1179+4)|0);
      HEAP16[(($1180)>>1)]=$1174;
      var $1181=$1;
      var $1182=(($1181+292)|0);
      var $1183=(($1182+2)|0);
      HEAP16[(($1183)>>1)]=$1174;
      __label__ = 90; break;
    case 90: 
      __label__ = 91; break;
    case 91: 
      __label__ = 99; break;
    case 92: 
      var $1187=$color_type;
      var $1188=(($1187)|0)==3;
      if ($1188) { __label__ = 93; break; } else { __label__ = 98; break; }
    case 93: 
      var $1190=$1;
      var $1191=(($1190+256)|0);
      var $1192=HEAP32[(($1191)>>2)];
      $palette7=$1192;
      var $1193=$1;
      var $1194=(($1193+260)|0);
      var $1195=HEAPU16[(($1194)>>1)];
      var $1196=(($1195)&65535);
      $num_palette8=$1196;
      $i9=0;
      __label__ = 94; break;
    case 94: 
      var $1198=$i9;
      var $1199=$num_palette8;
      var $1200=(($1198)|0) < (($1199)|0);
      if ($1200) { __label__ = 95; break; } else { __label__ = 97; break; }
    case 95: 
      var $1202=$i9;
      var $1203=$palette7;
      var $1204=(($1203+($1202)*(3))|0);
      var $1205=(($1204)|0);
      var $1206=HEAPU8[($1205)];
      var $1207=(($1206)&255);
      var $1208=$1;
      var $1209=(($1208+336)|0);
      var $1210=HEAP32[(($1209)>>2)];
      var $1211=(($1210+$1207)|0);
      var $1212=HEAP8[($1211)];
      var $1213=$i9;
      var $1214=$palette7;
      var $1215=(($1214+($1213)*(3))|0);
      var $1216=(($1215)|0);
      HEAP8[($1216)]=$1212;
      var $1217=$i9;
      var $1218=$palette7;
      var $1219=(($1218+($1217)*(3))|0);
      var $1220=(($1219+1)|0);
      var $1221=HEAPU8[($1220)];
      var $1222=(($1221)&255);
      var $1223=$1;
      var $1224=(($1223+336)|0);
      var $1225=HEAP32[(($1224)>>2)];
      var $1226=(($1225+$1222)|0);
      var $1227=HEAP8[($1226)];
      var $1228=$i9;
      var $1229=$palette7;
      var $1230=(($1229+($1228)*(3))|0);
      var $1231=(($1230+1)|0);
      HEAP8[($1231)]=$1227;
      var $1232=$i9;
      var $1233=$palette7;
      var $1234=(($1233+($1232)*(3))|0);
      var $1235=(($1234+2)|0);
      var $1236=HEAPU8[($1235)];
      var $1237=(($1236)&255);
      var $1238=$1;
      var $1239=(($1238+336)|0);
      var $1240=HEAP32[(($1239)>>2)];
      var $1241=(($1240+$1237)|0);
      var $1242=HEAP8[($1241)];
      var $1243=$i9;
      var $1244=$palette7;
      var $1245=(($1244+($1243)*(3))|0);
      var $1246=(($1245+2)|0);
      HEAP8[($1246)]=$1242;
      __label__ = 96; break;
    case 96: 
      var $1248=$i9;
      var $1249=((($1248)+(1))|0);
      $i9=$1249;
      __label__ = 94; break;
    case 97: 
      var $1251=$1;
      var $1252=(($1251+92)|0);
      var $1253=HEAP32[(($1252)>>2)];
      var $1254=$1253 & -8193;
      HEAP32[(($1252)>>2)]=$1254;
      __label__ = 98; break;
    case 98: 
      __label__ = 99; break;
    case 99: 
      __label__ = 113; break;
    case 100: 
      var $1258=$1;
      var $1259=(($1258+92)|0);
      var $1260=HEAP32[(($1259)>>2)];
      var $1261=$1260 & 128;
      var $1262=(($1261)|0)!=0;
      if ($1262) { __label__ = 101; break; } else { __label__ = 112; break; }
    case 101: 
      var $1264=$color_type;
      var $1265=(($1264)|0)==3;
      if ($1265) { __label__ = 102; break; } else { __label__ = 112; break; }
    case 102: 
      var $1267=$1;
      var $1268=(($1267+262)|0);
      var $1269=HEAPU16[(($1268)>>1)];
      var $1270=(($1269)&65535);
      $istop11=$1270;
      var $1271=$1;
      var $1272=(($1271+256)|0);
      var $1273=HEAP32[(($1272)>>2)];
      $palette13=$1273;
      var $1274=$1;
      var $1275=(($1274+292)|0);
      var $1276=(($1275+2)|0);
      var $1277=HEAP16[(($1276)>>1)];
      var $1278=(($1277) & 255);
      var $1279=(($back12)|0);
      HEAP8[($1279)]=$1278;
      var $1280=$1;
      var $1281=(($1280+292)|0);
      var $1282=(($1281+4)|0);
      var $1283=HEAP16[(($1282)>>1)];
      var $1284=(($1283) & 255);
      var $1285=(($back12+1)|0);
      HEAP8[($1285)]=$1284;
      var $1286=$1;
      var $1287=(($1286+292)|0);
      var $1288=(($1287+6)|0);
      var $1289=HEAP16[(($1288)>>1)];
      var $1290=(($1289) & 255);
      var $1291=(($back12+2)|0);
      HEAP8[($1291)]=$1290;
      $i10=0;
      __label__ = 103; break;
    case 103: 
      var $1293=$i10;
      var $1294=$istop11;
      var $1295=(($1293)|0) < (($1294)|0);
      if ($1295) { __label__ = 104; break; } else { __label__ = 111; break; }
    case 104: 
      var $1297=$i10;
      var $1298=$1;
      var $1299=(($1298+372)|0);
      var $1300=HEAP32[(($1299)>>2)];
      var $1301=(($1300+$1297)|0);
      var $1302=HEAPU8[($1301)];
      var $1303=(($1302)&255);
      var $1304=(($1303)|0)==0;
      if ($1304) { __label__ = 105; break; } else { __label__ = 106; break; }
    case 105: 
      var $1306=$i10;
      var $1307=$palette13;
      var $1308=(($1307+($1306)*(3))|0);
      var $1309=$1308;
      var $1310=$back12;
      assert(3 % 1 === 0, 'memcpy given ' + 3 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP8[($1309)]=HEAP8[($1310)];HEAP8[(($1309)+(1))]=HEAP8[(($1310)+(1))];HEAP8[(($1309)+(2))]=HEAP8[(($1310)+(2))];
      __label__ = 109; break;
    case 106: 
      var $1312=$i10;
      var $1313=$1;
      var $1314=(($1313+372)|0);
      var $1315=HEAP32[(($1314)>>2)];
      var $1316=(($1315+$1312)|0);
      var $1317=HEAPU8[($1316)];
      var $1318=(($1317)&255);
      var $1319=(($1318)|0)!=255;
      if ($1319) { __label__ = 107; break; } else { __label__ = 108; break; }
    case 107: 
      var $1321=$i10;
      var $1322=$palette13;
      var $1323=(($1322+($1321)*(3))|0);
      var $1324=(($1323)|0);
      var $1325=HEAPU8[($1324)];
      var $1326=(($1325)&255);
      var $1327=(($1326)&65535);
      var $1328=$i10;
      var $1329=$1;
      var $1330=(($1329+372)|0);
      var $1331=HEAP32[(($1330)>>2)];
      var $1332=(($1331+$1328)|0);
      var $1333=HEAPU8[($1332)];
      var $1334=(($1333)&255);
      var $1335=(($1334)&65535);
      var $1336=((($1327)*($1335))|0);
      var $1337=(($back12)|0);
      var $1338=HEAPU8[($1337)];
      var $1339=(($1338)&255);
      var $1340=(($1339)&65535);
      var $1341=$i10;
      var $1342=$1;
      var $1343=(($1342+372)|0);
      var $1344=HEAP32[(($1343)>>2)];
      var $1345=(($1344+$1341)|0);
      var $1346=HEAPU8[($1345)];
      var $1347=(($1346)&255);
      var $1348=(($1347)&65535);
      var $1349=(((255)-($1348))|0);
      var $1350=(($1349) & 65535);
      var $1351=(($1350)&65535);
      var $1352=((($1340)*($1351))|0);
      var $1353=((($1336)+($1352))|0);
      var $1354=((($1353)+(128))|0);
      var $1355=(($1354) & 65535);
      $temp14=$1355;
      var $1356=$temp14;
      var $1357=(($1356)&65535);
      var $1358=$temp14;
      var $1359=(($1358)&65535);
      var $1360=$1359 >> 8;
      var $1361=((($1357)+($1360))|0);
      var $1362=$1361 >> 8;
      var $1363=(($1362) & 255);
      var $1364=$i10;
      var $1365=$palette13;
      var $1366=(($1365+($1364)*(3))|0);
      var $1367=(($1366)|0);
      HEAP8[($1367)]=$1363;
      var $1368=$i10;
      var $1369=$palette13;
      var $1370=(($1369+($1368)*(3))|0);
      var $1371=(($1370+1)|0);
      var $1372=HEAPU8[($1371)];
      var $1373=(($1372)&255);
      var $1374=(($1373)&65535);
      var $1375=$i10;
      var $1376=$1;
      var $1377=(($1376+372)|0);
      var $1378=HEAP32[(($1377)>>2)];
      var $1379=(($1378+$1375)|0);
      var $1380=HEAPU8[($1379)];
      var $1381=(($1380)&255);
      var $1382=(($1381)&65535);
      var $1383=((($1374)*($1382))|0);
      var $1384=(($back12+1)|0);
      var $1385=HEAPU8[($1384)];
      var $1386=(($1385)&255);
      var $1387=(($1386)&65535);
      var $1388=$i10;
      var $1389=$1;
      var $1390=(($1389+372)|0);
      var $1391=HEAP32[(($1390)>>2)];
      var $1392=(($1391+$1388)|0);
      var $1393=HEAPU8[($1392)];
      var $1394=(($1393)&255);
      var $1395=(($1394)&65535);
      var $1396=(((255)-($1395))|0);
      var $1397=(($1396) & 65535);
      var $1398=(($1397)&65535);
      var $1399=((($1387)*($1398))|0);
      var $1400=((($1383)+($1399))|0);
      var $1401=((($1400)+(128))|0);
      var $1402=(($1401) & 65535);
      $temp15=$1402;
      var $1403=$temp15;
      var $1404=(($1403)&65535);
      var $1405=$temp15;
      var $1406=(($1405)&65535);
      var $1407=$1406 >> 8;
      var $1408=((($1404)+($1407))|0);
      var $1409=$1408 >> 8;
      var $1410=(($1409) & 255);
      var $1411=$i10;
      var $1412=$palette13;
      var $1413=(($1412+($1411)*(3))|0);
      var $1414=(($1413+1)|0);
      HEAP8[($1414)]=$1410;
      var $1415=$i10;
      var $1416=$palette13;
      var $1417=(($1416+($1415)*(3))|0);
      var $1418=(($1417+2)|0);
      var $1419=HEAPU8[($1418)];
      var $1420=(($1419)&255);
      var $1421=(($1420)&65535);
      var $1422=$i10;
      var $1423=$1;
      var $1424=(($1423+372)|0);
      var $1425=HEAP32[(($1424)>>2)];
      var $1426=(($1425+$1422)|0);
      var $1427=HEAPU8[($1426)];
      var $1428=(($1427)&255);
      var $1429=(($1428)&65535);
      var $1430=((($1421)*($1429))|0);
      var $1431=(($back12+2)|0);
      var $1432=HEAPU8[($1431)];
      var $1433=(($1432)&255);
      var $1434=(($1433)&65535);
      var $1435=$i10;
      var $1436=$1;
      var $1437=(($1436+372)|0);
      var $1438=HEAP32[(($1437)>>2)];
      var $1439=(($1438+$1435)|0);
      var $1440=HEAPU8[($1439)];
      var $1441=(($1440)&255);
      var $1442=(($1441)&65535);
      var $1443=(((255)-($1442))|0);
      var $1444=(($1443) & 65535);
      var $1445=(($1444)&65535);
      var $1446=((($1434)*($1445))|0);
      var $1447=((($1430)+($1446))|0);
      var $1448=((($1447)+(128))|0);
      var $1449=(($1448) & 65535);
      $temp16=$1449;
      var $1450=$temp16;
      var $1451=(($1450)&65535);
      var $1452=$temp16;
      var $1453=(($1452)&65535);
      var $1454=$1453 >> 8;
      var $1455=((($1451)+($1454))|0);
      var $1456=$1455 >> 8;
      var $1457=(($1456) & 255);
      var $1458=$i10;
      var $1459=$palette13;
      var $1460=(($1459+($1458)*(3))|0);
      var $1461=(($1460+2)|0);
      HEAP8[($1461)]=$1457;
      __label__ = 108; break;
    case 108: 
      __label__ = 109; break;
    case 109: 
      __label__ = 110; break;
    case 110: 
      var $1465=$i10;
      var $1466=((($1465)+(1))|0);
      $i10=$1466;
      __label__ = 103; break;
    case 111: 
      var $1468=$1;
      var $1469=(($1468+92)|0);
      var $1470=HEAP32[(($1469)>>2)];
      var $1471=$1470 & -129;
      HEAP32[(($1469)>>2)]=$1471;
      var $1472=$1;
      var $1473=(($1472+88)|0);
      var $1474=HEAP32[(($1473)>>2)];
      var $1475=$1474 | 4194304;
      HEAP32[(($1473)>>2)]=$1475;
      __label__ = 112; break;
    case 112: 
      __label__ = 113; break;
    case 113: 
      var $1478=$1;
      var $1479=(($1478+92)|0);
      var $1480=HEAP32[(($1479)>>2)];
      var $1481=$1480 & 8;
      var $1482=(($1481)|0)!=0;
      if ($1482) { __label__ = 114; break; } else { __label__ = 130; break; }
    case 114: 
      var $1484=$1;
      var $1485=(($1484+92)|0);
      var $1486=HEAP32[(($1485)>>2)];
      var $1487=$1486 & 4096;
      var $1488=(($1487)|0)!=0;
      if ($1488) { __label__ = 130; break; } else { __label__ = 115; break; }
    case 115: 
      var $1490=$color_type;
      var $1491=(($1490)|0)==3;
      if ($1491) { __label__ = 116; break; } else { __label__ = 130; break; }
    case 116: 
      var $1493=$1;
      var $1494=(($1493+260)|0);
      var $1495=HEAP16[(($1494)>>1)];
      $istop18=$1495;
      var $1496=$1;
      var $1497=(($1496+360)|0);
      var $1498=(($1497)|0);
      var $1499=HEAPU8[($1498)];
      var $1500=(($1499)&255);
      var $1501=(((8)-($1500))|0);
      $sr=$1501;
      var $1502=$1;
      var $1503=(($1502+360)|0);
      var $1504=(($1503+1)|0);
      var $1505=HEAPU8[($1504)];
      var $1506=(($1505)&255);
      var $1507=(((8)-($1506))|0);
      $sg=$1507;
      var $1508=$1;
      var $1509=(($1508+360)|0);
      var $1510=(($1509+2)|0);
      var $1511=HEAPU8[($1510)];
      var $1512=(($1511)&255);
      var $1513=(((8)-($1512))|0);
      $sb=$1513;
      var $1514=$sr;
      var $1515=(($1514)|0) < 0;
      if ($1515) { __label__ = 118; break; } else { __label__ = 117; break; }
    case 117: 
      var $1517=$sr;
      var $1518=(($1517)|0) > 8;
      if ($1518) { __label__ = 118; break; } else { __label__ = 119; break; }
    case 118: 
      $sr=0;
      __label__ = 119; break;
    case 119: 
      var $1521=$sg;
      var $1522=(($1521)|0) < 0;
      if ($1522) { __label__ = 121; break; } else { __label__ = 120; break; }
    case 120: 
      var $1524=$sg;
      var $1525=(($1524)|0) > 8;
      if ($1525) { __label__ = 121; break; } else { __label__ = 122; break; }
    case 121: 
      $sg=0;
      __label__ = 122; break;
    case 122: 
      var $1528=$sb;
      var $1529=(($1528)|0) < 0;
      if ($1529) { __label__ = 124; break; } else { __label__ = 123; break; }
    case 123: 
      var $1531=$sb;
      var $1532=(($1531)|0) > 8;
      if ($1532) { __label__ = 124; break; } else { __label__ = 125; break; }
    case 124: 
      $sb=0;
      __label__ = 125; break;
    case 125: 
      $i17=0;
      __label__ = 126; break;
    case 126: 
      var $1536=$i17;
      var $1537=(($1536)&65535);
      var $1538=$istop18;
      var $1539=(($1538)&65535);
      var $1540=(($1537)|0) < (($1539)|0);
      if ($1540) { __label__ = 127; break; } else { __label__ = 129; break; }
    case 127: 
      var $1542=$sr;
      var $1543=$i17;
      var $1544=(($1543)&65535);
      var $1545=$1;
      var $1546=(($1545+256)|0);
      var $1547=HEAP32[(($1546)>>2)];
      var $1548=(($1547+($1544)*(3))|0);
      var $1549=(($1548)|0);
      var $1550=HEAPU8[($1549)];
      var $1551=(($1550)&255);
      var $1552=$1551 >> (($1542)|0);
      var $1553=(($1552) & 255);
      HEAP8[($1549)]=$1553;
      var $1554=$sg;
      var $1555=$i17;
      var $1556=(($1555)&65535);
      var $1557=$1;
      var $1558=(($1557+256)|0);
      var $1559=HEAP32[(($1558)>>2)];
      var $1560=(($1559+($1556)*(3))|0);
      var $1561=(($1560+1)|0);
      var $1562=HEAPU8[($1561)];
      var $1563=(($1562)&255);
      var $1564=$1563 >> (($1554)|0);
      var $1565=(($1564) & 255);
      HEAP8[($1561)]=$1565;
      var $1566=$sb;
      var $1567=$i17;
      var $1568=(($1567)&65535);
      var $1569=$1;
      var $1570=(($1569+256)|0);
      var $1571=HEAP32[(($1570)>>2)];
      var $1572=(($1571+($1568)*(3))|0);
      var $1573=(($1572+2)|0);
      var $1574=HEAPU8[($1573)];
      var $1575=(($1574)&255);
      var $1576=$1575 >> (($1566)|0);
      var $1577=(($1576) & 255);
      HEAP8[($1573)]=$1577;
      __label__ = 128; break;
    case 128: 
      var $1579=$i17;
      var $1580=((($1579)+(1))&65535);
      $i17=$1580;
      __label__ = 126; break;
    case 129: 
      var $1582=$1;
      var $1583=(($1582+92)|0);
      var $1584=HEAP32[(($1583)>>2)];
      var $1585=$1584 & -9;
      HEAP32[(($1583)>>2)]=$1585;
      __label__ = 130; break;
    case 130: 
      STACKTOP = __stackBase__;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_png_init_read_transformations["X"]=1;

function _png_build_gamma_table($png_ptr, $bit_depth) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $i;
      var $g;
      var $g1;
      var $i2;
      var $j;
      var $shift;
      var $num;
      var $sig_bit;
      var $ig;
      var $fin;
      var $fout;
      var $last;
      var $max;
      $1=$png_ptr;
      $2=$bit_depth;
      var $3=$2;
      var $4=(($3)&255);
      var $5=(($4)|0) <= 8;
      if ($5) { __label__ = 3; break; } else { __label__ = 24; break; }
    case 3: 
      var $7=$1;
      var $8=(($7+332)|0);
      var $9=HEAPF32[(($8)>>2)];
      var $10=$9;
      var $11=$10 > 0.000001;
      if ($11) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      var $13=$1;
      var $14=(($13+328)|0);
      var $15=HEAPF32[(($14)>>2)];
      var $16=$1;
      var $17=(($16+332)|0);
      var $18=HEAPF32[(($17)>>2)];
      var $19=($15)*($18);
      var $20=$19;
      var $21=(1)/($20);
      $g=$21;
      __label__ = 6; break;
    case 5: 
      $g=1;
      __label__ = 6; break;
    case 6: 
      var $24=$1;
      var $25=_png_malloc($24, 256);
      var $26=$1;
      var $27=(($26+336)|0);
      HEAP32[(($27)>>2)]=$25;
      $i=0;
      __label__ = 7; break;
    case 7: 
      var $29=$i;
      var $30=(($29)|0) < 256;
      if ($30) { __label__ = 8; break; } else { __label__ = 10; break; }
    case 8: 
      var $32=$i;
      var $33=(($32)|0);
      var $34=($33)/(255);
      var $35=$g;
      var $36=_llvm_pow_f64($34, $35);
      var $37=($36)*(255);
      var $38=($37)+(0.5);
      var $39=($38 >= 0 ? Math.floor($38) : Math.ceil($38));
      var $40=$i;
      var $41=$1;
      var $42=(($41+336)|0);
      var $43=HEAP32[(($42)>>2)];
      var $44=(($43+$40)|0);
      HEAP8[($44)]=$39;
      __label__ = 9; break;
    case 9: 
      var $46=$i;
      var $47=((($46)+(1))|0);
      $i=$47;
      __label__ = 7; break;
    case 10: 
      var $49=$1;
      var $50=(($49+92)|0);
      var $51=HEAP32[(($50)>>2)];
      var $52=$51 & 6291584;
      var $53=(($52)|0)!=0;
      if ($53) { __label__ = 11; break; } else { __label__ = 23; break; }
    case 11: 
      var $55=$1;
      var $56=(($55+328)|0);
      var $57=HEAPF32[(($56)>>2)];
      var $58=$57;
      var $59=(1)/($58);
      $g=$59;
      var $60=$1;
      var $61=_png_malloc($60, 256);
      var $62=$1;
      var $63=(($62+344)|0);
      HEAP32[(($63)>>2)]=$61;
      $i=0;
      __label__ = 12; break;
    case 12: 
      var $65=$i;
      var $66=(($65)|0) < 256;
      if ($66) { __label__ = 13; break; } else { __label__ = 15; break; }
    case 13: 
      var $68=$i;
      var $69=(($68)|0);
      var $70=($69)/(255);
      var $71=$g;
      var $72=_llvm_pow_f64($70, $71);
      var $73=($72)*(255);
      var $74=($73)+(0.5);
      var $75=($74 >= 0 ? Math.floor($74) : Math.ceil($74));
      var $76=$i;
      var $77=$1;
      var $78=(($77+344)|0);
      var $79=HEAP32[(($78)>>2)];
      var $80=(($79+$76)|0);
      HEAP8[($80)]=$75;
      __label__ = 14; break;
    case 14: 
      var $82=$i;
      var $83=((($82)+(1))|0);
      $i=$83;
      __label__ = 12; break;
    case 15: 
      var $85=$1;
      var $86=_png_malloc($85, 256);
      var $87=$1;
      var $88=(($87+340)|0);
      HEAP32[(($88)>>2)]=$86;
      var $89=$1;
      var $90=(($89+332)|0);
      var $91=HEAPF32[(($90)>>2)];
      var $92=$91;
      var $93=$92 > 0.000001;
      if ($93) { __label__ = 16; break; } else { __label__ = 17; break; }
    case 16: 
      var $95=$1;
      var $96=(($95+332)|0);
      var $97=HEAPF32[(($96)>>2)];
      var $98=$97;
      var $99=(1)/($98);
      $g=$99;
      __label__ = 18; break;
    case 17: 
      var $101=$1;
      var $102=(($101+328)|0);
      var $103=HEAPF32[(($102)>>2)];
      var $104=$103;
      $g=$104;
      __label__ = 18; break;
    case 18: 
      $i=0;
      __label__ = 19; break;
    case 19: 
      var $107=$i;
      var $108=(($107)|0) < 256;
      if ($108) { __label__ = 20; break; } else { __label__ = 22; break; }
    case 20: 
      var $110=$i;
      var $111=(($110)|0);
      var $112=($111)/(255);
      var $113=$g;
      var $114=_llvm_pow_f64($112, $113);
      var $115=($114)*(255);
      var $116=($115)+(0.5);
      var $117=($116 >= 0 ? Math.floor($116) : Math.ceil($116));
      var $118=$i;
      var $119=$1;
      var $120=(($119+340)|0);
      var $121=HEAP32[(($120)>>2)];
      var $122=(($121+$118)|0);
      HEAP8[($122)]=$117;
      __label__ = 21; break;
    case 21: 
      var $124=$i;
      var $125=((($124)+(1))|0);
      $i=$125;
      __label__ = 19; break;
    case 22: 
      __label__ = 23; break;
    case 23: 
      __label__ = 92; break;
    case 24: 
      var $129=$1;
      var $130=(($129+274)|0);
      var $131=HEAPU8[($130)];
      var $132=(($131)&255);
      var $133=$132 & 2;
      var $134=(($133)|0)!=0;
      if ($134) { __label__ = 25; break; } else { __label__ = 30; break; }
    case 25: 
      var $136=$1;
      var $137=(($136+360)|0);
      var $138=(($137)|0);
      var $139=HEAPU8[($138)];
      var $140=(($139)&255);
      $sig_bit=$140;
      var $141=$1;
      var $142=(($141+360)|0);
      var $143=(($142+1)|0);
      var $144=HEAPU8[($143)];
      var $145=(($144)&255);
      var $146=$sig_bit;
      var $147=(($145)|0) > (($146)|0);
      if ($147) { __label__ = 26; break; } else { __label__ = 27; break; }
    case 26: 
      var $149=$1;
      var $150=(($149+360)|0);
      var $151=(($150+1)|0);
      var $152=HEAPU8[($151)];
      var $153=(($152)&255);
      $sig_bit=$153;
      __label__ = 27; break;
    case 27: 
      var $155=$1;
      var $156=(($155+360)|0);
      var $157=(($156+2)|0);
      var $158=HEAPU8[($157)];
      var $159=(($158)&255);
      var $160=$sig_bit;
      var $161=(($159)|0) > (($160)|0);
      if ($161) { __label__ = 28; break; } else { __label__ = 29; break; }
    case 28: 
      var $163=$1;
      var $164=(($163+360)|0);
      var $165=(($164+2)|0);
      var $166=HEAPU8[($165)];
      var $167=(($166)&255);
      $sig_bit=$167;
      __label__ = 29; break;
    case 29: 
      __label__ = 31; break;
    case 30: 
      var $170=$1;
      var $171=(($170+360)|0);
      var $172=(($171+3)|0);
      var $173=HEAPU8[($172)];
      var $174=(($173)&255);
      $sig_bit=$174;
      __label__ = 31; break;
    case 31: 
      var $176=$sig_bit;
      var $177=(($176)|0) > 0;
      if ($177) { __label__ = 32; break; } else { __label__ = 33; break; }
    case 32: 
      var $179=$sig_bit;
      var $180=(((16)-($179))|0);
      $shift=$180;
      __label__ = 34; break;
    case 33: 
      $shift=0;
      __label__ = 34; break;
    case 34: 
      var $183=$1;
      var $184=(($183+92)|0);
      var $185=HEAP32[(($184)>>2)];
      var $186=$185 & 1024;
      var $187=(($186)|0)!=0;
      if ($187) { __label__ = 35; break; } else { __label__ = 38; break; }
    case 35: 
      var $189=$shift;
      var $190=(($189)|0) < 5;
      if ($190) { __label__ = 36; break; } else { __label__ = 37; break; }
    case 36: 
      $shift=5;
      __label__ = 37; break;
    case 37: 
      __label__ = 38; break;
    case 38: 
      var $194=$shift;
      var $195=(($194)|0) > 8;
      if ($195) { __label__ = 39; break; } else { __label__ = 40; break; }
    case 39: 
      $shift=8;
      __label__ = 40; break;
    case 40: 
      var $198=$shift;
      var $199=(($198)|0) < 0;
      if ($199) { __label__ = 41; break; } else { __label__ = 42; break; }
    case 41: 
      $shift=0;
      __label__ = 42; break;
    case 42: 
      var $202=$shift;
      var $203=(($202) & 255);
      var $204=(($203)&255);
      var $205=$1;
      var $206=(($205+324)|0);
      HEAP32[(($206)>>2)]=$204;
      var $207=$shift;
      var $208=(((8)-($207))|0);
      var $209=1 << $208;
      $num=$209;
      var $210=$1;
      var $211=(($210+332)|0);
      var $212=HEAPF32[(($211)>>2)];
      var $213=$212;
      var $214=$213 > 0.000001;
      if ($214) { __label__ = 43; break; } else { __label__ = 44; break; }
    case 43: 
      var $216=$1;
      var $217=(($216+328)|0);
      var $218=HEAPF32[(($217)>>2)];
      var $219=$1;
      var $220=(($219+332)|0);
      var $221=HEAPF32[(($220)>>2)];
      var $222=($218)*($221);
      var $223=$222;
      var $224=(1)/($223);
      $g1=$224;
      __label__ = 45; break;
    case 44: 
      $g1=1;
      __label__ = 45; break;
    case 45: 
      var $227=$1;
      var $228=$num;
      var $229=((($228<<2))|0);
      var $230=_png_calloc($227, $229);
      var $231=$230;
      var $232=$1;
      var $233=(($232+348)|0);
      HEAP32[(($233)>>2)]=$231;
      var $234=$1;
      var $235=(($234+92)|0);
      var $236=HEAP32[(($235)>>2)];
      var $237=$236 & 1152;
      var $238=(($237)|0)!=0;
      if ($238) { __label__ = 46; break; } else { __label__ = 61; break; }
    case 46: 
      $i2=0;
      __label__ = 47; break;
    case 47: 
      var $241=$i2;
      var $242=$num;
      var $243=(($241)|0) < (($242)|0);
      if ($243) { __label__ = 48; break; } else { __label__ = 50; break; }
    case 48: 
      var $245=$1;
      var $246=_png_malloc($245, 512);
      var $247=$246;
      var $248=$i2;
      var $249=$1;
      var $250=(($249+348)|0);
      var $251=HEAP32[(($250)>>2)];
      var $252=(($251+($248<<2))|0);
      HEAP32[(($252)>>2)]=$247;
      __label__ = 49; break;
    case 49: 
      var $254=$i2;
      var $255=((($254)+(1))|0);
      $i2=$255;
      __label__ = 47; break;
    case 50: 
      var $257=$g1;
      var $258=(1)/($257);
      $g1=$258;
      $last=0;
      $i2=0;
      __label__ = 51; break;
    case 51: 
      var $260=$i2;
      var $261=(($260)|0) < 256;
      if ($261) { __label__ = 52; break; } else { __label__ = 57; break; }
    case 52: 
      var $263=$i2;
      var $264=(($263)|0);
      var $265=($264)+(0.5);
      var $266=($265)/(256);
      $fout=$266;
      var $267=$fout;
      var $268=$g1;
      var $269=_llvm_pow_f64($267, $268);
      $fin=$269;
      var $270=$fin;
      var $271=$num;
      var $272=$271 << 8;
      var $273=(($272)>>>0);
      var $274=($270)*($273);
      var $275=($274 >= 0 ? Math.floor($274) : Math.ceil($274));
      $max=$275;
      __label__ = 53; break;
    case 53: 
      var $277=$last;
      var $278=$max;
      var $279=(($277)>>>0) <= (($278)>>>0);
      if ($279) { __label__ = 54; break; } else { __label__ = 55; break; }
    case 54: 
      var $281=$i2;
      var $282=(($281) & 65535);
      var $283=(($282)&65535);
      var $284=$i2;
      var $285=(($284) & 65535);
      var $286=(($285)&65535);
      var $287=$286 << 8;
      var $288=$283 | $287;
      var $289=(($288) & 65535);
      var $290=$last;
      var $291=$shift;
      var $292=(((8)-($291))|0);
      var $293=$290 >>> (($292)>>>0);
      var $294=$last;
      var $295=$shift;
      var $296=255 >> (($295)|0);
      var $297=$294 & $296;
      var $298=$1;
      var $299=(($298+348)|0);
      var $300=HEAP32[(($299)>>2)];
      var $301=(($300+($297<<2))|0);
      var $302=HEAP32[(($301)>>2)];
      var $303=(($302+($293<<1))|0);
      HEAP16[(($303)>>1)]=$289;
      var $304=$last;
      var $305=((($304)+(1))|0);
      $last=$305;
      __label__ = 53; break;
    case 55: 
      __label__ = 56; break;
    case 56: 
      var $308=$i2;
      var $309=((($308)+(1))|0);
      $i2=$309;
      __label__ = 51; break;
    case 57: 
      __label__ = 58; break;
    case 58: 
      var $312=$last;
      var $313=$num;
      var $314=$313 << 8;
      var $315=(($312)>>>0) < (($314)>>>0);
      if ($315) { __label__ = 59; break; } else { __label__ = 60; break; }
    case 59: 
      var $317=$last;
      var $318=$shift;
      var $319=(((8)-($318))|0);
      var $320=$317 >>> (($319)>>>0);
      var $321=$last;
      var $322=$shift;
      var $323=255 >> (($322)|0);
      var $324=$321 & $323;
      var $325=$1;
      var $326=(($325+348)|0);
      var $327=HEAP32[(($326)>>2)];
      var $328=(($327+($324<<2))|0);
      var $329=HEAP32[(($328)>>2)];
      var $330=(($329+($320<<1))|0);
      HEAP16[(($330)>>1)]=-1;
      var $331=$last;
      var $332=((($331)+(1))|0);
      $last=$332;
      __label__ = 58; break;
    case 60: 
      __label__ = 70; break;
    case 61: 
      $i2=0;
      __label__ = 62; break;
    case 62: 
      var $336=$i2;
      var $337=$num;
      var $338=(($336)|0) < (($337)|0);
      if ($338) { __label__ = 63; break; } else { __label__ = 69; break; }
    case 63: 
      var $340=$1;
      var $341=_png_malloc($340, 512);
      var $342=$341;
      var $343=$i2;
      var $344=$1;
      var $345=(($344+348)|0);
      var $346=HEAP32[(($345)>>2)];
      var $347=(($346+($343<<2))|0);
      HEAP32[(($347)>>2)]=$342;
      var $348=$i2;
      var $349=$shift;
      var $350=((_png_gamma_shift+($349<<2))|0);
      var $351=HEAP32[(($350)>>2)];
      var $352=((($348)*($351))|0);
      var $353=$352 >>> 4;
      $ig=$353;
      $j=0;
      __label__ = 64; break;
    case 64: 
      var $355=$j;
      var $356=(($355)|0) < 256;
      if ($356) { __label__ = 65; break; } else { __label__ = 67; break; }
    case 65: 
      var $358=$ig;
      var $359=$j;
      var $360=$359 << 8;
      var $361=((($358)+($360))|0);
      var $362=(($361)>>>0);
      var $363=($362)/(65535);
      var $364=$g1;
      var $365=_llvm_pow_f64($363, $364);
      var $366=($365)*(65535);
      var $367=($366)+(0.5);
      var $368=($367 >= 0 ? Math.floor($367) : Math.ceil($367));
      var $369=$j;
      var $370=$i2;
      var $371=$1;
      var $372=(($371+348)|0);
      var $373=HEAP32[(($372)>>2)];
      var $374=(($373+($370<<2))|0);
      var $375=HEAP32[(($374)>>2)];
      var $376=(($375+($369<<1))|0);
      HEAP16[(($376)>>1)]=$368;
      __label__ = 66; break;
    case 66: 
      var $378=$j;
      var $379=((($378)+(1))|0);
      $j=$379;
      __label__ = 64; break;
    case 67: 
      __label__ = 68; break;
    case 68: 
      var $382=$i2;
      var $383=((($382)+(1))|0);
      $i2=$383;
      __label__ = 62; break;
    case 69: 
      __label__ = 70; break;
    case 70: 
      var $386=$1;
      var $387=(($386+92)|0);
      var $388=HEAP32[(($387)>>2)];
      var $389=$388 & 6291584;
      var $390=(($389)|0)!=0;
      if ($390) { __label__ = 71; break; } else { __label__ = 91; break; }
    case 71: 
      var $392=$1;
      var $393=(($392+328)|0);
      var $394=HEAPF32[(($393)>>2)];
      var $395=$394;
      var $396=(1)/($395);
      $g1=$396;
      var $397=$1;
      var $398=$num;
      var $399=((($398<<2))|0);
      var $400=_png_calloc($397, $399);
      var $401=$400;
      var $402=$1;
      var $403=(($402+356)|0);
      HEAP32[(($403)>>2)]=$401;
      $i2=0;
      __label__ = 72; break;
    case 72: 
      var $405=$i2;
      var $406=$num;
      var $407=(($405)|0) < (($406)|0);
      if ($407) { __label__ = 73; break; } else { __label__ = 79; break; }
    case 73: 
      var $409=$1;
      var $410=_png_malloc($409, 512);
      var $411=$410;
      var $412=$i2;
      var $413=$1;
      var $414=(($413+356)|0);
      var $415=HEAP32[(($414)>>2)];
      var $416=(($415+($412<<2))|0);
      HEAP32[(($416)>>2)]=$411;
      var $417=$i2;
      var $418=$shift;
      var $419=((_png_gamma_shift+($418<<2))|0);
      var $420=HEAP32[(($419)>>2)];
      var $421=((($417)*($420))|0);
      var $422=$421 >>> 4;
      $ig=$422;
      $j=0;
      __label__ = 74; break;
    case 74: 
      var $424=$j;
      var $425=(($424)|0) < 256;
      if ($425) { __label__ = 75; break; } else { __label__ = 77; break; }
    case 75: 
      var $427=$ig;
      var $428=$j;
      var $429=$428 << 8;
      var $430=((($427)+($429))|0);
      var $431=(($430)>>>0);
      var $432=($431)/(65535);
      var $433=$g1;
      var $434=_llvm_pow_f64($432, $433);
      var $435=($434)*(65535);
      var $436=($435)+(0.5);
      var $437=($436 >= 0 ? Math.floor($436) : Math.ceil($436));
      var $438=$j;
      var $439=$i2;
      var $440=$1;
      var $441=(($440+356)|0);
      var $442=HEAP32[(($441)>>2)];
      var $443=(($442+($439<<2))|0);
      var $444=HEAP32[(($443)>>2)];
      var $445=(($444+($438<<1))|0);
      HEAP16[(($445)>>1)]=$437;
      __label__ = 76; break;
    case 76: 
      var $447=$j;
      var $448=((($447)+(1))|0);
      $j=$448;
      __label__ = 74; break;
    case 77: 
      __label__ = 78; break;
    case 78: 
      var $451=$i2;
      var $452=((($451)+(1))|0);
      $i2=$452;
      __label__ = 72; break;
    case 79: 
      var $454=$1;
      var $455=(($454+332)|0);
      var $456=HEAPF32[(($455)>>2)];
      var $457=$456;
      var $458=$457 > 0.000001;
      if ($458) { __label__ = 80; break; } else { __label__ = 81; break; }
    case 80: 
      var $460=$1;
      var $461=(($460+332)|0);
      var $462=HEAPF32[(($461)>>2)];
      var $463=$462;
      var $464=(1)/($463);
      $g1=$464;
      __label__ = 82; break;
    case 81: 
      var $466=$1;
      var $467=(($466+328)|0);
      var $468=HEAPF32[(($467)>>2)];
      var $469=$468;
      $g1=$469;
      __label__ = 82; break;
    case 82: 
      var $471=$1;
      var $472=$num;
      var $473=((($472<<2))|0);
      var $474=_png_calloc($471, $473);
      var $475=$474;
      var $476=$1;
      var $477=(($476+352)|0);
      HEAP32[(($477)>>2)]=$475;
      $i2=0;
      __label__ = 83; break;
    case 83: 
      var $479=$i2;
      var $480=$num;
      var $481=(($479)|0) < (($480)|0);
      if ($481) { __label__ = 84; break; } else { __label__ = 90; break; }
    case 84: 
      var $483=$1;
      var $484=_png_malloc($483, 512);
      var $485=$484;
      var $486=$i2;
      var $487=$1;
      var $488=(($487+352)|0);
      var $489=HEAP32[(($488)>>2)];
      var $490=(($489+($486<<2))|0);
      HEAP32[(($490)>>2)]=$485;
      var $491=$i2;
      var $492=$shift;
      var $493=((_png_gamma_shift+($492<<2))|0);
      var $494=HEAP32[(($493)>>2)];
      var $495=((($491)*($494))|0);
      var $496=$495 >>> 4;
      $ig=$496;
      $j=0;
      __label__ = 85; break;
    case 85: 
      var $498=$j;
      var $499=(($498)|0) < 256;
      if ($499) { __label__ = 86; break; } else { __label__ = 88; break; }
    case 86: 
      var $501=$ig;
      var $502=$j;
      var $503=$502 << 8;
      var $504=((($501)+($503))|0);
      var $505=(($504)>>>0);
      var $506=($505)/(65535);
      var $507=$g1;
      var $508=_llvm_pow_f64($506, $507);
      var $509=($508)*(65535);
      var $510=($509)+(0.5);
      var $511=($510 >= 0 ? Math.floor($510) : Math.ceil($510));
      var $512=$j;
      var $513=$i2;
      var $514=$1;
      var $515=(($514+352)|0);
      var $516=HEAP32[(($515)>>2)];
      var $517=(($516+($513<<2))|0);
      var $518=HEAP32[(($517)>>2)];
      var $519=(($518+($512<<1))|0);
      HEAP16[(($519)>>1)]=$511;
      __label__ = 87; break;
    case 87: 
      var $521=$j;
      var $522=((($521)+(1))|0);
      $j=$522;
      __label__ = 85; break;
    case 88: 
      __label__ = 89; break;
    case 89: 
      var $525=$i2;
      var $526=((($525)+(1))|0);
      $i2=$526;
      __label__ = 83; break;
    case 90: 
      __label__ = 91; break;
    case 91: 
      __label__ = 92; break;
    case 92: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_png_build_gamma_table["X"]=1;

function _png_read_transform_info($png_ptr, $info_ptr) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      $1=$png_ptr;
      $2=$info_ptr;
      var $3=$1;
      var $4=(($3+92)|0);
      var $5=HEAP32[(($4)>>2)];
      var $6=$5 & 4096;
      var $7=(($6)|0)!=0;
      if ($7) { __label__ = 3; break; } else { __label__ = 16; break; }
    case 3: 
      var $9=$2;
      var $10=(($9+25)|0);
      var $11=HEAPU8[($10)];
      var $12=(($11)&255);
      var $13=(($12)|0)==3;
      if ($13) { __label__ = 4; break; } else { __label__ = 8; break; }
    case 4: 
      var $15=$1;
      var $16=(($15+262)|0);
      var $17=HEAP16[(($16)>>1)];
      var $18=(($17 << 16) >> 16)!=0;
      if ($18) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $20=$2;
      var $21=(($20+25)|0);
      HEAP8[($21)]=6;
      __label__ = 7; break;
    case 6: 
      var $23=$2;
      var $24=(($23+25)|0);
      HEAP8[($24)]=2;
      __label__ = 7; break;
    case 7: 
      var $26=$2;
      var $27=(($26+24)|0);
      HEAP8[($27)]=8;
      var $28=$2;
      var $29=(($28+22)|0);
      HEAP16[(($29)>>1)]=0;
      __label__ = 15; break;
    case 8: 
      var $31=$1;
      var $32=(($31+262)|0);
      var $33=HEAP16[(($32)>>1)];
      var $34=(($33 << 16) >> 16)!=0;
      if ($34) { __label__ = 9; break; } else { __label__ = 12; break; }
    case 9: 
      var $36=$1;
      var $37=(($36+92)|0);
      var $38=HEAP32[(($37)>>2)];
      var $39=$38 & 33554432;
      var $40=(($39)|0)!=0;
      if ($40) { __label__ = 10; break; } else { __label__ = 11; break; }
    case 10: 
      var $42=$2;
      var $43=(($42+25)|0);
      var $44=HEAPU8[($43)];
      var $45=(($44)&255);
      var $46=$45 | 4;
      var $47=(($46) & 255);
      HEAP8[($43)]=$47;
      __label__ = 11; break;
    case 11: 
      __label__ = 12; break;
    case 12: 
      var $50=$2;
      var $51=(($50+24)|0);
      var $52=HEAPU8[($51)];
      var $53=(($52)&255);
      var $54=(($53)|0) < 8;
      if ($54) { __label__ = 13; break; } else { __label__ = 14; break; }
    case 13: 
      var $56=$2;
      var $57=(($56+24)|0);
      HEAP8[($57)]=8;
      __label__ = 14; break;
    case 14: 
      var $59=$2;
      var $60=(($59+22)|0);
      HEAP16[(($60)>>1)]=0;
      __label__ = 15; break;
    case 15: 
      __label__ = 16; break;
    case 16: 
      var $63=$1;
      var $64=(($63+92)|0);
      var $65=HEAP32[(($64)>>2)];
      var $66=$65 & 128;
      var $67=(($66)|0)!=0;
      if ($67) { __label__ = 17; break; } else { __label__ = 18; break; }
    case 17: 
      var $69=$2;
      var $70=(($69+25)|0);
      var $71=HEAPU8[($70)];
      var $72=(($71)&255);
      var $73=$72 & -5;
      var $74=(($73) & 255);
      HEAP8[($70)]=$74;
      var $75=$2;
      var $76=(($75+22)|0);
      HEAP16[(($76)>>1)]=0;
      var $77=$2;
      var $78=(($77+90)|0);
      var $79=$1;
      var $80=(($79+292)|0);
      var $81=$78;
      var $82=$80;
      assert(10 % 1 === 0, 'memcpy given ' + 10 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP16[(($81)>>1)]=HEAP16[(($82)>>1)];HEAP16[((($81)+(2))>>1)]=HEAP16[((($82)+(2))>>1)];HEAP16[((($81)+(4))>>1)]=HEAP16[((($82)+(4))>>1)];HEAP16[((($81)+(6))>>1)]=HEAP16[((($82)+(6))>>1)];HEAP16[((($81)+(8))>>1)]=HEAP16[((($82)+(8))>>1)];
      __label__ = 18; break;
    case 18: 
      var $84=$1;
      var $85=(($84+92)|0);
      var $86=HEAP32[(($85)>>2)];
      var $87=$86 & 8192;
      var $88=(($87)|0)!=0;
      if ($88) { __label__ = 19; break; } else { __label__ = 20; break; }
    case 19: 
      var $90=$1;
      var $91=(($90+328)|0);
      var $92=HEAPF32[(($91)>>2)];
      var $93=$2;
      var $94=(($93+40)|0);
      HEAPF32[(($94)>>2)]=$92;
      var $95=$1;
      var $96=(($95+544)|0);
      var $97=HEAP32[(($96)>>2)];
      var $98=$2;
      var $99=(($98+252)|0);
      HEAP32[(($99)>>2)]=$97;
      __label__ = 20; break;
    case 20: 
      var $101=$1;
      var $102=(($101+92)|0);
      var $103=HEAP32[(($102)>>2)];
      var $104=$103 & 1024;
      var $105=(($104)|0)!=0;
      if ($105) { __label__ = 21; break; } else { __label__ = 23; break; }
    case 21: 
      var $107=$2;
      var $108=(($107+24)|0);
      var $109=HEAPU8[($108)];
      var $110=(($109)&255);
      var $111=(($110)|0)==16;
      if ($111) { __label__ = 22; break; } else { __label__ = 23; break; }
    case 22: 
      var $113=$2;
      var $114=(($113+24)|0);
      HEAP8[($114)]=8;
      __label__ = 23; break;
    case 23: 
      var $116=$1;
      var $117=(($116+92)|0);
      var $118=HEAP32[(($117)>>2)];
      var $119=$118 & 16384;
      var $120=(($119)|0)!=0;
      if ($120) { __label__ = 24; break; } else { __label__ = 25; break; }
    case 24: 
      var $122=$2;
      var $123=(($122+25)|0);
      var $124=HEAPU8[($123)];
      var $125=(($124)&255);
      var $126=$125 | 2;
      var $127=(($126) & 255);
      HEAP8[($123)]=$127;
      __label__ = 25; break;
    case 25: 
      var $129=$1;
      var $130=(($129+92)|0);
      var $131=HEAP32[(($130)>>2)];
      var $132=$131 & 6291456;
      var $133=(($132)|0)!=0;
      if ($133) { __label__ = 26; break; } else { __label__ = 27; break; }
    case 26: 
      var $135=$2;
      var $136=(($135+25)|0);
      var $137=HEAPU8[($136)];
      var $138=(($137)&255);
      var $139=$138 & -3;
      var $140=(($139) & 255);
      HEAP8[($136)]=$140;
      __label__ = 27; break;
    case 27: 
      var $142=$1;
      var $143=(($142+92)|0);
      var $144=HEAP32[(($143)>>2)];
      var $145=$144 & 64;
      var $146=(($145)|0)!=0;
      if ($146) { __label__ = 28; break; } else { __label__ = 34; break; }
    case 28: 
      var $148=$2;
      var $149=(($148+25)|0);
      var $150=HEAPU8[($149)];
      var $151=(($150)&255);
      var $152=(($151)|0)==2;
      if ($152) { __label__ = 30; break; } else { __label__ = 29; break; }
    case 29: 
      var $154=$2;
      var $155=(($154+25)|0);
      var $156=HEAPU8[($155)];
      var $157=(($156)&255);
      var $158=(($157)|0)==6;
      if ($158) { __label__ = 30; break; } else { __label__ = 33; break; }
    case 30: 
      var $160=$1;
      var $161=(($160+472)|0);
      var $162=HEAP32[(($161)>>2)];
      var $163=(($162)|0)!=0;
      if ($163) { __label__ = 31; break; } else { __label__ = 33; break; }
    case 31: 
      var $165=$2;
      var $166=(($165+24)|0);
      var $167=HEAPU8[($166)];
      var $168=(($167)&255);
      var $169=(($168)|0)==8;
      if ($169) { __label__ = 32; break; } else { __label__ = 33; break; }
    case 32: 
      var $171=$2;
      var $172=(($171+25)|0);
      HEAP8[($172)]=3;
      __label__ = 33; break;
    case 33: 
      __label__ = 34; break;
    case 34: 
      var $175=$1;
      var $176=(($175+92)|0);
      var $177=HEAP32[(($176)>>2)];
      var $178=$177 & 4;
      var $179=(($178)|0)!=0;
      if ($179) { __label__ = 35; break; } else { __label__ = 37; break; }
    case 35: 
      var $181=$2;
      var $182=(($181+24)|0);
      var $183=HEAPU8[($182)];
      var $184=(($183)&255);
      var $185=(($184)|0) < 8;
      if ($185) { __label__ = 36; break; } else { __label__ = 37; break; }
    case 36: 
      var $187=$2;
      var $188=(($187+24)|0);
      HEAP8[($188)]=8;
      __label__ = 37; break;
    case 37: 
      var $190=$2;
      var $191=(($190+25)|0);
      var $192=HEAPU8[($191)];
      var $193=(($192)&255);
      var $194=(($193)|0)==3;
      if ($194) { __label__ = 38; break; } else { __label__ = 39; break; }
    case 38: 
      var $196=$2;
      var $197=(($196+29)|0);
      HEAP8[($197)]=1;
      __label__ = 43; break;
    case 39: 
      var $199=$2;
      var $200=(($199+25)|0);
      var $201=HEAPU8[($200)];
      var $202=(($201)&255);
      var $203=$202 & 2;
      var $204=(($203)|0)!=0;
      if ($204) { __label__ = 40; break; } else { __label__ = 41; break; }
    case 40: 
      var $206=$2;
      var $207=(($206+29)|0);
      HEAP8[($207)]=3;
      __label__ = 42; break;
    case 41: 
      var $209=$2;
      var $210=(($209+29)|0);
      HEAP8[($210)]=1;
      __label__ = 42; break;
    case 42: 
      __label__ = 43; break;
    case 43: 
      var $213=$1;
      var $214=(($213+88)|0);
      var $215=HEAP32[(($214)>>2)];
      var $216=$215 & 4194304;
      var $217=(($216)|0)!=0;
      if ($217) { __label__ = 44; break; } else { __label__ = 45; break; }
    case 44: 
      var $219=$2;
      var $220=(($219+25)|0);
      var $221=HEAPU8[($220)];
      var $222=(($221)&255);
      var $223=$222 & -5;
      var $224=(($223) & 255);
      HEAP8[($220)]=$224;
      __label__ = 45; break;
    case 45: 
      var $226=$2;
      var $227=(($226+25)|0);
      var $228=HEAPU8[($227)];
      var $229=(($228)&255);
      var $230=$229 & 4;
      var $231=(($230)|0)!=0;
      if ($231) { __label__ = 46; break; } else { __label__ = 47; break; }
    case 46: 
      var $233=$2;
      var $234=(($233+29)|0);
      var $235=HEAP8[($234)];
      var $236=((($235)+(1))&255);
      HEAP8[($234)]=$236;
      __label__ = 47; break;
    case 47: 
      var $238=$1;
      var $239=(($238+92)|0);
      var $240=HEAP32[(($239)>>2)];
      var $241=$240 & 32768;
      var $242=(($241)|0)!=0;
      if ($242) { __label__ = 48; break; } else { __label__ = 53; break; }
    case 48: 
      var $244=$2;
      var $245=(($244+25)|0);
      var $246=HEAPU8[($245)];
      var $247=(($246)&255);
      var $248=(($247)|0)==2;
      if ($248) { __label__ = 50; break; } else { __label__ = 49; break; }
    case 49: 
      var $250=$2;
      var $251=(($250+25)|0);
      var $252=HEAPU8[($251)];
      var $253=(($252)&255);
      var $254=(($253)|0)==0;
      if ($254) { __label__ = 50; break; } else { __label__ = 53; break; }
    case 50: 
      var $256=$2;
      var $257=(($256+29)|0);
      var $258=HEAP8[($257)];
      var $259=((($258)+(1))&255);
      HEAP8[($257)]=$259;
      var $260=$1;
      var $261=(($260+92)|0);
      var $262=HEAP32[(($261)>>2)];
      var $263=$262 & 16777216;
      var $264=(($263)|0)!=0;
      if ($264) { __label__ = 51; break; } else { __label__ = 52; break; }
    case 51: 
      var $266=$2;
      var $267=(($266+25)|0);
      var $268=HEAPU8[($267)];
      var $269=(($268)&255);
      var $270=$269 | 4;
      var $271=(($270) & 255);
      HEAP8[($267)]=$271;
      __label__ = 52; break;
    case 52: 
      __label__ = 53; break;
    case 53: 
      var $274=$1;
      var $275=(($274+92)|0);
      var $276=HEAP32[(($275)>>2)];
      var $277=$276 & 1048576;
      var $278=(($277)|0)!=0;
      if ($278) { __label__ = 54; break; } else { __label__ = 59; break; }
    case 54: 
      var $280=$2;
      var $281=(($280+24)|0);
      var $282=HEAPU8[($281)];
      var $283=(($282)&255);
      var $284=$1;
      var $285=(($284+80)|0);
      var $286=HEAPU8[($285)];
      var $287=(($286)&255);
      var $288=(($283)|0) < (($287)|0);
      if ($288) { __label__ = 55; break; } else { __label__ = 56; break; }
    case 55: 
      var $290=$1;
      var $291=(($290+80)|0);
      var $292=HEAP8[($291)];
      var $293=$2;
      var $294=(($293+24)|0);
      HEAP8[($294)]=$292;
      __label__ = 56; break;
    case 56: 
      var $296=$2;
      var $297=(($296+29)|0);
      var $298=HEAPU8[($297)];
      var $299=(($298)&255);
      var $300=$1;
      var $301=(($300+81)|0);
      var $302=HEAPU8[($301)];
      var $303=(($302)&255);
      var $304=(($299)|0) < (($303)|0);
      if ($304) { __label__ = 57; break; } else { __label__ = 58; break; }
    case 57: 
      var $306=$1;
      var $307=(($306+81)|0);
      var $308=HEAP8[($307)];
      var $309=$2;
      var $310=(($309+29)|0);
      HEAP8[($310)]=$308;
      __label__ = 58; break;
    case 58: 
      __label__ = 59; break;
    case 59: 
      var $313=$2;
      var $314=(($313+29)|0);
      var $315=HEAPU8[($314)];
      var $316=(($315)&255);
      var $317=$2;
      var $318=(($317+24)|0);
      var $319=HEAPU8[($318)];
      var $320=(($319)&255);
      var $321=((($316)*($320))|0);
      var $322=(($321) & 255);
      var $323=$2;
      var $324=(($323+30)|0);
      HEAP8[($324)]=$322;
      var $325=$2;
      var $326=(($325+30)|0);
      var $327=HEAPU8[($326)];
      var $328=(($327)&255);
      var $329=(($328)|0) >= 8;
      if ($329) { __label__ = 60; break; } else { __label__ = 61; break; }
    case 60: 
      var $331=$2;
      var $332=(($331)|0);
      var $333=HEAP32[(($332)>>2)];
      var $334=$2;
      var $335=(($334+30)|0);
      var $336=HEAPU8[($335)];
      var $337=(($336)&255);
      var $338=$337 >>> 3;
      var $339=((($333)*($338))|0);
      var $352 = $339;__label__ = 62; break;
    case 61: 
      var $341=$2;
      var $342=(($341)|0);
      var $343=HEAP32[(($342)>>2)];
      var $344=$2;
      var $345=(($344+30)|0);
      var $346=HEAPU8[($345)];
      var $347=(($346)&255);
      var $348=((($343)*($347))|0);
      var $349=((($348)+(7))|0);
      var $350=$349 >>> 3;
      var $352 = $350;__label__ = 62; break;
    case 62: 
      var $352;
      var $353=$2;
      var $354=(($353+12)|0);
      HEAP32[(($354)>>2)]=$352;
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_png_read_transform_info["X"]=1;

function _png_do_read_transformations($png_ptr) {
  var __stackBase__  = STACKTOP; STACKTOP += 52; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $msg=__stackBase__;
      var $rgb_error;
      $1=$png_ptr;
      var $2=$1;
      var $3=(($2+216)|0);
      var $4=HEAP32[(($3)>>2)];
      var $5=(($4)|0)==0;
      if ($5) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $7=(($msg)|0);
      var $8=$1;
      var $9=(($8+208)|0);
      var $10=HEAP32[(($9)>>2)];
      var $11=$1;
      var $12=(($11+272)|0);
      var $13=HEAPU8[($12)];
      var $14=(($13)&255);
      var $15=_snprintf($7, 50, ((STRING_TABLE.__str5175)|0), (tempInt=STACKTOP,STACKTOP += 8,assert(STACKTOP < STACK_ROOT + STACK_MAX, "Ran out of stack"),HEAP32[((tempInt)>>2)]=$10,HEAP32[(((tempInt)+(4))>>2)]=$14,tempInt));
      var $16=$1;
      var $17=(($msg)|0);
      _png_error($16, $17);
      __label__ = 4; break;
    case 4: 
      var $19=$1;
      var $20=(($19+92)|0);
      var $21=HEAP32[(($20)>>2)];
      var $22=$21 & 4096;
      var $23=(($22)|0)!=0;
      if ($23) { __label__ = 5; break; } else { __label__ = 13; break; }
    case 5: 
      var $25=$1;
      var $26=(($25+236)|0);
      var $27=(($26+8)|0);
      var $28=HEAPU8[($27)];
      var $29=(($28)&255);
      var $30=(($29)|0)==3;
      if ($30) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      var $32=$1;
      var $33=(($32+236)|0);
      var $34=$1;
      var $35=(($34+216)|0);
      var $36=HEAP32[(($35)>>2)];
      var $37=(($36+1)|0);
      var $38=$1;
      var $39=(($38+256)|0);
      var $40=HEAP32[(($39)>>2)];
      var $41=$1;
      var $42=(($41+372)|0);
      var $43=HEAP32[(($42)>>2)];
      var $44=$1;
      var $45=(($44+262)|0);
      var $46=HEAPU16[(($45)>>1)];
      var $47=(($46)&65535);
      _png_do_expand_palette($33, $37, $40, $43, $47);
      __label__ = 12; break;
    case 7: 
      var $49=$1;
      var $50=(($49+262)|0);
      var $51=HEAPU16[(($50)>>1)];
      var $52=(($51)&65535);
      var $53=(($52)|0)!=0;
      if ($53) { __label__ = 8; break; } else { __label__ = 10; break; }
    case 8: 
      var $55=$1;
      var $56=(($55+92)|0);
      var $57=HEAP32[(($56)>>2)];
      var $58=$57 & 33554432;
      var $59=(($58)|0)!=0;
      if ($59) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      var $61=$1;
      var $62=(($61+236)|0);
      var $63=$1;
      var $64=(($63+216)|0);
      var $65=HEAP32[(($64)>>2)];
      var $66=(($65+1)|0);
      var $67=$1;
      var $68=(($67+376)|0);
      _png_do_expand($62, $66, $68);
      __label__ = 11; break;
    case 10: 
      var $70=$1;
      var $71=(($70+236)|0);
      var $72=$1;
      var $73=(($72+216)|0);
      var $74=HEAP32[(($73)>>2)];
      var $75=(($74+1)|0);
      _png_do_expand($71, $75, 0);
      __label__ = 11; break;
    case 11: 
      __label__ = 12; break;
    case 12: 
      __label__ = 13; break;
    case 13: 
      var $79=$1;
      var $80=(($79+88)|0);
      var $81=HEAP32[(($80)>>2)];
      var $82=$81 & 4194304;
      var $83=(($82)|0)!=0;
      if ($83) { __label__ = 14; break; } else { __label__ = 15; break; }
    case 14: 
      var $85=$1;
      var $86=(($85+236)|0);
      var $87=$1;
      var $88=(($87+216)|0);
      var $89=HEAP32[(($88)>>2)];
      var $90=(($89+1)|0);
      var $91=$1;
      var $92=(($91+88)|0);
      var $93=HEAP32[(($92)>>2)];
      var $94=$93 & 4194304;
      var $95=128 | $94;
      _png_do_strip_filler($86, $90, $95);
      __label__ = 15; break;
    case 15: 
      var $97=$1;
      var $98=(($97+92)|0);
      var $99=HEAP32[(($98)>>2)];
      var $100=$99 & 6291456;
      var $101=(($100)|0)!=0;
      if ($101) { __label__ = 16; break; } else { __label__ = 23; break; }
    case 16: 
      var $103=$1;
      var $104=$1;
      var $105=(($104+236)|0);
      var $106=$1;
      var $107=(($106+216)|0);
      var $108=HEAP32[(($107)>>2)];
      var $109=(($108+1)|0);
      var $110=_png_do_rgb_to_gray($103, $105, $109);
      $rgb_error=$110;
      var $111=$rgb_error;
      var $112=(($111)|0)!=0;
      if ($112) { __label__ = 17; break; } else { __label__ = 22; break; }
    case 17: 
      var $114=$1;
      var $115=(($114+532)|0);
      HEAP8[($115)]=1;
      var $116=$1;
      var $117=(($116+92)|0);
      var $118=HEAP32[(($117)>>2)];
      var $119=$118 & 6291456;
      var $120=(($119)|0)==4194304;
      if ($120) { __label__ = 18; break; } else { __label__ = 19; break; }
    case 18: 
      var $122=$1;
      _png_warning($122, ((STRING_TABLE.__str6176)|0));
      __label__ = 19; break;
    case 19: 
      var $124=$1;
      var $125=(($124+92)|0);
      var $126=HEAP32[(($125)>>2)];
      var $127=$126 & 6291456;
      var $128=(($127)|0)==2097152;
      if ($128) { __label__ = 20; break; } else { __label__ = 21; break; }
    case 20: 
      var $130=$1;
      _png_error($130, ((STRING_TABLE.__str6176)|0));
      __label__ = 21; break;
    case 21: 
      __label__ = 22; break;
    case 22: 
      __label__ = 23; break;
    case 23: 
      var $134=$1;
      var $135=(($134+92)|0);
      var $136=HEAP32[(($135)>>2)];
      var $137=$136 & 16384;
      var $138=(($137)|0)!=0;
      if ($138) { __label__ = 24; break; } else { __label__ = 26; break; }
    case 24: 
      var $140=$1;
      var $141=(($140+84)|0);
      var $142=HEAP32[(($141)>>2)];
      var $143=$142 & 2048;
      var $144=(($143)|0)!=0;
      if ($144) { __label__ = 26; break; } else { __label__ = 25; break; }
    case 25: 
      var $146=$1;
      var $147=(($146+236)|0);
      var $148=$1;
      var $149=(($148+216)|0);
      var $150=HEAP32[(($149)>>2)];
      var $151=(($150+1)|0);
      _png_do_gray_to_rgb($147, $151);
      __label__ = 26; break;
    case 26: 
      var $153=$1;
      var $154=(($153+92)|0);
      var $155=HEAP32[(($154)>>2)];
      var $156=$155 & 128;
      var $157=(($156)|0)!=0;
      if ($157) { __label__ = 27; break; } else { __label__ = 30; break; }
    case 27: 
      var $159=$1;
      var $160=(($159+262)|0);
      var $161=HEAPU16[(($160)>>1)];
      var $162=(($161)&65535);
      var $163=(($162)|0)!=0;
      if ($163) { __label__ = 29; break; } else { __label__ = 28; break; }
    case 28: 
      var $165=$1;
      var $166=(($165+274)|0);
      var $167=HEAPU8[($166)];
      var $168=(($167)&255);
      var $169=$168 & 4;
      var $170=(($169)|0)!=0;
      if ($170) { __label__ = 29; break; } else { __label__ = 30; break; }
    case 29: 
      var $172=$1;
      var $173=(($172+236)|0);
      var $174=$1;
      var $175=(($174+216)|0);
      var $176=HEAP32[(($175)>>2)];
      var $177=(($176+1)|0);
      var $178=$1;
      var $179=(($178+376)|0);
      var $180=$1;
      var $181=(($180+292)|0);
      var $182=$1;
      var $183=(($182+302)|0);
      var $184=$1;
      var $185=(($184+336)|0);
      var $186=HEAP32[(($185)>>2)];
      var $187=$1;
      var $188=(($187+340)|0);
      var $189=HEAP32[(($188)>>2)];
      var $190=$1;
      var $191=(($190+344)|0);
      var $192=HEAP32[(($191)>>2)];
      var $193=$1;
      var $194=(($193+348)|0);
      var $195=HEAP32[(($194)>>2)];
      var $196=$1;
      var $197=(($196+352)|0);
      var $198=HEAP32[(($197)>>2)];
      var $199=$1;
      var $200=(($199+356)|0);
      var $201=HEAP32[(($200)>>2)];
      var $202=$1;
      var $203=(($202+324)|0);
      var $204=HEAP32[(($203)>>2)];
      _png_do_background($173, $177, $179, $181, $183, $186, $189, $192, $195, $198, $201, $204);
      __label__ = 30; break;
    case 30: 
      var $206=$1;
      var $207=(($206+92)|0);
      var $208=HEAP32[(($207)>>2)];
      var $209=$208 & 8192;
      var $210=(($209)|0)!=0;
      if ($210) { __label__ = 31; break; } else { __label__ = 36; break; }
    case 31: 
      var $212=$1;
      var $213=(($212+92)|0);
      var $214=HEAP32[(($213)>>2)];
      var $215=$214 & 128;
      var $216=(($215)|0)!=0;
      if ($216) { __label__ = 32; break; } else { __label__ = 34; break; }
    case 32: 
      var $218=$1;
      var $219=(($218+262)|0);
      var $220=HEAPU16[(($219)>>1)];
      var $221=(($220)&65535);
      var $222=(($221)|0)!=0;
      if ($222) { __label__ = 36; break; } else { __label__ = 33; break; }
    case 33: 
      var $224=$1;
      var $225=(($224+274)|0);
      var $226=HEAPU8[($225)];
      var $227=(($226)&255);
      var $228=$227 & 4;
      var $229=(($228)|0)!=0;
      if ($229) { __label__ = 36; break; } else { __label__ = 34; break; }
    case 34: 
      var $231=$1;
      var $232=(($231+274)|0);
      var $233=HEAPU8[($232)];
      var $234=(($233)&255);
      var $235=(($234)|0)!=3;
      if ($235) { __label__ = 35; break; } else { __label__ = 36; break; }
    case 35: 
      var $237=$1;
      var $238=(($237+236)|0);
      var $239=$1;
      var $240=(($239+216)|0);
      var $241=HEAP32[(($240)>>2)];
      var $242=(($241+1)|0);
      var $243=$1;
      var $244=(($243+336)|0);
      var $245=HEAP32[(($244)>>2)];
      var $246=$1;
      var $247=(($246+348)|0);
      var $248=HEAP32[(($247)>>2)];
      var $249=$1;
      var $250=(($249+324)|0);
      var $251=HEAP32[(($250)>>2)];
      _png_do_gamma($238, $242, $245, $248, $251);
      __label__ = 36; break;
    case 36: 
      var $253=$1;
      var $254=(($253+92)|0);
      var $255=HEAP32[(($254)>>2)];
      var $256=$255 & 1024;
      var $257=(($256)|0)!=0;
      if ($257) { __label__ = 37; break; } else { __label__ = 38; break; }
    case 37: 
      var $259=$1;
      var $260=(($259+236)|0);
      var $261=$1;
      var $262=(($261+216)|0);
      var $263=HEAP32[(($262)>>2)];
      var $264=(($263+1)|0);
      _png_do_chop($260, $264);
      __label__ = 38; break;
    case 38: 
      var $266=$1;
      var $267=(($266+92)|0);
      var $268=HEAP32[(($267)>>2)];
      var $269=$268 & 64;
      var $270=(($269)|0)!=0;
      if ($270) { __label__ = 39; break; } else { __label__ = 42; break; }
    case 39: 
      var $272=$1;
      var $273=(($272+236)|0);
      var $274=$1;
      var $275=(($274+216)|0);
      var $276=HEAP32[(($275)>>2)];
      var $277=(($276+1)|0);
      var $278=$1;
      var $279=(($278+472)|0);
      var $280=HEAP32[(($279)>>2)];
      var $281=$1;
      var $282=(($281+476)|0);
      var $283=HEAP32[(($282)>>2)];
      _png_do_quantize($273, $277, $280, $283);
      var $284=$1;
      var $285=(($284+236)|0);
      var $286=(($285+4)|0);
      var $287=HEAP32[(($286)>>2)];
      var $288=(($287)|0)==0;
      if ($288) { __label__ = 40; break; } else { __label__ = 41; break; }
    case 40: 
      var $290=$1;
      _png_error($290, ((STRING_TABLE.__str7177)|0));
      __label__ = 41; break;
    case 41: 
      __label__ = 42; break;
    case 42: 
      var $293=$1;
      var $294=(($293+92)|0);
      var $295=HEAP32[(($294)>>2)];
      var $296=$295 & 32;
      var $297=(($296)|0)!=0;
      if ($297) { __label__ = 43; break; } else { __label__ = 44; break; }
    case 43: 
      var $299=$1;
      var $300=(($299+236)|0);
      var $301=$1;
      var $302=(($301+216)|0);
      var $303=HEAP32[(($302)>>2)];
      var $304=(($303+1)|0);
      _png_do_invert($300, $304);
      __label__ = 44; break;
    case 44: 
      var $306=$1;
      var $307=(($306+92)|0);
      var $308=HEAP32[(($307)>>2)];
      var $309=$308 & 8;
      var $310=(($309)|0)!=0;
      if ($310) { __label__ = 45; break; } else { __label__ = 46; break; }
    case 45: 
      var $312=$1;
      var $313=(($312+236)|0);
      var $314=$1;
      var $315=(($314+216)|0);
      var $316=HEAP32[(($315)>>2)];
      var $317=(($316+1)|0);
      var $318=$1;
      var $319=(($318+365)|0);
      _png_do_unshift($313, $317, $319);
      __label__ = 46; break;
    case 46: 
      var $321=$1;
      var $322=(($321+92)|0);
      var $323=HEAP32[(($322)>>2)];
      var $324=$323 & 4;
      var $325=(($324)|0)!=0;
      if ($325) { __label__ = 47; break; } else { __label__ = 48; break; }
    case 47: 
      var $327=$1;
      var $328=(($327+236)|0);
      var $329=$1;
      var $330=(($329+216)|0);
      var $331=HEAP32[(($330)>>2)];
      var $332=(($331+1)|0);
      _png_do_unpack($328, $332);
      __label__ = 48; break;
    case 48: 
      var $334=$1;
      var $335=(($334+92)|0);
      var $336=HEAP32[(($335)>>2)];
      var $337=$336 & 1;
      var $338=(($337)|0)!=0;
      if ($338) { __label__ = 49; break; } else { __label__ = 50; break; }
    case 49: 
      var $340=$1;
      var $341=(($340+236)|0);
      var $342=$1;
      var $343=(($342+216)|0);
      var $344=HEAP32[(($343)>>2)];
      var $345=(($344+1)|0);
      _png_do_bgr($341, $345);
      __label__ = 50; break;
    case 50: 
      var $347=$1;
      var $348=(($347+92)|0);
      var $349=HEAP32[(($348)>>2)];
      var $350=$349 & 65536;
      var $351=(($350)|0)!=0;
      if ($351) { __label__ = 51; break; } else { __label__ = 52; break; }
    case 51: 
      var $353=$1;
      var $354=(($353+236)|0);
      var $355=$1;
      var $356=(($355+216)|0);
      var $357=HEAP32[(($356)>>2)];
      var $358=(($357+1)|0);
      _png_do_packswap($354, $358);
      __label__ = 52; break;
    case 52: 
      var $360=$1;
      var $361=(($360+92)|0);
      var $362=HEAP32[(($361)>>2)];
      var $363=$362 & 16384;
      var $364=(($363)|0)!=0;
      if ($364) { __label__ = 53; break; } else { __label__ = 55; break; }
    case 53: 
      var $366=$1;
      var $367=(($366+84)|0);
      var $368=HEAP32[(($367)>>2)];
      var $369=$368 & 2048;
      var $370=(($369)|0)!=0;
      if ($370) { __label__ = 54; break; } else { __label__ = 55; break; }
    case 54: 
      var $372=$1;
      var $373=(($372+236)|0);
      var $374=$1;
      var $375=(($374+216)|0);
      var $376=HEAP32[(($375)>>2)];
      var $377=(($376+1)|0);
      _png_do_gray_to_rgb($373, $377);
      __label__ = 55; break;
    case 55: 
      var $379=$1;
      var $380=(($379+92)|0);
      var $381=HEAP32[(($380)>>2)];
      var $382=$381 & 32768;
      var $383=(($382)|0)!=0;
      if ($383) { __label__ = 56; break; } else { __label__ = 57; break; }
    case 56: 
      var $385=$1;
      var $386=(($385+236)|0);
      var $387=$1;
      var $388=(($387+216)|0);
      var $389=HEAP32[(($388)>>2)];
      var $390=(($389+1)|0);
      var $391=$1;
      var $392=(($391+282)|0);
      var $393=HEAPU16[(($392)>>1)];
      var $394=(($393)&65535);
      var $395=$1;
      var $396=(($395+88)|0);
      var $397=HEAP32[(($396)>>2)];
      _png_do_read_filler($386, $390, $394, $397);
      __label__ = 57; break;
    case 57: 
      var $399=$1;
      var $400=(($399+92)|0);
      var $401=HEAP32[(($400)>>2)];
      var $402=$401 & 524288;
      var $403=(($402)|0)!=0;
      if ($403) { __label__ = 58; break; } else { __label__ = 59; break; }
    case 58: 
      var $405=$1;
      var $406=(($405+236)|0);
      var $407=$1;
      var $408=(($407+216)|0);
      var $409=HEAP32[(($408)>>2)];
      var $410=(($409+1)|0);
      _png_do_read_invert_alpha($406, $410);
      __label__ = 59; break;
    case 59: 
      var $412=$1;
      var $413=(($412+92)|0);
      var $414=HEAP32[(($413)>>2)];
      var $415=$414 & 131072;
      var $416=(($415)|0)!=0;
      if ($416) { __label__ = 60; break; } else { __label__ = 61; break; }
    case 60: 
      var $418=$1;
      var $419=(($418+236)|0);
      var $420=$1;
      var $421=(($420+216)|0);
      var $422=HEAP32[(($421)>>2)];
      var $423=(($422+1)|0);
      _png_do_read_swap_alpha($419, $423);
      __label__ = 61; break;
    case 61: 
      var $425=$1;
      var $426=(($425+92)|0);
      var $427=HEAP32[(($426)>>2)];
      var $428=$427 & 16;
      var $429=(($428)|0)!=0;
      if ($429) { __label__ = 62; break; } else { __label__ = 63; break; }
    case 62: 
      var $431=$1;
      var $432=(($431+236)|0);
      var $433=$1;
      var $434=(($433+216)|0);
      var $435=HEAP32[(($434)>>2)];
      var $436=(($435+1)|0);
      _png_do_swap($432, $436);
      __label__ = 63; break;
    case 63: 
      var $438=$1;
      var $439=(($438+92)|0);
      var $440=HEAP32[(($439)>>2)];
      var $441=$440 & 1048576;
      var $442=(($441)|0)!=0;
      if ($442) { __label__ = 64; break; } else { __label__ = 74; break; }
    case 64: 
      var $444=$1;
      var $445=(($444+68)|0);
      var $446=HEAP32[(($445)>>2)];
      var $447=(($446)|0)!=0;
      if ($447) { __label__ = 65; break; } else { __label__ = 66; break; }
    case 65: 
      var $449=$1;
      var $450=(($449+68)|0);
      var $451=HEAP32[(($450)>>2)];
      var $452=$1;
      var $453=$1;
      var $454=(($453+236)|0);
      var $455=$1;
      var $456=(($455+216)|0);
      var $457=HEAP32[(($456)>>2)];
      var $458=(($457+1)|0);
      FUNCTION_TABLE[$451]($452, $454, $458);
      __label__ = 66; break;
    case 66: 
      var $460=$1;
      var $461=(($460+80)|0);
      var $462=HEAP8[($461)];
      var $463=(($462 << 24) >> 24)!=0;
      if ($463) { __label__ = 67; break; } else { __label__ = 68; break; }
    case 67: 
      var $465=$1;
      var $466=(($465+80)|0);
      var $467=HEAP8[($466)];
      var $468=$1;
      var $469=(($468+236)|0);
      var $470=(($469+9)|0);
      HEAP8[($470)]=$467;
      __label__ = 68; break;
    case 68: 
      var $472=$1;
      var $473=(($472+81)|0);
      var $474=HEAP8[($473)];
      var $475=(($474 << 24) >> 24)!=0;
      if ($475) { __label__ = 69; break; } else { __label__ = 70; break; }
    case 69: 
      var $477=$1;
      var $478=(($477+81)|0);
      var $479=HEAP8[($478)];
      var $480=$1;
      var $481=(($480+236)|0);
      var $482=(($481+10)|0);
      HEAP8[($482)]=$479;
      __label__ = 70; break;
    case 70: 
      var $484=$1;
      var $485=(($484+236)|0);
      var $486=(($485+9)|0);
      var $487=HEAPU8[($486)];
      var $488=(($487)&255);
      var $489=$1;
      var $490=(($489+236)|0);
      var $491=(($490+10)|0);
      var $492=HEAPU8[($491)];
      var $493=(($492)&255);
      var $494=((($488)*($493))|0);
      var $495=(($494) & 255);
      var $496=$1;
      var $497=(($496+236)|0);
      var $498=(($497+11)|0);
      HEAP8[($498)]=$495;
      var $499=$1;
      var $500=(($499+236)|0);
      var $501=(($500+11)|0);
      var $502=HEAPU8[($501)];
      var $503=(($502)&255);
      var $504=(($503)|0) >= 8;
      if ($504) { __label__ = 71; break; } else { __label__ = 72; break; }
    case 71: 
      var $506=$1;
      var $507=(($506+236)|0);
      var $508=(($507)|0);
      var $509=HEAP32[(($508)>>2)];
      var $510=$1;
      var $511=(($510+236)|0);
      var $512=(($511+11)|0);
      var $513=HEAPU8[($512)];
      var $514=(($513)&255);
      var $515=$514 >>> 3;
      var $516=((($509)*($515))|0);
      var $531 = $516;__label__ = 73; break;
    case 72: 
      var $518=$1;
      var $519=(($518+236)|0);
      var $520=(($519)|0);
      var $521=HEAP32[(($520)>>2)];
      var $522=$1;
      var $523=(($522+236)|0);
      var $524=(($523+11)|0);
      var $525=HEAPU8[($524)];
      var $526=(($525)&255);
      var $527=((($521)*($526))|0);
      var $528=((($527)+(7))|0);
      var $529=$528 >>> 3;
      var $531 = $529;__label__ = 73; break;
    case 73: 
      var $531;
      var $532=$1;
      var $533=(($532+236)|0);
      var $534=(($533+4)|0);
      HEAP32[(($534)>>2)]=$531;
      __label__ = 74; break;
    case 74: 
      STACKTOP = __stackBase__;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_png_do_read_transformations["X"]=1;

function _png_do_expand_palette($row_info, $row, $palette, $trans_alpha, $num_trans) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $5;
      var $shift;
      var $value;
      var $sp;
      var $dp;
      var $i;
      var $row_width;
      $1=$row_info;
      $2=$row;
      $3=$palette;
      $4=$trans_alpha;
      $5=$num_trans;
      var $6=$1;
      var $7=(($6)|0);
      var $8=HEAP32[(($7)>>2)];
      $row_width=$8;
      var $9=$1;
      var $10=(($9+8)|0);
      var $11=HEAPU8[($10)];
      var $12=(($11)&255);
      var $13=(($12)|0)==3;
      if ($13) { __label__ = 3; break; } else { __label__ = 51; break; }
    case 3: 
      var $15=$1;
      var $16=(($15+9)|0);
      var $17=HEAPU8[($16)];
      var $18=(($17)&255);
      var $19=(($18)|0) < 8;
      if ($19) { __label__ = 4; break; } else { __label__ = 34; break; }
    case 4: 
      var $21=$1;
      var $22=(($21+9)|0);
      var $23=HEAPU8[($22)];
      var $24=(($23)&255);
      if ((($24)|0) == 1) {
        __label__ = 5; break;
      }
      else if ((($24)|0) == 2) {
        __label__ = 16; break;
      }
      else if ((($24)|0) == 4) {
        __label__ = 24; break;
      }
      else {
      __label__ = 32; break;
      }
      
    case 5: 
      var $26=$2;
      var $27=$row_width;
      var $28=((($27)-(1))|0);
      var $29=$28 >>> 3;
      var $30=(($26+$29)|0);
      $sp=$30;
      var $31=$2;
      var $32=$row_width;
      var $33=(($31+$32)|0);
      var $34=((($33)-(1))|0);
      $dp=$34;
      var $35=$row_width;
      var $36=((($35)+(7))|0);
      var $37=$36 & 7;
      var $38=(((7)-($37))|0);
      $shift=$38;
      $i=0;
      __label__ = 6; break;
    case 6: 
      var $40=$i;
      var $41=$row_width;
      var $42=(($40)>>>0) < (($41)>>>0);
      if ($42) { __label__ = 7; break; } else { __label__ = 15; break; }
    case 7: 
      var $44=$sp;
      var $45=HEAPU8[($44)];
      var $46=(($45)&255);
      var $47=$shift;
      var $48=$46 >> (($47)|0);
      var $49=$48 & 1;
      var $50=(($49)|0)!=0;
      if ($50) { __label__ = 8; break; } else { __label__ = 9; break; }
    case 8: 
      var $52=$dp;
      HEAP8[($52)]=1;
      __label__ = 10; break;
    case 9: 
      var $54=$dp;
      HEAP8[($54)]=0;
      __label__ = 10; break;
    case 10: 
      var $56=$shift;
      var $57=(($56)|0)==7;
      if ($57) { __label__ = 11; break; } else { __label__ = 12; break; }
    case 11: 
      $shift=0;
      var $59=$sp;
      var $60=((($59)-(1))|0);
      $sp=$60;
      __label__ = 13; break;
    case 12: 
      var $62=$shift;
      var $63=((($62)+(1))|0);
      $shift=$63;
      __label__ = 13; break;
    case 13: 
      var $65=$dp;
      var $66=((($65)-(1))|0);
      $dp=$66;
      __label__ = 14; break;
    case 14: 
      var $68=$i;
      var $69=((($68)+(1))|0);
      $i=$69;
      __label__ = 6; break;
    case 15: 
      __label__ = 33; break;
    case 16: 
      var $72=$2;
      var $73=$row_width;
      var $74=((($73)-(1))|0);
      var $75=$74 >>> 2;
      var $76=(($72+$75)|0);
      $sp=$76;
      var $77=$2;
      var $78=$row_width;
      var $79=(($77+$78)|0);
      var $80=((($79)-(1))|0);
      $dp=$80;
      var $81=$row_width;
      var $82=((($81)+(3))|0);
      var $83=$82 & 3;
      var $84=(((3)-($83))|0);
      var $85=$84 << 1;
      $shift=$85;
      $i=0;
      __label__ = 17; break;
    case 17: 
      var $87=$i;
      var $88=$row_width;
      var $89=(($87)>>>0) < (($88)>>>0);
      if ($89) { __label__ = 18; break; } else { __label__ = 23; break; }
    case 18: 
      var $91=$sp;
      var $92=HEAPU8[($91)];
      var $93=(($92)&255);
      var $94=$shift;
      var $95=$93 >> (($94)|0);
      var $96=$95 & 3;
      $value=$96;
      var $97=$value;
      var $98=(($97) & 255);
      var $99=$dp;
      HEAP8[($99)]=$98;
      var $100=$shift;
      var $101=(($100)|0)==6;
      if ($101) { __label__ = 19; break; } else { __label__ = 20; break; }
    case 19: 
      $shift=0;
      var $103=$sp;
      var $104=((($103)-(1))|0);
      $sp=$104;
      __label__ = 21; break;
    case 20: 
      var $106=$shift;
      var $107=((($106)+(2))|0);
      $shift=$107;
      __label__ = 21; break;
    case 21: 
      var $109=$dp;
      var $110=((($109)-(1))|0);
      $dp=$110;
      __label__ = 22; break;
    case 22: 
      var $112=$i;
      var $113=((($112)+(1))|0);
      $i=$113;
      __label__ = 17; break;
    case 23: 
      __label__ = 33; break;
    case 24: 
      var $116=$2;
      var $117=$row_width;
      var $118=((($117)-(1))|0);
      var $119=$118 >>> 1;
      var $120=(($116+$119)|0);
      $sp=$120;
      var $121=$2;
      var $122=$row_width;
      var $123=(($121+$122)|0);
      var $124=((($123)-(1))|0);
      $dp=$124;
      var $125=$row_width;
      var $126=$125 & 1;
      var $127=$126 << 2;
      $shift=$127;
      $i=0;
      __label__ = 25; break;
    case 25: 
      var $129=$i;
      var $130=$row_width;
      var $131=(($129)>>>0) < (($130)>>>0);
      if ($131) { __label__ = 26; break; } else { __label__ = 31; break; }
    case 26: 
      var $133=$sp;
      var $134=HEAPU8[($133)];
      var $135=(($134)&255);
      var $136=$shift;
      var $137=$135 >> (($136)|0);
      var $138=$137 & 15;
      $value=$138;
      var $139=$value;
      var $140=(($139) & 255);
      var $141=$dp;
      HEAP8[($141)]=$140;
      var $142=$shift;
      var $143=(($142)|0)==4;
      if ($143) { __label__ = 27; break; } else { __label__ = 28; break; }
    case 27: 
      $shift=0;
      var $145=$sp;
      var $146=((($145)-(1))|0);
      $sp=$146;
      __label__ = 29; break;
    case 28: 
      var $148=$shift;
      var $149=((($148)+(4))|0);
      $shift=$149;
      __label__ = 29; break;
    case 29: 
      var $151=$dp;
      var $152=((($151)-(1))|0);
      $dp=$152;
      __label__ = 30; break;
    case 30: 
      var $154=$i;
      var $155=((($154)+(1))|0);
      $i=$155;
      __label__ = 25; break;
    case 31: 
      __label__ = 33; break;
    case 32: 
      __label__ = 33; break;
    case 33: 
      var $159=$1;
      var $160=(($159+9)|0);
      HEAP8[($160)]=8;
      var $161=$1;
      var $162=(($161+11)|0);
      HEAP8[($162)]=8;
      var $163=$row_width;
      var $164=$1;
      var $165=(($164+4)|0);
      HEAP32[(($165)>>2)]=$163;
      __label__ = 34; break;
    case 34: 
      var $167=$1;
      var $168=(($167+9)|0);
      var $169=HEAPU8[($168)];
      var $170=(($169)&255);
      if ((($170)|0) == 8) {
        __label__ = 35; break;
      }
      else {
      __label__ = 50; break;
      }
      
    case 35: 
      var $172=$4;
      var $173=(($172)|0)!=0;
      if ($173) { __label__ = 36; break; } else { __label__ = 44; break; }
    case 36: 
      var $175=$2;
      var $176=$row_width;
      var $177=(($175+$176)|0);
      var $178=((($177)-(1))|0);
      $sp=$178;
      var $179=$2;
      var $180=$row_width;
      var $181=$180 << 2;
      var $182=(($179+$181)|0);
      var $183=((($182)-(1))|0);
      $dp=$183;
      $i=0;
      __label__ = 37; break;
    case 37: 
      var $185=$i;
      var $186=$row_width;
      var $187=(($185)>>>0) < (($186)>>>0);
      if ($187) { __label__ = 38; break; } else { __label__ = 43; break; }
    case 38: 
      var $189=$sp;
      var $190=HEAPU8[($189)];
      var $191=(($190)&255);
      var $192=$5;
      var $193=(($191)|0) >= (($192)|0);
      if ($193) { __label__ = 39; break; } else { __label__ = 40; break; }
    case 39: 
      var $195=$dp;
      var $196=((($195)-(1))|0);
      $dp=$196;
      HEAP8[($195)]=-1;
      __label__ = 41; break;
    case 40: 
      var $198=$sp;
      var $199=HEAPU8[($198)];
      var $200=(($199)&255);
      var $201=$4;
      var $202=(($201+$200)|0);
      var $203=HEAP8[($202)];
      var $204=$dp;
      var $205=((($204)-(1))|0);
      $dp=$205;
      HEAP8[($204)]=$203;
      __label__ = 41; break;
    case 41: 
      var $207=$sp;
      var $208=HEAPU8[($207)];
      var $209=(($208)&255);
      var $210=$3;
      var $211=(($210+($209)*(3))|0);
      var $212=(($211+2)|0);
      var $213=HEAP8[($212)];
      var $214=$dp;
      var $215=((($214)-(1))|0);
      $dp=$215;
      HEAP8[($214)]=$213;
      var $216=$sp;
      var $217=HEAPU8[($216)];
      var $218=(($217)&255);
      var $219=$3;
      var $220=(($219+($218)*(3))|0);
      var $221=(($220+1)|0);
      var $222=HEAP8[($221)];
      var $223=$dp;
      var $224=((($223)-(1))|0);
      $dp=$224;
      HEAP8[($223)]=$222;
      var $225=$sp;
      var $226=HEAPU8[($225)];
      var $227=(($226)&255);
      var $228=$3;
      var $229=(($228+($227)*(3))|0);
      var $230=(($229)|0);
      var $231=HEAP8[($230)];
      var $232=$dp;
      var $233=((($232)-(1))|0);
      $dp=$233;
      HEAP8[($232)]=$231;
      var $234=$sp;
      var $235=((($234)-(1))|0);
      $sp=$235;
      __label__ = 42; break;
    case 42: 
      var $237=$i;
      var $238=((($237)+(1))|0);
      $i=$238;
      __label__ = 37; break;
    case 43: 
      var $240=$1;
      var $241=(($240+9)|0);
      HEAP8[($241)]=8;
      var $242=$1;
      var $243=(($242+11)|0);
      HEAP8[($243)]=32;
      var $244=$row_width;
      var $245=((($244<<2))|0);
      var $246=$1;
      var $247=(($246+4)|0);
      HEAP32[(($247)>>2)]=$245;
      var $248=$1;
      var $249=(($248+8)|0);
      HEAP8[($249)]=6;
      var $250=$1;
      var $251=(($250+10)|0);
      HEAP8[($251)]=4;
      __label__ = 49; break;
    case 44: 
      var $253=$2;
      var $254=$row_width;
      var $255=(($253+$254)|0);
      var $256=((($255)-(1))|0);
      $sp=$256;
      var $257=$2;
      var $258=$row_width;
      var $259=((($258)*(3))|0);
      var $260=(($257+$259)|0);
      var $261=((($260)-(1))|0);
      $dp=$261;
      $i=0;
      __label__ = 45; break;
    case 45: 
      var $263=$i;
      var $264=$row_width;
      var $265=(($263)>>>0) < (($264)>>>0);
      if ($265) { __label__ = 46; break; } else { __label__ = 48; break; }
    case 46: 
      var $267=$sp;
      var $268=HEAPU8[($267)];
      var $269=(($268)&255);
      var $270=$3;
      var $271=(($270+($269)*(3))|0);
      var $272=(($271+2)|0);
      var $273=HEAP8[($272)];
      var $274=$dp;
      var $275=((($274)-(1))|0);
      $dp=$275;
      HEAP8[($274)]=$273;
      var $276=$sp;
      var $277=HEAPU8[($276)];
      var $278=(($277)&255);
      var $279=$3;
      var $280=(($279+($278)*(3))|0);
      var $281=(($280+1)|0);
      var $282=HEAP8[($281)];
      var $283=$dp;
      var $284=((($283)-(1))|0);
      $dp=$284;
      HEAP8[($283)]=$282;
      var $285=$sp;
      var $286=HEAPU8[($285)];
      var $287=(($286)&255);
      var $288=$3;
      var $289=(($288+($287)*(3))|0);
      var $290=(($289)|0);
      var $291=HEAP8[($290)];
      var $292=$dp;
      var $293=((($292)-(1))|0);
      $dp=$293;
      HEAP8[($292)]=$291;
      var $294=$sp;
      var $295=((($294)-(1))|0);
      $sp=$295;
      __label__ = 47; break;
    case 47: 
      var $297=$i;
      var $298=((($297)+(1))|0);
      $i=$298;
      __label__ = 45; break;
    case 48: 
      var $300=$1;
      var $301=(($300+9)|0);
      HEAP8[($301)]=8;
      var $302=$1;
      var $303=(($302+11)|0);
      HEAP8[($303)]=24;
      var $304=$row_width;
      var $305=((($304)*(3))|0);
      var $306=$1;
      var $307=(($306+4)|0);
      HEAP32[(($307)>>2)]=$305;
      var $308=$1;
      var $309=(($308+8)|0);
      HEAP8[($309)]=2;
      var $310=$1;
      var $311=(($310+10)|0);
      HEAP8[($311)]=3;
      __label__ = 49; break;
    case 49: 
      __label__ = 50; break;
    case 50: 
      __label__ = 51; break;
    case 51: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_png_do_expand_palette["X"]=1;

function _png_do_expand($row_info, $row, $trans_value) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $shift;
      var $value;
      var $sp;
      var $dp;
      var $i;
      var $row_width;
      var $gray;
      var $gray_high;
      var $gray_low;
      var $red;
      var $green;
      var $blue;
      var $red_high;
      var $green_high;
      var $blue_high;
      var $red_low;
      var $green_low;
      var $blue_low;
      $1=$row_info;
      $2=$row;
      $3=$trans_value;
      var $4=$1;
      var $5=(($4)|0);
      var $6=HEAP32[(($5)>>2)];
      $row_width=$6;
      var $7=$1;
      var $8=(($7+8)|0);
      var $9=HEAPU8[($8)];
      var $10=(($9)&255);
      var $11=(($10)|0)==0;
      if ($11) { __label__ = 3; break; } else { __label__ = 63; break; }
    case 3: 
      var $13=$3;
      var $14=(($13)|0)!=0;
      if ($14) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      var $16=$3;
      var $17=(($16+8)|0);
      var $18=HEAPU16[(($17)>>1)];
      var $19=(($18)&65535);
      var $22 = $19;__label__ = 6; break;
    case 5: 
      var $22 = 0;__label__ = 6; break;
    case 6: 
      var $22;
      var $23=(($22) & 65535);
      $gray=$23;
      var $24=$1;
      var $25=(($24+9)|0);
      var $26=HEAPU8[($25)];
      var $27=(($26)&255);
      var $28=(($27)|0) < 8;
      if ($28) { __label__ = 7; break; } else { __label__ = 37; break; }
    case 7: 
      var $30=$1;
      var $31=(($30+9)|0);
      var $32=HEAPU8[($31)];
      var $33=(($32)&255);
      if ((($33)|0) == 1) {
        __label__ = 8; break;
      }
      else if ((($33)|0) == 2) {
        __label__ = 19; break;
      }
      else if ((($33)|0) == 4) {
        __label__ = 27; break;
      }
      else {
      __label__ = 35; break;
      }
      
    case 8: 
      var $35=$gray;
      var $36=(($35)&65535);
      var $37=$36 & 1;
      var $38=((($37)*(255))|0);
      var $39=(($38) & 65535);
      $gray=$39;
      var $40=$2;
      var $41=$row_width;
      var $42=((($41)-(1))|0);
      var $43=$42 >>> 3;
      var $44=(($40+$43)|0);
      $sp=$44;
      var $45=$2;
      var $46=$row_width;
      var $47=(($45+$46)|0);
      var $48=((($47)-(1))|0);
      $dp=$48;
      var $49=$row_width;
      var $50=((($49)+(7))|0);
      var $51=$50 & 7;
      var $52=(((7)-($51))|0);
      $shift=$52;
      $i=0;
      __label__ = 9; break;
    case 9: 
      var $54=$i;
      var $55=$row_width;
      var $56=(($54)>>>0) < (($55)>>>0);
      if ($56) { __label__ = 10; break; } else { __label__ = 18; break; }
    case 10: 
      var $58=$sp;
      var $59=HEAPU8[($58)];
      var $60=(($59)&255);
      var $61=$shift;
      var $62=$60 >> (($61)|0);
      var $63=$62 & 1;
      var $64=(($63)|0)!=0;
      if ($64) { __label__ = 11; break; } else { __label__ = 12; break; }
    case 11: 
      var $66=$dp;
      HEAP8[($66)]=-1;
      __label__ = 13; break;
    case 12: 
      var $68=$dp;
      HEAP8[($68)]=0;
      __label__ = 13; break;
    case 13: 
      var $70=$shift;
      var $71=(($70)|0)==7;
      if ($71) { __label__ = 14; break; } else { __label__ = 15; break; }
    case 14: 
      $shift=0;
      var $73=$sp;
      var $74=((($73)-(1))|0);
      $sp=$74;
      __label__ = 16; break;
    case 15: 
      var $76=$shift;
      var $77=((($76)+(1))|0);
      $shift=$77;
      __label__ = 16; break;
    case 16: 
      var $79=$dp;
      var $80=((($79)-(1))|0);
      $dp=$80;
      __label__ = 17; break;
    case 17: 
      var $82=$i;
      var $83=((($82)+(1))|0);
      $i=$83;
      __label__ = 9; break;
    case 18: 
      __label__ = 36; break;
    case 19: 
      var $86=$gray;
      var $87=(($86)&65535);
      var $88=$87 & 3;
      var $89=((($88)*(85))|0);
      var $90=(($89) & 65535);
      $gray=$90;
      var $91=$2;
      var $92=$row_width;
      var $93=((($92)-(1))|0);
      var $94=$93 >>> 2;
      var $95=(($91+$94)|0);
      $sp=$95;
      var $96=$2;
      var $97=$row_width;
      var $98=(($96+$97)|0);
      var $99=((($98)-(1))|0);
      $dp=$99;
      var $100=$row_width;
      var $101=((($100)+(3))|0);
      var $102=$101 & 3;
      var $103=(((3)-($102))|0);
      var $104=$103 << 1;
      $shift=$104;
      $i=0;
      __label__ = 20; break;
    case 20: 
      var $106=$i;
      var $107=$row_width;
      var $108=(($106)>>>0) < (($107)>>>0);
      if ($108) { __label__ = 21; break; } else { __label__ = 26; break; }
    case 21: 
      var $110=$sp;
      var $111=HEAPU8[($110)];
      var $112=(($111)&255);
      var $113=$shift;
      var $114=$112 >> (($113)|0);
      var $115=$114 & 3;
      $value=$115;
      var $116=$value;
      var $117=$value;
      var $118=$117 << 2;
      var $119=$116 | $118;
      var $120=$value;
      var $121=$120 << 4;
      var $122=$119 | $121;
      var $123=$value;
      var $124=$123 << 6;
      var $125=$122 | $124;
      var $126=(($125) & 255);
      var $127=$dp;
      HEAP8[($127)]=$126;
      var $128=$shift;
      var $129=(($128)|0)==6;
      if ($129) { __label__ = 22; break; } else { __label__ = 23; break; }
    case 22: 
      $shift=0;
      var $131=$sp;
      var $132=((($131)-(1))|0);
      $sp=$132;
      __label__ = 24; break;
    case 23: 
      var $134=$shift;
      var $135=((($134)+(2))|0);
      $shift=$135;
      __label__ = 24; break;
    case 24: 
      var $137=$dp;
      var $138=((($137)-(1))|0);
      $dp=$138;
      __label__ = 25; break;
    case 25: 
      var $140=$i;
      var $141=((($140)+(1))|0);
      $i=$141;
      __label__ = 20; break;
    case 26: 
      __label__ = 36; break;
    case 27: 
      var $144=$gray;
      var $145=(($144)&65535);
      var $146=$145 & 15;
      var $147=((($146)*(17))|0);
      var $148=(($147) & 65535);
      $gray=$148;
      var $149=$2;
      var $150=$row_width;
      var $151=((($150)-(1))|0);
      var $152=$151 >>> 1;
      var $153=(($149+$152)|0);
      $sp=$153;
      var $154=$2;
      var $155=$row_width;
      var $156=(($154+$155)|0);
      var $157=((($156)-(1))|0);
      $dp=$157;
      var $158=$row_width;
      var $159=((($158)+(1))|0);
      var $160=$159 & 1;
      var $161=(((1)-($160))|0);
      var $162=$161 << 2;
      $shift=$162;
      $i=0;
      __label__ = 28; break;
    case 28: 
      var $164=$i;
      var $165=$row_width;
      var $166=(($164)>>>0) < (($165)>>>0);
      if ($166) { __label__ = 29; break; } else { __label__ = 34; break; }
    case 29: 
      var $168=$sp;
      var $169=HEAPU8[($168)];
      var $170=(($169)&255);
      var $171=$shift;
      var $172=$170 >> (($171)|0);
      var $173=$172 & 15;
      $value=$173;
      var $174=$value;
      var $175=$value;
      var $176=$175 << 4;
      var $177=$174 | $176;
      var $178=(($177) & 255);
      var $179=$dp;
      HEAP8[($179)]=$178;
      var $180=$shift;
      var $181=(($180)|0)==4;
      if ($181) { __label__ = 30; break; } else { __label__ = 31; break; }
    case 30: 
      $shift=0;
      var $183=$sp;
      var $184=((($183)-(1))|0);
      $sp=$184;
      __label__ = 32; break;
    case 31: 
      $shift=4;
      __label__ = 32; break;
    case 32: 
      var $187=$dp;
      var $188=((($187)-(1))|0);
      $dp=$188;
      __label__ = 33; break;
    case 33: 
      var $190=$i;
      var $191=((($190)+(1))|0);
      $i=$191;
      __label__ = 28; break;
    case 34: 
      __label__ = 36; break;
    case 35: 
      __label__ = 36; break;
    case 36: 
      var $195=$1;
      var $196=(($195+9)|0);
      HEAP8[($196)]=8;
      var $197=$1;
      var $198=(($197+11)|0);
      HEAP8[($198)]=8;
      var $199=$row_width;
      var $200=$1;
      var $201=(($200+4)|0);
      HEAP32[(($201)>>2)]=$199;
      __label__ = 37; break;
    case 37: 
      var $203=$3;
      var $204=(($203)|0)!=0;
      if ($204) { __label__ = 38; break; } else { __label__ = 62; break; }
    case 38: 
      var $206=$1;
      var $207=(($206+9)|0);
      var $208=HEAPU8[($207)];
      var $209=(($208)&255);
      var $210=(($209)|0)==8;
      if ($210) { __label__ = 39; break; } else { __label__ = 47; break; }
    case 39: 
      var $212=$gray;
      var $213=(($212)&65535);
      var $214=$213 & 255;
      var $215=(($214) & 65535);
      $gray=$215;
      var $216=$2;
      var $217=$row_width;
      var $218=(($216+$217)|0);
      var $219=((($218)-(1))|0);
      $sp=$219;
      var $220=$2;
      var $221=$row_width;
      var $222=$221 << 1;
      var $223=(($220+$222)|0);
      var $224=((($223)-(1))|0);
      $dp=$224;
      $i=0;
      __label__ = 40; break;
    case 40: 
      var $226=$i;
      var $227=$row_width;
      var $228=(($226)>>>0) < (($227)>>>0);
      if ($228) { __label__ = 41; break; } else { __label__ = 46; break; }
    case 41: 
      var $230=$sp;
      var $231=HEAPU8[($230)];
      var $232=(($231)&255);
      var $233=$gray;
      var $234=(($233)&65535);
      var $235=(($232)|0)==(($234)|0);
      if ($235) { __label__ = 42; break; } else { __label__ = 43; break; }
    case 42: 
      var $237=$dp;
      var $238=((($237)-(1))|0);
      $dp=$238;
      HEAP8[($237)]=0;
      __label__ = 44; break;
    case 43: 
      var $240=$dp;
      var $241=((($240)-(1))|0);
      $dp=$241;
      HEAP8[($240)]=-1;
      __label__ = 44; break;
    case 44: 
      var $243=$sp;
      var $244=((($243)-(1))|0);
      $sp=$244;
      var $245=HEAP8[($243)];
      var $246=$dp;
      var $247=((($246)-(1))|0);
      $dp=$247;
      HEAP8[($246)]=$245;
      __label__ = 45; break;
    case 45: 
      var $249=$i;
      var $250=((($249)+(1))|0);
      $i=$250;
      __label__ = 40; break;
    case 46: 
      __label__ = 58; break;
    case 47: 
      var $253=$1;
      var $254=(($253+9)|0);
      var $255=HEAPU8[($254)];
      var $256=(($255)&255);
      var $257=(($256)|0)==16;
      if ($257) { __label__ = 48; break; } else { __label__ = 57; break; }
    case 48: 
      var $259=$gray;
      var $260=(($259)&65535);
      var $261=$260 >> 8;
      var $262=$261 & 255;
      var $263=(($262) & 255);
      $gray_high=$263;
      var $264=$gray;
      var $265=(($264)&65535);
      var $266=$265 & 255;
      var $267=(($266) & 255);
      $gray_low=$267;
      var $268=$2;
      var $269=$1;
      var $270=(($269+4)|0);
      var $271=HEAP32[(($270)>>2)];
      var $272=(($268+$271)|0);
      var $273=((($272)-(1))|0);
      $sp=$273;
      var $274=$2;
      var $275=$1;
      var $276=(($275+4)|0);
      var $277=HEAP32[(($276)>>2)];
      var $278=$277 << 1;
      var $279=(($274+$278)|0);
      var $280=((($279)-(1))|0);
      $dp=$280;
      $i=0;
      __label__ = 49; break;
    case 49: 
      var $282=$i;
      var $283=$row_width;
      var $284=(($282)>>>0) < (($283)>>>0);
      if ($284) { __label__ = 50; break; } else { __label__ = 56; break; }
    case 50: 
      var $286=$sp;
      var $287=((($286)-(1))|0);
      var $288=HEAPU8[($287)];
      var $289=(($288)&255);
      var $290=$gray_high;
      var $291=(($290)&255);
      var $292=(($289)|0)==(($291)|0);
      if ($292) { __label__ = 51; break; } else { __label__ = 53; break; }
    case 51: 
      var $294=$sp;
      var $295=HEAPU8[($294)];
      var $296=(($295)&255);
      var $297=$gray_low;
      var $298=(($297)&255);
      var $299=(($296)|0)==(($298)|0);
      if ($299) { __label__ = 52; break; } else { __label__ = 53; break; }
    case 52: 
      var $301=$dp;
      var $302=((($301)-(1))|0);
      $dp=$302;
      HEAP8[($301)]=0;
      var $303=$dp;
      var $304=((($303)-(1))|0);
      $dp=$304;
      HEAP8[($303)]=0;
      __label__ = 54; break;
    case 53: 
      var $306=$dp;
      var $307=((($306)-(1))|0);
      $dp=$307;
      HEAP8[($306)]=-1;
      var $308=$dp;
      var $309=((($308)-(1))|0);
      $dp=$309;
      HEAP8[($308)]=-1;
      __label__ = 54; break;
    case 54: 
      var $311=$sp;
      var $312=((($311)-(1))|0);
      $sp=$312;
      var $313=HEAP8[($311)];
      var $314=$dp;
      var $315=((($314)-(1))|0);
      $dp=$315;
      HEAP8[($314)]=$313;
      var $316=$sp;
      var $317=((($316)-(1))|0);
      $sp=$317;
      var $318=HEAP8[($316)];
      var $319=$dp;
      var $320=((($319)-(1))|0);
      $dp=$320;
      HEAP8[($319)]=$318;
      __label__ = 55; break;
    case 55: 
      var $322=$i;
      var $323=((($322)+(1))|0);
      $i=$323;
      __label__ = 49; break;
    case 56: 
      __label__ = 57; break;
    case 57: 
      __label__ = 58; break;
    case 58: 
      var $327=$1;
      var $328=(($327+8)|0);
      HEAP8[($328)]=4;
      var $329=$1;
      var $330=(($329+10)|0);
      HEAP8[($330)]=2;
      var $331=$1;
      var $332=(($331+9)|0);
      var $333=HEAPU8[($332)];
      var $334=(($333)&255);
      var $335=$334 << 1;
      var $336=(($335) & 255);
      var $337=$1;
      var $338=(($337+11)|0);
      HEAP8[($338)]=$336;
      var $339=$1;
      var $340=(($339+11)|0);
      var $341=HEAPU8[($340)];
      var $342=(($341)&255);
      var $343=(($342)|0) >= 8;
      if ($343) { __label__ = 59; break; } else { __label__ = 60; break; }
    case 59: 
      var $345=$row_width;
      var $346=$1;
      var $347=(($346+11)|0);
      var $348=HEAPU8[($347)];
      var $349=(($348)&255);
      var $350=$349 >>> 3;
      var $351=((($345)*($350))|0);
      var $362 = $351;__label__ = 61; break;
    case 60: 
      var $353=$row_width;
      var $354=$1;
      var $355=(($354+11)|0);
      var $356=HEAPU8[($355)];
      var $357=(($356)&255);
      var $358=((($353)*($357))|0);
      var $359=((($358)+(7))|0);
      var $360=$359 >>> 3;
      var $362 = $360;__label__ = 61; break;
    case 61: 
      var $362;
      var $363=$1;
      var $364=(($363+4)|0);
      HEAP32[(($364)>>2)]=$362;
      __label__ = 62; break;
    case 62: 
      __label__ = 96; break;
    case 63: 
      var $367=$1;
      var $368=(($367+8)|0);
      var $369=HEAPU8[($368)];
      var $370=(($369)&255);
      var $371=(($370)|0)==2;
      if ($371) { __label__ = 64; break; } else { __label__ = 95; break; }
    case 64: 
      var $373=$3;
      var $374=(($373)|0)!=0;
      if ($374) { __label__ = 65; break; } else { __label__ = 95; break; }
    case 65: 
      var $376=$1;
      var $377=(($376+9)|0);
      var $378=HEAPU8[($377)];
      var $379=(($378)&255);
      var $380=(($379)|0)==8;
      if ($380) { __label__ = 66; break; } else { __label__ = 76; break; }
    case 66: 
      var $382=$3;
      var $383=(($382+2)|0);
      var $384=HEAPU16[(($383)>>1)];
      var $385=(($384)&65535);
      var $386=$385 & 255;
      var $387=(($386) & 255);
      $red=$387;
      var $388=$3;
      var $389=(($388+4)|0);
      var $390=HEAPU16[(($389)>>1)];
      var $391=(($390)&65535);
      var $392=$391 & 255;
      var $393=(($392) & 255);
      $green=$393;
      var $394=$3;
      var $395=(($394+6)|0);
      var $396=HEAPU16[(($395)>>1)];
      var $397=(($396)&65535);
      var $398=$397 & 255;
      var $399=(($398) & 255);
      $blue=$399;
      var $400=$2;
      var $401=$1;
      var $402=(($401+4)|0);
      var $403=HEAP32[(($402)>>2)];
      var $404=(($400+$403)|0);
      var $405=((($404)-(1))|0);
      $sp=$405;
      var $406=$2;
      var $407=$row_width;
      var $408=$407 << 2;
      var $409=(($406+$408)|0);
      var $410=((($409)-(1))|0);
      $dp=$410;
      $i=0;
      __label__ = 67; break;
    case 67: 
      var $412=$i;
      var $413=$row_width;
      var $414=(($412)>>>0) < (($413)>>>0);
      if ($414) { __label__ = 68; break; } else { __label__ = 75; break; }
    case 68: 
      var $416=$sp;
      var $417=((($416)-(2))|0);
      var $418=HEAPU8[($417)];
      var $419=(($418)&255);
      var $420=$red;
      var $421=(($420)&255);
      var $422=(($419)|0)==(($421)|0);
      if ($422) { __label__ = 69; break; } else { __label__ = 72; break; }
    case 69: 
      var $424=$sp;
      var $425=((($424)-(1))|0);
      var $426=HEAPU8[($425)];
      var $427=(($426)&255);
      var $428=$green;
      var $429=(($428)&255);
      var $430=(($427)|0)==(($429)|0);
      if ($430) { __label__ = 70; break; } else { __label__ = 72; break; }
    case 70: 
      var $432=$sp;
      var $433=HEAPU8[($432)];
      var $434=(($433)&255);
      var $435=$blue;
      var $436=(($435)&255);
      var $437=(($434)|0)==(($436)|0);
      if ($437) { __label__ = 71; break; } else { __label__ = 72; break; }
    case 71: 
      var $439=$dp;
      var $440=((($439)-(1))|0);
      $dp=$440;
      HEAP8[($439)]=0;
      __label__ = 73; break;
    case 72: 
      var $442=$dp;
      var $443=((($442)-(1))|0);
      $dp=$443;
      HEAP8[($442)]=-1;
      __label__ = 73; break;
    case 73: 
      var $445=$sp;
      var $446=((($445)-(1))|0);
      $sp=$446;
      var $447=HEAP8[($445)];
      var $448=$dp;
      var $449=((($448)-(1))|0);
      $dp=$449;
      HEAP8[($448)]=$447;
      var $450=$sp;
      var $451=((($450)-(1))|0);
      $sp=$451;
      var $452=HEAP8[($450)];
      var $453=$dp;
      var $454=((($453)-(1))|0);
      $dp=$454;
      HEAP8[($453)]=$452;
      var $455=$sp;
      var $456=((($455)-(1))|0);
      $sp=$456;
      var $457=HEAP8[($455)];
      var $458=$dp;
      var $459=((($458)-(1))|0);
      $dp=$459;
      HEAP8[($458)]=$457;
      __label__ = 74; break;
    case 74: 
      var $461=$i;
      var $462=((($461)+(1))|0);
      $i=$462;
      __label__ = 67; break;
    case 75: 
      __label__ = 91; break;
    case 76: 
      var $465=$1;
      var $466=(($465+9)|0);
      var $467=HEAPU8[($466)];
      var $468=(($467)&255);
      var $469=(($468)|0)==16;
      if ($469) { __label__ = 77; break; } else { __label__ = 90; break; }
    case 77: 
      var $471=$3;
      var $472=(($471+2)|0);
      var $473=HEAPU16[(($472)>>1)];
      var $474=(($473)&65535);
      var $475=$474 >> 8;
      var $476=$475 & 255;
      var $477=(($476) & 255);
      $red_high=$477;
      var $478=$3;
      var $479=(($478+4)|0);
      var $480=HEAPU16[(($479)>>1)];
      var $481=(($480)&65535);
      var $482=$481 >> 8;
      var $483=$482 & 255;
      var $484=(($483) & 255);
      $green_high=$484;
      var $485=$3;
      var $486=(($485+6)|0);
      var $487=HEAPU16[(($486)>>1)];
      var $488=(($487)&65535);
      var $489=$488 >> 8;
      var $490=$489 & 255;
      var $491=(($490) & 255);
      $blue_high=$491;
      var $492=$3;
      var $493=(($492+2)|0);
      var $494=HEAPU16[(($493)>>1)];
      var $495=(($494)&65535);
      var $496=$495 & 255;
      var $497=(($496) & 255);
      $red_low=$497;
      var $498=$3;
      var $499=(($498+4)|0);
      var $500=HEAPU16[(($499)>>1)];
      var $501=(($500)&65535);
      var $502=$501 & 255;
      var $503=(($502) & 255);
      $green_low=$503;
      var $504=$3;
      var $505=(($504+6)|0);
      var $506=HEAPU16[(($505)>>1)];
      var $507=(($506)&65535);
      var $508=$507 & 255;
      var $509=(($508) & 255);
      $blue_low=$509;
      var $510=$2;
      var $511=$1;
      var $512=(($511+4)|0);
      var $513=HEAP32[(($512)>>2)];
      var $514=(($510+$513)|0);
      var $515=((($514)-(1))|0);
      $sp=$515;
      var $516=$2;
      var $517=$row_width;
      var $518=$517 << 3;
      var $519=(($516+$518)|0);
      var $520=((($519)-(1))|0);
      $dp=$520;
      $i=0;
      __label__ = 78; break;
    case 78: 
      var $522=$i;
      var $523=$row_width;
      var $524=(($522)>>>0) < (($523)>>>0);
      if ($524) { __label__ = 79; break; } else { __label__ = 89; break; }
    case 79: 
      var $526=$sp;
      var $527=((($526)-(5))|0);
      var $528=HEAPU8[($527)];
      var $529=(($528)&255);
      var $530=$red_high;
      var $531=(($530)&255);
      var $532=(($529)|0)==(($531)|0);
      if ($532) { __label__ = 80; break; } else { __label__ = 86; break; }
    case 80: 
      var $534=$sp;
      var $535=((($534)-(4))|0);
      var $536=HEAPU8[($535)];
      var $537=(($536)&255);
      var $538=$red_low;
      var $539=(($538)&255);
      var $540=(($537)|0)==(($539)|0);
      if ($540) { __label__ = 81; break; } else { __label__ = 86; break; }
    case 81: 
      var $542=$sp;
      var $543=((($542)-(3))|0);
      var $544=HEAPU8[($543)];
      var $545=(($544)&255);
      var $546=$green_high;
      var $547=(($546)&255);
      var $548=(($545)|0)==(($547)|0);
      if ($548) { __label__ = 82; break; } else { __label__ = 86; break; }
    case 82: 
      var $550=$sp;
      var $551=((($550)-(2))|0);
      var $552=HEAPU8[($551)];
      var $553=(($552)&255);
      var $554=$green_low;
      var $555=(($554)&255);
      var $556=(($553)|0)==(($555)|0);
      if ($556) { __label__ = 83; break; } else { __label__ = 86; break; }
    case 83: 
      var $558=$sp;
      var $559=((($558)-(1))|0);
      var $560=HEAPU8[($559)];
      var $561=(($560)&255);
      var $562=$blue_high;
      var $563=(($562)&255);
      var $564=(($561)|0)==(($563)|0);
      if ($564) { __label__ = 84; break; } else { __label__ = 86; break; }
    case 84: 
      var $566=$sp;
      var $567=HEAPU8[($566)];
      var $568=(($567)&255);
      var $569=$blue_low;
      var $570=(($569)&255);
      var $571=(($568)|0)==(($570)|0);
      if ($571) { __label__ = 85; break; } else { __label__ = 86; break; }
    case 85: 
      var $573=$dp;
      var $574=((($573)-(1))|0);
      $dp=$574;
      HEAP8[($573)]=0;
      var $575=$dp;
      var $576=((($575)-(1))|0);
      $dp=$576;
      HEAP8[($575)]=0;
      __label__ = 87; break;
    case 86: 
      var $578=$dp;
      var $579=((($578)-(1))|0);
      $dp=$579;
      HEAP8[($578)]=-1;
      var $580=$dp;
      var $581=((($580)-(1))|0);
      $dp=$581;
      HEAP8[($580)]=-1;
      __label__ = 87; break;
    case 87: 
      var $583=$sp;
      var $584=((($583)-(1))|0);
      $sp=$584;
      var $585=HEAP8[($583)];
      var $586=$dp;
      var $587=((($586)-(1))|0);
      $dp=$587;
      HEAP8[($586)]=$585;
      var $588=$sp;
      var $589=((($588)-(1))|0);
      $sp=$589;
      var $590=HEAP8[($588)];
      var $591=$dp;
      var $592=((($591)-(1))|0);
      $dp=$592;
      HEAP8[($591)]=$590;
      var $593=$sp;
      var $594=((($593)-(1))|0);
      $sp=$594;
      var $595=HEAP8[($593)];
      var $596=$dp;
      var $597=((($596)-(1))|0);
      $dp=$597;
      HEAP8[($596)]=$595;
      var $598=$sp;
      var $599=((($598)-(1))|0);
      $sp=$599;
      var $600=HEAP8[($598)];
      var $601=$dp;
      var $602=((($601)-(1))|0);
      $dp=$602;
      HEAP8[($601)]=$600;
      var $603=$sp;
      var $604=((($603)-(1))|0);
      $sp=$604;
      var $605=HEAP8[($603)];
      var $606=$dp;
      var $607=((($606)-(1))|0);
      $dp=$607;
      HEAP8[($606)]=$605;
      var $608=$sp;
      var $609=((($608)-(1))|0);
      $sp=$609;
      var $610=HEAP8[($608)];
      var $611=$dp;
      var $612=((($611)-(1))|0);
      $dp=$612;
      HEAP8[($611)]=$610;
      __label__ = 88; break;
    case 88: 
      var $614=$i;
      var $615=((($614)+(1))|0);
      $i=$615;
      __label__ = 78; break;
    case 89: 
      __label__ = 90; break;
    case 90: 
      __label__ = 91; break;
    case 91: 
      var $619=$1;
      var $620=(($619+8)|0);
      HEAP8[($620)]=6;
      var $621=$1;
      var $622=(($621+10)|0);
      HEAP8[($622)]=4;
      var $623=$1;
      var $624=(($623+9)|0);
      var $625=HEAPU8[($624)];
      var $626=(($625)&255);
      var $627=$626 << 2;
      var $628=(($627) & 255);
      var $629=$1;
      var $630=(($629+11)|0);
      HEAP8[($630)]=$628;
      var $631=$1;
      var $632=(($631+11)|0);
      var $633=HEAPU8[($632)];
      var $634=(($633)&255);
      var $635=(($634)|0) >= 8;
      if ($635) { __label__ = 92; break; } else { __label__ = 93; break; }
    case 92: 
      var $637=$row_width;
      var $638=$1;
      var $639=(($638+11)|0);
      var $640=HEAPU8[($639)];
      var $641=(($640)&255);
      var $642=$641 >>> 3;
      var $643=((($637)*($642))|0);
      var $654 = $643;__label__ = 94; break;
    case 93: 
      var $645=$row_width;
      var $646=$1;
      var $647=(($646+11)|0);
      var $648=HEAPU8[($647)];
      var $649=(($648)&255);
      var $650=((($645)*($649))|0);
      var $651=((($650)+(7))|0);
      var $652=$651 >>> 3;
      var $654 = $652;__label__ = 94; break;
    case 94: 
      var $654;
      var $655=$1;
      var $656=(($655+4)|0);
      HEAP32[(($656)>>2)]=$654;
      __label__ = 95; break;
    case 95: 
      __label__ = 96; break;
    case 96: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_png_do_expand["X"]=1;

function _png_do_rgb_to_gray($png_ptr, $row_info, $row) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $i;
      var $row_width;
      var $rgb_error;
      var $rc;
      var $gc;
      var $bc;
      var $sp;
      var $dp;
      var $red;
      var $green;
      var $blue;
      var $sp1;
      var $dp2;
      var $red3;
      var $green4;
      var $blue5;
      var $sp6;
      var $dp7;
      var $red8;
      var $green9;
      var $blue10;
      var $w;
      var $red_1;
      var $green_1;
      var $blue_1;
      var $gray16;
      var $sp11;
      var $dp12;
      var $red13;
      var $green14;
      var $blue15;
      var $gray1616;
      var $sp17;
      var $dp18;
      var $red19;
      var $green20;
      var $blue21;
      var $sp22;
      var $dp23;
      var $red24;
      var $green25;
      var $blue26;
      var $sp27;
      var $dp28;
      var $red29;
      var $green30;
      var $blue31;
      var $w32;
      var $red_133;
      var $green_134;
      var $blue_135;
      var $gray1636;
      var $sp37;
      var $dp38;
      var $red39;
      var $green40;
      var $blue41;
      var $gray1642;
      $1=$png_ptr;
      $2=$row_info;
      $3=$row;
      var $4=$2;
      var $5=(($4)|0);
      var $6=HEAP32[(($5)>>2)];
      $row_width=$6;
      $rgb_error=0;
      var $7=$2;
      var $8=(($7+8)|0);
      var $9=HEAPU8[($8)];
      var $10=(($9)&255);
      var $11=$10 & 1;
      var $12=(($11)|0)!=0;
      if ($12) { __label__ = 94; break; } else { __label__ = 3; break; }
    case 3: 
      var $14=$2;
      var $15=(($14+8)|0);
      var $16=HEAPU8[($15)];
      var $17=(($16)&255);
      var $18=$17 & 2;
      var $19=(($18)|0)!=0;
      if ($19) { __label__ = 4; break; } else { __label__ = 94; break; }
    case 4: 
      var $21=$1;
      var $22=(($21+534)|0);
      var $23=HEAPU16[(($22)>>1)];
      var $24=(($23)&65535);
      $rc=$24;
      var $25=$1;
      var $26=(($25+536)|0);
      var $27=HEAPU16[(($26)>>1)];
      var $28=(($27)&65535);
      $gc=$28;
      var $29=$1;
      var $30=(($29+538)|0);
      var $31=HEAPU16[(($30)>>1)];
      var $32=(($31)&65535);
      $bc=$32;
      var $33=$2;
      var $34=(($33+8)|0);
      var $35=HEAPU8[($34)];
      var $36=(($35)&255);
      var $37=(($36)|0)==2;
      if ($37) { __label__ = 5; break; } else { __label__ = 48; break; }
    case 5: 
      var $39=$2;
      var $40=(($39+9)|0);
      var $41=HEAPU8[($40)];
      var $42=(($41)&255);
      var $43=(($42)|0)==8;
      if ($43) { __label__ = 6; break; } else { __label__ = 27; break; }
    case 6: 
      var $45=$1;
      var $46=(($45+340)|0);
      var $47=HEAP32[(($46)>>2)];
      var $48=(($47)|0)!=0;
      if ($48) { __label__ = 7; break; } else { __label__ = 17; break; }
    case 7: 
      var $50=$1;
      var $51=(($50+344)|0);
      var $52=HEAP32[(($51)>>2)];
      var $53=(($52)|0)!=0;
      if ($53) { __label__ = 8; break; } else { __label__ = 17; break; }
    case 8: 
      var $55=$3;
      $sp=$55;
      var $56=$3;
      $dp=$56;
      $i=0;
      __label__ = 9; break;
    case 9: 
      var $58=$i;
      var $59=$row_width;
      var $60=(($58)>>>0) < (($59)>>>0);
      if ($60) { __label__ = 10; break; } else { __label__ = 16; break; }
    case 10: 
      var $62=$sp;
      var $63=(($62+1)|0);
      $sp=$63;
      var $64=HEAPU8[($62)];
      var $65=(($64)&255);
      var $66=$1;
      var $67=(($66+344)|0);
      var $68=HEAP32[(($67)>>2)];
      var $69=(($68+$65)|0);
      var $70=HEAP8[($69)];
      $red=$70;
      var $71=$sp;
      var $72=(($71+1)|0);
      $sp=$72;
      var $73=HEAPU8[($71)];
      var $74=(($73)&255);
      var $75=$1;
      var $76=(($75+344)|0);
      var $77=HEAP32[(($76)>>2)];
      var $78=(($77+$74)|0);
      var $79=HEAP8[($78)];
      $green=$79;
      var $80=$sp;
      var $81=(($80+1)|0);
      $sp=$81;
      var $82=HEAPU8[($80)];
      var $83=(($82)&255);
      var $84=$1;
      var $85=(($84+344)|0);
      var $86=HEAP32[(($85)>>2)];
      var $87=(($86+$83)|0);
      var $88=HEAP8[($87)];
      $blue=$88;
      var $89=$red;
      var $90=(($89)&255);
      var $91=$green;
      var $92=(($91)&255);
      var $93=(($90)|0)!=(($92)|0);
      if ($93) { __label__ = 12; break; } else { __label__ = 11; break; }
    case 11: 
      var $95=$red;
      var $96=(($95)&255);
      var $97=$blue;
      var $98=(($97)&255);
      var $99=(($96)|0)!=(($98)|0);
      if ($99) { __label__ = 12; break; } else { __label__ = 13; break; }
    case 12: 
      var $101=$rgb_error;
      var $102=$101 | 1;
      $rgb_error=$102;
      var $103=$rc;
      var $104=$red;
      var $105=(($104)&255);
      var $106=((($103)*($105))|0);
      var $107=$gc;
      var $108=$green;
      var $109=(($108)&255);
      var $110=((($107)*($109))|0);
      var $111=((($106)+($110))|0);
      var $112=$bc;
      var $113=$blue;
      var $114=(($113)&255);
      var $115=((($112)*($114))|0);
      var $116=((($111)+($115))|0);
      var $117=$116 >>> 15;
      var $118=$1;
      var $119=(($118+340)|0);
      var $120=HEAP32[(($119)>>2)];
      var $121=(($120+$117)|0);
      var $122=HEAP8[($121)];
      var $123=$dp;
      var $124=(($123+1)|0);
      $dp=$124;
      HEAP8[($123)]=$122;
      __label__ = 14; break;
    case 13: 
      var $126=$sp;
      var $127=((($126)-(1))|0);
      var $128=HEAP8[($127)];
      var $129=$dp;
      var $130=(($129+1)|0);
      $dp=$130;
      HEAP8[($129)]=$128;
      __label__ = 14; break;
    case 14: 
      __label__ = 15; break;
    case 15: 
      var $133=$i;
      var $134=((($133)+(1))|0);
      $i=$134;
      __label__ = 9; break;
    case 16: 
      __label__ = 26; break;
    case 17: 
      var $137=$3;
      $sp1=$137;
      var $138=$3;
      $dp2=$138;
      $i=0;
      __label__ = 18; break;
    case 18: 
      var $140=$i;
      var $141=$row_width;
      var $142=(($140)>>>0) < (($141)>>>0);
      if ($142) { __label__ = 19; break; } else { __label__ = 25; break; }
    case 19: 
      var $144=$sp1;
      var $145=(($144+1)|0);
      $sp1=$145;
      var $146=HEAP8[($144)];
      $red3=$146;
      var $147=$sp1;
      var $148=(($147+1)|0);
      $sp1=$148;
      var $149=HEAP8[($147)];
      $green4=$149;
      var $150=$sp1;
      var $151=(($150+1)|0);
      $sp1=$151;
      var $152=HEAP8[($150)];
      $blue5=$152;
      var $153=$red3;
      var $154=(($153)&255);
      var $155=$green4;
      var $156=(($155)&255);
      var $157=(($154)|0)!=(($156)|0);
      if ($157) { __label__ = 21; break; } else { __label__ = 20; break; }
    case 20: 
      var $159=$red3;
      var $160=(($159)&255);
      var $161=$blue5;
      var $162=(($161)&255);
      var $163=(($160)|0)!=(($162)|0);
      if ($163) { __label__ = 21; break; } else { __label__ = 22; break; }
    case 21: 
      var $165=$rgb_error;
      var $166=$165 | 1;
      $rgb_error=$166;
      var $167=$rc;
      var $168=$red3;
      var $169=(($168)&255);
      var $170=((($167)*($169))|0);
      var $171=$gc;
      var $172=$green4;
      var $173=(($172)&255);
      var $174=((($171)*($173))|0);
      var $175=((($170)+($174))|0);
      var $176=$bc;
      var $177=$blue5;
      var $178=(($177)&255);
      var $179=((($176)*($178))|0);
      var $180=((($175)+($179))|0);
      var $181=$180 >>> 15;
      var $182=(($181) & 255);
      var $183=$dp2;
      var $184=(($183+1)|0);
      $dp2=$184;
      HEAP8[($183)]=$182;
      __label__ = 23; break;
    case 22: 
      var $186=$sp1;
      var $187=((($186)-(1))|0);
      var $188=HEAP8[($187)];
      var $189=$dp2;
      var $190=(($189+1)|0);
      $dp2=$190;
      HEAP8[($189)]=$188;
      __label__ = 23; break;
    case 23: 
      __label__ = 24; break;
    case 24: 
      var $193=$i;
      var $194=((($193)+(1))|0);
      $i=$194;
      __label__ = 18; break;
    case 25: 
      __label__ = 26; break;
    case 26: 
      __label__ = 47; break;
    case 27: 
      var $198=$1;
      var $199=(($198+356)|0);
      var $200=HEAP32[(($199)>>2)];
      var $201=(($200)|0)!=0;
      if ($201) { __label__ = 28; break; } else { __label__ = 38; break; }
    case 28: 
      var $203=$1;
      var $204=(($203+352)|0);
      var $205=HEAP32[(($204)>>2)];
      var $206=(($205)|0)!=0;
      if ($206) { __label__ = 29; break; } else { __label__ = 38; break; }
    case 29: 
      var $208=$3;
      $sp6=$208;
      var $209=$3;
      $dp7=$209;
      $i=0;
      __label__ = 30; break;
    case 30: 
      var $211=$i;
      var $212=$row_width;
      var $213=(($211)>>>0) < (($212)>>>0);
      if ($213) { __label__ = 31; break; } else { __label__ = 37; break; }
    case 31: 
      var $215=$sp6;
      var $216=HEAPU8[($215)];
      var $217=(($216)&255);
      var $218=$217 << 8;
      var $219=$sp6;
      var $220=(($219+1)|0);
      var $221=HEAPU8[($220)];
      var $222=(($221)&255);
      var $223=$218 | $222;
      var $224=(($223) & 65535);
      $red8=$224;
      var $225=$sp6;
      var $226=(($225+2)|0);
      $sp6=$226;
      var $227=$sp6;
      var $228=HEAPU8[($227)];
      var $229=(($228)&255);
      var $230=$229 << 8;
      var $231=$sp6;
      var $232=(($231+1)|0);
      var $233=HEAPU8[($232)];
      var $234=(($233)&255);
      var $235=$230 | $234;
      var $236=(($235) & 65535);
      $green9=$236;
      var $237=$sp6;
      var $238=(($237+2)|0);
      $sp6=$238;
      var $239=$sp6;
      var $240=HEAPU8[($239)];
      var $241=(($240)&255);
      var $242=$241 << 8;
      var $243=$sp6;
      var $244=(($243+1)|0);
      var $245=HEAPU8[($244)];
      var $246=(($245)&255);
      var $247=$242 | $246;
      var $248=(($247) & 65535);
      $blue10=$248;
      var $249=$sp6;
      var $250=(($249+2)|0);
      $sp6=$250;
      var $251=$red8;
      var $252=(($251)&65535);
      var $253=$green9;
      var $254=(($253)&65535);
      var $255=(($252)|0)==(($254)|0);
      if ($255) { __label__ = 32; break; } else { __label__ = 34; break; }
    case 32: 
      var $257=$red8;
      var $258=(($257)&65535);
      var $259=$blue10;
      var $260=(($259)&65535);
      var $261=(($258)|0)==(($260)|0);
      if ($261) { __label__ = 33; break; } else { __label__ = 34; break; }
    case 33: 
      var $263=$red8;
      $w=$263;
      __label__ = 35; break;
    case 34: 
      var $265=$red8;
      var $266=(($265)&65535);
      var $267=$266 >> 8;
      var $268=$red8;
      var $269=(($268)&65535);
      var $270=$269 & 255;
      var $271=$1;
      var $272=(($271+324)|0);
      var $273=HEAP32[(($272)>>2)];
      var $274=$270 >> (($273)|0);
      var $275=$1;
      var $276=(($275+356)|0);
      var $277=HEAP32[(($276)>>2)];
      var $278=(($277+($274<<2))|0);
      var $279=HEAP32[(($278)>>2)];
      var $280=(($279+($267<<1))|0);
      var $281=HEAP16[(($280)>>1)];
      $red_1=$281;
      var $282=$green9;
      var $283=(($282)&65535);
      var $284=$283 >> 8;
      var $285=$green9;
      var $286=(($285)&65535);
      var $287=$286 & 255;
      var $288=$1;
      var $289=(($288+324)|0);
      var $290=HEAP32[(($289)>>2)];
      var $291=$287 >> (($290)|0);
      var $292=$1;
      var $293=(($292+356)|0);
      var $294=HEAP32[(($293)>>2)];
      var $295=(($294+($291<<2))|0);
      var $296=HEAP32[(($295)>>2)];
      var $297=(($296+($284<<1))|0);
      var $298=HEAP16[(($297)>>1)];
      $green_1=$298;
      var $299=$blue10;
      var $300=(($299)&65535);
      var $301=$300 >> 8;
      var $302=$blue10;
      var $303=(($302)&65535);
      var $304=$303 & 255;
      var $305=$1;
      var $306=(($305+324)|0);
      var $307=HEAP32[(($306)>>2)];
      var $308=$304 >> (($307)|0);
      var $309=$1;
      var $310=(($309+356)|0);
      var $311=HEAP32[(($310)>>2)];
      var $312=(($311+($308<<2))|0);
      var $313=HEAP32[(($312)>>2)];
      var $314=(($313+($301<<1))|0);
      var $315=HEAP16[(($314)>>1)];
      $blue_1=$315;
      var $316=$rc;
      var $317=$red_1;
      var $318=(($317)&65535);
      var $319=((($316)*($318))|0);
      var $320=$gc;
      var $321=$green_1;
      var $322=(($321)&65535);
      var $323=((($320)*($322))|0);
      var $324=((($319)+($323))|0);
      var $325=$bc;
      var $326=$blue_1;
      var $327=(($326)&65535);
      var $328=((($325)*($327))|0);
      var $329=((($324)+($328))|0);
      var $330=$329 >>> 15;
      var $331=(($330) & 65535);
      $gray16=$331;
      var $332=$gray16;
      var $333=(($332)&65535);
      var $334=$333 >> 8;
      var $335=$gray16;
      var $336=(($335)&65535);
      var $337=$336 & 255;
      var $338=$1;
      var $339=(($338+324)|0);
      var $340=HEAP32[(($339)>>2)];
      var $341=$337 >> (($340)|0);
      var $342=$1;
      var $343=(($342+352)|0);
      var $344=HEAP32[(($343)>>2)];
      var $345=(($344+($341<<2))|0);
      var $346=HEAP32[(($345)>>2)];
      var $347=(($346+($334<<1))|0);
      var $348=HEAP16[(($347)>>1)];
      $w=$348;
      var $349=$rgb_error;
      var $350=$349 | 1;
      $rgb_error=$350;
      __label__ = 35; break;
    case 35: 
      var $352=$w;
      var $353=(($352)&65535);
      var $354=$353 >> 8;
      var $355=$354 & 255;
      var $356=(($355) & 255);
      var $357=$dp7;
      var $358=(($357+1)|0);
      $dp7=$358;
      HEAP8[($357)]=$356;
      var $359=$w;
      var $360=(($359)&65535);
      var $361=$360 & 255;
      var $362=(($361) & 255);
      var $363=$dp7;
      var $364=(($363+1)|0);
      $dp7=$364;
      HEAP8[($363)]=$362;
      __label__ = 36; break;
    case 36: 
      var $366=$i;
      var $367=((($366)+(1))|0);
      $i=$367;
      __label__ = 30; break;
    case 37: 
      __label__ = 46; break;
    case 38: 
      var $370=$3;
      $sp11=$370;
      var $371=$3;
      $dp12=$371;
      $i=0;
      __label__ = 39; break;
    case 39: 
      var $373=$i;
      var $374=$row_width;
      var $375=(($373)>>>0) < (($374)>>>0);
      if ($375) { __label__ = 40; break; } else { __label__ = 45; break; }
    case 40: 
      var $377=$sp11;
      var $378=HEAPU8[($377)];
      var $379=(($378)&255);
      var $380=$379 << 8;
      var $381=$sp11;
      var $382=(($381+1)|0);
      var $383=HEAPU8[($382)];
      var $384=(($383)&255);
      var $385=$380 | $384;
      var $386=(($385) & 65535);
      $red13=$386;
      var $387=$sp11;
      var $388=(($387+2)|0);
      $sp11=$388;
      var $389=$sp11;
      var $390=HEAPU8[($389)];
      var $391=(($390)&255);
      var $392=$391 << 8;
      var $393=$sp11;
      var $394=(($393+1)|0);
      var $395=HEAPU8[($394)];
      var $396=(($395)&255);
      var $397=$392 | $396;
      var $398=(($397) & 65535);
      $green14=$398;
      var $399=$sp11;
      var $400=(($399+2)|0);
      $sp11=$400;
      var $401=$sp11;
      var $402=HEAPU8[($401)];
      var $403=(($402)&255);
      var $404=$403 << 8;
      var $405=$sp11;
      var $406=(($405+1)|0);
      var $407=HEAPU8[($406)];
      var $408=(($407)&255);
      var $409=$404 | $408;
      var $410=(($409) & 65535);
      $blue15=$410;
      var $411=$sp11;
      var $412=(($411+2)|0);
      $sp11=$412;
      var $413=$red13;
      var $414=(($413)&65535);
      var $415=$green14;
      var $416=(($415)&65535);
      var $417=(($414)|0)!=(($416)|0);
      if ($417) { __label__ = 42; break; } else { __label__ = 41; break; }
    case 41: 
      var $419=$red13;
      var $420=(($419)&65535);
      var $421=$blue15;
      var $422=(($421)&65535);
      var $423=(($420)|0)!=(($422)|0);
      if ($423) { __label__ = 42; break; } else { __label__ = 43; break; }
    case 42: 
      var $425=$rgb_error;
      var $426=$425 | 1;
      $rgb_error=$426;
      __label__ = 43; break;
    case 43: 
      var $428=$rc;
      var $429=$red13;
      var $430=(($429)&65535);
      var $431=((($428)*($430))|0);
      var $432=$gc;
      var $433=$green14;
      var $434=(($433)&65535);
      var $435=((($432)*($434))|0);
      var $436=((($431)+($435))|0);
      var $437=$bc;
      var $438=$blue15;
      var $439=(($438)&65535);
      var $440=((($437)*($439))|0);
      var $441=((($436)+($440))|0);
      var $442=$441 >>> 15;
      var $443=(($442) & 65535);
      $gray1616=$443;
      var $444=$gray1616;
      var $445=(($444)&65535);
      var $446=$445 >> 8;
      var $447=$446 & 255;
      var $448=(($447) & 255);
      var $449=$dp12;
      var $450=(($449+1)|0);
      $dp12=$450;
      HEAP8[($449)]=$448;
      var $451=$gray1616;
      var $452=(($451)&65535);
      var $453=$452 & 255;
      var $454=(($453) & 255);
      var $455=$dp12;
      var $456=(($455+1)|0);
      $dp12=$456;
      HEAP8[($455)]=$454;
      __label__ = 44; break;
    case 44: 
      var $458=$i;
      var $459=((($458)+(1))|0);
      $i=$459;
      __label__ = 39; break;
    case 45: 
      __label__ = 46; break;
    case 46: 
      __label__ = 47; break;
    case 47: 
      __label__ = 48; break;
    case 48: 
      var $464=$2;
      var $465=(($464+8)|0);
      var $466=HEAPU8[($465)];
      var $467=(($466)&255);
      var $468=(($467)|0)==6;
      if ($468) { __label__ = 49; break; } else { __label__ = 90; break; }
    case 49: 
      var $470=$2;
      var $471=(($470+9)|0);
      var $472=HEAPU8[($471)];
      var $473=(($472)&255);
      var $474=(($473)|0)==8;
      if ($474) { __label__ = 50; break; } else { __label__ = 69; break; }
    case 50: 
      var $476=$1;
      var $477=(($476+340)|0);
      var $478=HEAP32[(($477)>>2)];
      var $479=(($478)|0)!=0;
      if ($479) { __label__ = 51; break; } else { __label__ = 60; break; }
    case 51: 
      var $481=$1;
      var $482=(($481+344)|0);
      var $483=HEAP32[(($482)>>2)];
      var $484=(($483)|0)!=0;
      if ($484) { __label__ = 52; break; } else { __label__ = 60; break; }
    case 52: 
      var $486=$3;
      $sp17=$486;
      var $487=$3;
      $dp18=$487;
      $i=0;
      __label__ = 53; break;
    case 53: 
      var $489=$i;
      var $490=$row_width;
      var $491=(($489)>>>0) < (($490)>>>0);
      if ($491) { __label__ = 54; break; } else { __label__ = 59; break; }
    case 54: 
      var $493=$sp17;
      var $494=(($493+1)|0);
      $sp17=$494;
      var $495=HEAPU8[($493)];
      var $496=(($495)&255);
      var $497=$1;
      var $498=(($497+344)|0);
      var $499=HEAP32[(($498)>>2)];
      var $500=(($499+$496)|0);
      var $501=HEAP8[($500)];
      $red19=$501;
      var $502=$sp17;
      var $503=(($502+1)|0);
      $sp17=$503;
      var $504=HEAPU8[($502)];
      var $505=(($504)&255);
      var $506=$1;
      var $507=(($506+344)|0);
      var $508=HEAP32[(($507)>>2)];
      var $509=(($508+$505)|0);
      var $510=HEAP8[($509)];
      $green20=$510;
      var $511=$sp17;
      var $512=(($511+1)|0);
      $sp17=$512;
      var $513=HEAPU8[($511)];
      var $514=(($513)&255);
      var $515=$1;
      var $516=(($515+344)|0);
      var $517=HEAP32[(($516)>>2)];
      var $518=(($517+$514)|0);
      var $519=HEAP8[($518)];
      $blue21=$519;
      var $520=$red19;
      var $521=(($520)&255);
      var $522=$green20;
      var $523=(($522)&255);
      var $524=(($521)|0)!=(($523)|0);
      if ($524) { __label__ = 56; break; } else { __label__ = 55; break; }
    case 55: 
      var $526=$red19;
      var $527=(($526)&255);
      var $528=$blue21;
      var $529=(($528)&255);
      var $530=(($527)|0)!=(($529)|0);
      if ($530) { __label__ = 56; break; } else { __label__ = 57; break; }
    case 56: 
      var $532=$rgb_error;
      var $533=$532 | 1;
      $rgb_error=$533;
      __label__ = 57; break;
    case 57: 
      var $535=$rc;
      var $536=$red19;
      var $537=(($536)&255);
      var $538=((($535)*($537))|0);
      var $539=$gc;
      var $540=$green20;
      var $541=(($540)&255);
      var $542=((($539)*($541))|0);
      var $543=((($538)+($542))|0);
      var $544=$bc;
      var $545=$blue21;
      var $546=(($545)&255);
      var $547=((($544)*($546))|0);
      var $548=((($543)+($547))|0);
      var $549=$548 >>> 15;
      var $550=$1;
      var $551=(($550+340)|0);
      var $552=HEAP32[(($551)>>2)];
      var $553=(($552+$549)|0);
      var $554=HEAP8[($553)];
      var $555=$dp18;
      var $556=(($555+1)|0);
      $dp18=$556;
      HEAP8[($555)]=$554;
      var $557=$sp17;
      var $558=(($557+1)|0);
      $sp17=$558;
      var $559=HEAP8[($557)];
      var $560=$dp18;
      var $561=(($560+1)|0);
      $dp18=$561;
      HEAP8[($560)]=$559;
      __label__ = 58; break;
    case 58: 
      var $563=$i;
      var $564=((($563)+(1))|0);
      $i=$564;
      __label__ = 53; break;
    case 59: 
      __label__ = 68; break;
    case 60: 
      var $567=$3;
      $sp22=$567;
      var $568=$3;
      $dp23=$568;
      $i=0;
      __label__ = 61; break;
    case 61: 
      var $570=$i;
      var $571=$row_width;
      var $572=(($570)>>>0) < (($571)>>>0);
      if ($572) { __label__ = 62; break; } else { __label__ = 67; break; }
    case 62: 
      var $574=$sp22;
      var $575=(($574+1)|0);
      $sp22=$575;
      var $576=HEAP8[($574)];
      $red24=$576;
      var $577=$sp22;
      var $578=(($577+1)|0);
      $sp22=$578;
      var $579=HEAP8[($577)];
      $green25=$579;
      var $580=$sp22;
      var $581=(($580+1)|0);
      $sp22=$581;
      var $582=HEAP8[($580)];
      $blue26=$582;
      var $583=$red24;
      var $584=(($583)&255);
      var $585=$green25;
      var $586=(($585)&255);
      var $587=(($584)|0)!=(($586)|0);
      if ($587) { __label__ = 64; break; } else { __label__ = 63; break; }
    case 63: 
      var $589=$red24;
      var $590=(($589)&255);
      var $591=$blue26;
      var $592=(($591)&255);
      var $593=(($590)|0)!=(($592)|0);
      if ($593) { __label__ = 64; break; } else { __label__ = 65; break; }
    case 64: 
      var $595=$rgb_error;
      var $596=$595 | 1;
      $rgb_error=$596;
      __label__ = 65; break;
    case 65: 
      var $598=$rc;
      var $599=$red24;
      var $600=(($599)&255);
      var $601=((($598)*($600))|0);
      var $602=$gc;
      var $603=$green25;
      var $604=(($603)&255);
      var $605=((($602)*($604))|0);
      var $606=((($601)+($605))|0);
      var $607=$bc;
      var $608=$blue26;
      var $609=(($608)&255);
      var $610=((($607)*($609))|0);
      var $611=((($606)+($610))|0);
      var $612=$611 >>> 15;
      var $613=(($612) & 255);
      var $614=$dp23;
      var $615=(($614+1)|0);
      $dp23=$615;
      HEAP8[($614)]=$613;
      var $616=$sp22;
      var $617=(($616+1)|0);
      $sp22=$617;
      var $618=HEAP8[($616)];
      var $619=$dp23;
      var $620=(($619+1)|0);
      $dp23=$620;
      HEAP8[($619)]=$618;
      __label__ = 66; break;
    case 66: 
      var $622=$i;
      var $623=((($622)+(1))|0);
      $i=$623;
      __label__ = 61; break;
    case 67: 
      __label__ = 68; break;
    case 68: 
      __label__ = 89; break;
    case 69: 
      var $627=$1;
      var $628=(($627+356)|0);
      var $629=HEAP32[(($628)>>2)];
      var $630=(($629)|0)!=0;
      if ($630) { __label__ = 70; break; } else { __label__ = 80; break; }
    case 70: 
      var $632=$1;
      var $633=(($632+352)|0);
      var $634=HEAP32[(($633)>>2)];
      var $635=(($634)|0)!=0;
      if ($635) { __label__ = 71; break; } else { __label__ = 80; break; }
    case 71: 
      var $637=$3;
      $sp27=$637;
      var $638=$3;
      $dp28=$638;
      $i=0;
      __label__ = 72; break;
    case 72: 
      var $640=$i;
      var $641=$row_width;
      var $642=(($640)>>>0) < (($641)>>>0);
      if ($642) { __label__ = 73; break; } else { __label__ = 79; break; }
    case 73: 
      var $644=$sp27;
      var $645=HEAPU8[($644)];
      var $646=(($645)&255);
      var $647=$646 << 8;
      var $648=$sp27;
      var $649=(($648+1)|0);
      var $650=HEAPU8[($649)];
      var $651=(($650)&255);
      var $652=$647 | $651;
      var $653=(($652) & 65535);
      $red29=$653;
      var $654=$sp27;
      var $655=(($654+2)|0);
      $sp27=$655;
      var $656=$sp27;
      var $657=HEAPU8[($656)];
      var $658=(($657)&255);
      var $659=$658 << 8;
      var $660=$sp27;
      var $661=(($660+1)|0);
      var $662=HEAPU8[($661)];
      var $663=(($662)&255);
      var $664=$659 | $663;
      var $665=(($664) & 65535);
      $green30=$665;
      var $666=$sp27;
      var $667=(($666+2)|0);
      $sp27=$667;
      var $668=$sp27;
      var $669=HEAPU8[($668)];
      var $670=(($669)&255);
      var $671=$670 << 8;
      var $672=$sp27;
      var $673=(($672+1)|0);
      var $674=HEAPU8[($673)];
      var $675=(($674)&255);
      var $676=$671 | $675;
      var $677=(($676) & 65535);
      $blue31=$677;
      var $678=$sp27;
      var $679=(($678+2)|0);
      $sp27=$679;
      var $680=$red29;
      var $681=(($680)&65535);
      var $682=$green30;
      var $683=(($682)&65535);
      var $684=(($681)|0)==(($683)|0);
      if ($684) { __label__ = 74; break; } else { __label__ = 76; break; }
    case 74: 
      var $686=$red29;
      var $687=(($686)&65535);
      var $688=$blue31;
      var $689=(($688)&65535);
      var $690=(($687)|0)==(($689)|0);
      if ($690) { __label__ = 75; break; } else { __label__ = 76; break; }
    case 75: 
      var $692=$red29;
      $w32=$692;
      __label__ = 77; break;
    case 76: 
      var $694=$red29;
      var $695=(($694)&65535);
      var $696=$695 >> 8;
      var $697=$red29;
      var $698=(($697)&65535);
      var $699=$698 & 255;
      var $700=$1;
      var $701=(($700+324)|0);
      var $702=HEAP32[(($701)>>2)];
      var $703=$699 >> (($702)|0);
      var $704=$1;
      var $705=(($704+356)|0);
      var $706=HEAP32[(($705)>>2)];
      var $707=(($706+($703<<2))|0);
      var $708=HEAP32[(($707)>>2)];
      var $709=(($708+($696<<1))|0);
      var $710=HEAP16[(($709)>>1)];
      $red_133=$710;
      var $711=$green30;
      var $712=(($711)&65535);
      var $713=$712 >> 8;
      var $714=$green30;
      var $715=(($714)&65535);
      var $716=$715 & 255;
      var $717=$1;
      var $718=(($717+324)|0);
      var $719=HEAP32[(($718)>>2)];
      var $720=$716 >> (($719)|0);
      var $721=$1;
      var $722=(($721+356)|0);
      var $723=HEAP32[(($722)>>2)];
      var $724=(($723+($720<<2))|0);
      var $725=HEAP32[(($724)>>2)];
      var $726=(($725+($713<<1))|0);
      var $727=HEAP16[(($726)>>1)];
      $green_134=$727;
      var $728=$blue31;
      var $729=(($728)&65535);
      var $730=$729 >> 8;
      var $731=$blue31;
      var $732=(($731)&65535);
      var $733=$732 & 255;
      var $734=$1;
      var $735=(($734+324)|0);
      var $736=HEAP32[(($735)>>2)];
      var $737=$733 >> (($736)|0);
      var $738=$1;
      var $739=(($738+356)|0);
      var $740=HEAP32[(($739)>>2)];
      var $741=(($740+($737<<2))|0);
      var $742=HEAP32[(($741)>>2)];
      var $743=(($742+($730<<1))|0);
      var $744=HEAP16[(($743)>>1)];
      $blue_135=$744;
      var $745=$rc;
      var $746=$red_133;
      var $747=(($746)&65535);
      var $748=((($745)*($747))|0);
      var $749=$gc;
      var $750=$green_134;
      var $751=(($750)&65535);
      var $752=((($749)*($751))|0);
      var $753=((($748)+($752))|0);
      var $754=$bc;
      var $755=$blue_135;
      var $756=(($755)&65535);
      var $757=((($754)*($756))|0);
      var $758=((($753)+($757))|0);
      var $759=$758 >>> 15;
      var $760=(($759) & 65535);
      $gray1636=$760;
      var $761=$gray1636;
      var $762=(($761)&65535);
      var $763=$762 >> 8;
      var $764=$gray1636;
      var $765=(($764)&65535);
      var $766=$765 & 255;
      var $767=$1;
      var $768=(($767+324)|0);
      var $769=HEAP32[(($768)>>2)];
      var $770=$766 >> (($769)|0);
      var $771=$1;
      var $772=(($771+352)|0);
      var $773=HEAP32[(($772)>>2)];
      var $774=(($773+($770<<2))|0);
      var $775=HEAP32[(($774)>>2)];
      var $776=(($775+($763<<1))|0);
      var $777=HEAP16[(($776)>>1)];
      $w32=$777;
      var $778=$rgb_error;
      var $779=$778 | 1;
      $rgb_error=$779;
      __label__ = 77; break;
    case 77: 
      var $781=$w32;
      var $782=(($781)&65535);
      var $783=$782 >> 8;
      var $784=$783 & 255;
      var $785=(($784) & 255);
      var $786=$dp28;
      var $787=(($786+1)|0);
      $dp28=$787;
      HEAP8[($786)]=$785;
      var $788=$w32;
      var $789=(($788)&65535);
      var $790=$789 & 255;
      var $791=(($790) & 255);
      var $792=$dp28;
      var $793=(($792+1)|0);
      $dp28=$793;
      HEAP8[($792)]=$791;
      var $794=$sp27;
      var $795=(($794+1)|0);
      $sp27=$795;
      var $796=HEAP8[($794)];
      var $797=$dp28;
      var $798=(($797+1)|0);
      $dp28=$798;
      HEAP8[($797)]=$796;
      var $799=$sp27;
      var $800=(($799+1)|0);
      $sp27=$800;
      var $801=HEAP8[($799)];
      var $802=$dp28;
      var $803=(($802+1)|0);
      $dp28=$803;
      HEAP8[($802)]=$801;
      __label__ = 78; break;
    case 78: 
      var $805=$i;
      var $806=((($805)+(1))|0);
      $i=$806;
      __label__ = 72; break;
    case 79: 
      __label__ = 88; break;
    case 80: 
      var $809=$3;
      $sp37=$809;
      var $810=$3;
      $dp38=$810;
      $i=0;
      __label__ = 81; break;
    case 81: 
      var $812=$i;
      var $813=$row_width;
      var $814=(($812)>>>0) < (($813)>>>0);
      if ($814) { __label__ = 82; break; } else { __label__ = 87; break; }
    case 82: 
      var $816=$sp37;
      var $817=HEAPU8[($816)];
      var $818=(($817)&255);
      var $819=$818 << 8;
      var $820=$sp37;
      var $821=(($820+1)|0);
      var $822=HEAPU8[($821)];
      var $823=(($822)&255);
      var $824=$819 | $823;
      var $825=(($824) & 65535);
      $red39=$825;
      var $826=$sp37;
      var $827=(($826+2)|0);
      $sp37=$827;
      var $828=$sp37;
      var $829=HEAPU8[($828)];
      var $830=(($829)&255);
      var $831=$830 << 8;
      var $832=$sp37;
      var $833=(($832+1)|0);
      var $834=HEAPU8[($833)];
      var $835=(($834)&255);
      var $836=$831 | $835;
      var $837=(($836) & 65535);
      $green40=$837;
      var $838=$sp37;
      var $839=(($838+2)|0);
      $sp37=$839;
      var $840=$sp37;
      var $841=HEAPU8[($840)];
      var $842=(($841)&255);
      var $843=$842 << 8;
      var $844=$sp37;
      var $845=(($844+1)|0);
      var $846=HEAPU8[($845)];
      var $847=(($846)&255);
      var $848=$843 | $847;
      var $849=(($848) & 65535);
      $blue41=$849;
      var $850=$sp37;
      var $851=(($850+2)|0);
      $sp37=$851;
      var $852=$red39;
      var $853=(($852)&65535);
      var $854=$green40;
      var $855=(($854)&65535);
      var $856=(($853)|0)!=(($855)|0);
      if ($856) { __label__ = 84; break; } else { __label__ = 83; break; }
    case 83: 
      var $858=$red39;
      var $859=(($858)&65535);
      var $860=$blue41;
      var $861=(($860)&65535);
      var $862=(($859)|0)!=(($861)|0);
      if ($862) { __label__ = 84; break; } else { __label__ = 85; break; }
    case 84: 
      var $864=$rgb_error;
      var $865=$864 | 1;
      $rgb_error=$865;
      __label__ = 85; break;
    case 85: 
      var $867=$rc;
      var $868=$red39;
      var $869=(($868)&65535);
      var $870=((($867)*($869))|0);
      var $871=$gc;
      var $872=$green40;
      var $873=(($872)&65535);
      var $874=((($871)*($873))|0);
      var $875=((($870)+($874))|0);
      var $876=$bc;
      var $877=$blue41;
      var $878=(($877)&65535);
      var $879=((($876)*($878))|0);
      var $880=((($875)+($879))|0);
      var $881=$880 >>> 15;
      var $882=(($881) & 65535);
      $gray1642=$882;
      var $883=$gray1642;
      var $884=(($883)&65535);
      var $885=$884 >> 8;
      var $886=$885 & 255;
      var $887=(($886) & 255);
      var $888=$dp38;
      var $889=(($888+1)|0);
      $dp38=$889;
      HEAP8[($888)]=$887;
      var $890=$gray1642;
      var $891=(($890)&65535);
      var $892=$891 & 255;
      var $893=(($892) & 255);
      var $894=$dp38;
      var $895=(($894+1)|0);
      $dp38=$895;
      HEAP8[($894)]=$893;
      var $896=$sp37;
      var $897=(($896+1)|0);
      $sp37=$897;
      var $898=HEAP8[($896)];
      var $899=$dp38;
      var $900=(($899+1)|0);
      $dp38=$900;
      HEAP8[($899)]=$898;
      var $901=$sp37;
      var $902=(($901+1)|0);
      $sp37=$902;
      var $903=HEAP8[($901)];
      var $904=$dp38;
      var $905=(($904+1)|0);
      $dp38=$905;
      HEAP8[($904)]=$903;
      __label__ = 86; break;
    case 86: 
      var $907=$i;
      var $908=((($907)+(1))|0);
      $i=$908;
      __label__ = 81; break;
    case 87: 
      __label__ = 88; break;
    case 88: 
      __label__ = 89; break;
    case 89: 
      __label__ = 90; break;
    case 90: 
      var $913=$2;
      var $914=(($913+10)|0);
      var $915=HEAPU8[($914)];
      var $916=(($915)&255);
      var $917=((($916)-(2))|0);
      var $918=(($917) & 255);
      HEAP8[($914)]=$918;
      var $919=$2;
      var $920=(($919+8)|0);
      var $921=HEAPU8[($920)];
      var $922=(($921)&255);
      var $923=$922 & -3;
      var $924=(($923) & 255);
      HEAP8[($920)]=$924;
      var $925=$2;
      var $926=(($925+10)|0);
      var $927=HEAPU8[($926)];
      var $928=(($927)&255);
      var $929=$2;
      var $930=(($929+9)|0);
      var $931=HEAPU8[($930)];
      var $932=(($931)&255);
      var $933=((($928)*($932))|0);
      var $934=(($933) & 255);
      var $935=$2;
      var $936=(($935+11)|0);
      HEAP8[($936)]=$934;
      var $937=$2;
      var $938=(($937+11)|0);
      var $939=HEAPU8[($938)];
      var $940=(($939)&255);
      var $941=(($940)|0) >= 8;
      if ($941) { __label__ = 91; break; } else { __label__ = 92; break; }
    case 91: 
      var $943=$row_width;
      var $944=$2;
      var $945=(($944+11)|0);
      var $946=HEAPU8[($945)];
      var $947=(($946)&255);
      var $948=$947 >>> 3;
      var $949=((($943)*($948))|0);
      var $960 = $949;__label__ = 93; break;
    case 92: 
      var $951=$row_width;
      var $952=$2;
      var $953=(($952+11)|0);
      var $954=HEAPU8[($953)];
      var $955=(($954)&255);
      var $956=((($951)*($955))|0);
      var $957=((($956)+(7))|0);
      var $958=$957 >>> 3;
      var $960 = $958;__label__ = 93; break;
    case 93: 
      var $960;
      var $961=$2;
      var $962=(($961+4)|0);
      HEAP32[(($962)>>2)]=$960;
      __label__ = 94; break;
    case 94: 
      var $964=$rgb_error;
      ;
      return $964;
    default: assert(0, "bad label: " + __label__);
  }
}
_png_do_rgb_to_gray["X"]=1;

function _png_do_gray_to_rgb($row_info, $row) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $i;
      var $row_width;
      var $sp;
      var $dp;
      var $sp1;
      var $dp2;
      var $sp3;
      var $dp4;
      var $sp5;
      var $dp6;
      $1=$row_info;
      $2=$row;
      var $3=$1;
      var $4=(($3)|0);
      var $5=HEAP32[(($4)>>2)];
      $row_width=$5;
      var $6=$1;
      var $7=(($6+9)|0);
      var $8=HEAPU8[($7)];
      var $9=(($8)&255);
      var $10=(($9)|0) >= 8;
      if ($10) { __label__ = 3; break; } else { __label__ = 35; break; }
    case 3: 
      var $12=$1;
      var $13=(($12+8)|0);
      var $14=HEAPU8[($13)];
      var $15=(($14)&255);
      var $16=$15 & 2;
      var $17=(($16)|0)!=0;
      if ($17) { __label__ = 35; break; } else { __label__ = 4; break; }
    case 4: 
      var $19=$1;
      var $20=(($19+8)|0);
      var $21=HEAPU8[($20)];
      var $22=(($21)&255);
      var $23=(($22)|0)==0;
      if ($23) { __label__ = 5; break; } else { __label__ = 17; break; }
    case 5: 
      var $25=$1;
      var $26=(($25+9)|0);
      var $27=HEAPU8[($26)];
      var $28=(($27)&255);
      var $29=(($28)|0)==8;
      if ($29) { __label__ = 6; break; } else { __label__ = 11; break; }
    case 6: 
      var $31=$2;
      var $32=$row_width;
      var $33=(($31+$32)|0);
      var $34=((($33)-(1))|0);
      $sp=$34;
      var $35=$sp;
      var $36=$row_width;
      var $37=((($36<<1))|0);
      var $38=(($35+$37)|0);
      $dp=$38;
      $i=0;
      __label__ = 7; break;
    case 7: 
      var $40=$i;
      var $41=$row_width;
      var $42=(($40)>>>0) < (($41)>>>0);
      if ($42) { __label__ = 8; break; } else { __label__ = 10; break; }
    case 8: 
      var $44=$sp;
      var $45=HEAP8[($44)];
      var $46=$dp;
      var $47=((($46)-(1))|0);
      $dp=$47;
      HEAP8[($46)]=$45;
      var $48=$sp;
      var $49=HEAP8[($48)];
      var $50=$dp;
      var $51=((($50)-(1))|0);
      $dp=$51;
      HEAP8[($50)]=$49;
      var $52=$sp;
      var $53=((($52)-(1))|0);
      $sp=$53;
      var $54=HEAP8[($52)];
      var $55=$dp;
      var $56=((($55)-(1))|0);
      $dp=$56;
      HEAP8[($55)]=$54;
      __label__ = 9; break;
    case 9: 
      var $58=$i;
      var $59=((($58)+(1))|0);
      $i=$59;
      __label__ = 7; break;
    case 10: 
      __label__ = 16; break;
    case 11: 
      var $62=$2;
      var $63=$row_width;
      var $64=((($63<<1))|0);
      var $65=(($62+$64)|0);
      var $66=((($65)-(1))|0);
      $sp1=$66;
      var $67=$sp1;
      var $68=$row_width;
      var $69=((($68<<2))|0);
      var $70=(($67+$69)|0);
      $dp2=$70;
      $i=0;
      __label__ = 12; break;
    case 12: 
      var $72=$i;
      var $73=$row_width;
      var $74=(($72)>>>0) < (($73)>>>0);
      if ($74) { __label__ = 13; break; } else { __label__ = 15; break; }
    case 13: 
      var $76=$sp1;
      var $77=HEAP8[($76)];
      var $78=$dp2;
      var $79=((($78)-(1))|0);
      $dp2=$79;
      HEAP8[($78)]=$77;
      var $80=$sp1;
      var $81=((($80)-(1))|0);
      var $82=HEAP8[($81)];
      var $83=$dp2;
      var $84=((($83)-(1))|0);
      $dp2=$84;
      HEAP8[($83)]=$82;
      var $85=$sp1;
      var $86=HEAP8[($85)];
      var $87=$dp2;
      var $88=((($87)-(1))|0);
      $dp2=$88;
      HEAP8[($87)]=$86;
      var $89=$sp1;
      var $90=((($89)-(1))|0);
      var $91=HEAP8[($90)];
      var $92=$dp2;
      var $93=((($92)-(1))|0);
      $dp2=$93;
      HEAP8[($92)]=$91;
      var $94=$sp1;
      var $95=((($94)-(1))|0);
      $sp1=$95;
      var $96=HEAP8[($94)];
      var $97=$dp2;
      var $98=((($97)-(1))|0);
      $dp2=$98;
      HEAP8[($97)]=$96;
      var $99=$sp1;
      var $100=((($99)-(1))|0);
      $sp1=$100;
      var $101=HEAP8[($99)];
      var $102=$dp2;
      var $103=((($102)-(1))|0);
      $dp2=$103;
      HEAP8[($102)]=$101;
      __label__ = 14; break;
    case 14: 
      var $105=$i;
      var $106=((($105)+(1))|0);
      $i=$106;
      __label__ = 12; break;
    case 15: 
      __label__ = 16; break;
    case 16: 
      __label__ = 31; break;
    case 17: 
      var $110=$1;
      var $111=(($110+8)|0);
      var $112=HEAPU8[($111)];
      var $113=(($112)&255);
      var $114=(($113)|0)==4;
      if ($114) { __label__ = 18; break; } else { __label__ = 30; break; }
    case 18: 
      var $116=$1;
      var $117=(($116+9)|0);
      var $118=HEAPU8[($117)];
      var $119=(($118)&255);
      var $120=(($119)|0)==8;
      if ($120) { __label__ = 19; break; } else { __label__ = 24; break; }
    case 19: 
      var $122=$2;
      var $123=$row_width;
      var $124=((($123<<1))|0);
      var $125=(($122+$124)|0);
      var $126=((($125)-(1))|0);
      $sp3=$126;
      var $127=$sp3;
      var $128=$row_width;
      var $129=((($128<<1))|0);
      var $130=(($127+$129)|0);
      $dp4=$130;
      $i=0;
      __label__ = 20; break;
    case 20: 
      var $132=$i;
      var $133=$row_width;
      var $134=(($132)>>>0) < (($133)>>>0);
      if ($134) { __label__ = 21; break; } else { __label__ = 23; break; }
    case 21: 
      var $136=$sp3;
      var $137=((($136)-(1))|0);
      $sp3=$137;
      var $138=HEAP8[($136)];
      var $139=$dp4;
      var $140=((($139)-(1))|0);
      $dp4=$140;
      HEAP8[($139)]=$138;
      var $141=$sp3;
      var $142=HEAP8[($141)];
      var $143=$dp4;
      var $144=((($143)-(1))|0);
      $dp4=$144;
      HEAP8[($143)]=$142;
      var $145=$sp3;
      var $146=HEAP8[($145)];
      var $147=$dp4;
      var $148=((($147)-(1))|0);
      $dp4=$148;
      HEAP8[($147)]=$146;
      var $149=$sp3;
      var $150=((($149)-(1))|0);
      $sp3=$150;
      var $151=HEAP8[($149)];
      var $152=$dp4;
      var $153=((($152)-(1))|0);
      $dp4=$153;
      HEAP8[($152)]=$151;
      __label__ = 22; break;
    case 22: 
      var $155=$i;
      var $156=((($155)+(1))|0);
      $i=$156;
      __label__ = 20; break;
    case 23: 
      __label__ = 29; break;
    case 24: 
      var $159=$2;
      var $160=$row_width;
      var $161=((($160<<2))|0);
      var $162=(($159+$161)|0);
      var $163=((($162)-(1))|0);
      $sp5=$163;
      var $164=$sp5;
      var $165=$row_width;
      var $166=((($165<<2))|0);
      var $167=(($164+$166)|0);
      $dp6=$167;
      $i=0;
      __label__ = 25; break;
    case 25: 
      var $169=$i;
      var $170=$row_width;
      var $171=(($169)>>>0) < (($170)>>>0);
      if ($171) { __label__ = 26; break; } else { __label__ = 28; break; }
    case 26: 
      var $173=$sp5;
      var $174=((($173)-(1))|0);
      $sp5=$174;
      var $175=HEAP8[($173)];
      var $176=$dp6;
      var $177=((($176)-(1))|0);
      $dp6=$177;
      HEAP8[($176)]=$175;
      var $178=$sp5;
      var $179=((($178)-(1))|0);
      $sp5=$179;
      var $180=HEAP8[($178)];
      var $181=$dp6;
      var $182=((($181)-(1))|0);
      $dp6=$182;
      HEAP8[($181)]=$180;
      var $183=$sp5;
      var $184=HEAP8[($183)];
      var $185=$dp6;
      var $186=((($185)-(1))|0);
      $dp6=$186;
      HEAP8[($185)]=$184;
      var $187=$sp5;
      var $188=((($187)-(1))|0);
      var $189=HEAP8[($188)];
      var $190=$dp6;
      var $191=((($190)-(1))|0);
      $dp6=$191;
      HEAP8[($190)]=$189;
      var $192=$sp5;
      var $193=HEAP8[($192)];
      var $194=$dp6;
      var $195=((($194)-(1))|0);
      $dp6=$195;
      HEAP8[($194)]=$193;
      var $196=$sp5;
      var $197=((($196)-(1))|0);
      var $198=HEAP8[($197)];
      var $199=$dp6;
      var $200=((($199)-(1))|0);
      $dp6=$200;
      HEAP8[($199)]=$198;
      var $201=$sp5;
      var $202=((($201)-(1))|0);
      $sp5=$202;
      var $203=HEAP8[($201)];
      var $204=$dp6;
      var $205=((($204)-(1))|0);
      $dp6=$205;
      HEAP8[($204)]=$203;
      var $206=$sp5;
      var $207=((($206)-(1))|0);
      $sp5=$207;
      var $208=HEAP8[($206)];
      var $209=$dp6;
      var $210=((($209)-(1))|0);
      $dp6=$210;
      HEAP8[($209)]=$208;
      __label__ = 27; break;
    case 27: 
      var $212=$i;
      var $213=((($212)+(1))|0);
      $i=$213;
      __label__ = 25; break;
    case 28: 
      __label__ = 29; break;
    case 29: 
      __label__ = 30; break;
    case 30: 
      __label__ = 31; break;
    case 31: 
      var $218=$1;
      var $219=(($218+10)|0);
      var $220=HEAPU8[($219)];
      var $221=(($220)&255);
      var $222=((($221)+(2))|0);
      var $223=(($222) & 255);
      HEAP8[($219)]=$223;
      var $224=$1;
      var $225=(($224+8)|0);
      var $226=HEAPU8[($225)];
      var $227=(($226)&255);
      var $228=$227 | 2;
      var $229=(($228) & 255);
      HEAP8[($225)]=$229;
      var $230=$1;
      var $231=(($230+10)|0);
      var $232=HEAPU8[($231)];
      var $233=(($232)&255);
      var $234=$1;
      var $235=(($234+9)|0);
      var $236=HEAPU8[($235)];
      var $237=(($236)&255);
      var $238=((($233)*($237))|0);
      var $239=(($238) & 255);
      var $240=$1;
      var $241=(($240+11)|0);
      HEAP8[($241)]=$239;
      var $242=$1;
      var $243=(($242+11)|0);
      var $244=HEAPU8[($243)];
      var $245=(($244)&255);
      var $246=(($245)|0) >= 8;
      if ($246) { __label__ = 32; break; } else { __label__ = 33; break; }
    case 32: 
      var $248=$row_width;
      var $249=$1;
      var $250=(($249+11)|0);
      var $251=HEAPU8[($250)];
      var $252=(($251)&255);
      var $253=$252 >>> 3;
      var $254=((($248)*($253))|0);
      var $265 = $254;__label__ = 34; break;
    case 33: 
      var $256=$row_width;
      var $257=$1;
      var $258=(($257+11)|0);
      var $259=HEAPU8[($258)];
      var $260=(($259)&255);
      var $261=((($256)*($260))|0);
      var $262=((($261)+(7))|0);
      var $263=$262 >>> 3;
      var $265 = $263;__label__ = 34; break;
    case 34: 
      var $265;
      var $266=$1;
      var $267=(($266+4)|0);
      HEAP32[(($267)>>2)]=$265;
      __label__ = 35; break;
    case 35: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_png_do_gray_to_rgb["X"]=1;

function _png_do_background($row_info, $row, $trans_color, $background, $background_1, $gamma_table, $gamma_from_1, $gamma_to_1, $gamma_16, $gamma_16_from_1, $gamma_16_to_1, $gamma_shift) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $5;
      var $6;
      var $7;
      var $8;
      var $9;
      var $10;
      var $11;
      var $12;
      var $sp;
      var $dp;
      var $i;
      var $row_width;
      var $shift;
      var $p;
      var $g;
      var $p1;
      var $g2;
      var $v;
      var $v3;
      var $r;
      var $g4;
      var $b;
      var $v5;
      var $r6;
      var $g7;
      var $b8;
      var $a;
      var $v9;
      var $w;
      var $temp;
      var $a10;
      var $temp11;
      var $a12;
      var $v13;
      var $g14;
      var $v15;
      var $w16;
      var $temp17;
      var $a18;
      var $g19;
      var $v20;
      var $temp21;
      var $a22;
      var $v23;
      var $w24;
      var $temp25;
      var $temp26;
      var $temp27;
      var $a28;
      var $temp29;
      var $temp30;
      var $temp31;
      var $a32;
      var $v33;
      var $v34;
      var $w35;
      var $x;
      var $temp36;
      var $temp37;
      var $temp38;
      var $a39;
      var $v40;
      var $r41;
      var $g42;
      var $b43;
      var $temp44;
      var $temp45;
      var $temp46;
      $1=$row_info;
      $2=$row;
      $3=$trans_color;
      $4=$background;
      $5=$background_1;
      $6=$gamma_table;
      $7=$gamma_from_1;
      $8=$gamma_to_1;
      $9=$gamma_16;
      $10=$gamma_16_from_1;
      $11=$gamma_16_to_1;
      $12=$gamma_shift;
      var $13=$1;
      var $14=(($13)|0);
      var $15=HEAP32[(($14)>>2)];
      $row_width=$15;
      var $16=$4;
      var $17=(($16)|0)!=0;
      if ($17) { __label__ = 3; break; } else { __label__ = 259; break; }
    case 3: 
      var $19=$1;
      var $20=(($19+8)|0);
      var $21=HEAPU8[($20)];
      var $22=(($21)&255);
      var $23=$22 & 4;
      var $24=(($23)|0)!=0;
      if ($24) { __label__ = 4; break; } else { __label__ = 6; break; }
    case 4: 
      var $26=$1;
      var $27=(($26+8)|0);
      var $28=HEAPU8[($27)];
      var $29=(($28)&255);
      var $30=(($29)|0)!=3;
      if ($30) { __label__ = 5; break; } else { __label__ = 259; break; }
    case 5: 
      var $32=$3;
      var $33=(($32)|0)!=0;
      if ($33) { __label__ = 6; break; } else { __label__ = 259; break; }
    case 6: 
      var $35=$1;
      var $36=(($35+8)|0);
      var $37=HEAPU8[($36)];
      var $38=(($37)&255);
      if ((($38)|0) == 0) {
        __label__ = 7; break;
      }
      else if ((($38)|0) == 2) {
        __label__ = 100; break;
      }
      else if ((($38)|0) == 4) {
        __label__ = 144; break;
      }
      else if ((($38)|0) == 6) {
        __label__ = 198; break;
      }
      else {
      __label__ = 252; break;
      }
      
    case 7: 
      var $40=$1;
      var $41=(($40+9)|0);
      var $42=HEAPU8[($41)];
      var $43=(($42)&255);
      if ((($43)|0) == 1) {
        __label__ = 8; break;
      }
      else if ((($43)|0) == 2) {
        __label__ = 18; break;
      }
      else if ((($43)|0) == 4) {
        __label__ = 41; break;
      }
      else if ((($43)|0) == 8) {
        __label__ = 64; break;
      }
      else if ((($43)|0) == 16) {
        __label__ = 81; break;
      }
      else {
      __label__ = 98; break;
      }
      
    case 8: 
      var $45=$2;
      $sp=$45;
      $shift=7;
      $i=0;
      __label__ = 9; break;
    case 9: 
      var $47=$i;
      var $48=$row_width;
      var $49=(($47)>>>0) < (($48)>>>0);
      if ($49) { __label__ = 10; break; } else { __label__ = 17; break; }
    case 10: 
      var $51=$sp;
      var $52=HEAPU8[($51)];
      var $53=(($52)&255);
      var $54=$shift;
      var $55=$53 >> (($54)|0);
      var $56=$55 & 1;
      var $57=(($56) & 65535);
      var $58=(($57)&65535);
      var $59=$3;
      var $60=(($59+8)|0);
      var $61=HEAPU16[(($60)>>1)];
      var $62=(($61)&65535);
      var $63=(($58)|0)==(($62)|0);
      if ($63) { __label__ = 11; break; } else { __label__ = 12; break; }
    case 11: 
      var $65=$shift;
      var $66=(((7)-($65))|0);
      var $67=32639 >> (($66)|0);
      var $68=$67 & 255;
      var $69=(($68) & 255);
      var $70=(($69)&255);
      var $71=$sp;
      var $72=HEAPU8[($71)];
      var $73=(($72)&255);
      var $74=$73 & $70;
      var $75=(($74) & 255);
      HEAP8[($71)]=$75;
      var $76=$4;
      var $77=(($76+8)|0);
      var $78=HEAPU16[(($77)>>1)];
      var $79=(($78)&65535);
      var $80=$shift;
      var $81=$79 << $80;
      var $82=(($81) & 255);
      var $83=(($82)&255);
      var $84=$sp;
      var $85=HEAPU8[($84)];
      var $86=(($85)&255);
      var $87=$86 | $83;
      var $88=(($87) & 255);
      HEAP8[($84)]=$88;
      __label__ = 12; break;
    case 12: 
      var $90=$shift;
      var $91=(($90)|0)!=0;
      if ($91) { __label__ = 14; break; } else { __label__ = 13; break; }
    case 13: 
      $shift=7;
      var $93=$sp;
      var $94=(($93+1)|0);
      $sp=$94;
      __label__ = 15; break;
    case 14: 
      var $96=$shift;
      var $97=((($96)-(1))|0);
      $shift=$97;
      __label__ = 15; break;
    case 15: 
      __label__ = 16; break;
    case 16: 
      var $100=$i;
      var $101=((($100)+(1))|0);
      $i=$101;
      __label__ = 9; break;
    case 17: 
      __label__ = 99; break;
    case 18: 
      var $104=$6;
      var $105=(($104)|0)!=0;
      if ($105) { __label__ = 19; break; } else { __label__ = 30; break; }
    case 19: 
      var $107=$2;
      $sp=$107;
      $shift=6;
      $i=0;
      __label__ = 20; break;
    case 20: 
      var $109=$i;
      var $110=$row_width;
      var $111=(($109)>>>0) < (($110)>>>0);
      if ($111) { __label__ = 21; break; } else { __label__ = 29; break; }
    case 21: 
      var $113=$sp;
      var $114=HEAPU8[($113)];
      var $115=(($114)&255);
      var $116=$shift;
      var $117=$115 >> (($116)|0);
      var $118=$117 & 3;
      var $119=(($118) & 65535);
      var $120=(($119)&65535);
      var $121=$3;
      var $122=(($121+8)|0);
      var $123=HEAPU16[(($122)>>1)];
      var $124=(($123)&65535);
      var $125=(($120)|0)==(($124)|0);
      if ($125) { __label__ = 22; break; } else { __label__ = 23; break; }
    case 22: 
      var $127=$shift;
      var $128=(((6)-($127))|0);
      var $129=16191 >> (($128)|0);
      var $130=$129 & 255;
      var $131=(($130) & 255);
      var $132=(($131)&255);
      var $133=$sp;
      var $134=HEAPU8[($133)];
      var $135=(($134)&255);
      var $136=$135 & $132;
      var $137=(($136) & 255);
      HEAP8[($133)]=$137;
      var $138=$4;
      var $139=(($138+8)|0);
      var $140=HEAPU16[(($139)>>1)];
      var $141=(($140)&65535);
      var $142=$shift;
      var $143=$141 << $142;
      var $144=(($143) & 255);
      var $145=(($144)&255);
      var $146=$sp;
      var $147=HEAPU8[($146)];
      var $148=(($147)&255);
      var $149=$148 | $145;
      var $150=(($149) & 255);
      HEAP8[($146)]=$150;
      __label__ = 24; break;
    case 23: 
      var $152=$sp;
      var $153=HEAPU8[($152)];
      var $154=(($153)&255);
      var $155=$shift;
      var $156=$154 >> (($155)|0);
      var $157=$156 & 3;
      var $158=(($157) & 255);
      $p=$158;
      var $159=$p;
      var $160=(($159)&255);
      var $161=$p;
      var $162=(($161)&255);
      var $163=$162 << 2;
      var $164=$160 | $163;
      var $165=$p;
      var $166=(($165)&255);
      var $167=$166 << 4;
      var $168=$164 | $167;
      var $169=$p;
      var $170=(($169)&255);
      var $171=$170 << 6;
      var $172=$168 | $171;
      var $173=$6;
      var $174=(($173+$172)|0);
      var $175=HEAPU8[($174)];
      var $176=(($175)&255);
      var $177=$176 >> 6;
      var $178=$177 & 3;
      var $179=(($178) & 255);
      $g=$179;
      var $180=$shift;
      var $181=(((6)-($180))|0);
      var $182=16191 >> (($181)|0);
      var $183=$182 & 255;
      var $184=(($183) & 255);
      var $185=(($184)&255);
      var $186=$sp;
      var $187=HEAPU8[($186)];
      var $188=(($187)&255);
      var $189=$188 & $185;
      var $190=(($189) & 255);
      HEAP8[($186)]=$190;
      var $191=$g;
      var $192=(($191)&255);
      var $193=$shift;
      var $194=$192 << $193;
      var $195=(($194) & 255);
      var $196=(($195)&255);
      var $197=$sp;
      var $198=HEAPU8[($197)];
      var $199=(($198)&255);
      var $200=$199 | $196;
      var $201=(($200) & 255);
      HEAP8[($197)]=$201;
      __label__ = 24; break;
    case 24: 
      var $203=$shift;
      var $204=(($203)|0)!=0;
      if ($204) { __label__ = 26; break; } else { __label__ = 25; break; }
    case 25: 
      $shift=6;
      var $206=$sp;
      var $207=(($206+1)|0);
      $sp=$207;
      __label__ = 27; break;
    case 26: 
      var $209=$shift;
      var $210=((($209)-(2))|0);
      $shift=$210;
      __label__ = 27; break;
    case 27: 
      __label__ = 28; break;
    case 28: 
      var $213=$i;
      var $214=((($213)+(1))|0);
      $i=$214;
      __label__ = 20; break;
    case 29: 
      __label__ = 40; break;
    case 30: 
      var $217=$2;
      $sp=$217;
      $shift=6;
      $i=0;
      __label__ = 31; break;
    case 31: 
      var $219=$i;
      var $220=$row_width;
      var $221=(($219)>>>0) < (($220)>>>0);
      if ($221) { __label__ = 32; break; } else { __label__ = 39; break; }
    case 32: 
      var $223=$sp;
      var $224=HEAPU8[($223)];
      var $225=(($224)&255);
      var $226=$shift;
      var $227=$225 >> (($226)|0);
      var $228=$227 & 3;
      var $229=(($228) & 65535);
      var $230=(($229)&65535);
      var $231=$3;
      var $232=(($231+8)|0);
      var $233=HEAPU16[(($232)>>1)];
      var $234=(($233)&65535);
      var $235=(($230)|0)==(($234)|0);
      if ($235) { __label__ = 33; break; } else { __label__ = 34; break; }
    case 33: 
      var $237=$shift;
      var $238=(((6)-($237))|0);
      var $239=16191 >> (($238)|0);
      var $240=$239 & 255;
      var $241=(($240) & 255);
      var $242=(($241)&255);
      var $243=$sp;
      var $244=HEAPU8[($243)];
      var $245=(($244)&255);
      var $246=$245 & $242;
      var $247=(($246) & 255);
      HEAP8[($243)]=$247;
      var $248=$4;
      var $249=(($248+8)|0);
      var $250=HEAPU16[(($249)>>1)];
      var $251=(($250)&65535);
      var $252=$shift;
      var $253=$251 << $252;
      var $254=(($253) & 255);
      var $255=(($254)&255);
      var $256=$sp;
      var $257=HEAPU8[($256)];
      var $258=(($257)&255);
      var $259=$258 | $255;
      var $260=(($259) & 255);
      HEAP8[($256)]=$260;
      __label__ = 34; break;
    case 34: 
      var $262=$shift;
      var $263=(($262)|0)!=0;
      if ($263) { __label__ = 36; break; } else { __label__ = 35; break; }
    case 35: 
      $shift=6;
      var $265=$sp;
      var $266=(($265+1)|0);
      $sp=$266;
      __label__ = 37; break;
    case 36: 
      var $268=$shift;
      var $269=((($268)-(2))|0);
      $shift=$269;
      __label__ = 37; break;
    case 37: 
      __label__ = 38; break;
    case 38: 
      var $272=$i;
      var $273=((($272)+(1))|0);
      $i=$273;
      __label__ = 31; break;
    case 39: 
      __label__ = 40; break;
    case 40: 
      __label__ = 99; break;
    case 41: 
      var $277=$6;
      var $278=(($277)|0)!=0;
      if ($278) { __label__ = 42; break; } else { __label__ = 53; break; }
    case 42: 
      var $280=$2;
      $sp=$280;
      $shift=4;
      $i=0;
      __label__ = 43; break;
    case 43: 
      var $282=$i;
      var $283=$row_width;
      var $284=(($282)>>>0) < (($283)>>>0);
      if ($284) { __label__ = 44; break; } else { __label__ = 52; break; }
    case 44: 
      var $286=$sp;
      var $287=HEAPU8[($286)];
      var $288=(($287)&255);
      var $289=$shift;
      var $290=$288 >> (($289)|0);
      var $291=$290 & 15;
      var $292=(($291) & 65535);
      var $293=(($292)&65535);
      var $294=$3;
      var $295=(($294+8)|0);
      var $296=HEAPU16[(($295)>>1)];
      var $297=(($296)&65535);
      var $298=(($293)|0)==(($297)|0);
      if ($298) { __label__ = 45; break; } else { __label__ = 46; break; }
    case 45: 
      var $300=$shift;
      var $301=(((4)-($300))|0);
      var $302=3855 >> (($301)|0);
      var $303=$302 & 255;
      var $304=(($303) & 255);
      var $305=(($304)&255);
      var $306=$sp;
      var $307=HEAPU8[($306)];
      var $308=(($307)&255);
      var $309=$308 & $305;
      var $310=(($309) & 255);
      HEAP8[($306)]=$310;
      var $311=$4;
      var $312=(($311+8)|0);
      var $313=HEAPU16[(($312)>>1)];
      var $314=(($313)&65535);
      var $315=$shift;
      var $316=$314 << $315;
      var $317=(($316) & 255);
      var $318=(($317)&255);
      var $319=$sp;
      var $320=HEAPU8[($319)];
      var $321=(($320)&255);
      var $322=$321 | $318;
      var $323=(($322) & 255);
      HEAP8[($319)]=$323;
      __label__ = 47; break;
    case 46: 
      var $325=$sp;
      var $326=HEAPU8[($325)];
      var $327=(($326)&255);
      var $328=$shift;
      var $329=$327 >> (($328)|0);
      var $330=$329 & 15;
      var $331=(($330) & 255);
      $p1=$331;
      var $332=$p1;
      var $333=(($332)&255);
      var $334=$p1;
      var $335=(($334)&255);
      var $336=$335 << 4;
      var $337=$333 | $336;
      var $338=$6;
      var $339=(($338+$337)|0);
      var $340=HEAPU8[($339)];
      var $341=(($340)&255);
      var $342=$341 >> 4;
      var $343=$342 & 15;
      var $344=(($343) & 255);
      $g2=$344;
      var $345=$shift;
      var $346=(((4)-($345))|0);
      var $347=3855 >> (($346)|0);
      var $348=$347 & 255;
      var $349=(($348) & 255);
      var $350=(($349)&255);
      var $351=$sp;
      var $352=HEAPU8[($351)];
      var $353=(($352)&255);
      var $354=$353 & $350;
      var $355=(($354) & 255);
      HEAP8[($351)]=$355;
      var $356=$g2;
      var $357=(($356)&255);
      var $358=$shift;
      var $359=$357 << $358;
      var $360=(($359) & 255);
      var $361=(($360)&255);
      var $362=$sp;
      var $363=HEAPU8[($362)];
      var $364=(($363)&255);
      var $365=$364 | $361;
      var $366=(($365) & 255);
      HEAP8[($362)]=$366;
      __label__ = 47; break;
    case 47: 
      var $368=$shift;
      var $369=(($368)|0)!=0;
      if ($369) { __label__ = 49; break; } else { __label__ = 48; break; }
    case 48: 
      $shift=4;
      var $371=$sp;
      var $372=(($371+1)|0);
      $sp=$372;
      __label__ = 50; break;
    case 49: 
      var $374=$shift;
      var $375=((($374)-(4))|0);
      $shift=$375;
      __label__ = 50; break;
    case 50: 
      __label__ = 51; break;
    case 51: 
      var $378=$i;
      var $379=((($378)+(1))|0);
      $i=$379;
      __label__ = 43; break;
    case 52: 
      __label__ = 63; break;
    case 53: 
      var $382=$2;
      $sp=$382;
      $shift=4;
      $i=0;
      __label__ = 54; break;
    case 54: 
      var $384=$i;
      var $385=$row_width;
      var $386=(($384)>>>0) < (($385)>>>0);
      if ($386) { __label__ = 55; break; } else { __label__ = 62; break; }
    case 55: 
      var $388=$sp;
      var $389=HEAPU8[($388)];
      var $390=(($389)&255);
      var $391=$shift;
      var $392=$390 >> (($391)|0);
      var $393=$392 & 15;
      var $394=(($393) & 65535);
      var $395=(($394)&65535);
      var $396=$3;
      var $397=(($396+8)|0);
      var $398=HEAPU16[(($397)>>1)];
      var $399=(($398)&65535);
      var $400=(($395)|0)==(($399)|0);
      if ($400) { __label__ = 56; break; } else { __label__ = 57; break; }
    case 56: 
      var $402=$shift;
      var $403=(((4)-($402))|0);
      var $404=3855 >> (($403)|0);
      var $405=$404 & 255;
      var $406=(($405) & 255);
      var $407=(($406)&255);
      var $408=$sp;
      var $409=HEAPU8[($408)];
      var $410=(($409)&255);
      var $411=$410 & $407;
      var $412=(($411) & 255);
      HEAP8[($408)]=$412;
      var $413=$4;
      var $414=(($413+8)|0);
      var $415=HEAPU16[(($414)>>1)];
      var $416=(($415)&65535);
      var $417=$shift;
      var $418=$416 << $417;
      var $419=(($418) & 255);
      var $420=(($419)&255);
      var $421=$sp;
      var $422=HEAPU8[($421)];
      var $423=(($422)&255);
      var $424=$423 | $420;
      var $425=(($424) & 255);
      HEAP8[($421)]=$425;
      __label__ = 57; break;
    case 57: 
      var $427=$shift;
      var $428=(($427)|0)!=0;
      if ($428) { __label__ = 59; break; } else { __label__ = 58; break; }
    case 58: 
      $shift=4;
      var $430=$sp;
      var $431=(($430+1)|0);
      $sp=$431;
      __label__ = 60; break;
    case 59: 
      var $433=$shift;
      var $434=((($433)-(4))|0);
      $shift=$434;
      __label__ = 60; break;
    case 60: 
      __label__ = 61; break;
    case 61: 
      var $437=$i;
      var $438=((($437)+(1))|0);
      $i=$438;
      __label__ = 54; break;
    case 62: 
      __label__ = 63; break;
    case 63: 
      __label__ = 99; break;
    case 64: 
      var $442=$6;
      var $443=(($442)|0)!=0;
      if ($443) { __label__ = 65; break; } else { __label__ = 73; break; }
    case 65: 
      var $445=$2;
      $sp=$445;
      $i=0;
      __label__ = 66; break;
    case 66: 
      var $447=$i;
      var $448=$row_width;
      var $449=(($447)>>>0) < (($448)>>>0);
      if ($449) { __label__ = 67; break; } else { __label__ = 72; break; }
    case 67: 
      var $451=$sp;
      var $452=HEAPU8[($451)];
      var $453=(($452)&255);
      var $454=$3;
      var $455=(($454+8)|0);
      var $456=HEAPU16[(($455)>>1)];
      var $457=(($456)&65535);
      var $458=(($453)|0)==(($457)|0);
      if ($458) { __label__ = 68; break; } else { __label__ = 69; break; }
    case 68: 
      var $460=$4;
      var $461=(($460+8)|0);
      var $462=HEAP16[(($461)>>1)];
      var $463=(($462) & 255);
      var $464=$sp;
      HEAP8[($464)]=$463;
      __label__ = 70; break;
    case 69: 
      var $466=$sp;
      var $467=HEAPU8[($466)];
      var $468=(($467)&255);
      var $469=$6;
      var $470=(($469+$468)|0);
      var $471=HEAP8[($470)];
      var $472=$sp;
      HEAP8[($472)]=$471;
      __label__ = 70; break;
    case 70: 
      __label__ = 71; break;
    case 71: 
      var $475=$i;
      var $476=((($475)+(1))|0);
      $i=$476;
      var $477=$sp;
      var $478=(($477+1)|0);
      $sp=$478;
      __label__ = 66; break;
    case 72: 
      __label__ = 80; break;
    case 73: 
      var $481=$2;
      $sp=$481;
      $i=0;
      __label__ = 74; break;
    case 74: 
      var $483=$i;
      var $484=$row_width;
      var $485=(($483)>>>0) < (($484)>>>0);
      if ($485) { __label__ = 75; break; } else { __label__ = 79; break; }
    case 75: 
      var $487=$sp;
      var $488=HEAPU8[($487)];
      var $489=(($488)&255);
      var $490=$3;
      var $491=(($490+8)|0);
      var $492=HEAPU16[(($491)>>1)];
      var $493=(($492)&65535);
      var $494=(($489)|0)==(($493)|0);
      if ($494) { __label__ = 76; break; } else { __label__ = 77; break; }
    case 76: 
      var $496=$4;
      var $497=(($496+8)|0);
      var $498=HEAP16[(($497)>>1)];
      var $499=(($498) & 255);
      var $500=$sp;
      HEAP8[($500)]=$499;
      __label__ = 77; break;
    case 77: 
      __label__ = 78; break;
    case 78: 
      var $503=$i;
      var $504=((($503)+(1))|0);
      $i=$504;
      var $505=$sp;
      var $506=(($505+1)|0);
      $sp=$506;
      __label__ = 74; break;
    case 79: 
      __label__ = 80; break;
    case 80: 
      __label__ = 99; break;
    case 81: 
      var $510=$9;
      var $511=(($510)|0)!=0;
      if ($511) { __label__ = 82; break; } else { __label__ = 90; break; }
    case 82: 
      var $513=$2;
      $sp=$513;
      $i=0;
      __label__ = 83; break;
    case 83: 
      var $515=$i;
      var $516=$row_width;
      var $517=(($515)>>>0) < (($516)>>>0);
      if ($517) { __label__ = 84; break; } else { __label__ = 89; break; }
    case 84: 
      var $519=$sp;
      var $520=HEAPU8[($519)];
      var $521=(($520)&255);
      var $522=$521 << 8;
      var $523=$sp;
      var $524=(($523+1)|0);
      var $525=HEAPU8[($524)];
      var $526=(($525)&255);
      var $527=((($522)+($526))|0);
      var $528=(($527) & 65535);
      $v=$528;
      var $529=$v;
      var $530=(($529)&65535);
      var $531=$3;
      var $532=(($531+8)|0);
      var $533=HEAPU16[(($532)>>1)];
      var $534=(($533)&65535);
      var $535=(($530)|0)==(($534)|0);
      if ($535) { __label__ = 85; break; } else { __label__ = 86; break; }
    case 85: 
      var $537=$4;
      var $538=(($537+8)|0);
      var $539=HEAPU16[(($538)>>1)];
      var $540=(($539)&65535);
      var $541=$540 >> 8;
      var $542=$541 & 255;
      var $543=(($542) & 255);
      var $544=$sp;
      HEAP8[($544)]=$543;
      var $545=$4;
      var $546=(($545+8)|0);
      var $547=HEAPU16[(($546)>>1)];
      var $548=(($547)&65535);
      var $549=$548 & 255;
      var $550=(($549) & 255);
      var $551=$sp;
      var $552=(($551+1)|0);
      HEAP8[($552)]=$550;
      __label__ = 87; break;
    case 86: 
      var $554=$sp;
      var $555=HEAPU8[($554)];
      var $556=(($555)&255);
      var $557=$sp;
      var $558=(($557+1)|0);
      var $559=HEAPU8[($558)];
      var $560=(($559)&255);
      var $561=$12;
      var $562=$560 >> (($561)|0);
      var $563=$9;
      var $564=(($563+($562<<2))|0);
      var $565=HEAP32[(($564)>>2)];
      var $566=(($565+($556<<1))|0);
      var $567=HEAP16[(($566)>>1)];
      $v=$567;
      var $568=$v;
      var $569=(($568)&65535);
      var $570=$569 >> 8;
      var $571=$570 & 255;
      var $572=(($571) & 255);
      var $573=$sp;
      HEAP8[($573)]=$572;
      var $574=$v;
      var $575=(($574)&65535);
      var $576=$575 & 255;
      var $577=(($576) & 255);
      var $578=$sp;
      var $579=(($578+1)|0);
      HEAP8[($579)]=$577;
      __label__ = 87; break;
    case 87: 
      __label__ = 88; break;
    case 88: 
      var $582=$i;
      var $583=((($582)+(1))|0);
      $i=$583;
      var $584=$sp;
      var $585=(($584+2)|0);
      $sp=$585;
      __label__ = 83; break;
    case 89: 
      __label__ = 97; break;
    case 90: 
      var $588=$2;
      $sp=$588;
      $i=0;
      __label__ = 91; break;
    case 91: 
      var $590=$i;
      var $591=$row_width;
      var $592=(($590)>>>0) < (($591)>>>0);
      if ($592) { __label__ = 92; break; } else { __label__ = 96; break; }
    case 92: 
      var $594=$sp;
      var $595=HEAPU8[($594)];
      var $596=(($595)&255);
      var $597=$596 << 8;
      var $598=$sp;
      var $599=(($598+1)|0);
      var $600=HEAPU8[($599)];
      var $601=(($600)&255);
      var $602=((($597)+($601))|0);
      var $603=(($602) & 65535);
      $v3=$603;
      var $604=$v3;
      var $605=(($604)&65535);
      var $606=$3;
      var $607=(($606+8)|0);
      var $608=HEAPU16[(($607)>>1)];
      var $609=(($608)&65535);
      var $610=(($605)|0)==(($609)|0);
      if ($610) { __label__ = 93; break; } else { __label__ = 94; break; }
    case 93: 
      var $612=$4;
      var $613=(($612+8)|0);
      var $614=HEAPU16[(($613)>>1)];
      var $615=(($614)&65535);
      var $616=$615 >> 8;
      var $617=$616 & 255;
      var $618=(($617) & 255);
      var $619=$sp;
      HEAP8[($619)]=$618;
      var $620=$4;
      var $621=(($620+8)|0);
      var $622=HEAPU16[(($621)>>1)];
      var $623=(($622)&65535);
      var $624=$623 & 255;
      var $625=(($624) & 255);
      var $626=$sp;
      var $627=(($626+1)|0);
      HEAP8[($627)]=$625;
      __label__ = 94; break;
    case 94: 
      __label__ = 95; break;
    case 95: 
      var $630=$i;
      var $631=((($630)+(1))|0);
      $i=$631;
      var $632=$sp;
      var $633=(($632+2)|0);
      $sp=$633;
      __label__ = 91; break;
    case 96: 
      __label__ = 97; break;
    case 97: 
      __label__ = 99; break;
    case 98: 
      __label__ = 99; break;
    case 99: 
      __label__ = 253; break;
    case 100: 
      var $639=$1;
      var $640=(($639+9)|0);
      var $641=HEAPU8[($640)];
      var $642=(($641)&255);
      var $643=(($642)|0)==8;
      if ($643) { __label__ = 101; break; } else { __label__ = 122; break; }
    case 101: 
      var $645=$6;
      var $646=(($645)|0)!=0;
      if ($646) { __label__ = 102; break; } else { __label__ = 112; break; }
    case 102: 
      var $648=$2;
      $sp=$648;
      $i=0;
      __label__ = 103; break;
    case 103: 
      var $650=$i;
      var $651=$row_width;
      var $652=(($650)>>>0) < (($651)>>>0);
      if ($652) { __label__ = 104; break; } else { __label__ = 111; break; }
    case 104: 
      var $654=$sp;
      var $655=HEAPU8[($654)];
      var $656=(($655)&255);
      var $657=$3;
      var $658=(($657+2)|0);
      var $659=HEAPU16[(($658)>>1)];
      var $660=(($659)&65535);
      var $661=(($656)|0)==(($660)|0);
      if ($661) { __label__ = 105; break; } else { __label__ = 108; break; }
    case 105: 
      var $663=$sp;
      var $664=(($663+1)|0);
      var $665=HEAPU8[($664)];
      var $666=(($665)&255);
      var $667=$3;
      var $668=(($667+4)|0);
      var $669=HEAPU16[(($668)>>1)];
      var $670=(($669)&65535);
      var $671=(($666)|0)==(($670)|0);
      if ($671) { __label__ = 106; break; } else { __label__ = 108; break; }
    case 106: 
      var $673=$sp;
      var $674=(($673+2)|0);
      var $675=HEAPU8[($674)];
      var $676=(($675)&255);
      var $677=$3;
      var $678=(($677+6)|0);
      var $679=HEAPU16[(($678)>>1)];
      var $680=(($679)&65535);
      var $681=(($676)|0)==(($680)|0);
      if ($681) { __label__ = 107; break; } else { __label__ = 108; break; }
    case 107: 
      var $683=$4;
      var $684=(($683+2)|0);
      var $685=HEAP16[(($684)>>1)];
      var $686=(($685) & 255);
      var $687=$sp;
      HEAP8[($687)]=$686;
      var $688=$4;
      var $689=(($688+4)|0);
      var $690=HEAP16[(($689)>>1)];
      var $691=(($690) & 255);
      var $692=$sp;
      var $693=(($692+1)|0);
      HEAP8[($693)]=$691;
      var $694=$4;
      var $695=(($694+6)|0);
      var $696=HEAP16[(($695)>>1)];
      var $697=(($696) & 255);
      var $698=$sp;
      var $699=(($698+2)|0);
      HEAP8[($699)]=$697;
      __label__ = 109; break;
    case 108: 
      var $701=$sp;
      var $702=HEAPU8[($701)];
      var $703=(($702)&255);
      var $704=$6;
      var $705=(($704+$703)|0);
      var $706=HEAP8[($705)];
      var $707=$sp;
      HEAP8[($707)]=$706;
      var $708=$sp;
      var $709=(($708+1)|0);
      var $710=HEAPU8[($709)];
      var $711=(($710)&255);
      var $712=$6;
      var $713=(($712+$711)|0);
      var $714=HEAP8[($713)];
      var $715=$sp;
      var $716=(($715+1)|0);
      HEAP8[($716)]=$714;
      var $717=$sp;
      var $718=(($717+2)|0);
      var $719=HEAPU8[($718)];
      var $720=(($719)&255);
      var $721=$6;
      var $722=(($721+$720)|0);
      var $723=HEAP8[($722)];
      var $724=$sp;
      var $725=(($724+2)|0);
      HEAP8[($725)]=$723;
      __label__ = 109; break;
    case 109: 
      __label__ = 110; break;
    case 110: 
      var $728=$i;
      var $729=((($728)+(1))|0);
      $i=$729;
      var $730=$sp;
      var $731=(($730+3)|0);
      $sp=$731;
      __label__ = 103; break;
    case 111: 
      __label__ = 121; break;
    case 112: 
      var $734=$2;
      $sp=$734;
      $i=0;
      __label__ = 113; break;
    case 113: 
      var $736=$i;
      var $737=$row_width;
      var $738=(($736)>>>0) < (($737)>>>0);
      if ($738) { __label__ = 114; break; } else { __label__ = 120; break; }
    case 114: 
      var $740=$sp;
      var $741=HEAPU8[($740)];
      var $742=(($741)&255);
      var $743=$3;
      var $744=(($743+2)|0);
      var $745=HEAPU16[(($744)>>1)];
      var $746=(($745)&65535);
      var $747=(($742)|0)==(($746)|0);
      if ($747) { __label__ = 115; break; } else { __label__ = 118; break; }
    case 115: 
      var $749=$sp;
      var $750=(($749+1)|0);
      var $751=HEAPU8[($750)];
      var $752=(($751)&255);
      var $753=$3;
      var $754=(($753+4)|0);
      var $755=HEAPU16[(($754)>>1)];
      var $756=(($755)&65535);
      var $757=(($752)|0)==(($756)|0);
      if ($757) { __label__ = 116; break; } else { __label__ = 118; break; }
    case 116: 
      var $759=$sp;
      var $760=(($759+2)|0);
      var $761=HEAPU8[($760)];
      var $762=(($761)&255);
      var $763=$3;
      var $764=(($763+6)|0);
      var $765=HEAPU16[(($764)>>1)];
      var $766=(($765)&65535);
      var $767=(($762)|0)==(($766)|0);
      if ($767) { __label__ = 117; break; } else { __label__ = 118; break; }
    case 117: 
      var $769=$4;
      var $770=(($769+2)|0);
      var $771=HEAP16[(($770)>>1)];
      var $772=(($771) & 255);
      var $773=$sp;
      HEAP8[($773)]=$772;
      var $774=$4;
      var $775=(($774+4)|0);
      var $776=HEAP16[(($775)>>1)];
      var $777=(($776) & 255);
      var $778=$sp;
      var $779=(($778+1)|0);
      HEAP8[($779)]=$777;
      var $780=$4;
      var $781=(($780+6)|0);
      var $782=HEAP16[(($781)>>1)];
      var $783=(($782) & 255);
      var $784=$sp;
      var $785=(($784+2)|0);
      HEAP8[($785)]=$783;
      __label__ = 118; break;
    case 118: 
      __label__ = 119; break;
    case 119: 
      var $788=$i;
      var $789=((($788)+(1))|0);
      $i=$789;
      var $790=$sp;
      var $791=(($790+3)|0);
      $sp=$791;
      __label__ = 113; break;
    case 120: 
      __label__ = 121; break;
    case 121: 
      __label__ = 143; break;
    case 122: 
      var $795=$9;
      var $796=(($795)|0)!=0;
      if ($796) { __label__ = 123; break; } else { __label__ = 133; break; }
    case 123: 
      var $798=$2;
      $sp=$798;
      $i=0;
      __label__ = 124; break;
    case 124: 
      var $800=$i;
      var $801=$row_width;
      var $802=(($800)>>>0) < (($801)>>>0);
      if ($802) { __label__ = 125; break; } else { __label__ = 132; break; }
    case 125: 
      var $804=$sp;
      var $805=HEAPU8[($804)];
      var $806=(($805)&255);
      var $807=$806 << 8;
      var $808=$sp;
      var $809=(($808+1)|0);
      var $810=HEAPU8[($809)];
      var $811=(($810)&255);
      var $812=((($807)+($811))|0);
      var $813=(($812) & 65535);
      $r=$813;
      var $814=$sp;
      var $815=(($814+2)|0);
      var $816=HEAPU8[($815)];
      var $817=(($816)&255);
      var $818=$817 << 8;
      var $819=$sp;
      var $820=(($819+3)|0);
      var $821=HEAPU8[($820)];
      var $822=(($821)&255);
      var $823=((($818)+($822))|0);
      var $824=(($823) & 65535);
      $g4=$824;
      var $825=$sp;
      var $826=(($825+4)|0);
      var $827=HEAPU8[($826)];
      var $828=(($827)&255);
      var $829=$828 << 8;
      var $830=$sp;
      var $831=(($830+5)|0);
      var $832=HEAPU8[($831)];
      var $833=(($832)&255);
      var $834=((($829)+($833))|0);
      var $835=(($834) & 65535);
      $b=$835;
      var $836=$r;
      var $837=(($836)&65535);
      var $838=$3;
      var $839=(($838+2)|0);
      var $840=HEAPU16[(($839)>>1)];
      var $841=(($840)&65535);
      var $842=(($837)|0)==(($841)|0);
      if ($842) { __label__ = 126; break; } else { __label__ = 129; break; }
    case 126: 
      var $844=$g4;
      var $845=(($844)&65535);
      var $846=$3;
      var $847=(($846+4)|0);
      var $848=HEAPU16[(($847)>>1)];
      var $849=(($848)&65535);
      var $850=(($845)|0)==(($849)|0);
      if ($850) { __label__ = 127; break; } else { __label__ = 129; break; }
    case 127: 
      var $852=$b;
      var $853=(($852)&65535);
      var $854=$3;
      var $855=(($854+6)|0);
      var $856=HEAPU16[(($855)>>1)];
      var $857=(($856)&65535);
      var $858=(($853)|0)==(($857)|0);
      if ($858) { __label__ = 128; break; } else { __label__ = 129; break; }
    case 128: 
      var $860=$4;
      var $861=(($860+2)|0);
      var $862=HEAPU16[(($861)>>1)];
      var $863=(($862)&65535);
      var $864=$863 >> 8;
      var $865=$864 & 255;
      var $866=(($865) & 255);
      var $867=$sp;
      HEAP8[($867)]=$866;
      var $868=$4;
      var $869=(($868+2)|0);
      var $870=HEAPU16[(($869)>>1)];
      var $871=(($870)&65535);
      var $872=$871 & 255;
      var $873=(($872) & 255);
      var $874=$sp;
      var $875=(($874+1)|0);
      HEAP8[($875)]=$873;
      var $876=$4;
      var $877=(($876+4)|0);
      var $878=HEAPU16[(($877)>>1)];
      var $879=(($878)&65535);
      var $880=$879 >> 8;
      var $881=$880 & 255;
      var $882=(($881) & 255);
      var $883=$sp;
      var $884=(($883+2)|0);
      HEAP8[($884)]=$882;
      var $885=$4;
      var $886=(($885+4)|0);
      var $887=HEAPU16[(($886)>>1)];
      var $888=(($887)&65535);
      var $889=$888 & 255;
      var $890=(($889) & 255);
      var $891=$sp;
      var $892=(($891+3)|0);
      HEAP8[($892)]=$890;
      var $893=$4;
      var $894=(($893+6)|0);
      var $895=HEAPU16[(($894)>>1)];
      var $896=(($895)&65535);
      var $897=$896 >> 8;
      var $898=$897 & 255;
      var $899=(($898) & 255);
      var $900=$sp;
      var $901=(($900+4)|0);
      HEAP8[($901)]=$899;
      var $902=$4;
      var $903=(($902+6)|0);
      var $904=HEAPU16[(($903)>>1)];
      var $905=(($904)&65535);
      var $906=$905 & 255;
      var $907=(($906) & 255);
      var $908=$sp;
      var $909=(($908+5)|0);
      HEAP8[($909)]=$907;
      __label__ = 130; break;
    case 129: 
      var $911=$sp;
      var $912=HEAPU8[($911)];
      var $913=(($912)&255);
      var $914=$sp;
      var $915=(($914+1)|0);
      var $916=HEAPU8[($915)];
      var $917=(($916)&255);
      var $918=$12;
      var $919=$917 >> (($918)|0);
      var $920=$9;
      var $921=(($920+($919<<2))|0);
      var $922=HEAP32[(($921)>>2)];
      var $923=(($922+($913<<1))|0);
      var $924=HEAP16[(($923)>>1)];
      $v5=$924;
      var $925=$v5;
      var $926=(($925)&65535);
      var $927=$926 >> 8;
      var $928=$927 & 255;
      var $929=(($928) & 255);
      var $930=$sp;
      HEAP8[($930)]=$929;
      var $931=$v5;
      var $932=(($931)&65535);
      var $933=$932 & 255;
      var $934=(($933) & 255);
      var $935=$sp;
      var $936=(($935+1)|0);
      HEAP8[($936)]=$934;
      var $937=$sp;
      var $938=(($937+2)|0);
      var $939=HEAPU8[($938)];
      var $940=(($939)&255);
      var $941=$sp;
      var $942=(($941+3)|0);
      var $943=HEAPU8[($942)];
      var $944=(($943)&255);
      var $945=$12;
      var $946=$944 >> (($945)|0);
      var $947=$9;
      var $948=(($947+($946<<2))|0);
      var $949=HEAP32[(($948)>>2)];
      var $950=(($949+($940<<1))|0);
      var $951=HEAP16[(($950)>>1)];
      $v5=$951;
      var $952=$v5;
      var $953=(($952)&65535);
      var $954=$953 >> 8;
      var $955=$954 & 255;
      var $956=(($955) & 255);
      var $957=$sp;
      var $958=(($957+2)|0);
      HEAP8[($958)]=$956;
      var $959=$v5;
      var $960=(($959)&65535);
      var $961=$960 & 255;
      var $962=(($961) & 255);
      var $963=$sp;
      var $964=(($963+3)|0);
      HEAP8[($964)]=$962;
      var $965=$sp;
      var $966=(($965+4)|0);
      var $967=HEAPU8[($966)];
      var $968=(($967)&255);
      var $969=$sp;
      var $970=(($969+5)|0);
      var $971=HEAPU8[($970)];
      var $972=(($971)&255);
      var $973=$12;
      var $974=$972 >> (($973)|0);
      var $975=$9;
      var $976=(($975+($974<<2))|0);
      var $977=HEAP32[(($976)>>2)];
      var $978=(($977+($968<<1))|0);
      var $979=HEAP16[(($978)>>1)];
      $v5=$979;
      var $980=$v5;
      var $981=(($980)&65535);
      var $982=$981 >> 8;
      var $983=$982 & 255;
      var $984=(($983) & 255);
      var $985=$sp;
      var $986=(($985+4)|0);
      HEAP8[($986)]=$984;
      var $987=$v5;
      var $988=(($987)&65535);
      var $989=$988 & 255;
      var $990=(($989) & 255);
      var $991=$sp;
      var $992=(($991+5)|0);
      HEAP8[($992)]=$990;
      __label__ = 130; break;
    case 130: 
      __label__ = 131; break;
    case 131: 
      var $995=$i;
      var $996=((($995)+(1))|0);
      $i=$996;
      var $997=$sp;
      var $998=(($997+6)|0);
      $sp=$998;
      __label__ = 124; break;
    case 132: 
      __label__ = 142; break;
    case 133: 
      var $1001=$2;
      $sp=$1001;
      $i=0;
      __label__ = 134; break;
    case 134: 
      var $1003=$i;
      var $1004=$row_width;
      var $1005=(($1003)>>>0) < (($1004)>>>0);
      if ($1005) { __label__ = 135; break; } else { __label__ = 141; break; }
    case 135: 
      var $1007=$sp;
      var $1008=HEAPU8[($1007)];
      var $1009=(($1008)&255);
      var $1010=$1009 << 8;
      var $1011=$sp;
      var $1012=(($1011+1)|0);
      var $1013=HEAPU8[($1012)];
      var $1014=(($1013)&255);
      var $1015=((($1010)+($1014))|0);
      var $1016=(($1015) & 65535);
      $r6=$1016;
      var $1017=$sp;
      var $1018=(($1017+2)|0);
      var $1019=HEAPU8[($1018)];
      var $1020=(($1019)&255);
      var $1021=$1020 << 8;
      var $1022=$sp;
      var $1023=(($1022+3)|0);
      var $1024=HEAPU8[($1023)];
      var $1025=(($1024)&255);
      var $1026=((($1021)+($1025))|0);
      var $1027=(($1026) & 65535);
      $g7=$1027;
      var $1028=$sp;
      var $1029=(($1028+4)|0);
      var $1030=HEAPU8[($1029)];
      var $1031=(($1030)&255);
      var $1032=$1031 << 8;
      var $1033=$sp;
      var $1034=(($1033+5)|0);
      var $1035=HEAPU8[($1034)];
      var $1036=(($1035)&255);
      var $1037=((($1032)+($1036))|0);
      var $1038=(($1037) & 65535);
      $b8=$1038;
      var $1039=$r6;
      var $1040=(($1039)&65535);
      var $1041=$3;
      var $1042=(($1041+2)|0);
      var $1043=HEAPU16[(($1042)>>1)];
      var $1044=(($1043)&65535);
      var $1045=(($1040)|0)==(($1044)|0);
      if ($1045) { __label__ = 136; break; } else { __label__ = 139; break; }
    case 136: 
      var $1047=$g7;
      var $1048=(($1047)&65535);
      var $1049=$3;
      var $1050=(($1049+4)|0);
      var $1051=HEAPU16[(($1050)>>1)];
      var $1052=(($1051)&65535);
      var $1053=(($1048)|0)==(($1052)|0);
      if ($1053) { __label__ = 137; break; } else { __label__ = 139; break; }
    case 137: 
      var $1055=$b8;
      var $1056=(($1055)&65535);
      var $1057=$3;
      var $1058=(($1057+6)|0);
      var $1059=HEAPU16[(($1058)>>1)];
      var $1060=(($1059)&65535);
      var $1061=(($1056)|0)==(($1060)|0);
      if ($1061) { __label__ = 138; break; } else { __label__ = 139; break; }
    case 138: 
      var $1063=$4;
      var $1064=(($1063+2)|0);
      var $1065=HEAPU16[(($1064)>>1)];
      var $1066=(($1065)&65535);
      var $1067=$1066 >> 8;
      var $1068=$1067 & 255;
      var $1069=(($1068) & 255);
      var $1070=$sp;
      HEAP8[($1070)]=$1069;
      var $1071=$4;
      var $1072=(($1071+2)|0);
      var $1073=HEAPU16[(($1072)>>1)];
      var $1074=(($1073)&65535);
      var $1075=$1074 & 255;
      var $1076=(($1075) & 255);
      var $1077=$sp;
      var $1078=(($1077+1)|0);
      HEAP8[($1078)]=$1076;
      var $1079=$4;
      var $1080=(($1079+4)|0);
      var $1081=HEAPU16[(($1080)>>1)];
      var $1082=(($1081)&65535);
      var $1083=$1082 >> 8;
      var $1084=$1083 & 255;
      var $1085=(($1084) & 255);
      var $1086=$sp;
      var $1087=(($1086+2)|0);
      HEAP8[($1087)]=$1085;
      var $1088=$4;
      var $1089=(($1088+4)|0);
      var $1090=HEAPU16[(($1089)>>1)];
      var $1091=(($1090)&65535);
      var $1092=$1091 & 255;
      var $1093=(($1092) & 255);
      var $1094=$sp;
      var $1095=(($1094+3)|0);
      HEAP8[($1095)]=$1093;
      var $1096=$4;
      var $1097=(($1096+6)|0);
      var $1098=HEAPU16[(($1097)>>1)];
      var $1099=(($1098)&65535);
      var $1100=$1099 >> 8;
      var $1101=$1100 & 255;
      var $1102=(($1101) & 255);
      var $1103=$sp;
      var $1104=(($1103+4)|0);
      HEAP8[($1104)]=$1102;
      var $1105=$4;
      var $1106=(($1105+6)|0);
      var $1107=HEAPU16[(($1106)>>1)];
      var $1108=(($1107)&65535);
      var $1109=$1108 & 255;
      var $1110=(($1109) & 255);
      var $1111=$sp;
      var $1112=(($1111+5)|0);
      HEAP8[($1112)]=$1110;
      __label__ = 139; break;
    case 139: 
      __label__ = 140; break;
    case 140: 
      var $1115=$i;
      var $1116=((($1115)+(1))|0);
      $i=$1116;
      var $1117=$sp;
      var $1118=(($1117+6)|0);
      $sp=$1118;
      __label__ = 134; break;
    case 141: 
      __label__ = 142; break;
    case 142: 
      __label__ = 143; break;
    case 143: 
      __label__ = 253; break;
    case 144: 
      var $1123=$1;
      var $1124=(($1123+9)|0);
      var $1125=HEAPU8[($1124)];
      var $1126=(($1125)&255);
      var $1127=(($1126)|0)==8;
      if ($1127) { __label__ = 145; break; } else { __label__ = 171; break; }
    case 145: 
      var $1129=$8;
      var $1130=(($1129)|0)!=0;
      if ($1130) { __label__ = 146; break; } else { __label__ = 159; break; }
    case 146: 
      var $1132=$7;
      var $1133=(($1132)|0)!=0;
      if ($1133) { __label__ = 147; break; } else { __label__ = 159; break; }
    case 147: 
      var $1135=$6;
      var $1136=(($1135)|0)!=0;
      if ($1136) { __label__ = 148; break; } else { __label__ = 159; break; }
    case 148: 
      var $1138=$2;
      $sp=$1138;
      var $1139=$2;
      $dp=$1139;
      $i=0;
      __label__ = 149; break;
    case 149: 
      var $1141=$i;
      var $1142=$row_width;
      var $1143=(($1141)>>>0) < (($1142)>>>0);
      if ($1143) { __label__ = 150; break; } else { __label__ = 158; break; }
    case 150: 
      var $1145=$sp;
      var $1146=(($1145+1)|0);
      var $1147=HEAPU8[($1146)];
      var $1148=(($1147)&255);
      $a=$1148;
      var $1149=$a;
      var $1150=(($1149)&65535);
      var $1151=(($1150)|0)==255;
      if ($1151) { __label__ = 151; break; } else { __label__ = 152; break; }
    case 151: 
      var $1153=$sp;
      var $1154=HEAPU8[($1153)];
      var $1155=(($1154)&255);
      var $1156=$6;
      var $1157=(($1156+$1155)|0);
      var $1158=HEAP8[($1157)];
      var $1159=$dp;
      HEAP8[($1159)]=$1158;
      __label__ = 156; break;
    case 152: 
      var $1161=$a;
      var $1162=(($1161)&65535);
      var $1163=(($1162)|0)==0;
      if ($1163) { __label__ = 153; break; } else { __label__ = 154; break; }
    case 153: 
      var $1165=$4;
      var $1166=(($1165+8)|0);
      var $1167=HEAP16[(($1166)>>1)];
      var $1168=(($1167) & 255);
      var $1169=$dp;
      HEAP8[($1169)]=$1168;
      __label__ = 155; break;
    case 154: 
      var $1171=$sp;
      var $1172=HEAPU8[($1171)];
      var $1173=(($1172)&255);
      var $1174=$8;
      var $1175=(($1174+$1173)|0);
      var $1176=HEAP8[($1175)];
      $v9=$1176;
      var $1177=$v9;
      var $1178=(($1177)&255);
      var $1179=(($1178)&65535);
      var $1180=$a;
      var $1181=(($1180)&65535);
      var $1182=((($1179)*($1181))|0);
      var $1183=$5;
      var $1184=(($1183+8)|0);
      var $1185=HEAPU16[(($1184)>>1)];
      var $1186=(($1185)&65535);
      var $1187=$a;
      var $1188=(($1187)&65535);
      var $1189=(((255)-($1188))|0);
      var $1190=(($1189) & 65535);
      var $1191=(($1190)&65535);
      var $1192=((($1186)*($1191))|0);
      var $1193=((($1182)+($1192))|0);
      var $1194=((($1193)+(128))|0);
      var $1195=(($1194) & 65535);
      $temp=$1195;
      var $1196=$temp;
      var $1197=(($1196)&65535);
      var $1198=$temp;
      var $1199=(($1198)&65535);
      var $1200=$1199 >> 8;
      var $1201=((($1197)+($1200))|0);
      var $1202=$1201 >> 8;
      var $1203=(($1202) & 255);
      $w=$1203;
      var $1204=$w;
      var $1205=(($1204)&255);
      var $1206=$7;
      var $1207=(($1206+$1205)|0);
      var $1208=HEAP8[($1207)];
      var $1209=$dp;
      HEAP8[($1209)]=$1208;
      __label__ = 155; break;
    case 155: 
      __label__ = 156; break;
    case 156: 
      __label__ = 157; break;
    case 157: 
      var $1213=$i;
      var $1214=((($1213)+(1))|0);
      $i=$1214;
      var $1215=$sp;
      var $1216=(($1215+2)|0);
      $sp=$1216;
      var $1217=$dp;
      var $1218=(($1217+1)|0);
      $dp=$1218;
      __label__ = 149; break;
    case 158: 
      __label__ = 170; break;
    case 159: 
      var $1221=$2;
      $sp=$1221;
      var $1222=$2;
      $dp=$1222;
      $i=0;
      __label__ = 160; break;
    case 160: 
      var $1224=$i;
      var $1225=$row_width;
      var $1226=(($1224)>>>0) < (($1225)>>>0);
      if ($1226) { __label__ = 161; break; } else { __label__ = 169; break; }
    case 161: 
      var $1228=$sp;
      var $1229=(($1228+1)|0);
      var $1230=HEAP8[($1229)];
      $a10=$1230;
      var $1231=$a10;
      var $1232=(($1231)&255);
      var $1233=(($1232)|0)==255;
      if ($1233) { __label__ = 162; break; } else { __label__ = 163; break; }
    case 162: 
      var $1235=$sp;
      var $1236=HEAP8[($1235)];
      var $1237=$dp;
      HEAP8[($1237)]=$1236;
      __label__ = 167; break;
    case 163: 
      var $1239=$a10;
      var $1240=(($1239)&255);
      var $1241=(($1240)|0)==0;
      if ($1241) { __label__ = 164; break; } else { __label__ = 165; break; }
    case 164: 
      var $1243=$4;
      var $1244=(($1243+8)|0);
      var $1245=HEAP16[(($1244)>>1)];
      var $1246=(($1245) & 255);
      var $1247=$dp;
      HEAP8[($1247)]=$1246;
      __label__ = 166; break;
    case 165: 
      var $1249=$sp;
      var $1250=HEAPU8[($1249)];
      var $1251=(($1250)&255);
      var $1252=(($1251)&65535);
      var $1253=$a10;
      var $1254=(($1253)&255);
      var $1255=(($1254)&65535);
      var $1256=((($1252)*($1255))|0);
      var $1257=$5;
      var $1258=(($1257+8)|0);
      var $1259=HEAPU16[(($1258)>>1)];
      var $1260=(($1259)&65535);
      var $1261=$a10;
      var $1262=(($1261)&255);
      var $1263=(($1262)&65535);
      var $1264=(((255)-($1263))|0);
      var $1265=(($1264) & 65535);
      var $1266=(($1265)&65535);
      var $1267=((($1260)*($1266))|0);
      var $1268=((($1256)+($1267))|0);
      var $1269=((($1268)+(128))|0);
      var $1270=(($1269) & 65535);
      $temp11=$1270;
      var $1271=$temp11;
      var $1272=(($1271)&65535);
      var $1273=$temp11;
      var $1274=(($1273)&65535);
      var $1275=$1274 >> 8;
      var $1276=((($1272)+($1275))|0);
      var $1277=$1276 >> 8;
      var $1278=(($1277) & 255);
      var $1279=$dp;
      HEAP8[($1279)]=$1278;
      __label__ = 166; break;
    case 166: 
      __label__ = 167; break;
    case 167: 
      __label__ = 168; break;
    case 168: 
      var $1283=$i;
      var $1284=((($1283)+(1))|0);
      $i=$1284;
      var $1285=$sp;
      var $1286=(($1285+2)|0);
      $sp=$1286;
      var $1287=$dp;
      var $1288=(($1287+1)|0);
      $dp=$1288;
      __label__ = 160; break;
    case 169: 
      __label__ = 170; break;
    case 170: 
      __label__ = 197; break;
    case 171: 
      var $1292=$9;
      var $1293=(($1292)|0)!=0;
      if ($1293) { __label__ = 172; break; } else { __label__ = 185; break; }
    case 172: 
      var $1295=$10;
      var $1296=(($1295)|0)!=0;
      if ($1296) { __label__ = 173; break; } else { __label__ = 185; break; }
    case 173: 
      var $1298=$11;
      var $1299=(($1298)|0)!=0;
      if ($1299) { __label__ = 174; break; } else { __label__ = 185; break; }
    case 174: 
      var $1301=$2;
      $sp=$1301;
      var $1302=$2;
      $dp=$1302;
      $i=0;
      __label__ = 175; break;
    case 175: 
      var $1304=$i;
      var $1305=$row_width;
      var $1306=(($1304)>>>0) < (($1305)>>>0);
      if ($1306) { __label__ = 176; break; } else { __label__ = 184; break; }
    case 176: 
      var $1308=$sp;
      var $1309=(($1308+2)|0);
      var $1310=HEAPU8[($1309)];
      var $1311=(($1310)&255);
      var $1312=$1311 << 8;
      var $1313=$sp;
      var $1314=(($1313+3)|0);
      var $1315=HEAPU8[($1314)];
      var $1316=(($1315)&255);
      var $1317=((($1312)+($1316))|0);
      var $1318=(($1317) & 65535);
      $a12=$1318;
      var $1319=$a12;
      var $1320=(($1319)&65535);
      var $1321=(($1320)|0)==65535;
      if ($1321) { __label__ = 177; break; } else { __label__ = 178; break; }
    case 177: 
      var $1323=$sp;
      var $1324=HEAPU8[($1323)];
      var $1325=(($1324)&255);
      var $1326=$sp;
      var $1327=(($1326+1)|0);
      var $1328=HEAPU8[($1327)];
      var $1329=(($1328)&255);
      var $1330=$12;
      var $1331=$1329 >> (($1330)|0);
      var $1332=$9;
      var $1333=(($1332+($1331<<2))|0);
      var $1334=HEAP32[(($1333)>>2)];
      var $1335=(($1334+($1325<<1))|0);
      var $1336=HEAP16[(($1335)>>1)];
      $v13=$1336;
      var $1337=$v13;
      var $1338=(($1337)&65535);
      var $1339=$1338 >> 8;
      var $1340=$1339 & 255;
      var $1341=(($1340) & 255);
      var $1342=$dp;
      HEAP8[($1342)]=$1341;
      var $1343=$v13;
      var $1344=(($1343)&65535);
      var $1345=$1344 & 255;
      var $1346=(($1345) & 255);
      var $1347=$dp;
      var $1348=(($1347+1)|0);
      HEAP8[($1348)]=$1346;
      __label__ = 182; break;
    case 178: 
      var $1350=$a12;
      var $1351=(($1350)&65535);
      var $1352=(($1351)|0)==0;
      if ($1352) { __label__ = 179; break; } else { __label__ = 180; break; }
    case 179: 
      var $1354=$4;
      var $1355=(($1354+8)|0);
      var $1356=HEAPU16[(($1355)>>1)];
      var $1357=(($1356)&65535);
      var $1358=$1357 >> 8;
      var $1359=$1358 & 255;
      var $1360=(($1359) & 255);
      var $1361=$dp;
      HEAP8[($1361)]=$1360;
      var $1362=$4;
      var $1363=(($1362+8)|0);
      var $1364=HEAPU16[(($1363)>>1)];
      var $1365=(($1364)&65535);
      var $1366=$1365 & 255;
      var $1367=(($1366) & 255);
      var $1368=$dp;
      var $1369=(($1368+1)|0);
      HEAP8[($1369)]=$1367;
      __label__ = 181; break;
    case 180: 
      var $1371=$sp;
      var $1372=HEAPU8[($1371)];
      var $1373=(($1372)&255);
      var $1374=$sp;
      var $1375=(($1374+1)|0);
      var $1376=HEAPU8[($1375)];
      var $1377=(($1376)&255);
      var $1378=$12;
      var $1379=$1377 >> (($1378)|0);
      var $1380=$11;
      var $1381=(($1380+($1379<<2))|0);
      var $1382=HEAP32[(($1381)>>2)];
      var $1383=(($1382+($1373<<1))|0);
      var $1384=HEAP16[(($1383)>>1)];
      $g14=$1384;
      var $1385=$g14;
      var $1386=(($1385)&65535);
      var $1387=$a12;
      var $1388=(($1387)&65535);
      var $1389=((($1386)*($1388))|0);
      var $1390=$5;
      var $1391=(($1390+8)|0);
      var $1392=HEAPU16[(($1391)>>1)];
      var $1393=(($1392)&65535);
      var $1394=$a12;
      var $1395=(($1394)&65535);
      var $1396=(((65535)-($1395))|0);
      var $1397=((($1393)*($1396))|0);
      var $1398=((($1389)+($1397))|0);
      var $1399=((($1398)+(32768))|0);
      $temp17=$1399;
      var $1400=$temp17;
      var $1401=$temp17;
      var $1402=$1401 >>> 16;
      var $1403=((($1400)+($1402))|0);
      var $1404=$1403 >>> 16;
      var $1405=(($1404) & 65535);
      $v15=$1405;
      var $1406=$v15;
      var $1407=(($1406)&65535);
      var $1408=$1407 >> 8;
      var $1409=$v15;
      var $1410=(($1409)&65535);
      var $1411=$1410 & 255;
      var $1412=$12;
      var $1413=$1411 >> (($1412)|0);
      var $1414=$10;
      var $1415=(($1414+($1413<<2))|0);
      var $1416=HEAP32[(($1415)>>2)];
      var $1417=(($1416+($1408<<1))|0);
      var $1418=HEAP16[(($1417)>>1)];
      $w16=$1418;
      var $1419=$w16;
      var $1420=(($1419)&65535);
      var $1421=$1420 >> 8;
      var $1422=$1421 & 255;
      var $1423=(($1422) & 255);
      var $1424=$dp;
      HEAP8[($1424)]=$1423;
      var $1425=$w16;
      var $1426=(($1425)&65535);
      var $1427=$1426 & 255;
      var $1428=(($1427) & 255);
      var $1429=$dp;
      var $1430=(($1429+1)|0);
      HEAP8[($1430)]=$1428;
      __label__ = 181; break;
    case 181: 
      __label__ = 182; break;
    case 182: 
      __label__ = 183; break;
    case 183: 
      var $1434=$i;
      var $1435=((($1434)+(1))|0);
      $i=$1435;
      var $1436=$sp;
      var $1437=(($1436+4)|0);
      $sp=$1437;
      var $1438=$dp;
      var $1439=(($1438+2)|0);
      $dp=$1439;
      __label__ = 175; break;
    case 184: 
      __label__ = 196; break;
    case 185: 
      var $1442=$2;
      $sp=$1442;
      var $1443=$2;
      $dp=$1443;
      $i=0;
      __label__ = 186; break;
    case 186: 
      var $1445=$i;
      var $1446=$row_width;
      var $1447=(($1445)>>>0) < (($1446)>>>0);
      if ($1447) { __label__ = 187; break; } else { __label__ = 195; break; }
    case 187: 
      var $1449=$sp;
      var $1450=(($1449+2)|0);
      var $1451=HEAPU8[($1450)];
      var $1452=(($1451)&255);
      var $1453=$1452 << 8;
      var $1454=$sp;
      var $1455=(($1454+3)|0);
      var $1456=HEAPU8[($1455)];
      var $1457=(($1456)&255);
      var $1458=((($1453)+($1457))|0);
      var $1459=(($1458) & 65535);
      $a18=$1459;
      var $1460=$a18;
      var $1461=(($1460)&65535);
      var $1462=(($1461)|0)==65535;
      if ($1462) { __label__ = 188; break; } else { __label__ = 189; break; }
    case 188: 
      var $1464=$dp;
      var $1465=$sp;
      assert(2 % 1 === 0, 'memcpy given ' + 2 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP8[($1464)]=HEAP8[($1465)];HEAP8[(($1464)+(1))]=HEAP8[(($1465)+(1))];
      __label__ = 193; break;
    case 189: 
      var $1467=$a18;
      var $1468=(($1467)&65535);
      var $1469=(($1468)|0)==0;
      if ($1469) { __label__ = 190; break; } else { __label__ = 191; break; }
    case 190: 
      var $1471=$4;
      var $1472=(($1471+8)|0);
      var $1473=HEAPU16[(($1472)>>1)];
      var $1474=(($1473)&65535);
      var $1475=$1474 >> 8;
      var $1476=$1475 & 255;
      var $1477=(($1476) & 255);
      var $1478=$dp;
      HEAP8[($1478)]=$1477;
      var $1479=$4;
      var $1480=(($1479+8)|0);
      var $1481=HEAPU16[(($1480)>>1)];
      var $1482=(($1481)&65535);
      var $1483=$1482 & 255;
      var $1484=(($1483) & 255);
      var $1485=$dp;
      var $1486=(($1485+1)|0);
      HEAP8[($1486)]=$1484;
      __label__ = 192; break;
    case 191: 
      var $1488=$sp;
      var $1489=HEAPU8[($1488)];
      var $1490=(($1489)&255);
      var $1491=$1490 << 8;
      var $1492=$sp;
      var $1493=(($1492+1)|0);
      var $1494=HEAPU8[($1493)];
      var $1495=(($1494)&255);
      var $1496=((($1491)+($1495))|0);
      var $1497=(($1496) & 65535);
      $g19=$1497;
      var $1498=$g19;
      var $1499=(($1498)&65535);
      var $1500=$a18;
      var $1501=(($1500)&65535);
      var $1502=((($1499)*($1501))|0);
      var $1503=$5;
      var $1504=(($1503+8)|0);
      var $1505=HEAPU16[(($1504)>>1)];
      var $1506=(($1505)&65535);
      var $1507=$a18;
      var $1508=(($1507)&65535);
      var $1509=(((65535)-($1508))|0);
      var $1510=((($1506)*($1509))|0);
      var $1511=((($1502)+($1510))|0);
      var $1512=((($1511)+(32768))|0);
      $temp21=$1512;
      var $1513=$temp21;
      var $1514=$temp21;
      var $1515=$1514 >>> 16;
      var $1516=((($1513)+($1515))|0);
      var $1517=$1516 >>> 16;
      var $1518=(($1517) & 65535);
      $v20=$1518;
      var $1519=$v20;
      var $1520=(($1519)&65535);
      var $1521=$1520 >> 8;
      var $1522=$1521 & 255;
      var $1523=(($1522) & 255);
      var $1524=$dp;
      HEAP8[($1524)]=$1523;
      var $1525=$v20;
      var $1526=(($1525)&65535);
      var $1527=$1526 & 255;
      var $1528=(($1527) & 255);
      var $1529=$dp;
      var $1530=(($1529+1)|0);
      HEAP8[($1530)]=$1528;
      __label__ = 192; break;
    case 192: 
      __label__ = 193; break;
    case 193: 
      __label__ = 194; break;
    case 194: 
      var $1534=$i;
      var $1535=((($1534)+(1))|0);
      $i=$1535;
      var $1536=$sp;
      var $1537=(($1536+4)|0);
      $sp=$1537;
      var $1538=$dp;
      var $1539=(($1538+2)|0);
      $dp=$1539;
      __label__ = 186; break;
    case 195: 
      __label__ = 196; break;
    case 196: 
      __label__ = 197; break;
    case 197: 
      __label__ = 253; break;
    case 198: 
      var $1544=$1;
      var $1545=(($1544+9)|0);
      var $1546=HEAPU8[($1545)];
      var $1547=(($1546)&255);
      var $1548=(($1547)|0)==8;
      if ($1548) { __label__ = 199; break; } else { __label__ = 225; break; }
    case 199: 
      var $1550=$8;
      var $1551=(($1550)|0)!=0;
      if ($1551) { __label__ = 200; break; } else { __label__ = 213; break; }
    case 200: 
      var $1553=$7;
      var $1554=(($1553)|0)!=0;
      if ($1554) { __label__ = 201; break; } else { __label__ = 213; break; }
    case 201: 
      var $1556=$6;
      var $1557=(($1556)|0)!=0;
      if ($1557) { __label__ = 202; break; } else { __label__ = 213; break; }
    case 202: 
      var $1559=$2;
      $sp=$1559;
      var $1560=$2;
      $dp=$1560;
      $i=0;
      __label__ = 203; break;
    case 203: 
      var $1562=$i;
      var $1563=$row_width;
      var $1564=(($1562)>>>0) < (($1563)>>>0);
      if ($1564) { __label__ = 204; break; } else { __label__ = 212; break; }
    case 204: 
      var $1566=$sp;
      var $1567=(($1566+3)|0);
      var $1568=HEAP8[($1567)];
      $a22=$1568;
      var $1569=$a22;
      var $1570=(($1569)&255);
      var $1571=(($1570)|0)==255;
      if ($1571) { __label__ = 205; break; } else { __label__ = 206; break; }
    case 205: 
      var $1573=$sp;
      var $1574=HEAPU8[($1573)];
      var $1575=(($1574)&255);
      var $1576=$6;
      var $1577=(($1576+$1575)|0);
      var $1578=HEAP8[($1577)];
      var $1579=$dp;
      HEAP8[($1579)]=$1578;
      var $1580=$sp;
      var $1581=(($1580+1)|0);
      var $1582=HEAPU8[($1581)];
      var $1583=(($1582)&255);
      var $1584=$6;
      var $1585=(($1584+$1583)|0);
      var $1586=HEAP8[($1585)];
      var $1587=$dp;
      var $1588=(($1587+1)|0);
      HEAP8[($1588)]=$1586;
      var $1589=$sp;
      var $1590=(($1589+2)|0);
      var $1591=HEAPU8[($1590)];
      var $1592=(($1591)&255);
      var $1593=$6;
      var $1594=(($1593+$1592)|0);
      var $1595=HEAP8[($1594)];
      var $1596=$dp;
      var $1597=(($1596+2)|0);
      HEAP8[($1597)]=$1595;
      __label__ = 210; break;
    case 206: 
      var $1599=$a22;
      var $1600=(($1599)&255);
      var $1601=(($1600)|0)==0;
      if ($1601) { __label__ = 207; break; } else { __label__ = 208; break; }
    case 207: 
      var $1603=$4;
      var $1604=(($1603+2)|0);
      var $1605=HEAP16[(($1604)>>1)];
      var $1606=(($1605) & 255);
      var $1607=$dp;
      HEAP8[($1607)]=$1606;
      var $1608=$4;
      var $1609=(($1608+4)|0);
      var $1610=HEAP16[(($1609)>>1)];
      var $1611=(($1610) & 255);
      var $1612=$dp;
      var $1613=(($1612+1)|0);
      HEAP8[($1613)]=$1611;
      var $1614=$4;
      var $1615=(($1614+6)|0);
      var $1616=HEAP16[(($1615)>>1)];
      var $1617=(($1616) & 255);
      var $1618=$dp;
      var $1619=(($1618+2)|0);
      HEAP8[($1619)]=$1617;
      __label__ = 209; break;
    case 208: 
      var $1621=$sp;
      var $1622=HEAPU8[($1621)];
      var $1623=(($1622)&255);
      var $1624=$8;
      var $1625=(($1624+$1623)|0);
      var $1626=HEAP8[($1625)];
      $v23=$1626;
      var $1627=$v23;
      var $1628=(($1627)&255);
      var $1629=(($1628)&65535);
      var $1630=$a22;
      var $1631=(($1630)&255);
      var $1632=(($1631)&65535);
      var $1633=((($1629)*($1632))|0);
      var $1634=$5;
      var $1635=(($1634+2)|0);
      var $1636=HEAPU16[(($1635)>>1)];
      var $1637=(($1636)&65535);
      var $1638=$a22;
      var $1639=(($1638)&255);
      var $1640=(($1639)&65535);
      var $1641=(((255)-($1640))|0);
      var $1642=(($1641) & 65535);
      var $1643=(($1642)&65535);
      var $1644=((($1637)*($1643))|0);
      var $1645=((($1633)+($1644))|0);
      var $1646=((($1645)+(128))|0);
      var $1647=(($1646) & 65535);
      $temp25=$1647;
      var $1648=$temp25;
      var $1649=(($1648)&65535);
      var $1650=$temp25;
      var $1651=(($1650)&65535);
      var $1652=$1651 >> 8;
      var $1653=((($1649)+($1652))|0);
      var $1654=$1653 >> 8;
      var $1655=(($1654) & 255);
      $w24=$1655;
      var $1656=$w24;
      var $1657=(($1656)&255);
      var $1658=$7;
      var $1659=(($1658+$1657)|0);
      var $1660=HEAP8[($1659)];
      var $1661=$dp;
      HEAP8[($1661)]=$1660;
      var $1662=$sp;
      var $1663=(($1662+1)|0);
      var $1664=HEAPU8[($1663)];
      var $1665=(($1664)&255);
      var $1666=$8;
      var $1667=(($1666+$1665)|0);
      var $1668=HEAP8[($1667)];
      $v23=$1668;
      var $1669=$v23;
      var $1670=(($1669)&255);
      var $1671=(($1670)&65535);
      var $1672=$a22;
      var $1673=(($1672)&255);
      var $1674=(($1673)&65535);
      var $1675=((($1671)*($1674))|0);
      var $1676=$5;
      var $1677=(($1676+4)|0);
      var $1678=HEAPU16[(($1677)>>1)];
      var $1679=(($1678)&65535);
      var $1680=$a22;
      var $1681=(($1680)&255);
      var $1682=(($1681)&65535);
      var $1683=(((255)-($1682))|0);
      var $1684=(($1683) & 65535);
      var $1685=(($1684)&65535);
      var $1686=((($1679)*($1685))|0);
      var $1687=((($1675)+($1686))|0);
      var $1688=((($1687)+(128))|0);
      var $1689=(($1688) & 65535);
      $temp26=$1689;
      var $1690=$temp26;
      var $1691=(($1690)&65535);
      var $1692=$temp26;
      var $1693=(($1692)&65535);
      var $1694=$1693 >> 8;
      var $1695=((($1691)+($1694))|0);
      var $1696=$1695 >> 8;
      var $1697=(($1696) & 255);
      $w24=$1697;
      var $1698=$w24;
      var $1699=(($1698)&255);
      var $1700=$7;
      var $1701=(($1700+$1699)|0);
      var $1702=HEAP8[($1701)];
      var $1703=$dp;
      var $1704=(($1703+1)|0);
      HEAP8[($1704)]=$1702;
      var $1705=$sp;
      var $1706=(($1705+2)|0);
      var $1707=HEAPU8[($1706)];
      var $1708=(($1707)&255);
      var $1709=$8;
      var $1710=(($1709+$1708)|0);
      var $1711=HEAP8[($1710)];
      $v23=$1711;
      var $1712=$v23;
      var $1713=(($1712)&255);
      var $1714=(($1713)&65535);
      var $1715=$a22;
      var $1716=(($1715)&255);
      var $1717=(($1716)&65535);
      var $1718=((($1714)*($1717))|0);
      var $1719=$5;
      var $1720=(($1719+6)|0);
      var $1721=HEAPU16[(($1720)>>1)];
      var $1722=(($1721)&65535);
      var $1723=$a22;
      var $1724=(($1723)&255);
      var $1725=(($1724)&65535);
      var $1726=(((255)-($1725))|0);
      var $1727=(($1726) & 65535);
      var $1728=(($1727)&65535);
      var $1729=((($1722)*($1728))|0);
      var $1730=((($1718)+($1729))|0);
      var $1731=((($1730)+(128))|0);
      var $1732=(($1731) & 65535);
      $temp27=$1732;
      var $1733=$temp27;
      var $1734=(($1733)&65535);
      var $1735=$temp27;
      var $1736=(($1735)&65535);
      var $1737=$1736 >> 8;
      var $1738=((($1734)+($1737))|0);
      var $1739=$1738 >> 8;
      var $1740=(($1739) & 255);
      $w24=$1740;
      var $1741=$w24;
      var $1742=(($1741)&255);
      var $1743=$7;
      var $1744=(($1743+$1742)|0);
      var $1745=HEAP8[($1744)];
      var $1746=$dp;
      var $1747=(($1746+2)|0);
      HEAP8[($1747)]=$1745;
      __label__ = 209; break;
    case 209: 
      __label__ = 210; break;
    case 210: 
      __label__ = 211; break;
    case 211: 
      var $1751=$i;
      var $1752=((($1751)+(1))|0);
      $i=$1752;
      var $1753=$sp;
      var $1754=(($1753+4)|0);
      $sp=$1754;
      var $1755=$dp;
      var $1756=(($1755+3)|0);
      $dp=$1756;
      __label__ = 203; break;
    case 212: 
      __label__ = 224; break;
    case 213: 
      var $1759=$2;
      $sp=$1759;
      var $1760=$2;
      $dp=$1760;
      $i=0;
      __label__ = 214; break;
    case 214: 
      var $1762=$i;
      var $1763=$row_width;
      var $1764=(($1762)>>>0) < (($1763)>>>0);
      if ($1764) { __label__ = 215; break; } else { __label__ = 223; break; }
    case 215: 
      var $1766=$sp;
      var $1767=(($1766+3)|0);
      var $1768=HEAP8[($1767)];
      $a28=$1768;
      var $1769=$a28;
      var $1770=(($1769)&255);
      var $1771=(($1770)|0)==255;
      if ($1771) { __label__ = 216; break; } else { __label__ = 217; break; }
    case 216: 
      var $1773=$sp;
      var $1774=HEAP8[($1773)];
      var $1775=$dp;
      HEAP8[($1775)]=$1774;
      var $1776=$sp;
      var $1777=(($1776+1)|0);
      var $1778=HEAP8[($1777)];
      var $1779=$dp;
      var $1780=(($1779+1)|0);
      HEAP8[($1780)]=$1778;
      var $1781=$sp;
      var $1782=(($1781+2)|0);
      var $1783=HEAP8[($1782)];
      var $1784=$dp;
      var $1785=(($1784+2)|0);
      HEAP8[($1785)]=$1783;
      __label__ = 221; break;
    case 217: 
      var $1787=$a28;
      var $1788=(($1787)&255);
      var $1789=(($1788)|0)==0;
      if ($1789) { __label__ = 218; break; } else { __label__ = 219; break; }
    case 218: 
      var $1791=$4;
      var $1792=(($1791+2)|0);
      var $1793=HEAP16[(($1792)>>1)];
      var $1794=(($1793) & 255);
      var $1795=$dp;
      HEAP8[($1795)]=$1794;
      var $1796=$4;
      var $1797=(($1796+4)|0);
      var $1798=HEAP16[(($1797)>>1)];
      var $1799=(($1798) & 255);
      var $1800=$dp;
      var $1801=(($1800+1)|0);
      HEAP8[($1801)]=$1799;
      var $1802=$4;
      var $1803=(($1802+6)|0);
      var $1804=HEAP16[(($1803)>>1)];
      var $1805=(($1804) & 255);
      var $1806=$dp;
      var $1807=(($1806+2)|0);
      HEAP8[($1807)]=$1805;
      __label__ = 220; break;
    case 219: 
      var $1809=$sp;
      var $1810=HEAPU8[($1809)];
      var $1811=(($1810)&255);
      var $1812=(($1811)&65535);
      var $1813=$a28;
      var $1814=(($1813)&255);
      var $1815=(($1814)&65535);
      var $1816=((($1812)*($1815))|0);
      var $1817=$4;
      var $1818=(($1817+2)|0);
      var $1819=HEAPU16[(($1818)>>1)];
      var $1820=(($1819)&65535);
      var $1821=$a28;
      var $1822=(($1821)&255);
      var $1823=(($1822)&65535);
      var $1824=(((255)-($1823))|0);
      var $1825=(($1824) & 65535);
      var $1826=(($1825)&65535);
      var $1827=((($1820)*($1826))|0);
      var $1828=((($1816)+($1827))|0);
      var $1829=((($1828)+(128))|0);
      var $1830=(($1829) & 65535);
      $temp29=$1830;
      var $1831=$temp29;
      var $1832=(($1831)&65535);
      var $1833=$temp29;
      var $1834=(($1833)&65535);
      var $1835=$1834 >> 8;
      var $1836=((($1832)+($1835))|0);
      var $1837=$1836 >> 8;
      var $1838=(($1837) & 255);
      var $1839=$dp;
      HEAP8[($1839)]=$1838;
      var $1840=$sp;
      var $1841=(($1840+1)|0);
      var $1842=HEAPU8[($1841)];
      var $1843=(($1842)&255);
      var $1844=(($1843)&65535);
      var $1845=$a28;
      var $1846=(($1845)&255);
      var $1847=(($1846)&65535);
      var $1848=((($1844)*($1847))|0);
      var $1849=$4;
      var $1850=(($1849+4)|0);
      var $1851=HEAPU16[(($1850)>>1)];
      var $1852=(($1851)&65535);
      var $1853=$a28;
      var $1854=(($1853)&255);
      var $1855=(($1854)&65535);
      var $1856=(((255)-($1855))|0);
      var $1857=(($1856) & 65535);
      var $1858=(($1857)&65535);
      var $1859=((($1852)*($1858))|0);
      var $1860=((($1848)+($1859))|0);
      var $1861=((($1860)+(128))|0);
      var $1862=(($1861) & 65535);
      $temp30=$1862;
      var $1863=$temp30;
      var $1864=(($1863)&65535);
      var $1865=$temp30;
      var $1866=(($1865)&65535);
      var $1867=$1866 >> 8;
      var $1868=((($1864)+($1867))|0);
      var $1869=$1868 >> 8;
      var $1870=(($1869) & 255);
      var $1871=$dp;
      var $1872=(($1871+1)|0);
      HEAP8[($1872)]=$1870;
      var $1873=$sp;
      var $1874=(($1873+2)|0);
      var $1875=HEAPU8[($1874)];
      var $1876=(($1875)&255);
      var $1877=(($1876)&65535);
      var $1878=$a28;
      var $1879=(($1878)&255);
      var $1880=(($1879)&65535);
      var $1881=((($1877)*($1880))|0);
      var $1882=$4;
      var $1883=(($1882+6)|0);
      var $1884=HEAPU16[(($1883)>>1)];
      var $1885=(($1884)&65535);
      var $1886=$a28;
      var $1887=(($1886)&255);
      var $1888=(($1887)&65535);
      var $1889=(((255)-($1888))|0);
      var $1890=(($1889) & 65535);
      var $1891=(($1890)&65535);
      var $1892=((($1885)*($1891))|0);
      var $1893=((($1881)+($1892))|0);
      var $1894=((($1893)+(128))|0);
      var $1895=(($1894) & 65535);
      $temp31=$1895;
      var $1896=$temp31;
      var $1897=(($1896)&65535);
      var $1898=$temp31;
      var $1899=(($1898)&65535);
      var $1900=$1899 >> 8;
      var $1901=((($1897)+($1900))|0);
      var $1902=$1901 >> 8;
      var $1903=(($1902) & 255);
      var $1904=$dp;
      var $1905=(($1904+2)|0);
      HEAP8[($1905)]=$1903;
      __label__ = 220; break;
    case 220: 
      __label__ = 221; break;
    case 221: 
      __label__ = 222; break;
    case 222: 
      var $1909=$i;
      var $1910=((($1909)+(1))|0);
      $i=$1910;
      var $1911=$sp;
      var $1912=(($1911+4)|0);
      $sp=$1912;
      var $1913=$dp;
      var $1914=(($1913+3)|0);
      $dp=$1914;
      __label__ = 214; break;
    case 223: 
      __label__ = 224; break;
    case 224: 
      __label__ = 251; break;
    case 225: 
      var $1918=$9;
      var $1919=(($1918)|0)!=0;
      if ($1919) { __label__ = 226; break; } else { __label__ = 239; break; }
    case 226: 
      var $1921=$10;
      var $1922=(($1921)|0)!=0;
      if ($1922) { __label__ = 227; break; } else { __label__ = 239; break; }
    case 227: 
      var $1924=$11;
      var $1925=(($1924)|0)!=0;
      if ($1925) { __label__ = 228; break; } else { __label__ = 239; break; }
    case 228: 
      var $1927=$2;
      $sp=$1927;
      var $1928=$2;
      $dp=$1928;
      $i=0;
      __label__ = 229; break;
    case 229: 
      var $1930=$i;
      var $1931=$row_width;
      var $1932=(($1930)>>>0) < (($1931)>>>0);
      if ($1932) { __label__ = 230; break; } else { __label__ = 238; break; }
    case 230: 
      var $1934=$sp;
      var $1935=(($1934+6)|0);
      var $1936=HEAPU8[($1935)];
      var $1937=(($1936)&255);
      var $1938=(($1937)&65535);
      var $1939=$1938 << 8;
      var $1940=$sp;
      var $1941=(($1940+7)|0);
      var $1942=HEAPU8[($1941)];
      var $1943=(($1942)&255);
      var $1944=(($1943)&65535);
      var $1945=((($1939)+($1944))|0);
      var $1946=(($1945) & 65535);
      $a32=$1946;
      var $1947=$a32;
      var $1948=(($1947)&65535);
      var $1949=(($1948)|0)==65535;
      if ($1949) { __label__ = 231; break; } else { __label__ = 232; break; }
    case 231: 
      var $1951=$sp;
      var $1952=HEAPU8[($1951)];
      var $1953=(($1952)&255);
      var $1954=$sp;
      var $1955=(($1954+1)|0);
      var $1956=HEAPU8[($1955)];
      var $1957=(($1956)&255);
      var $1958=$12;
      var $1959=$1957 >> (($1958)|0);
      var $1960=$9;
      var $1961=(($1960+($1959<<2))|0);
      var $1962=HEAP32[(($1961)>>2)];
      var $1963=(($1962+($1953<<1))|0);
      var $1964=HEAP16[(($1963)>>1)];
      $v33=$1964;
      var $1965=$v33;
      var $1966=(($1965)&65535);
      var $1967=$1966 >> 8;
      var $1968=$1967 & 255;
      var $1969=(($1968) & 255);
      var $1970=$dp;
      HEAP8[($1970)]=$1969;
      var $1971=$v33;
      var $1972=(($1971)&65535);
      var $1973=$1972 & 255;
      var $1974=(($1973) & 255);
      var $1975=$dp;
      var $1976=(($1975+1)|0);
      HEAP8[($1976)]=$1974;
      var $1977=$sp;
      var $1978=(($1977+2)|0);
      var $1979=HEAPU8[($1978)];
      var $1980=(($1979)&255);
      var $1981=$sp;
      var $1982=(($1981+3)|0);
      var $1983=HEAPU8[($1982)];
      var $1984=(($1983)&255);
      var $1985=$12;
      var $1986=$1984 >> (($1985)|0);
      var $1987=$9;
      var $1988=(($1987+($1986<<2))|0);
      var $1989=HEAP32[(($1988)>>2)];
      var $1990=(($1989+($1980<<1))|0);
      var $1991=HEAP16[(($1990)>>1)];
      $v33=$1991;
      var $1992=$v33;
      var $1993=(($1992)&65535);
      var $1994=$1993 >> 8;
      var $1995=$1994 & 255;
      var $1996=(($1995) & 255);
      var $1997=$dp;
      var $1998=(($1997+2)|0);
      HEAP8[($1998)]=$1996;
      var $1999=$v33;
      var $2000=(($1999)&65535);
      var $2001=$2000 & 255;
      var $2002=(($2001) & 255);
      var $2003=$dp;
      var $2004=(($2003+3)|0);
      HEAP8[($2004)]=$2002;
      var $2005=$sp;
      var $2006=(($2005+4)|0);
      var $2007=HEAPU8[($2006)];
      var $2008=(($2007)&255);
      var $2009=$sp;
      var $2010=(($2009+5)|0);
      var $2011=HEAPU8[($2010)];
      var $2012=(($2011)&255);
      var $2013=$12;
      var $2014=$2012 >> (($2013)|0);
      var $2015=$9;
      var $2016=(($2015+($2014<<2))|0);
      var $2017=HEAP32[(($2016)>>2)];
      var $2018=(($2017+($2008<<1))|0);
      var $2019=HEAP16[(($2018)>>1)];
      $v33=$2019;
      var $2020=$v33;
      var $2021=(($2020)&65535);
      var $2022=$2021 >> 8;
      var $2023=$2022 & 255;
      var $2024=(($2023) & 255);
      var $2025=$dp;
      var $2026=(($2025+4)|0);
      HEAP8[($2026)]=$2024;
      var $2027=$v33;
      var $2028=(($2027)&65535);
      var $2029=$2028 & 255;
      var $2030=(($2029) & 255);
      var $2031=$dp;
      var $2032=(($2031+5)|0);
      HEAP8[($2032)]=$2030;
      __label__ = 236; break;
    case 232: 
      var $2034=$a32;
      var $2035=(($2034)&65535);
      var $2036=(($2035)|0)==0;
      if ($2036) { __label__ = 233; break; } else { __label__ = 234; break; }
    case 233: 
      var $2038=$4;
      var $2039=(($2038+2)|0);
      var $2040=HEAPU16[(($2039)>>1)];
      var $2041=(($2040)&65535);
      var $2042=$2041 >> 8;
      var $2043=$2042 & 255;
      var $2044=(($2043) & 255);
      var $2045=$dp;
      HEAP8[($2045)]=$2044;
      var $2046=$4;
      var $2047=(($2046+2)|0);
      var $2048=HEAPU16[(($2047)>>1)];
      var $2049=(($2048)&65535);
      var $2050=$2049 & 255;
      var $2051=(($2050) & 255);
      var $2052=$dp;
      var $2053=(($2052+1)|0);
      HEAP8[($2053)]=$2051;
      var $2054=$4;
      var $2055=(($2054+4)|0);
      var $2056=HEAPU16[(($2055)>>1)];
      var $2057=(($2056)&65535);
      var $2058=$2057 >> 8;
      var $2059=$2058 & 255;
      var $2060=(($2059) & 255);
      var $2061=$dp;
      var $2062=(($2061+2)|0);
      HEAP8[($2062)]=$2060;
      var $2063=$4;
      var $2064=(($2063+4)|0);
      var $2065=HEAPU16[(($2064)>>1)];
      var $2066=(($2065)&65535);
      var $2067=$2066 & 255;
      var $2068=(($2067) & 255);
      var $2069=$dp;
      var $2070=(($2069+3)|0);
      HEAP8[($2070)]=$2068;
      var $2071=$4;
      var $2072=(($2071+6)|0);
      var $2073=HEAPU16[(($2072)>>1)];
      var $2074=(($2073)&65535);
      var $2075=$2074 >> 8;
      var $2076=$2075 & 255;
      var $2077=(($2076) & 255);
      var $2078=$dp;
      var $2079=(($2078+4)|0);
      HEAP8[($2079)]=$2077;
      var $2080=$4;
      var $2081=(($2080+6)|0);
      var $2082=HEAPU16[(($2081)>>1)];
      var $2083=(($2082)&65535);
      var $2084=$2083 & 255;
      var $2085=(($2084) & 255);
      var $2086=$dp;
      var $2087=(($2086+5)|0);
      HEAP8[($2087)]=$2085;
      __label__ = 235; break;
    case 234: 
      var $2089=$sp;
      var $2090=HEAPU8[($2089)];
      var $2091=(($2090)&255);
      var $2092=$sp;
      var $2093=(($2092+1)|0);
      var $2094=HEAPU8[($2093)];
      var $2095=(($2094)&255);
      var $2096=$12;
      var $2097=$2095 >> (($2096)|0);
      var $2098=$11;
      var $2099=(($2098+($2097<<2))|0);
      var $2100=HEAP32[(($2099)>>2)];
      var $2101=(($2100+($2091<<1))|0);
      var $2102=HEAP16[(($2101)>>1)];
      $v34=$2102;
      var $2103=$v34;
      var $2104=(($2103)&65535);
      var $2105=$a32;
      var $2106=(($2105)&65535);
      var $2107=((($2104)*($2106))|0);
      var $2108=$5;
      var $2109=(($2108+2)|0);
      var $2110=HEAPU16[(($2109)>>1)];
      var $2111=(($2110)&65535);
      var $2112=$a32;
      var $2113=(($2112)&65535);
      var $2114=(((65535)-($2113))|0);
      var $2115=((($2111)*($2114))|0);
      var $2116=((($2107)+($2115))|0);
      var $2117=((($2116)+(32768))|0);
      $temp36=$2117;
      var $2118=$temp36;
      var $2119=$temp36;
      var $2120=$2119 >>> 16;
      var $2121=((($2118)+($2120))|0);
      var $2122=$2121 >>> 16;
      var $2123=(($2122) & 65535);
      $w35=$2123;
      var $2124=$w35;
      var $2125=(($2124)&65535);
      var $2126=$2125 >> 8;
      var $2127=$w35;
      var $2128=(($2127)&65535);
      var $2129=$2128 & 255;
      var $2130=$12;
      var $2131=$2129 >> (($2130)|0);
      var $2132=$10;
      var $2133=(($2132+($2131<<2))|0);
      var $2134=HEAP32[(($2133)>>2)];
      var $2135=(($2134+($2126<<1))|0);
      var $2136=HEAP16[(($2135)>>1)];
      $x=$2136;
      var $2137=$x;
      var $2138=(($2137)&65535);
      var $2139=$2138 >> 8;
      var $2140=$2139 & 255;
      var $2141=(($2140) & 255);
      var $2142=$dp;
      HEAP8[($2142)]=$2141;
      var $2143=$x;
      var $2144=(($2143)&65535);
      var $2145=$2144 & 255;
      var $2146=(($2145) & 255);
      var $2147=$dp;
      var $2148=(($2147+1)|0);
      HEAP8[($2148)]=$2146;
      var $2149=$sp;
      var $2150=(($2149+2)|0);
      var $2151=HEAPU8[($2150)];
      var $2152=(($2151)&255);
      var $2153=$sp;
      var $2154=(($2153+3)|0);
      var $2155=HEAPU8[($2154)];
      var $2156=(($2155)&255);
      var $2157=$12;
      var $2158=$2156 >> (($2157)|0);
      var $2159=$11;
      var $2160=(($2159+($2158<<2))|0);
      var $2161=HEAP32[(($2160)>>2)];
      var $2162=(($2161+($2152<<1))|0);
      var $2163=HEAP16[(($2162)>>1)];
      $v34=$2163;
      var $2164=$v34;
      var $2165=(($2164)&65535);
      var $2166=$a32;
      var $2167=(($2166)&65535);
      var $2168=((($2165)*($2167))|0);
      var $2169=$5;
      var $2170=(($2169+4)|0);
      var $2171=HEAPU16[(($2170)>>1)];
      var $2172=(($2171)&65535);
      var $2173=$a32;
      var $2174=(($2173)&65535);
      var $2175=(((65535)-($2174))|0);
      var $2176=((($2172)*($2175))|0);
      var $2177=((($2168)+($2176))|0);
      var $2178=((($2177)+(32768))|0);
      $temp37=$2178;
      var $2179=$temp37;
      var $2180=$temp37;
      var $2181=$2180 >>> 16;
      var $2182=((($2179)+($2181))|0);
      var $2183=$2182 >>> 16;
      var $2184=(($2183) & 65535);
      $w35=$2184;
      var $2185=$w35;
      var $2186=(($2185)&65535);
      var $2187=$2186 >> 8;
      var $2188=$w35;
      var $2189=(($2188)&65535);
      var $2190=$2189 & 255;
      var $2191=$12;
      var $2192=$2190 >> (($2191)|0);
      var $2193=$10;
      var $2194=(($2193+($2192<<2))|0);
      var $2195=HEAP32[(($2194)>>2)];
      var $2196=(($2195+($2187<<1))|0);
      var $2197=HEAP16[(($2196)>>1)];
      $x=$2197;
      var $2198=$x;
      var $2199=(($2198)&65535);
      var $2200=$2199 >> 8;
      var $2201=$2200 & 255;
      var $2202=(($2201) & 255);
      var $2203=$dp;
      var $2204=(($2203+2)|0);
      HEAP8[($2204)]=$2202;
      var $2205=$x;
      var $2206=(($2205)&65535);
      var $2207=$2206 & 255;
      var $2208=(($2207) & 255);
      var $2209=$dp;
      var $2210=(($2209+3)|0);
      HEAP8[($2210)]=$2208;
      var $2211=$sp;
      var $2212=(($2211+4)|0);
      var $2213=HEAPU8[($2212)];
      var $2214=(($2213)&255);
      var $2215=$sp;
      var $2216=(($2215+5)|0);
      var $2217=HEAPU8[($2216)];
      var $2218=(($2217)&255);
      var $2219=$12;
      var $2220=$2218 >> (($2219)|0);
      var $2221=$11;
      var $2222=(($2221+($2220<<2))|0);
      var $2223=HEAP32[(($2222)>>2)];
      var $2224=(($2223+($2214<<1))|0);
      var $2225=HEAP16[(($2224)>>1)];
      $v34=$2225;
      var $2226=$v34;
      var $2227=(($2226)&65535);
      var $2228=$a32;
      var $2229=(($2228)&65535);
      var $2230=((($2227)*($2229))|0);
      var $2231=$5;
      var $2232=(($2231+6)|0);
      var $2233=HEAPU16[(($2232)>>1)];
      var $2234=(($2233)&65535);
      var $2235=$a32;
      var $2236=(($2235)&65535);
      var $2237=(((65535)-($2236))|0);
      var $2238=((($2234)*($2237))|0);
      var $2239=((($2230)+($2238))|0);
      var $2240=((($2239)+(32768))|0);
      $temp38=$2240;
      var $2241=$temp38;
      var $2242=$temp38;
      var $2243=$2242 >>> 16;
      var $2244=((($2241)+($2243))|0);
      var $2245=$2244 >>> 16;
      var $2246=(($2245) & 65535);
      $w35=$2246;
      var $2247=$w35;
      var $2248=(($2247)&65535);
      var $2249=$2248 >> 8;
      var $2250=$w35;
      var $2251=(($2250)&65535);
      var $2252=$2251 & 255;
      var $2253=$12;
      var $2254=$2252 >> (($2253)|0);
      var $2255=$10;
      var $2256=(($2255+($2254<<2))|0);
      var $2257=HEAP32[(($2256)>>2)];
      var $2258=(($2257+($2249<<1))|0);
      var $2259=HEAP16[(($2258)>>1)];
      $x=$2259;
      var $2260=$x;
      var $2261=(($2260)&65535);
      var $2262=$2261 >> 8;
      var $2263=$2262 & 255;
      var $2264=(($2263) & 255);
      var $2265=$dp;
      var $2266=(($2265+4)|0);
      HEAP8[($2266)]=$2264;
      var $2267=$x;
      var $2268=(($2267)&65535);
      var $2269=$2268 & 255;
      var $2270=(($2269) & 255);
      var $2271=$dp;
      var $2272=(($2271+5)|0);
      HEAP8[($2272)]=$2270;
      __label__ = 235; break;
    case 235: 
      __label__ = 236; break;
    case 236: 
      __label__ = 237; break;
    case 237: 
      var $2276=$i;
      var $2277=((($2276)+(1))|0);
      $i=$2277;
      var $2278=$sp;
      var $2279=(($2278+8)|0);
      $sp=$2279;
      var $2280=$dp;
      var $2281=(($2280+6)|0);
      $dp=$2281;
      __label__ = 229; break;
    case 238: 
      __label__ = 250; break;
    case 239: 
      var $2284=$2;
      $sp=$2284;
      var $2285=$2;
      $dp=$2285;
      $i=0;
      __label__ = 240; break;
    case 240: 
      var $2287=$i;
      var $2288=$row_width;
      var $2289=(($2287)>>>0) < (($2288)>>>0);
      if ($2289) { __label__ = 241; break; } else { __label__ = 249; break; }
    case 241: 
      var $2291=$sp;
      var $2292=(($2291+6)|0);
      var $2293=HEAPU8[($2292)];
      var $2294=(($2293)&255);
      var $2295=(($2294)&65535);
      var $2296=$2295 << 8;
      var $2297=$sp;
      var $2298=(($2297+7)|0);
      var $2299=HEAPU8[($2298)];
      var $2300=(($2299)&255);
      var $2301=(($2300)&65535);
      var $2302=((($2296)+($2301))|0);
      var $2303=(($2302) & 65535);
      $a39=$2303;
      var $2304=$a39;
      var $2305=(($2304)&65535);
      var $2306=(($2305)|0)==65535;
      if ($2306) { __label__ = 242; break; } else { __label__ = 243; break; }
    case 242: 
      var $2308=$dp;
      var $2309=$sp;
      assert(6 % 1 === 0, 'memcpy given ' + 6 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP8[($2308)]=HEAP8[($2309)];HEAP8[(($2308)+(1))]=HEAP8[(($2309)+(1))];HEAP8[(($2308)+(2))]=HEAP8[(($2309)+(2))];HEAP8[(($2308)+(3))]=HEAP8[(($2309)+(3))];HEAP8[(($2308)+(4))]=HEAP8[(($2309)+(4))];HEAP8[(($2308)+(5))]=HEAP8[(($2309)+(5))];
      __label__ = 247; break;
    case 243: 
      var $2311=$a39;
      var $2312=(($2311)&65535);
      var $2313=(($2312)|0)==0;
      if ($2313) { __label__ = 244; break; } else { __label__ = 245; break; }
    case 244: 
      var $2315=$4;
      var $2316=(($2315+2)|0);
      var $2317=HEAPU16[(($2316)>>1)];
      var $2318=(($2317)&65535);
      var $2319=$2318 >> 8;
      var $2320=$2319 & 255;
      var $2321=(($2320) & 255);
      var $2322=$dp;
      HEAP8[($2322)]=$2321;
      var $2323=$4;
      var $2324=(($2323+2)|0);
      var $2325=HEAPU16[(($2324)>>1)];
      var $2326=(($2325)&65535);
      var $2327=$2326 & 255;
      var $2328=(($2327) & 255);
      var $2329=$dp;
      var $2330=(($2329+1)|0);
      HEAP8[($2330)]=$2328;
      var $2331=$4;
      var $2332=(($2331+4)|0);
      var $2333=HEAPU16[(($2332)>>1)];
      var $2334=(($2333)&65535);
      var $2335=$2334 >> 8;
      var $2336=$2335 & 255;
      var $2337=(($2336) & 255);
      var $2338=$dp;
      var $2339=(($2338+2)|0);
      HEAP8[($2339)]=$2337;
      var $2340=$4;
      var $2341=(($2340+4)|0);
      var $2342=HEAPU16[(($2341)>>1)];
      var $2343=(($2342)&65535);
      var $2344=$2343 & 255;
      var $2345=(($2344) & 255);
      var $2346=$dp;
      var $2347=(($2346+3)|0);
      HEAP8[($2347)]=$2345;
      var $2348=$4;
      var $2349=(($2348+6)|0);
      var $2350=HEAPU16[(($2349)>>1)];
      var $2351=(($2350)&65535);
      var $2352=$2351 >> 8;
      var $2353=$2352 & 255;
      var $2354=(($2353) & 255);
      var $2355=$dp;
      var $2356=(($2355+4)|0);
      HEAP8[($2356)]=$2354;
      var $2357=$4;
      var $2358=(($2357+6)|0);
      var $2359=HEAPU16[(($2358)>>1)];
      var $2360=(($2359)&65535);
      var $2361=$2360 & 255;
      var $2362=(($2361) & 255);
      var $2363=$dp;
      var $2364=(($2363+5)|0);
      HEAP8[($2364)]=$2362;
      __label__ = 246; break;
    case 245: 
      var $2366=$sp;
      var $2367=HEAPU8[($2366)];
      var $2368=(($2367)&255);
      var $2369=$2368 << 8;
      var $2370=$sp;
      var $2371=(($2370+1)|0);
      var $2372=HEAPU8[($2371)];
      var $2373=(($2372)&255);
      var $2374=((($2369)+($2373))|0);
      var $2375=(($2374) & 65535);
      $r41=$2375;
      var $2376=$sp;
      var $2377=(($2376+2)|0);
      var $2378=HEAPU8[($2377)];
      var $2379=(($2378)&255);
      var $2380=$2379 << 8;
      var $2381=$sp;
      var $2382=(($2381+3)|0);
      var $2383=HEAPU8[($2382)];
      var $2384=(($2383)&255);
      var $2385=((($2380)+($2384))|0);
      var $2386=(($2385) & 65535);
      $g42=$2386;
      var $2387=$sp;
      var $2388=(($2387+4)|0);
      var $2389=HEAPU8[($2388)];
      var $2390=(($2389)&255);
      var $2391=$2390 << 8;
      var $2392=$sp;
      var $2393=(($2392+5)|0);
      var $2394=HEAPU8[($2393)];
      var $2395=(($2394)&255);
      var $2396=((($2391)+($2395))|0);
      var $2397=(($2396) & 65535);
      $b43=$2397;
      var $2398=$r41;
      var $2399=(($2398)&65535);
      var $2400=$a39;
      var $2401=(($2400)&65535);
      var $2402=((($2399)*($2401))|0);
      var $2403=$4;
      var $2404=(($2403+2)|0);
      var $2405=HEAPU16[(($2404)>>1)];
      var $2406=(($2405)&65535);
      var $2407=$a39;
      var $2408=(($2407)&65535);
      var $2409=(((65535)-($2408))|0);
      var $2410=((($2406)*($2409))|0);
      var $2411=((($2402)+($2410))|0);
      var $2412=((($2411)+(32768))|0);
      $temp44=$2412;
      var $2413=$temp44;
      var $2414=$temp44;
      var $2415=$2414 >>> 16;
      var $2416=((($2413)+($2415))|0);
      var $2417=$2416 >>> 16;
      var $2418=(($2417) & 65535);
      $v40=$2418;
      var $2419=$v40;
      var $2420=(($2419)&65535);
      var $2421=$2420 >> 8;
      var $2422=$2421 & 255;
      var $2423=(($2422) & 255);
      var $2424=$dp;
      HEAP8[($2424)]=$2423;
      var $2425=$v40;
      var $2426=(($2425)&65535);
      var $2427=$2426 & 255;
      var $2428=(($2427) & 255);
      var $2429=$dp;
      var $2430=(($2429+1)|0);
      HEAP8[($2430)]=$2428;
      var $2431=$g42;
      var $2432=(($2431)&65535);
      var $2433=$a39;
      var $2434=(($2433)&65535);
      var $2435=((($2432)*($2434))|0);
      var $2436=$4;
      var $2437=(($2436+4)|0);
      var $2438=HEAPU16[(($2437)>>1)];
      var $2439=(($2438)&65535);
      var $2440=$a39;
      var $2441=(($2440)&65535);
      var $2442=(((65535)-($2441))|0);
      var $2443=((($2439)*($2442))|0);
      var $2444=((($2435)+($2443))|0);
      var $2445=((($2444)+(32768))|0);
      $temp45=$2445;
      var $2446=$temp45;
      var $2447=$temp45;
      var $2448=$2447 >>> 16;
      var $2449=((($2446)+($2448))|0);
      var $2450=$2449 >>> 16;
      var $2451=(($2450) & 65535);
      $v40=$2451;
      var $2452=$v40;
      var $2453=(($2452)&65535);
      var $2454=$2453 >> 8;
      var $2455=$2454 & 255;
      var $2456=(($2455) & 255);
      var $2457=$dp;
      var $2458=(($2457+2)|0);
      HEAP8[($2458)]=$2456;
      var $2459=$v40;
      var $2460=(($2459)&65535);
      var $2461=$2460 & 255;
      var $2462=(($2461) & 255);
      var $2463=$dp;
      var $2464=(($2463+3)|0);
      HEAP8[($2464)]=$2462;
      var $2465=$b43;
      var $2466=(($2465)&65535);
      var $2467=$a39;
      var $2468=(($2467)&65535);
      var $2469=((($2466)*($2468))|0);
      var $2470=$4;
      var $2471=(($2470+6)|0);
      var $2472=HEAPU16[(($2471)>>1)];
      var $2473=(($2472)&65535);
      var $2474=$a39;
      var $2475=(($2474)&65535);
      var $2476=(((65535)-($2475))|0);
      var $2477=((($2473)*($2476))|0);
      var $2478=((($2469)+($2477))|0);
      var $2479=((($2478)+(32768))|0);
      $temp46=$2479;
      var $2480=$temp46;
      var $2481=$temp46;
      var $2482=$2481 >>> 16;
      var $2483=((($2480)+($2482))|0);
      var $2484=$2483 >>> 16;
      var $2485=(($2484) & 65535);
      $v40=$2485;
      var $2486=$v40;
      var $2487=(($2486)&65535);
      var $2488=$2487 >> 8;
      var $2489=$2488 & 255;
      var $2490=(($2489) & 255);
      var $2491=$dp;
      var $2492=(($2491+4)|0);
      HEAP8[($2492)]=$2490;
      var $2493=$v40;
      var $2494=(($2493)&65535);
      var $2495=$2494 & 255;
      var $2496=(($2495) & 255);
      var $2497=$dp;
      var $2498=(($2497+5)|0);
      HEAP8[($2498)]=$2496;
      __label__ = 246; break;
    case 246: 
      __label__ = 247; break;
    case 247: 
      __label__ = 248; break;
    case 248: 
      var $2502=$i;
      var $2503=((($2502)+(1))|0);
      $i=$2503;
      var $2504=$sp;
      var $2505=(($2504+8)|0);
      $sp=$2505;
      var $2506=$dp;
      var $2507=(($2506+6)|0);
      $dp=$2507;
      __label__ = 240; break;
    case 249: 
      __label__ = 250; break;
    case 250: 
      __label__ = 251; break;
    case 251: 
      __label__ = 253; break;
    case 252: 
      __label__ = 253; break;
    case 253: 
      var $2513=$1;
      var $2514=(($2513+8)|0);
      var $2515=HEAPU8[($2514)];
      var $2516=(($2515)&255);
      var $2517=$2516 & 4;
      var $2518=(($2517)|0)!=0;
      if ($2518) { __label__ = 254; break; } else { __label__ = 258; break; }
    case 254: 
      var $2520=$1;
      var $2521=(($2520+8)|0);
      var $2522=HEAPU8[($2521)];
      var $2523=(($2522)&255);
      var $2524=$2523 & -5;
      var $2525=(($2524) & 255);
      HEAP8[($2521)]=$2525;
      var $2526=$1;
      var $2527=(($2526+10)|0);
      var $2528=HEAP8[($2527)];
      var $2529=((($2528)-(1))&255);
      HEAP8[($2527)]=$2529;
      var $2530=$1;
      var $2531=(($2530+10)|0);
      var $2532=HEAPU8[($2531)];
      var $2533=(($2532)&255);
      var $2534=$1;
      var $2535=(($2534+9)|0);
      var $2536=HEAPU8[($2535)];
      var $2537=(($2536)&255);
      var $2538=((($2533)*($2537))|0);
      var $2539=(($2538) & 255);
      var $2540=$1;
      var $2541=(($2540+11)|0);
      HEAP8[($2541)]=$2539;
      var $2542=$1;
      var $2543=(($2542+11)|0);
      var $2544=HEAPU8[($2543)];
      var $2545=(($2544)&255);
      var $2546=(($2545)|0) >= 8;
      if ($2546) { __label__ = 255; break; } else { __label__ = 256; break; }
    case 255: 
      var $2548=$row_width;
      var $2549=$1;
      var $2550=(($2549+11)|0);
      var $2551=HEAPU8[($2550)];
      var $2552=(($2551)&255);
      var $2553=$2552 >>> 3;
      var $2554=((($2548)*($2553))|0);
      var $2565 = $2554;__label__ = 257; break;
    case 256: 
      var $2556=$row_width;
      var $2557=$1;
      var $2558=(($2557+11)|0);
      var $2559=HEAPU8[($2558)];
      var $2560=(($2559)&255);
      var $2561=((($2556)*($2560))|0);
      var $2562=((($2561)+(7))|0);
      var $2563=$2562 >>> 3;
      var $2565 = $2563;__label__ = 257; break;
    case 257: 
      var $2565;
      var $2566=$1;
      var $2567=(($2566+4)|0);
      HEAP32[(($2567)>>2)]=$2565;
      __label__ = 258; break;
    case 258: 
      __label__ = 259; break;
    case 259: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_png_do_background["X"]=1;

function _png_do_gamma($row_info, $row, $gamma_table, $gamma_16_table, $gamma_shift) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $5;
      var $sp;
      var $i;
      var $row_width;
      var $v;
      var $v1;
      var $v2;
      var $a;
      var $b;
      var $c;
      var $d;
      var $msb;
      var $lsb;
      var $v3;
      $1=$row_info;
      $2=$row;
      $3=$gamma_table;
      $4=$gamma_16_table;
      $5=$gamma_shift;
      var $6=$1;
      var $7=(($6)|0);
      var $8=HEAP32[(($7)>>2)];
      $row_width=$8;
      var $9=$1;
      var $10=(($9+9)|0);
      var $11=HEAPU8[($10)];
      var $12=(($11)&255);
      var $13=(($12)|0) <= 8;
      if ($13) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $15=$3;
      var $16=(($15)|0)!=0;
      if ($16) { __label__ = 6; break; } else { __label__ = 4; break; }
    case 4: 
      var $18=$1;
      var $19=(($18+9)|0);
      var $20=HEAPU8[($19)];
      var $21=(($20)&255);
      var $22=(($21)|0)==16;
      if ($22) { __label__ = 5; break; } else { __label__ = 72; break; }
    case 5: 
      var $24=$4;
      var $25=(($24)|0)!=0;
      if ($25) { __label__ = 6; break; } else { __label__ = 72; break; }
    case 6: 
      var $27=$1;
      var $28=(($27+8)|0);
      var $29=HEAPU8[($28)];
      var $30=(($29)&255);
      if ((($30)|0) == 2) {
        __label__ = 7; break;
      }
      else if ((($30)|0) == 6) {
        __label__ = 19; break;
      }
      else if ((($30)|0) == 4) {
        __label__ = 31; break;
      }
      else if ((($30)|0) == 0) {
        __label__ = 43; break;
      }
      else {
      __label__ = 70; break;
      }
      
    case 7: 
      var $32=$1;
      var $33=(($32+9)|0);
      var $34=HEAPU8[($33)];
      var $35=(($34)&255);
      var $36=(($35)|0)==8;
      if ($36) { __label__ = 8; break; } else { __label__ = 13; break; }
    case 8: 
      var $38=$2;
      $sp=$38;
      $i=0;
      __label__ = 9; break;
    case 9: 
      var $40=$i;
      var $41=$row_width;
      var $42=(($40)>>>0) < (($41)>>>0);
      if ($42) { __label__ = 10; break; } else { __label__ = 12; break; }
    case 10: 
      var $44=$sp;
      var $45=HEAPU8[($44)];
      var $46=(($45)&255);
      var $47=$3;
      var $48=(($47+$46)|0);
      var $49=HEAP8[($48)];
      var $50=$sp;
      HEAP8[($50)]=$49;
      var $51=$sp;
      var $52=(($51+1)|0);
      $sp=$52;
      var $53=$sp;
      var $54=HEAPU8[($53)];
      var $55=(($54)&255);
      var $56=$3;
      var $57=(($56+$55)|0);
      var $58=HEAP8[($57)];
      var $59=$sp;
      HEAP8[($59)]=$58;
      var $60=$sp;
      var $61=(($60+1)|0);
      $sp=$61;
      var $62=$sp;
      var $63=HEAPU8[($62)];
      var $64=(($63)&255);
      var $65=$3;
      var $66=(($65+$64)|0);
      var $67=HEAP8[($66)];
      var $68=$sp;
      HEAP8[($68)]=$67;
      var $69=$sp;
      var $70=(($69+1)|0);
      $sp=$70;
      __label__ = 11; break;
    case 11: 
      var $72=$i;
      var $73=((($72)+(1))|0);
      $i=$73;
      __label__ = 9; break;
    case 12: 
      __label__ = 18; break;
    case 13: 
      var $76=$2;
      $sp=$76;
      $i=0;
      __label__ = 14; break;
    case 14: 
      var $78=$i;
      var $79=$row_width;
      var $80=(($78)>>>0) < (($79)>>>0);
      if ($80) { __label__ = 15; break; } else { __label__ = 17; break; }
    case 15: 
      var $82=$sp;
      var $83=HEAPU8[($82)];
      var $84=(($83)&255);
      var $85=$sp;
      var $86=(($85+1)|0);
      var $87=HEAPU8[($86)];
      var $88=(($87)&255);
      var $89=$5;
      var $90=$88 >> (($89)|0);
      var $91=$4;
      var $92=(($91+($90<<2))|0);
      var $93=HEAP32[(($92)>>2)];
      var $94=(($93+($84<<1))|0);
      var $95=HEAP16[(($94)>>1)];
      $v=$95;
      var $96=$v;
      var $97=(($96)&65535);
      var $98=$97 >> 8;
      var $99=$98 & 255;
      var $100=(($99) & 255);
      var $101=$sp;
      HEAP8[($101)]=$100;
      var $102=$v;
      var $103=(($102)&65535);
      var $104=$103 & 255;
      var $105=(($104) & 255);
      var $106=$sp;
      var $107=(($106+1)|0);
      HEAP8[($107)]=$105;
      var $108=$sp;
      var $109=(($108+2)|0);
      $sp=$109;
      var $110=$sp;
      var $111=HEAPU8[($110)];
      var $112=(($111)&255);
      var $113=$sp;
      var $114=(($113+1)|0);
      var $115=HEAPU8[($114)];
      var $116=(($115)&255);
      var $117=$5;
      var $118=$116 >> (($117)|0);
      var $119=$4;
      var $120=(($119+($118<<2))|0);
      var $121=HEAP32[(($120)>>2)];
      var $122=(($121+($112<<1))|0);
      var $123=HEAP16[(($122)>>1)];
      $v=$123;
      var $124=$v;
      var $125=(($124)&65535);
      var $126=$125 >> 8;
      var $127=$126 & 255;
      var $128=(($127) & 255);
      var $129=$sp;
      HEAP8[($129)]=$128;
      var $130=$v;
      var $131=(($130)&65535);
      var $132=$131 & 255;
      var $133=(($132) & 255);
      var $134=$sp;
      var $135=(($134+1)|0);
      HEAP8[($135)]=$133;
      var $136=$sp;
      var $137=(($136+2)|0);
      $sp=$137;
      var $138=$sp;
      var $139=HEAPU8[($138)];
      var $140=(($139)&255);
      var $141=$sp;
      var $142=(($141+1)|0);
      var $143=HEAPU8[($142)];
      var $144=(($143)&255);
      var $145=$5;
      var $146=$144 >> (($145)|0);
      var $147=$4;
      var $148=(($147+($146<<2))|0);
      var $149=HEAP32[(($148)>>2)];
      var $150=(($149+($140<<1))|0);
      var $151=HEAP16[(($150)>>1)];
      $v=$151;
      var $152=$v;
      var $153=(($152)&65535);
      var $154=$153 >> 8;
      var $155=$154 & 255;
      var $156=(($155) & 255);
      var $157=$sp;
      HEAP8[($157)]=$156;
      var $158=$v;
      var $159=(($158)&65535);
      var $160=$159 & 255;
      var $161=(($160) & 255);
      var $162=$sp;
      var $163=(($162+1)|0);
      HEAP8[($163)]=$161;
      var $164=$sp;
      var $165=(($164+2)|0);
      $sp=$165;
      __label__ = 16; break;
    case 16: 
      var $167=$i;
      var $168=((($167)+(1))|0);
      $i=$168;
      __label__ = 14; break;
    case 17: 
      __label__ = 18; break;
    case 18: 
      __label__ = 71; break;
    case 19: 
      var $172=$1;
      var $173=(($172+9)|0);
      var $174=HEAPU8[($173)];
      var $175=(($174)&255);
      var $176=(($175)|0)==8;
      if ($176) { __label__ = 20; break; } else { __label__ = 25; break; }
    case 20: 
      var $178=$2;
      $sp=$178;
      $i=0;
      __label__ = 21; break;
    case 21: 
      var $180=$i;
      var $181=$row_width;
      var $182=(($180)>>>0) < (($181)>>>0);
      if ($182) { __label__ = 22; break; } else { __label__ = 24; break; }
    case 22: 
      var $184=$sp;
      var $185=HEAPU8[($184)];
      var $186=(($185)&255);
      var $187=$3;
      var $188=(($187+$186)|0);
      var $189=HEAP8[($188)];
      var $190=$sp;
      HEAP8[($190)]=$189;
      var $191=$sp;
      var $192=(($191+1)|0);
      $sp=$192;
      var $193=$sp;
      var $194=HEAPU8[($193)];
      var $195=(($194)&255);
      var $196=$3;
      var $197=(($196+$195)|0);
      var $198=HEAP8[($197)];
      var $199=$sp;
      HEAP8[($199)]=$198;
      var $200=$sp;
      var $201=(($200+1)|0);
      $sp=$201;
      var $202=$sp;
      var $203=HEAPU8[($202)];
      var $204=(($203)&255);
      var $205=$3;
      var $206=(($205+$204)|0);
      var $207=HEAP8[($206)];
      var $208=$sp;
      HEAP8[($208)]=$207;
      var $209=$sp;
      var $210=(($209+1)|0);
      $sp=$210;
      var $211=$sp;
      var $212=(($211+1)|0);
      $sp=$212;
      __label__ = 23; break;
    case 23: 
      var $214=$i;
      var $215=((($214)+(1))|0);
      $i=$215;
      __label__ = 21; break;
    case 24: 
      __label__ = 30; break;
    case 25: 
      var $218=$2;
      $sp=$218;
      $i=0;
      __label__ = 26; break;
    case 26: 
      var $220=$i;
      var $221=$row_width;
      var $222=(($220)>>>0) < (($221)>>>0);
      if ($222) { __label__ = 27; break; } else { __label__ = 29; break; }
    case 27: 
      var $224=$sp;
      var $225=HEAPU8[($224)];
      var $226=(($225)&255);
      var $227=$sp;
      var $228=(($227+1)|0);
      var $229=HEAPU8[($228)];
      var $230=(($229)&255);
      var $231=$5;
      var $232=$230 >> (($231)|0);
      var $233=$4;
      var $234=(($233+($232<<2))|0);
      var $235=HEAP32[(($234)>>2)];
      var $236=(($235+($226<<1))|0);
      var $237=HEAP16[(($236)>>1)];
      $v1=$237;
      var $238=$v1;
      var $239=(($238)&65535);
      var $240=$239 >> 8;
      var $241=$240 & 255;
      var $242=(($241) & 255);
      var $243=$sp;
      HEAP8[($243)]=$242;
      var $244=$v1;
      var $245=(($244)&65535);
      var $246=$245 & 255;
      var $247=(($246) & 255);
      var $248=$sp;
      var $249=(($248+1)|0);
      HEAP8[($249)]=$247;
      var $250=$sp;
      var $251=(($250+2)|0);
      $sp=$251;
      var $252=$sp;
      var $253=HEAPU8[($252)];
      var $254=(($253)&255);
      var $255=$sp;
      var $256=(($255+1)|0);
      var $257=HEAPU8[($256)];
      var $258=(($257)&255);
      var $259=$5;
      var $260=$258 >> (($259)|0);
      var $261=$4;
      var $262=(($261+($260<<2))|0);
      var $263=HEAP32[(($262)>>2)];
      var $264=(($263+($254<<1))|0);
      var $265=HEAP16[(($264)>>1)];
      $v1=$265;
      var $266=$v1;
      var $267=(($266)&65535);
      var $268=$267 >> 8;
      var $269=$268 & 255;
      var $270=(($269) & 255);
      var $271=$sp;
      HEAP8[($271)]=$270;
      var $272=$v1;
      var $273=(($272)&65535);
      var $274=$273 & 255;
      var $275=(($274) & 255);
      var $276=$sp;
      var $277=(($276+1)|0);
      HEAP8[($277)]=$275;
      var $278=$sp;
      var $279=(($278+2)|0);
      $sp=$279;
      var $280=$sp;
      var $281=HEAPU8[($280)];
      var $282=(($281)&255);
      var $283=$sp;
      var $284=(($283+1)|0);
      var $285=HEAPU8[($284)];
      var $286=(($285)&255);
      var $287=$5;
      var $288=$286 >> (($287)|0);
      var $289=$4;
      var $290=(($289+($288<<2))|0);
      var $291=HEAP32[(($290)>>2)];
      var $292=(($291+($282<<1))|0);
      var $293=HEAP16[(($292)>>1)];
      $v1=$293;
      var $294=$v1;
      var $295=(($294)&65535);
      var $296=$295 >> 8;
      var $297=$296 & 255;
      var $298=(($297) & 255);
      var $299=$sp;
      HEAP8[($299)]=$298;
      var $300=$v1;
      var $301=(($300)&65535);
      var $302=$301 & 255;
      var $303=(($302) & 255);
      var $304=$sp;
      var $305=(($304+1)|0);
      HEAP8[($305)]=$303;
      var $306=$sp;
      var $307=(($306+4)|0);
      $sp=$307;
      __label__ = 28; break;
    case 28: 
      var $309=$i;
      var $310=((($309)+(1))|0);
      $i=$310;
      __label__ = 26; break;
    case 29: 
      __label__ = 30; break;
    case 30: 
      __label__ = 71; break;
    case 31: 
      var $314=$1;
      var $315=(($314+9)|0);
      var $316=HEAPU8[($315)];
      var $317=(($316)&255);
      var $318=(($317)|0)==8;
      if ($318) { __label__ = 32; break; } else { __label__ = 37; break; }
    case 32: 
      var $320=$2;
      $sp=$320;
      $i=0;
      __label__ = 33; break;
    case 33: 
      var $322=$i;
      var $323=$row_width;
      var $324=(($322)>>>0) < (($323)>>>0);
      if ($324) { __label__ = 34; break; } else { __label__ = 36; break; }
    case 34: 
      var $326=$sp;
      var $327=HEAPU8[($326)];
      var $328=(($327)&255);
      var $329=$3;
      var $330=(($329+$328)|0);
      var $331=HEAP8[($330)];
      var $332=$sp;
      HEAP8[($332)]=$331;
      var $333=$sp;
      var $334=(($333+2)|0);
      $sp=$334;
      __label__ = 35; break;
    case 35: 
      var $336=$i;
      var $337=((($336)+(1))|0);
      $i=$337;
      __label__ = 33; break;
    case 36: 
      __label__ = 42; break;
    case 37: 
      var $340=$2;
      $sp=$340;
      $i=0;
      __label__ = 38; break;
    case 38: 
      var $342=$i;
      var $343=$row_width;
      var $344=(($342)>>>0) < (($343)>>>0);
      if ($344) { __label__ = 39; break; } else { __label__ = 41; break; }
    case 39: 
      var $346=$sp;
      var $347=HEAPU8[($346)];
      var $348=(($347)&255);
      var $349=$sp;
      var $350=(($349+1)|0);
      var $351=HEAPU8[($350)];
      var $352=(($351)&255);
      var $353=$5;
      var $354=$352 >> (($353)|0);
      var $355=$4;
      var $356=(($355+($354<<2))|0);
      var $357=HEAP32[(($356)>>2)];
      var $358=(($357+($348<<1))|0);
      var $359=HEAP16[(($358)>>1)];
      $v2=$359;
      var $360=$v2;
      var $361=(($360)&65535);
      var $362=$361 >> 8;
      var $363=$362 & 255;
      var $364=(($363) & 255);
      var $365=$sp;
      HEAP8[($365)]=$364;
      var $366=$v2;
      var $367=(($366)&65535);
      var $368=$367 & 255;
      var $369=(($368) & 255);
      var $370=$sp;
      var $371=(($370+1)|0);
      HEAP8[($371)]=$369;
      var $372=$sp;
      var $373=(($372+4)|0);
      $sp=$373;
      __label__ = 40; break;
    case 40: 
      var $375=$i;
      var $376=((($375)+(1))|0);
      $i=$376;
      __label__ = 38; break;
    case 41: 
      __label__ = 42; break;
    case 42: 
      __label__ = 71; break;
    case 43: 
      var $380=$1;
      var $381=(($380+9)|0);
      var $382=HEAPU8[($381)];
      var $383=(($382)&255);
      var $384=(($383)|0)==2;
      if ($384) { __label__ = 44; break; } else { __label__ = 49; break; }
    case 44: 
      var $386=$2;
      $sp=$386;
      $i=0;
      __label__ = 45; break;
    case 45: 
      var $388=$i;
      var $389=$row_width;
      var $390=(($388)>>>0) < (($389)>>>0);
      if ($390) { __label__ = 46; break; } else { __label__ = 48; break; }
    case 46: 
      var $392=$sp;
      var $393=HEAPU8[($392)];
      var $394=(($393)&255);
      var $395=$394 & 192;
      $a=$395;
      var $396=$sp;
      var $397=HEAPU8[($396)];
      var $398=(($397)&255);
      var $399=$398 & 48;
      $b=$399;
      var $400=$sp;
      var $401=HEAPU8[($400)];
      var $402=(($401)&255);
      var $403=$402 & 12;
      $c=$403;
      var $404=$sp;
      var $405=HEAPU8[($404)];
      var $406=(($405)&255);
      var $407=$406 & 3;
      $d=$407;
      var $408=$a;
      var $409=$a;
      var $410=$409 >> 2;
      var $411=$408 | $410;
      var $412=$a;
      var $413=$412 >> 4;
      var $414=$411 | $413;
      var $415=$a;
      var $416=$415 >> 6;
      var $417=$414 | $416;
      var $418=$3;
      var $419=(($418+$417)|0);
      var $420=HEAPU8[($419)];
      var $421=(($420)&255);
      var $422=$421 & 192;
      var $423=$b;
      var $424=$423 << 2;
      var $425=$b;
      var $426=$424 | $425;
      var $427=$b;
      var $428=$427 >> 2;
      var $429=$426 | $428;
      var $430=$b;
      var $431=$430 >> 4;
      var $432=$429 | $431;
      var $433=$3;
      var $434=(($433+$432)|0);
      var $435=HEAPU8[($434)];
      var $436=(($435)&255);
      var $437=$436 >> 2;
      var $438=$437 & 48;
      var $439=$422 | $438;
      var $440=$c;
      var $441=$440 << 4;
      var $442=$c;
      var $443=$442 << 2;
      var $444=$441 | $443;
      var $445=$c;
      var $446=$444 | $445;
      var $447=$c;
      var $448=$447 >> 2;
      var $449=$446 | $448;
      var $450=$3;
      var $451=(($450+$449)|0);
      var $452=HEAPU8[($451)];
      var $453=(($452)&255);
      var $454=$453 >> 4;
      var $455=$454 & 12;
      var $456=$439 | $455;
      var $457=$d;
      var $458=$457 << 6;
      var $459=$d;
      var $460=$459 << 4;
      var $461=$458 | $460;
      var $462=$d;
      var $463=$462 << 2;
      var $464=$461 | $463;
      var $465=$d;
      var $466=$464 | $465;
      var $467=$3;
      var $468=(($467+$466)|0);
      var $469=HEAPU8[($468)];
      var $470=(($469)&255);
      var $471=$470 >> 6;
      var $472=$456 | $471;
      var $473=(($472) & 255);
      var $474=$sp;
      HEAP8[($474)]=$473;
      var $475=$sp;
      var $476=(($475+1)|0);
      $sp=$476;
      __label__ = 47; break;
    case 47: 
      var $478=$i;
      var $479=((($478)+(4))|0);
      $i=$479;
      __label__ = 45; break;
    case 48: 
      __label__ = 49; break;
    case 49: 
      var $482=$1;
      var $483=(($482+9)|0);
      var $484=HEAPU8[($483)];
      var $485=(($484)&255);
      var $486=(($485)|0)==4;
      if ($486) { __label__ = 50; break; } else { __label__ = 55; break; }
    case 50: 
      var $488=$2;
      $sp=$488;
      $i=0;
      __label__ = 51; break;
    case 51: 
      var $490=$i;
      var $491=$row_width;
      var $492=(($490)>>>0) < (($491)>>>0);
      if ($492) { __label__ = 52; break; } else { __label__ = 54; break; }
    case 52: 
      var $494=$sp;
      var $495=HEAPU8[($494)];
      var $496=(($495)&255);
      var $497=$496 & 240;
      $msb=$497;
      var $498=$sp;
      var $499=HEAPU8[($498)];
      var $500=(($499)&255);
      var $501=$500 & 15;
      $lsb=$501;
      var $502=$msb;
      var $503=$msb;
      var $504=$503 >> 4;
      var $505=$502 | $504;
      var $506=$3;
      var $507=(($506+$505)|0);
      var $508=HEAPU8[($507)];
      var $509=(($508)&255);
      var $510=$509 & 240;
      var $511=$lsb;
      var $512=$511 << 4;
      var $513=$lsb;
      var $514=$512 | $513;
      var $515=$3;
      var $516=(($515+$514)|0);
      var $517=HEAPU8[($516)];
      var $518=(($517)&255);
      var $519=$518 >> 4;
      var $520=$510 | $519;
      var $521=(($520) & 255);
      var $522=$sp;
      HEAP8[($522)]=$521;
      var $523=$sp;
      var $524=(($523+1)|0);
      $sp=$524;
      __label__ = 53; break;
    case 53: 
      var $526=$i;
      var $527=((($526)+(2))|0);
      $i=$527;
      __label__ = 51; break;
    case 54: 
      __label__ = 69; break;
    case 55: 
      var $530=$1;
      var $531=(($530+9)|0);
      var $532=HEAPU8[($531)];
      var $533=(($532)&255);
      var $534=(($533)|0)==8;
      if ($534) { __label__ = 56; break; } else { __label__ = 61; break; }
    case 56: 
      var $536=$2;
      $sp=$536;
      $i=0;
      __label__ = 57; break;
    case 57: 
      var $538=$i;
      var $539=$row_width;
      var $540=(($538)>>>0) < (($539)>>>0);
      if ($540) { __label__ = 58; break; } else { __label__ = 60; break; }
    case 58: 
      var $542=$sp;
      var $543=HEAPU8[($542)];
      var $544=(($543)&255);
      var $545=$3;
      var $546=(($545+$544)|0);
      var $547=HEAP8[($546)];
      var $548=$sp;
      HEAP8[($548)]=$547;
      var $549=$sp;
      var $550=(($549+1)|0);
      $sp=$550;
      __label__ = 59; break;
    case 59: 
      var $552=$i;
      var $553=((($552)+(1))|0);
      $i=$553;
      __label__ = 57; break;
    case 60: 
      __label__ = 68; break;
    case 61: 
      var $556=$1;
      var $557=(($556+9)|0);
      var $558=HEAPU8[($557)];
      var $559=(($558)&255);
      var $560=(($559)|0)==16;
      if ($560) { __label__ = 62; break; } else { __label__ = 67; break; }
    case 62: 
      var $562=$2;
      $sp=$562;
      $i=0;
      __label__ = 63; break;
    case 63: 
      var $564=$i;
      var $565=$row_width;
      var $566=(($564)>>>0) < (($565)>>>0);
      if ($566) { __label__ = 64; break; } else { __label__ = 66; break; }
    case 64: 
      var $568=$sp;
      var $569=HEAPU8[($568)];
      var $570=(($569)&255);
      var $571=$sp;
      var $572=(($571+1)|0);
      var $573=HEAPU8[($572)];
      var $574=(($573)&255);
      var $575=$5;
      var $576=$574 >> (($575)|0);
      var $577=$4;
      var $578=(($577+($576<<2))|0);
      var $579=HEAP32[(($578)>>2)];
      var $580=(($579+($570<<1))|0);
      var $581=HEAP16[(($580)>>1)];
      $v3=$581;
      var $582=$v3;
      var $583=(($582)&65535);
      var $584=$583 >> 8;
      var $585=$584 & 255;
      var $586=(($585) & 255);
      var $587=$sp;
      HEAP8[($587)]=$586;
      var $588=$v3;
      var $589=(($588)&65535);
      var $590=$589 & 255;
      var $591=(($590) & 255);
      var $592=$sp;
      var $593=(($592+1)|0);
      HEAP8[($593)]=$591;
      var $594=$sp;
      var $595=(($594+2)|0);
      $sp=$595;
      __label__ = 65; break;
    case 65: 
      var $597=$i;
      var $598=((($597)+(1))|0);
      $i=$598;
      __label__ = 63; break;
    case 66: 
      __label__ = 67; break;
    case 67: 
      __label__ = 68; break;
    case 68: 
      __label__ = 69; break;
    case 69: 
      __label__ = 71; break;
    case 70: 
      __label__ = 71; break;
    case 71: 
      __label__ = 72; break;
    case 72: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_png_do_gamma["X"]=1;

function _png_do_chop($row_info, $row) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $sp;
      var $dp;
      var $i;
      var $istop;
      $1=$row_info;
      $2=$row;
      var $3=$1;
      var $4=(($3+9)|0);
      var $5=HEAPU8[($4)];
      var $6=(($5)&255);
      var $7=(($6)|0)==16;
      if ($7) { __label__ = 3; break; } else { __label__ = 8; break; }
    case 3: 
      var $9=$2;
      $sp=$9;
      var $10=$2;
      $dp=$10;
      var $11=$1;
      var $12=(($11)|0);
      var $13=HEAP32[(($12)>>2)];
      var $14=$1;
      var $15=(($14+10)|0);
      var $16=HEAPU8[($15)];
      var $17=(($16)&255);
      var $18=((($13)*($17))|0);
      $istop=$18;
      $i=0;
      __label__ = 4; break;
    case 4: 
      var $20=$i;
      var $21=$istop;
      var $22=(($20)>>>0) < (($21)>>>0);
      if ($22) { __label__ = 5; break; } else { __label__ = 7; break; }
    case 5: 
      var $24=$sp;
      var $25=HEAP8[($24)];
      var $26=$dp;
      HEAP8[($26)]=$25;
      __label__ = 6; break;
    case 6: 
      var $28=$i;
      var $29=((($28)+(1))|0);
      $i=$29;
      var $30=$sp;
      var $31=(($30+2)|0);
      $sp=$31;
      var $32=$dp;
      var $33=(($32+1)|0);
      $dp=$33;
      __label__ = 4; break;
    case 7: 
      var $35=$1;
      var $36=(($35+9)|0);
      HEAP8[($36)]=8;
      var $37=$1;
      var $38=(($37+10)|0);
      var $39=HEAPU8[($38)];
      var $40=(($39)&255);
      var $41=((($40<<3))|0);
      var $42=(($41) & 255);
      var $43=$1;
      var $44=(($43+11)|0);
      HEAP8[($44)]=$42;
      var $45=$1;
      var $46=(($45)|0);
      var $47=HEAP32[(($46)>>2)];
      var $48=$1;
      var $49=(($48+10)|0);
      var $50=HEAPU8[($49)];
      var $51=(($50)&255);
      var $52=((($47)*($51))|0);
      var $53=$1;
      var $54=(($53+4)|0);
      HEAP32[(($54)>>2)]=$52;
      __label__ = 8; break;
    case 8: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_png_do_chop["X"]=1;

function _png_do_quantize($row_info, $row, $palette_lookup, $quantize_lookup) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $sp;
      var $dp;
      var $i;
      var $row_width;
      var $r;
      var $g;
      var $b;
      var $p;
      var $r1;
      var $g2;
      var $b3;
      var $p4;
      $1=$row_info;
      $2=$row;
      $3=$palette_lookup;
      $4=$quantize_lookup;
      var $5=$1;
      var $6=(($5)|0);
      var $7=HEAP32[(($6)>>2)];
      $row_width=$7;
      var $8=$1;
      var $9=(($8+8)|0);
      var $10=HEAPU8[($9)];
      var $11=(($10)&255);
      var $12=(($11)|0)==2;
      if ($12) { __label__ = 3; break; } else { __label__ = 13; break; }
    case 3: 
      var $14=$3;
      var $15=(($14)|0)!=0;
      if ($15) { __label__ = 4; break; } else { __label__ = 13; break; }
    case 4: 
      var $17=$1;
      var $18=(($17+9)|0);
      var $19=HEAPU8[($18)];
      var $20=(($19)&255);
      var $21=(($20)|0)==8;
      if ($21) { __label__ = 5; break; } else { __label__ = 13; break; }
    case 5: 
      var $23=$2;
      $sp=$23;
      var $24=$2;
      $dp=$24;
      $i=0;
      __label__ = 6; break;
    case 6: 
      var $26=$i;
      var $27=$row_width;
      var $28=(($26)>>>0) < (($27)>>>0);
      if ($28) { __label__ = 7; break; } else { __label__ = 9; break; }
    case 7: 
      var $30=$sp;
      var $31=(($30+1)|0);
      $sp=$31;
      var $32=HEAPU8[($30)];
      var $33=(($32)&255);
      $r=$33;
      var $34=$sp;
      var $35=(($34+1)|0);
      $sp=$35;
      var $36=HEAPU8[($34)];
      var $37=(($36)&255);
      $g=$37;
      var $38=$sp;
      var $39=(($38+1)|0);
      $sp=$39;
      var $40=HEAPU8[($38)];
      var $41=(($40)&255);
      $b=$41;
      var $42=$r;
      var $43=$42 >> 3;
      var $44=$43 & 31;
      var $45=$44 << 10;
      var $46=$g;
      var $47=$46 >> 3;
      var $48=$47 & 31;
      var $49=$48 << 5;
      var $50=$45 | $49;
      var $51=$b;
      var $52=$51 >> 3;
      var $53=$52 & 31;
      var $54=$50 | $53;
      $p=$54;
      var $55=$p;
      var $56=$3;
      var $57=(($56+$55)|0);
      var $58=HEAP8[($57)];
      var $59=$dp;
      var $60=(($59+1)|0);
      $dp=$60;
      HEAP8[($59)]=$58;
      __label__ = 8; break;
    case 8: 
      var $62=$i;
      var $63=((($62)+(1))|0);
      $i=$63;
      __label__ = 6; break;
    case 9: 
      var $65=$1;
      var $66=(($65+8)|0);
      HEAP8[($66)]=3;
      var $67=$1;
      var $68=(($67+10)|0);
      HEAP8[($68)]=1;
      var $69=$1;
      var $70=(($69+9)|0);
      var $71=HEAP8[($70)];
      var $72=$1;
      var $73=(($72+11)|0);
      HEAP8[($73)]=$71;
      var $74=$1;
      var $75=(($74+11)|0);
      var $76=HEAPU8[($75)];
      var $77=(($76)&255);
      var $78=(($77)|0) >= 8;
      if ($78) { __label__ = 10; break; } else { __label__ = 11; break; }
    case 10: 
      var $80=$row_width;
      var $81=$1;
      var $82=(($81+11)|0);
      var $83=HEAPU8[($82)];
      var $84=(($83)&255);
      var $85=$84 >>> 3;
      var $86=((($80)*($85))|0);
      var $97 = $86;__label__ = 12; break;
    case 11: 
      var $88=$row_width;
      var $89=$1;
      var $90=(($89+11)|0);
      var $91=HEAPU8[($90)];
      var $92=(($91)&255);
      var $93=((($88)*($92))|0);
      var $94=((($93)+(7))|0);
      var $95=$94 >>> 3;
      var $97 = $95;__label__ = 12; break;
    case 12: 
      var $97;
      var $98=$1;
      var $99=(($98+4)|0);
      HEAP32[(($99)>>2)]=$97;
      __label__ = 34; break;
    case 13: 
      var $101=$1;
      var $102=(($101+8)|0);
      var $103=HEAPU8[($102)];
      var $104=(($103)&255);
      var $105=(($104)|0)==6;
      if ($105) { __label__ = 14; break; } else { __label__ = 24; break; }
    case 14: 
      var $107=$3;
      var $108=(($107)|0)!=0;
      if ($108) { __label__ = 15; break; } else { __label__ = 24; break; }
    case 15: 
      var $110=$1;
      var $111=(($110+9)|0);
      var $112=HEAPU8[($111)];
      var $113=(($112)&255);
      var $114=(($113)|0)==8;
      if ($114) { __label__ = 16; break; } else { __label__ = 24; break; }
    case 16: 
      var $116=$2;
      $sp=$116;
      var $117=$2;
      $dp=$117;
      $i=0;
      __label__ = 17; break;
    case 17: 
      var $119=$i;
      var $120=$row_width;
      var $121=(($119)>>>0) < (($120)>>>0);
      if ($121) { __label__ = 18; break; } else { __label__ = 20; break; }
    case 18: 
      var $123=$sp;
      var $124=(($123+1)|0);
      $sp=$124;
      var $125=HEAPU8[($123)];
      var $126=(($125)&255);
      $r1=$126;
      var $127=$sp;
      var $128=(($127+1)|0);
      $sp=$128;
      var $129=HEAPU8[($127)];
      var $130=(($129)&255);
      $g2=$130;
      var $131=$sp;
      var $132=(($131+1)|0);
      $sp=$132;
      var $133=HEAPU8[($131)];
      var $134=(($133)&255);
      $b3=$134;
      var $135=$sp;
      var $136=(($135+1)|0);
      $sp=$136;
      var $137=$r1;
      var $138=$137 >> 3;
      var $139=$138 & 31;
      var $140=$139 << 10;
      var $141=$g2;
      var $142=$141 >> 3;
      var $143=$142 & 31;
      var $144=$143 << 5;
      var $145=$140 | $144;
      var $146=$b3;
      var $147=$146 >> 3;
      var $148=$147 & 31;
      var $149=$145 | $148;
      $p4=$149;
      var $150=$p4;
      var $151=$3;
      var $152=(($151+$150)|0);
      var $153=HEAP8[($152)];
      var $154=$dp;
      var $155=(($154+1)|0);
      $dp=$155;
      HEAP8[($154)]=$153;
      __label__ = 19; break;
    case 19: 
      var $157=$i;
      var $158=((($157)+(1))|0);
      $i=$158;
      __label__ = 17; break;
    case 20: 
      var $160=$1;
      var $161=(($160+8)|0);
      HEAP8[($161)]=3;
      var $162=$1;
      var $163=(($162+10)|0);
      HEAP8[($163)]=1;
      var $164=$1;
      var $165=(($164+9)|0);
      var $166=HEAP8[($165)];
      var $167=$1;
      var $168=(($167+11)|0);
      HEAP8[($168)]=$166;
      var $169=$1;
      var $170=(($169+11)|0);
      var $171=HEAPU8[($170)];
      var $172=(($171)&255);
      var $173=(($172)|0) >= 8;
      if ($173) { __label__ = 21; break; } else { __label__ = 22; break; }
    case 21: 
      var $175=$row_width;
      var $176=$1;
      var $177=(($176+11)|0);
      var $178=HEAPU8[($177)];
      var $179=(($178)&255);
      var $180=$179 >>> 3;
      var $181=((($175)*($180))|0);
      var $192 = $181;__label__ = 23; break;
    case 22: 
      var $183=$row_width;
      var $184=$1;
      var $185=(($184+11)|0);
      var $186=HEAPU8[($185)];
      var $187=(($186)&255);
      var $188=((($183)*($187))|0);
      var $189=((($188)+(7))|0);
      var $190=$189 >>> 3;
      var $192 = $190;__label__ = 23; break;
    case 23: 
      var $192;
      var $193=$1;
      var $194=(($193+4)|0);
      HEAP32[(($194)>>2)]=$192;
      __label__ = 33; break;
    case 24: 
      var $196=$1;
      var $197=(($196+8)|0);
      var $198=HEAPU8[($197)];
      var $199=(($198)&255);
      var $200=(($199)|0)==3;
      if ($200) { __label__ = 25; break; } else { __label__ = 32; break; }
    case 25: 
      var $202=$4;
      var $203=(($202)|0)!=0;
      if ($203) { __label__ = 26; break; } else { __label__ = 32; break; }
    case 26: 
      var $205=$1;
      var $206=(($205+9)|0);
      var $207=HEAPU8[($206)];
      var $208=(($207)&255);
      var $209=(($208)|0)==8;
      if ($209) { __label__ = 27; break; } else { __label__ = 32; break; }
    case 27: 
      var $211=$2;
      $sp=$211;
      $i=0;
      __label__ = 28; break;
    case 28: 
      var $213=$i;
      var $214=$row_width;
      var $215=(($213)>>>0) < (($214)>>>0);
      if ($215) { __label__ = 29; break; } else { __label__ = 31; break; }
    case 29: 
      var $217=$sp;
      var $218=HEAPU8[($217)];
      var $219=(($218)&255);
      var $220=$4;
      var $221=(($220+$219)|0);
      var $222=HEAP8[($221)];
      var $223=$sp;
      HEAP8[($223)]=$222;
      __label__ = 30; break;
    case 30: 
      var $225=$i;
      var $226=((($225)+(1))|0);
      $i=$226;
      var $227=$sp;
      var $228=(($227+1)|0);
      $sp=$228;
      __label__ = 28; break;
    case 31: 
      __label__ = 32; break;
    case 32: 
      __label__ = 33; break;
    case 33: 
      __label__ = 34; break;
    case 34: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_png_do_quantize["X"]=1;

function _png_do_unshift($row_info, $row, $sig_bits) {
  var __stackBase__  = STACKTOP; STACKTOP += 16; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $shift=__stackBase__;
      var $channels;
      var $c;
      var $value;
      var $row_width;
      var $bp;
      var $i;
      var $istop;
      var $bp1;
      var $i2;
      var $istop3;
      var $mask;
      var $bp4;
      var $i5;
      var $istop6;
      var $bp7;
      var $i8;
      var $istop9;
      $1=$row_info;
      $2=$row;
      $3=$sig_bits;
      var $4=$1;
      var $5=(($4+8)|0);
      var $6=HEAPU8[($5)];
      var $7=(($6)&255);
      var $8=(($7)|0)!=3;
      if ($8) { __label__ = 3; break; } else { __label__ = 40; break; }
    case 3: 
      $channels=0;
      $value=0;
      var $10=$1;
      var $11=(($10)|0);
      var $12=HEAP32[(($11)>>2)];
      $row_width=$12;
      var $13=$1;
      var $14=(($13+8)|0);
      var $15=HEAPU8[($14)];
      var $16=(($15)&255);
      var $17=$16 & 2;
      var $18=(($17)|0)!=0;
      if ($18) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      var $20=$1;
      var $21=(($20+9)|0);
      var $22=HEAPU8[($21)];
      var $23=(($22)&255);
      var $24=$3;
      var $25=(($24)|0);
      var $26=HEAPU8[($25)];
      var $27=(($26)&255);
      var $28=((($23)-($27))|0);
      var $29=$channels;
      var $30=((($29)+(1))|0);
      $channels=$30;
      var $31=(($shift+($29<<2))|0);
      HEAP32[(($31)>>2)]=$28;
      var $32=$1;
      var $33=(($32+9)|0);
      var $34=HEAPU8[($33)];
      var $35=(($34)&255);
      var $36=$3;
      var $37=(($36+1)|0);
      var $38=HEAPU8[($37)];
      var $39=(($38)&255);
      var $40=((($35)-($39))|0);
      var $41=$channels;
      var $42=((($41)+(1))|0);
      $channels=$42;
      var $43=(($shift+($41<<2))|0);
      HEAP32[(($43)>>2)]=$40;
      var $44=$1;
      var $45=(($44+9)|0);
      var $46=HEAPU8[($45)];
      var $47=(($46)&255);
      var $48=$3;
      var $49=(($48+2)|0);
      var $50=HEAPU8[($49)];
      var $51=(($50)&255);
      var $52=((($47)-($51))|0);
      var $53=$channels;
      var $54=((($53)+(1))|0);
      $channels=$54;
      var $55=(($shift+($53<<2))|0);
      HEAP32[(($55)>>2)]=$52;
      __label__ = 6; break;
    case 5: 
      var $57=$1;
      var $58=(($57+9)|0);
      var $59=HEAPU8[($58)];
      var $60=(($59)&255);
      var $61=$3;
      var $62=(($61+3)|0);
      var $63=HEAPU8[($62)];
      var $64=(($63)&255);
      var $65=((($60)-($64))|0);
      var $66=$channels;
      var $67=((($66)+(1))|0);
      $channels=$67;
      var $68=(($shift+($66<<2))|0);
      HEAP32[(($68)>>2)]=$65;
      __label__ = 6; break;
    case 6: 
      var $70=$1;
      var $71=(($70+8)|0);
      var $72=HEAPU8[($71)];
      var $73=(($72)&255);
      var $74=$73 & 4;
      var $75=(($74)|0)!=0;
      if ($75) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $77=$1;
      var $78=(($77+9)|0);
      var $79=HEAPU8[($78)];
      var $80=(($79)&255);
      var $81=$3;
      var $82=(($81+4)|0);
      var $83=HEAPU8[($82)];
      var $84=(($83)&255);
      var $85=((($80)-($84))|0);
      var $86=$channels;
      var $87=((($86)+(1))|0);
      $channels=$87;
      var $88=(($shift+($86<<2))|0);
      HEAP32[(($88)>>2)]=$85;
      __label__ = 8; break;
    case 8: 
      $c=0;
      __label__ = 9; break;
    case 9: 
      var $91=$c;
      var $92=$channels;
      var $93=(($91)|0) < (($92)|0);
      if ($93) { __label__ = 10; break; } else { __label__ = 15; break; }
    case 10: 
      var $95=$c;
      var $96=(($shift+($95<<2))|0);
      var $97=HEAP32[(($96)>>2)];
      var $98=(($97)|0) <= 0;
      if ($98) { __label__ = 11; break; } else { __label__ = 12; break; }
    case 11: 
      var $100=$c;
      var $101=(($shift+($100<<2))|0);
      HEAP32[(($101)>>2)]=0;
      __label__ = 13; break;
    case 12: 
      $value=1;
      __label__ = 13; break;
    case 13: 
      __label__ = 14; break;
    case 14: 
      var $105=$c;
      var $106=((($105)+(1))|0);
      $c=$106;
      __label__ = 9; break;
    case 15: 
      var $108=$value;
      var $109=(($108 << 16) >> 16)!=0;
      if ($109) { __label__ = 17; break; } else { __label__ = 16; break; }
    case 16: 
      __label__ = 40; break;
    case 17: 
      var $112=$1;
      var $113=(($112+9)|0);
      var $114=HEAPU8[($113)];
      var $115=(($114)&255);
      if ((($115)|0) == 2) {
        __label__ = 19; break;
      }
      else if ((($115)|0) == 4) {
        __label__ = 24; break;
      }
      else if ((($115)|0) == 8) {
        __label__ = 29; break;
      }
      else if ((($115)|0) == 16) {
        __label__ = 34; break;
      }
      else {
      __label__ = 18; break;
      }
      
    case 18: 
      __label__ = 39; break;
    case 19: 
      var $118=$1;
      var $119=(($118+4)|0);
      var $120=HEAP32[(($119)>>2)];
      $istop=$120;
      var $121=$2;
      $bp=$121;
      $i=0;
      __label__ = 20; break;
    case 20: 
      var $123=$i;
      var $124=$istop;
      var $125=(($123)>>>0) < (($124)>>>0);
      if ($125) { __label__ = 21; break; } else { __label__ = 23; break; }
    case 21: 
      var $127=$bp;
      var $128=HEAPU8[($127)];
      var $129=(($128)&255);
      var $130=$129 >> 1;
      var $131=(($130) & 255);
      HEAP8[($127)]=$131;
      var $132=$bp;
      var $133=(($132+1)|0);
      $bp=$133;
      var $134=HEAPU8[($132)];
      var $135=(($134)&255);
      var $136=$135 & 85;
      var $137=(($136) & 255);
      HEAP8[($132)]=$137;
      __label__ = 22; break;
    case 22: 
      var $139=$i;
      var $140=((($139)+(1))|0);
      $i=$140;
      __label__ = 20; break;
    case 23: 
      __label__ = 39; break;
    case 24: 
      var $143=$2;
      $bp1=$143;
      var $144=$1;
      var $145=(($144+4)|0);
      var $146=HEAP32[(($145)>>2)];
      $istop3=$146;
      var $147=(($shift)|0);
      var $148=HEAP32[(($147)>>2)];
      var $149=240 >> (($148)|0);
      var $150=$149 & 240;
      var $151=(($shift)|0);
      var $152=HEAP32[(($151)>>2)];
      var $153=15 >> (($152)|0);
      var $154=(($153) & 255);
      var $155=(($154)&255);
      var $156=$150 | $155;
      var $157=(($156) & 255);
      $mask=$157;
      $i2=0;
      __label__ = 25; break;
    case 25: 
      var $159=$i2;
      var $160=$istop3;
      var $161=(($159)>>>0) < (($160)>>>0);
      if ($161) { __label__ = 26; break; } else { __label__ = 28; break; }
    case 26: 
      var $163=(($shift)|0);
      var $164=HEAP32[(($163)>>2)];
      var $165=$bp1;
      var $166=HEAPU8[($165)];
      var $167=(($166)&255);
      var $168=$167 >> (($164)|0);
      var $169=(($168) & 255);
      HEAP8[($165)]=$169;
      var $170=$mask;
      var $171=(($170)&255);
      var $172=$bp1;
      var $173=(($172+1)|0);
      $bp1=$173;
      var $174=HEAPU8[($172)];
      var $175=(($174)&255);
      var $176=$175 & $171;
      var $177=(($176) & 255);
      HEAP8[($172)]=$177;
      __label__ = 27; break;
    case 27: 
      var $179=$i2;
      var $180=((($179)+(1))|0);
      $i2=$180;
      __label__ = 25; break;
    case 28: 
      __label__ = 39; break;
    case 29: 
      var $183=$2;
      $bp4=$183;
      var $184=$row_width;
      var $185=$channels;
      var $186=((($184)*($185))|0);
      $istop6=$186;
      $i5=0;
      __label__ = 30; break;
    case 30: 
      var $188=$i5;
      var $189=$istop6;
      var $190=(($188)>>>0) < (($189)>>>0);
      if ($190) { __label__ = 31; break; } else { __label__ = 33; break; }
    case 31: 
      var $192=$i5;
      var $193=$channels;
      var $194=((($192)>>>0))%((($193)>>>0));
      var $195=(($shift+($194<<2))|0);
      var $196=HEAP32[(($195)>>2)];
      var $197=$bp4;
      var $198=(($197+1)|0);
      $bp4=$198;
      var $199=HEAPU8[($197)];
      var $200=(($199)&255);
      var $201=$200 >> (($196)|0);
      var $202=(($201) & 255);
      HEAP8[($197)]=$202;
      __label__ = 32; break;
    case 32: 
      var $204=$i5;
      var $205=((($204)+(1))|0);
      $i5=$205;
      __label__ = 30; break;
    case 33: 
      __label__ = 39; break;
    case 34: 
      var $208=$2;
      $bp7=$208;
      var $209=$channels;
      var $210=$row_width;
      var $211=((($209)*($210))|0);
      $istop9=$211;
      $i8=0;
      __label__ = 35; break;
    case 35: 
      var $213=$i8;
      var $214=$istop9;
      var $215=(($213)>>>0) < (($214)>>>0);
      if ($215) { __label__ = 36; break; } else { __label__ = 38; break; }
    case 36: 
      var $217=$bp7;
      var $218=HEAPU8[($217)];
      var $219=(($218)&255);
      var $220=$219 << 8;
      var $221=$bp7;
      var $222=(($221+1)|0);
      var $223=HEAPU8[($222)];
      var $224=(($223)&255);
      var $225=((($220)+($224))|0);
      var $226=(($225) & 65535);
      $value=$226;
      var $227=$i8;
      var $228=$channels;
      var $229=((($227)>>>0))%((($228)>>>0));
      var $230=(($shift+($229<<2))|0);
      var $231=HEAP32[(($230)>>2)];
      var $232=$value;
      var $233=(($232)&65535);
      var $234=$233 >> (($231)|0);
      var $235=(($234) & 65535);
      $value=$235;
      var $236=$value;
      var $237=(($236)&65535);
      var $238=$237 >> 8;
      var $239=(($238) & 255);
      var $240=$bp7;
      var $241=(($240+1)|0);
      $bp7=$241;
      HEAP8[($240)]=$239;
      var $242=$value;
      var $243=(($242)&65535);
      var $244=$243 & 255;
      var $245=(($244) & 255);
      var $246=$bp7;
      var $247=(($246+1)|0);
      $bp7=$247;
      HEAP8[($246)]=$245;
      __label__ = 37; break;
    case 37: 
      var $249=$i8;
      var $250=((($249)+(1))|0);
      $i8=$250;
      __label__ = 35; break;
    case 38: 
      __label__ = 39; break;
    case 39: 
      __label__ = 40; break;
    case 40: 
      STACKTOP = __stackBase__;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_png_do_unshift["X"]=1;

function _png_do_unpack($row_info, $row) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $i;
      var $row_width;
      var $sp;
      var $dp;
      var $shift;
      var $sp1;
      var $dp2;
      var $shift3;
      var $sp4;
      var $dp5;
      var $shift6;
      $1=$row_info;
      $2=$row;
      var $3=$1;
      var $4=(($3+9)|0);
      var $5=HEAPU8[($4)];
      var $6=(($5)&255);
      var $7=(($6)|0) < 8;
      if ($7) { __label__ = 3; break; } else { __label__ = 30; break; }
    case 3: 
      var $9=$1;
      var $10=(($9)|0);
      var $11=HEAP32[(($10)>>2)];
      $row_width=$11;
      var $12=$1;
      var $13=(($12+9)|0);
      var $14=HEAPU8[($13)];
      var $15=(($14)&255);
      if ((($15)|0) == 1) {
        __label__ = 4; break;
      }
      else if ((($15)|0) == 2) {
        __label__ = 12; break;
      }
      else if ((($15)|0) == 4) {
        __label__ = 20; break;
      }
      else {
      __label__ = 28; break;
      }
      
    case 4: 
      var $17=$2;
      var $18=$row_width;
      var $19=((($18)-(1))|0);
      var $20=$19 >>> 3;
      var $21=(($17+$20)|0);
      $sp=$21;
      var $22=$2;
      var $23=$row_width;
      var $24=(($22+$23)|0);
      var $25=((($24)-(1))|0);
      $dp=$25;
      var $26=$row_width;
      var $27=((($26)+(7))|0);
      var $28=$27 & 7;
      var $29=(((7)-($28))|0);
      $shift=$29;
      $i=0;
      __label__ = 5; break;
    case 5: 
      var $31=$i;
      var $32=$row_width;
      var $33=(($31)>>>0) < (($32)>>>0);
      if ($33) { __label__ = 6; break; } else { __label__ = 11; break; }
    case 6: 
      var $35=$sp;
      var $36=HEAPU8[($35)];
      var $37=(($36)&255);
      var $38=$shift;
      var $39=$37 >> (($38)|0);
      var $40=$39 & 1;
      var $41=(($40) & 255);
      var $42=$dp;
      HEAP8[($42)]=$41;
      var $43=$shift;
      var $44=(($43)|0)==7;
      if ($44) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      $shift=0;
      var $46=$sp;
      var $47=((($46)-(1))|0);
      $sp=$47;
      __label__ = 9; break;
    case 8: 
      var $49=$shift;
      var $50=((($49)+(1))|0);
      $shift=$50;
      __label__ = 9; break;
    case 9: 
      var $52=$dp;
      var $53=((($52)-(1))|0);
      $dp=$53;
      __label__ = 10; break;
    case 10: 
      var $55=$i;
      var $56=((($55)+(1))|0);
      $i=$56;
      __label__ = 5; break;
    case 11: 
      __label__ = 29; break;
    case 12: 
      var $59=$2;
      var $60=$row_width;
      var $61=((($60)-(1))|0);
      var $62=$61 >>> 2;
      var $63=(($59+$62)|0);
      $sp1=$63;
      var $64=$2;
      var $65=$row_width;
      var $66=(($64+$65)|0);
      var $67=((($66)-(1))|0);
      $dp2=$67;
      var $68=$row_width;
      var $69=((($68)+(3))|0);
      var $70=$69 & 3;
      var $71=(((3)-($70))|0);
      var $72=$71 << 1;
      $shift3=$72;
      $i=0;
      __label__ = 13; break;
    case 13: 
      var $74=$i;
      var $75=$row_width;
      var $76=(($74)>>>0) < (($75)>>>0);
      if ($76) { __label__ = 14; break; } else { __label__ = 19; break; }
    case 14: 
      var $78=$sp1;
      var $79=HEAPU8[($78)];
      var $80=(($79)&255);
      var $81=$shift3;
      var $82=$80 >> (($81)|0);
      var $83=$82 & 3;
      var $84=(($83) & 255);
      var $85=$dp2;
      HEAP8[($85)]=$84;
      var $86=$shift3;
      var $87=(($86)|0)==6;
      if ($87) { __label__ = 15; break; } else { __label__ = 16; break; }
    case 15: 
      $shift3=0;
      var $89=$sp1;
      var $90=((($89)-(1))|0);
      $sp1=$90;
      __label__ = 17; break;
    case 16: 
      var $92=$shift3;
      var $93=((($92)+(2))|0);
      $shift3=$93;
      __label__ = 17; break;
    case 17: 
      var $95=$dp2;
      var $96=((($95)-(1))|0);
      $dp2=$96;
      __label__ = 18; break;
    case 18: 
      var $98=$i;
      var $99=((($98)+(1))|0);
      $i=$99;
      __label__ = 13; break;
    case 19: 
      __label__ = 29; break;
    case 20: 
      var $102=$2;
      var $103=$row_width;
      var $104=((($103)-(1))|0);
      var $105=$104 >>> 1;
      var $106=(($102+$105)|0);
      $sp4=$106;
      var $107=$2;
      var $108=$row_width;
      var $109=(($107+$108)|0);
      var $110=((($109)-(1))|0);
      $dp5=$110;
      var $111=$row_width;
      var $112=((($111)+(1))|0);
      var $113=$112 & 1;
      var $114=(((1)-($113))|0);
      var $115=$114 << 2;
      $shift6=$115;
      $i=0;
      __label__ = 21; break;
    case 21: 
      var $117=$i;
      var $118=$row_width;
      var $119=(($117)>>>0) < (($118)>>>0);
      if ($119) { __label__ = 22; break; } else { __label__ = 27; break; }
    case 22: 
      var $121=$sp4;
      var $122=HEAPU8[($121)];
      var $123=(($122)&255);
      var $124=$shift6;
      var $125=$123 >> (($124)|0);
      var $126=$125 & 15;
      var $127=(($126) & 255);
      var $128=$dp5;
      HEAP8[($128)]=$127;
      var $129=$shift6;
      var $130=(($129)|0)==4;
      if ($130) { __label__ = 23; break; } else { __label__ = 24; break; }
    case 23: 
      $shift6=0;
      var $132=$sp4;
      var $133=((($132)-(1))|0);
      $sp4=$133;
      __label__ = 25; break;
    case 24: 
      $shift6=4;
      __label__ = 25; break;
    case 25: 
      var $136=$dp5;
      var $137=((($136)-(1))|0);
      $dp5=$137;
      __label__ = 26; break;
    case 26: 
      var $139=$i;
      var $140=((($139)+(1))|0);
      $i=$140;
      __label__ = 21; break;
    case 27: 
      __label__ = 29; break;
    case 28: 
      __label__ = 29; break;
    case 29: 
      var $144=$1;
      var $145=(($144+9)|0);
      HEAP8[($145)]=8;
      var $146=$1;
      var $147=(($146+10)|0);
      var $148=HEAPU8[($147)];
      var $149=(($148)&255);
      var $150=((($149<<3))|0);
      var $151=(($150) & 255);
      var $152=$1;
      var $153=(($152+11)|0);
      HEAP8[($153)]=$151;
      var $154=$row_width;
      var $155=$1;
      var $156=(($155+10)|0);
      var $157=HEAPU8[($156)];
      var $158=(($157)&255);
      var $159=((($154)*($158))|0);
      var $160=$1;
      var $161=(($160+4)|0);
      HEAP32[(($161)>>2)]=$159;
      __label__ = 30; break;
    case 30: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_png_do_unpack["X"]=1;

function _png_do_read_filler($row_info, $row, $filler, $flags) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $i;
      var $row_width;
      var $hi_filler;
      var $lo_filler;
      var $sp;
      var $dp;
      var $sp1;
      var $dp2;
      var $sp3;
      var $dp4;
      var $sp5;
      var $dp6;
      var $sp7;
      var $dp8;
      var $sp9;
      var $dp10;
      var $sp11;
      var $dp12;
      var $sp13;
      var $dp14;
      $1=$row_info;
      $2=$row;
      $3=$filler;
      $4=$flags;
      var $5=$1;
      var $6=(($5)|0);
      var $7=HEAP32[(($6)>>2)];
      $row_width=$7;
      var $8=$3;
      var $9=$8 >>> 8;
      var $10=$9 & 255;
      var $11=(($10) & 255);
      $hi_filler=$11;
      var $12=$3;
      var $13=$12 & 255;
      var $14=(($13) & 255);
      $lo_filler=$14;
      var $15=$1;
      var $16=(($15+8)|0);
      var $17=HEAPU8[($16)];
      var $18=(($17)&255);
      var $19=(($18)|0)==0;
      if ($19) { __label__ = 3; break; } else { __label__ = 31; break; }
    case 3: 
      var $21=$1;
      var $22=(($21+9)|0);
      var $23=HEAPU8[($22)];
      var $24=(($23)&255);
      var $25=(($24)|0)==8;
      if ($25) { __label__ = 4; break; } else { __label__ = 16; break; }
    case 4: 
      var $27=$4;
      var $28=$27 & 128;
      var $29=(($28)|0)!=0;
      if ($29) { __label__ = 5; break; } else { __label__ = 10; break; }
    case 5: 
      var $31=$2;
      var $32=$row_width;
      var $33=(($31+$32)|0);
      $sp=$33;
      var $34=$sp;
      var $35=$row_width;
      var $36=(($34+$35)|0);
      $dp=$36;
      $i=1;
      __label__ = 6; break;
    case 6: 
      var $38=$i;
      var $39=$row_width;
      var $40=(($38)>>>0) < (($39)>>>0);
      if ($40) { __label__ = 7; break; } else { __label__ = 9; break; }
    case 7: 
      var $42=$lo_filler;
      var $43=$dp;
      var $44=((($43)-(1))|0);
      $dp=$44;
      HEAP8[($44)]=$42;
      var $45=$sp;
      var $46=((($45)-(1))|0);
      $sp=$46;
      var $47=HEAP8[($46)];
      var $48=$dp;
      var $49=((($48)-(1))|0);
      $dp=$49;
      HEAP8[($49)]=$47;
      __label__ = 8; break;
    case 8: 
      var $51=$i;
      var $52=((($51)+(1))|0);
      $i=$52;
      __label__ = 6; break;
    case 9: 
      var $54=$lo_filler;
      var $55=$dp;
      var $56=((($55)-(1))|0);
      $dp=$56;
      HEAP8[($56)]=$54;
      var $57=$1;
      var $58=(($57+10)|0);
      HEAP8[($58)]=2;
      var $59=$1;
      var $60=(($59+11)|0);
      HEAP8[($60)]=16;
      var $61=$row_width;
      var $62=((($61<<1))|0);
      var $63=$1;
      var $64=(($63+4)|0);
      HEAP32[(($64)>>2)]=$62;
      __label__ = 15; break;
    case 10: 
      var $66=$2;
      var $67=$row_width;
      var $68=(($66+$67)|0);
      $sp1=$68;
      var $69=$sp1;
      var $70=$row_width;
      var $71=(($69+$70)|0);
      $dp2=$71;
      $i=0;
      __label__ = 11; break;
    case 11: 
      var $73=$i;
      var $74=$row_width;
      var $75=(($73)>>>0) < (($74)>>>0);
      if ($75) { __label__ = 12; break; } else { __label__ = 14; break; }
    case 12: 
      var $77=$sp1;
      var $78=((($77)-(1))|0);
      $sp1=$78;
      var $79=HEAP8[($78)];
      var $80=$dp2;
      var $81=((($80)-(1))|0);
      $dp2=$81;
      HEAP8[($81)]=$79;
      var $82=$lo_filler;
      var $83=$dp2;
      var $84=((($83)-(1))|0);
      $dp2=$84;
      HEAP8[($84)]=$82;
      __label__ = 13; break;
    case 13: 
      var $86=$i;
      var $87=((($86)+(1))|0);
      $i=$87;
      __label__ = 11; break;
    case 14: 
      var $89=$1;
      var $90=(($89+10)|0);
      HEAP8[($90)]=2;
      var $91=$1;
      var $92=(($91+11)|0);
      HEAP8[($92)]=16;
      var $93=$row_width;
      var $94=((($93<<1))|0);
      var $95=$1;
      var $96=(($95+4)|0);
      HEAP32[(($96)>>2)]=$94;
      __label__ = 15; break;
    case 15: 
      __label__ = 30; break;
    case 16: 
      var $99=$1;
      var $100=(($99+9)|0);
      var $101=HEAPU8[($100)];
      var $102=(($101)&255);
      var $103=(($102)|0)==16;
      if ($103) { __label__ = 17; break; } else { __label__ = 29; break; }
    case 17: 
      var $105=$4;
      var $106=$105 & 128;
      var $107=(($106)|0)!=0;
      if ($107) { __label__ = 18; break; } else { __label__ = 23; break; }
    case 18: 
      var $109=$2;
      var $110=$row_width;
      var $111=((($110<<1))|0);
      var $112=(($109+$111)|0);
      $sp3=$112;
      var $113=$sp3;
      var $114=$row_width;
      var $115=((($114<<1))|0);
      var $116=(($113+$115)|0);
      $dp4=$116;
      $i=1;
      __label__ = 19; break;
    case 19: 
      var $118=$i;
      var $119=$row_width;
      var $120=(($118)>>>0) < (($119)>>>0);
      if ($120) { __label__ = 20; break; } else { __label__ = 22; break; }
    case 20: 
      var $122=$hi_filler;
      var $123=$dp4;
      var $124=((($123)-(1))|0);
      $dp4=$124;
      HEAP8[($124)]=$122;
      var $125=$lo_filler;
      var $126=$dp4;
      var $127=((($126)-(1))|0);
      $dp4=$127;
      HEAP8[($127)]=$125;
      var $128=$sp3;
      var $129=((($128)-(1))|0);
      $sp3=$129;
      var $130=HEAP8[($129)];
      var $131=$dp4;
      var $132=((($131)-(1))|0);
      $dp4=$132;
      HEAP8[($132)]=$130;
      var $133=$sp3;
      var $134=((($133)-(1))|0);
      $sp3=$134;
      var $135=HEAP8[($134)];
      var $136=$dp4;
      var $137=((($136)-(1))|0);
      $dp4=$137;
      HEAP8[($137)]=$135;
      __label__ = 21; break;
    case 21: 
      var $139=$i;
      var $140=((($139)+(1))|0);
      $i=$140;
      __label__ = 19; break;
    case 22: 
      var $142=$hi_filler;
      var $143=$dp4;
      var $144=((($143)-(1))|0);
      $dp4=$144;
      HEAP8[($144)]=$142;
      var $145=$lo_filler;
      var $146=$dp4;
      var $147=((($146)-(1))|0);
      $dp4=$147;
      HEAP8[($147)]=$145;
      var $148=$1;
      var $149=(($148+10)|0);
      HEAP8[($149)]=2;
      var $150=$1;
      var $151=(($150+11)|0);
      HEAP8[($151)]=32;
      var $152=$row_width;
      var $153=((($152<<2))|0);
      var $154=$1;
      var $155=(($154+4)|0);
      HEAP32[(($155)>>2)]=$153;
      __label__ = 28; break;
    case 23: 
      var $157=$2;
      var $158=$row_width;
      var $159=((($158<<1))|0);
      var $160=(($157+$159)|0);
      $sp5=$160;
      var $161=$sp5;
      var $162=$row_width;
      var $163=((($162<<1))|0);
      var $164=(($161+$163)|0);
      $dp6=$164;
      $i=0;
      __label__ = 24; break;
    case 24: 
      var $166=$i;
      var $167=$row_width;
      var $168=(($166)>>>0) < (($167)>>>0);
      if ($168) { __label__ = 25; break; } else { __label__ = 27; break; }
    case 25: 
      var $170=$sp5;
      var $171=((($170)-(1))|0);
      $sp5=$171;
      var $172=HEAP8[($171)];
      var $173=$dp6;
      var $174=((($173)-(1))|0);
      $dp6=$174;
      HEAP8[($174)]=$172;
      var $175=$sp5;
      var $176=((($175)-(1))|0);
      $sp5=$176;
      var $177=HEAP8[($176)];
      var $178=$dp6;
      var $179=((($178)-(1))|0);
      $dp6=$179;
      HEAP8[($179)]=$177;
      var $180=$hi_filler;
      var $181=$dp6;
      var $182=((($181)-(1))|0);
      $dp6=$182;
      HEAP8[($182)]=$180;
      var $183=$lo_filler;
      var $184=$dp6;
      var $185=((($184)-(1))|0);
      $dp6=$185;
      HEAP8[($185)]=$183;
      __label__ = 26; break;
    case 26: 
      var $187=$i;
      var $188=((($187)+(1))|0);
      $i=$188;
      __label__ = 24; break;
    case 27: 
      var $190=$1;
      var $191=(($190+10)|0);
      HEAP8[($191)]=2;
      var $192=$1;
      var $193=(($192+11)|0);
      HEAP8[($193)]=32;
      var $194=$row_width;
      var $195=((($194<<2))|0);
      var $196=$1;
      var $197=(($196+4)|0);
      HEAP32[(($197)>>2)]=$195;
      __label__ = 28; break;
    case 28: 
      __label__ = 29; break;
    case 29: 
      __label__ = 30; break;
    case 30: 
      __label__ = 61; break;
    case 31: 
      var $202=$1;
      var $203=(($202+8)|0);
      var $204=HEAPU8[($203)];
      var $205=(($204)&255);
      var $206=(($205)|0)==2;
      if ($206) { __label__ = 32; break; } else { __label__ = 60; break; }
    case 32: 
      var $208=$1;
      var $209=(($208+9)|0);
      var $210=HEAPU8[($209)];
      var $211=(($210)&255);
      var $212=(($211)|0)==8;
      if ($212) { __label__ = 33; break; } else { __label__ = 45; break; }
    case 33: 
      var $214=$4;
      var $215=$214 & 128;
      var $216=(($215)|0)!=0;
      if ($216) { __label__ = 34; break; } else { __label__ = 39; break; }
    case 34: 
      var $218=$2;
      var $219=$row_width;
      var $220=((($219)*(3))|0);
      var $221=(($218+$220)|0);
      $sp7=$221;
      var $222=$sp7;
      var $223=$row_width;
      var $224=(($222+$223)|0);
      $dp8=$224;
      $i=1;
      __label__ = 35; break;
    case 35: 
      var $226=$i;
      var $227=$row_width;
      var $228=(($226)>>>0) < (($227)>>>0);
      if ($228) { __label__ = 36; break; } else { __label__ = 38; break; }
    case 36: 
      var $230=$lo_filler;
      var $231=$dp8;
      var $232=((($231)-(1))|0);
      $dp8=$232;
      HEAP8[($232)]=$230;
      var $233=$sp7;
      var $234=((($233)-(1))|0);
      $sp7=$234;
      var $235=HEAP8[($234)];
      var $236=$dp8;
      var $237=((($236)-(1))|0);
      $dp8=$237;
      HEAP8[($237)]=$235;
      var $238=$sp7;
      var $239=((($238)-(1))|0);
      $sp7=$239;
      var $240=HEAP8[($239)];
      var $241=$dp8;
      var $242=((($241)-(1))|0);
      $dp8=$242;
      HEAP8[($242)]=$240;
      var $243=$sp7;
      var $244=((($243)-(1))|0);
      $sp7=$244;
      var $245=HEAP8[($244)];
      var $246=$dp8;
      var $247=((($246)-(1))|0);
      $dp8=$247;
      HEAP8[($247)]=$245;
      __label__ = 37; break;
    case 37: 
      var $249=$i;
      var $250=((($249)+(1))|0);
      $i=$250;
      __label__ = 35; break;
    case 38: 
      var $252=$lo_filler;
      var $253=$dp8;
      var $254=((($253)-(1))|0);
      $dp8=$254;
      HEAP8[($254)]=$252;
      var $255=$1;
      var $256=(($255+10)|0);
      HEAP8[($256)]=4;
      var $257=$1;
      var $258=(($257+11)|0);
      HEAP8[($258)]=32;
      var $259=$row_width;
      var $260=((($259<<2))|0);
      var $261=$1;
      var $262=(($261+4)|0);
      HEAP32[(($262)>>2)]=$260;
      __label__ = 44; break;
    case 39: 
      var $264=$2;
      var $265=$row_width;
      var $266=((($265)*(3))|0);
      var $267=(($264+$266)|0);
      $sp9=$267;
      var $268=$sp9;
      var $269=$row_width;
      var $270=(($268+$269)|0);
      $dp10=$270;
      $i=0;
      __label__ = 40; break;
    case 40: 
      var $272=$i;
      var $273=$row_width;
      var $274=(($272)>>>0) < (($273)>>>0);
      if ($274) { __label__ = 41; break; } else { __label__ = 43; break; }
    case 41: 
      var $276=$sp9;
      var $277=((($276)-(1))|0);
      $sp9=$277;
      var $278=HEAP8[($277)];
      var $279=$dp10;
      var $280=((($279)-(1))|0);
      $dp10=$280;
      HEAP8[($280)]=$278;
      var $281=$sp9;
      var $282=((($281)-(1))|0);
      $sp9=$282;
      var $283=HEAP8[($282)];
      var $284=$dp10;
      var $285=((($284)-(1))|0);
      $dp10=$285;
      HEAP8[($285)]=$283;
      var $286=$sp9;
      var $287=((($286)-(1))|0);
      $sp9=$287;
      var $288=HEAP8[($287)];
      var $289=$dp10;
      var $290=((($289)-(1))|0);
      $dp10=$290;
      HEAP8[($290)]=$288;
      var $291=$lo_filler;
      var $292=$dp10;
      var $293=((($292)-(1))|0);
      $dp10=$293;
      HEAP8[($293)]=$291;
      __label__ = 42; break;
    case 42: 
      var $295=$i;
      var $296=((($295)+(1))|0);
      $i=$296;
      __label__ = 40; break;
    case 43: 
      var $298=$1;
      var $299=(($298+10)|0);
      HEAP8[($299)]=4;
      var $300=$1;
      var $301=(($300+11)|0);
      HEAP8[($301)]=32;
      var $302=$row_width;
      var $303=((($302<<2))|0);
      var $304=$1;
      var $305=(($304+4)|0);
      HEAP32[(($305)>>2)]=$303;
      __label__ = 44; break;
    case 44: 
      __label__ = 59; break;
    case 45: 
      var $308=$1;
      var $309=(($308+9)|0);
      var $310=HEAPU8[($309)];
      var $311=(($310)&255);
      var $312=(($311)|0)==16;
      if ($312) { __label__ = 46; break; } else { __label__ = 58; break; }
    case 46: 
      var $314=$4;
      var $315=$314 & 128;
      var $316=(($315)|0)!=0;
      if ($316) { __label__ = 47; break; } else { __label__ = 52; break; }
    case 47: 
      var $318=$2;
      var $319=$row_width;
      var $320=((($319)*(6))|0);
      var $321=(($318+$320)|0);
      $sp11=$321;
      var $322=$sp11;
      var $323=$row_width;
      var $324=((($323<<1))|0);
      var $325=(($322+$324)|0);
      $dp12=$325;
      $i=1;
      __label__ = 48; break;
    case 48: 
      var $327=$i;
      var $328=$row_width;
      var $329=(($327)>>>0) < (($328)>>>0);
      if ($329) { __label__ = 49; break; } else { __label__ = 51; break; }
    case 49: 
      var $331=$hi_filler;
      var $332=$dp12;
      var $333=((($332)-(1))|0);
      $dp12=$333;
      HEAP8[($333)]=$331;
      var $334=$lo_filler;
      var $335=$dp12;
      var $336=((($335)-(1))|0);
      $dp12=$336;
      HEAP8[($336)]=$334;
      var $337=$sp11;
      var $338=((($337)-(1))|0);
      $sp11=$338;
      var $339=HEAP8[($338)];
      var $340=$dp12;
      var $341=((($340)-(1))|0);
      $dp12=$341;
      HEAP8[($341)]=$339;
      var $342=$sp11;
      var $343=((($342)-(1))|0);
      $sp11=$343;
      var $344=HEAP8[($343)];
      var $345=$dp12;
      var $346=((($345)-(1))|0);
      $dp12=$346;
      HEAP8[($346)]=$344;
      var $347=$sp11;
      var $348=((($347)-(1))|0);
      $sp11=$348;
      var $349=HEAP8[($348)];
      var $350=$dp12;
      var $351=((($350)-(1))|0);
      $dp12=$351;
      HEAP8[($351)]=$349;
      var $352=$sp11;
      var $353=((($352)-(1))|0);
      $sp11=$353;
      var $354=HEAP8[($353)];
      var $355=$dp12;
      var $356=((($355)-(1))|0);
      $dp12=$356;
      HEAP8[($356)]=$354;
      var $357=$sp11;
      var $358=((($357)-(1))|0);
      $sp11=$358;
      var $359=HEAP8[($358)];
      var $360=$dp12;
      var $361=((($360)-(1))|0);
      $dp12=$361;
      HEAP8[($361)]=$359;
      var $362=$sp11;
      var $363=((($362)-(1))|0);
      $sp11=$363;
      var $364=HEAP8[($363)];
      var $365=$dp12;
      var $366=((($365)-(1))|0);
      $dp12=$366;
      HEAP8[($366)]=$364;
      __label__ = 50; break;
    case 50: 
      var $368=$i;
      var $369=((($368)+(1))|0);
      $i=$369;
      __label__ = 48; break;
    case 51: 
      var $371=$hi_filler;
      var $372=$dp12;
      var $373=((($372)-(1))|0);
      $dp12=$373;
      HEAP8[($373)]=$371;
      var $374=$lo_filler;
      var $375=$dp12;
      var $376=((($375)-(1))|0);
      $dp12=$376;
      HEAP8[($376)]=$374;
      var $377=$1;
      var $378=(($377+10)|0);
      HEAP8[($378)]=4;
      var $379=$1;
      var $380=(($379+11)|0);
      HEAP8[($380)]=64;
      var $381=$row_width;
      var $382=((($381<<3))|0);
      var $383=$1;
      var $384=(($383+4)|0);
      HEAP32[(($384)>>2)]=$382;
      __label__ = 57; break;
    case 52: 
      var $386=$2;
      var $387=$row_width;
      var $388=((($387)*(6))|0);
      var $389=(($386+$388)|0);
      $sp13=$389;
      var $390=$sp13;
      var $391=$row_width;
      var $392=((($391<<1))|0);
      var $393=(($390+$392)|0);
      $dp14=$393;
      $i=0;
      __label__ = 53; break;
    case 53: 
      var $395=$i;
      var $396=$row_width;
      var $397=(($395)>>>0) < (($396)>>>0);
      if ($397) { __label__ = 54; break; } else { __label__ = 56; break; }
    case 54: 
      var $399=$sp13;
      var $400=((($399)-(1))|0);
      $sp13=$400;
      var $401=HEAP8[($400)];
      var $402=$dp14;
      var $403=((($402)-(1))|0);
      $dp14=$403;
      HEAP8[($403)]=$401;
      var $404=$sp13;
      var $405=((($404)-(1))|0);
      $sp13=$405;
      var $406=HEAP8[($405)];
      var $407=$dp14;
      var $408=((($407)-(1))|0);
      $dp14=$408;
      HEAP8[($408)]=$406;
      var $409=$sp13;
      var $410=((($409)-(1))|0);
      $sp13=$410;
      var $411=HEAP8[($410)];
      var $412=$dp14;
      var $413=((($412)-(1))|0);
      $dp14=$413;
      HEAP8[($413)]=$411;
      var $414=$sp13;
      var $415=((($414)-(1))|0);
      $sp13=$415;
      var $416=HEAP8[($415)];
      var $417=$dp14;
      var $418=((($417)-(1))|0);
      $dp14=$418;
      HEAP8[($418)]=$416;
      var $419=$sp13;
      var $420=((($419)-(1))|0);
      $sp13=$420;
      var $421=HEAP8[($420)];
      var $422=$dp14;
      var $423=((($422)-(1))|0);
      $dp14=$423;
      HEAP8[($423)]=$421;
      var $424=$sp13;
      var $425=((($424)-(1))|0);
      $sp13=$425;
      var $426=HEAP8[($425)];
      var $427=$dp14;
      var $428=((($427)-(1))|0);
      $dp14=$428;
      HEAP8[($428)]=$426;
      var $429=$hi_filler;
      var $430=$dp14;
      var $431=((($430)-(1))|0);
      $dp14=$431;
      HEAP8[($431)]=$429;
      var $432=$lo_filler;
      var $433=$dp14;
      var $434=((($433)-(1))|0);
      $dp14=$434;
      HEAP8[($434)]=$432;
      __label__ = 55; break;
    case 55: 
      var $436=$i;
      var $437=((($436)+(1))|0);
      $i=$437;
      __label__ = 53; break;
    case 56: 
      var $439=$1;
      var $440=(($439+10)|0);
      HEAP8[($440)]=4;
      var $441=$1;
      var $442=(($441+11)|0);
      HEAP8[($442)]=64;
      var $443=$row_width;
      var $444=((($443<<3))|0);
      var $445=$1;
      var $446=(($445+4)|0);
      HEAP32[(($446)>>2)]=$444;
      __label__ = 57; break;
    case 57: 
      __label__ = 58; break;
    case 58: 
      __label__ = 59; break;
    case 59: 
      __label__ = 60; break;
    case 60: 
      __label__ = 61; break;
    case 61: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_png_do_read_filler["X"]=1;

function _png_do_read_invert_alpha($row_info, $row) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $row_width;
      var $sp;
      var $dp;
      var $i;
      var $sp1;
      var $dp2;
      var $i3;
      var $sp4;
      var $dp5;
      var $i6;
      var $sp7;
      var $dp8;
      var $i9;
      $1=$row_info;
      $2=$row;
      var $3=$1;
      var $4=(($3)|0);
      var $5=HEAP32[(($4)>>2)];
      $row_width=$5;
      var $6=$1;
      var $7=(($6+8)|0);
      var $8=HEAPU8[($7)];
      var $9=(($8)&255);
      var $10=(($9)|0)==6;
      if ($10) { __label__ = 3; break; } else { __label__ = 15; break; }
    case 3: 
      var $12=$1;
      var $13=(($12+9)|0);
      var $14=HEAPU8[($13)];
      var $15=(($14)&255);
      var $16=(($15)|0)==8;
      if ($16) { __label__ = 4; break; } else { __label__ = 9; break; }
    case 4: 
      var $18=$2;
      var $19=$1;
      var $20=(($19+4)|0);
      var $21=HEAP32[(($20)>>2)];
      var $22=(($18+$21)|0);
      $sp=$22;
      var $23=$sp;
      $dp=$23;
      $i=0;
      __label__ = 5; break;
    case 5: 
      var $25=$i;
      var $26=$row_width;
      var $27=(($25)>>>0) < (($26)>>>0);
      if ($27) { __label__ = 6; break; } else { __label__ = 8; break; }
    case 6: 
      var $29=$sp;
      var $30=((($29)-(1))|0);
      $sp=$30;
      var $31=HEAPU8[($30)];
      var $32=(($31)&255);
      var $33=(((255)-($32))|0);
      var $34=(($33) & 255);
      var $35=$dp;
      var $36=((($35)-(1))|0);
      $dp=$36;
      HEAP8[($36)]=$34;
      var $37=$sp;
      var $38=((($37)-(3))|0);
      $sp=$38;
      var $39=$sp;
      $dp=$39;
      __label__ = 7; break;
    case 7: 
      var $41=$i;
      var $42=((($41)+(1))|0);
      $i=$42;
      __label__ = 5; break;
    case 8: 
      __label__ = 14; break;
    case 9: 
      var $45=$2;
      var $46=$1;
      var $47=(($46+4)|0);
      var $48=HEAP32[(($47)>>2)];
      var $49=(($45+$48)|0);
      $sp1=$49;
      var $50=$sp1;
      $dp2=$50;
      $i3=0;
      __label__ = 10; break;
    case 10: 
      var $52=$i3;
      var $53=$row_width;
      var $54=(($52)>>>0) < (($53)>>>0);
      if ($54) { __label__ = 11; break; } else { __label__ = 13; break; }
    case 11: 
      var $56=$sp1;
      var $57=((($56)-(1))|0);
      $sp1=$57;
      var $58=HEAPU8[($57)];
      var $59=(($58)&255);
      var $60=(((255)-($59))|0);
      var $61=(($60) & 255);
      var $62=$dp2;
      var $63=((($62)-(1))|0);
      $dp2=$63;
      HEAP8[($63)]=$61;
      var $64=$sp1;
      var $65=((($64)-(1))|0);
      $sp1=$65;
      var $66=HEAPU8[($65)];
      var $67=(($66)&255);
      var $68=(((255)-($67))|0);
      var $69=(($68) & 255);
      var $70=$dp2;
      var $71=((($70)-(1))|0);
      $dp2=$71;
      HEAP8[($71)]=$69;
      var $72=$sp1;
      var $73=((($72)-(6))|0);
      $sp1=$73;
      var $74=$sp1;
      $dp2=$74;
      __label__ = 12; break;
    case 12: 
      var $76=$i3;
      var $77=((($76)+(1))|0);
      $i3=$77;
      __label__ = 10; break;
    case 13: 
      __label__ = 14; break;
    case 14: 
      __label__ = 29; break;
    case 15: 
      var $81=$1;
      var $82=(($81+8)|0);
      var $83=HEAPU8[($82)];
      var $84=(($83)&255);
      var $85=(($84)|0)==4;
      if ($85) { __label__ = 16; break; } else { __label__ = 28; break; }
    case 16: 
      var $87=$1;
      var $88=(($87+9)|0);
      var $89=HEAPU8[($88)];
      var $90=(($89)&255);
      var $91=(($90)|0)==8;
      if ($91) { __label__ = 17; break; } else { __label__ = 22; break; }
    case 17: 
      var $93=$2;
      var $94=$1;
      var $95=(($94+4)|0);
      var $96=HEAP32[(($95)>>2)];
      var $97=(($93+$96)|0);
      $sp4=$97;
      var $98=$sp4;
      $dp5=$98;
      $i6=0;
      __label__ = 18; break;
    case 18: 
      var $100=$i6;
      var $101=$row_width;
      var $102=(($100)>>>0) < (($101)>>>0);
      if ($102) { __label__ = 19; break; } else { __label__ = 21; break; }
    case 19: 
      var $104=$sp4;
      var $105=((($104)-(1))|0);
      $sp4=$105;
      var $106=HEAPU8[($105)];
      var $107=(($106)&255);
      var $108=(((255)-($107))|0);
      var $109=(($108) & 255);
      var $110=$dp5;
      var $111=((($110)-(1))|0);
      $dp5=$111;
      HEAP8[($111)]=$109;
      var $112=$sp4;
      var $113=((($112)-(1))|0);
      $sp4=$113;
      var $114=HEAP8[($113)];
      var $115=$dp5;
      var $116=((($115)-(1))|0);
      $dp5=$116;
      HEAP8[($116)]=$114;
      __label__ = 20; break;
    case 20: 
      var $118=$i6;
      var $119=((($118)+(1))|0);
      $i6=$119;
      __label__ = 18; break;
    case 21: 
      __label__ = 27; break;
    case 22: 
      var $122=$2;
      var $123=$1;
      var $124=(($123+4)|0);
      var $125=HEAP32[(($124)>>2)];
      var $126=(($122+$125)|0);
      $sp7=$126;
      var $127=$sp7;
      $dp8=$127;
      $i9=0;
      __label__ = 23; break;
    case 23: 
      var $129=$i9;
      var $130=$row_width;
      var $131=(($129)>>>0) < (($130)>>>0);
      if ($131) { __label__ = 24; break; } else { __label__ = 26; break; }
    case 24: 
      var $133=$sp7;
      var $134=((($133)-(1))|0);
      $sp7=$134;
      var $135=HEAPU8[($134)];
      var $136=(($135)&255);
      var $137=(((255)-($136))|0);
      var $138=(($137) & 255);
      var $139=$dp8;
      var $140=((($139)-(1))|0);
      $dp8=$140;
      HEAP8[($140)]=$138;
      var $141=$sp7;
      var $142=((($141)-(1))|0);
      $sp7=$142;
      var $143=HEAPU8[($142)];
      var $144=(($143)&255);
      var $145=(((255)-($144))|0);
      var $146=(($145) & 255);
      var $147=$dp8;
      var $148=((($147)-(1))|0);
      $dp8=$148;
      HEAP8[($148)]=$146;
      var $149=$sp7;
      var $150=((($149)-(2))|0);
      $sp7=$150;
      var $151=$sp7;
      $dp8=$151;
      __label__ = 25; break;
    case 25: 
      var $153=$i9;
      var $154=((($153)+(1))|0);
      $i9=$154;
      __label__ = 23; break;
    case 26: 
      __label__ = 27; break;
    case 27: 
      __label__ = 28; break;
    case 28: 
      __label__ = 29; break;
    case 29: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_png_do_read_invert_alpha["X"]=1;

function _png_do_read_swap_alpha($row_info, $row) {
  var __stackBase__  = STACKTOP; STACKTOP += 8; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $row_width;
      var $sp;
      var $dp;
      var $save;
      var $i;
      var $sp1;
      var $dp2;
      var $save3=__stackBase__;
      var $i4;
      var $sp5;
      var $dp6;
      var $save7;
      var $i8;
      var $sp9;
      var $dp10;
      var $save11=(__stackBase__)+(4);
      var $i12;
      $1=$row_info;
      $2=$row;
      var $3=$1;
      var $4=(($3)|0);
      var $5=HEAP32[(($4)>>2)];
      $row_width=$5;
      var $6=$1;
      var $7=(($6+8)|0);
      var $8=HEAPU8[($7)];
      var $9=(($8)&255);
      var $10=(($9)|0)==6;
      if ($10) { __label__ = 3; break; } else { __label__ = 15; break; }
    case 3: 
      var $12=$1;
      var $13=(($12+9)|0);
      var $14=HEAPU8[($13)];
      var $15=(($14)&255);
      var $16=(($15)|0)==8;
      if ($16) { __label__ = 4; break; } else { __label__ = 9; break; }
    case 4: 
      var $18=$2;
      var $19=$1;
      var $20=(($19+4)|0);
      var $21=HEAP32[(($20)>>2)];
      var $22=(($18+$21)|0);
      $sp=$22;
      var $23=$sp;
      $dp=$23;
      $i=0;
      __label__ = 5; break;
    case 5: 
      var $25=$i;
      var $26=$row_width;
      var $27=(($25)>>>0) < (($26)>>>0);
      if ($27) { __label__ = 6; break; } else { __label__ = 8; break; }
    case 6: 
      var $29=$sp;
      var $30=((($29)-(1))|0);
      $sp=$30;
      var $31=HEAP8[($30)];
      $save=$31;
      var $32=$sp;
      var $33=((($32)-(1))|0);
      $sp=$33;
      var $34=HEAP8[($33)];
      var $35=$dp;
      var $36=((($35)-(1))|0);
      $dp=$36;
      HEAP8[($36)]=$34;
      var $37=$sp;
      var $38=((($37)-(1))|0);
      $sp=$38;
      var $39=HEAP8[($38)];
      var $40=$dp;
      var $41=((($40)-(1))|0);
      $dp=$41;
      HEAP8[($41)]=$39;
      var $42=$sp;
      var $43=((($42)-(1))|0);
      $sp=$43;
      var $44=HEAP8[($43)];
      var $45=$dp;
      var $46=((($45)-(1))|0);
      $dp=$46;
      HEAP8[($46)]=$44;
      var $47=$save;
      var $48=$dp;
      var $49=((($48)-(1))|0);
      $dp=$49;
      HEAP8[($49)]=$47;
      __label__ = 7; break;
    case 7: 
      var $51=$i;
      var $52=((($51)+(1))|0);
      $i=$52;
      __label__ = 5; break;
    case 8: 
      __label__ = 14; break;
    case 9: 
      var $55=$2;
      var $56=$1;
      var $57=(($56+4)|0);
      var $58=HEAP32[(($57)>>2)];
      var $59=(($55+$58)|0);
      $sp1=$59;
      var $60=$sp1;
      $dp2=$60;
      $i4=0;
      __label__ = 10; break;
    case 10: 
      var $62=$i4;
      var $63=$row_width;
      var $64=(($62)>>>0) < (($63)>>>0);
      if ($64) { __label__ = 11; break; } else { __label__ = 13; break; }
    case 11: 
      var $66=$sp1;
      var $67=((($66)-(1))|0);
      $sp1=$67;
      var $68=HEAP8[($67)];
      var $69=(($save3)|0);
      HEAP8[($69)]=$68;
      var $70=$sp1;
      var $71=((($70)-(1))|0);
      $sp1=$71;
      var $72=HEAP8[($71)];
      var $73=(($save3+1)|0);
      HEAP8[($73)]=$72;
      var $74=$sp1;
      var $75=((($74)-(1))|0);
      $sp1=$75;
      var $76=HEAP8[($75)];
      var $77=$dp2;
      var $78=((($77)-(1))|0);
      $dp2=$78;
      HEAP8[($78)]=$76;
      var $79=$sp1;
      var $80=((($79)-(1))|0);
      $sp1=$80;
      var $81=HEAP8[($80)];
      var $82=$dp2;
      var $83=((($82)-(1))|0);
      $dp2=$83;
      HEAP8[($83)]=$81;
      var $84=$sp1;
      var $85=((($84)-(1))|0);
      $sp1=$85;
      var $86=HEAP8[($85)];
      var $87=$dp2;
      var $88=((($87)-(1))|0);
      $dp2=$88;
      HEAP8[($88)]=$86;
      var $89=$sp1;
      var $90=((($89)-(1))|0);
      $sp1=$90;
      var $91=HEAP8[($90)];
      var $92=$dp2;
      var $93=((($92)-(1))|0);
      $dp2=$93;
      HEAP8[($93)]=$91;
      var $94=$sp1;
      var $95=((($94)-(1))|0);
      $sp1=$95;
      var $96=HEAP8[($95)];
      var $97=$dp2;
      var $98=((($97)-(1))|0);
      $dp2=$98;
      HEAP8[($98)]=$96;
      var $99=$sp1;
      var $100=((($99)-(1))|0);
      $sp1=$100;
      var $101=HEAP8[($100)];
      var $102=$dp2;
      var $103=((($102)-(1))|0);
      $dp2=$103;
      HEAP8[($103)]=$101;
      var $104=(($save3)|0);
      var $105=HEAP8[($104)];
      var $106=$dp2;
      var $107=((($106)-(1))|0);
      $dp2=$107;
      HEAP8[($107)]=$105;
      var $108=(($save3+1)|0);
      var $109=HEAP8[($108)];
      var $110=$dp2;
      var $111=((($110)-(1))|0);
      $dp2=$111;
      HEAP8[($111)]=$109;
      __label__ = 12; break;
    case 12: 
      var $113=$i4;
      var $114=((($113)+(1))|0);
      $i4=$114;
      __label__ = 10; break;
    case 13: 
      __label__ = 14; break;
    case 14: 
      __label__ = 29; break;
    case 15: 
      var $118=$1;
      var $119=(($118+8)|0);
      var $120=HEAPU8[($119)];
      var $121=(($120)&255);
      var $122=(($121)|0)==4;
      if ($122) { __label__ = 16; break; } else { __label__ = 28; break; }
    case 16: 
      var $124=$1;
      var $125=(($124+9)|0);
      var $126=HEAPU8[($125)];
      var $127=(($126)&255);
      var $128=(($127)|0)==8;
      if ($128) { __label__ = 17; break; } else { __label__ = 22; break; }
    case 17: 
      var $130=$2;
      var $131=$1;
      var $132=(($131+4)|0);
      var $133=HEAP32[(($132)>>2)];
      var $134=(($130+$133)|0);
      $sp5=$134;
      var $135=$sp5;
      $dp6=$135;
      $i8=0;
      __label__ = 18; break;
    case 18: 
      var $137=$i8;
      var $138=$row_width;
      var $139=(($137)>>>0) < (($138)>>>0);
      if ($139) { __label__ = 19; break; } else { __label__ = 21; break; }
    case 19: 
      var $141=$sp5;
      var $142=((($141)-(1))|0);
      $sp5=$142;
      var $143=HEAP8[($142)];
      $save7=$143;
      var $144=$sp5;
      var $145=((($144)-(1))|0);
      $sp5=$145;
      var $146=HEAP8[($145)];
      var $147=$dp6;
      var $148=((($147)-(1))|0);
      $dp6=$148;
      HEAP8[($148)]=$146;
      var $149=$save7;
      var $150=$dp6;
      var $151=((($150)-(1))|0);
      $dp6=$151;
      HEAP8[($151)]=$149;
      __label__ = 20; break;
    case 20: 
      var $153=$i8;
      var $154=((($153)+(1))|0);
      $i8=$154;
      __label__ = 18; break;
    case 21: 
      __label__ = 27; break;
    case 22: 
      var $157=$2;
      var $158=$1;
      var $159=(($158+4)|0);
      var $160=HEAP32[(($159)>>2)];
      var $161=(($157+$160)|0);
      $sp9=$161;
      var $162=$sp9;
      $dp10=$162;
      $i12=0;
      __label__ = 23; break;
    case 23: 
      var $164=$i12;
      var $165=$row_width;
      var $166=(($164)>>>0) < (($165)>>>0);
      if ($166) { __label__ = 24; break; } else { __label__ = 26; break; }
    case 24: 
      var $168=$sp9;
      var $169=((($168)-(1))|0);
      $sp9=$169;
      var $170=HEAP8[($169)];
      var $171=(($save11)|0);
      HEAP8[($171)]=$170;
      var $172=$sp9;
      var $173=((($172)-(1))|0);
      $sp9=$173;
      var $174=HEAP8[($173)];
      var $175=(($save11+1)|0);
      HEAP8[($175)]=$174;
      var $176=$sp9;
      var $177=((($176)-(1))|0);
      $sp9=$177;
      var $178=HEAP8[($177)];
      var $179=$dp10;
      var $180=((($179)-(1))|0);
      $dp10=$180;
      HEAP8[($180)]=$178;
      var $181=$sp9;
      var $182=((($181)-(1))|0);
      $sp9=$182;
      var $183=HEAP8[($182)];
      var $184=$dp10;
      var $185=((($184)-(1))|0);
      $dp10=$185;
      HEAP8[($185)]=$183;
      var $186=(($save11)|0);
      var $187=HEAP8[($186)];
      var $188=$dp10;
      var $189=((($188)-(1))|0);
      $dp10=$189;
      HEAP8[($189)]=$187;
      var $190=(($save11+1)|0);
      var $191=HEAP8[($190)];
      var $192=$dp10;
      var $193=((($192)-(1))|0);
      $dp10=$193;
      HEAP8[($193)]=$191;
      __label__ = 25; break;
    case 25: 
      var $195=$i12;
      var $196=((($195)+(1))|0);
      $i12=$196;
      __label__ = 23; break;
    case 26: 
      __label__ = 27; break;
    case 27: 
      __label__ = 28; break;
    case 28: 
      __label__ = 29; break;
    case 29: 
      STACKTOP = __stackBase__;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_png_do_read_swap_alpha["X"]=1;

function _png_do_read_intrapixel($row_info, $row) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $bytes_per_pixel;
      var $row_width;
      var $rp;
      var $i;
      var $rp1;
      var $i2;
      var $s0;
      var $s1;
      var $s2;
      var $red;
      var $blue;
      $1=$row_info;
      $2=$row;
      var $3=$1;
      var $4=(($3+8)|0);
      var $5=HEAPU8[($4)];
      var $6=(($5)&255);
      var $7=$6 & 2;
      var $8=(($7)|0)!=0;
      if ($8) { __label__ = 3; break; } else { __label__ = 29; break; }
    case 3: 
      var $10=$1;
      var $11=(($10)|0);
      var $12=HEAP32[(($11)>>2)];
      $row_width=$12;
      var $13=$1;
      var $14=(($13+9)|0);
      var $15=HEAPU8[($14)];
      var $16=(($15)&255);
      var $17=(($16)|0)==8;
      if ($17) { __label__ = 4; break; } else { __label__ = 15; break; }
    case 4: 
      var $19=$1;
      var $20=(($19+8)|0);
      var $21=HEAPU8[($20)];
      var $22=(($21)&255);
      var $23=(($22)|0)==2;
      if ($23) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      $bytes_per_pixel=3;
      __label__ = 10; break;
    case 6: 
      var $26=$1;
      var $27=(($26+8)|0);
      var $28=HEAPU8[($27)];
      var $29=(($28)&255);
      var $30=(($29)|0)==6;
      if ($30) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      $bytes_per_pixel=4;
      __label__ = 9; break;
    case 8: 
      __label__ = 29; break;
    case 9: 
      __label__ = 10; break;
    case 10: 
      $i=0;
      var $35=$2;
      $rp=$35;
      __label__ = 11; break;
    case 11: 
      var $37=$i;
      var $38=$row_width;
      var $39=(($37)>>>0) < (($38)>>>0);
      if ($39) { __label__ = 12; break; } else { __label__ = 14; break; }
    case 12: 
      var $41=$rp;
      var $42=HEAPU8[($41)];
      var $43=(($42)&255);
      var $44=((($43)+(256))|0);
      var $45=$rp;
      var $46=(($45+1)|0);
      var $47=HEAPU8[($46)];
      var $48=(($47)&255);
      var $49=((($44)+($48))|0);
      var $50=$49 & 255;
      var $51=(($50) & 255);
      var $52=$rp;
      HEAP8[($52)]=$51;
      var $53=$rp;
      var $54=(($53+2)|0);
      var $55=HEAPU8[($54)];
      var $56=(($55)&255);
      var $57=((($56)+(256))|0);
      var $58=$rp;
      var $59=(($58+1)|0);
      var $60=HEAPU8[($59)];
      var $61=(($60)&255);
      var $62=((($57)+($61))|0);
      var $63=$62 & 255;
      var $64=(($63) & 255);
      var $65=$rp;
      var $66=(($65+2)|0);
      HEAP8[($66)]=$64;
      __label__ = 13; break;
    case 13: 
      var $68=$i;
      var $69=((($68)+(1))|0);
      $i=$69;
      var $70=$bytes_per_pixel;
      var $71=$rp;
      var $72=(($71+$70)|0);
      $rp=$72;
      __label__ = 11; break;
    case 14: 
      __label__ = 28; break;
    case 15: 
      var $75=$1;
      var $76=(($75+9)|0);
      var $77=HEAPU8[($76)];
      var $78=(($77)&255);
      var $79=(($78)|0)==16;
      if ($79) { __label__ = 16; break; } else { __label__ = 27; break; }
    case 16: 
      var $81=$1;
      var $82=(($81+8)|0);
      var $83=HEAPU8[($82)];
      var $84=(($83)&255);
      var $85=(($84)|0)==2;
      if ($85) { __label__ = 17; break; } else { __label__ = 18; break; }
    case 17: 
      $bytes_per_pixel=6;
      __label__ = 22; break;
    case 18: 
      var $88=$1;
      var $89=(($88+8)|0);
      var $90=HEAPU8[($89)];
      var $91=(($90)&255);
      var $92=(($91)|0)==6;
      if ($92) { __label__ = 19; break; } else { __label__ = 20; break; }
    case 19: 
      $bytes_per_pixel=8;
      __label__ = 21; break;
    case 20: 
      __label__ = 29; break;
    case 21: 
      __label__ = 22; break;
    case 22: 
      $i2=0;
      var $97=$2;
      $rp1=$97;
      __label__ = 23; break;
    case 23: 
      var $99=$i2;
      var $100=$row_width;
      var $101=(($99)>>>0) < (($100)>>>0);
      if ($101) { __label__ = 24; break; } else { __label__ = 26; break; }
    case 24: 
      var $103=$rp1;
      var $104=HEAPU8[($103)];
      var $105=(($104)&255);
      var $106=$105 << 8;
      var $107=$rp1;
      var $108=(($107+1)|0);
      var $109=HEAPU8[($108)];
      var $110=(($109)&255);
      var $111=$106 | $110;
      $s0=$111;
      var $112=$rp1;
      var $113=(($112+2)|0);
      var $114=HEAPU8[($113)];
      var $115=(($114)&255);
      var $116=$115 << 8;
      var $117=$rp1;
      var $118=(($117+3)|0);
      var $119=HEAPU8[($118)];
      var $120=(($119)&255);
      var $121=$116 | $120;
      $s1=$121;
      var $122=$rp1;
      var $123=(($122+4)|0);
      var $124=HEAPU8[($123)];
      var $125=(($124)&255);
      var $126=$125 << 8;
      var $127=$rp1;
      var $128=(($127+5)|0);
      var $129=HEAPU8[($128)];
      var $130=(($129)&255);
      var $131=$126 | $130;
      $s2=$131;
      var $132=$s0;
      var $133=$s1;
      var $134=((($132)+($133))|0);
      var $135=((($134)+(65536))|0);
      var $136=$135 & 65535;
      $red=$136;
      var $137=$s2;
      var $138=$s1;
      var $139=((($137)+($138))|0);
      var $140=((($139)+(65536))|0);
      var $141=$140 & 65535;
      $blue=$141;
      var $142=$red;
      var $143=$142 >>> 8;
      var $144=$143 & 255;
      var $145=(($144) & 255);
      var $146=$rp1;
      HEAP8[($146)]=$145;
      var $147=$red;
      var $148=$147 & 255;
      var $149=(($148) & 255);
      var $150=$rp1;
      var $151=(($150+1)|0);
      HEAP8[($151)]=$149;
      var $152=$blue;
      var $153=$152 >>> 8;
      var $154=$153 & 255;
      var $155=(($154) & 255);
      var $156=$rp1;
      var $157=(($156+4)|0);
      HEAP8[($157)]=$155;
      var $158=$blue;
      var $159=$158 & 255;
      var $160=(($159) & 255);
      var $161=$rp1;
      var $162=(($161+5)|0);
      HEAP8[($162)]=$160;
      __label__ = 25; break;
    case 25: 
      var $164=$i2;
      var $165=((($164)+(1))|0);
      $i2=$165;
      var $166=$bytes_per_pixel;
      var $167=$rp1;
      var $168=(($167+$166)|0);
      $rp1=$168;
      __label__ = 23; break;
    case 26: 
      __label__ = 27; break;
    case 27: 
      __label__ = 28; break;
    case 28: 
      __label__ = 29; break;
    case 29: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_png_do_read_intrapixel["X"]=1;

function _png_get_uint_31($png_ptr, $buf) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $val;
      $1=$png_ptr;
      $2=$buf;
      var $3=$2;
      var $4=HEAPU8[($3)];
      var $5=(($4)&255);
      var $6=$5 << 24;
      var $7=$2;
      var $8=(($7+1)|0);
      var $9=HEAPU8[($8)];
      var $10=(($9)&255);
      var $11=$10 << 16;
      var $12=((($6)+($11))|0);
      var $13=$2;
      var $14=(($13+2)|0);
      var $15=HEAPU8[($14)];
      var $16=(($15)&255);
      var $17=$16 << 8;
      var $18=((($12)+($17))|0);
      var $19=$2;
      var $20=(($19+3)|0);
      var $21=HEAPU8[($20)];
      var $22=(($21)&255);
      var $23=((($18)+($22))|0);
      $val=$23;
      var $24=$val;
      var $25=(($24)>>>0) > 2147483647;
      if ($25) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $27=$1;
      _png_error($27, ((STRING_TABLE.__str193)|0));
      __label__ = 4; break;
    case 4: 
      var $29=$val;
      ;
      return $29;
    default: assert(0, "bad label: " + __label__);
  }
}


function _png_read_sig($png_ptr, $info_ptr) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $num_checked;
      var $num_to_check;
      $1=$png_ptr;
      $2=$info_ptr;
      var $3=$1;
      var $4=(($3+280)|0);
      var $5=HEAPU8[($4)];
      var $6=(($5)&255);
      var $7=(($6)|0) >= 8;
      if ($7) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      __label__ = 12; break;
    case 4: 
      var $10=$1;
      var $11=(($10+280)|0);
      var $12=HEAPU8[($11)];
      var $13=(($12)&255);
      $num_checked=$13;
      var $14=$num_checked;
      var $15=(((8)-($14))|0);
      $num_to_check=$15;
      var $16=$1;
      var $17=(($16+628)|0);
      HEAP32[(($17)>>2)]=17;
      var $18=$1;
      var $19=$num_checked;
      var $20=$2;
      var $21=(($20+32)|0);
      var $22=(($21+$19)|0);
      var $23=$num_to_check;
      _png_read_data($18, $22, $23);
      var $24=$1;
      var $25=(($24+280)|0);
      HEAP8[($25)]=8;
      var $26=$2;
      var $27=(($26+32)|0);
      var $28=(($27)|0);
      var $29=$num_checked;
      var $30=$num_to_check;
      var $31=_png_sig_cmp($28, $29, $30);
      var $32=(($31)|0)!=0;
      if ($32) { __label__ = 5; break; } else { __label__ = 10; break; }
    case 5: 
      var $34=$num_checked;
      var $35=(($34)>>>0) < 4;
      if ($35) { __label__ = 6; break; } else { __label__ = 8; break; }
    case 6: 
      var $37=$2;
      var $38=(($37+32)|0);
      var $39=(($38)|0);
      var $40=$num_checked;
      var $41=$num_to_check;
      var $42=((($41)-(4))|0);
      var $43=_png_sig_cmp($39, $40, $42);
      var $44=(($43)|0)!=0;
      if ($44) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $46=$1;
      _png_error($46, ((STRING_TABLE.__str1194)|0));
      __label__ = 9; break;
    case 8: 
      var $48=$1;
      _png_error($48, ((STRING_TABLE.__str2195)|0));
      __label__ = 9; break;
    case 9: 
      __label__ = 10; break;
    case 10: 
      var $51=$num_checked;
      var $52=(($51)>>>0) < 3;
      if ($52) { __label__ = 11; break; } else { __label__ = 12; break; }
    case 11: 
      var $54=$1;
      var $55=(($54+84)|0);
      var $56=HEAP32[(($55)>>2)];
      var $57=$56 | 4096;
      HEAP32[(($55)>>2)]=$57;
      __label__ = 12; break;
    case 12: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_png_read_sig["X"]=1;

function _png_read_chunk_header($png_ptr) {
  var __stackBase__  = STACKTOP; STACKTOP += 8; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;

  var $1;
  var $buf=__stackBase__;
  var $length;
  $1=$png_ptr;
  var $2=$1;
  var $3=(($2+628)|0);
  HEAP32[(($3)>>2)]=33;
  var $4=$1;
  var $5=(($buf)|0);
  _png_read_data($4, $5, 8);
  var $6=$1;
  var $7=(($buf)|0);
  var $8=_png_get_uint_31($6, $7);
  $length=$8;
  var $9=$1;
  var $10=(($9+264)|0);
  var $11=(($10)|0);
  var $12=(($buf)|0);
  var $13=(($12+4)|0);
  assert(4 % 1 === 0, 'memcpy given ' + 4 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP8[($11)]=HEAP8[($13)];HEAP8[(($11)+(1))]=HEAP8[(($13)+(1))];HEAP8[(($11)+(2))]=HEAP8[(($13)+(2))];HEAP8[(($11)+(3))]=HEAP8[(($13)+(3))];
  var $14=$1;
  _png_reset_crc($14);
  var $15=$1;
  var $16=$1;
  var $17=(($16+264)|0);
  var $18=(($17)|0);
  _png_calculate_crc($15, $18, 4);
  var $19=$1;
  var $20=$1;
  var $21=(($20+264)|0);
  var $22=(($21)|0);
  _png_check_chunk_name($19, $22);
  var $23=$1;
  var $24=(($23+628)|0);
  HEAP32[(($24)>>2)]=65;
  var $25=$length;
  STACKTOP = __stackBase__;
  return $25;
}


function _png_check_chunk_name($png_ptr, $chunk_name) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      $1=$png_ptr;
      $2=$chunk_name;
      var $3=$2;
      var $4=(($3)|0);
      var $5=HEAPU8[($4)];
      var $6=(($5)&255);
      var $7=(($6)|0) < 65;
      if ($7) { __label__ = 18; break; } else { __label__ = 3; break; }
    case 3: 
      var $9=$2;
      var $10=(($9)|0);
      var $11=HEAPU8[($10)];
      var $12=(($11)&255);
      var $13=(($12)|0) > 122;
      if ($13) { __label__ = 18; break; } else { __label__ = 4; break; }
    case 4: 
      var $15=$2;
      var $16=(($15)|0);
      var $17=HEAPU8[($16)];
      var $18=(($17)&255);
      var $19=(($18)|0) > 90;
      if ($19) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $21=$2;
      var $22=(($21)|0);
      var $23=HEAPU8[($22)];
      var $24=(($23)&255);
      var $25=(($24)|0) < 97;
      if ($25) { __label__ = 18; break; } else { __label__ = 6; break; }
    case 6: 
      var $27=$2;
      var $28=(($27+1)|0);
      var $29=HEAPU8[($28)];
      var $30=(($29)&255);
      var $31=(($30)|0) < 65;
      if ($31) { __label__ = 18; break; } else { __label__ = 7; break; }
    case 7: 
      var $33=$2;
      var $34=(($33+1)|0);
      var $35=HEAPU8[($34)];
      var $36=(($35)&255);
      var $37=(($36)|0) > 122;
      if ($37) { __label__ = 18; break; } else { __label__ = 8; break; }
    case 8: 
      var $39=$2;
      var $40=(($39+1)|0);
      var $41=HEAPU8[($40)];
      var $42=(($41)&255);
      var $43=(($42)|0) > 90;
      if ($43) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      var $45=$2;
      var $46=(($45+1)|0);
      var $47=HEAPU8[($46)];
      var $48=(($47)&255);
      var $49=(($48)|0) < 97;
      if ($49) { __label__ = 18; break; } else { __label__ = 10; break; }
    case 10: 
      var $51=$2;
      var $52=(($51+2)|0);
      var $53=HEAPU8[($52)];
      var $54=(($53)&255);
      var $55=(($54)|0) < 65;
      if ($55) { __label__ = 18; break; } else { __label__ = 11; break; }
    case 11: 
      var $57=$2;
      var $58=(($57+2)|0);
      var $59=HEAPU8[($58)];
      var $60=(($59)&255);
      var $61=(($60)|0) > 122;
      if ($61) { __label__ = 18; break; } else { __label__ = 12; break; }
    case 12: 
      var $63=$2;
      var $64=(($63+2)|0);
      var $65=HEAPU8[($64)];
      var $66=(($65)&255);
      var $67=(($66)|0) > 90;
      if ($67) { __label__ = 13; break; } else { __label__ = 14; break; }
    case 13: 
      var $69=$2;
      var $70=(($69+2)|0);
      var $71=HEAPU8[($70)];
      var $72=(($71)&255);
      var $73=(($72)|0) < 97;
      if ($73) { __label__ = 18; break; } else { __label__ = 14; break; }
    case 14: 
      var $75=$2;
      var $76=(($75+3)|0);
      var $77=HEAPU8[($76)];
      var $78=(($77)&255);
      var $79=(($78)|0) < 65;
      if ($79) { __label__ = 18; break; } else { __label__ = 15; break; }
    case 15: 
      var $81=$2;
      var $82=(($81+3)|0);
      var $83=HEAPU8[($82)];
      var $84=(($83)&255);
      var $85=(($84)|0) > 122;
      if ($85) { __label__ = 18; break; } else { __label__ = 16; break; }
    case 16: 
      var $87=$2;
      var $88=(($87+3)|0);
      var $89=HEAPU8[($88)];
      var $90=(($89)&255);
      var $91=(($90)|0) > 90;
      if ($91) { __label__ = 17; break; } else { __label__ = 19; break; }
    case 17: 
      var $93=$2;
      var $94=(($93+3)|0);
      var $95=HEAPU8[($94)];
      var $96=(($95)&255);
      var $97=(($96)|0) < 97;
      if ($97) { __label__ = 18; break; } else { __label__ = 19; break; }
    case 18: 
      var $99=$1;
      _png_chunk_error($99, ((STRING_TABLE.__str133232)|0));
      __label__ = 19; break;
    case 19: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_png_check_chunk_name["X"]=1;

function _png_crc_read($png_ptr, $buf, $length) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      $1=$png_ptr;
      $2=$buf;
      $3=$length;
      var $4=$1;
      var $5=(($4)|0)==0;
      if ($5) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      __label__ = 5; break;
    case 4: 
      var $8=$1;
      var $9=$2;
      var $10=$3;
      _png_read_data($8, $9, $10);
      var $11=$1;
      var $12=$2;
      var $13=$3;
      _png_calculate_crc($11, $12, $13);
      __label__ = 5; break;
    case 5: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}


function _png_crc_finish($png_ptr, $skip) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $i;
      var $istop;
      $2=$png_ptr;
      $3=$skip;
      var $4=$2;
      var $5=(($4+156)|0);
      var $6=HEAP32[(($5)>>2)];
      $istop=$6;
      var $7=$3;
      $i=$7;
      __label__ = 3; break;
    case 3: 
      var $9=$i;
      var $10=$istop;
      var $11=(($9)>>>0) > (($10)>>>0);
      if ($11) { __label__ = 4; break; } else { __label__ = 6; break; }
    case 4: 
      var $13=$2;
      var $14=$2;
      var $15=(($14+152)|0);
      var $16=HEAP32[(($15)>>2)];
      var $17=$2;
      var $18=(($17+156)|0);
      var $19=HEAP32[(($18)>>2)];
      _png_crc_read($13, $16, $19);
      __label__ = 5; break;
    case 5: 
      var $21=$istop;
      var $22=$i;
      var $23=((($22)-($21))|0);
      $i=$23;
      __label__ = 3; break;
    case 6: 
      var $25=$i;
      var $26=(($25)|0)!=0;
      if ($26) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $28=$2;
      var $29=$2;
      var $30=(($29+152)|0);
      var $31=HEAP32[(($30)>>2)];
      var $32=$i;
      _png_crc_read($28, $31, $32);
      __label__ = 8; break;
    case 8: 
      var $34=$2;
      var $35=_png_crc_error($34);
      var $36=(($35)|0)!=0;
      if ($36) { __label__ = 9; break; } else { __label__ = 16; break; }
    case 9: 
      var $38=$2;
      var $39=(($38+264)|0);
      var $40=(($39)|0);
      var $41=HEAPU8[($40)];
      var $42=(($41)&255);
      var $43=$42 & 32;
      var $44=(($43)|0)!=0;
      if ($44) { __label__ = 10; break; } else { __label__ = 11; break; }
    case 10: 
      var $46=$2;
      var $47=(($46+88)|0);
      var $48=HEAP32[(($47)>>2)];
      var $49=$48 & 512;
      var $50=(($49)|0)!=0;
      if ($50) { __label__ = 11; break; } else { __label__ = 13; break; }
    case 11: 
      var $52=$2;
      var $53=(($52+264)|0);
      var $54=(($53)|0);
      var $55=HEAPU8[($54)];
      var $56=(($55)&255);
      var $57=$56 & 32;
      var $58=(($57)|0)!=0;
      if ($58) { __label__ = 14; break; } else { __label__ = 12; break; }
    case 12: 
      var $60=$2;
      var $61=(($60+88)|0);
      var $62=HEAP32[(($61)>>2)];
      var $63=$62 & 1024;
      var $64=(($63)|0)!=0;
      if ($64) { __label__ = 13; break; } else { __label__ = 14; break; }
    case 13: 
      var $66=$2;
      _png_chunk_warning($66, ((STRING_TABLE.__str3196)|0));
      __label__ = 15; break;
    case 14: 
      var $68=$2;
      _png_chunk_error($68, ((STRING_TABLE.__str3196)|0));
      $1=0;
      __label__ = 17; break;
    case 15: 
      $1=1;
      __label__ = 17; break;
    case 16: 
      $1=0;
      __label__ = 17; break;
    case 17: 
      var $72=$1;
      ;
      return $72;
    default: assert(0, "bad label: " + __label__);
  }
}
_png_crc_finish["X"]=1;

function _png_crc_error($png_ptr) {
  var __stackBase__  = STACKTOP; STACKTOP += 4; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $crc_bytes=__stackBase__;
      var $crc;
      var $need_crc;
      $2=$png_ptr;
      $need_crc=1;
      var $3=$2;
      var $4=(($3+264)|0);
      var $5=(($4)|0);
      var $6=HEAPU8[($5)];
      var $7=(($6)&255);
      var $8=$7 & 32;
      var $9=(($8)|0)!=0;
      if ($9) { __label__ = 3; break; } else { __label__ = 6; break; }
    case 3: 
      var $11=$2;
      var $12=(($11+88)|0);
      var $13=HEAP32[(($12)>>2)];
      var $14=$13 & 768;
      var $15=(($14)|0)==768;
      if ($15) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      $need_crc=0;
      __label__ = 5; break;
    case 5: 
      __label__ = 9; break;
    case 6: 
      var $19=$2;
      var $20=(($19+88)|0);
      var $21=HEAP32[(($20)>>2)];
      var $22=$21 & 2048;
      var $23=(($22)|0)!=0;
      if ($23) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      $need_crc=0;
      __label__ = 8; break;
    case 8: 
      __label__ = 9; break;
    case 9: 
      var $27=$2;
      var $28=(($27+628)|0);
      HEAP32[(($28)>>2)]=129;
      var $29=$2;
      var $30=(($crc_bytes)|0);
      _png_read_data($29, $30, 4);
      var $31=$need_crc;
      var $32=(($31)|0)!=0;
      if ($32) { __label__ = 10; break; } else { __label__ = 11; break; }
    case 10: 
      var $34=(($crc_bytes)|0);
      var $35=HEAPU8[($34)];
      var $36=(($35)&255);
      var $37=$36 << 24;
      var $38=(($crc_bytes)|0);
      var $39=(($38+1)|0);
      var $40=HEAPU8[($39)];
      var $41=(($40)&255);
      var $42=$41 << 16;
      var $43=((($37)+($42))|0);
      var $44=(($crc_bytes)|0);
      var $45=(($44+2)|0);
      var $46=HEAPU8[($45)];
      var $47=(($46)&255);
      var $48=$47 << 8;
      var $49=((($43)+($48))|0);
      var $50=(($crc_bytes)|0);
      var $51=(($50+3)|0);
      var $52=HEAPU8[($51)];
      var $53=(($52)&255);
      var $54=((($49)+($53))|0);
      $crc=$54;
      var $55=$crc;
      var $56=$2;
      var $57=(($56+252)|0);
      var $58=HEAP32[(($57)>>2)];
      var $59=(($55)|0)!=(($58)|0);
      var $60=(($59)&1);
      $1=$60;
      __label__ = 12; break;
    case 11: 
      $1=0;
      __label__ = 12; break;
    case 12: 
      var $63=$1;
      STACKTOP = __stackBase__;
      return $63;
    default: assert(0, "bad label: " + __label__);
  }
}
_png_crc_error["X"]=1;

function _png_decompress_chunk($png_ptr, $comp_type, $chunklength, $prefix_size, $newlength) {
  var __stackBase__  = STACKTOP; STACKTOP += 52; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $5;
      var $expanded_size;
      var $new_size;
      var $text;
      var $umsg=__stackBase__;
      var $text1;
      $1=$png_ptr;
      $2=$comp_type;
      $3=$chunklength;
      $4=$prefix_size;
      $5=$newlength;
      var $6=$4;
      var $7=$3;
      var $8=(($6)>>>0) > (($7)>>>0);
      if ($8) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $10=$1;
      _png_warning($10, ((STRING_TABLE.__str4197)|0));
      $4=0;
      __label__ = 21; break;
    case 4: 
      var $12=$2;
      var $13=(($12)|0)==0;
      if ($13) { __label__ = 5; break; } else { __label__ = 19; break; }
    case 5: 
      var $15=$1;
      var $16=$1;
      var $17=(($16+624)|0);
      var $18=HEAP32[(($17)>>2)];
      var $19=$4;
      var $20=(($18+$19)|0);
      var $21=$3;
      var $22=$4;
      var $23=((($21)-($22))|0);
      var $24=_png_inflate($15, $20, $23, 0, 0);
      $expanded_size=$24;
      var $25=$4;
      var $26=(($25)>>>0) >= 4294967294;
      if ($26) { __label__ = 9; break; } else { __label__ = 6; break; }
    case 6: 
      var $28=$expanded_size;
      var $29=$4;
      var $30=(((-2)-($29))|0);
      var $31=(($28)>>>0) >= (($30)>>>0);
      if ($31) { __label__ = 9; break; } else { __label__ = 7; break; }
    case 7: 
      var $33=$1;
      var $34=(($33+200)|0);
      var $35=HEAP32[(($34)>>2)];
      var $36=(($35)|0)!=0;
      if ($36) { __label__ = 8; break; } else { __label__ = 10; break; }
    case 8: 
      var $38=$4;
      var $39=$expanded_size;
      var $40=((($38)+($39))|0);
      var $41=$1;
      var $42=(($41+200)|0);
      var $43=HEAP32[(($42)>>2)];
      var $44=((($43)-(1))|0);
      var $45=(($40)>>>0) >= (($44)>>>0);
      if ($45) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      var $47=$1;
      _png_warning($47, ((STRING_TABLE.__str5198)|0));
      __label__ = 18; break;
    case 10: 
      var $49=$expanded_size;
      var $50=(($49)>>>0) > 0;
      if ($50) { __label__ = 11; break; } else { __label__ = 17; break; }
    case 11: 
      $new_size=0;
      var $52=$1;
      var $53=$4;
      var $54=$expanded_size;
      var $55=((($53)+($54))|0);
      var $56=((($55)+(1))|0);
      var $57=_png_malloc_warn($52, $56);
      $text=$57;
      var $58=$text;
      var $59=(($58)|0)!=0;
      if ($59) { __label__ = 12; break; } else { __label__ = 15; break; }
    case 12: 
      var $61=$text;
      var $62=$1;
      var $63=(($62+624)|0);
      var $64=HEAP32[(($63)>>2)];
      var $65=$4;
      assert($65 % 1 === 0, 'memcpy given ' + $65 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');_memcpy($61, $64, $65, 1);
      var $66=$1;
      var $67=$1;
      var $68=(($67+624)|0);
      var $69=HEAP32[(($68)>>2)];
      var $70=$4;
      var $71=(($69+$70)|0);
      var $72=$3;
      var $73=$4;
      var $74=((($72)-($73))|0);
      var $75=$text;
      var $76=$4;
      var $77=(($75+$76)|0);
      var $78=$expanded_size;
      var $79=_png_inflate($66, $71, $74, $77, $78);
      $new_size=$79;
      var $80=$4;
      var $81=$expanded_size;
      var $82=((($80)+($81))|0);
      var $83=$text;
      var $84=(($83+$82)|0);
      HEAP8[($84)]=0;
      var $85=$new_size;
      var $86=$expanded_size;
      var $87=(($85)|0)==(($86)|0);
      if ($87) { __label__ = 13; break; } else { __label__ = 14; break; }
    case 13: 
      var $89=$1;
      var $90=$1;
      var $91=(($90+624)|0);
      var $92=HEAP32[(($91)>>2)];
      _png_free($89, $92);
      var $93=$text;
      var $94=$1;
      var $95=(($94+624)|0);
      HEAP32[(($95)>>2)]=$93;
      var $96=$4;
      var $97=$expanded_size;
      var $98=((($96)+($97))|0);
      var $99=$5;
      HEAP32[(($99)>>2)]=$98;
      __label__ = 26; break;
    case 14: 
      var $101=$1;
      _png_warning($101, ((STRING_TABLE.__str6199)|0));
      var $102=$1;
      var $103=$text;
      _png_free($102, $103);
      __label__ = 16; break;
    case 15: 
      var $105=$1;
      _png_warning($105, ((STRING_TABLE.__str7200)|0));
      __label__ = 16; break;
    case 16: 
      __label__ = 17; break;
    case 17: 
      __label__ = 18; break;
    case 18: 
      __label__ = 20; break;
    case 19: 
      var $110=(($umsg)|0);
      var $111=$2;
      var $112=_snprintf($110, 50, ((STRING_TABLE.__str8201)|0), (tempInt=STACKTOP,STACKTOP += 4,assert(STACKTOP < STACK_ROOT + STACK_MAX, "Ran out of stack"),HEAP32[((tempInt)>>2)]=$111,tempInt));
      var $113=$1;
      var $114=(($umsg)|0);
      _png_warning($113, $114);
      __label__ = 20; break;
    case 20: 
      __label__ = 21; break;
    case 21: 
      var $117=$1;
      var $118=$4;
      var $119=((($118)+(1))|0);
      var $120=_png_malloc_warn($117, $119);
      $text1=$120;
      var $121=$text1;
      var $122=(($121)|0)!=0;
      if ($122) { __label__ = 22; break; } else { __label__ = 25; break; }
    case 22: 
      var $124=$4;
      var $125=(($124)>>>0) > 0;
      if ($125) { __label__ = 23; break; } else { __label__ = 24; break; }
    case 23: 
      var $127=$text1;
      var $128=$1;
      var $129=(($128+624)|0);
      var $130=HEAP32[(($129)>>2)];
      var $131=$4;
      assert($131 % 1 === 0, 'memcpy given ' + $131 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');_memcpy($127, $130, $131, 1);
      __label__ = 24; break;
    case 24: 
      var $133=$1;
      var $134=$1;
      var $135=(($134+624)|0);
      var $136=HEAP32[(($135)>>2)];
      _png_free($133, $136);
      var $137=$text1;
      var $138=$1;
      var $139=(($138+624)|0);
      HEAP32[(($139)>>2)]=$137;
      var $140=$1;
      var $141=(($140+624)|0);
      var $142=HEAP32[(($141)>>2)];
      var $143=$4;
      var $144=(($142+$143)|0);
      HEAP8[($144)]=0;
      __label__ = 25; break;
    case 25: 
      var $146=$4;
      var $147=$5;
      HEAP32[(($147)>>2)]=$146;
      __label__ = 26; break;
    case 26: 
      STACKTOP = __stackBase__;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_png_decompress_chunk["X"]=1;

function _png_inflate($png_ptr, $data, $size, $output, $output_size) {
  var __stackBase__  = STACKTOP; STACKTOP += 52; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $5;
      var $6;
      var $count;
      var $ret;
      var $avail;
      var $copy;
      var $msg;
      var $umsg=__stackBase__;
      $2=$png_ptr;
      $3=$data;
      $4=$size;
      $5=$output;
      $6=$output_size;
      $count=0;
      var $7=$3;
      var $8=$2;
      var $9=(($8+96)|0);
      var $10=(($9)|0);
      HEAP32[(($10)>>2)]=$7;
      var $11=$4;
      var $12=$2;
      var $13=(($12+96)|0);
      var $14=(($13+4)|0);
      HEAP32[(($14)>>2)]=$11;
      __label__ = 3; break;
    case 3: 
      var $16=$2;
      var $17=(($16+152)|0);
      var $18=HEAP32[(($17)>>2)];
      var $19=$2;
      var $20=(($19+96)|0);
      var $21=(($20+12)|0);
      HEAP32[(($21)>>2)]=$18;
      var $22=$2;
      var $23=(($22+156)|0);
      var $24=HEAP32[(($23)>>2)];
      var $25=$2;
      var $26=(($25+96)|0);
      var $27=(($26+16)|0);
      HEAP32[(($27)>>2)]=$24;
      var $28=$2;
      var $29=(($28+96)|0);
      var $30=_inflate($29, 0);
      $ret=$30;
      var $31=$2;
      var $32=(($31+156)|0);
      var $33=HEAP32[(($32)>>2)];
      var $34=$2;
      var $35=(($34+96)|0);
      var $36=(($35+16)|0);
      var $37=HEAP32[(($36)>>2)];
      var $38=((($33)-($37))|0);
      $avail=$38;
      var $39=$ret;
      var $40=(($39)|0)==0;
      if ($40) { __label__ = 5; break; } else { __label__ = 4; break; }
    case 4: 
      var $42=$ret;
      var $43=(($42)|0)==1;
      if ($43) { __label__ = 5; break; } else { __label__ = 12; break; }
    case 5: 
      var $45=$avail;
      var $46=(($45)|0) > 0;
      if ($46) { __label__ = 6; break; } else { __label__ = 12; break; }
    case 6: 
      var $48=$5;
      var $49=(($48)|0)!=0;
      if ($49) { __label__ = 7; break; } else { __label__ = 11; break; }
    case 7: 
      var $51=$6;
      var $52=$count;
      var $53=(($51)>>>0) > (($52)>>>0);
      if ($53) { __label__ = 8; break; } else { __label__ = 11; break; }
    case 8: 
      var $55=$6;
      var $56=$count;
      var $57=((($55)-($56))|0);
      $copy=$57;
      var $58=$avail;
      var $59=$copy;
      var $60=(($58)>>>0) < (($59)>>>0);
      if ($60) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      var $62=$avail;
      $copy=$62;
      __label__ = 10; break;
    case 10: 
      var $64=$5;
      var $65=$count;
      var $66=(($64+$65)|0);
      var $67=$2;
      var $68=(($67+152)|0);
      var $69=HEAP32[(($68)>>2)];
      var $70=$copy;
      assert($70 % 1 === 0, 'memcpy given ' + $70 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');_memcpy($66, $69, $70, 1);
      __label__ = 11; break;
    case 11: 
      var $72=$avail;
      var $73=$count;
      var $74=((($73)+($72))|0);
      $count=$74;
      __label__ = 12; break;
    case 12: 
      var $76=$ret;
      var $77=(($76)|0)==0;
      if ($77) { __label__ = 13; break; } else { __label__ = 14; break; }
    case 13: 
      __label__ = 3; break;
    case 14: 
      var $80=$2;
      var $81=(($80+96)|0);
      var $82=(($81+4)|0);
      HEAP32[(($82)>>2)]=0;
      var $83=$2;
      var $84=(($83+96)|0);
      var $85=_inflateReset($84);
      var $86=$ret;
      var $87=(($86)|0)==1;
      if ($87) { __label__ = 15; break; } else { __label__ = 16; break; }
    case 15: 
      var $89=$count;
      $1=$89;
      __label__ = 24; break;
    case 16: 
      var $91=$2;
      var $92=(($91+96)|0);
      var $93=(($92+24)|0);
      var $94=HEAP32[(($93)>>2)];
      var $95=(($94)|0)!=0;
      if ($95) { __label__ = 17; break; } else { __label__ = 18; break; }
    case 17: 
      var $97=$2;
      var $98=(($97+96)|0);
      var $99=(($98+24)|0);
      var $100=HEAP32[(($99)>>2)];
      $msg=$100;
      __label__ = 23; break;
    case 18: 
      var $102=$ret;
      if ((($102)|0) == -5) {
        __label__ = 19; break;
      }
      else if ((($102)|0) == -3) {
        __label__ = 20; break;
      }
      else {
      __label__ = 21; break;
      }
      
    case 19: 
      $msg=((STRING_TABLE.__str140)|0);
      __label__ = 22; break;
    case 20: 
      $msg=((STRING_TABLE.__str141)|0);
      __label__ = 22; break;
    case 21: 
      $msg=((STRING_TABLE.__str142)|0);
      __label__ = 22; break;
    case 22: 
      var $107=(($umsg)|0);
      var $108=$msg;
      var $109=$2;
      var $110=(($109+264)|0);
      var $111=(($110)|0);
      var $112=_snprintf($107, 52, $108, (tempInt=STACKTOP,STACKTOP += 4,assert(STACKTOP < STACK_ROOT + STACK_MAX, "Ran out of stack"),HEAP32[((tempInt)>>2)]=$111,tempInt));
      var $113=(($umsg)|0);
      $msg=$113;
      __label__ = 23; break;
    case 23: 
      var $115=$2;
      var $116=$msg;
      _png_warning($115, $116);
      $1=0;
      __label__ = 24; break;
    case 24: 
      var $118=$1;
      STACKTOP = __stackBase__;
      return $118;
    default: assert(0, "bad label: " + __label__);
  }
}
_png_inflate["X"]=1;

function _png_handle_IHDR($png_ptr, $info_ptr, $length) {
  var __stackBase__  = STACKTOP; STACKTOP += 16; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $buf=__stackBase__;
      var $width;
      var $height;
      var $bit_depth;
      var $color_type;
      var $compression_type;
      var $filter_type;
      var $interlace_type;
      $1=$png_ptr;
      $2=$info_ptr;
      $3=$length;
      var $4=$1;
      var $5=(($4+84)|0);
      var $6=HEAP32[(($5)>>2)];
      var $7=$6 & 1;
      var $8=(($7)|0)!=0;
      if ($8) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $10=$1;
      _png_error($10, ((STRING_TABLE.__str9202)|0));
      __label__ = 4; break;
    case 4: 
      var $12=$3;
      var $13=(($12)|0)!=13;
      if ($13) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $15=$1;
      _png_error($15, ((STRING_TABLE.__str10203)|0));
      __label__ = 6; break;
    case 6: 
      var $17=$1;
      var $18=(($17+84)|0);
      var $19=HEAP32[(($18)>>2)];
      var $20=$19 | 1;
      HEAP32[(($18)>>2)]=$20;
      var $21=$1;
      var $22=(($buf)|0);
      _png_crc_read($21, $22, 13);
      var $23=$1;
      var $24=_png_crc_finish($23, 0);
      var $25=$1;
      var $26=(($buf)|0);
      var $27=_png_get_uint_31($25, $26);
      $width=$27;
      var $28=$1;
      var $29=(($buf)|0);
      var $30=(($29+4)|0);
      var $31=_png_get_uint_31($28, $30);
      $height=$31;
      var $32=(($buf+8)|0);
      var $33=HEAPU8[($32)];
      var $34=(($33)&255);
      $bit_depth=$34;
      var $35=(($buf+9)|0);
      var $36=HEAPU8[($35)];
      var $37=(($36)&255);
      $color_type=$37;
      var $38=(($buf+10)|0);
      var $39=HEAPU8[($38)];
      var $40=(($39)&255);
      $compression_type=$40;
      var $41=(($buf+11)|0);
      var $42=HEAPU8[($41)];
      var $43=(($42)&255);
      $filter_type=$43;
      var $44=(($buf+12)|0);
      var $45=HEAPU8[($44)];
      var $46=(($45)&255);
      $interlace_type=$46;
      var $47=$width;
      var $48=$1;
      var $49=(($48+180)|0);
      HEAP32[(($49)>>2)]=$47;
      var $50=$height;
      var $51=$1;
      var $52=(($51+184)|0);
      HEAP32[(($52)>>2)]=$50;
      var $53=$bit_depth;
      var $54=(($53) & 255);
      var $55=$1;
      var $56=(($55+275)|0);
      HEAP8[($56)]=$54;
      var $57=$interlace_type;
      var $58=(($57) & 255);
      var $59=$1;
      var $60=(($59+271)|0);
      HEAP8[($60)]=$58;
      var $61=$color_type;
      var $62=(($61) & 255);
      var $63=$1;
      var $64=(($63+274)|0);
      HEAP8[($64)]=$62;
      var $65=$filter_type;
      var $66=(($65) & 255);
      var $67=$1;
      var $68=(($67+548)|0);
      HEAP8[($68)]=$66;
      var $69=$compression_type;
      var $70=(($69) & 255);
      var $71=$1;
      var $72=(($71+580)|0);
      HEAP8[($72)]=$70;
      var $73=$1;
      var $74=(($73+274)|0);
      var $75=HEAPU8[($74)];
      var $76=(($75)&255);
      if ((($76)|0) == 0 || (($76)|0) == 3) {
        __label__ = 7; break;
      }
      else if ((($76)|0) == 2) {
        __label__ = 8; break;
      }
      else if ((($76)|0) == 4) {
        __label__ = 9; break;
      }
      else if ((($76)|0) == 6) {
        __label__ = 10; break;
      }
      else {
      __label__ = 11; break;
      }
      
    case 7: 
      var $78=$1;
      var $79=(($78+278)|0);
      HEAP8[($79)]=1;
      __label__ = 11; break;
    case 8: 
      var $81=$1;
      var $82=(($81+278)|0);
      HEAP8[($82)]=3;
      __label__ = 11; break;
    case 9: 
      var $84=$1;
      var $85=(($84+278)|0);
      HEAP8[($85)]=2;
      __label__ = 11; break;
    case 10: 
      var $87=$1;
      var $88=(($87+278)|0);
      HEAP8[($88)]=4;
      __label__ = 11; break;
    case 11: 
      var $90=$1;
      var $91=(($90+275)|0);
      var $92=HEAPU8[($91)];
      var $93=(($92)&255);
      var $94=$1;
      var $95=(($94+278)|0);
      var $96=HEAPU8[($95)];
      var $97=(($96)&255);
      var $98=((($93)*($97))|0);
      var $99=(($98) & 255);
      var $100=$1;
      var $101=(($100+277)|0);
      HEAP8[($101)]=$99;
      var $102=$1;
      var $103=(($102+277)|0);
      var $104=HEAPU8[($103)];
      var $105=(($104)&255);
      var $106=(($105)|0) >= 8;
      if ($106) { __label__ = 12; break; } else { __label__ = 13; break; }
    case 12: 
      var $108=$1;
      var $109=(($108+180)|0);
      var $110=HEAP32[(($109)>>2)];
      var $111=$1;
      var $112=(($111+277)|0);
      var $113=HEAPU8[($112)];
      var $114=(($113)&255);
      var $115=$114 >>> 3;
      var $116=((($110)*($115))|0);
      var $129 = $116;__label__ = 14; break;
    case 13: 
      var $118=$1;
      var $119=(($118+180)|0);
      var $120=HEAP32[(($119)>>2)];
      var $121=$1;
      var $122=(($121+277)|0);
      var $123=HEAPU8[($122)];
      var $124=(($123)&255);
      var $125=((($120)*($124))|0);
      var $126=((($125)+(7))|0);
      var $127=$126 >>> 3;
      var $129 = $127;__label__ = 14; break;
    case 14: 
      var $129;
      var $130=$1;
      var $131=(($130+196)|0);
      HEAP32[(($131)>>2)]=$129;
      var $132=$1;
      var $133=$2;
      var $134=$width;
      var $135=$height;
      var $136=$bit_depth;
      var $137=$color_type;
      var $138=$interlace_type;
      var $139=$compression_type;
      var $140=$filter_type;
      _png_set_IHDR($132, $133, $134, $135, $136, $137, $138, $139, $140);
      STACKTOP = __stackBase__;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_png_handle_IHDR["X"]=1;

function _png_handle_PLTE($png_ptr, $info_ptr, $length) {
  var __stackBase__  = STACKTOP; STACKTOP += 772; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $palette=__stackBase__;
      var $num;
      var $i;
      var $pal_ptr;
      var $buf=(__stackBase__)+(768);
      $1=$png_ptr;
      $2=$info_ptr;
      $3=$length;
      var $4=$1;
      var $5=(($4+84)|0);
      var $6=HEAP32[(($5)>>2)];
      var $7=$6 & 1;
      var $8=(($7)|0)!=0;
      if ($8) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      var $10=$1;
      _png_error($10, ((STRING_TABLE.__str11204)|0));
      __label__ = 10; break;
    case 4: 
      var $12=$1;
      var $13=(($12+84)|0);
      var $14=HEAP32[(($13)>>2)];
      var $15=$14 & 4;
      var $16=(($15)|0)!=0;
      if ($16) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $18=$1;
      _png_warning($18, ((STRING_TABLE.__str12205)|0));
      var $19=$1;
      var $20=$3;
      var $21=_png_crc_finish($19, $20);
      __label__ = 31; break;
    case 6: 
      var $23=$1;
      var $24=(($23+84)|0);
      var $25=HEAP32[(($24)>>2)];
      var $26=$25 & 2;
      var $27=(($26)|0)!=0;
      if ($27) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $29=$1;
      _png_error($29, ((STRING_TABLE.__str13206)|0));
      __label__ = 8; break;
    case 8: 
      __label__ = 9; break;
    case 9: 
      __label__ = 10; break;
    case 10: 
      var $33=$1;
      var $34=(($33+84)|0);
      var $35=HEAP32[(($34)>>2)];
      var $36=$35 | 2;
      HEAP32[(($34)>>2)]=$36;
      var $37=$1;
      var $38=(($37+274)|0);
      var $39=HEAPU8[($38)];
      var $40=(($39)&255);
      var $41=$40 & 2;
      var $42=(($41)|0)!=0;
      if ($42) { __label__ = 12; break; } else { __label__ = 11; break; }
    case 11: 
      var $44=$1;
      _png_warning($44, ((STRING_TABLE.__str14207)|0));
      var $45=$1;
      var $46=$3;
      var $47=_png_crc_finish($45, $46);
      __label__ = 31; break;
    case 12: 
      var $49=$3;
      var $50=(($49)>>>0) > 768;
      if ($50) { __label__ = 14; break; } else { __label__ = 13; break; }
    case 13: 
      var $52=$3;
      var $53=((($52)>>>0))%(3);
      var $54=(($53)|0)!=0;
      if ($54) { __label__ = 14; break; } else { __label__ = 18; break; }
    case 14: 
      var $56=$1;
      var $57=(($56+274)|0);
      var $58=HEAPU8[($57)];
      var $59=(($58)&255);
      var $60=(($59)|0)!=3;
      if ($60) { __label__ = 15; break; } else { __label__ = 16; break; }
    case 15: 
      var $62=$1;
      _png_warning($62, ((STRING_TABLE.__str15208)|0));
      var $63=$1;
      var $64=$3;
      var $65=_png_crc_finish($63, $64);
      __label__ = 31; break;
    case 16: 
      var $67=$1;
      _png_error($67, ((STRING_TABLE.__str15208)|0));
      __label__ = 17; break;
    case 17: 
      __label__ = 18; break;
    case 18: 
      var $70=$3;
      var $71=((((($70)|0))/(3))&-1);
      $num=$71;
      $i=0;
      var $72=(($palette)|0);
      $pal_ptr=$72;
      __label__ = 19; break;
    case 19: 
      var $74=$i;
      var $75=$num;
      var $76=(($74)|0) < (($75)|0);
      if ($76) { __label__ = 20; break; } else { __label__ = 22; break; }
    case 20: 
      var $78=$1;
      var $79=(($buf)|0);
      _png_crc_read($78, $79, 3);
      var $80=(($buf)|0);
      var $81=HEAP8[($80)];
      var $82=$pal_ptr;
      var $83=(($82)|0);
      HEAP8[($83)]=$81;
      var $84=(($buf+1)|0);
      var $85=HEAP8[($84)];
      var $86=$pal_ptr;
      var $87=(($86+1)|0);
      HEAP8[($87)]=$85;
      var $88=(($buf+2)|0);
      var $89=HEAP8[($88)];
      var $90=$pal_ptr;
      var $91=(($90+2)|0);
      HEAP8[($91)]=$89;
      __label__ = 21; break;
    case 21: 
      var $93=$i;
      var $94=((($93)+(1))|0);
      $i=$94;
      var $95=$pal_ptr;
      var $96=(($95+3)|0);
      $pal_ptr=$96;
      __label__ = 19; break;
    case 22: 
      var $98=$1;
      var $99=_png_crc_finish($98, 0);
      var $100=$1;
      var $101=$2;
      var $102=(($palette)|0);
      var $103=$num;
      _png_set_PLTE($100, $101, $102, $103);
      var $104=$1;
      var $105=(($104+274)|0);
      var $106=HEAPU8[($105)];
      var $107=(($106)&255);
      var $108=(($107)|0)==3;
      if ($108) { __label__ = 23; break; } else { __label__ = 31; break; }
    case 23: 
      var $110=$2;
      var $111=(($110)|0)!=0;
      if ($111) { __label__ = 24; break; } else { __label__ = 30; break; }
    case 24: 
      var $113=$2;
      var $114=(($113+8)|0);
      var $115=HEAP32[(($114)>>2)];
      var $116=$115 & 16;
      var $117=(($116)|0)!=0;
      if ($117) { __label__ = 25; break; } else { __label__ = 30; break; }
    case 25: 
      var $119=$1;
      var $120=(($119+262)|0);
      var $121=HEAPU16[(($120)>>1)];
      var $122=(($121)&65535);
      var $123=$num;
      var $124=(($123) & 65535);
      var $125=(($124)&65535);
      var $126=(($122)|0) > (($125)|0);
      if ($126) { __label__ = 26; break; } else { __label__ = 27; break; }
    case 26: 
      var $128=$1;
      _png_warning($128, ((STRING_TABLE.__str16209)|0));
      var $129=$num;
      var $130=(($129) & 65535);
      var $131=$1;
      var $132=(($131+262)|0);
      HEAP16[(($132)>>1)]=$130;
      __label__ = 27; break;
    case 27: 
      var $134=$2;
      var $135=(($134+22)|0);
      var $136=HEAPU16[(($135)>>1)];
      var $137=(($136)&65535);
      var $138=$num;
      var $139=(($138) & 65535);
      var $140=(($139)&65535);
      var $141=(($137)|0) > (($140)|0);
      if ($141) { __label__ = 28; break; } else { __label__ = 29; break; }
    case 28: 
      var $143=$1;
      _png_warning($143, ((STRING_TABLE.__str17210)|0));
      var $144=$num;
      var $145=(($144) & 65535);
      var $146=$2;
      var $147=(($146+22)|0);
      HEAP16[(($147)>>1)]=$145;
      __label__ = 29; break;
    case 29: 
      __label__ = 30; break;
    case 30: 
      __label__ = 31; break;
    case 31: 
      STACKTOP = __stackBase__;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_png_handle_PLTE["X"]=1;

function _png_handle_IEND($png_ptr, $info_ptr, $length) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      $1=$png_ptr;
      $2=$info_ptr;
      $3=$length;
      var $4=$1;
      var $5=(($4+84)|0);
      var $6=HEAP32[(($5)>>2)];
      var $7=$6 & 1;
      var $8=(($7)|0)!=0;
      if ($8) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $10=$1;
      var $11=(($10+84)|0);
      var $12=HEAP32[(($11)>>2)];
      var $13=$12 & 4;
      var $14=(($13)|0)!=0;
      if ($14) { __label__ = 5; break; } else { __label__ = 4; break; }
    case 4: 
      var $16=$1;
      _png_error($16, ((STRING_TABLE.__str18211)|0));
      __label__ = 5; break;
    case 5: 
      var $18=$1;
      var $19=(($18+84)|0);
      var $20=HEAP32[(($19)>>2)];
      var $21=$20 | 24;
      HEAP32[(($19)>>2)]=$21;
      var $22=$3;
      var $23=(($22)|0)!=0;
      if ($23) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      var $25=$1;
      _png_warning($25, ((STRING_TABLE.__str19212)|0));
      __label__ = 7; break;
    case 7: 
      var $27=$1;
      var $28=$3;
      var $29=_png_crc_finish($27, $28);
      var $30=$2;
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}


function _png_handle_gAMA($png_ptr, $info_ptr, $length) {
  var __stackBase__  = STACKTOP; STACKTOP += 4; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $igamma;
      var $file_gamma;
      var $buf=__stackBase__;
      $1=$png_ptr;
      $2=$info_ptr;
      $3=$length;
      var $4=$1;
      var $5=(($4+84)|0);
      var $6=HEAP32[(($5)>>2)];
      var $7=$6 & 1;
      var $8=(($7)|0)!=0;
      if ($8) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      var $10=$1;
      _png_error($10, ((STRING_TABLE.__str20213)|0));
      __label__ = 10; break;
    case 4: 
      var $12=$1;
      var $13=(($12+84)|0);
      var $14=HEAP32[(($13)>>2)];
      var $15=$14 & 4;
      var $16=(($15)|0)!=0;
      if ($16) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $18=$1;
      _png_warning($18, ((STRING_TABLE.__str21214)|0));
      var $19=$1;
      var $20=$3;
      var $21=_png_crc_finish($19, $20);
      __label__ = 27; break;
    case 6: 
      var $23=$1;
      var $24=(($23+84)|0);
      var $25=HEAP32[(($24)>>2)];
      var $26=$25 & 2;
      var $27=(($26)|0)!=0;
      if ($27) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $29=$1;
      _png_warning($29, ((STRING_TABLE.__str22215)|0));
      __label__ = 8; break;
    case 8: 
      __label__ = 9; break;
    case 9: 
      __label__ = 10; break;
    case 10: 
      var $33=$2;
      var $34=(($33)|0)!=0;
      if ($34) { __label__ = 11; break; } else { __label__ = 14; break; }
    case 11: 
      var $36=$2;
      var $37=(($36+8)|0);
      var $38=HEAP32[(($37)>>2)];
      var $39=$38 & 1;
      var $40=(($39)|0)!=0;
      if ($40) { __label__ = 12; break; } else { __label__ = 14; break; }
    case 12: 
      var $42=$2;
      var $43=(($42+8)|0);
      var $44=HEAP32[(($43)>>2)];
      var $45=$44 & 2048;
      var $46=(($45)|0)!=0;
      if ($46) { __label__ = 14; break; } else { __label__ = 13; break; }
    case 13: 
      var $48=$1;
      _png_warning($48, ((STRING_TABLE.__str23216)|0));
      var $49=$1;
      var $50=$3;
      var $51=_png_crc_finish($49, $50);
      __label__ = 27; break;
    case 14: 
      var $53=$3;
      var $54=(($53)|0)!=4;
      if ($54) { __label__ = 15; break; } else { __label__ = 16; break; }
    case 15: 
      var $56=$1;
      _png_warning($56, ((STRING_TABLE.__str24217)|0));
      var $57=$1;
      var $58=$3;
      var $59=_png_crc_finish($57, $58);
      __label__ = 27; break;
    case 16: 
      var $61=$1;
      var $62=(($buf)|0);
      _png_crc_read($61, $62, 4);
      var $63=$1;
      var $64=_png_crc_finish($63, 0);
      var $65=(($64)|0)!=0;
      if ($65) { __label__ = 17; break; } else { __label__ = 18; break; }
    case 17: 
      __label__ = 27; break;
    case 18: 
      var $68=(($buf)|0);
      var $69=HEAPU8[($68)];
      var $70=(($69)&255);
      var $71=$70 << 24;
      var $72=(($buf)|0);
      var $73=(($72+1)|0);
      var $74=HEAPU8[($73)];
      var $75=(($74)&255);
      var $76=$75 << 16;
      var $77=((($71)+($76))|0);
      var $78=(($buf)|0);
      var $79=(($78+2)|0);
      var $80=HEAPU8[($79)];
      var $81=(($80)&255);
      var $82=$81 << 8;
      var $83=((($77)+($82))|0);
      var $84=(($buf)|0);
      var $85=(($84+3)|0);
      var $86=HEAPU8[($85)];
      var $87=(($86)&255);
      var $88=((($83)+($87))|0);
      $igamma=$88;
      var $89=$igamma;
      var $90=(($89)|0)==0;
      if ($90) { __label__ = 19; break; } else { __label__ = 20; break; }
    case 19: 
      var $92=$1;
      _png_warning($92, ((STRING_TABLE.__str25218)|0));
      __label__ = 27; break;
    case 20: 
      var $94=$2;
      var $95=(($94)|0)!=0;
      if ($95) { __label__ = 21; break; } else { __label__ = 26; break; }
    case 21: 
      var $97=$2;
      var $98=(($97+8)|0);
      var $99=HEAP32[(($98)>>2)];
      var $100=$99 & 2048;
      var $101=(($100)|0)!=0;
      if ($101) { __label__ = 22; break; } else { __label__ = 26; break; }
    case 22: 
      var $103=$igamma;
      var $104=(($103)|0) < 45000;
      if ($104) { __label__ = 24; break; } else { __label__ = 23; break; }
    case 23: 
      var $106=$igamma;
      var $107=(($106)|0) > 46000;
      if ($107) { __label__ = 24; break; } else { __label__ = 25; break; }
    case 24: 
      var $109=$1;
      _png_warning($109, ((STRING_TABLE.__str26219)|0));
      var $110=HEAP32[((_stderr)>>2)];
      var $111=$igamma;
      var $112=_fprintf($110, ((STRING_TABLE.__str27220)|0), (tempInt=STACKTOP,STACKTOP += 4,assert(STACKTOP < STACK_ROOT + STACK_MAX, "Ran out of stack"),HEAP32[((tempInt)>>2)]=$111,tempInt));
      __label__ = 27; break;
    case 25: 
      __label__ = 26; break;
    case 26: 
      var $115=$igamma;
      var $116=(($115)|0);
      var $117=($116)/(100000);
      $file_gamma=$117;
      var $118=$file_gamma;
      var $119=$1;
      var $120=(($119+328)|0);
      HEAPF32[(($120)>>2)]=$118;
      var $121=$1;
      var $122=$2;
      var $123=$file_gamma;
      var $124=$123;
      _png_set_gAMA($121, $122, $124);
      var $125=$1;
      var $126=$2;
      var $127=$igamma;
      _png_set_gAMA_fixed($125, $126, $127);
      __label__ = 27; break;
    case 27: 
      STACKTOP = __stackBase__;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_png_handle_gAMA["X"]=1;

function _png_handle_sBIT($png_ptr, $info_ptr, $length) {
  var __stackBase__  = STACKTOP; STACKTOP += 4; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $truelen;
      var $buf=__stackBase__;
      $1=$png_ptr;
      $2=$info_ptr;
      $3=$length;
      var $4=(($buf+3)|0);
      HEAP8[($4)]=0;
      var $5=(($buf+2)|0);
      HEAP8[($5)]=0;
      var $6=(($buf+1)|0);
      HEAP8[($6)]=0;
      var $7=(($buf)|0);
      HEAP8[($7)]=0;
      var $8=$1;
      var $9=(($8+84)|0);
      var $10=HEAP32[(($9)>>2)];
      var $11=$10 & 1;
      var $12=(($11)|0)!=0;
      if ($12) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      var $14=$1;
      _png_error($14, ((STRING_TABLE.__str28221)|0));
      __label__ = 10; break;
    case 4: 
      var $16=$1;
      var $17=(($16+84)|0);
      var $18=HEAP32[(($17)>>2)];
      var $19=$18 & 4;
      var $20=(($19)|0)!=0;
      if ($20) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $22=$1;
      _png_warning($22, ((STRING_TABLE.__str29222)|0));
      var $23=$1;
      var $24=$3;
      var $25=_png_crc_finish($23, $24);
      __label__ = 25; break;
    case 6: 
      var $27=$1;
      var $28=(($27+84)|0);
      var $29=HEAP32[(($28)>>2)];
      var $30=$29 & 2;
      var $31=(($30)|0)!=0;
      if ($31) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $33=$1;
      _png_warning($33, ((STRING_TABLE.__str30)|0));
      __label__ = 8; break;
    case 8: 
      __label__ = 9; break;
    case 9: 
      __label__ = 10; break;
    case 10: 
      var $37=$2;
      var $38=(($37)|0)!=0;
      if ($38) { __label__ = 11; break; } else { __label__ = 13; break; }
    case 11: 
      var $40=$2;
      var $41=(($40+8)|0);
      var $42=HEAP32[(($41)>>2)];
      var $43=$42 & 2;
      var $44=(($43)|0)!=0;
      if ($44) { __label__ = 12; break; } else { __label__ = 13; break; }
    case 12: 
      var $46=$1;
      _png_warning($46, ((STRING_TABLE.__str31)|0));
      var $47=$1;
      var $48=$3;
      var $49=_png_crc_finish($47, $48);
      __label__ = 25; break;
    case 13: 
      var $51=$1;
      var $52=(($51+274)|0);
      var $53=HEAPU8[($52)];
      var $54=(($53)&255);
      var $55=(($54)|0)==3;
      if ($55) { __label__ = 14; break; } else { __label__ = 15; break; }
    case 14: 
      $truelen=3;
      __label__ = 16; break;
    case 15: 
      var $58=$1;
      var $59=(($58+278)|0);
      var $60=HEAPU8[($59)];
      var $61=(($60)&255);
      $truelen=$61;
      __label__ = 16; break;
    case 16: 
      var $63=$3;
      var $64=$truelen;
      var $65=(($63)|0)!=(($64)|0);
      if ($65) { __label__ = 18; break; } else { __label__ = 17; break; }
    case 17: 
      var $67=$3;
      var $68=(($67)>>>0) > 4;
      if ($68) { __label__ = 18; break; } else { __label__ = 19; break; }
    case 18: 
      var $70=$1;
      _png_warning($70, ((STRING_TABLE.__str32)|0));
      var $71=$1;
      var $72=$3;
      var $73=_png_crc_finish($71, $72);
      __label__ = 25; break;
    case 19: 
      var $75=$1;
      var $76=(($buf)|0);
      var $77=$truelen;
      _png_crc_read($75, $76, $77);
      var $78=$1;
      var $79=_png_crc_finish($78, 0);
      var $80=(($79)|0)!=0;
      if ($80) { __label__ = 20; break; } else { __label__ = 21; break; }
    case 20: 
      __label__ = 25; break;
    case 21: 
      var $83=$1;
      var $84=(($83+274)|0);
      var $85=HEAPU8[($84)];
      var $86=(($85)&255);
      var $87=$86 & 2;
      var $88=(($87)|0)!=0;
      if ($88) { __label__ = 22; break; } else { __label__ = 23; break; }
    case 22: 
      var $90=(($buf)|0);
      var $91=HEAP8[($90)];
      var $92=$1;
      var $93=(($92+360)|0);
      var $94=(($93)|0);
      HEAP8[($94)]=$91;
      var $95=(($buf+1)|0);
      var $96=HEAP8[($95)];
      var $97=$1;
      var $98=(($97+360)|0);
      var $99=(($98+1)|0);
      HEAP8[($99)]=$96;
      var $100=(($buf+2)|0);
      var $101=HEAP8[($100)];
      var $102=$1;
      var $103=(($102+360)|0);
      var $104=(($103+2)|0);
      HEAP8[($104)]=$101;
      var $105=(($buf+3)|0);
      var $106=HEAP8[($105)];
      var $107=$1;
      var $108=(($107+360)|0);
      var $109=(($108+4)|0);
      HEAP8[($109)]=$106;
      __label__ = 24; break;
    case 23: 
      var $111=(($buf)|0);
      var $112=HEAP8[($111)];
      var $113=$1;
      var $114=(($113+360)|0);
      var $115=(($114+3)|0);
      HEAP8[($115)]=$112;
      var $116=(($buf)|0);
      var $117=HEAP8[($116)];
      var $118=$1;
      var $119=(($118+360)|0);
      var $120=(($119)|0);
      HEAP8[($120)]=$117;
      var $121=(($buf)|0);
      var $122=HEAP8[($121)];
      var $123=$1;
      var $124=(($123+360)|0);
      var $125=(($124+1)|0);
      HEAP8[($125)]=$122;
      var $126=(($buf)|0);
      var $127=HEAP8[($126)];
      var $128=$1;
      var $129=(($128+360)|0);
      var $130=(($129+2)|0);
      HEAP8[($130)]=$127;
      var $131=(($buf+1)|0);
      var $132=HEAP8[($131)];
      var $133=$1;
      var $134=(($133+360)|0);
      var $135=(($134+4)|0);
      HEAP8[($135)]=$132;
      __label__ = 24; break;
    case 24: 
      var $137=$1;
      var $138=$2;
      var $139=$1;
      var $140=(($139+360)|0);
      _png_set_sBIT($137, $138, $140);
      __label__ = 25; break;
    case 25: 
      STACKTOP = __stackBase__;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_png_handle_sBIT["X"]=1;

function _png_handle_cHRM($png_ptr, $info_ptr, $length) {
  var __stackBase__  = STACKTOP; STACKTOP += 32; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $buf=__stackBase__;
      var $white_x;
      var $white_y;
      var $red_x;
      var $red_y;
      var $green_x;
      var $green_y;
      var $blue_x;
      var $blue_y;
      var $int_x_white;
      var $int_y_white;
      var $int_x_red;
      var $int_y_red;
      var $int_x_green;
      var $int_y_green;
      var $int_x_blue;
      var $int_y_blue;
      var $uint_x;
      var $uint_y;
      $1=$png_ptr;
      $2=$info_ptr;
      $3=$length;
      var $4=$1;
      var $5=(($4+84)|0);
      var $6=HEAP32[(($5)>>2)];
      var $7=$6 & 1;
      var $8=(($7)|0)!=0;
      if ($8) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      var $10=$1;
      _png_error($10, ((STRING_TABLE.__str33)|0));
      __label__ = 10; break;
    case 4: 
      var $12=$1;
      var $13=(($12+84)|0);
      var $14=HEAP32[(($13)>>2)];
      var $15=$14 & 4;
      var $16=(($15)|0)!=0;
      if ($16) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $18=$1;
      _png_warning($18, ((STRING_TABLE.__str34223)|0));
      var $19=$1;
      var $20=$3;
      var $21=_png_crc_finish($19, $20);
      __label__ = 39; break;
    case 6: 
      var $23=$1;
      var $24=(($23+84)|0);
      var $25=HEAP32[(($24)>>2)];
      var $26=$25 & 2;
      var $27=(($26)|0)!=0;
      if ($27) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $29=$1;
      _png_warning($29, ((STRING_TABLE.__str35)|0));
      __label__ = 8; break;
    case 8: 
      __label__ = 9; break;
    case 9: 
      __label__ = 10; break;
    case 10: 
      var $33=$2;
      var $34=(($33)|0)!=0;
      if ($34) { __label__ = 11; break; } else { __label__ = 14; break; }
    case 11: 
      var $36=$2;
      var $37=(($36+8)|0);
      var $38=HEAP32[(($37)>>2)];
      var $39=$38 & 4;
      var $40=(($39)|0)!=0;
      if ($40) { __label__ = 12; break; } else { __label__ = 14; break; }
    case 12: 
      var $42=$2;
      var $43=(($42+8)|0);
      var $44=HEAP32[(($43)>>2)];
      var $45=$44 & 2048;
      var $46=(($45)|0)!=0;
      if ($46) { __label__ = 14; break; } else { __label__ = 13; break; }
    case 13: 
      var $48=$1;
      _png_warning($48, ((STRING_TABLE.__str36)|0));
      var $49=$1;
      var $50=$3;
      var $51=_png_crc_finish($49, $50);
      __label__ = 39; break;
    case 14: 
      var $53=$3;
      var $54=(($53)|0)!=32;
      if ($54) { __label__ = 15; break; } else { __label__ = 16; break; }
    case 15: 
      var $56=$1;
      _png_warning($56, ((STRING_TABLE.__str37)|0));
      var $57=$1;
      var $58=$3;
      var $59=_png_crc_finish($57, $58);
      __label__ = 39; break;
    case 16: 
      var $61=$1;
      var $62=(($buf)|0);
      _png_crc_read($61, $62, 32);
      var $63=$1;
      var $64=_png_crc_finish($63, 0);
      var $65=(($64)|0)!=0;
      if ($65) { __label__ = 17; break; } else { __label__ = 18; break; }
    case 17: 
      __label__ = 39; break;
    case 18: 
      var $68=(($buf)|0);
      var $69=HEAPU8[($68)];
      var $70=(($69)&255);
      var $71=$70 << 24;
      var $72=(($buf)|0);
      var $73=(($72+1)|0);
      var $74=HEAPU8[($73)];
      var $75=(($74)&255);
      var $76=$75 << 16;
      var $77=((($71)+($76))|0);
      var $78=(($buf)|0);
      var $79=(($78+2)|0);
      var $80=HEAPU8[($79)];
      var $81=(($80)&255);
      var $82=$81 << 8;
      var $83=((($77)+($82))|0);
      var $84=(($buf)|0);
      var $85=(($84+3)|0);
      var $86=HEAPU8[($85)];
      var $87=(($86)&255);
      var $88=((($83)+($87))|0);
      $uint_x=$88;
      var $89=(($buf)|0);
      var $90=(($89+4)|0);
      var $91=HEAPU8[($90)];
      var $92=(($91)&255);
      var $93=$92 << 24;
      var $94=(($buf)|0);
      var $95=(($94+4)|0);
      var $96=(($95+1)|0);
      var $97=HEAPU8[($96)];
      var $98=(($97)&255);
      var $99=$98 << 16;
      var $100=((($93)+($99))|0);
      var $101=(($buf)|0);
      var $102=(($101+4)|0);
      var $103=(($102+2)|0);
      var $104=HEAPU8[($103)];
      var $105=(($104)&255);
      var $106=$105 << 8;
      var $107=((($100)+($106))|0);
      var $108=(($buf)|0);
      var $109=(($108+4)|0);
      var $110=(($109+3)|0);
      var $111=HEAPU8[($110)];
      var $112=(($111)&255);
      var $113=((($107)+($112))|0);
      $uint_y=$113;
      var $114=$uint_x;
      $int_x_white=$114;
      var $115=$uint_y;
      $int_y_white=$115;
      var $116=(($buf)|0);
      var $117=(($116+8)|0);
      var $118=HEAPU8[($117)];
      var $119=(($118)&255);
      var $120=$119 << 24;
      var $121=(($buf)|0);
      var $122=(($121+8)|0);
      var $123=(($122+1)|0);
      var $124=HEAPU8[($123)];
      var $125=(($124)&255);
      var $126=$125 << 16;
      var $127=((($120)+($126))|0);
      var $128=(($buf)|0);
      var $129=(($128+8)|0);
      var $130=(($129+2)|0);
      var $131=HEAPU8[($130)];
      var $132=(($131)&255);
      var $133=$132 << 8;
      var $134=((($127)+($133))|0);
      var $135=(($buf)|0);
      var $136=(($135+8)|0);
      var $137=(($136+3)|0);
      var $138=HEAPU8[($137)];
      var $139=(($138)&255);
      var $140=((($134)+($139))|0);
      $uint_x=$140;
      var $141=(($buf)|0);
      var $142=(($141+12)|0);
      var $143=HEAPU8[($142)];
      var $144=(($143)&255);
      var $145=$144 << 24;
      var $146=(($buf)|0);
      var $147=(($146+12)|0);
      var $148=(($147+1)|0);
      var $149=HEAPU8[($148)];
      var $150=(($149)&255);
      var $151=$150 << 16;
      var $152=((($145)+($151))|0);
      var $153=(($buf)|0);
      var $154=(($153+12)|0);
      var $155=(($154+2)|0);
      var $156=HEAPU8[($155)];
      var $157=(($156)&255);
      var $158=$157 << 8;
      var $159=((($152)+($158))|0);
      var $160=(($buf)|0);
      var $161=(($160+12)|0);
      var $162=(($161+3)|0);
      var $163=HEAPU8[($162)];
      var $164=(($163)&255);
      var $165=((($159)+($164))|0);
      $uint_y=$165;
      var $166=$uint_x;
      $int_x_red=$166;
      var $167=$uint_y;
      $int_y_red=$167;
      var $168=(($buf)|0);
      var $169=(($168+16)|0);
      var $170=HEAPU8[($169)];
      var $171=(($170)&255);
      var $172=$171 << 24;
      var $173=(($buf)|0);
      var $174=(($173+16)|0);
      var $175=(($174+1)|0);
      var $176=HEAPU8[($175)];
      var $177=(($176)&255);
      var $178=$177 << 16;
      var $179=((($172)+($178))|0);
      var $180=(($buf)|0);
      var $181=(($180+16)|0);
      var $182=(($181+2)|0);
      var $183=HEAPU8[($182)];
      var $184=(($183)&255);
      var $185=$184 << 8;
      var $186=((($179)+($185))|0);
      var $187=(($buf)|0);
      var $188=(($187+16)|0);
      var $189=(($188+3)|0);
      var $190=HEAPU8[($189)];
      var $191=(($190)&255);
      var $192=((($186)+($191))|0);
      $uint_x=$192;
      var $193=(($buf)|0);
      var $194=(($193+20)|0);
      var $195=HEAPU8[($194)];
      var $196=(($195)&255);
      var $197=$196 << 24;
      var $198=(($buf)|0);
      var $199=(($198+20)|0);
      var $200=(($199+1)|0);
      var $201=HEAPU8[($200)];
      var $202=(($201)&255);
      var $203=$202 << 16;
      var $204=((($197)+($203))|0);
      var $205=(($buf)|0);
      var $206=(($205+20)|0);
      var $207=(($206+2)|0);
      var $208=HEAPU8[($207)];
      var $209=(($208)&255);
      var $210=$209 << 8;
      var $211=((($204)+($210))|0);
      var $212=(($buf)|0);
      var $213=(($212+20)|0);
      var $214=(($213+3)|0);
      var $215=HEAPU8[($214)];
      var $216=(($215)&255);
      var $217=((($211)+($216))|0);
      $uint_y=$217;
      var $218=$uint_x;
      $int_x_green=$218;
      var $219=$uint_y;
      $int_y_green=$219;
      var $220=(($buf)|0);
      var $221=(($220+24)|0);
      var $222=HEAPU8[($221)];
      var $223=(($222)&255);
      var $224=$223 << 24;
      var $225=(($buf)|0);
      var $226=(($225+24)|0);
      var $227=(($226+1)|0);
      var $228=HEAPU8[($227)];
      var $229=(($228)&255);
      var $230=$229 << 16;
      var $231=((($224)+($230))|0);
      var $232=(($buf)|0);
      var $233=(($232+24)|0);
      var $234=(($233+2)|0);
      var $235=HEAPU8[($234)];
      var $236=(($235)&255);
      var $237=$236 << 8;
      var $238=((($231)+($237))|0);
      var $239=(($buf)|0);
      var $240=(($239+24)|0);
      var $241=(($240+3)|0);
      var $242=HEAPU8[($241)];
      var $243=(($242)&255);
      var $244=((($238)+($243))|0);
      $uint_x=$244;
      var $245=(($buf)|0);
      var $246=(($245+28)|0);
      var $247=HEAPU8[($246)];
      var $248=(($247)&255);
      var $249=$248 << 24;
      var $250=(($buf)|0);
      var $251=(($250+28)|0);
      var $252=(($251+1)|0);
      var $253=HEAPU8[($252)];
      var $254=(($253)&255);
      var $255=$254 << 16;
      var $256=((($249)+($255))|0);
      var $257=(($buf)|0);
      var $258=(($257+28)|0);
      var $259=(($258+2)|0);
      var $260=HEAPU8[($259)];
      var $261=(($260)&255);
      var $262=$261 << 8;
      var $263=((($256)+($262))|0);
      var $264=(($buf)|0);
      var $265=(($264+28)|0);
      var $266=(($265+3)|0);
      var $267=HEAPU8[($266)];
      var $268=(($267)&255);
      var $269=((($263)+($268))|0);
      $uint_y=$269;
      var $270=$uint_x;
      $int_x_blue=$270;
      var $271=$uint_y;
      $int_y_blue=$271;
      var $272=$int_x_white;
      var $273=(($272)|0);
      var $274=($273)/(100000);
      $white_x=$274;
      var $275=$int_y_white;
      var $276=(($275)|0);
      var $277=($276)/(100000);
      $white_y=$277;
      var $278=$int_x_red;
      var $279=(($278)|0);
      var $280=($279)/(100000);
      $red_x=$280;
      var $281=$int_y_red;
      var $282=(($281)|0);
      var $283=($282)/(100000);
      $red_y=$283;
      var $284=$int_x_green;
      var $285=(($284)|0);
      var $286=($285)/(100000);
      $green_x=$286;
      var $287=$int_y_green;
      var $288=(($287)|0);
      var $289=($288)/(100000);
      $green_y=$289;
      var $290=$int_x_blue;
      var $291=(($290)|0);
      var $292=($291)/(100000);
      $blue_x=$292;
      var $293=$int_y_blue;
      var $294=(($293)|0);
      var $295=($294)/(100000);
      $blue_y=$295;
      var $296=$2;
      var $297=(($296)|0)!=0;
      if ($297) { __label__ = 19; break; } else { __label__ = 38; break; }
    case 19: 
      var $299=$2;
      var $300=(($299+8)|0);
      var $301=HEAP32[(($300)>>2)];
      var $302=$301 & 2048;
      var $303=(($302)|0)!=0;
      if ($303) { __label__ = 20; break; } else { __label__ = 38; break; }
    case 20: 
      var $305=$int_x_white;
      var $306=(($305)|0) < 30270;
      if ($306) { __label__ = 36; break; } else { __label__ = 21; break; }
    case 21: 
      var $308=$int_x_white;
      var $309=(($308)|0) > 32270;
      if ($309) { __label__ = 36; break; } else { __label__ = 22; break; }
    case 22: 
      var $311=$int_y_white;
      var $312=(($311)|0) < 31900;
      if ($312) { __label__ = 36; break; } else { __label__ = 23; break; }
    case 23: 
      var $314=$int_y_white;
      var $315=(($314)|0) > 33900;
      if ($315) { __label__ = 36; break; } else { __label__ = 24; break; }
    case 24: 
      var $317=$int_x_red;
      var $318=(($317)|0) < 63000;
      if ($318) { __label__ = 36; break; } else { __label__ = 25; break; }
    case 25: 
      var $320=$int_x_red;
      var $321=(($320)|0) > 65000;
      if ($321) { __label__ = 36; break; } else { __label__ = 26; break; }
    case 26: 
      var $323=$int_y_red;
      var $324=(($323)|0) < 32000;
      if ($324) { __label__ = 36; break; } else { __label__ = 27; break; }
    case 27: 
      var $326=$int_y_red;
      var $327=(($326)|0) > 34000;
      if ($327) { __label__ = 36; break; } else { __label__ = 28; break; }
    case 28: 
      var $329=$int_x_green;
      var $330=(($329)|0) < 29000;
      if ($330) { __label__ = 36; break; } else { __label__ = 29; break; }
    case 29: 
      var $332=$int_x_green;
      var $333=(($332)|0) > 31000;
      if ($333) { __label__ = 36; break; } else { __label__ = 30; break; }
    case 30: 
      var $335=$int_y_green;
      var $336=(($335)|0) < 59000;
      if ($336) { __label__ = 36; break; } else { __label__ = 31; break; }
    case 31: 
      var $338=$int_y_green;
      var $339=(($338)|0) > 61000;
      if ($339) { __label__ = 36; break; } else { __label__ = 32; break; }
    case 32: 
      var $341=$int_x_blue;
      var $342=(($341)|0) < 14000;
      if ($342) { __label__ = 36; break; } else { __label__ = 33; break; }
    case 33: 
      var $344=$int_x_blue;
      var $345=(($344)|0) > 16000;
      if ($345) { __label__ = 36; break; } else { __label__ = 34; break; }
    case 34: 
      var $347=$int_y_blue;
      var $348=(($347)|0) < 5000;
      if ($348) { __label__ = 36; break; } else { __label__ = 35; break; }
    case 35: 
      var $350=$int_y_blue;
      var $351=(($350)|0) > 7000;
      if ($351) { __label__ = 36; break; } else { __label__ = 37; break; }
    case 36: 
      var $353=$1;
      _png_warning($353, ((STRING_TABLE.__str38)|0));
      var $354=HEAP32[((_stderr)>>2)];
      var $355=$white_x;
      var $356=$355;
      var $357=$white_y;
      var $358=$357;
      var $359=$red_x;
      var $360=$359;
      var $361=$red_y;
      var $362=$361;
      var $363=_fprintf($354, ((STRING_TABLE.__str39)|0), (tempInt=STACKTOP,STACKTOP += 32,assert(STACKTOP < STACK_ROOT + STACK_MAX, "Ran out of stack"),(tempDoubleF64[0]=$356,HEAP32[((tempInt)>>2)]=tempDoubleI32[0],HEAP32[(((tempInt)+(4))>>2)]=tempDoubleI32[1]),(tempDoubleF64[0]=$358,HEAP32[(((tempInt)+(8))>>2)]=tempDoubleI32[0],HEAP32[((((tempInt)+(8))+(4))>>2)]=tempDoubleI32[1]),(tempDoubleF64[0]=$360,HEAP32[(((tempInt)+(16))>>2)]=tempDoubleI32[0],HEAP32[((((tempInt)+(16))+(4))>>2)]=tempDoubleI32[1]),(tempDoubleF64[0]=$362,HEAP32[(((tempInt)+(24))>>2)]=tempDoubleI32[0],HEAP32[((((tempInt)+(24))+(4))>>2)]=tempDoubleI32[1]),tempInt));
      var $364=HEAP32[((_stderr)>>2)];
      var $365=$green_x;
      var $366=$365;
      var $367=$green_y;
      var $368=$367;
      var $369=$blue_x;
      var $370=$369;
      var $371=$blue_y;
      var $372=$371;
      var $373=_fprintf($364, ((STRING_TABLE.__str40)|0), (tempInt=STACKTOP,STACKTOP += 32,assert(STACKTOP < STACK_ROOT + STACK_MAX, "Ran out of stack"),(tempDoubleF64[0]=$366,HEAP32[((tempInt)>>2)]=tempDoubleI32[0],HEAP32[(((tempInt)+(4))>>2)]=tempDoubleI32[1]),(tempDoubleF64[0]=$368,HEAP32[(((tempInt)+(8))>>2)]=tempDoubleI32[0],HEAP32[((((tempInt)+(8))+(4))>>2)]=tempDoubleI32[1]),(tempDoubleF64[0]=$370,HEAP32[(((tempInt)+(16))>>2)]=tempDoubleI32[0],HEAP32[((((tempInt)+(16))+(4))>>2)]=tempDoubleI32[1]),(tempDoubleF64[0]=$372,HEAP32[(((tempInt)+(24))>>2)]=tempDoubleI32[0],HEAP32[((((tempInt)+(24))+(4))>>2)]=tempDoubleI32[1]),tempInt));
      __label__ = 37; break;
    case 37: 
      __label__ = 39; break;
    case 38: 
      var $376=$1;
      var $377=$2;
      var $378=$white_x;
      var $379=$378;
      var $380=$white_y;
      var $381=$380;
      var $382=$red_x;
      var $383=$382;
      var $384=$red_y;
      var $385=$384;
      var $386=$green_x;
      var $387=$386;
      var $388=$green_y;
      var $389=$388;
      var $390=$blue_x;
      var $391=$390;
      var $392=$blue_y;
      var $393=$392;
      _png_set_cHRM($376, $377, $379, $381, $383, $385, $387, $389, $391, $393);
      var $394=$1;
      var $395=$2;
      var $396=$int_x_white;
      var $397=$int_y_white;
      var $398=$int_x_red;
      var $399=$int_y_red;
      var $400=$int_x_green;
      var $401=$int_y_green;
      var $402=$int_x_blue;
      var $403=$int_y_blue;
      _png_set_cHRM_fixed($394, $395, $396, $397, $398, $399, $400, $401, $402, $403);
      __label__ = 39; break;
    case 39: 
      STACKTOP = __stackBase__;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_png_handle_cHRM["X"]=1;

function _png_handle_sRGB($png_ptr, $info_ptr, $length) {
  var __stackBase__  = STACKTOP; STACKTOP += 4; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $intent;
      var $buf=__stackBase__;
      var $igamma;
      $1=$png_ptr;
      $2=$info_ptr;
      $3=$length;
      var $4=$1;
      var $5=(($4+84)|0);
      var $6=HEAP32[(($5)>>2)];
      var $7=$6 & 1;
      var $8=(($7)|0)!=0;
      if ($8) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      var $10=$1;
      _png_error($10, ((STRING_TABLE.__str41)|0));
      __label__ = 10; break;
    case 4: 
      var $12=$1;
      var $13=(($12+84)|0);
      var $14=HEAP32[(($13)>>2)];
      var $15=$14 & 4;
      var $16=(($15)|0)!=0;
      if ($16) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $18=$1;
      _png_warning($18, ((STRING_TABLE.__str42)|0));
      var $19=$1;
      var $20=$3;
      var $21=_png_crc_finish($19, $20);
      __label__ = 46; break;
    case 6: 
      var $23=$1;
      var $24=(($23+84)|0);
      var $25=HEAP32[(($24)>>2)];
      var $26=$25 & 2;
      var $27=(($26)|0)!=0;
      if ($27) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $29=$1;
      _png_warning($29, ((STRING_TABLE.__str43)|0));
      __label__ = 8; break;
    case 8: 
      __label__ = 9; break;
    case 9: 
      __label__ = 10; break;
    case 10: 
      var $33=$2;
      var $34=(($33)|0)!=0;
      if ($34) { __label__ = 11; break; } else { __label__ = 13; break; }
    case 11: 
      var $36=$2;
      var $37=(($36+8)|0);
      var $38=HEAP32[(($37)>>2)];
      var $39=$38 & 2048;
      var $40=(($39)|0)!=0;
      if ($40) { __label__ = 12; break; } else { __label__ = 13; break; }
    case 12: 
      var $42=$1;
      _png_warning($42, ((STRING_TABLE.__str44)|0));
      var $43=$1;
      var $44=$3;
      var $45=_png_crc_finish($43, $44);
      __label__ = 46; break;
    case 13: 
      var $47=$3;
      var $48=(($47)|0)!=1;
      if ($48) { __label__ = 14; break; } else { __label__ = 15; break; }
    case 14: 
      var $50=$1;
      _png_warning($50, ((STRING_TABLE.__str45)|0));
      var $51=$1;
      var $52=$3;
      var $53=_png_crc_finish($51, $52);
      __label__ = 46; break;
    case 15: 
      var $55=$1;
      var $56=(($buf)|0);
      _png_crc_read($55, $56, 1);
      var $57=$1;
      var $58=_png_crc_finish($57, 0);
      var $59=(($58)|0)!=0;
      if ($59) { __label__ = 16; break; } else { __label__ = 17; break; }
    case 16: 
      __label__ = 46; break;
    case 17: 
      var $62=(($buf)|0);
      var $63=HEAPU8[($62)];
      var $64=(($63)&255);
      $intent=$64;
      var $65=$intent;
      var $66=(($65)|0) >= 4;
      if ($66) { __label__ = 18; break; } else { __label__ = 19; break; }
    case 18: 
      var $68=$1;
      _png_warning($68, ((STRING_TABLE.__str46)|0));
      __label__ = 46; break;
    case 19: 
      var $70=$2;
      var $71=(($70)|0)!=0;
      if ($71) { __label__ = 20; break; } else { __label__ = 25; break; }
    case 20: 
      var $73=$2;
      var $74=(($73+8)|0);
      var $75=HEAP32[(($74)>>2)];
      var $76=$75 & 1;
      var $77=(($76)|0)!=0;
      if ($77) { __label__ = 21; break; } else { __label__ = 25; break; }
    case 21: 
      var $79=$2;
      var $80=(($79+252)|0);
      var $81=HEAP32[(($80)>>2)];
      $igamma=$81;
      var $82=$igamma;
      var $83=(($82)|0) < 45000;
      if ($83) { __label__ = 23; break; } else { __label__ = 22; break; }
    case 22: 
      var $85=$igamma;
      var $86=(($85)|0) > 46000;
      if ($86) { __label__ = 23; break; } else { __label__ = 24; break; }
    case 23: 
      var $88=$1;
      _png_warning($88, ((STRING_TABLE.__str26219)|0));
      var $89=HEAP32[((_stderr)>>2)];
      var $90=$1;
      var $91=(($90+544)|0);
      var $92=HEAP32[(($91)>>2)];
      var $93=_fprintf($89, ((STRING_TABLE.__str47)|0), (tempInt=STACKTOP,STACKTOP += 4,assert(STACKTOP < STACK_ROOT + STACK_MAX, "Ran out of stack"),HEAP32[((tempInt)>>2)]=$92,tempInt));
      __label__ = 24; break;
    case 24: 
      __label__ = 25; break;
    case 25: 
      var $96=$2;
      var $97=(($96)|0)!=0;
      if ($97) { __label__ = 26; break; } else { __label__ = 45; break; }
    case 26: 
      var $99=$2;
      var $100=(($99+8)|0);
      var $101=HEAP32[(($100)>>2)];
      var $102=$101 & 4;
      var $103=(($102)|0)!=0;
      if ($103) { __label__ = 27; break; } else { __label__ = 45; break; }
    case 27: 
      var $105=$2;
      var $106=(($105+256)|0);
      var $107=HEAP32[(($106)>>2)];
      var $108=(($107)|0) < 30270;
      if ($108) { __label__ = 43; break; } else { __label__ = 28; break; }
    case 28: 
      var $110=$2;
      var $111=(($110+256)|0);
      var $112=HEAP32[(($111)>>2)];
      var $113=(($112)|0) > 32270;
      if ($113) { __label__ = 43; break; } else { __label__ = 29; break; }
    case 29: 
      var $115=$2;
      var $116=(($115+260)|0);
      var $117=HEAP32[(($116)>>2)];
      var $118=(($117)|0) < 31900;
      if ($118) { __label__ = 43; break; } else { __label__ = 30; break; }
    case 30: 
      var $120=$2;
      var $121=(($120+260)|0);
      var $122=HEAP32[(($121)>>2)];
      var $123=(($122)|0) > 33900;
      if ($123) { __label__ = 43; break; } else { __label__ = 31; break; }
    case 31: 
      var $125=$2;
      var $126=(($125+264)|0);
      var $127=HEAP32[(($126)>>2)];
      var $128=(($127)|0) < 63000;
      if ($128) { __label__ = 43; break; } else { __label__ = 32; break; }
    case 32: 
      var $130=$2;
      var $131=(($130+264)|0);
      var $132=HEAP32[(($131)>>2)];
      var $133=(($132)|0) > 65000;
      if ($133) { __label__ = 43; break; } else { __label__ = 33; break; }
    case 33: 
      var $135=$2;
      var $136=(($135+268)|0);
      var $137=HEAP32[(($136)>>2)];
      var $138=(($137)|0) < 32000;
      if ($138) { __label__ = 43; break; } else { __label__ = 34; break; }
    case 34: 
      var $140=$2;
      var $141=(($140+268)|0);
      var $142=HEAP32[(($141)>>2)];
      var $143=(($142)|0) > 34000;
      if ($143) { __label__ = 43; break; } else { __label__ = 35; break; }
    case 35: 
      var $145=$2;
      var $146=(($145+272)|0);
      var $147=HEAP32[(($146)>>2)];
      var $148=(($147)|0) < 29000;
      if ($148) { __label__ = 43; break; } else { __label__ = 36; break; }
    case 36: 
      var $150=$2;
      var $151=(($150+272)|0);
      var $152=HEAP32[(($151)>>2)];
      var $153=(($152)|0) > 31000;
      if ($153) { __label__ = 43; break; } else { __label__ = 37; break; }
    case 37: 
      var $155=$2;
      var $156=(($155+276)|0);
      var $157=HEAP32[(($156)>>2)];
      var $158=(($157)|0) < 59000;
      if ($158) { __label__ = 43; break; } else { __label__ = 38; break; }
    case 38: 
      var $160=$2;
      var $161=(($160+276)|0);
      var $162=HEAP32[(($161)>>2)];
      var $163=(($162)|0) > 61000;
      if ($163) { __label__ = 43; break; } else { __label__ = 39; break; }
    case 39: 
      var $165=$2;
      var $166=(($165+280)|0);
      var $167=HEAP32[(($166)>>2)];
      var $168=(($167)|0) < 14000;
      if ($168) { __label__ = 43; break; } else { __label__ = 40; break; }
    case 40: 
      var $170=$2;
      var $171=(($170+280)|0);
      var $172=HEAP32[(($171)>>2)];
      var $173=(($172)|0) > 16000;
      if ($173) { __label__ = 43; break; } else { __label__ = 41; break; }
    case 41: 
      var $175=$2;
      var $176=(($175+284)|0);
      var $177=HEAP32[(($176)>>2)];
      var $178=(($177)|0) < 5000;
      if ($178) { __label__ = 43; break; } else { __label__ = 42; break; }
    case 42: 
      var $180=$2;
      var $181=(($180+284)|0);
      var $182=HEAP32[(($181)>>2)];
      var $183=(($182)|0) > 7000;
      if ($183) { __label__ = 43; break; } else { __label__ = 44; break; }
    case 43: 
      var $185=$1;
      _png_warning($185, ((STRING_TABLE.__str38)|0));
      __label__ = 44; break;
    case 44: 
      __label__ = 45; break;
    case 45: 
      var $188=$1;
      var $189=$2;
      var $190=$intent;
      _png_set_sRGB_gAMA_and_cHRM($188, $189, $190);
      __label__ = 46; break;
    case 46: 
      STACKTOP = __stackBase__;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_png_handle_sRGB["X"]=1;

function _png_handle_iCCP($png_ptr, $info_ptr, $length) {
  var __stackBase__  = STACKTOP; STACKTOP += 56; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $compression_type;
      var $pC;
      var $profile;
      var $skip;
      var $profile_size;
      var $profile_length;
      var $slength;
      var $prefix_length;
      var $data_length=__stackBase__;
      var $umsg=(__stackBase__)+(4);
      $1=$png_ptr;
      $2=$info_ptr;
      $3=$length;
      $skip=0;
      var $4=$1;
      var $5=(($4+84)|0);
      var $6=HEAP32[(($5)>>2)];
      var $7=$6 & 1;
      var $8=(($7)|0)!=0;
      if ($8) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      var $10=$1;
      _png_error($10, ((STRING_TABLE.__str48)|0));
      __label__ = 10; break;
    case 4: 
      var $12=$1;
      var $13=(($12+84)|0);
      var $14=HEAP32[(($13)>>2)];
      var $15=$14 & 4;
      var $16=(($15)|0)!=0;
      if ($16) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $18=$1;
      _png_warning($18, ((STRING_TABLE.__str49)|0));
      var $19=$1;
      var $20=$3;
      var $21=_png_crc_finish($19, $20);
      __label__ = 31; break;
    case 6: 
      var $23=$1;
      var $24=(($23+84)|0);
      var $25=HEAP32[(($24)>>2)];
      var $26=$25 & 2;
      var $27=(($26)|0)!=0;
      if ($27) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $29=$1;
      _png_warning($29, ((STRING_TABLE.__str50)|0));
      __label__ = 8; break;
    case 8: 
      __label__ = 9; break;
    case 9: 
      __label__ = 10; break;
    case 10: 
      var $33=$2;
      var $34=(($33)|0)!=0;
      if ($34) { __label__ = 11; break; } else { __label__ = 13; break; }
    case 11: 
      var $36=$2;
      var $37=(($36+8)|0);
      var $38=HEAP32[(($37)>>2)];
      var $39=$38 & 4096;
      var $40=(($39)|0)!=0;
      if ($40) { __label__ = 12; break; } else { __label__ = 13; break; }
    case 12: 
      var $42=$1;
      _png_warning($42, ((STRING_TABLE.__str51)|0));
      var $43=$1;
      var $44=$3;
      var $45=_png_crc_finish($43, $44);
      __label__ = 31; break;
    case 13: 
      var $47=$1;
      var $48=$1;
      var $49=(($48+624)|0);
      var $50=HEAP32[(($49)>>2)];
      _png_free($47, $50);
      var $51=$1;
      var $52=$3;
      var $53=((($52)+(1))|0);
      var $54=_png_malloc($51, $53);
      var $55=$1;
      var $56=(($55+624)|0);
      HEAP32[(($56)>>2)]=$54;
      var $57=$3;
      $slength=$57;
      var $58=$1;
      var $59=$1;
      var $60=(($59+624)|0);
      var $61=HEAP32[(($60)>>2)];
      var $62=$slength;
      _png_crc_read($58, $61, $62);
      var $63=$1;
      var $64=$skip;
      var $65=_png_crc_finish($63, $64);
      var $66=(($65)|0)!=0;
      if ($66) { __label__ = 14; break; } else { __label__ = 15; break; }
    case 14: 
      var $68=$1;
      var $69=$1;
      var $70=(($69+624)|0);
      var $71=HEAP32[(($70)>>2)];
      _png_free($68, $71);
      var $72=$1;
      var $73=(($72+624)|0);
      HEAP32[(($73)>>2)]=0;
      __label__ = 31; break;
    case 15: 
      var $75=$slength;
      var $76=$1;
      var $77=(($76+624)|0);
      var $78=HEAP32[(($77)>>2)];
      var $79=(($78+$75)|0);
      HEAP8[($79)]=0;
      var $80=$1;
      var $81=(($80+624)|0);
      var $82=HEAP32[(($81)>>2)];
      $profile=$82;
      __label__ = 16; break;
    case 16: 
      var $84=$profile;
      var $85=HEAP8[($84)];
      var $86=(($85 << 24) >> 24)!=0;
      if ($86) { __label__ = 17; break; } else { __label__ = 19; break; }
    case 17: 
      __label__ = 18; break;
    case 18: 
      var $89=$profile;
      var $90=(($89+1)|0);
      $profile=$90;
      __label__ = 16; break;
    case 19: 
      var $92=$profile;
      var $93=(($92+1)|0);
      $profile=$93;
      var $94=$profile;
      var $95=$1;
      var $96=(($95+624)|0);
      var $97=HEAP32[(($96)>>2)];
      var $98=$slength;
      var $99=(($97+$98)|0);
      var $100=((($99)-(1))|0);
      var $101=(($94)>>>0) >= (($100)>>>0);
      if ($101) { __label__ = 20; break; } else { __label__ = 21; break; }
    case 20: 
      var $103=$1;
      var $104=$1;
      var $105=(($104+624)|0);
      var $106=HEAP32[(($105)>>2)];
      _png_free($103, $106);
      var $107=$1;
      var $108=(($107+624)|0);
      HEAP32[(($108)>>2)]=0;
      var $109=$1;
      _png_warning($109, ((STRING_TABLE.__str52)|0));
      __label__ = 31; break;
    case 21: 
      var $111=$profile;
      var $112=(($111+1)|0);
      $profile=$112;
      var $113=HEAP8[($111)];
      $compression_type=$113;
      var $114=$compression_type;
      var $115=(($114 << 24) >> 24)!=0;
      if ($115) { __label__ = 22; break; } else { __label__ = 23; break; }
    case 22: 
      var $117=$1;
      _png_warning($117, ((STRING_TABLE.__str53)|0));
      $compression_type=0;
      __label__ = 23; break;
    case 23: 
      var $119=$profile;
      var $120=$1;
      var $121=(($120+624)|0);
      var $122=HEAP32[(($121)>>2)];
      var $123=$119;
      var $124=$122;
      var $125=((($123)-($124))|0);
      $prefix_length=$125;
      var $126=$1;
      var $127=$compression_type;
      var $128=(($127)&255);
      var $129=$slength;
      var $130=$prefix_length;
      _png_decompress_chunk($126, $128, $129, $130, $data_length);
      var $131=HEAP32[(($data_length)>>2)];
      var $132=$prefix_length;
      var $133=((($131)-($132))|0);
      $profile_length=$133;
      var $134=$prefix_length;
      var $135=HEAPU32[(($data_length)>>2)];
      var $136=(($134)>>>0) > (($135)>>>0);
      if ($136) { __label__ = 25; break; } else { __label__ = 24; break; }
    case 24: 
      var $138=$profile_length;
      var $139=(($138)>>>0) < 4;
      if ($139) { __label__ = 25; break; } else { __label__ = 26; break; }
    case 25: 
      var $141=$1;
      var $142=$1;
      var $143=(($142+624)|0);
      var $144=HEAP32[(($143)>>2)];
      _png_free($141, $144);
      var $145=$1;
      var $146=(($145+624)|0);
      HEAP32[(($146)>>2)]=0;
      var $147=$1;
      _png_warning($147, ((STRING_TABLE.__str54)|0));
      __label__ = 31; break;
    case 26: 
      var $149=$1;
      var $150=(($149+624)|0);
      var $151=HEAP32[(($150)>>2)];
      var $152=$prefix_length;
      var $153=(($151+$152)|0);
      $pC=$153;
      var $154=$pC;
      var $155=HEAPU8[($154)];
      var $156=(($155)&255);
      var $157=$156 << 24;
      var $158=$pC;
      var $159=(($158+1)|0);
      var $160=HEAPU8[($159)];
      var $161=(($160)&255);
      var $162=$161 << 16;
      var $163=$157 | $162;
      var $164=$pC;
      var $165=(($164+2)|0);
      var $166=HEAPU8[($165)];
      var $167=(($166)&255);
      var $168=$167 << 8;
      var $169=$163 | $168;
      var $170=$pC;
      var $171=(($170+3)|0);
      var $172=HEAPU8[($171)];
      var $173=(($172)&255);
      var $174=$169 | $173;
      $profile_size=$174;
      var $175=$profile_size;
      var $176=$profile_length;
      var $177=(($175)>>>0) < (($176)>>>0);
      if ($177) { __label__ = 27; break; } else { __label__ = 28; break; }
    case 27: 
      var $179=$profile_size;
      $profile_length=$179;
      __label__ = 28; break;
    case 28: 
      var $181=$profile_size;
      var $182=$profile_length;
      var $183=(($181)>>>0) > (($182)>>>0);
      if ($183) { __label__ = 29; break; } else { __label__ = 30; break; }
    case 29: 
      var $185=$1;
      var $186=$1;
      var $187=(($186+624)|0);
      var $188=HEAP32[(($187)>>2)];
      _png_free($185, $188);
      var $189=$1;
      var $190=(($189+624)|0);
      HEAP32[(($190)>>2)]=0;
      var $191=$1;
      _png_warning($191, ((STRING_TABLE.__str55)|0));
      var $192=(($umsg)|0);
      var $193=$profile_size;
      var $194=_snprintf($192, 50, ((STRING_TABLE.__str56)|0), (tempInt=STACKTOP,STACKTOP += 4,assert(STACKTOP < STACK_ROOT + STACK_MAX, "Ran out of stack"),HEAP32[((tempInt)>>2)]=$193,tempInt));
      var $195=$1;
      var $196=(($umsg)|0);
      _png_warning($195, $196);
      var $197=(($umsg)|0);
      var $198=$profile_length;
      var $199=_snprintf($197, 50, ((STRING_TABLE.__str57)|0), (tempInt=STACKTOP,STACKTOP += 4,assert(STACKTOP < STACK_ROOT + STACK_MAX, "Ran out of stack"),HEAP32[((tempInt)>>2)]=$198,tempInt));
      var $200=$1;
      var $201=(($umsg)|0);
      _png_warning($200, $201);
      __label__ = 31; break;
    case 30: 
      var $203=$1;
      var $204=$2;
      var $205=$1;
      var $206=(($205+624)|0);
      var $207=HEAP32[(($206)>>2)];
      var $208=$compression_type;
      var $209=(($208)&255);
      var $210=$1;
      var $211=(($210+624)|0);
      var $212=HEAP32[(($211)>>2)];
      var $213=$prefix_length;
      var $214=(($212+$213)|0);
      var $215=$profile_length;
      _png_set_iCCP($203, $204, $207, $209, $214, $215);
      var $216=$1;
      var $217=$1;
      var $218=(($217+624)|0);
      var $219=HEAP32[(($218)>>2)];
      _png_free($216, $219);
      var $220=$1;
      var $221=(($220+624)|0);
      HEAP32[(($221)>>2)]=0;
      __label__ = 31; break;
    case 31: 
      STACKTOP = __stackBase__;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_png_handle_iCCP["X"]=1;

function _png_handle_sPLT($png_ptr, $info_ptr, $length) {
  var __stackBase__  = STACKTOP; STACKTOP += 16; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $entry_start;
      var $new_palette=__stackBase__;
      var $pp;
      var $data_length;
      var $entry_size;
      var $i;
      var $skip;
      var $slength;
      $1=$png_ptr;
      $2=$info_ptr;
      $3=$length;
      $skip=0;
      var $4=$1;
      var $5=(($4+592)|0);
      var $6=HEAP32[(($5)>>2)];
      var $7=(($6)|0)!=0;
      if ($7) { __label__ = 3; break; } else { __label__ = 8; break; }
    case 3: 
      var $9=$1;
      var $10=(($9+592)|0);
      var $11=HEAP32[(($10)>>2)];
      var $12=(($11)|0)==1;
      if ($12) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      var $14=$1;
      var $15=$3;
      var $16=_png_crc_finish($14, $15);
      __label__ = 35; break;
    case 5: 
      var $18=$1;
      var $19=(($18+592)|0);
      var $20=HEAP32[(($19)>>2)];
      var $21=((($20)-(1))|0);
      HEAP32[(($19)>>2)]=$21;
      var $22=(($21)|0)==1;
      if ($22) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      var $24=$1;
      _png_warning($24, ((STRING_TABLE.__str58)|0));
      var $25=$1;
      var $26=$3;
      var $27=_png_crc_finish($25, $26);
      __label__ = 35; break;
    case 7: 
      __label__ = 8; break;
    case 8: 
      var $30=$1;
      var $31=(($30+84)|0);
      var $32=HEAP32[(($31)>>2)];
      var $33=$32 & 1;
      var $34=(($33)|0)!=0;
      if ($34) { __label__ = 10; break; } else { __label__ = 9; break; }
    case 9: 
      var $36=$1;
      _png_error($36, ((STRING_TABLE.__str59)|0));
      __label__ = 13; break;
    case 10: 
      var $38=$1;
      var $39=(($38+84)|0);
      var $40=HEAP32[(($39)>>2)];
      var $41=$40 & 4;
      var $42=(($41)|0)!=0;
      if ($42) { __label__ = 11; break; } else { __label__ = 12; break; }
    case 11: 
      var $44=$1;
      _png_warning($44, ((STRING_TABLE.__str60)|0));
      var $45=$1;
      var $46=$3;
      var $47=_png_crc_finish($45, $46);
      __label__ = 35; break;
    case 12: 
      __label__ = 13; break;
    case 13: 
      var $50=$1;
      var $51=$1;
      var $52=(($51+624)|0);
      var $53=HEAP32[(($52)>>2)];
      _png_free($50, $53);
      var $54=$1;
      var $55=$3;
      var $56=((($55)+(1))|0);
      var $57=_png_malloc($54, $56);
      var $58=$1;
      var $59=(($58+624)|0);
      HEAP32[(($59)>>2)]=$57;
      var $60=$3;
      $slength=$60;
      var $61=$1;
      var $62=$1;
      var $63=(($62+624)|0);
      var $64=HEAP32[(($63)>>2)];
      var $65=$slength;
      _png_crc_read($61, $64, $65);
      var $66=$1;
      var $67=$skip;
      var $68=_png_crc_finish($66, $67);
      var $69=(($68)|0)!=0;
      if ($69) { __label__ = 14; break; } else { __label__ = 15; break; }
    case 14: 
      var $71=$1;
      var $72=$1;
      var $73=(($72+624)|0);
      var $74=HEAP32[(($73)>>2)];
      _png_free($71, $74);
      var $75=$1;
      var $76=(($75+624)|0);
      HEAP32[(($76)>>2)]=0;
      __label__ = 35; break;
    case 15: 
      var $78=$slength;
      var $79=$1;
      var $80=(($79+624)|0);
      var $81=HEAP32[(($80)>>2)];
      var $82=(($81+$78)|0);
      HEAP8[($82)]=0;
      var $83=$1;
      var $84=(($83+624)|0);
      var $85=HEAP32[(($84)>>2)];
      $entry_start=$85;
      __label__ = 16; break;
    case 16: 
      var $87=$entry_start;
      var $88=HEAP8[($87)];
      var $89=(($88 << 24) >> 24)!=0;
      if ($89) { __label__ = 17; break; } else { __label__ = 19; break; }
    case 17: 
      __label__ = 18; break;
    case 18: 
      var $92=$entry_start;
      var $93=(($92+1)|0);
      $entry_start=$93;
      __label__ = 16; break;
    case 19: 
      var $95=$entry_start;
      var $96=(($95+1)|0);
      $entry_start=$96;
      var $97=$entry_start;
      var $98=$1;
      var $99=(($98+624)|0);
      var $100=HEAP32[(($99)>>2)];
      var $101=$slength;
      var $102=(($100+$101)|0);
      var $103=((($102)-(2))|0);
      var $104=(($97)>>>0) > (($103)>>>0);
      if ($104) { __label__ = 20; break; } else { __label__ = 21; break; }
    case 20: 
      var $106=$1;
      var $107=$1;
      var $108=(($107+624)|0);
      var $109=HEAP32[(($108)>>2)];
      _png_free($106, $109);
      var $110=$1;
      var $111=(($110+624)|0);
      HEAP32[(($111)>>2)]=0;
      var $112=$1;
      _png_warning($112, ((STRING_TABLE.__str61)|0));
      __label__ = 35; break;
    case 21: 
      var $114=$entry_start;
      var $115=(($114+1)|0);
      $entry_start=$115;
      var $116=HEAP8[($114)];
      var $117=(($new_palette+4)|0);
      HEAP8[($117)]=$116;
      var $118=(($new_palette+4)|0);
      var $119=HEAPU8[($118)];
      var $120=(($119)&255);
      var $121=(($120)|0)==8;
      var $122=$121 ? 6 : 10;
      $entry_size=$122;
      var $123=$slength;
      var $124=$entry_start;
      var $125=$1;
      var $126=(($125+624)|0);
      var $127=HEAP32[(($126)>>2)];
      var $128=$124;
      var $129=$127;
      var $130=((($128)-($129))|0);
      var $131=((($123)-($130))|0);
      $data_length=$131;
      var $132=$data_length;
      var $133=$entry_size;
      var $134=((($132)|0))%((($133)|0));
      var $135=(($134)|0)!=0;
      if ($135) { __label__ = 22; break; } else { __label__ = 23; break; }
    case 22: 
      var $137=$1;
      var $138=$1;
      var $139=(($138+624)|0);
      var $140=HEAP32[(($139)>>2)];
      _png_free($137, $140);
      var $141=$1;
      var $142=(($141+624)|0);
      HEAP32[(($142)>>2)]=0;
      var $143=$1;
      _png_warning($143, ((STRING_TABLE.__str62)|0));
      __label__ = 35; break;
    case 23: 
      var $145=$data_length;
      var $146=$entry_size;
      var $147=((((($145)|0))/((($146)|0)))&-1);
      var $148=(($new_palette+12)|0);
      HEAP32[(($148)>>2)]=$147;
      var $149=(($new_palette+12)|0);
      var $150=HEAPU32[(($149)>>2)];
      var $151=(($150)>>>0) > 429496729;
      if ($151) { __label__ = 24; break; } else { __label__ = 25; break; }
    case 24: 
      var $153=$1;
      _png_warning($153, ((STRING_TABLE.__str63)|0));
      __label__ = 35; break;
    case 25: 
      var $155=$1;
      var $156=(($new_palette+12)|0);
      var $157=HEAP32[(($156)>>2)];
      var $158=((($157)*(10))|0);
      var $159=_png_malloc_warn($155, $158);
      var $160=$159;
      var $161=(($new_palette+8)|0);
      HEAP32[(($161)>>2)]=$160;
      var $162=(($new_palette+8)|0);
      var $163=HEAP32[(($162)>>2)];
      var $164=(($163)|0)==0;
      if ($164) { __label__ = 26; break; } else { __label__ = 27; break; }
    case 26: 
      var $166=$1;
      _png_warning($166, ((STRING_TABLE.__str64)|0));
      __label__ = 35; break;
    case 27: 
      $i=0;
      __label__ = 28; break;
    case 28: 
      var $169=$i;
      var $170=(($new_palette+12)|0);
      var $171=HEAP32[(($170)>>2)];
      var $172=(($169)|0) < (($171)|0);
      if ($172) { __label__ = 29; break; } else { __label__ = 34; break; }
    case 29: 
      var $174=(($new_palette+8)|0);
      var $175=HEAP32[(($174)>>2)];
      var $176=$i;
      var $177=(($175+($176)*(10))|0);
      $pp=$177;
      var $178=(($new_palette+4)|0);
      var $179=HEAPU8[($178)];
      var $180=(($179)&255);
      var $181=(($180)|0)==8;
      if ($181) { __label__ = 30; break; } else { __label__ = 31; break; }
    case 30: 
      var $183=$entry_start;
      var $184=(($183+1)|0);
      $entry_start=$184;
      var $185=HEAPU8[($183)];
      var $186=(($185)&255);
      var $187=$pp;
      var $188=(($187)|0);
      HEAP16[(($188)>>1)]=$186;
      var $189=$entry_start;
      var $190=(($189+1)|0);
      $entry_start=$190;
      var $191=HEAPU8[($189)];
      var $192=(($191)&255);
      var $193=$pp;
      var $194=(($193+2)|0);
      HEAP16[(($194)>>1)]=$192;
      var $195=$entry_start;
      var $196=(($195+1)|0);
      $entry_start=$196;
      var $197=HEAPU8[($195)];
      var $198=(($197)&255);
      var $199=$pp;
      var $200=(($199+4)|0);
      HEAP16[(($200)>>1)]=$198;
      var $201=$entry_start;
      var $202=(($201+1)|0);
      $entry_start=$202;
      var $203=HEAPU8[($201)];
      var $204=(($203)&255);
      var $205=$pp;
      var $206=(($205+6)|0);
      HEAP16[(($206)>>1)]=$204;
      __label__ = 32; break;
    case 31: 
      var $208=$entry_start;
      var $209=HEAPU8[($208)];
      var $210=(($209)&255);
      var $211=$210 << 8;
      var $212=$entry_start;
      var $213=(($212+1)|0);
      var $214=HEAPU8[($213)];
      var $215=(($214)&255);
      var $216=((($211)+($215))|0);
      var $217=(($216) & 65535);
      var $218=$pp;
      var $219=(($218)|0);
      HEAP16[(($219)>>1)]=$217;
      var $220=$entry_start;
      var $221=(($220+2)|0);
      $entry_start=$221;
      var $222=$entry_start;
      var $223=HEAPU8[($222)];
      var $224=(($223)&255);
      var $225=$224 << 8;
      var $226=$entry_start;
      var $227=(($226+1)|0);
      var $228=HEAPU8[($227)];
      var $229=(($228)&255);
      var $230=((($225)+($229))|0);
      var $231=(($230) & 65535);
      var $232=$pp;
      var $233=(($232+2)|0);
      HEAP16[(($233)>>1)]=$231;
      var $234=$entry_start;
      var $235=(($234+2)|0);
      $entry_start=$235;
      var $236=$entry_start;
      var $237=HEAPU8[($236)];
      var $238=(($237)&255);
      var $239=$238 << 8;
      var $240=$entry_start;
      var $241=(($240+1)|0);
      var $242=HEAPU8[($241)];
      var $243=(($242)&255);
      var $244=((($239)+($243))|0);
      var $245=(($244) & 65535);
      var $246=$pp;
      var $247=(($246+4)|0);
      HEAP16[(($247)>>1)]=$245;
      var $248=$entry_start;
      var $249=(($248+2)|0);
      $entry_start=$249;
      var $250=$entry_start;
      var $251=HEAPU8[($250)];
      var $252=(($251)&255);
      var $253=$252 << 8;
      var $254=$entry_start;
      var $255=(($254+1)|0);
      var $256=HEAPU8[($255)];
      var $257=(($256)&255);
      var $258=((($253)+($257))|0);
      var $259=(($258) & 65535);
      var $260=$pp;
      var $261=(($260+6)|0);
      HEAP16[(($261)>>1)]=$259;
      var $262=$entry_start;
      var $263=(($262+2)|0);
      $entry_start=$263;
      __label__ = 32; break;
    case 32: 
      var $265=$entry_start;
      var $266=HEAPU8[($265)];
      var $267=(($266)&255);
      var $268=$267 << 8;
      var $269=$entry_start;
      var $270=(($269+1)|0);
      var $271=HEAPU8[($270)];
      var $272=(($271)&255);
      var $273=((($268)+($272))|0);
      var $274=(($273) & 65535);
      var $275=$pp;
      var $276=(($275+8)|0);
      HEAP16[(($276)>>1)]=$274;
      var $277=$entry_start;
      var $278=(($277+2)|0);
      $entry_start=$278;
      __label__ = 33; break;
    case 33: 
      var $280=$i;
      var $281=((($280)+(1))|0);
      $i=$281;
      __label__ = 28; break;
    case 34: 
      var $283=$1;
      var $284=(($283+624)|0);
      var $285=HEAP32[(($284)>>2)];
      var $286=(($new_palette)|0);
      HEAP32[(($286)>>2)]=$285;
      var $287=$1;
      var $288=$2;
      _png_set_sPLT($287, $288, $new_palette, 1);
      var $289=$1;
      var $290=$1;
      var $291=(($290+624)|0);
      var $292=HEAP32[(($291)>>2)];
      _png_free($289, $292);
      var $293=$1;
      var $294=(($293+624)|0);
      HEAP32[(($294)>>2)]=0;
      var $295=$1;
      var $296=(($new_palette+8)|0);
      var $297=HEAP32[(($296)>>2)];
      var $298=$297;
      _png_free($295, $298);
      __label__ = 35; break;
    case 35: 
      STACKTOP = __stackBase__;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_png_handle_sPLT["X"]=1;

function _png_handle_tRNS($png_ptr, $info_ptr, $length) {
  var __stackBase__  = STACKTOP; STACKTOP += 268; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $readbuf=__stackBase__;
      var $buf=(__stackBase__)+(256);
      var $buf1=(__stackBase__)+(260);
      $1=$png_ptr;
      $2=$info_ptr;
      $3=$length;
      var $4=$1;
      var $5=(($4+84)|0);
      var $6=HEAP32[(($5)>>2)];
      var $7=$6 & 1;
      var $8=(($7)|0)!=0;
      if ($8) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      var $10=$1;
      _png_error($10, ((STRING_TABLE.__str65)|0));
      __label__ = 11; break;
    case 4: 
      var $12=$1;
      var $13=(($12+84)|0);
      var $14=HEAP32[(($13)>>2)];
      var $15=$14 & 4;
      var $16=(($15)|0)!=0;
      if ($16) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $18=$1;
      _png_warning($18, ((STRING_TABLE.__str66)|0));
      var $19=$1;
      var $20=$3;
      var $21=_png_crc_finish($19, $20);
      __label__ = 34; break;
    case 6: 
      var $23=$2;
      var $24=(($23)|0)!=0;
      if ($24) { __label__ = 7; break; } else { __label__ = 9; break; }
    case 7: 
      var $26=$2;
      var $27=(($26+8)|0);
      var $28=HEAP32[(($27)>>2)];
      var $29=$28 & 16;
      var $30=(($29)|0)!=0;
      if ($30) { __label__ = 8; break; } else { __label__ = 9; break; }
    case 8: 
      var $32=$1;
      _png_warning($32, ((STRING_TABLE.__str67)|0));
      var $33=$1;
      var $34=$3;
      var $35=_png_crc_finish($33, $34);
      __label__ = 34; break;
    case 9: 
      __label__ = 10; break;
    case 10: 
      __label__ = 11; break;
    case 11: 
      var $39=$1;
      var $40=(($39+274)|0);
      var $41=HEAPU8[($40)];
      var $42=(($41)&255);
      var $43=(($42)|0)==0;
      if ($43) { __label__ = 12; break; } else { __label__ = 15; break; }
    case 12: 
      var $45=$3;
      var $46=(($45)|0)!=2;
      if ($46) { __label__ = 13; break; } else { __label__ = 14; break; }
    case 13: 
      var $48=$1;
      _png_warning($48, ((STRING_TABLE.__str68)|0));
      var $49=$1;
      var $50=$3;
      var $51=_png_crc_finish($49, $50);
      __label__ = 34; break;
    case 14: 
      var $53=$1;
      var $54=(($buf)|0);
      _png_crc_read($53, $54, 2);
      var $55=$1;
      var $56=(($55+262)|0);
      HEAP16[(($56)>>1)]=1;
      var $57=(($buf)|0);
      var $58=HEAPU8[($57)];
      var $59=(($58)&255);
      var $60=$59 << 8;
      var $61=(($buf)|0);
      var $62=(($61+1)|0);
      var $63=HEAPU8[($62)];
      var $64=(($63)&255);
      var $65=((($60)+($64))|0);
      var $66=(($65) & 65535);
      var $67=$1;
      var $68=(($67+376)|0);
      var $69=(($68+8)|0);
      HEAP16[(($69)>>1)]=$66;
      __label__ = 31; break;
    case 15: 
      var $71=$1;
      var $72=(($71+274)|0);
      var $73=HEAPU8[($72)];
      var $74=(($73)&255);
      var $75=(($74)|0)==2;
      if ($75) { __label__ = 16; break; } else { __label__ = 19; break; }
    case 16: 
      var $77=$3;
      var $78=(($77)|0)!=6;
      if ($78) { __label__ = 17; break; } else { __label__ = 18; break; }
    case 17: 
      var $80=$1;
      _png_warning($80, ((STRING_TABLE.__str68)|0));
      var $81=$1;
      var $82=$3;
      var $83=_png_crc_finish($81, $82);
      __label__ = 34; break;
    case 18: 
      var $85=$1;
      var $86=(($buf1)|0);
      var $87=$3;
      _png_crc_read($85, $86, $87);
      var $88=$1;
      var $89=(($88+262)|0);
      HEAP16[(($89)>>1)]=1;
      var $90=(($buf1)|0);
      var $91=HEAPU8[($90)];
      var $92=(($91)&255);
      var $93=$92 << 8;
      var $94=(($buf1)|0);
      var $95=(($94+1)|0);
      var $96=HEAPU8[($95)];
      var $97=(($96)&255);
      var $98=((($93)+($97))|0);
      var $99=(($98) & 65535);
      var $100=$1;
      var $101=(($100+376)|0);
      var $102=(($101+2)|0);
      HEAP16[(($102)>>1)]=$99;
      var $103=(($buf1)|0);
      var $104=(($103+2)|0);
      var $105=HEAPU8[($104)];
      var $106=(($105)&255);
      var $107=$106 << 8;
      var $108=(($buf1)|0);
      var $109=(($108+2)|0);
      var $110=(($109+1)|0);
      var $111=HEAPU8[($110)];
      var $112=(($111)&255);
      var $113=((($107)+($112))|0);
      var $114=(($113) & 65535);
      var $115=$1;
      var $116=(($115+376)|0);
      var $117=(($116+4)|0);
      HEAP16[(($117)>>1)]=$114;
      var $118=(($buf1)|0);
      var $119=(($118+4)|0);
      var $120=HEAPU8[($119)];
      var $121=(($120)&255);
      var $122=$121 << 8;
      var $123=(($buf1)|0);
      var $124=(($123+4)|0);
      var $125=(($124+1)|0);
      var $126=HEAPU8[($125)];
      var $127=(($126)&255);
      var $128=((($122)+($127))|0);
      var $129=(($128) & 65535);
      var $130=$1;
      var $131=(($130+376)|0);
      var $132=(($131+6)|0);
      HEAP16[(($132)>>1)]=$129;
      __label__ = 30; break;
    case 19: 
      var $134=$1;
      var $135=(($134+274)|0);
      var $136=HEAPU8[($135)];
      var $137=(($136)&255);
      var $138=(($137)|0)==3;
      if ($138) { __label__ = 20; break; } else { __label__ = 28; break; }
    case 20: 
      var $140=$1;
      var $141=(($140+84)|0);
      var $142=HEAP32[(($141)>>2)];
      var $143=$142 & 2;
      var $144=(($143)|0)!=0;
      if ($144) { __label__ = 22; break; } else { __label__ = 21; break; }
    case 21: 
      var $146=$1;
      _png_warning($146, ((STRING_TABLE.__str69)|0));
      __label__ = 22; break;
    case 22: 
      var $148=$3;
      var $149=$1;
      var $150=(($149+260)|0);
      var $151=HEAPU16[(($150)>>1)];
      var $152=(($151)&65535);
      var $153=(($148)>>>0) > (($152)>>>0);
      if ($153) { __label__ = 24; break; } else { __label__ = 23; break; }
    case 23: 
      var $155=$3;
      var $156=(($155)>>>0) > 256;
      if ($156) { __label__ = 24; break; } else { __label__ = 25; break; }
    case 24: 
      var $158=$1;
      _png_warning($158, ((STRING_TABLE.__str68)|0));
      var $159=$1;
      var $160=$3;
      var $161=_png_crc_finish($159, $160);
      __label__ = 34; break;
    case 25: 
      var $163=$3;
      var $164=(($163)|0)==0;
      if ($164) { __label__ = 26; break; } else { __label__ = 27; break; }
    case 26: 
      var $166=$1;
      _png_warning($166, ((STRING_TABLE.__str70)|0));
      var $167=$1;
      var $168=$3;
      var $169=_png_crc_finish($167, $168);
      __label__ = 34; break;
    case 27: 
      var $171=$1;
      var $172=(($readbuf)|0);
      var $173=$3;
      _png_crc_read($171, $172, $173);
      var $174=$3;
      var $175=(($174) & 65535);
      var $176=$1;
      var $177=(($176+262)|0);
      HEAP16[(($177)>>1)]=$175;
      __label__ = 29; break;
    case 28: 
      var $179=$1;
      _png_warning($179, ((STRING_TABLE.__str71)|0));
      var $180=$1;
      var $181=$3;
      var $182=_png_crc_finish($180, $181);
      __label__ = 34; break;
    case 29: 
      __label__ = 30; break;
    case 30: 
      __label__ = 31; break;
    case 31: 
      var $186=$1;
      var $187=_png_crc_finish($186, 0);
      var $188=(($187)|0)!=0;
      if ($188) { __label__ = 32; break; } else { __label__ = 33; break; }
    case 32: 
      var $190=$1;
      var $191=(($190+262)|0);
      HEAP16[(($191)>>1)]=0;
      __label__ = 34; break;
    case 33: 
      var $193=$1;
      var $194=$2;
      var $195=(($readbuf)|0);
      var $196=$1;
      var $197=(($196+262)|0);
      var $198=HEAPU16[(($197)>>1)];
      var $199=(($198)&65535);
      var $200=$1;
      var $201=(($200+376)|0);
      _png_set_tRNS($193, $194, $195, $199, $201);
      __label__ = 34; break;
    case 34: 
      STACKTOP = __stackBase__;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_png_handle_tRNS["X"]=1;

function _png_handle_bKGD($png_ptr, $info_ptr, $length) {
  var __stackBase__  = STACKTOP; STACKTOP += 8; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $truelen;
      var $buf=__stackBase__;
      $1=$png_ptr;
      $2=$info_ptr;
      $3=$length;
      var $4=$1;
      var $5=(($4+84)|0);
      var $6=HEAP32[(($5)>>2)];
      var $7=$6 & 1;
      var $8=(($7)|0)!=0;
      if ($8) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      var $10=$1;
      _png_error($10, ((STRING_TABLE.__str72)|0));
      __label__ = 15; break;
    case 4: 
      var $12=$1;
      var $13=(($12+84)|0);
      var $14=HEAP32[(($13)>>2)];
      var $15=$14 & 4;
      var $16=(($15)|0)!=0;
      if ($16) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $18=$1;
      _png_warning($18, ((STRING_TABLE.__str73)|0));
      var $19=$1;
      var $20=$3;
      var $21=_png_crc_finish($19, $20);
      __label__ = 37; break;
    case 6: 
      var $23=$1;
      var $24=(($23+274)|0);
      var $25=HEAPU8[($24)];
      var $26=(($25)&255);
      var $27=(($26)|0)==3;
      if ($27) { __label__ = 7; break; } else { __label__ = 9; break; }
    case 7: 
      var $29=$1;
      var $30=(($29+84)|0);
      var $31=HEAP32[(($30)>>2)];
      var $32=$31 & 2;
      var $33=(($32)|0)!=0;
      if ($33) { __label__ = 9; break; } else { __label__ = 8; break; }
    case 8: 
      var $35=$1;
      _png_warning($35, ((STRING_TABLE.__str74224)|0));
      var $36=$1;
      var $37=$3;
      var $38=_png_crc_finish($36, $37);
      __label__ = 37; break;
    case 9: 
      var $40=$2;
      var $41=(($40)|0)!=0;
      if ($41) { __label__ = 10; break; } else { __label__ = 12; break; }
    case 10: 
      var $43=$2;
      var $44=(($43+8)|0);
      var $45=HEAP32[(($44)>>2)];
      var $46=$45 & 32;
      var $47=(($46)|0)!=0;
      if ($47) { __label__ = 11; break; } else { __label__ = 12; break; }
    case 11: 
      var $49=$1;
      _png_warning($49, ((STRING_TABLE.__str75225)|0));
      var $50=$1;
      var $51=$3;
      var $52=_png_crc_finish($50, $51);
      __label__ = 37; break;
    case 12: 
      __label__ = 13; break;
    case 13: 
      __label__ = 14; break;
    case 14: 
      __label__ = 15; break;
    case 15: 
      var $57=$1;
      var $58=(($57+274)|0);
      var $59=HEAPU8[($58)];
      var $60=(($59)&255);
      var $61=(($60)|0)==3;
      if ($61) { __label__ = 16; break; } else { __label__ = 17; break; }
    case 16: 
      $truelen=1;
      __label__ = 21; break;
    case 17: 
      var $64=$1;
      var $65=(($64+274)|0);
      var $66=HEAPU8[($65)];
      var $67=(($66)&255);
      var $68=$67 & 2;
      var $69=(($68)|0)!=0;
      if ($69) { __label__ = 18; break; } else { __label__ = 19; break; }
    case 18: 
      $truelen=6;
      __label__ = 20; break;
    case 19: 
      $truelen=2;
      __label__ = 20; break;
    case 20: 
      __label__ = 21; break;
    case 21: 
      var $74=$3;
      var $75=$truelen;
      var $76=(($74)|0)!=(($75)|0);
      if ($76) { __label__ = 22; break; } else { __label__ = 23; break; }
    case 22: 
      var $78=$1;
      _png_warning($78, ((STRING_TABLE.__str76)|0));
      var $79=$1;
      var $80=$3;
      var $81=_png_crc_finish($79, $80);
      __label__ = 37; break;
    case 23: 
      var $83=$1;
      var $84=(($buf)|0);
      var $85=$truelen;
      _png_crc_read($83, $84, $85);
      var $86=$1;
      var $87=_png_crc_finish($86, 0);
      var $88=(($87)|0)!=0;
      if ($88) { __label__ = 24; break; } else { __label__ = 25; break; }
    case 24: 
      __label__ = 37; break;
    case 25: 
      var $91=$1;
      var $92=(($91+274)|0);
      var $93=HEAPU8[($92)];
      var $94=(($93)&255);
      var $95=(($94)|0)==3;
      if ($95) { __label__ = 26; break; } else { __label__ = 32; break; }
    case 26: 
      var $97=(($buf)|0);
      var $98=HEAP8[($97)];
      var $99=$1;
      var $100=(($99+292)|0);
      var $101=(($100)|0);
      HEAP8[($101)]=$98;
      var $102=$2;
      var $103=(($102)|0)!=0;
      if ($103) { __label__ = 27; break; } else { __label__ = 31; break; }
    case 27: 
      var $105=$2;
      var $106=(($105+20)|0);
      var $107=HEAPU16[(($106)>>1)];
      var $108=(($107)&65535);
      var $109=(($108)|0)!=0;
      if ($109) { __label__ = 28; break; } else { __label__ = 31; break; }
    case 28: 
      var $111=(($buf)|0);
      var $112=HEAPU8[($111)];
      var $113=(($112)&255);
      var $114=$2;
      var $115=(($114+20)|0);
      var $116=HEAPU16[(($115)>>1)];
      var $117=(($116)&65535);
      var $118=(($113)|0) >= (($117)|0);
      if ($118) { __label__ = 29; break; } else { __label__ = 30; break; }
    case 29: 
      var $120=$1;
      _png_warning($120, ((STRING_TABLE.__str77)|0));
      __label__ = 37; break;
    case 30: 
      var $122=(($buf)|0);
      var $123=HEAPU8[($122)];
      var $124=(($123)&255);
      var $125=$1;
      var $126=(($125+256)|0);
      var $127=HEAP32[(($126)>>2)];
      var $128=(($127+($124)*(3))|0);
      var $129=(($128)|0);
      var $130=HEAPU8[($129)];
      var $131=(($130)&255);
      var $132=$1;
      var $133=(($132+292)|0);
      var $134=(($133+2)|0);
      HEAP16[(($134)>>1)]=$131;
      var $135=(($buf)|0);
      var $136=HEAPU8[($135)];
      var $137=(($136)&255);
      var $138=$1;
      var $139=(($138+256)|0);
      var $140=HEAP32[(($139)>>2)];
      var $141=(($140+($137)*(3))|0);
      var $142=(($141+1)|0);
      var $143=HEAPU8[($142)];
      var $144=(($143)&255);
      var $145=$1;
      var $146=(($145+292)|0);
      var $147=(($146+4)|0);
      HEAP16[(($147)>>1)]=$144;
      var $148=(($buf)|0);
      var $149=HEAPU8[($148)];
      var $150=(($149)&255);
      var $151=$1;
      var $152=(($151+256)|0);
      var $153=HEAP32[(($152)>>2)];
      var $154=(($153+($150)*(3))|0);
      var $155=(($154+2)|0);
      var $156=HEAPU8[($155)];
      var $157=(($156)&255);
      var $158=$1;
      var $159=(($158+292)|0);
      var $160=(($159+6)|0);
      HEAP16[(($160)>>1)]=$157;
      __label__ = 31; break;
    case 31: 
      __label__ = 36; break;
    case 32: 
      var $163=$1;
      var $164=(($163+274)|0);
      var $165=HEAPU8[($164)];
      var $166=(($165)&255);
      var $167=$166 & 2;
      var $168=(($167)|0)!=0;
      if ($168) { __label__ = 34; break; } else { __label__ = 33; break; }
    case 33: 
      var $170=(($buf)|0);
      var $171=HEAPU8[($170)];
      var $172=(($171)&255);
      var $173=$172 << 8;
      var $174=(($buf)|0);
      var $175=(($174+1)|0);
      var $176=HEAPU8[($175)];
      var $177=(($176)&255);
      var $178=((($173)+($177))|0);
      var $179=(($178) & 65535);
      var $180=$1;
      var $181=(($180+292)|0);
      var $182=(($181+8)|0);
      HEAP16[(($182)>>1)]=$179;
      var $183=$1;
      var $184=(($183+292)|0);
      var $185=(($184+6)|0);
      HEAP16[(($185)>>1)]=$179;
      var $186=$1;
      var $187=(($186+292)|0);
      var $188=(($187+4)|0);
      HEAP16[(($188)>>1)]=$179;
      var $189=$1;
      var $190=(($189+292)|0);
      var $191=(($190+2)|0);
      HEAP16[(($191)>>1)]=$179;
      __label__ = 35; break;
    case 34: 
      var $193=(($buf)|0);
      var $194=HEAPU8[($193)];
      var $195=(($194)&255);
      var $196=$195 << 8;
      var $197=(($buf)|0);
      var $198=(($197+1)|0);
      var $199=HEAPU8[($198)];
      var $200=(($199)&255);
      var $201=((($196)+($200))|0);
      var $202=(($201) & 65535);
      var $203=$1;
      var $204=(($203+292)|0);
      var $205=(($204+2)|0);
      HEAP16[(($205)>>1)]=$202;
      var $206=(($buf)|0);
      var $207=(($206+2)|0);
      var $208=HEAPU8[($207)];
      var $209=(($208)&255);
      var $210=$209 << 8;
      var $211=(($buf)|0);
      var $212=(($211+2)|0);
      var $213=(($212+1)|0);
      var $214=HEAPU8[($213)];
      var $215=(($214)&255);
      var $216=((($210)+($215))|0);
      var $217=(($216) & 65535);
      var $218=$1;
      var $219=(($218+292)|0);
      var $220=(($219+4)|0);
      HEAP16[(($220)>>1)]=$217;
      var $221=(($buf)|0);
      var $222=(($221+4)|0);
      var $223=HEAPU8[($222)];
      var $224=(($223)&255);
      var $225=$224 << 8;
      var $226=(($buf)|0);
      var $227=(($226+4)|0);
      var $228=(($227+1)|0);
      var $229=HEAPU8[($228)];
      var $230=(($229)&255);
      var $231=((($225)+($230))|0);
      var $232=(($231) & 65535);
      var $233=$1;
      var $234=(($233+292)|0);
      var $235=(($234+6)|0);
      HEAP16[(($235)>>1)]=$232;
      __label__ = 35; break;
    case 35: 
      __label__ = 36; break;
    case 36: 
      var $238=$1;
      var $239=$2;
      var $240=$1;
      var $241=(($240+292)|0);
      _png_set_bKGD($238, $239, $241);
      __label__ = 37; break;
    case 37: 
      STACKTOP = __stackBase__;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_png_handle_bKGD["X"]=1;

function _png_handle_hIST($png_ptr, $info_ptr, $length) {
  var __stackBase__  = STACKTOP; STACKTOP += 516; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $num;
      var $i;
      var $readbuf=__stackBase__;
      var $buf=(__stackBase__)+(512);
      $1=$png_ptr;
      $2=$info_ptr;
      $3=$length;
      var $4=$1;
      var $5=(($4+84)|0);
      var $6=HEAP32[(($5)>>2)];
      var $7=$6 & 1;
      var $8=(($7)|0)!=0;
      if ($8) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      var $10=$1;
      _png_error($10, ((STRING_TABLE.__str78)|0));
      __label__ = 14; break;
    case 4: 
      var $12=$1;
      var $13=(($12+84)|0);
      var $14=HEAP32[(($13)>>2)];
      var $15=$14 & 4;
      var $16=(($15)|0)!=0;
      if ($16) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $18=$1;
      _png_warning($18, ((STRING_TABLE.__str79)|0));
      var $19=$1;
      var $20=$3;
      var $21=_png_crc_finish($19, $20);
      __label__ = 24; break;
    case 6: 
      var $23=$1;
      var $24=(($23+84)|0);
      var $25=HEAP32[(($24)>>2)];
      var $26=$25 & 2;
      var $27=(($26)|0)!=0;
      if ($27) { __label__ = 8; break; } else { __label__ = 7; break; }
    case 7: 
      var $29=$1;
      _png_warning($29, ((STRING_TABLE.__str80)|0));
      var $30=$1;
      var $31=$3;
      var $32=_png_crc_finish($30, $31);
      __label__ = 24; break;
    case 8: 
      var $34=$2;
      var $35=(($34)|0)!=0;
      if ($35) { __label__ = 9; break; } else { __label__ = 11; break; }
    case 9: 
      var $37=$2;
      var $38=(($37+8)|0);
      var $39=HEAP32[(($38)>>2)];
      var $40=$39 & 64;
      var $41=(($40)|0)!=0;
      if ($41) { __label__ = 10; break; } else { __label__ = 11; break; }
    case 10: 
      var $43=$1;
      _png_warning($43, ((STRING_TABLE.__str81)|0));
      var $44=$1;
      var $45=$3;
      var $46=_png_crc_finish($44, $45);
      __label__ = 24; break;
    case 11: 
      __label__ = 12; break;
    case 12: 
      __label__ = 13; break;
    case 13: 
      __label__ = 14; break;
    case 14: 
      var $51=$3;
      var $52=(($51)>>>0) > 512;
      if ($52) { __label__ = 16; break; } else { __label__ = 15; break; }
    case 15: 
      var $54=$3;
      var $55=$1;
      var $56=(($55+260)|0);
      var $57=HEAPU16[(($56)>>1)];
      var $58=(($57)&65535);
      var $59=((($58<<1))|0);
      var $60=(($54)|0)!=(($59)|0);
      if ($60) { __label__ = 16; break; } else { __label__ = 17; break; }
    case 16: 
      var $62=$1;
      _png_warning($62, ((STRING_TABLE.__str82)|0));
      var $63=$1;
      var $64=$3;
      var $65=_png_crc_finish($63, $64);
      __label__ = 24; break;
    case 17: 
      var $67=$3;
      var $68=Math.floor(((($67)>>>0))/(2));
      $num=$68;
      $i=0;
      __label__ = 18; break;
    case 18: 
      var $70=$i;
      var $71=$num;
      var $72=(($70)>>>0) < (($71)>>>0);
      if ($72) { __label__ = 19; break; } else { __label__ = 21; break; }
    case 19: 
      var $74=$1;
      var $75=(($buf)|0);
      _png_crc_read($74, $75, 2);
      var $76=(($buf)|0);
      var $77=HEAPU8[($76)];
      var $78=(($77)&255);
      var $79=$78 << 8;
      var $80=(($buf)|0);
      var $81=(($80+1)|0);
      var $82=HEAPU8[($81)];
      var $83=(($82)&255);
      var $84=((($79)+($83))|0);
      var $85=(($84) & 65535);
      var $86=$i;
      var $87=(($readbuf+($86<<1))|0);
      HEAP16[(($87)>>1)]=$85;
      __label__ = 20; break;
    case 20: 
      var $89=$i;
      var $90=((($89)+(1))|0);
      $i=$90;
      __label__ = 18; break;
    case 21: 
      var $92=$1;
      var $93=_png_crc_finish($92, 0);
      var $94=(($93)|0)!=0;
      if ($94) { __label__ = 22; break; } else { __label__ = 23; break; }
    case 22: 
      __label__ = 24; break;
    case 23: 
      var $97=$1;
      var $98=$2;
      var $99=(($readbuf)|0);
      _png_set_hIST($97, $98, $99);
      __label__ = 24; break;
    case 24: 
      STACKTOP = __stackBase__;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_png_handle_hIST["X"]=1;

function _png_handle_pHYs($png_ptr, $info_ptr, $length) {
  var __stackBase__  = STACKTOP; STACKTOP += 12; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $buf=__stackBase__;
      var $res_x;
      var $res_y;
      var $unit_type;
      $1=$png_ptr;
      $2=$info_ptr;
      $3=$length;
      var $4=$1;
      var $5=(($4+84)|0);
      var $6=HEAP32[(($5)>>2)];
      var $7=$6 & 1;
      var $8=(($7)|0)!=0;
      if ($8) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      var $10=$1;
      _png_error($10, ((STRING_TABLE.__str83)|0));
      __label__ = 11; break;
    case 4: 
      var $12=$1;
      var $13=(($12+84)|0);
      var $14=HEAP32[(($13)>>2)];
      var $15=$14 & 4;
      var $16=(($15)|0)!=0;
      if ($16) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $18=$1;
      _png_warning($18, ((STRING_TABLE.__str84)|0));
      var $19=$1;
      var $20=$3;
      var $21=_png_crc_finish($19, $20);
      __label__ = 16; break;
    case 6: 
      var $23=$2;
      var $24=(($23)|0)!=0;
      if ($24) { __label__ = 7; break; } else { __label__ = 9; break; }
    case 7: 
      var $26=$2;
      var $27=(($26+8)|0);
      var $28=HEAP32[(($27)>>2)];
      var $29=$28 & 128;
      var $30=(($29)|0)!=0;
      if ($30) { __label__ = 8; break; } else { __label__ = 9; break; }
    case 8: 
      var $32=$1;
      _png_warning($32, ((STRING_TABLE.__str85)|0));
      var $33=$1;
      var $34=$3;
      var $35=_png_crc_finish($33, $34);
      __label__ = 16; break;
    case 9: 
      __label__ = 10; break;
    case 10: 
      __label__ = 11; break;
    case 11: 
      var $39=$3;
      var $40=(($39)|0)!=9;
      if ($40) { __label__ = 12; break; } else { __label__ = 13; break; }
    case 12: 
      var $42=$1;
      _png_warning($42, ((STRING_TABLE.__str86)|0));
      var $43=$1;
      var $44=$3;
      var $45=_png_crc_finish($43, $44);
      __label__ = 16; break;
    case 13: 
      var $47=$1;
      var $48=(($buf)|0);
      _png_crc_read($47, $48, 9);
      var $49=$1;
      var $50=_png_crc_finish($49, 0);
      var $51=(($50)|0)!=0;
      if ($51) { __label__ = 14; break; } else { __label__ = 15; break; }
    case 14: 
      __label__ = 16; break;
    case 15: 
      var $54=(($buf)|0);
      var $55=HEAPU8[($54)];
      var $56=(($55)&255);
      var $57=$56 << 24;
      var $58=(($buf)|0);
      var $59=(($58+1)|0);
      var $60=HEAPU8[($59)];
      var $61=(($60)&255);
      var $62=$61 << 16;
      var $63=((($57)+($62))|0);
      var $64=(($buf)|0);
      var $65=(($64+2)|0);
      var $66=HEAPU8[($65)];
      var $67=(($66)&255);
      var $68=$67 << 8;
      var $69=((($63)+($68))|0);
      var $70=(($buf)|0);
      var $71=(($70+3)|0);
      var $72=HEAPU8[($71)];
      var $73=(($72)&255);
      var $74=((($69)+($73))|0);
      $res_x=$74;
      var $75=(($buf)|0);
      var $76=(($75+4)|0);
      var $77=HEAPU8[($76)];
      var $78=(($77)&255);
      var $79=$78 << 24;
      var $80=(($buf)|0);
      var $81=(($80+4)|0);
      var $82=(($81+1)|0);
      var $83=HEAPU8[($82)];
      var $84=(($83)&255);
      var $85=$84 << 16;
      var $86=((($79)+($85))|0);
      var $87=(($buf)|0);
      var $88=(($87+4)|0);
      var $89=(($88+2)|0);
      var $90=HEAPU8[($89)];
      var $91=(($90)&255);
      var $92=$91 << 8;
      var $93=((($86)+($92))|0);
      var $94=(($buf)|0);
      var $95=(($94+4)|0);
      var $96=(($95+3)|0);
      var $97=HEAPU8[($96)];
      var $98=(($97)&255);
      var $99=((($93)+($98))|0);
      $res_y=$99;
      var $100=(($buf+8)|0);
      var $101=HEAPU8[($100)];
      var $102=(($101)&255);
      $unit_type=$102;
      var $103=$1;
      var $104=$2;
      var $105=$res_x;
      var $106=$res_y;
      var $107=$unit_type;
      _png_set_pHYs($103, $104, $105, $106, $107);
      __label__ = 16; break;
    case 16: 
      STACKTOP = __stackBase__;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_png_handle_pHYs["X"]=1;

function _png_handle_oFFs($png_ptr, $info_ptr, $length) {
  var __stackBase__  = STACKTOP; STACKTOP += 12; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $buf=__stackBase__;
      var $offset_x;
      var $offset_y;
      var $unit_type;
      $1=$png_ptr;
      $2=$info_ptr;
      $3=$length;
      var $4=$1;
      var $5=(($4+84)|0);
      var $6=HEAP32[(($5)>>2)];
      var $7=$6 & 1;
      var $8=(($7)|0)!=0;
      if ($8) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      var $10=$1;
      _png_error($10, ((STRING_TABLE.__str87)|0));
      __label__ = 11; break;
    case 4: 
      var $12=$1;
      var $13=(($12+84)|0);
      var $14=HEAP32[(($13)>>2)];
      var $15=$14 & 4;
      var $16=(($15)|0)!=0;
      if ($16) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $18=$1;
      _png_warning($18, ((STRING_TABLE.__str88)|0));
      var $19=$1;
      var $20=$3;
      var $21=_png_crc_finish($19, $20);
      __label__ = 22; break;
    case 6: 
      var $23=$2;
      var $24=(($23)|0)!=0;
      if ($24) { __label__ = 7; break; } else { __label__ = 9; break; }
    case 7: 
      var $26=$2;
      var $27=(($26+8)|0);
      var $28=HEAP32[(($27)>>2)];
      var $29=$28 & 256;
      var $30=(($29)|0)!=0;
      if ($30) { __label__ = 8; break; } else { __label__ = 9; break; }
    case 8: 
      var $32=$1;
      _png_warning($32, ((STRING_TABLE.__str89)|0));
      var $33=$1;
      var $34=$3;
      var $35=_png_crc_finish($33, $34);
      __label__ = 22; break;
    case 9: 
      __label__ = 10; break;
    case 10: 
      __label__ = 11; break;
    case 11: 
      var $39=$3;
      var $40=(($39)|0)!=9;
      if ($40) { __label__ = 12; break; } else { __label__ = 13; break; }
    case 12: 
      var $42=$1;
      _png_warning($42, ((STRING_TABLE.__str90)|0));
      var $43=$1;
      var $44=$3;
      var $45=_png_crc_finish($43, $44);
      __label__ = 22; break;
    case 13: 
      var $47=$1;
      var $48=(($buf)|0);
      _png_crc_read($47, $48, 9);
      var $49=$1;
      var $50=_png_crc_finish($49, 0);
      var $51=(($50)|0)!=0;
      if ($51) { __label__ = 14; break; } else { __label__ = 15; break; }
    case 14: 
      __label__ = 22; break;
    case 15: 
      var $54=(($buf)|0);
      var $55=HEAPU8[($54)];
      var $56=(($55)&255);
      var $57=$56 & 128;
      var $58=(($57)|0)!=0;
      if ($58) { __label__ = 16; break; } else { __label__ = 17; break; }
    case 16: 
      var $60=(($buf)|0);
      var $61=HEAPU8[($60)];
      var $62=(($61)&255);
      var $63=$62 << 24;
      var $64=(($buf)|0);
      var $65=(($64+1)|0);
      var $66=HEAPU8[($65)];
      var $67=(($66)&255);
      var $68=$67 << 16;
      var $69=((($63)+($68))|0);
      var $70=(($buf)|0);
      var $71=(($70+2)|0);
      var $72=HEAPU8[($71)];
      var $73=(($72)&255);
      var $74=$73 << 8;
      var $75=((($69)+($74))|0);
      var $76=(($buf)|0);
      var $77=(($76+3)|0);
      var $78=HEAPU8[($77)];
      var $79=(($78)&255);
      var $80=((($75)+($79))|0);
      var $81=$80 ^ -1;
      var $82=((($81)+(1))|0);
      var $83=(((-$82))|0);
      var $107 = $83;__label__ = 18; break;
    case 17: 
      var $85=(($buf)|0);
      var $86=HEAPU8[($85)];
      var $87=(($86)&255);
      var $88=$87 << 24;
      var $89=(($buf)|0);
      var $90=(($89+1)|0);
      var $91=HEAPU8[($90)];
      var $92=(($91)&255);
      var $93=$92 << 16;
      var $94=((($88)+($93))|0);
      var $95=(($buf)|0);
      var $96=(($95+2)|0);
      var $97=HEAPU8[($96)];
      var $98=(($97)&255);
      var $99=$98 << 8;
      var $100=((($94)+($99))|0);
      var $101=(($buf)|0);
      var $102=(($101+3)|0);
      var $103=HEAPU8[($102)];
      var $104=(($103)&255);
      var $105=((($100)+($104))|0);
      var $107 = $105;__label__ = 18; break;
    case 18: 
      var $107;
      $offset_x=$107;
      var $108=(($buf)|0);
      var $109=(($108+4)|0);
      var $110=HEAPU8[($109)];
      var $111=(($110)&255);
      var $112=$111 & 128;
      var $113=(($112)|0)!=0;
      if ($113) { __label__ = 19; break; } else { __label__ = 20; break; }
    case 19: 
      var $115=(($buf)|0);
      var $116=(($115+4)|0);
      var $117=HEAPU8[($116)];
      var $118=(($117)&255);
      var $119=$118 << 24;
      var $120=(($buf)|0);
      var $121=(($120+4)|0);
      var $122=(($121+1)|0);
      var $123=HEAPU8[($122)];
      var $124=(($123)&255);
      var $125=$124 << 16;
      var $126=((($119)+($125))|0);
      var $127=(($buf)|0);
      var $128=(($127+4)|0);
      var $129=(($128+2)|0);
      var $130=HEAPU8[($129)];
      var $131=(($130)&255);
      var $132=$131 << 8;
      var $133=((($126)+($132))|0);
      var $134=(($buf)|0);
      var $135=(($134+4)|0);
      var $136=(($135+3)|0);
      var $137=HEAPU8[($136)];
      var $138=(($137)&255);
      var $139=((($133)+($138))|0);
      var $140=$139 ^ -1;
      var $141=((($140)+(1))|0);
      var $142=(((-$141))|0);
      var $170 = $142;__label__ = 21; break;
    case 20: 
      var $144=(($buf)|0);
      var $145=(($144+4)|0);
      var $146=HEAPU8[($145)];
      var $147=(($146)&255);
      var $148=$147 << 24;
      var $149=(($buf)|0);
      var $150=(($149+4)|0);
      var $151=(($150+1)|0);
      var $152=HEAPU8[($151)];
      var $153=(($152)&255);
      var $154=$153 << 16;
      var $155=((($148)+($154))|0);
      var $156=(($buf)|0);
      var $157=(($156+4)|0);
      var $158=(($157+2)|0);
      var $159=HEAPU8[($158)];
      var $160=(($159)&255);
      var $161=$160 << 8;
      var $162=((($155)+($161))|0);
      var $163=(($buf)|0);
      var $164=(($163+4)|0);
      var $165=(($164+3)|0);
      var $166=HEAPU8[($165)];
      var $167=(($166)&255);
      var $168=((($162)+($167))|0);
      var $170 = $168;__label__ = 21; break;
    case 21: 
      var $170;
      $offset_y=$170;
      var $171=(($buf+8)|0);
      var $172=HEAPU8[($171)];
      var $173=(($172)&255);
      $unit_type=$173;
      var $174=$1;
      var $175=$2;
      var $176=$offset_x;
      var $177=$offset_y;
      var $178=$unit_type;
      _png_set_oFFs($174, $175, $176, $177, $178);
      __label__ = 22; break;
    case 22: 
      STACKTOP = __stackBase__;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_png_handle_oFFs["X"]=1;

function _png_handle_pCAL($png_ptr, $info_ptr, $length) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $X0;
      var $X1;
      var $type;
      var $nparams;
      var $buf;
      var $units;
      var $endptr;
      var $params;
      var $slength;
      var $i;
      $1=$png_ptr;
      $2=$info_ptr;
      $3=$length;
      var $4=$1;
      var $5=(($4+84)|0);
      var $6=HEAP32[(($5)>>2)];
      var $7=$6 & 1;
      var $8=(($7)|0)!=0;
      if ($8) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      var $10=$1;
      _png_error($10, ((STRING_TABLE.__str91226)|0));
      __label__ = 11; break;
    case 4: 
      var $12=$1;
      var $13=(($12+84)|0);
      var $14=HEAP32[(($13)>>2)];
      var $15=$14 & 4;
      var $16=(($15)|0)!=0;
      if ($16) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $18=$1;
      _png_warning($18, ((STRING_TABLE.__str92)|0));
      var $19=$1;
      var $20=$3;
      var $21=_png_crc_finish($19, $20);
      __label__ = 58; break;
    case 6: 
      var $23=$2;
      var $24=(($23)|0)!=0;
      if ($24) { __label__ = 7; break; } else { __label__ = 9; break; }
    case 7: 
      var $26=$2;
      var $27=(($26+8)|0);
      var $28=HEAP32[(($27)>>2)];
      var $29=$28 & 1024;
      var $30=(($29)|0)!=0;
      if ($30) { __label__ = 8; break; } else { __label__ = 9; break; }
    case 8: 
      var $32=$1;
      _png_warning($32, ((STRING_TABLE.__str93)|0));
      var $33=$1;
      var $34=$3;
      var $35=_png_crc_finish($33, $34);
      __label__ = 58; break;
    case 9: 
      __label__ = 10; break;
    case 10: 
      __label__ = 11; break;
    case 11: 
      var $39=$1;
      var $40=$1;
      var $41=(($40+624)|0);
      var $42=HEAP32[(($41)>>2)];
      _png_free($39, $42);
      var $43=$1;
      var $44=$3;
      var $45=((($44)+(1))|0);
      var $46=_png_malloc_warn($43, $45);
      var $47=$1;
      var $48=(($47+624)|0);
      HEAP32[(($48)>>2)]=$46;
      var $49=$1;
      var $50=(($49+624)|0);
      var $51=HEAP32[(($50)>>2)];
      var $52=(($51)|0)==0;
      if ($52) { __label__ = 12; break; } else { __label__ = 13; break; }
    case 12: 
      var $54=$1;
      _png_warning($54, ((STRING_TABLE.__str94)|0));
      __label__ = 58; break;
    case 13: 
      var $56=$3;
      $slength=$56;
      var $57=$1;
      var $58=$1;
      var $59=(($58+624)|0);
      var $60=HEAP32[(($59)>>2)];
      var $61=$slength;
      _png_crc_read($57, $60, $61);
      var $62=$1;
      var $63=_png_crc_finish($62, 0);
      var $64=(($63)|0)!=0;
      if ($64) { __label__ = 14; break; } else { __label__ = 15; break; }
    case 14: 
      var $66=$1;
      var $67=$1;
      var $68=(($67+624)|0);
      var $69=HEAP32[(($68)>>2)];
      _png_free($66, $69);
      var $70=$1;
      var $71=(($70+624)|0);
      HEAP32[(($71)>>2)]=0;
      __label__ = 58; break;
    case 15: 
      var $73=$slength;
      var $74=$1;
      var $75=(($74+624)|0);
      var $76=HEAP32[(($75)>>2)];
      var $77=(($76+$73)|0);
      HEAP8[($77)]=0;
      var $78=$1;
      var $79=(($78+624)|0);
      var $80=HEAP32[(($79)>>2)];
      $buf=$80;
      __label__ = 16; break;
    case 16: 
      var $82=$buf;
      var $83=HEAP8[($82)];
      var $84=(($83 << 24) >> 24)!=0;
      if ($84) { __label__ = 17; break; } else { __label__ = 19; break; }
    case 17: 
      __label__ = 18; break;
    case 18: 
      var $87=$buf;
      var $88=(($87+1)|0);
      $buf=$88;
      __label__ = 16; break;
    case 19: 
      var $90=$1;
      var $91=(($90+624)|0);
      var $92=HEAP32[(($91)>>2)];
      var $93=$slength;
      var $94=(($92+$93)|0);
      $endptr=$94;
      var $95=$endptr;
      var $96=$buf;
      var $97=(($96+12)|0);
      var $98=(($95)>>>0) <= (($97)>>>0);
      if ($98) { __label__ = 20; break; } else { __label__ = 21; break; }
    case 20: 
      var $100=$1;
      _png_warning($100, ((STRING_TABLE.__str95)|0));
      var $101=$1;
      var $102=$1;
      var $103=(($102+624)|0);
      var $104=HEAP32[(($103)>>2)];
      _png_free($101, $104);
      var $105=$1;
      var $106=(($105+624)|0);
      HEAP32[(($106)>>2)]=0;
      __label__ = 58; break;
    case 21: 
      var $108=$buf;
      var $109=(($108+1)|0);
      var $110=HEAPU8[($109)];
      var $111=(($110)&255);
      var $112=$111 & 128;
      var $113=(($112)|0)!=0;
      if ($113) { __label__ = 22; break; } else { __label__ = 23; break; }
    case 22: 
      var $115=$buf;
      var $116=(($115+1)|0);
      var $117=HEAPU8[($116)];
      var $118=(($117)&255);
      var $119=$118 << 24;
      var $120=$buf;
      var $121=(($120+1)|0);
      var $122=(($121+1)|0);
      var $123=HEAPU8[($122)];
      var $124=(($123)&255);
      var $125=$124 << 16;
      var $126=((($119)+($125))|0);
      var $127=$buf;
      var $128=(($127+1)|0);
      var $129=(($128+2)|0);
      var $130=HEAPU8[($129)];
      var $131=(($130)&255);
      var $132=$131 << 8;
      var $133=((($126)+($132))|0);
      var $134=$buf;
      var $135=(($134+1)|0);
      var $136=(($135+3)|0);
      var $137=HEAPU8[($136)];
      var $138=(($137)&255);
      var $139=((($133)+($138))|0);
      var $140=$139 ^ -1;
      var $141=((($140)+(1))|0);
      var $142=(((-$141))|0);
      var $170 = $142;__label__ = 24; break;
    case 23: 
      var $144=$buf;
      var $145=(($144+1)|0);
      var $146=HEAPU8[($145)];
      var $147=(($146)&255);
      var $148=$147 << 24;
      var $149=$buf;
      var $150=(($149+1)|0);
      var $151=(($150+1)|0);
      var $152=HEAPU8[($151)];
      var $153=(($152)&255);
      var $154=$153 << 16;
      var $155=((($148)+($154))|0);
      var $156=$buf;
      var $157=(($156+1)|0);
      var $158=(($157+2)|0);
      var $159=HEAPU8[($158)];
      var $160=(($159)&255);
      var $161=$160 << 8;
      var $162=((($155)+($161))|0);
      var $163=$buf;
      var $164=(($163+1)|0);
      var $165=(($164+3)|0);
      var $166=HEAPU8[($165)];
      var $167=(($166)&255);
      var $168=((($162)+($167))|0);
      var $170 = $168;__label__ = 24; break;
    case 24: 
      var $170;
      $X0=$170;
      var $171=$buf;
      var $172=(($171+5)|0);
      var $173=HEAPU8[($172)];
      var $174=(($173)&255);
      var $175=$174 & 128;
      var $176=(($175)|0)!=0;
      if ($176) { __label__ = 25; break; } else { __label__ = 26; break; }
    case 25: 
      var $178=$buf;
      var $179=(($178+5)|0);
      var $180=HEAPU8[($179)];
      var $181=(($180)&255);
      var $182=$181 << 24;
      var $183=$buf;
      var $184=(($183+5)|0);
      var $185=(($184+1)|0);
      var $186=HEAPU8[($185)];
      var $187=(($186)&255);
      var $188=$187 << 16;
      var $189=((($182)+($188))|0);
      var $190=$buf;
      var $191=(($190+5)|0);
      var $192=(($191+2)|0);
      var $193=HEAPU8[($192)];
      var $194=(($193)&255);
      var $195=$194 << 8;
      var $196=((($189)+($195))|0);
      var $197=$buf;
      var $198=(($197+5)|0);
      var $199=(($198+3)|0);
      var $200=HEAPU8[($199)];
      var $201=(($200)&255);
      var $202=((($196)+($201))|0);
      var $203=$202 ^ -1;
      var $204=((($203)+(1))|0);
      var $205=(((-$204))|0);
      var $233 = $205;__label__ = 27; break;
    case 26: 
      var $207=$buf;
      var $208=(($207+5)|0);
      var $209=HEAPU8[($208)];
      var $210=(($209)&255);
      var $211=$210 << 24;
      var $212=$buf;
      var $213=(($212+5)|0);
      var $214=(($213+1)|0);
      var $215=HEAPU8[($214)];
      var $216=(($215)&255);
      var $217=$216 << 16;
      var $218=((($211)+($217))|0);
      var $219=$buf;
      var $220=(($219+5)|0);
      var $221=(($220+2)|0);
      var $222=HEAPU8[($221)];
      var $223=(($222)&255);
      var $224=$223 << 8;
      var $225=((($218)+($224))|0);
      var $226=$buf;
      var $227=(($226+5)|0);
      var $228=(($227+3)|0);
      var $229=HEAPU8[($228)];
      var $230=(($229)&255);
      var $231=((($225)+($230))|0);
      var $233 = $231;__label__ = 27; break;
    case 27: 
      var $233;
      $X1=$233;
      var $234=$buf;
      var $235=(($234+9)|0);
      var $236=HEAP8[($235)];
      $type=$236;
      var $237=$buf;
      var $238=(($237+10)|0);
      var $239=HEAP8[($238)];
      $nparams=$239;
      var $240=$buf;
      var $241=(($240+11)|0);
      $units=$241;
      var $242=$type;
      var $243=(($242)&255);
      var $244=(($243)|0)==0;
      if ($244) { __label__ = 28; break; } else { __label__ = 29; break; }
    case 28: 
      var $246=$nparams;
      var $247=(($246)&255);
      var $248=(($247)|0)!=2;
      if ($248) { __label__ = 35; break; } else { __label__ = 29; break; }
    case 29: 
      var $250=$type;
      var $251=(($250)&255);
      var $252=(($251)|0)==1;
      if ($252) { __label__ = 30; break; } else { __label__ = 31; break; }
    case 30: 
      var $254=$nparams;
      var $255=(($254)&255);
      var $256=(($255)|0)!=3;
      if ($256) { __label__ = 35; break; } else { __label__ = 31; break; }
    case 31: 
      var $258=$type;
      var $259=(($258)&255);
      var $260=(($259)|0)==2;
      if ($260) { __label__ = 32; break; } else { __label__ = 33; break; }
    case 32: 
      var $262=$nparams;
      var $263=(($262)&255);
      var $264=(($263)|0)!=3;
      if ($264) { __label__ = 35; break; } else { __label__ = 33; break; }
    case 33: 
      var $266=$type;
      var $267=(($266)&255);
      var $268=(($267)|0)==3;
      if ($268) { __label__ = 34; break; } else { __label__ = 36; break; }
    case 34: 
      var $270=$nparams;
      var $271=(($270)&255);
      var $272=(($271)|0)!=4;
      if ($272) { __label__ = 35; break; } else { __label__ = 36; break; }
    case 35: 
      var $274=$1;
      _png_warning($274, ((STRING_TABLE.__str96)|0));
      var $275=$1;
      var $276=$1;
      var $277=(($276+624)|0);
      var $278=HEAP32[(($277)>>2)];
      _png_free($275, $278);
      var $279=$1;
      var $280=(($279+624)|0);
      HEAP32[(($280)>>2)]=0;
      __label__ = 58; break;
    case 36: 
      var $282=$type;
      var $283=(($282)&255);
      var $284=(($283)|0) >= 4;
      if ($284) { __label__ = 37; break; } else { __label__ = 38; break; }
    case 37: 
      var $286=$1;
      _png_warning($286, ((STRING_TABLE.__str97)|0));
      __label__ = 38; break;
    case 38: 
      __label__ = 39; break;
    case 39: 
      var $289=$units;
      $buf=$289;
      __label__ = 40; break;
    case 40: 
      var $291=$buf;
      var $292=HEAP8[($291)];
      var $293=(($292 << 24) >> 24)!=0;
      if ($293) { __label__ = 41; break; } else { __label__ = 43; break; }
    case 41: 
      __label__ = 42; break;
    case 42: 
      var $296=$buf;
      var $297=(($296+1)|0);
      $buf=$297;
      __label__ = 40; break;
    case 43: 
      var $299=$1;
      var $300=$nparams;
      var $301=(($300)&255);
      var $302=((($301<<2))|0);
      var $303=_png_malloc_warn($299, $302);
      var $304=$303;
      $params=$304;
      var $305=$params;
      var $306=(($305)|0)==0;
      if ($306) { __label__ = 44; break; } else { __label__ = 45; break; }
    case 44: 
      var $308=$1;
      var $309=$1;
      var $310=(($309+624)|0);
      var $311=HEAP32[(($310)>>2)];
      _png_free($308, $311);
      var $312=$1;
      var $313=(($312+624)|0);
      HEAP32[(($313)>>2)]=0;
      var $314=$1;
      _png_warning($314, ((STRING_TABLE.__str98)|0));
      __label__ = 58; break;
    case 45: 
      $i=0;
      __label__ = 46; break;
    case 46: 
      var $317=$i;
      var $318=$nparams;
      var $319=(($318)&255);
      var $320=(($317)|0) < (($319)|0);
      if ($320) { __label__ = 47; break; } else { __label__ = 57; break; }
    case 47: 
      var $322=$buf;
      var $323=(($322+1)|0);
      $buf=$323;
      var $324=$buf;
      var $325=$i;
      var $326=$params;
      var $327=(($326+($325<<2))|0);
      HEAP32[(($327)>>2)]=$324;
      __label__ = 48; break;
    case 48: 
      var $329=$buf;
      var $330=$endptr;
      var $331=(($329)>>>0) <= (($330)>>>0);
      if ($331) { __label__ = 49; break; } else { var $338 = 0;__label__ = 50; break; }
    case 49: 
      var $333=$buf;
      var $334=HEAP8[($333)];
      var $335=(($334 << 24) >> 24);
      var $336=(($335)|0)!=0;
      var $338 = $336;__label__ = 50; break;
    case 50: 
      var $338;
      if ($338) { __label__ = 51; break; } else { __label__ = 53; break; }
    case 51: 
      __label__ = 52; break;
    case 52: 
      var $341=$buf;
      var $342=(($341+1)|0);
      $buf=$342;
      __label__ = 48; break;
    case 53: 
      var $344=$buf;
      var $345=$endptr;
      var $346=(($344)>>>0) > (($345)>>>0);
      if ($346) { __label__ = 54; break; } else { __label__ = 55; break; }
    case 54: 
      var $348=$1;
      _png_warning($348, ((STRING_TABLE.__str95)|0));
      var $349=$1;
      var $350=$1;
      var $351=(($350+624)|0);
      var $352=HEAP32[(($351)>>2)];
      _png_free($349, $352);
      var $353=$1;
      var $354=(($353+624)|0);
      HEAP32[(($354)>>2)]=0;
      var $355=$1;
      var $356=$params;
      var $357=$356;
      _png_free($355, $357);
      __label__ = 58; break;
    case 55: 
      __label__ = 56; break;
    case 56: 
      var $360=$i;
      var $361=((($360)+(1))|0);
      $i=$361;
      __label__ = 46; break;
    case 57: 
      var $363=$1;
      var $364=$2;
      var $365=$1;
      var $366=(($365+624)|0);
      var $367=HEAP32[(($366)>>2)];
      var $368=$X0;
      var $369=$X1;
      var $370=$type;
      var $371=(($370)&255);
      var $372=$nparams;
      var $373=(($372)&255);
      var $374=$units;
      var $375=$params;
      _png_set_pCAL($363, $364, $367, $368, $369, $371, $373, $374, $375);
      var $376=$1;
      var $377=$1;
      var $378=(($377+624)|0);
      var $379=HEAP32[(($378)>>2)];
      _png_free($376, $379);
      var $380=$1;
      var $381=(($380+624)|0);
      HEAP32[(($381)>>2)]=0;
      var $382=$1;
      var $383=$params;
      var $384=$383;
      _png_free($382, $384);
      __label__ = 58; break;
    case 58: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_png_handle_pCAL["X"]=1;

function _png_handle_sCAL($png_ptr, $info_ptr, $length) {
  var __stackBase__  = STACKTOP; STACKTOP += 4; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $ep;
      var $width;
      var $height;
      var $vp=__stackBase__;
      var $slength;
      $1=$png_ptr;
      $2=$info_ptr;
      $3=$length;
      var $4=$1;
      var $5=(($4+84)|0);
      var $6=HEAP32[(($5)>>2)];
      var $7=$6 & 1;
      var $8=(($7)|0)!=0;
      if ($8) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      var $10=$1;
      _png_error($10, ((STRING_TABLE.__str99)|0));
      __label__ = 14; break;
    case 4: 
      var $12=$1;
      var $13=(($12+84)|0);
      var $14=HEAP32[(($13)>>2)];
      var $15=$14 & 4;
      var $16=(($15)|0)!=0;
      if ($16) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $18=$1;
      _png_warning($18, ((STRING_TABLE.__str100)|0));
      var $19=$1;
      var $20=$3;
      var $21=_png_crc_finish($19, $20);
      __label__ = 33; break;
    case 6: 
      var $23=$2;
      var $24=(($23)|0)!=0;
      if ($24) { __label__ = 7; break; } else { __label__ = 9; break; }
    case 7: 
      var $26=$2;
      var $27=(($26+8)|0);
      var $28=HEAP32[(($27)>>2)];
      var $29=$28 & 16384;
      var $30=(($29)|0)!=0;
      if ($30) { __label__ = 8; break; } else { __label__ = 9; break; }
    case 8: 
      var $32=$1;
      _png_warning($32, ((STRING_TABLE.__str101)|0));
      var $33=$1;
      var $34=$3;
      var $35=_png_crc_finish($33, $34);
      __label__ = 33; break;
    case 9: 
      var $37=$3;
      var $38=(($37)>>>0) < 4;
      if ($38) { __label__ = 10; break; } else { __label__ = 11; break; }
    case 10: 
      var $40=$1;
      _png_warning($40, ((STRING_TABLE.__str102)|0));
      var $41=$1;
      var $42=$3;
      var $43=_png_crc_finish($41, $42);
      __label__ = 33; break;
    case 11: 
      __label__ = 12; break;
    case 12: 
      __label__ = 13; break;
    case 13: 
      __label__ = 14; break;
    case 14: 
      var $48=$1;
      var $49=$3;
      var $50=((($49)+(1))|0);
      var $51=_png_malloc_warn($48, $50);
      var $52=$1;
      var $53=(($52+624)|0);
      HEAP32[(($53)>>2)]=$51;
      var $54=$1;
      var $55=(($54+624)|0);
      var $56=HEAP32[(($55)>>2)];
      var $57=(($56)|0)==0;
      if ($57) { __label__ = 15; break; } else { __label__ = 16; break; }
    case 15: 
      var $59=$1;
      _png_warning($59, ((STRING_TABLE.__str103)|0));
      var $60=$1;
      var $61=$3;
      var $62=_png_crc_finish($60, $61);
      __label__ = 33; break;
    case 16: 
      var $64=$3;
      $slength=$64;
      var $65=$1;
      var $66=$1;
      var $67=(($66+624)|0);
      var $68=HEAP32[(($67)>>2)];
      var $69=$slength;
      _png_crc_read($65, $68, $69);
      var $70=$1;
      var $71=_png_crc_finish($70, 0);
      var $72=(($71)|0)!=0;
      if ($72) { __label__ = 17; break; } else { __label__ = 18; break; }
    case 17: 
      var $74=$1;
      var $75=$1;
      var $76=(($75+624)|0);
      var $77=HEAP32[(($76)>>2)];
      _png_free($74, $77);
      var $78=$1;
      var $79=(($78+624)|0);
      HEAP32[(($79)>>2)]=0;
      __label__ = 33; break;
    case 18: 
      var $81=$slength;
      var $82=$1;
      var $83=(($82+624)|0);
      var $84=HEAP32[(($83)>>2)];
      var $85=(($84+$81)|0);
      HEAP8[($85)]=0;
      var $86=$1;
      var $87=(($86+624)|0);
      var $88=HEAP32[(($87)>>2)];
      var $89=(($88+1)|0);
      $ep=$89;
      var $90=$ep;
      var $91=_strtod($90, $vp);
      $width=$91;
      var $92=HEAP32[(($vp)>>2)];
      var $93=HEAP8[($92)];
      var $94=(($93 << 24) >> 24)!=0;
      if ($94) { __label__ = 19; break; } else { __label__ = 20; break; }
    case 19: 
      var $96=$1;
      _png_warning($96, ((STRING_TABLE.__str104)|0));
      var $97=$1;
      var $98=$1;
      var $99=(($98+624)|0);
      var $100=HEAP32[(($99)>>2)];
      _png_free($97, $100);
      var $101=$1;
      var $102=(($101+624)|0);
      HEAP32[(($102)>>2)]=0;
      __label__ = 33; break;
    case 20: 
      var $104=$1;
      var $105=(($104+624)|0);
      var $106=HEAP32[(($105)>>2)];
      var $107=(($106+1)|0);
      $ep=$107;
      __label__ = 21; break;
    case 21: 
      var $109=$ep;
      var $110=HEAP8[($109)];
      var $111=(($110 << 24) >> 24)!=0;
      if ($111) { __label__ = 22; break; } else { __label__ = 24; break; }
    case 22: 
      __label__ = 23; break;
    case 23: 
      var $114=$ep;
      var $115=(($114+1)|0);
      $ep=$115;
      __label__ = 21; break;
    case 24: 
      var $117=$ep;
      var $118=(($117+1)|0);
      $ep=$118;
      var $119=$1;
      var $120=(($119+624)|0);
      var $121=HEAP32[(($120)>>2)];
      var $122=$slength;
      var $123=(($121+$122)|0);
      var $124=$ep;
      var $125=(($123)>>>0) < (($124)>>>0);
      if ($125) { __label__ = 25; break; } else { __label__ = 26; break; }
    case 25: 
      var $127=$1;
      _png_warning($127, ((STRING_TABLE.__str105)|0));
      var $128=$1;
      var $129=$1;
      var $130=(($129+624)|0);
      var $131=HEAP32[(($130)>>2)];
      _png_free($128, $131);
      var $132=$1;
      var $133=(($132+624)|0);
      HEAP32[(($133)>>2)]=0;
      __label__ = 33; break;
    case 26: 
      var $135=$ep;
      var $136=_strtod($135, $vp);
      $height=$136;
      var $137=HEAP32[(($vp)>>2)];
      var $138=HEAP8[($137)];
      var $139=(($138 << 24) >> 24)!=0;
      if ($139) { __label__ = 27; break; } else { __label__ = 28; break; }
    case 27: 
      var $141=$1;
      _png_warning($141, ((STRING_TABLE.__str106)|0));
      var $142=$1;
      var $143=$1;
      var $144=(($143+624)|0);
      var $145=HEAP32[(($144)>>2)];
      _png_free($142, $145);
      var $146=$1;
      var $147=(($146+624)|0);
      HEAP32[(($147)>>2)]=0;
      __label__ = 33; break;
    case 28: 
      var $149=$1;
      var $150=(($149+624)|0);
      var $151=HEAP32[(($150)>>2)];
      var $152=$slength;
      var $153=(($151+$152)|0);
      var $154=$ep;
      var $155=(($153)>>>0) < (($154)>>>0);
      if ($155) { __label__ = 31; break; } else { __label__ = 29; break; }
    case 29: 
      var $157=$width;
      var $158=$157 <= 0;
      if ($158) { __label__ = 31; break; } else { __label__ = 30; break; }
    case 30: 
      var $160=$height;
      var $161=$160 <= 0;
      if ($161) { __label__ = 31; break; } else { __label__ = 32; break; }
    case 31: 
      var $163=$1;
      _png_warning($163, ((STRING_TABLE.__str107)|0));
      var $164=$1;
      var $165=$1;
      var $166=(($165+624)|0);
      var $167=HEAP32[(($166)>>2)];
      _png_free($164, $167);
      var $168=$1;
      var $169=(($168+624)|0);
      HEAP32[(($169)>>2)]=0;
      __label__ = 33; break;
    case 32: 
      var $171=$1;
      var $172=$2;
      var $173=$1;
      var $174=(($173+624)|0);
      var $175=HEAP32[(($174)>>2)];
      var $176=(($175)|0);
      var $177=HEAP8[($176)];
      var $178=(($177 << 24) >> 24);
      var $179=$width;
      var $180=$height;
      _png_set_sCAL($171, $172, $178, $179, $180);
      var $181=$1;
      var $182=$1;
      var $183=(($182+624)|0);
      var $184=HEAP32[(($183)>>2)];
      _png_free($181, $184);
      var $185=$1;
      var $186=(($185+624)|0);
      HEAP32[(($186)>>2)]=0;
      __label__ = 33; break;
    case 33: 
      STACKTOP = __stackBase__;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_png_handle_sCAL["X"]=1;

function _png_handle_tIME($png_ptr, $info_ptr, $length) {
  var __stackBase__  = STACKTOP; STACKTOP += 16; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $buf=__stackBase__;
      var $mod_time=(__stackBase__)+(8);
      $1=$png_ptr;
      $2=$info_ptr;
      $3=$length;
      var $4=$1;
      var $5=(($4+84)|0);
      var $6=HEAP32[(($5)>>2)];
      var $7=$6 & 1;
      var $8=(($7)|0)!=0;
      if ($8) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      var $10=$1;
      _png_error($10, ((STRING_TABLE.__str108)|0));
      __label__ = 8; break;
    case 4: 
      var $12=$2;
      var $13=(($12)|0)!=0;
      if ($13) { __label__ = 5; break; } else { __label__ = 7; break; }
    case 5: 
      var $15=$2;
      var $16=(($15+8)|0);
      var $17=HEAP32[(($16)>>2)];
      var $18=$17 & 512;
      var $19=(($18)|0)!=0;
      if ($19) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      var $21=$1;
      _png_warning($21, ((STRING_TABLE.__str109)|0));
      var $22=$1;
      var $23=$3;
      var $24=_png_crc_finish($22, $23);
      __label__ = 15; break;
    case 7: 
      __label__ = 8; break;
    case 8: 
      var $27=$1;
      var $28=(($27+84)|0);
      var $29=HEAP32[(($28)>>2)];
      var $30=$29 & 4;
      var $31=(($30)|0)!=0;
      if ($31) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      var $33=$1;
      var $34=(($33+84)|0);
      var $35=HEAP32[(($34)>>2)];
      var $36=$35 | 8;
      HEAP32[(($34)>>2)]=$36;
      __label__ = 10; break;
    case 10: 
      var $38=$3;
      var $39=(($38)|0)!=7;
      if ($39) { __label__ = 11; break; } else { __label__ = 12; break; }
    case 11: 
      var $41=$1;
      _png_warning($41, ((STRING_TABLE.__str110)|0));
      var $42=$1;
      var $43=$3;
      var $44=_png_crc_finish($42, $43);
      __label__ = 15; break;
    case 12: 
      var $46=$1;
      var $47=(($buf)|0);
      _png_crc_read($46, $47, 7);
      var $48=$1;
      var $49=_png_crc_finish($48, 0);
      var $50=(($49)|0)!=0;
      if ($50) { __label__ = 13; break; } else { __label__ = 14; break; }
    case 13: 
      __label__ = 15; break;
    case 14: 
      var $53=(($buf+6)|0);
      var $54=HEAP8[($53)];
      var $55=(($mod_time+6)|0);
      HEAP8[($55)]=$54;
      var $56=(($buf+5)|0);
      var $57=HEAP8[($56)];
      var $58=(($mod_time+5)|0);
      HEAP8[($58)]=$57;
      var $59=(($buf+4)|0);
      var $60=HEAP8[($59)];
      var $61=(($mod_time+4)|0);
      HEAP8[($61)]=$60;
      var $62=(($buf+3)|0);
      var $63=HEAP8[($62)];
      var $64=(($mod_time+3)|0);
      HEAP8[($64)]=$63;
      var $65=(($buf+2)|0);
      var $66=HEAP8[($65)];
      var $67=(($mod_time+2)|0);
      HEAP8[($67)]=$66;
      var $68=(($buf)|0);
      var $69=HEAPU8[($68)];
      var $70=(($69)&255);
      var $71=$70 << 8;
      var $72=(($buf)|0);
      var $73=(($72+1)|0);
      var $74=HEAPU8[($73)];
      var $75=(($74)&255);
      var $76=((($71)+($75))|0);
      var $77=(($76) & 65535);
      var $78=(($mod_time)|0);
      HEAP16[(($78)>>1)]=$77;
      var $79=$1;
      var $80=$2;
      _png_set_tIME($79, $80, $mod_time);
      __label__ = 15; break;
    case 15: 
      STACKTOP = __stackBase__;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_png_handle_tIME["X"]=1;

function _png_handle_tEXt($png_ptr, $info_ptr, $length) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $text_ptr;
      var $key;
      var $text;
      var $skip;
      var $slength;
      var $ret;
      $1=$png_ptr;
      $2=$info_ptr;
      $3=$length;
      $skip=0;
      var $4=$1;
      var $5=(($4+592)|0);
      var $6=HEAP32[(($5)>>2)];
      var $7=(($6)|0)!=0;
      if ($7) { __label__ = 3; break; } else { __label__ = 8; break; }
    case 3: 
      var $9=$1;
      var $10=(($9+592)|0);
      var $11=HEAP32[(($10)>>2)];
      var $12=(($11)|0)==1;
      if ($12) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      var $14=$1;
      var $15=$3;
      var $16=_png_crc_finish($14, $15);
      __label__ = 26; break;
    case 5: 
      var $18=$1;
      var $19=(($18+592)|0);
      var $20=HEAP32[(($19)>>2)];
      var $21=((($20)-(1))|0);
      HEAP32[(($19)>>2)]=$21;
      var $22=(($21)|0)==1;
      if ($22) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      var $24=$1;
      _png_warning($24, ((STRING_TABLE.__str111)|0));
      var $25=$1;
      var $26=$3;
      var $27=_png_crc_finish($25, $26);
      __label__ = 26; break;
    case 7: 
      __label__ = 8; break;
    case 8: 
      var $30=$1;
      var $31=(($30+84)|0);
      var $32=HEAP32[(($31)>>2)];
      var $33=$32 & 1;
      var $34=(($33)|0)!=0;
      if ($34) { __label__ = 10; break; } else { __label__ = 9; break; }
    case 9: 
      var $36=$1;
      _png_error($36, ((STRING_TABLE.__str112)|0));
      __label__ = 10; break;
    case 10: 
      var $38=$1;
      var $39=(($38+84)|0);
      var $40=HEAP32[(($39)>>2)];
      var $41=$40 & 4;
      var $42=(($41)|0)!=0;
      if ($42) { __label__ = 11; break; } else { __label__ = 12; break; }
    case 11: 
      var $44=$1;
      var $45=(($44+84)|0);
      var $46=HEAP32[(($45)>>2)];
      var $47=$46 | 8;
      HEAP32[(($45)>>2)]=$47;
      __label__ = 12; break;
    case 12: 
      var $49=$1;
      var $50=$1;
      var $51=(($50+624)|0);
      var $52=HEAP32[(($51)>>2)];
      _png_free($49, $52);
      var $53=$1;
      var $54=$3;
      var $55=((($54)+(1))|0);
      var $56=_png_malloc_warn($53, $55);
      var $57=$1;
      var $58=(($57+624)|0);
      HEAP32[(($58)>>2)]=$56;
      var $59=$1;
      var $60=(($59+624)|0);
      var $61=HEAP32[(($60)>>2)];
      var $62=(($61)|0)==0;
      if ($62) { __label__ = 13; break; } else { __label__ = 14; break; }
    case 13: 
      var $64=$1;
      _png_warning($64, ((STRING_TABLE.__str113227)|0));
      __label__ = 26; break;
    case 14: 
      var $66=$3;
      $slength=$66;
      var $67=$1;
      var $68=$1;
      var $69=(($68+624)|0);
      var $70=HEAP32[(($69)>>2)];
      var $71=$slength;
      _png_crc_read($67, $70, $71);
      var $72=$1;
      var $73=$skip;
      var $74=_png_crc_finish($72, $73);
      var $75=(($74)|0)!=0;
      if ($75) { __label__ = 15; break; } else { __label__ = 16; break; }
    case 15: 
      var $77=$1;
      var $78=$1;
      var $79=(($78+624)|0);
      var $80=HEAP32[(($79)>>2)];
      _png_free($77, $80);
      var $81=$1;
      var $82=(($81+624)|0);
      HEAP32[(($82)>>2)]=0;
      __label__ = 26; break;
    case 16: 
      var $84=$1;
      var $85=(($84+624)|0);
      var $86=HEAP32[(($85)>>2)];
      $key=$86;
      var $87=$slength;
      var $88=$key;
      var $89=(($88+$87)|0);
      HEAP8[($89)]=0;
      var $90=$key;
      $text=$90;
      __label__ = 17; break;
    case 17: 
      var $92=$text;
      var $93=HEAP8[($92)];
      var $94=(($93 << 24) >> 24)!=0;
      if ($94) { __label__ = 18; break; } else { __label__ = 20; break; }
    case 18: 
      __label__ = 19; break;
    case 19: 
      var $97=$text;
      var $98=(($97+1)|0);
      $text=$98;
      __label__ = 17; break;
    case 20: 
      var $100=$text;
      var $101=$key;
      var $102=$slength;
      var $103=(($101+$102)|0);
      var $104=(($100)|0)!=(($103)|0);
      if ($104) { __label__ = 21; break; } else { __label__ = 22; break; }
    case 21: 
      var $106=$text;
      var $107=(($106+1)|0);
      $text=$107;
      __label__ = 22; break;
    case 22: 
      var $109=$1;
      var $110=_png_malloc_warn($109, 28);
      var $111=$110;
      $text_ptr=$111;
      var $112=$text_ptr;
      var $113=(($112)|0)==0;
      if ($113) { __label__ = 23; break; } else { __label__ = 24; break; }
    case 23: 
      var $115=$1;
      _png_warning($115, ((STRING_TABLE.__str114)|0));
      var $116=$1;
      var $117=$1;
      var $118=(($117+624)|0);
      var $119=HEAP32[(($118)>>2)];
      _png_free($116, $119);
      var $120=$1;
      var $121=(($120+624)|0);
      HEAP32[(($121)>>2)]=0;
      __label__ = 26; break;
    case 24: 
      var $123=$text_ptr;
      var $124=(($123)|0);
      HEAP32[(($124)>>2)]=-1;
      var $125=$key;
      var $126=$text_ptr;
      var $127=(($126+4)|0);
      HEAP32[(($127)>>2)]=$125;
      var $128=$text_ptr;
      var $129=(($128+20)|0);
      HEAP32[(($129)>>2)]=0;
      var $130=$text_ptr;
      var $131=(($130+24)|0);
      HEAP32[(($131)>>2)]=0;
      var $132=$text_ptr;
      var $133=(($132+16)|0);
      HEAP32[(($133)>>2)]=0;
      var $134=$text;
      var $135=$text_ptr;
      var $136=(($135+8)|0);
      HEAP32[(($136)>>2)]=$134;
      var $137=$text;
      var $138=_strlen($137);
      var $139=$text_ptr;
      var $140=(($139+12)|0);
      HEAP32[(($140)>>2)]=$138;
      var $141=$1;
      var $142=$2;
      var $143=$text_ptr;
      var $144=_png_set_text_2($141, $142, $143, 1);
      $ret=$144;
      var $145=$1;
      var $146=$1;
      var $147=(($146+624)|0);
      var $148=HEAP32[(($147)>>2)];
      _png_free($145, $148);
      var $149=$1;
      var $150=(($149+624)|0);
      HEAP32[(($150)>>2)]=0;
      var $151=$1;
      var $152=$text_ptr;
      var $153=$152;
      _png_free($151, $153);
      var $154=$ret;
      var $155=(($154)|0)!=0;
      if ($155) { __label__ = 25; break; } else { __label__ = 26; break; }
    case 25: 
      var $157=$1;
      _png_warning($157, ((STRING_TABLE.__str115228)|0));
      __label__ = 26; break;
    case 26: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_png_handle_tEXt["X"]=1;

function _png_handle_zTXt($png_ptr, $info_ptr, $length) {
  var __stackBase__  = STACKTOP; STACKTOP += 4; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $text_ptr;
      var $text;
      var $comp_type;
      var $ret;
      var $slength;
      var $prefix_len;
      var $data_len=__stackBase__;
      $1=$png_ptr;
      $2=$info_ptr;
      $3=$length;
      var $4=$1;
      var $5=(($4+592)|0);
      var $6=HEAP32[(($5)>>2)];
      var $7=(($6)|0)!=0;
      if ($7) { __label__ = 3; break; } else { __label__ = 8; break; }
    case 3: 
      var $9=$1;
      var $10=(($9+592)|0);
      var $11=HEAP32[(($10)>>2)];
      var $12=(($11)|0)==1;
      if ($12) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      var $14=$1;
      var $15=$3;
      var $16=_png_crc_finish($14, $15);
      __label__ = 29; break;
    case 5: 
      var $18=$1;
      var $19=(($18+592)|0);
      var $20=HEAP32[(($19)>>2)];
      var $21=((($20)-(1))|0);
      HEAP32[(($19)>>2)]=$21;
      var $22=(($21)|0)==1;
      if ($22) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      var $24=$1;
      _png_warning($24, ((STRING_TABLE.__str116)|0));
      var $25=$1;
      var $26=$3;
      var $27=_png_crc_finish($25, $26);
      __label__ = 29; break;
    case 7: 
      __label__ = 8; break;
    case 8: 
      var $30=$1;
      var $31=(($30+84)|0);
      var $32=HEAP32[(($31)>>2)];
      var $33=$32 & 1;
      var $34=(($33)|0)!=0;
      if ($34) { __label__ = 10; break; } else { __label__ = 9; break; }
    case 9: 
      var $36=$1;
      _png_error($36, ((STRING_TABLE.__str117)|0));
      __label__ = 10; break;
    case 10: 
      var $38=$1;
      var $39=(($38+84)|0);
      var $40=HEAP32[(($39)>>2)];
      var $41=$40 & 4;
      var $42=(($41)|0)!=0;
      if ($42) { __label__ = 11; break; } else { __label__ = 12; break; }
    case 11: 
      var $44=$1;
      var $45=(($44+84)|0);
      var $46=HEAP32[(($45)>>2)];
      var $47=$46 | 8;
      HEAP32[(($45)>>2)]=$47;
      __label__ = 12; break;
    case 12: 
      var $49=$1;
      var $50=$1;
      var $51=(($50+624)|0);
      var $52=HEAP32[(($51)>>2)];
      _png_free($49, $52);
      var $53=$1;
      var $54=$3;
      var $55=((($54)+(1))|0);
      var $56=_png_malloc_warn($53, $55);
      var $57=$1;
      var $58=(($57+624)|0);
      HEAP32[(($58)>>2)]=$56;
      var $59=$1;
      var $60=(($59+624)|0);
      var $61=HEAP32[(($60)>>2)];
      var $62=(($61)|0)==0;
      if ($62) { __label__ = 13; break; } else { __label__ = 14; break; }
    case 13: 
      var $64=$1;
      _png_warning($64, ((STRING_TABLE.__str118)|0));
      __label__ = 29; break;
    case 14: 
      var $66=$3;
      $slength=$66;
      var $67=$1;
      var $68=$1;
      var $69=(($68+624)|0);
      var $70=HEAP32[(($69)>>2)];
      var $71=$slength;
      _png_crc_read($67, $70, $71);
      var $72=$1;
      var $73=_png_crc_finish($72, 0);
      var $74=(($73)|0)!=0;
      if ($74) { __label__ = 15; break; } else { __label__ = 16; break; }
    case 15: 
      var $76=$1;
      var $77=$1;
      var $78=(($77+624)|0);
      var $79=HEAP32[(($78)>>2)];
      _png_free($76, $79);
      var $80=$1;
      var $81=(($80+624)|0);
      HEAP32[(($81)>>2)]=0;
      __label__ = 29; break;
    case 16: 
      var $83=$slength;
      var $84=$1;
      var $85=(($84+624)|0);
      var $86=HEAP32[(($85)>>2)];
      var $87=(($86+$83)|0);
      HEAP8[($87)]=0;
      var $88=$1;
      var $89=(($88+624)|0);
      var $90=HEAP32[(($89)>>2)];
      $text=$90;
      __label__ = 17; break;
    case 17: 
      var $92=$text;
      var $93=HEAP8[($92)];
      var $94=(($93 << 24) >> 24)!=0;
      if ($94) { __label__ = 18; break; } else { __label__ = 20; break; }
    case 18: 
      __label__ = 19; break;
    case 19: 
      var $97=$text;
      var $98=(($97+1)|0);
      $text=$98;
      __label__ = 17; break;
    case 20: 
      var $100=$text;
      var $101=$1;
      var $102=(($101+624)|0);
      var $103=HEAP32[(($102)>>2)];
      var $104=$slength;
      var $105=(($103+$104)|0);
      var $106=((($105)-(2))|0);
      var $107=(($100)>>>0) >= (($106)>>>0);
      if ($107) { __label__ = 21; break; } else { __label__ = 22; break; }
    case 21: 
      var $109=$1;
      _png_warning($109, ((STRING_TABLE.__str119)|0));
      var $110=$1;
      var $111=$1;
      var $112=(($111+624)|0);
      var $113=HEAP32[(($112)>>2)];
      _png_free($110, $113);
      var $114=$1;
      var $115=(($114+624)|0);
      HEAP32[(($115)>>2)]=0;
      __label__ = 29; break;
    case 22: 
      var $117=$text;
      var $118=(($117+1)|0);
      $text=$118;
      var $119=HEAP8[($118)];
      var $120=(($119 << 24) >> 24);
      $comp_type=$120;
      var $121=$comp_type;
      var $122=(($121)|0)!=0;
      if ($122) { __label__ = 23; break; } else { __label__ = 24; break; }
    case 23: 
      var $124=$1;
      _png_warning($124, ((STRING_TABLE.__str120229)|0));
      $comp_type=0;
      __label__ = 24; break;
    case 24: 
      var $126=$text;
      var $127=(($126+1)|0);
      $text=$127;
      __label__ = 25; break;
    case 25: 
      var $129=$text;
      var $130=$1;
      var $131=(($130+624)|0);
      var $132=HEAP32[(($131)>>2)];
      var $133=$129;
      var $134=$132;
      var $135=((($133)-($134))|0);
      $prefix_len=$135;
      var $136=$1;
      var $137=$comp_type;
      var $138=$3;
      var $139=$prefix_len;
      _png_decompress_chunk($136, $137, $138, $139, $data_len);
      var $140=$1;
      var $141=_png_malloc_warn($140, 28);
      var $142=$141;
      $text_ptr=$142;
      var $143=$text_ptr;
      var $144=(($143)|0)==0;
      if ($144) { __label__ = 26; break; } else { __label__ = 27; break; }
    case 26: 
      var $146=$1;
      _png_warning($146, ((STRING_TABLE.__str121230)|0));
      var $147=$1;
      var $148=$1;
      var $149=(($148+624)|0);
      var $150=HEAP32[(($149)>>2)];
      _png_free($147, $150);
      var $151=$1;
      var $152=(($151+624)|0);
      HEAP32[(($152)>>2)]=0;
      __label__ = 29; break;
    case 27: 
      var $154=$comp_type;
      var $155=$text_ptr;
      var $156=(($155)|0);
      HEAP32[(($156)>>2)]=$154;
      var $157=$1;
      var $158=(($157+624)|0);
      var $159=HEAP32[(($158)>>2)];
      var $160=$text_ptr;
      var $161=(($160+4)|0);
      HEAP32[(($161)>>2)]=$159;
      var $162=$text_ptr;
      var $163=(($162+20)|0);
      HEAP32[(($163)>>2)]=0;
      var $164=$text_ptr;
      var $165=(($164+24)|0);
      HEAP32[(($165)>>2)]=0;
      var $166=$text_ptr;
      var $167=(($166+16)|0);
      HEAP32[(($167)>>2)]=0;
      var $168=$1;
      var $169=(($168+624)|0);
      var $170=HEAP32[(($169)>>2)];
      var $171=$prefix_len;
      var $172=(($170+$171)|0);
      var $173=$text_ptr;
      var $174=(($173+8)|0);
      HEAP32[(($174)>>2)]=$172;
      var $175=HEAP32[(($data_len)>>2)];
      var $176=$text_ptr;
      var $177=(($176+12)|0);
      HEAP32[(($177)>>2)]=$175;
      var $178=$1;
      var $179=$2;
      var $180=$text_ptr;
      var $181=_png_set_text_2($178, $179, $180, 1);
      $ret=$181;
      var $182=$1;
      var $183=$text_ptr;
      var $184=$183;
      _png_free($182, $184);
      var $185=$1;
      var $186=$1;
      var $187=(($186+624)|0);
      var $188=HEAP32[(($187)>>2)];
      _png_free($185, $188);
      var $189=$1;
      var $190=(($189+624)|0);
      HEAP32[(($190)>>2)]=0;
      var $191=$ret;
      var $192=(($191)|0)!=0;
      if ($192) { __label__ = 28; break; } else { __label__ = 29; break; }
    case 28: 
      var $194=$1;
      _png_error($194, ((STRING_TABLE.__str122)|0));
      __label__ = 29; break;
    case 29: 
      STACKTOP = __stackBase__;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_png_handle_zTXt["X"]=1;

function _png_handle_iTXt($png_ptr, $info_ptr, $length) {
  var __stackBase__  = STACKTOP; STACKTOP += 4; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $text_ptr;
      var $key;
      var $lang;
      var $text;
      var $lang_key;
      var $comp_flag;
      var $comp_type;
      var $ret;
      var $slength;
      var $prefix_len;
      var $data_len=__stackBase__;
      $1=$png_ptr;
      $2=$info_ptr;
      $3=$length;
      $comp_type=0;
      var $4=$1;
      var $5=(($4+592)|0);
      var $6=HEAP32[(($5)>>2)];
      var $7=(($6)|0)!=0;
      if ($7) { __label__ = 3; break; } else { __label__ = 8; break; }
    case 3: 
      var $9=$1;
      var $10=(($9+592)|0);
      var $11=HEAP32[(($10)>>2)];
      var $12=(($11)|0)==1;
      if ($12) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      var $14=$1;
      var $15=$3;
      var $16=_png_crc_finish($14, $15);
      __label__ = 42; break;
    case 5: 
      var $18=$1;
      var $19=(($18+592)|0);
      var $20=HEAP32[(($19)>>2)];
      var $21=((($20)-(1))|0);
      HEAP32[(($19)>>2)]=$21;
      var $22=(($21)|0)==1;
      if ($22) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      var $24=$1;
      _png_warning($24, ((STRING_TABLE.__str123)|0));
      var $25=$1;
      var $26=$3;
      var $27=_png_crc_finish($25, $26);
      __label__ = 42; break;
    case 7: 
      __label__ = 8; break;
    case 8: 
      var $30=$1;
      var $31=(($30+84)|0);
      var $32=HEAP32[(($31)>>2)];
      var $33=$32 & 1;
      var $34=(($33)|0)!=0;
      if ($34) { __label__ = 10; break; } else { __label__ = 9; break; }
    case 9: 
      var $36=$1;
      _png_error($36, ((STRING_TABLE.__str124)|0));
      __label__ = 10; break;
    case 10: 
      var $38=$1;
      var $39=(($38+84)|0);
      var $40=HEAP32[(($39)>>2)];
      var $41=$40 & 4;
      var $42=(($41)|0)!=0;
      if ($42) { __label__ = 11; break; } else { __label__ = 12; break; }
    case 11: 
      var $44=$1;
      var $45=(($44+84)|0);
      var $46=HEAP32[(($45)>>2)];
      var $47=$46 | 8;
      HEAP32[(($45)>>2)]=$47;
      __label__ = 12; break;
    case 12: 
      var $49=$1;
      var $50=$1;
      var $51=(($50+624)|0);
      var $52=HEAP32[(($51)>>2)];
      _png_free($49, $52);
      var $53=$1;
      var $54=$3;
      var $55=((($54)+(1))|0);
      var $56=_png_malloc_warn($53, $55);
      var $57=$1;
      var $58=(($57+624)|0);
      HEAP32[(($58)>>2)]=$56;
      var $59=$1;
      var $60=(($59+624)|0);
      var $61=HEAP32[(($60)>>2)];
      var $62=(($61)|0)==0;
      if ($62) { __label__ = 13; break; } else { __label__ = 14; break; }
    case 13: 
      var $64=$1;
      _png_warning($64, ((STRING_TABLE.__str125)|0));
      __label__ = 42; break;
    case 14: 
      var $66=$3;
      $slength=$66;
      var $67=$1;
      var $68=$1;
      var $69=(($68+624)|0);
      var $70=HEAP32[(($69)>>2)];
      var $71=$slength;
      _png_crc_read($67, $70, $71);
      var $72=$1;
      var $73=_png_crc_finish($72, 0);
      var $74=(($73)|0)!=0;
      if ($74) { __label__ = 15; break; } else { __label__ = 16; break; }
    case 15: 
      var $76=$1;
      var $77=$1;
      var $78=(($77+624)|0);
      var $79=HEAP32[(($78)>>2)];
      _png_free($76, $79);
      var $80=$1;
      var $81=(($80+624)|0);
      HEAP32[(($81)>>2)]=0;
      __label__ = 42; break;
    case 16: 
      var $83=$slength;
      var $84=$1;
      var $85=(($84+624)|0);
      var $86=HEAP32[(($85)>>2)];
      var $87=(($86+$83)|0);
      HEAP8[($87)]=0;
      var $88=$1;
      var $89=(($88+624)|0);
      var $90=HEAP32[(($89)>>2)];
      $lang=$90;
      __label__ = 17; break;
    case 17: 
      var $92=$lang;
      var $93=HEAP8[($92)];
      var $94=(($93 << 24) >> 24)!=0;
      if ($94) { __label__ = 18; break; } else { __label__ = 20; break; }
    case 18: 
      __label__ = 19; break;
    case 19: 
      var $97=$lang;
      var $98=(($97+1)|0);
      $lang=$98;
      __label__ = 17; break;
    case 20: 
      var $100=$lang;
      var $101=(($100+1)|0);
      $lang=$101;
      var $102=$lang;
      var $103=$1;
      var $104=(($103+624)|0);
      var $105=HEAP32[(($104)>>2)];
      var $106=$slength;
      var $107=(($105+$106)|0);
      var $108=((($107)-(3))|0);
      var $109=(($102)>>>0) >= (($108)>>>0);
      if ($109) { __label__ = 21; break; } else { __label__ = 22; break; }
    case 21: 
      var $111=$1;
      _png_warning($111, ((STRING_TABLE.__str126)|0));
      var $112=$1;
      var $113=$1;
      var $114=(($113+624)|0);
      var $115=HEAP32[(($114)>>2)];
      _png_free($112, $115);
      var $116=$1;
      var $117=(($116+624)|0);
      HEAP32[(($117)>>2)]=0;
      __label__ = 42; break;
    case 22: 
      var $119=$lang;
      var $120=(($119+1)|0);
      $lang=$120;
      var $121=HEAP8[($119)];
      var $122=(($121 << 24) >> 24);
      $comp_flag=$122;
      var $123=$lang;
      var $124=(($123+1)|0);
      $lang=$124;
      var $125=HEAP8[($123)];
      var $126=(($125 << 24) >> 24);
      $comp_type=$126;
      __label__ = 23; break;
    case 23: 
      var $128=$lang;
      $lang_key=$128;
      __label__ = 24; break;
    case 24: 
      var $130=$lang_key;
      var $131=HEAP8[($130)];
      var $132=(($131 << 24) >> 24)!=0;
      if ($132) { __label__ = 25; break; } else { __label__ = 27; break; }
    case 25: 
      __label__ = 26; break;
    case 26: 
      var $135=$lang_key;
      var $136=(($135+1)|0);
      $lang_key=$136;
      __label__ = 24; break;
    case 27: 
      var $138=$lang_key;
      var $139=(($138+1)|0);
      $lang_key=$139;
      var $140=$lang_key;
      var $141=$1;
      var $142=(($141+624)|0);
      var $143=HEAP32[(($142)>>2)];
      var $144=$slength;
      var $145=(($143+$144)|0);
      var $146=(($140)>>>0) >= (($145)>>>0);
      if ($146) { __label__ = 28; break; } else { __label__ = 29; break; }
    case 28: 
      var $148=$1;
      _png_warning($148, ((STRING_TABLE.__str126)|0));
      var $149=$1;
      var $150=$1;
      var $151=(($150+624)|0);
      var $152=HEAP32[(($151)>>2)];
      _png_free($149, $152);
      var $153=$1;
      var $154=(($153+624)|0);
      HEAP32[(($154)>>2)]=0;
      __label__ = 42; break;
    case 29: 
      var $156=$lang_key;
      $text=$156;
      __label__ = 30; break;
    case 30: 
      var $158=$text;
      var $159=HEAP8[($158)];
      var $160=(($159 << 24) >> 24)!=0;
      if ($160) { __label__ = 31; break; } else { __label__ = 33; break; }
    case 31: 
      __label__ = 32; break;
    case 32: 
      var $163=$text;
      var $164=(($163+1)|0);
      $text=$164;
      __label__ = 30; break;
    case 33: 
      var $166=$text;
      var $167=(($166+1)|0);
      $text=$167;
      var $168=$text;
      var $169=$1;
      var $170=(($169+624)|0);
      var $171=HEAP32[(($170)>>2)];
      var $172=$slength;
      var $173=(($171+$172)|0);
      var $174=(($168)>>>0) >= (($173)>>>0);
      if ($174) { __label__ = 34; break; } else { __label__ = 35; break; }
    case 34: 
      var $176=$1;
      _png_warning($176, ((STRING_TABLE.__str127)|0));
      var $177=$1;
      var $178=$1;
      var $179=(($178+624)|0);
      var $180=HEAP32[(($179)>>2)];
      _png_free($177, $180);
      var $181=$1;
      var $182=(($181+624)|0);
      HEAP32[(($182)>>2)]=0;
      __label__ = 42; break;
    case 35: 
      var $184=$text;
      var $185=$1;
      var $186=(($185+624)|0);
      var $187=HEAP32[(($186)>>2)];
      var $188=$184;
      var $189=$187;
      var $190=((($188)-($189))|0);
      $prefix_len=$190;
      var $191=$1;
      var $192=(($191+624)|0);
      var $193=HEAP32[(($192)>>2)];
      $key=$193;
      var $194=$comp_flag;
      var $195=(($194)|0)!=0;
      if ($195) { __label__ = 36; break; } else { __label__ = 37; break; }
    case 36: 
      var $197=$1;
      var $198=$comp_type;
      var $199=$3;
      var $200=$prefix_len;
      _png_decompress_chunk($197, $198, $199, $200, $data_len);
      __label__ = 38; break;
    case 37: 
      var $202=$1;
      var $203=(($202+624)|0);
      var $204=HEAP32[(($203)>>2)];
      var $205=$prefix_len;
      var $206=(($204+$205)|0);
      var $207=_strlen($206);
      HEAP32[(($data_len)>>2)]=$207;
      __label__ = 38; break;
    case 38: 
      var $209=$1;
      var $210=_png_malloc_warn($209, 28);
      var $211=$210;
      $text_ptr=$211;
      var $212=$text_ptr;
      var $213=(($212)|0)==0;
      if ($213) { __label__ = 39; break; } else { __label__ = 40; break; }
    case 39: 
      var $215=$1;
      _png_warning($215, ((STRING_TABLE.__str128)|0));
      var $216=$1;
      var $217=$1;
      var $218=(($217+624)|0);
      var $219=HEAP32[(($218)>>2)];
      _png_free($216, $219);
      var $220=$1;
      var $221=(($220+624)|0);
      HEAP32[(($221)>>2)]=0;
      __label__ = 42; break;
    case 40: 
      var $223=$comp_flag;
      var $224=((($223)+(1))|0);
      var $225=$text_ptr;
      var $226=(($225)|0);
      HEAP32[(($226)>>2)]=$224;
      var $227=$1;
      var $228=(($227+624)|0);
      var $229=HEAP32[(($228)>>2)];
      var $230=$lang_key;
      var $231=$key;
      var $232=$230;
      var $233=$231;
      var $234=((($232)-($233))|0);
      var $235=(($229+$234)|0);
      var $236=$text_ptr;
      var $237=(($236+24)|0);
      HEAP32[(($237)>>2)]=$235;
      var $238=$1;
      var $239=(($238+624)|0);
      var $240=HEAP32[(($239)>>2)];
      var $241=$lang;
      var $242=$key;
      var $243=$241;
      var $244=$242;
      var $245=((($243)-($244))|0);
      var $246=(($240+$245)|0);
      var $247=$text_ptr;
      var $248=(($247+20)|0);
      HEAP32[(($248)>>2)]=$246;
      var $249=HEAP32[(($data_len)>>2)];
      var $250=$text_ptr;
      var $251=(($250+16)|0);
      HEAP32[(($251)>>2)]=$249;
      var $252=$text_ptr;
      var $253=(($252+12)|0);
      HEAP32[(($253)>>2)]=0;
      var $254=$1;
      var $255=(($254+624)|0);
      var $256=HEAP32[(($255)>>2)];
      var $257=$text_ptr;
      var $258=(($257+4)|0);
      HEAP32[(($258)>>2)]=$256;
      var $259=$1;
      var $260=(($259+624)|0);
      var $261=HEAP32[(($260)>>2)];
      var $262=$prefix_len;
      var $263=(($261+$262)|0);
      var $264=$text_ptr;
      var $265=(($264+8)|0);
      HEAP32[(($265)>>2)]=$263;
      var $266=$1;
      var $267=$2;
      var $268=$text_ptr;
      var $269=_png_set_text_2($266, $267, $268, 1);
      $ret=$269;
      var $270=$1;
      var $271=$text_ptr;
      var $272=$271;
      _png_free($270, $272);
      var $273=$1;
      var $274=$1;
      var $275=(($274+624)|0);
      var $276=HEAP32[(($275)>>2)];
      _png_free($273, $276);
      var $277=$1;
      var $278=(($277+624)|0);
      HEAP32[(($278)>>2)]=0;
      var $279=$ret;
      var $280=(($279)|0)!=0;
      if ($280) { __label__ = 41; break; } else { __label__ = 42; break; }
    case 41: 
      var $282=$1;
      _png_error($282, ((STRING_TABLE.__str129)|0));
      __label__ = 42; break;
    case 42: 
      STACKTOP = __stackBase__;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_png_handle_iTXt["X"]=1;

function _png_handle_unknown($png_ptr, $info_ptr, $length) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $skip;
      var $ret;
      $1=$png_ptr;
      $2=$info_ptr;
      $3=$length;
      $skip=0;
      var $4=$1;
      var $5=(($4+592)|0);
      var $6=HEAP32[(($5)>>2)];
      var $7=(($6)|0)!=0;
      if ($7) { __label__ = 3; break; } else { __label__ = 8; break; }
    case 3: 
      var $9=$1;
      var $10=(($9+592)|0);
      var $11=HEAP32[(($10)>>2)];
      var $12=(($11)|0)==1;
      if ($12) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      var $14=$1;
      var $15=$3;
      var $16=_png_crc_finish($14, $15);
      __label__ = 36; break;
    case 5: 
      var $18=$1;
      var $19=(($18+592)|0);
      var $20=HEAP32[(($19)>>2)];
      var $21=((($20)-(1))|0);
      HEAP32[(($19)>>2)]=$21;
      var $22=(($21)|0)==1;
      if ($22) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      var $24=$1;
      _png_warning($24, ((STRING_TABLE.__str130231)|0));
      var $25=$1;
      var $26=$3;
      var $27=_png_crc_finish($25, $26);
      __label__ = 36; break;
    case 7: 
      __label__ = 8; break;
    case 8: 
      var $30=$1;
      var $31=(($30+84)|0);
      var $32=HEAP32[(($31)>>2)];
      var $33=$32 & 4;
      var $34=(($33)|0)!=0;
      if ($34) { __label__ = 9; break; } else { __label__ = 12; break; }
    case 9: 
      var $36=$1;
      var $37=(($36+264)|0);
      var $38=(($37)|0);
      var $39=_memcmp($38, ((STRING_TABLE._png_handle_unknown_png_IDAT)|0), 4);
      var $40=(($39)|0)!=0;
      if ($40) { __label__ = 10; break; } else { __label__ = 11; break; }
    case 10: 
      var $42=$1;
      var $43=(($42+84)|0);
      var $44=HEAP32[(($43)>>2)];
      var $45=$44 | 8;
      HEAP32[(($43)>>2)]=$45;
      __label__ = 11; break;
    case 11: 
      __label__ = 12; break;
    case 12: 
      var $48=$1;
      var $49=(($48+264)|0);
      var $50=(($49)|0);
      var $51=HEAPU8[($50)];
      var $52=(($51)&255);
      var $53=$52 & 32;
      var $54=(($53)|0)!=0;
      if ($54) { __label__ = 17; break; } else { __label__ = 13; break; }
    case 13: 
      var $56=$1;
      var $57=$1;
      var $58=(($57+264)|0);
      var $59=(($58)|0);
      var $60=_png_handle_as_unknown($56, $59);
      var $61=(($60)|0)!=3;
      if ($61) { __label__ = 14; break; } else { __label__ = 16; break; }
    case 14: 
      var $63=$1;
      var $64=(($63+520)|0);
      var $65=HEAP32[(($64)>>2)];
      var $66=(($65)|0)==0;
      if ($66) { __label__ = 15; break; } else { __label__ = 16; break; }
    case 15: 
      var $68=$1;
      _png_chunk_error($68, ((STRING_TABLE.__str131)|0));
      __label__ = 16; break;
    case 16: 
      __label__ = 17; break;
    case 17: 
      var $71=$1;
      var $72=(($71+88)|0);
      var $73=HEAP32[(($72)>>2)];
      var $74=$73 & 32768;
      var $75=(($74)|0)!=0;
      if ($75) { __label__ = 19; break; } else { __label__ = 18; break; }
    case 18: 
      var $77=$1;
      var $78=(($77+520)|0);
      var $79=HEAP32[(($78)>>2)];
      var $80=(($79)|0)!=0;
      if ($80) { __label__ = 19; break; } else { __label__ = 34; break; }
    case 19: 
      var $82=$1;
      var $83=(($82+596)|0);
      var $84=(($83)|0);
      var $85=(($84)|0);
      var $86=$1;
      var $87=(($86+264)|0);
      var $88=(($87)|0);
      assert(5 % 1 === 0, 'memcpy given ' + 5 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP8[($85)]=HEAP8[($88)];HEAP8[(($85)+(1))]=HEAP8[(($88)+(1))];HEAP8[(($85)+(2))]=HEAP8[(($88)+(2))];HEAP8[(($85)+(3))]=HEAP8[(($88)+(3))];HEAP8[(($85)+(4))]=HEAP8[(($88)+(4))];
      var $89=$1;
      var $90=(($89+596)|0);
      var $91=(($90)|0);
      var $92=(($91+4)|0);
      HEAP8[($92)]=0;
      var $93=$3;
      var $94=$1;
      var $95=(($94+596)|0);
      var $96=(($95+12)|0);
      HEAP32[(($96)>>2)]=$93;
      var $97=$3;
      var $98=(($97)|0)==0;
      if ($98) { __label__ = 20; break; } else { __label__ = 21; break; }
    case 20: 
      var $100=$1;
      var $101=(($100+596)|0);
      var $102=(($101+8)|0);
      HEAP32[(($102)>>2)]=0;
      __label__ = 22; break;
    case 21: 
      var $104=$1;
      var $105=$3;
      var $106=_png_malloc($104, $105);
      var $107=$1;
      var $108=(($107+596)|0);
      var $109=(($108+8)|0);
      HEAP32[(($109)>>2)]=$106;
      var $110=$1;
      var $111=$1;
      var $112=(($111+596)|0);
      var $113=(($112+8)|0);
      var $114=HEAP32[(($113)>>2)];
      var $115=$3;
      _png_crc_read($110, $114, $115);
      __label__ = 22; break;
    case 22: 
      var $117=$1;
      var $118=(($117+520)|0);
      var $119=HEAP32[(($118)>>2)];
      var $120=(($119)|0)!=0;
      if ($120) { __label__ = 23; break; } else { __label__ = 32; break; }
    case 23: 
      var $122=$1;
      var $123=(($122+520)|0);
      var $124=HEAP32[(($123)>>2)];
      var $125=$1;
      var $126=$1;
      var $127=(($126+596)|0);
      var $128=FUNCTION_TABLE[$124]($125, $127);
      $ret=$128;
      var $129=$ret;
      var $130=(($129)|0) < 0;
      if ($130) { __label__ = 24; break; } else { __label__ = 25; break; }
    case 24: 
      var $132=$1;
      _png_chunk_error($132, ((STRING_TABLE.__str132)|0));
      __label__ = 25; break;
    case 25: 
      var $134=$ret;
      var $135=(($134)|0)==0;
      if ($135) { __label__ = 26; break; } else { __label__ = 31; break; }
    case 26: 
      var $137=$1;
      var $138=(($137+264)|0);
      var $139=(($138)|0);
      var $140=HEAPU8[($139)];
      var $141=(($140)&255);
      var $142=$141 & 32;
      var $143=(($142)|0)!=0;
      if ($143) { __label__ = 30; break; } else { __label__ = 27; break; }
    case 27: 
      var $145=$1;
      var $146=$1;
      var $147=(($146+264)|0);
      var $148=(($147)|0);
      var $149=_png_handle_as_unknown($145, $148);
      var $150=(($149)|0)!=3;
      if ($150) { __label__ = 28; break; } else { __label__ = 29; break; }
    case 28: 
      var $152=$1;
      _png_chunk_error($152, ((STRING_TABLE.__str131)|0));
      __label__ = 29; break;
    case 29: 
      __label__ = 30; break;
    case 30: 
      var $155=$1;
      var $156=$2;
      var $157=$1;
      var $158=(($157+596)|0);
      _png_set_unknown_chunks($155, $156, $158, 1);
      __label__ = 31; break;
    case 31: 
      __label__ = 33; break;
    case 32: 
      var $161=$1;
      var $162=$2;
      var $163=$1;
      var $164=(($163+596)|0);
      _png_set_unknown_chunks($161, $162, $164, 1);
      __label__ = 33; break;
    case 33: 
      var $166=$1;
      var $167=$1;
      var $168=(($167+596)|0);
      var $169=(($168+8)|0);
      var $170=HEAP32[(($169)>>2)];
      _png_free($166, $170);
      var $171=$1;
      var $172=(($171+596)|0);
      var $173=(($172+8)|0);
      HEAP32[(($173)>>2)]=0;
      __label__ = 35; break;
    case 34: 
      var $175=$3;
      $skip=$175;
      __label__ = 35; break;
    case 35: 
      var $177=$1;
      var $178=$skip;
      var $179=_png_crc_finish($177, $178);
      __label__ = 36; break;
    case 36: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_png_handle_unknown["X"]=1;

function _png_combine_row($png_ptr, $row, $mask) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $sp;
      var $dp;
      var $s_inc;
      var $s_start;
      var $s_end;
      var $m;
      var $shift;
      var $i;
      var $row_width;
      var $value;
      var $sp1;
      var $dp2;
      var $s_start3;
      var $s_end4;
      var $s_inc5;
      var $m6;
      var $shift7;
      var $i8;
      var $row_width9;
      var $value10;
      var $sp11;
      var $dp12;
      var $s_start13;
      var $s_end14;
      var $s_inc15;
      var $m16;
      var $shift17;
      var $i18;
      var $row_width19;
      var $value20;
      var $sp21;
      var $dp22;
      var $pixel_bytes;
      var $i23;
      var $row_width24;
      var $m25;
      $1=$png_ptr;
      $2=$row;
      $3=$mask;
      var $4=$3;
      var $5=(($4)|0)==255;
      if ($5) { __label__ = 3; break; } else { __label__ = 7; break; }
    case 3: 
      var $7=$2;
      var $8=$1;
      var $9=(($8+216)|0);
      var $10=HEAP32[(($9)>>2)];
      var $11=(($10+1)|0);
      var $12=$1;
      var $13=(($12+236)|0);
      var $14=(($13+11)|0);
      var $15=HEAPU8[($14)];
      var $16=(($15)&255);
      var $17=(($16)|0) >= 8;
      if ($17) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      var $19=$1;
      var $20=(($19+180)|0);
      var $21=HEAP32[(($20)>>2)];
      var $22=$1;
      var $23=(($22+236)|0);
      var $24=(($23+11)|0);
      var $25=HEAPU8[($24)];
      var $26=(($25)&255);
      var $27=$26 >>> 3;
      var $28=((($21)*($27))|0);
      var $42 = $28;__label__ = 6; break;
    case 5: 
      var $30=$1;
      var $31=(($30+180)|0);
      var $32=HEAP32[(($31)>>2)];
      var $33=$1;
      var $34=(($33+236)|0);
      var $35=(($34+11)|0);
      var $36=HEAPU8[($35)];
      var $37=(($36)&255);
      var $38=((($32)*($37))|0);
      var $39=((($38)+(7))|0);
      var $40=$39 >>> 3;
      var $42 = $40;__label__ = 6; break;
    case 6: 
      var $42;
      assert($42 % 1 === 0, 'memcpy given ' + $42 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');_memcpy($7, $11, $42, 1);
      __label__ = 67; break;
    case 7: 
      var $44=$1;
      var $45=(($44+236)|0);
      var $46=(($45+11)|0);
      var $47=HEAPU8[($46)];
      var $48=(($47)&255);
      if ((($48)|0) == 1) {
        __label__ = 8; break;
      }
      else if ((($48)|0) == 2) {
        __label__ = 24; break;
      }
      else if ((($48)|0) == 4) {
        __label__ = 40; break;
      }
      else {
      __label__ = 56; break;
      }
      
    case 8: 
      var $50=$1;
      var $51=(($50+216)|0);
      var $52=HEAP32[(($51)>>2)];
      var $53=(($52+1)|0);
      $sp=$53;
      var $54=$2;
      $dp=$54;
      $m=128;
      var $55=$1;
      var $56=(($55+180)|0);
      var $57=HEAP32[(($56)>>2)];
      $row_width=$57;
      var $58=$1;
      var $59=(($58+92)|0);
      var $60=HEAP32[(($59)>>2)];
      var $61=$60 & 65536;
      var $62=(($61)|0)!=0;
      if ($62) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      $s_start=0;
      $s_end=7;
      $s_inc=1;
      __label__ = 11; break;
    case 10: 
      $s_start=7;
      $s_end=0;
      $s_inc=-1;
      __label__ = 11; break;
    case 11: 
      var $66=$s_start;
      $shift=$66;
      $i=0;
      __label__ = 12; break;
    case 12: 
      var $68=$i;
      var $69=$row_width;
      var $70=(($68)>>>0) < (($69)>>>0);
      if ($70) { __label__ = 13; break; } else { __label__ = 23; break; }
    case 13: 
      var $72=$m;
      var $73=$3;
      var $74=$72 & $73;
      var $75=(($74)|0)!=0;
      if ($75) { __label__ = 14; break; } else { __label__ = 15; break; }
    case 14: 
      var $77=$sp;
      var $78=HEAPU8[($77)];
      var $79=(($78)&255);
      var $80=$shift;
      var $81=$79 >> (($80)|0);
      var $82=$81 & 1;
      $value=$82;
      var $83=$shift;
      var $84=(((7)-($83))|0);
      var $85=32639 >> (($84)|0);
      var $86=$85 & 255;
      var $87=(($86) & 255);
      var $88=(($87)&255);
      var $89=$dp;
      var $90=HEAPU8[($89)];
      var $91=(($90)&255);
      var $92=$91 & $88;
      var $93=(($92) & 255);
      HEAP8[($89)]=$93;
      var $94=$value;
      var $95=$shift;
      var $96=$94 << $95;
      var $97=(($96) & 255);
      var $98=(($97)&255);
      var $99=$dp;
      var $100=HEAPU8[($99)];
      var $101=(($100)&255);
      var $102=$101 | $98;
      var $103=(($102) & 255);
      HEAP8[($99)]=$103;
      __label__ = 15; break;
    case 15: 
      var $105=$shift;
      var $106=$s_end;
      var $107=(($105)|0)==(($106)|0);
      if ($107) { __label__ = 16; break; } else { __label__ = 17; break; }
    case 16: 
      var $109=$s_start;
      $shift=$109;
      var $110=$sp;
      var $111=(($110+1)|0);
      $sp=$111;
      var $112=$dp;
      var $113=(($112+1)|0);
      $dp=$113;
      __label__ = 18; break;
    case 17: 
      var $115=$s_inc;
      var $116=$shift;
      var $117=((($116)+($115))|0);
      $shift=$117;
      __label__ = 18; break;
    case 18: 
      var $119=$m;
      var $120=(($119)|0)==1;
      if ($120) { __label__ = 19; break; } else { __label__ = 20; break; }
    case 19: 
      $m=128;
      __label__ = 21; break;
    case 20: 
      var $123=$m;
      var $124=$123 >> 1;
      $m=$124;
      __label__ = 21; break;
    case 21: 
      __label__ = 22; break;
    case 22: 
      var $127=$i;
      var $128=((($127)+(1))|0);
      $i=$128;
      __label__ = 12; break;
    case 23: 
      __label__ = 66; break;
    case 24: 
      var $131=$1;
      var $132=(($131+216)|0);
      var $133=HEAP32[(($132)>>2)];
      var $134=(($133+1)|0);
      $sp1=$134;
      var $135=$2;
      $dp2=$135;
      $m6=128;
      var $136=$1;
      var $137=(($136+180)|0);
      var $138=HEAP32[(($137)>>2)];
      $row_width9=$138;
      var $139=$1;
      var $140=(($139+92)|0);
      var $141=HEAP32[(($140)>>2)];
      var $142=$141 & 65536;
      var $143=(($142)|0)!=0;
      if ($143) { __label__ = 25; break; } else { __label__ = 26; break; }
    case 25: 
      $s_start3=0;
      $s_end4=6;
      $s_inc5=2;
      __label__ = 27; break;
    case 26: 
      $s_start3=6;
      $s_end4=0;
      $s_inc5=-2;
      __label__ = 27; break;
    case 27: 
      var $147=$s_start3;
      $shift7=$147;
      $i8=0;
      __label__ = 28; break;
    case 28: 
      var $149=$i8;
      var $150=$row_width9;
      var $151=(($149)>>>0) < (($150)>>>0);
      if ($151) { __label__ = 29; break; } else { __label__ = 39; break; }
    case 29: 
      var $153=$m6;
      var $154=$3;
      var $155=$153 & $154;
      var $156=(($155)|0)!=0;
      if ($156) { __label__ = 30; break; } else { __label__ = 31; break; }
    case 30: 
      var $158=$sp1;
      var $159=HEAPU8[($158)];
      var $160=(($159)&255);
      var $161=$shift7;
      var $162=$160 >> (($161)|0);
      var $163=$162 & 3;
      $value10=$163;
      var $164=$shift7;
      var $165=(((6)-($164))|0);
      var $166=16191 >> (($165)|0);
      var $167=$166 & 255;
      var $168=(($167) & 255);
      var $169=(($168)&255);
      var $170=$dp2;
      var $171=HEAPU8[($170)];
      var $172=(($171)&255);
      var $173=$172 & $169;
      var $174=(($173) & 255);
      HEAP8[($170)]=$174;
      var $175=$value10;
      var $176=$shift7;
      var $177=$175 << $176;
      var $178=(($177) & 255);
      var $179=(($178)&255);
      var $180=$dp2;
      var $181=HEAPU8[($180)];
      var $182=(($181)&255);
      var $183=$182 | $179;
      var $184=(($183) & 255);
      HEAP8[($180)]=$184;
      __label__ = 31; break;
    case 31: 
      var $186=$shift7;
      var $187=$s_end4;
      var $188=(($186)|0)==(($187)|0);
      if ($188) { __label__ = 32; break; } else { __label__ = 33; break; }
    case 32: 
      var $190=$s_start3;
      $shift7=$190;
      var $191=$sp1;
      var $192=(($191+1)|0);
      $sp1=$192;
      var $193=$dp2;
      var $194=(($193+1)|0);
      $dp2=$194;
      __label__ = 34; break;
    case 33: 
      var $196=$s_inc5;
      var $197=$shift7;
      var $198=((($197)+($196))|0);
      $shift7=$198;
      __label__ = 34; break;
    case 34: 
      var $200=$m6;
      var $201=(($200)|0)==1;
      if ($201) { __label__ = 35; break; } else { __label__ = 36; break; }
    case 35: 
      $m6=128;
      __label__ = 37; break;
    case 36: 
      var $204=$m6;
      var $205=$204 >> 1;
      $m6=$205;
      __label__ = 37; break;
    case 37: 
      __label__ = 38; break;
    case 38: 
      var $208=$i8;
      var $209=((($208)+(1))|0);
      $i8=$209;
      __label__ = 28; break;
    case 39: 
      __label__ = 66; break;
    case 40: 
      var $212=$1;
      var $213=(($212+216)|0);
      var $214=HEAP32[(($213)>>2)];
      var $215=(($214+1)|0);
      $sp11=$215;
      var $216=$2;
      $dp12=$216;
      $m16=128;
      var $217=$1;
      var $218=(($217+180)|0);
      var $219=HEAP32[(($218)>>2)];
      $row_width19=$219;
      var $220=$1;
      var $221=(($220+92)|0);
      var $222=HEAP32[(($221)>>2)];
      var $223=$222 & 65536;
      var $224=(($223)|0)!=0;
      if ($224) { __label__ = 41; break; } else { __label__ = 42; break; }
    case 41: 
      $s_start13=0;
      $s_end14=4;
      $s_inc15=4;
      __label__ = 43; break;
    case 42: 
      $s_start13=4;
      $s_end14=0;
      $s_inc15=-4;
      __label__ = 43; break;
    case 43: 
      var $228=$s_start13;
      $shift17=$228;
      $i18=0;
      __label__ = 44; break;
    case 44: 
      var $230=$i18;
      var $231=$row_width19;
      var $232=(($230)>>>0) < (($231)>>>0);
      if ($232) { __label__ = 45; break; } else { __label__ = 55; break; }
    case 45: 
      var $234=$m16;
      var $235=$3;
      var $236=$234 & $235;
      var $237=(($236)|0)!=0;
      if ($237) { __label__ = 46; break; } else { __label__ = 47; break; }
    case 46: 
      var $239=$sp11;
      var $240=HEAPU8[($239)];
      var $241=(($240)&255);
      var $242=$shift17;
      var $243=$241 >> (($242)|0);
      var $244=$243 & 15;
      $value20=$244;
      var $245=$shift17;
      var $246=(((4)-($245))|0);
      var $247=3855 >> (($246)|0);
      var $248=$247 & 255;
      var $249=(($248) & 255);
      var $250=(($249)&255);
      var $251=$dp12;
      var $252=HEAPU8[($251)];
      var $253=(($252)&255);
      var $254=$253 & $250;
      var $255=(($254) & 255);
      HEAP8[($251)]=$255;
      var $256=$value20;
      var $257=$shift17;
      var $258=$256 << $257;
      var $259=(($258) & 255);
      var $260=(($259)&255);
      var $261=$dp12;
      var $262=HEAPU8[($261)];
      var $263=(($262)&255);
      var $264=$263 | $260;
      var $265=(($264) & 255);
      HEAP8[($261)]=$265;
      __label__ = 47; break;
    case 47: 
      var $267=$shift17;
      var $268=$s_end14;
      var $269=(($267)|0)==(($268)|0);
      if ($269) { __label__ = 48; break; } else { __label__ = 49; break; }
    case 48: 
      var $271=$s_start13;
      $shift17=$271;
      var $272=$sp11;
      var $273=(($272+1)|0);
      $sp11=$273;
      var $274=$dp12;
      var $275=(($274+1)|0);
      $dp12=$275;
      __label__ = 50; break;
    case 49: 
      var $277=$s_inc15;
      var $278=$shift17;
      var $279=((($278)+($277))|0);
      $shift17=$279;
      __label__ = 50; break;
    case 50: 
      var $281=$m16;
      var $282=(($281)|0)==1;
      if ($282) { __label__ = 51; break; } else { __label__ = 52; break; }
    case 51: 
      $m16=128;
      __label__ = 53; break;
    case 52: 
      var $285=$m16;
      var $286=$285 >> 1;
      $m16=$286;
      __label__ = 53; break;
    case 53: 
      __label__ = 54; break;
    case 54: 
      var $289=$i18;
      var $290=((($289)+(1))|0);
      $i18=$290;
      __label__ = 44; break;
    case 55: 
      __label__ = 66; break;
    case 56: 
      var $293=$1;
      var $294=(($293+216)|0);
      var $295=HEAP32[(($294)>>2)];
      var $296=(($295+1)|0);
      $sp21=$296;
      var $297=$2;
      $dp22=$297;
      var $298=$1;
      var $299=(($298+236)|0);
      var $300=(($299+11)|0);
      var $301=HEAPU8[($300)];
      var $302=(($301)&255);
      var $303=$302 >> 3;
      $pixel_bytes=$303;
      var $304=$1;
      var $305=(($304+180)|0);
      var $306=HEAP32[(($305)>>2)];
      $row_width24=$306;
      $m25=-128;
      $i23=0;
      __label__ = 57; break;
    case 57: 
      var $308=$i23;
      var $309=$row_width24;
      var $310=(($308)>>>0) < (($309)>>>0);
      if ($310) { __label__ = 58; break; } else { __label__ = 65; break; }
    case 58: 
      var $312=$m25;
      var $313=(($312)&255);
      var $314=$3;
      var $315=$313 & $314;
      var $316=(($315)|0)!=0;
      if ($316) { __label__ = 59; break; } else { __label__ = 60; break; }
    case 59: 
      var $318=$dp22;
      var $319=$sp21;
      var $320=$pixel_bytes;
      assert($320 % 1 === 0, 'memcpy given ' + $320 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');_memcpy($318, $319, $320, 1);
      __label__ = 60; break;
    case 60: 
      var $322=$pixel_bytes;
      var $323=$sp21;
      var $324=(($323+$322)|0);
      $sp21=$324;
      var $325=$pixel_bytes;
      var $326=$dp22;
      var $327=(($326+$325)|0);
      $dp22=$327;
      var $328=$m25;
      var $329=(($328)&255);
      var $330=(($329)|0)==1;
      if ($330) { __label__ = 61; break; } else { __label__ = 62; break; }
    case 61: 
      $m25=-128;
      __label__ = 63; break;
    case 62: 
      var $333=$m25;
      var $334=(($333)&255);
      var $335=$334 >> 1;
      var $336=(($335) & 255);
      $m25=$336;
      __label__ = 63; break;
    case 63: 
      __label__ = 64; break;
    case 64: 
      var $339=$i23;
      var $340=((($339)+(1))|0);
      $i23=$340;
      __label__ = 57; break;
    case 65: 
      __label__ = 66; break;
    case 66: 
      __label__ = 67; break;
    case 67: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_png_combine_row["X"]=1;

function _png_do_read_interlace($png_ptr) {
  var __stackBase__  = STACKTOP; STACKTOP += 8; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $row_info;
      var $row;
      var $pass;
      var $transformations;
      var $final_width;
      var $sp;
      var $dp;
      var $sshift;
      var $dshift;
      var $s_start;
      var $s_end;
      var $s_inc;
      var $jstop;
      var $v;
      var $i;
      var $j;
      var $sp1;
      var $dp2;
      var $sshift3;
      var $dshift4;
      var $s_start5;
      var $s_end6;
      var $s_inc7;
      var $jstop8;
      var $i9;
      var $v10;
      var $j11;
      var $sp12;
      var $dp13;
      var $sshift14;
      var $dshift15;
      var $s_start16;
      var $s_end17;
      var $s_inc18;
      var $i19;
      var $jstop20;
      var $v21;
      var $j22;
      var $pixel_bytes;
      var $sp23;
      var $dp24;
      var $jstop25;
      var $i26;
      var $v27=__stackBase__;
      var $j28;
      $1=$png_ptr;
      var $2=$1;
      var $3=(($2+236)|0);
      $row_info=$3;
      var $4=$1;
      var $5=(($4+216)|0);
      var $6=HEAP32[(($5)>>2)];
      var $7=(($6+1)|0);
      $row=$7;
      var $8=$1;
      var $9=(($8+272)|0);
      var $10=HEAPU8[($9)];
      var $11=(($10)&255);
      $pass=$11;
      var $12=$1;
      var $13=(($12+92)|0);
      var $14=HEAP32[(($13)>>2)];
      $transformations=$14;
      var $15=$row;
      var $16=(($15)|0)!=0;
      if ($16) { __label__ = 3; break; } else { __label__ = 72; break; }
    case 3: 
      var $18=$row_info;
      var $19=(($18)|0)!=0;
      if ($19) { __label__ = 4; break; } else { __label__ = 72; break; }
    case 4: 
      var $21=$row_info;
      var $22=(($21)|0);
      var $23=HEAP32[(($22)>>2)];
      var $24=$pass;
      var $25=((_png_do_read_interlace_png_pass_inc+($24<<2))|0);
      var $26=HEAP32[(($25)>>2)];
      var $27=((($23)*($26))|0);
      $final_width=$27;
      var $28=$row_info;
      var $29=(($28+11)|0);
      var $30=HEAPU8[($29)];
      var $31=(($30)&255);
      if ((($31)|0) == 1) {
        __label__ = 5; break;
      }
      else if ((($31)|0) == 2) {
        __label__ = 23; break;
      }
      else if ((($31)|0) == 4) {
        __label__ = 41; break;
      }
      else {
      __label__ = 59; break;
      }
      
    case 5: 
      var $33=$row;
      var $34=$row_info;
      var $35=(($34)|0);
      var $36=HEAP32[(($35)>>2)];
      var $37=((($36)-(1))|0);
      var $38=$37 >>> 3;
      var $39=(($33+$38)|0);
      $sp=$39;
      var $40=$row;
      var $41=$final_width;
      var $42=((($41)-(1))|0);
      var $43=$42 >>> 3;
      var $44=(($40+$43)|0);
      $dp=$44;
      var $45=$pass;
      var $46=((_png_do_read_interlace_png_pass_inc+($45<<2))|0);
      var $47=HEAP32[(($46)>>2)];
      $jstop=$47;
      var $48=$transformations;
      var $49=$48 & 65536;
      var $50=(($49)|0)!=0;
      if ($50) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      var $52=$row_info;
      var $53=(($52)|0);
      var $54=HEAP32[(($53)>>2)];
      var $55=((($54)+(7))|0);
      var $56=$55 & 7;
      $sshift=$56;
      var $57=$final_width;
      var $58=((($57)+(7))|0);
      var $59=$58 & 7;
      $dshift=$59;
      $s_start=7;
      $s_end=0;
      $s_inc=-1;
      __label__ = 8; break;
    case 7: 
      var $61=$row_info;
      var $62=(($61)|0);
      var $63=HEAP32[(($62)>>2)];
      var $64=((($63)+(7))|0);
      var $65=$64 & 7;
      var $66=(((7)-($65))|0);
      $sshift=$66;
      var $67=$final_width;
      var $68=((($67)+(7))|0);
      var $69=$68 & 7;
      var $70=(((7)-($69))|0);
      $dshift=$70;
      $s_start=0;
      $s_end=7;
      $s_inc=1;
      __label__ = 8; break;
    case 8: 
      $i=0;
      __label__ = 9; break;
    case 9: 
      var $73=$i;
      var $74=$row_info;
      var $75=(($74)|0);
      var $76=HEAPU32[(($75)>>2)];
      var $77=(($73)>>>0) < (($76)>>>0);
      if ($77) { __label__ = 10; break; } else { __label__ = 22; break; }
    case 10: 
      var $79=$sp;
      var $80=HEAPU8[($79)];
      var $81=(($80)&255);
      var $82=$sshift;
      var $83=$81 >> (($82)|0);
      var $84=$83 & 1;
      var $85=(($84) & 255);
      $v=$85;
      $j=0;
      __label__ = 11; break;
    case 11: 
      var $87=$j;
      var $88=$jstop;
      var $89=(($87)|0) < (($88)|0);
      if ($89) { __label__ = 12; break; } else { __label__ = 17; break; }
    case 12: 
      var $91=$dshift;
      var $92=(((7)-($91))|0);
      var $93=32639 >> (($92)|0);
      var $94=$93 & 255;
      var $95=(($94) & 255);
      var $96=(($95)&255);
      var $97=$dp;
      var $98=HEAPU8[($97)];
      var $99=(($98)&255);
      var $100=$99 & $96;
      var $101=(($100) & 255);
      HEAP8[($97)]=$101;
      var $102=$v;
      var $103=(($102)&255);
      var $104=$dshift;
      var $105=$103 << $104;
      var $106=(($105) & 255);
      var $107=(($106)&255);
      var $108=$dp;
      var $109=HEAPU8[($108)];
      var $110=(($109)&255);
      var $111=$110 | $107;
      var $112=(($111) & 255);
      HEAP8[($108)]=$112;
      var $113=$dshift;
      var $114=$s_end;
      var $115=(($113)|0)==(($114)|0);
      if ($115) { __label__ = 13; break; } else { __label__ = 14; break; }
    case 13: 
      var $117=$s_start;
      $dshift=$117;
      var $118=$dp;
      var $119=((($118)-(1))|0);
      $dp=$119;
      __label__ = 15; break;
    case 14: 
      var $121=$s_inc;
      var $122=$dshift;
      var $123=((($122)+($121))|0);
      $dshift=$123;
      __label__ = 15; break;
    case 15: 
      __label__ = 16; break;
    case 16: 
      var $126=$j;
      var $127=((($126)+(1))|0);
      $j=$127;
      __label__ = 11; break;
    case 17: 
      var $129=$sshift;
      var $130=$s_end;
      var $131=(($129)|0)==(($130)|0);
      if ($131) { __label__ = 18; break; } else { __label__ = 19; break; }
    case 18: 
      var $133=$s_start;
      $sshift=$133;
      var $134=$sp;
      var $135=((($134)-(1))|0);
      $sp=$135;
      __label__ = 20; break;
    case 19: 
      var $137=$s_inc;
      var $138=$sshift;
      var $139=((($138)+($137))|0);
      $sshift=$139;
      __label__ = 20; break;
    case 20: 
      __label__ = 21; break;
    case 21: 
      var $142=$i;
      var $143=((($142)+(1))|0);
      $i=$143;
      __label__ = 9; break;
    case 22: 
      __label__ = 68; break;
    case 23: 
      var $146=$row;
      var $147=$row_info;
      var $148=(($147)|0);
      var $149=HEAP32[(($148)>>2)];
      var $150=((($149)-(1))|0);
      var $151=$150 >>> 2;
      var $152=(($146+$151)|0);
      $sp1=$152;
      var $153=$row;
      var $154=$final_width;
      var $155=((($154)-(1))|0);
      var $156=$155 >>> 2;
      var $157=(($153+$156)|0);
      $dp2=$157;
      var $158=$pass;
      var $159=((_png_do_read_interlace_png_pass_inc+($158<<2))|0);
      var $160=HEAP32[(($159)>>2)];
      $jstop8=$160;
      var $161=$transformations;
      var $162=$161 & 65536;
      var $163=(($162)|0)!=0;
      if ($163) { __label__ = 24; break; } else { __label__ = 25; break; }
    case 24: 
      var $165=$row_info;
      var $166=(($165)|0);
      var $167=HEAP32[(($166)>>2)];
      var $168=((($167)+(3))|0);
      var $169=$168 & 3;
      var $170=$169 << 1;
      $sshift3=$170;
      var $171=$final_width;
      var $172=((($171)+(3))|0);
      var $173=$172 & 3;
      var $174=$173 << 1;
      $dshift4=$174;
      $s_start5=6;
      $s_end6=0;
      $s_inc7=-2;
      __label__ = 26; break;
    case 25: 
      var $176=$row_info;
      var $177=(($176)|0);
      var $178=HEAP32[(($177)>>2)];
      var $179=((($178)+(3))|0);
      var $180=$179 & 3;
      var $181=(((3)-($180))|0);
      var $182=$181 << 1;
      $sshift3=$182;
      var $183=$final_width;
      var $184=((($183)+(3))|0);
      var $185=$184 & 3;
      var $186=(((3)-($185))|0);
      var $187=$186 << 1;
      $dshift4=$187;
      $s_start5=0;
      $s_end6=6;
      $s_inc7=2;
      __label__ = 26; break;
    case 26: 
      $i9=0;
      __label__ = 27; break;
    case 27: 
      var $190=$i9;
      var $191=$row_info;
      var $192=(($191)|0);
      var $193=HEAPU32[(($192)>>2)];
      var $194=(($190)>>>0) < (($193)>>>0);
      if ($194) { __label__ = 28; break; } else { __label__ = 40; break; }
    case 28: 
      var $196=$sp1;
      var $197=HEAPU8[($196)];
      var $198=(($197)&255);
      var $199=$sshift3;
      var $200=$198 >> (($199)|0);
      var $201=$200 & 3;
      var $202=(($201) & 255);
      $v10=$202;
      $j11=0;
      __label__ = 29; break;
    case 29: 
      var $204=$j11;
      var $205=$jstop8;
      var $206=(($204)|0) < (($205)|0);
      if ($206) { __label__ = 30; break; } else { __label__ = 35; break; }
    case 30: 
      var $208=$dshift4;
      var $209=(((6)-($208))|0);
      var $210=16191 >> (($209)|0);
      var $211=$210 & 255;
      var $212=(($211) & 255);
      var $213=(($212)&255);
      var $214=$dp2;
      var $215=HEAPU8[($214)];
      var $216=(($215)&255);
      var $217=$216 & $213;
      var $218=(($217) & 255);
      HEAP8[($214)]=$218;
      var $219=$v10;
      var $220=(($219)&255);
      var $221=$dshift4;
      var $222=$220 << $221;
      var $223=(($222) & 255);
      var $224=(($223)&255);
      var $225=$dp2;
      var $226=HEAPU8[($225)];
      var $227=(($226)&255);
      var $228=$227 | $224;
      var $229=(($228) & 255);
      HEAP8[($225)]=$229;
      var $230=$dshift4;
      var $231=$s_end6;
      var $232=(($230)|0)==(($231)|0);
      if ($232) { __label__ = 31; break; } else { __label__ = 32; break; }
    case 31: 
      var $234=$s_start5;
      $dshift4=$234;
      var $235=$dp2;
      var $236=((($235)-(1))|0);
      $dp2=$236;
      __label__ = 33; break;
    case 32: 
      var $238=$s_inc7;
      var $239=$dshift4;
      var $240=((($239)+($238))|0);
      $dshift4=$240;
      __label__ = 33; break;
    case 33: 
      __label__ = 34; break;
    case 34: 
      var $243=$j11;
      var $244=((($243)+(1))|0);
      $j11=$244;
      __label__ = 29; break;
    case 35: 
      var $246=$sshift3;
      var $247=$s_end6;
      var $248=(($246)|0)==(($247)|0);
      if ($248) { __label__ = 36; break; } else { __label__ = 37; break; }
    case 36: 
      var $250=$s_start5;
      $sshift3=$250;
      var $251=$sp1;
      var $252=((($251)-(1))|0);
      $sp1=$252;
      __label__ = 38; break;
    case 37: 
      var $254=$s_inc7;
      var $255=$sshift3;
      var $256=((($255)+($254))|0);
      $sshift3=$256;
      __label__ = 38; break;
    case 38: 
      __label__ = 39; break;
    case 39: 
      var $259=$i9;
      var $260=((($259)+(1))|0);
      $i9=$260;
      __label__ = 27; break;
    case 40: 
      __label__ = 68; break;
    case 41: 
      var $263=$row;
      var $264=$row_info;
      var $265=(($264)|0);
      var $266=HEAP32[(($265)>>2)];
      var $267=((($266)-(1))|0);
      var $268=$267 >>> 1;
      var $269=(($263+$268)|0);
      $sp12=$269;
      var $270=$row;
      var $271=$final_width;
      var $272=((($271)-(1))|0);
      var $273=$272 >>> 1;
      var $274=(($270+$273)|0);
      $dp13=$274;
      var $275=$pass;
      var $276=((_png_do_read_interlace_png_pass_inc+($275<<2))|0);
      var $277=HEAP32[(($276)>>2)];
      $jstop20=$277;
      var $278=$transformations;
      var $279=$278 & 65536;
      var $280=(($279)|0)!=0;
      if ($280) { __label__ = 42; break; } else { __label__ = 43; break; }
    case 42: 
      var $282=$row_info;
      var $283=(($282)|0);
      var $284=HEAP32[(($283)>>2)];
      var $285=((($284)+(1))|0);
      var $286=$285 & 1;
      var $287=$286 << 2;
      $sshift14=$287;
      var $288=$final_width;
      var $289=((($288)+(1))|0);
      var $290=$289 & 1;
      var $291=$290 << 2;
      $dshift15=$291;
      $s_start16=4;
      $s_end17=0;
      $s_inc18=-4;
      __label__ = 44; break;
    case 43: 
      var $293=$row_info;
      var $294=(($293)|0);
      var $295=HEAP32[(($294)>>2)];
      var $296=((($295)+(1))|0);
      var $297=$296 & 1;
      var $298=(((1)-($297))|0);
      var $299=$298 << 2;
      $sshift14=$299;
      var $300=$final_width;
      var $301=((($300)+(1))|0);
      var $302=$301 & 1;
      var $303=(((1)-($302))|0);
      var $304=$303 << 2;
      $dshift15=$304;
      $s_start16=0;
      $s_end17=4;
      $s_inc18=4;
      __label__ = 44; break;
    case 44: 
      $i19=0;
      __label__ = 45; break;
    case 45: 
      var $307=$i19;
      var $308=$row_info;
      var $309=(($308)|0);
      var $310=HEAPU32[(($309)>>2)];
      var $311=(($307)>>>0) < (($310)>>>0);
      if ($311) { __label__ = 46; break; } else { __label__ = 58; break; }
    case 46: 
      var $313=$sp12;
      var $314=HEAPU8[($313)];
      var $315=(($314)&255);
      var $316=$sshift14;
      var $317=$315 >> (($316)|0);
      var $318=$317 & 15;
      var $319=(($318) & 255);
      $v21=$319;
      $j22=0;
      __label__ = 47; break;
    case 47: 
      var $321=$j22;
      var $322=$jstop20;
      var $323=(($321)|0) < (($322)|0);
      if ($323) { __label__ = 48; break; } else { __label__ = 53; break; }
    case 48: 
      var $325=$dshift15;
      var $326=(((4)-($325))|0);
      var $327=3855 >> (($326)|0);
      var $328=$327 & 255;
      var $329=(($328) & 255);
      var $330=(($329)&255);
      var $331=$dp13;
      var $332=HEAPU8[($331)];
      var $333=(($332)&255);
      var $334=$333 & $330;
      var $335=(($334) & 255);
      HEAP8[($331)]=$335;
      var $336=$v21;
      var $337=(($336)&255);
      var $338=$dshift15;
      var $339=$337 << $338;
      var $340=(($339) & 255);
      var $341=(($340)&255);
      var $342=$dp13;
      var $343=HEAPU8[($342)];
      var $344=(($343)&255);
      var $345=$344 | $341;
      var $346=(($345) & 255);
      HEAP8[($342)]=$346;
      var $347=$dshift15;
      var $348=$s_end17;
      var $349=(($347)|0)==(($348)|0);
      if ($349) { __label__ = 49; break; } else { __label__ = 50; break; }
    case 49: 
      var $351=$s_start16;
      $dshift15=$351;
      var $352=$dp13;
      var $353=((($352)-(1))|0);
      $dp13=$353;
      __label__ = 51; break;
    case 50: 
      var $355=$s_inc18;
      var $356=$dshift15;
      var $357=((($356)+($355))|0);
      $dshift15=$357;
      __label__ = 51; break;
    case 51: 
      __label__ = 52; break;
    case 52: 
      var $360=$j22;
      var $361=((($360)+(1))|0);
      $j22=$361;
      __label__ = 47; break;
    case 53: 
      var $363=$sshift14;
      var $364=$s_end17;
      var $365=(($363)|0)==(($364)|0);
      if ($365) { __label__ = 54; break; } else { __label__ = 55; break; }
    case 54: 
      var $367=$s_start16;
      $sshift14=$367;
      var $368=$sp12;
      var $369=((($368)-(1))|0);
      $sp12=$369;
      __label__ = 56; break;
    case 55: 
      var $371=$s_inc18;
      var $372=$sshift14;
      var $373=((($372)+($371))|0);
      $sshift14=$373;
      __label__ = 56; break;
    case 56: 
      __label__ = 57; break;
    case 57: 
      var $376=$i19;
      var $377=((($376)+(1))|0);
      $i19=$377;
      __label__ = 45; break;
    case 58: 
      __label__ = 68; break;
    case 59: 
      var $380=$row_info;
      var $381=(($380+11)|0);
      var $382=HEAPU8[($381)];
      var $383=(($382)&255);
      var $384=$383 >> 3;
      $pixel_bytes=$384;
      var $385=$row;
      var $386=$row_info;
      var $387=(($386)|0);
      var $388=HEAP32[(($387)>>2)];
      var $389=((($388)-(1))|0);
      var $390=$pixel_bytes;
      var $391=((($389)*($390))|0);
      var $392=(($385+$391)|0);
      $sp23=$392;
      var $393=$row;
      var $394=$final_width;
      var $395=((($394)-(1))|0);
      var $396=$pixel_bytes;
      var $397=((($395)*($396))|0);
      var $398=(($393+$397)|0);
      $dp24=$398;
      var $399=$pass;
      var $400=((_png_do_read_interlace_png_pass_inc+($399<<2))|0);
      var $401=HEAP32[(($400)>>2)];
      $jstop25=$401;
      $i26=0;
      __label__ = 60; break;
    case 60: 
      var $403=$i26;
      var $404=$row_info;
      var $405=(($404)|0);
      var $406=HEAPU32[(($405)>>2)];
      var $407=(($403)>>>0) < (($406)>>>0);
      if ($407) { __label__ = 61; break; } else { __label__ = 67; break; }
    case 61: 
      var $409=(($v27)|0);
      var $410=$sp23;
      var $411=$pixel_bytes;
      assert($411 % 1 === 0, 'memcpy given ' + $411 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');_memcpy($409, $410, $411, 1);
      $j28=0;
      __label__ = 62; break;
    case 62: 
      var $413=$j28;
      var $414=$jstop25;
      var $415=(($413)|0) < (($414)|0);
      if ($415) { __label__ = 63; break; } else { __label__ = 65; break; }
    case 63: 
      var $417=$dp24;
      var $418=(($v27)|0);
      var $419=$pixel_bytes;
      assert($419 % 1 === 0, 'memcpy given ' + $419 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');_memcpy($417, $418, $419, 1);
      var $420=$pixel_bytes;
      var $421=$dp24;
      var $422=(((-$420))|0);
      var $423=(($421+$422)|0);
      $dp24=$423;
      __label__ = 64; break;
    case 64: 
      var $425=$j28;
      var $426=((($425)+(1))|0);
      $j28=$426;
      __label__ = 62; break;
    case 65: 
      var $428=$pixel_bytes;
      var $429=$sp23;
      var $430=(((-$428))|0);
      var $431=(($429+$430)|0);
      $sp23=$431;
      __label__ = 66; break;
    case 66: 
      var $433=$i26;
      var $434=((($433)+(1))|0);
      $i26=$434;
      __label__ = 60; break;
    case 67: 
      __label__ = 68; break;
    case 68: 
      var $437=$final_width;
      var $438=$row_info;
      var $439=(($438)|0);
      HEAP32[(($439)>>2)]=$437;
      var $440=$row_info;
      var $441=(($440+11)|0);
      var $442=HEAPU8[($441)];
      var $443=(($442)&255);
      var $444=(($443)|0) >= 8;
      if ($444) { __label__ = 69; break; } else { __label__ = 70; break; }
    case 69: 
      var $446=$final_width;
      var $447=$row_info;
      var $448=(($447+11)|0);
      var $449=HEAPU8[($448)];
      var $450=(($449)&255);
      var $451=$450 >>> 3;
      var $452=((($446)*($451))|0);
      var $463 = $452;__label__ = 71; break;
    case 70: 
      var $454=$final_width;
      var $455=$row_info;
      var $456=(($455+11)|0);
      var $457=HEAPU8[($456)];
      var $458=(($457)&255);
      var $459=((($454)*($458))|0);
      var $460=((($459)+(7))|0);
      var $461=$460 >>> 3;
      var $463 = $461;__label__ = 71; break;
    case 71: 
      var $463;
      var $464=$row_info;
      var $465=(($464+4)|0);
      HEAP32[(($465)>>2)]=$463;
      __label__ = 72; break;
    case 72: 
      STACKTOP = __stackBase__;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_png_do_read_interlace["X"]=1;

function _png_read_filter_row($png_ptr, $row_info, $row, $prev_row, $filter) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $5;
      var $i;
      var $istop;
      var $bpp;
      var $rp;
      var $lp;
      var $i1;
      var $istop2;
      var $rp3;
      var $pp;
      var $i4;
      var $rp5;
      var $pp6;
      var $lp7;
      var $bpp8;
      var $istop9;
      var $i10;
      var $rp11;
      var $pp12;
      var $lp13;
      var $cp;
      var $bpp14;
      var $istop15;
      var $a;
      var $b;
      var $c;
      var $pa;
      var $pb;
      var $pc;
      var $p;
      $1=$png_ptr;
      $2=$row_info;
      $3=$row;
      $4=$prev_row;
      $5=$filter;
      var $6=$5;
      if ((($6)|0) == 1) {
        __label__ = 3; break;
      }
      else if ((($6)|0) == 2) {
        __label__ = 8; break;
      }
      else if ((($6)|0) == 3) {
        __label__ = 13; break;
      }
      else if ((($6)|0) == 4) {
        __label__ = 22; break;
      }
      else if ((($6)|0) == 0) {
        __label__ = 48; break;
      }
      else {
      __label__ = 47; break;
      }
      
    case 3: 
      var $8=$2;
      var $9=(($8+4)|0);
      var $10=HEAP32[(($9)>>2)];
      $istop=$10;
      var $11=$2;
      var $12=(($11+11)|0);
      var $13=HEAPU8[($12)];
      var $14=(($13)&255);
      var $15=((($14)+(7))|0);
      var $16=$15 >> 3;
      $bpp=$16;
      var $17=$3;
      var $18=$bpp;
      var $19=(($17+$18)|0);
      $rp=$19;
      var $20=$3;
      $lp=$20;
      var $21=$bpp;
      $i=$21;
      __label__ = 4; break;
    case 4: 
      var $23=$i;
      var $24=$istop;
      var $25=(($23)>>>0) < (($24)>>>0);
      if ($25) { __label__ = 5; break; } else { __label__ = 7; break; }
    case 5: 
      var $27=$rp;
      var $28=HEAPU8[($27)];
      var $29=(($28)&255);
      var $30=$lp;
      var $31=(($30+1)|0);
      $lp=$31;
      var $32=HEAPU8[($30)];
      var $33=(($32)&255);
      var $34=((($29)+($33))|0);
      var $35=$34 & 255;
      var $36=(($35) & 255);
      var $37=$rp;
      HEAP8[($37)]=$36;
      var $38=$rp;
      var $39=(($38+1)|0);
      $rp=$39;
      __label__ = 6; break;
    case 6: 
      var $41=$i;
      var $42=((($41)+(1))|0);
      $i=$42;
      __label__ = 4; break;
    case 7: 
      __label__ = 48; break;
    case 8: 
      var $45=$2;
      var $46=(($45+4)|0);
      var $47=HEAP32[(($46)>>2)];
      $istop2=$47;
      var $48=$3;
      $rp3=$48;
      var $49=$4;
      $pp=$49;
      $i1=0;
      __label__ = 9; break;
    case 9: 
      var $51=$i1;
      var $52=$istop2;
      var $53=(($51)>>>0) < (($52)>>>0);
      if ($53) { __label__ = 10; break; } else { __label__ = 12; break; }
    case 10: 
      var $55=$rp3;
      var $56=HEAPU8[($55)];
      var $57=(($56)&255);
      var $58=$pp;
      var $59=(($58+1)|0);
      $pp=$59;
      var $60=HEAPU8[($58)];
      var $61=(($60)&255);
      var $62=((($57)+($61))|0);
      var $63=$62 & 255;
      var $64=(($63) & 255);
      var $65=$rp3;
      HEAP8[($65)]=$64;
      var $66=$rp3;
      var $67=(($66+1)|0);
      $rp3=$67;
      __label__ = 11; break;
    case 11: 
      var $69=$i1;
      var $70=((($69)+(1))|0);
      $i1=$70;
      __label__ = 9; break;
    case 12: 
      __label__ = 48; break;
    case 13: 
      var $73=$3;
      $rp5=$73;
      var $74=$4;
      $pp6=$74;
      var $75=$3;
      $lp7=$75;
      var $76=$2;
      var $77=(($76+11)|0);
      var $78=HEAPU8[($77)];
      var $79=(($78)&255);
      var $80=((($79)+(7))|0);
      var $81=$80 >> 3;
      $bpp8=$81;
      var $82=$2;
      var $83=(($82+4)|0);
      var $84=HEAP32[(($83)>>2)];
      var $85=$bpp8;
      var $86=((($84)-($85))|0);
      $istop9=$86;
      $i4=0;
      __label__ = 14; break;
    case 14: 
      var $88=$i4;
      var $89=$bpp8;
      var $90=(($88)>>>0) < (($89)>>>0);
      if ($90) { __label__ = 15; break; } else { __label__ = 17; break; }
    case 15: 
      var $92=$rp5;
      var $93=HEAPU8[($92)];
      var $94=(($93)&255);
      var $95=$pp6;
      var $96=(($95+1)|0);
      $pp6=$96;
      var $97=HEAPU8[($95)];
      var $98=(($97)&255);
      var $99=((((($98)|0))/(2))&-1);
      var $100=((($94)+($99))|0);
      var $101=$100 & 255;
      var $102=(($101) & 255);
      var $103=$rp5;
      HEAP8[($103)]=$102;
      var $104=$rp5;
      var $105=(($104+1)|0);
      $rp5=$105;
      __label__ = 16; break;
    case 16: 
      var $107=$i4;
      var $108=((($107)+(1))|0);
      $i4=$108;
      __label__ = 14; break;
    case 17: 
      $i4=0;
      __label__ = 18; break;
    case 18: 
      var $111=$i4;
      var $112=$istop9;
      var $113=(($111)>>>0) < (($112)>>>0);
      if ($113) { __label__ = 19; break; } else { __label__ = 21; break; }
    case 19: 
      var $115=$rp5;
      var $116=HEAPU8[($115)];
      var $117=(($116)&255);
      var $118=$pp6;
      var $119=(($118+1)|0);
      $pp6=$119;
      var $120=HEAPU8[($118)];
      var $121=(($120)&255);
      var $122=$lp7;
      var $123=(($122+1)|0);
      $lp7=$123;
      var $124=HEAPU8[($122)];
      var $125=(($124)&255);
      var $126=((($121)+($125))|0);
      var $127=((((($126)|0))/(2))&-1);
      var $128=((($117)+($127))|0);
      var $129=$128 & 255;
      var $130=(($129) & 255);
      var $131=$rp5;
      HEAP8[($131)]=$130;
      var $132=$rp5;
      var $133=(($132+1)|0);
      $rp5=$133;
      __label__ = 20; break;
    case 20: 
      var $135=$i4;
      var $136=((($135)+(1))|0);
      $i4=$136;
      __label__ = 18; break;
    case 21: 
      __label__ = 48; break;
    case 22: 
      var $139=$3;
      $rp11=$139;
      var $140=$4;
      $pp12=$140;
      var $141=$3;
      $lp13=$141;
      var $142=$4;
      $cp=$142;
      var $143=$2;
      var $144=(($143+11)|0);
      var $145=HEAPU8[($144)];
      var $146=(($145)&255);
      var $147=((($146)+(7))|0);
      var $148=$147 >> 3;
      $bpp14=$148;
      var $149=$2;
      var $150=(($149+4)|0);
      var $151=HEAP32[(($150)>>2)];
      var $152=$bpp14;
      var $153=((($151)-($152))|0);
      $istop15=$153;
      $i10=0;
      __label__ = 23; break;
    case 23: 
      var $155=$i10;
      var $156=$bpp14;
      var $157=(($155)>>>0) < (($156)>>>0);
      if ($157) { __label__ = 24; break; } else { __label__ = 26; break; }
    case 24: 
      var $159=$rp11;
      var $160=HEAPU8[($159)];
      var $161=(($160)&255);
      var $162=$pp12;
      var $163=(($162+1)|0);
      $pp12=$163;
      var $164=HEAPU8[($162)];
      var $165=(($164)&255);
      var $166=((($161)+($165))|0);
      var $167=$166 & 255;
      var $168=(($167) & 255);
      var $169=$rp11;
      HEAP8[($169)]=$168;
      var $170=$rp11;
      var $171=(($170+1)|0);
      $rp11=$171;
      __label__ = 25; break;
    case 25: 
      var $173=$i10;
      var $174=((($173)+(1))|0);
      $i10=$174;
      __label__ = 23; break;
    case 26: 
      $i10=0;
      __label__ = 27; break;
    case 27: 
      var $177=$i10;
      var $178=$istop15;
      var $179=(($177)>>>0) < (($178)>>>0);
      if ($179) { __label__ = 28; break; } else { __label__ = 46; break; }
    case 28: 
      var $181=$lp13;
      var $182=(($181+1)|0);
      $lp13=$182;
      var $183=HEAPU8[($181)];
      var $184=(($183)&255);
      $a=$184;
      var $185=$pp12;
      var $186=(($185+1)|0);
      $pp12=$186;
      var $187=HEAPU8[($185)];
      var $188=(($187)&255);
      $b=$188;
      var $189=$cp;
      var $190=(($189+1)|0);
      $cp=$190;
      var $191=HEAPU8[($189)];
      var $192=(($191)&255);
      $c=$192;
      var $193=$b;
      var $194=$c;
      var $195=((($193)-($194))|0);
      $p=$195;
      var $196=$a;
      var $197=$c;
      var $198=((($196)-($197))|0);
      $pc=$198;
      var $199=$p;
      var $200=(($199)|0) < 0;
      if ($200) { __label__ = 29; break; } else { __label__ = 30; break; }
    case 29: 
      var $202=$p;
      var $203=(((-$202))|0);
      var $207 = $203;__label__ = 31; break;
    case 30: 
      var $205=$p;
      var $207 = $205;__label__ = 31; break;
    case 31: 
      var $207;
      $pa=$207;
      var $208=$pc;
      var $209=(($208)|0) < 0;
      if ($209) { __label__ = 32; break; } else { __label__ = 33; break; }
    case 32: 
      var $211=$pc;
      var $212=(((-$211))|0);
      var $216 = $212;__label__ = 34; break;
    case 33: 
      var $214=$pc;
      var $216 = $214;__label__ = 34; break;
    case 34: 
      var $216;
      $pb=$216;
      var $217=$p;
      var $218=$pc;
      var $219=((($217)+($218))|0);
      var $220=(($219)|0) < 0;
      if ($220) { __label__ = 35; break; } else { __label__ = 36; break; }
    case 35: 
      var $222=$p;
      var $223=$pc;
      var $224=((($222)+($223))|0);
      var $225=(((-$224))|0);
      var $231 = $225;__label__ = 37; break;
    case 36: 
      var $227=$p;
      var $228=$pc;
      var $229=((($227)+($228))|0);
      var $231 = $229;__label__ = 37; break;
    case 37: 
      var $231;
      $pc=$231;
      var $232=$pa;
      var $233=$pb;
      var $234=(($232)|0) <= (($233)|0);
      if ($234) { __label__ = 38; break; } else { __label__ = 40; break; }
    case 38: 
      var $236=$pa;
      var $237=$pc;
      var $238=(($236)|0) <= (($237)|0);
      if ($238) { __label__ = 39; break; } else { __label__ = 40; break; }
    case 39: 
      var $240=$a;
      var $252 = $240;__label__ = 44; break;
    case 40: 
      var $242=$pb;
      var $243=$pc;
      var $244=(($242)|0) <= (($243)|0);
      if ($244) { __label__ = 41; break; } else { __label__ = 42; break; }
    case 41: 
      var $246=$b;
      var $250 = $246;__label__ = 43; break;
    case 42: 
      var $248=$c;
      var $250 = $248;__label__ = 43; break;
    case 43: 
      var $250;
      var $252 = $250;__label__ = 44; break;
    case 44: 
      var $252;
      $p=$252;
      var $253=$rp11;
      var $254=HEAPU8[($253)];
      var $255=(($254)&255);
      var $256=$p;
      var $257=((($255)+($256))|0);
      var $258=$257 & 255;
      var $259=(($258) & 255);
      var $260=$rp11;
      HEAP8[($260)]=$259;
      var $261=$rp11;
      var $262=(($261+1)|0);
      $rp11=$262;
      __label__ = 45; break;
    case 45: 
      var $264=$i10;
      var $265=((($264)+(1))|0);
      $i10=$265;
      __label__ = 27; break;
    case 46: 
      __label__ = 48; break;
    case 47: 
      var $268=$1;
      _png_warning($268, ((STRING_TABLE.__str134)|0));
      var $269=$3;
      HEAP8[($269)]=0;
      __label__ = 48; break;
    case 48: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_png_read_filter_row["X"]=1;

function _png_read_finish_row($png_ptr) {
  var __stackBase__  = STACKTOP; STACKTOP += 4; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $extra=__stackBase__;
      var $ret;
      $1=$png_ptr;
      var $2=$1;
      var $3=(($2+208)|0);
      var $4=HEAP32[(($3)>>2)];
      var $5=((($4)+(1))|0);
      HEAP32[(($3)>>2)]=$5;
      var $6=$1;
      var $7=(($6+208)|0);
      var $8=HEAPU32[(($7)>>2)];
      var $9=$1;
      var $10=(($9+188)|0);
      var $11=HEAPU32[(($10)>>2)];
      var $12=(($8)>>>0) < (($11)>>>0);
      if ($12) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      __label__ = 48; break;
    case 4: 
      var $15=$1;
      var $16=(($15+271)|0);
      var $17=HEAP8[($16)];
      var $18=(($17 << 24) >> 24)!=0;
      if ($18) { __label__ = 5; break; } else { __label__ = 18; break; }
    case 5: 
      var $20=$1;
      var $21=(($20+208)|0);
      HEAP32[(($21)>>2)]=0;
      var $22=$1;
      var $23=(($22+212)|0);
      var $24=HEAP32[(($23)>>2)];
      var $25=$1;
      var $26=(($25+196)|0);
      var $27=HEAP32[(($26)>>2)];
      var $28=((($27)+(1))|0);
      _memset($24, 0, $28, 1);
      __label__ = 6; break;
    case 6: 
      var $30=$1;
      var $31=(($30+272)|0);
      var $32=HEAP8[($31)];
      var $33=((($32)+(1))&255);
      HEAP8[($31)]=$33;
      var $34=$1;
      var $35=(($34+272)|0);
      var $36=HEAPU8[($35)];
      var $37=(($36)&255);
      var $38=(($37)|0) >= 7;
      if ($38) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      __label__ = 15; break;
    case 8: 
      var $41=$1;
      var $42=(($41+180)|0);
      var $43=HEAP32[(($42)>>2)];
      var $44=$1;
      var $45=(($44+272)|0);
      var $46=HEAPU8[($45)];
      var $47=(($46)&255);
      var $48=((_png_read_finish_row_png_pass_inc+($47<<2))|0);
      var $49=HEAP32[(($48)>>2)];
      var $50=((($43)+($49))|0);
      var $51=((($50)-(1))|0);
      var $52=$1;
      var $53=(($52+272)|0);
      var $54=HEAPU8[($53)];
      var $55=(($54)&255);
      var $56=((_png_read_finish_row_png_pass_start+($55<<2))|0);
      var $57=HEAP32[(($56)>>2)];
      var $58=((($51)-($57))|0);
      var $59=$1;
      var $60=(($59+272)|0);
      var $61=HEAPU8[($60)];
      var $62=(($61)&255);
      var $63=((_png_read_finish_row_png_pass_inc+($62<<2))|0);
      var $64=HEAPU32[(($63)>>2)];
      var $65=Math.floor(((($58)>>>0))/((($64)>>>0)));
      var $66=$1;
      var $67=(($66+204)|0);
      HEAP32[(($67)>>2)]=$65;
      var $68=$1;
      var $69=(($68+92)|0);
      var $70=HEAP32[(($69)>>2)];
      var $71=$70 & 2;
      var $72=(($71)|0)!=0;
      if ($72) { __label__ = 12; break; } else { __label__ = 9; break; }
    case 9: 
      var $74=$1;
      var $75=(($74+184)|0);
      var $76=HEAP32[(($75)>>2)];
      var $77=$1;
      var $78=(($77+272)|0);
      var $79=HEAPU8[($78)];
      var $80=(($79)&255);
      var $81=((_png_read_finish_row_png_pass_yinc+($80<<2))|0);
      var $82=HEAP32[(($81)>>2)];
      var $83=((($76)+($82))|0);
      var $84=((($83)-(1))|0);
      var $85=$1;
      var $86=(($85+272)|0);
      var $87=HEAPU8[($86)];
      var $88=(($87)&255);
      var $89=((_png_read_finish_row_png_pass_ystart+($88<<2))|0);
      var $90=HEAP32[(($89)>>2)];
      var $91=((($84)-($90))|0);
      var $92=$1;
      var $93=(($92+272)|0);
      var $94=HEAPU8[($93)];
      var $95=(($94)&255);
      var $96=((_png_read_finish_row_png_pass_yinc+($95<<2))|0);
      var $97=HEAPU32[(($96)>>2)];
      var $98=Math.floor(((($91)>>>0))/((($97)>>>0)));
      var $99=$1;
      var $100=(($99+188)|0);
      HEAP32[(($100)>>2)]=$98;
      var $101=$1;
      var $102=(($101+188)|0);
      var $103=HEAP32[(($102)>>2)];
      var $104=(($103)|0)!=0;
      if ($104) { __label__ = 11; break; } else { __label__ = 10; break; }
    case 10: 
      __label__ = 14; break;
    case 11: 
      __label__ = 13; break;
    case 12: 
      __label__ = 15; break;
    case 13: 
      __label__ = 14; break;
    case 14: 
      var $110=$1;
      var $111=(($110+204)|0);
      var $112=HEAP32[(($111)>>2)];
      var $113=(($112)|0)==0;
      if ($113) { __label__ = 6; break; } else { __label__ = 15; break; }
    case 15: 
      var $115=$1;
      var $116=(($115+272)|0);
      var $117=HEAPU8[($116)];
      var $118=(($117)&255);
      var $119=(($118)|0) < 7;
      if ($119) { __label__ = 16; break; } else { __label__ = 17; break; }
    case 16: 
      __label__ = 48; break;
    case 17: 
      __label__ = 18; break;
    case 18: 
      var $123=$1;
      var $124=(($123+88)|0);
      var $125=HEAP32[(($124)>>2)];
      var $126=$125 & 32;
      var $127=(($126)|0)!=0;
      if ($127) { __label__ = 44; break; } else { __label__ = 19; break; }
    case 19: 
      var $129=$1;
      var $130=(($129+96)|0);
      var $131=(($130+12)|0);
      HEAP32[(($131)>>2)]=$extra;
      var $132=$1;
      var $133=(($132+96)|0);
      var $134=(($133+16)|0);
      HEAP32[(($134)>>2)]=1;
      __label__ = 20; break;
    case 20: 
      var $136=$1;
      var $137=(($136+96)|0);
      var $138=(($137+4)|0);
      var $139=HEAP32[(($138)>>2)];
      var $140=(($139)|0)!=0;
      if ($140) { __label__ = 29; break; } else { __label__ = 21; break; }
    case 21: 
      __label__ = 22; break;
    case 22: 
      var $143=$1;
      var $144=(($143+248)|0);
      var $145=HEAP32[(($144)>>2)];
      var $146=(($145)|0)!=0;
      var $147=$146 ^ 1;
      if ($147) { __label__ = 23; break; } else { __label__ = 26; break; }
    case 23: 
      var $149=$1;
      var $150=_png_crc_finish($149, 0);
      var $151=$1;
      var $152=_png_read_chunk_header($151);
      var $153=$1;
      var $154=(($153+248)|0);
      HEAP32[(($154)>>2)]=$152;
      var $155=$1;
      var $156=(($155+264)|0);
      var $157=(($156)|0);
      var $158=_memcmp($157, ((STRING_TABLE._png_read_finish_row_png_IDAT)|0), 4);
      var $159=(($158)|0)!=0;
      if ($159) { __label__ = 24; break; } else { __label__ = 25; break; }
    case 24: 
      var $161=$1;
      _png_error($161, ((STRING_TABLE.__str135233)|0));
      __label__ = 25; break;
    case 25: 
      __label__ = 22; break;
    case 26: 
      var $164=$1;
      var $165=(($164+156)|0);
      var $166=HEAP32[(($165)>>2)];
      var $167=$1;
      var $168=(($167+96)|0);
      var $169=(($168+4)|0);
      HEAP32[(($169)>>2)]=$166;
      var $170=$1;
      var $171=(($170+152)|0);
      var $172=HEAP32[(($171)>>2)];
      var $173=$1;
      var $174=(($173+96)|0);
      var $175=(($174)|0);
      HEAP32[(($175)>>2)]=$172;
      var $176=$1;
      var $177=(($176+156)|0);
      var $178=HEAPU32[(($177)>>2)];
      var $179=$1;
      var $180=(($179+248)|0);
      var $181=HEAPU32[(($180)>>2)];
      var $182=(($178)>>>0) > (($181)>>>0);
      if ($182) { __label__ = 27; break; } else { __label__ = 28; break; }
    case 27: 
      var $184=$1;
      var $185=(($184+248)|0);
      var $186=HEAP32[(($185)>>2)];
      var $187=$1;
      var $188=(($187+96)|0);
      var $189=(($188+4)|0);
      HEAP32[(($189)>>2)]=$186;
      __label__ = 28; break;
    case 28: 
      var $191=$1;
      var $192=$1;
      var $193=(($192+152)|0);
      var $194=HEAP32[(($193)>>2)];
      var $195=$1;
      var $196=(($195+96)|0);
      var $197=(($196+4)|0);
      var $198=HEAP32[(($197)>>2)];
      _png_crc_read($191, $194, $198);
      var $199=$1;
      var $200=(($199+96)|0);
      var $201=(($200+4)|0);
      var $202=HEAP32[(($201)>>2)];
      var $203=$1;
      var $204=(($203+248)|0);
      var $205=HEAP32[(($204)>>2)];
      var $206=((($205)-($202))|0);
      HEAP32[(($204)>>2)]=$206;
      __label__ = 29; break;
    case 29: 
      var $208=$1;
      var $209=(($208+96)|0);
      var $210=_inflate($209, 1);
      $ret=$210;
      var $211=$ret;
      var $212=(($211)|0)==1;
      if ($212) { __label__ = 30; break; } else { __label__ = 35; break; }
    case 30: 
      var $214=$1;
      var $215=(($214+96)|0);
      var $216=(($215+16)|0);
      var $217=HEAP32[(($216)>>2)];
      var $218=(($217)|0)!=0;
      if ($218) { __label__ = 31; break; } else { __label__ = 33; break; }
    case 31: 
      var $220=$1;
      var $221=(($220+96)|0);
      var $222=(($221+4)|0);
      var $223=HEAP32[(($222)>>2)];
      var $224=(($223)|0)!=0;
      if ($224) { __label__ = 33; break; } else { __label__ = 32; break; }
    case 32: 
      var $226=$1;
      var $227=(($226+248)|0);
      var $228=HEAP32[(($227)>>2)];
      var $229=(($228)|0)!=0;
      if ($229) { __label__ = 33; break; } else { __label__ = 34; break; }
    case 33: 
      var $231=$1;
      _png_warning($231, ((STRING_TABLE.__str136)|0));
      __label__ = 34; break;
    case 34: 
      var $233=$1;
      var $234=(($233+84)|0);
      var $235=HEAP32[(($234)>>2)];
      var $236=$235 | 8;
      HEAP32[(($234)>>2)]=$236;
      var $237=$1;
      var $238=(($237+88)|0);
      var $239=HEAP32[(($238)>>2)];
      var $240=$239 | 32;
      HEAP32[(($238)>>2)]=$240;
      __label__ = 43; break;
    case 35: 
      var $242=$ret;
      var $243=(($242)|0)!=0;
      if ($243) { __label__ = 36; break; } else { __label__ = 40; break; }
    case 36: 
      var $245=$1;
      var $246=$1;
      var $247=(($246+96)|0);
      var $248=(($247+24)|0);
      var $249=HEAP32[(($248)>>2)];
      var $250=(($249)|0)!=0;
      if ($250) { __label__ = 37; break; } else { __label__ = 38; break; }
    case 37: 
      var $252=$1;
      var $253=(($252+96)|0);
      var $254=(($253+24)|0);
      var $255=HEAP32[(($254)>>2)];
      var $258 = $255;__label__ = 39; break;
    case 38: 
      var $258 = ((STRING_TABLE.__str137)|0);__label__ = 39; break;
    case 39: 
      var $258;
      _png_error($245, $258);
      __label__ = 40; break;
    case 40: 
      var $260=$1;
      var $261=(($260+96)|0);
      var $262=(($261+16)|0);
      var $263=HEAP32[(($262)>>2)];
      var $264=(($263)|0)!=0;
      if ($264) { __label__ = 42; break; } else { __label__ = 41; break; }
    case 41: 
      var $266=$1;
      _png_warning($266, ((STRING_TABLE.__str136)|0));
      var $267=$1;
      var $268=(($267+84)|0);
      var $269=HEAP32[(($268)>>2)];
      var $270=$269 | 8;
      HEAP32[(($268)>>2)]=$270;
      var $271=$1;
      var $272=(($271+88)|0);
      var $273=HEAP32[(($272)>>2)];
      var $274=$273 | 32;
      HEAP32[(($272)>>2)]=$274;
      __label__ = 43; break;
    case 42: 
      __label__ = 20; break;
    case 43: 
      var $277=$1;
      var $278=(($277+96)|0);
      var $279=(($278+16)|0);
      HEAP32[(($279)>>2)]=0;
      __label__ = 44; break;
    case 44: 
      var $281=$1;
      var $282=(($281+248)|0);
      var $283=HEAP32[(($282)>>2)];
      var $284=(($283)|0)!=0;
      if ($284) { __label__ = 46; break; } else { __label__ = 45; break; }
    case 45: 
      var $286=$1;
      var $287=(($286+96)|0);
      var $288=(($287+4)|0);
      var $289=HEAP32[(($288)>>2)];
      var $290=(($289)|0)!=0;
      if ($290) { __label__ = 46; break; } else { __label__ = 47; break; }
    case 46: 
      var $292=$1;
      _png_warning($292, ((STRING_TABLE.__str138)|0));
      __label__ = 47; break;
    case 47: 
      var $294=$1;
      var $295=(($294+96)|0);
      var $296=_inflateReset($295);
      var $297=$1;
      var $298=(($297+84)|0);
      var $299=HEAP32[(($298)>>2)];
      var $300=$299 | 8;
      HEAP32[(($298)>>2)]=$300;
      __label__ = 48; break;
    case 48: 
      STACKTOP = __stackBase__;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_png_read_finish_row["X"]=1;

function _png_set_cHRM($png_ptr, $info_ptr, $white_x, $white_y, $red_x, $red_y, $green_x, $green_y, $blue_x, $blue_y) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $5;
      var $6;
      var $7;
      var $8;
      var $9;
      var $10;
      $1=$png_ptr;
      $2=$info_ptr;
      $3=$white_x;
      $4=$white_y;
      $5=$red_x;
      $6=$red_y;
      $7=$green_x;
      $8=$green_y;
      $9=$blue_x;
      $10=$blue_y;
      var $11=$1;
      var $12=(($11)|0)==0;
      if ($12) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      var $14=$2;
      var $15=(($14)|0)==0;
      if ($15) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      __label__ = 6; break;
    case 5: 
      var $18=$3;
      var $19=$18;
      var $20=$2;
      var $21=(($20+128)|0);
      HEAPF32[(($21)>>2)]=$19;
      var $22=$4;
      var $23=$22;
      var $24=$2;
      var $25=(($24+132)|0);
      HEAPF32[(($25)>>2)]=$23;
      var $26=$5;
      var $27=$26;
      var $28=$2;
      var $29=(($28+136)|0);
      HEAPF32[(($29)>>2)]=$27;
      var $30=$6;
      var $31=$30;
      var $32=$2;
      var $33=(($32+140)|0);
      HEAPF32[(($33)>>2)]=$31;
      var $34=$7;
      var $35=$34;
      var $36=$2;
      var $37=(($36+144)|0);
      HEAPF32[(($37)>>2)]=$35;
      var $38=$8;
      var $39=$38;
      var $40=$2;
      var $41=(($40+148)|0);
      HEAPF32[(($41)>>2)]=$39;
      var $42=$9;
      var $43=$42;
      var $44=$2;
      var $45=(($44+152)|0);
      HEAPF32[(($45)>>2)]=$43;
      var $46=$10;
      var $47=$46;
      var $48=$2;
      var $49=(($48+156)|0);
      HEAPF32[(($49)>>2)]=$47;
      var $50=$3;
      var $51=($50)*(100000);
      var $52=($51)+(0.5);
      var $53=(($52)&-1);
      var $54=$2;
      var $55=(($54+256)|0);
      HEAP32[(($55)>>2)]=$53;
      var $56=$4;
      var $57=($56)*(100000);
      var $58=($57)+(0.5);
      var $59=(($58)&-1);
      var $60=$2;
      var $61=(($60+260)|0);
      HEAP32[(($61)>>2)]=$59;
      var $62=$5;
      var $63=($62)*(100000);
      var $64=($63)+(0.5);
      var $65=(($64)&-1);
      var $66=$2;
      var $67=(($66+264)|0);
      HEAP32[(($67)>>2)]=$65;
      var $68=$6;
      var $69=($68)*(100000);
      var $70=($69)+(0.5);
      var $71=(($70)&-1);
      var $72=$2;
      var $73=(($72+268)|0);
      HEAP32[(($73)>>2)]=$71;
      var $74=$7;
      var $75=($74)*(100000);
      var $76=($75)+(0.5);
      var $77=(($76)&-1);
      var $78=$2;
      var $79=(($78+272)|0);
      HEAP32[(($79)>>2)]=$77;
      var $80=$8;
      var $81=($80)*(100000);
      var $82=($81)+(0.5);
      var $83=(($82)&-1);
      var $84=$2;
      var $85=(($84+276)|0);
      HEAP32[(($85)>>2)]=$83;
      var $86=$9;
      var $87=($86)*(100000);
      var $88=($87)+(0.5);
      var $89=(($88)&-1);
      var $90=$2;
      var $91=(($90+280)|0);
      HEAP32[(($91)>>2)]=$89;
      var $92=$10;
      var $93=($92)*(100000);
      var $94=($93)+(0.5);
      var $95=(($94)&-1);
      var $96=$2;
      var $97=(($96+284)|0);
      HEAP32[(($97)>>2)]=$95;
      var $98=$2;
      var $99=(($98+8)|0);
      var $100=HEAP32[(($99)>>2)];
      var $101=$100 | 4;
      HEAP32[(($99)>>2)]=$101;
      __label__ = 6; break;
    case 6: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_png_set_cHRM["X"]=1;

function _png_read_start_row($png_ptr) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $max_pixel_depth;
      var $row_bytes;
      var $user_pixel_depth;
      $1=$png_ptr;
      var $2=$1;
      var $3=(($2+96)|0);
      var $4=(($3+4)|0);
      HEAP32[(($4)>>2)]=0;
      var $5=$1;
      _png_init_read_transformations($5);
      var $6=$1;
      var $7=(($6+271)|0);
      var $8=HEAP8[($7)];
      var $9=(($8 << 24) >> 24)!=0;
      if ($9) { __label__ = 3; break; } else { __label__ = 7; break; }
    case 3: 
      var $11=$1;
      var $12=(($11+92)|0);
      var $13=HEAP32[(($12)>>2)];
      var $14=$13 & 2;
      var $15=(($14)|0)!=0;
      if ($15) { __label__ = 5; break; } else { __label__ = 4; break; }
    case 4: 
      var $17=$1;
      var $18=(($17+184)|0);
      var $19=HEAP32[(($18)>>2)];
      var $20=HEAP32[((((_png_read_start_row_png_pass_yinc)|0))>>2)];
      var $21=((($19)+($20))|0);
      var $22=((($21)-(1))|0);
      var $23=HEAP32[((((_png_read_start_row_png_pass_ystart)|0))>>2)];
      var $24=((($22)-($23))|0);
      var $25=HEAPU32[((((_png_read_start_row_png_pass_yinc)|0))>>2)];
      var $26=Math.floor(((($24)>>>0))/((($25)>>>0)));
      var $27=$1;
      var $28=(($27+188)|0);
      HEAP32[(($28)>>2)]=$26;
      __label__ = 6; break;
    case 5: 
      var $30=$1;
      var $31=(($30+184)|0);
      var $32=HEAP32[(($31)>>2)];
      var $33=$1;
      var $34=(($33+188)|0);
      HEAP32[(($34)>>2)]=$32;
      __label__ = 6; break;
    case 6: 
      var $36=$1;
      var $37=(($36+180)|0);
      var $38=HEAP32[(($37)>>2)];
      var $39=$1;
      var $40=(($39+272)|0);
      var $41=HEAPU8[($40)];
      var $42=(($41)&255);
      var $43=((_png_read_start_row_png_pass_inc+($42<<2))|0);
      var $44=HEAP32[(($43)>>2)];
      var $45=((($38)+($44))|0);
      var $46=((($45)-(1))|0);
      var $47=$1;
      var $48=(($47+272)|0);
      var $49=HEAPU8[($48)];
      var $50=(($49)&255);
      var $51=((_png_read_start_row_png_pass_start+($50<<2))|0);
      var $52=HEAP32[(($51)>>2)];
      var $53=((($46)-($52))|0);
      var $54=$1;
      var $55=(($54+272)|0);
      var $56=HEAPU8[($55)];
      var $57=(($56)&255);
      var $58=((_png_read_start_row_png_pass_inc+($57<<2))|0);
      var $59=HEAPU32[(($58)>>2)];
      var $60=Math.floor(((($53)>>>0))/((($59)>>>0)));
      var $61=$1;
      var $62=(($61+204)|0);
      HEAP32[(($62)>>2)]=$60;
      __label__ = 8; break;
    case 7: 
      var $64=$1;
      var $65=(($64+184)|0);
      var $66=HEAP32[(($65)>>2)];
      var $67=$1;
      var $68=(($67+188)|0);
      HEAP32[(($68)>>2)]=$66;
      var $69=$1;
      var $70=(($69+180)|0);
      var $71=HEAP32[(($70)>>2)];
      var $72=$1;
      var $73=(($72+204)|0);
      HEAP32[(($73)>>2)]=$71;
      __label__ = 8; break;
    case 8: 
      var $75=$1;
      var $76=(($75+277)|0);
      var $77=HEAPU8[($76)];
      var $78=(($77)&255);
      $max_pixel_depth=$78;
      var $79=$1;
      var $80=(($79+92)|0);
      var $81=HEAP32[(($80)>>2)];
      var $82=$81 & 4;
      var $83=(($82)|0)!=0;
      if ($83) { __label__ = 9; break; } else { __label__ = 11; break; }
    case 9: 
      var $85=$1;
      var $86=(($85+275)|0);
      var $87=HEAPU8[($86)];
      var $88=(($87)&255);
      var $89=(($88)|0) < 8;
      if ($89) { __label__ = 10; break; } else { __label__ = 11; break; }
    case 10: 
      $max_pixel_depth=8;
      __label__ = 11; break;
    case 11: 
      var $92=$1;
      var $93=(($92+92)|0);
      var $94=HEAP32[(($93)>>2)];
      var $95=$94 & 4096;
      var $96=(($95)|0)!=0;
      if ($96) { __label__ = 12; break; } else { __label__ = 30; break; }
    case 12: 
      var $98=$1;
      var $99=(($98+274)|0);
      var $100=HEAPU8[($99)];
      var $101=(($100)&255);
      var $102=(($101)|0)==3;
      if ($102) { __label__ = 13; break; } else { __label__ = 17; break; }
    case 13: 
      var $104=$1;
      var $105=(($104+262)|0);
      var $106=HEAP16[(($105)>>1)];
      var $107=(($106 << 16) >> 16)!=0;
      if ($107) { __label__ = 14; break; } else { __label__ = 15; break; }
    case 14: 
      $max_pixel_depth=32;
      __label__ = 16; break;
    case 15: 
      $max_pixel_depth=24;
      __label__ = 16; break;
    case 16: 
      __label__ = 29; break;
    case 17: 
      var $112=$1;
      var $113=(($112+274)|0);
      var $114=HEAPU8[($113)];
      var $115=(($114)&255);
      var $116=(($115)|0)==0;
      if ($116) { __label__ = 18; break; } else { __label__ = 23; break; }
    case 18: 
      var $118=$max_pixel_depth;
      var $119=(($118)|0) < 8;
      if ($119) { __label__ = 19; break; } else { __label__ = 20; break; }
    case 19: 
      $max_pixel_depth=8;
      __label__ = 20; break;
    case 20: 
      var $122=$1;
      var $123=(($122+262)|0);
      var $124=HEAP16[(($123)>>1)];
      var $125=(($124 << 16) >> 16)!=0;
      if ($125) { __label__ = 21; break; } else { __label__ = 22; break; }
    case 21: 
      var $127=$max_pixel_depth;
      var $128=((($127<<1))|0);
      $max_pixel_depth=$128;
      __label__ = 22; break;
    case 22: 
      __label__ = 28; break;
    case 23: 
      var $131=$1;
      var $132=(($131+274)|0);
      var $133=HEAPU8[($132)];
      var $134=(($133)&255);
      var $135=(($134)|0)==2;
      if ($135) { __label__ = 24; break; } else { __label__ = 27; break; }
    case 24: 
      var $137=$1;
      var $138=(($137+262)|0);
      var $139=HEAP16[(($138)>>1)];
      var $140=(($139 << 16) >> 16)!=0;
      if ($140) { __label__ = 25; break; } else { __label__ = 26; break; }
    case 25: 
      var $142=$max_pixel_depth;
      var $143=((($142<<2))|0);
      $max_pixel_depth=$143;
      var $144=$max_pixel_depth;
      var $145=((((($144)|0))/(3))&-1);
      $max_pixel_depth=$145;
      __label__ = 26; break;
    case 26: 
      __label__ = 27; break;
    case 27: 
      __label__ = 28; break;
    case 28: 
      __label__ = 29; break;
    case 29: 
      __label__ = 30; break;
    case 30: 
      var $151=$1;
      var $152=(($151+92)|0);
      var $153=HEAP32[(($152)>>2)];
      var $154=$153 & 32768;
      var $155=(($154)|0)!=0;
      if ($155) { __label__ = 31; break; } else { __label__ = 46; break; }
    case 31: 
      var $157=$1;
      var $158=(($157+274)|0);
      var $159=HEAPU8[($158)];
      var $160=(($159)&255);
      var $161=(($160)|0)==3;
      if ($161) { __label__ = 32; break; } else { __label__ = 33; break; }
    case 32: 
      $max_pixel_depth=32;
      __label__ = 45; break;
    case 33: 
      var $164=$1;
      var $165=(($164+274)|0);
      var $166=HEAPU8[($165)];
      var $167=(($166)&255);
      var $168=(($167)|0)==0;
      if ($168) { __label__ = 34; break; } else { __label__ = 38; break; }
    case 34: 
      var $170=$max_pixel_depth;
      var $171=(($170)|0) <= 8;
      if ($171) { __label__ = 35; break; } else { __label__ = 36; break; }
    case 35: 
      $max_pixel_depth=16;
      __label__ = 37; break;
    case 36: 
      $max_pixel_depth=32;
      __label__ = 37; break;
    case 37: 
      __label__ = 44; break;
    case 38: 
      var $176=$1;
      var $177=(($176+274)|0);
      var $178=HEAPU8[($177)];
      var $179=(($178)&255);
      var $180=(($179)|0)==2;
      if ($180) { __label__ = 39; break; } else { __label__ = 43; break; }
    case 39: 
      var $182=$max_pixel_depth;
      var $183=(($182)|0) <= 32;
      if ($183) { __label__ = 40; break; } else { __label__ = 41; break; }
    case 40: 
      $max_pixel_depth=32;
      __label__ = 42; break;
    case 41: 
      $max_pixel_depth=64;
      __label__ = 42; break;
    case 42: 
      __label__ = 43; break;
    case 43: 
      __label__ = 44; break;
    case 44: 
      __label__ = 45; break;
    case 45: 
      __label__ = 46; break;
    case 46: 
      var $191=$1;
      var $192=(($191+92)|0);
      var $193=HEAP32[(($192)>>2)];
      var $194=$193 & 16384;
      var $195=(($194)|0)!=0;
      if ($195) { __label__ = 47; break; } else { __label__ = 66; break; }
    case 47: 
      var $197=$1;
      var $198=(($197+262)|0);
      var $199=HEAPU16[(($198)>>1)];
      var $200=(($199)&65535);
      var $201=(($200)|0)!=0;
      if ($201) { __label__ = 48; break; } else { __label__ = 49; break; }
    case 48: 
      var $203=$1;
      var $204=(($203+92)|0);
      var $205=HEAP32[(($204)>>2)];
      var $206=$205 & 4096;
      var $207=(($206)|0)!=0;
      if ($207) { __label__ = 51; break; } else { __label__ = 49; break; }
    case 49: 
      var $209=$1;
      var $210=(($209+92)|0);
      var $211=HEAP32[(($210)>>2)];
      var $212=$211 & 32768;
      var $213=(($212)|0)!=0;
      if ($213) { __label__ = 51; break; } else { __label__ = 50; break; }
    case 50: 
      var $215=$1;
      var $216=(($215+274)|0);
      var $217=HEAPU8[($216)];
      var $218=(($217)&255);
      var $219=(($218)|0)==4;
      if ($219) { __label__ = 51; break; } else { __label__ = 55; break; }
    case 51: 
      var $221=$max_pixel_depth;
      var $222=(($221)|0) <= 16;
      if ($222) { __label__ = 52; break; } else { __label__ = 53; break; }
    case 52: 
      $max_pixel_depth=32;
      __label__ = 54; break;
    case 53: 
      $max_pixel_depth=64;
      __label__ = 54; break;
    case 54: 
      __label__ = 65; break;
    case 55: 
      var $227=$max_pixel_depth;
      var $228=(($227)|0) <= 8;
      if ($228) { __label__ = 56; break; } else { __label__ = 60; break; }
    case 56: 
      var $230=$1;
      var $231=(($230+274)|0);
      var $232=HEAPU8[($231)];
      var $233=(($232)&255);
      var $234=(($233)|0)==6;
      if ($234) { __label__ = 57; break; } else { __label__ = 58; break; }
    case 57: 
      $max_pixel_depth=32;
      __label__ = 59; break;
    case 58: 
      $max_pixel_depth=24;
      __label__ = 59; break;
    case 59: 
      __label__ = 64; break;
    case 60: 
      var $239=$1;
      var $240=(($239+274)|0);
      var $241=HEAPU8[($240)];
      var $242=(($241)&255);
      var $243=(($242)|0)==6;
      if ($243) { __label__ = 61; break; } else { __label__ = 62; break; }
    case 61: 
      $max_pixel_depth=64;
      __label__ = 63; break;
    case 62: 
      $max_pixel_depth=48;
      __label__ = 63; break;
    case 63: 
      __label__ = 64; break;
    case 64: 
      __label__ = 65; break;
    case 65: 
      __label__ = 66; break;
    case 66: 
      var $250=$1;
      var $251=(($250+92)|0);
      var $252=HEAP32[(($251)>>2)];
      var $253=$252 & 1048576;
      var $254=(($253)|0)!=0;
      if ($254) { __label__ = 67; break; } else { __label__ = 70; break; }
    case 67: 
      var $256=$1;
      var $257=(($256+80)|0);
      var $258=HEAPU8[($257)];
      var $259=(($258)&255);
      var $260=$1;
      var $261=(($260+81)|0);
      var $262=HEAPU8[($261)];
      var $263=(($262)&255);
      var $264=((($259)*($263))|0);
      $user_pixel_depth=$264;
      var $265=$user_pixel_depth;
      var $266=$max_pixel_depth;
      var $267=(($265)|0) > (($266)|0);
      if ($267) { __label__ = 68; break; } else { __label__ = 69; break; }
    case 68: 
      var $269=$user_pixel_depth;
      $max_pixel_depth=$269;
      __label__ = 69; break;
    case 69: 
      __label__ = 70; break;
    case 70: 
      var $272=$1;
      var $273=(($272+180)|0);
      var $274=HEAP32[(($273)>>2)];
      var $275=((($274)+(7))|0);
      var $276=$275 & -8;
      $row_bytes=$276;
      var $277=$max_pixel_depth;
      var $278=(($277)|0) >= 8;
      if ($278) { __label__ = 71; break; } else { __label__ = 72; break; }
    case 71: 
      var $280=$row_bytes;
      var $281=$max_pixel_depth;
      var $282=$281 >>> 3;
      var $283=((($280)*($282))|0);
      var $291 = $283;__label__ = 73; break;
    case 72: 
      var $285=$row_bytes;
      var $286=$max_pixel_depth;
      var $287=((($285)*($286))|0);
      var $288=((($287)+(7))|0);
      var $289=$288 >>> 3;
      var $291 = $289;__label__ = 73; break;
    case 73: 
      var $291;
      var $292=((($291)+(1))|0);
      var $293=$max_pixel_depth;
      var $294=((($293)+(7))|0);
      var $295=$294 >> 3;
      var $296=((($292)+($295))|0);
      $row_bytes=$296;
      var $297=$row_bytes;
      var $298=((($297)+(48))|0);
      var $299=$1;
      var $300=(($299+616)|0);
      var $301=HEAPU32[(($300)>>2)];
      var $302=(($298)>>>0) > (($301)>>>0);
      if ($302) { __label__ = 74; break; } else { __label__ = 78; break; }
    case 74: 
      var $304=$1;
      var $305=$1;
      var $306=(($305+564)|0);
      var $307=HEAP32[(($306)>>2)];
      _png_free($304, $307);
      var $308=$1;
      var $309=(($308+271)|0);
      var $310=HEAP8[($309)];
      var $311=(($310 << 24) >> 24)!=0;
      if ($311) { __label__ = 75; break; } else { __label__ = 76; break; }
    case 75: 
      var $313=$1;
      var $314=$row_bytes;
      var $315=((($314)+(48))|0);
      var $316=_png_calloc($313, $315);
      var $317=$1;
      var $318=(($317+564)|0);
      HEAP32[(($318)>>2)]=$316;
      __label__ = 77; break;
    case 76: 
      var $320=$1;
      var $321=$row_bytes;
      var $322=((($321)+(48))|0);
      var $323=_png_malloc($320, $322);
      var $324=$1;
      var $325=(($324+564)|0);
      HEAP32[(($325)>>2)]=$323;
      __label__ = 77; break;
    case 77: 
      var $327=$row_bytes;
      var $328=((($327)+(48))|0);
      var $329=$1;
      var $330=(($329+616)|0);
      HEAP32[(($330)>>2)]=$328;
      var $331=$1;
      var $332=(($331+564)|0);
      var $333=HEAP32[(($332)>>2)];
      var $334=(($333+32)|0);
      var $335=$1;
      var $336=(($335+564)|0);
      var $337=HEAP32[(($336)>>2)];
      var $338=(($337)|0);
      var $339=$338;
      var $340=((($339)+(15))|0);
      var $341=((($340)>>>0))%(16);
      var $342=(((-$341))|0);
      var $343=(($334+$342)|0);
      var $344=$1;
      var $345=(($344+216)|0);
      HEAP32[(($345)>>2)]=$343;
      var $346=$row_bytes;
      var $347=((($346)+(48))|0);
      var $348=$1;
      var $349=(($348+616)|0);
      HEAP32[(($349)>>2)]=$347;
      var $350=$row_bytes;
      var $351=((($350)+(48))|0);
      var $352=$1;
      var $353=(($352+616)|0);
      HEAP32[(($353)>>2)]=$351;
      __label__ = 78; break;
    case 78: 
      var $355=$1;
      var $356=(($355+196)|0);
      var $357=HEAPU32[(($356)>>2)];
      var $358=(($357)>>>0) > 4294967294;
      if ($358) { __label__ = 79; break; } else { __label__ = 80; break; }
    case 79: 
      var $360=$1;
      _png_error($360, ((STRING_TABLE.__str139)|0));
      __label__ = 80; break;
    case 80: 
      var $362=$1;
      var $363=(($362+196)|0);
      var $364=HEAP32[(($363)>>2)];
      var $365=((($364)+(1))|0);
      var $366=$1;
      var $367=(($366+620)|0);
      var $368=HEAPU32[(($367)>>2)];
      var $369=(($365)>>>0) > (($368)>>>0);
      if ($369) { __label__ = 81; break; } else { __label__ = 82; break; }
    case 81: 
      var $371=$1;
      var $372=$1;
      var $373=(($372+212)|0);
      var $374=HEAP32[(($373)>>2)];
      _png_free($371, $374);
      var $375=$1;
      var $376=$1;
      var $377=(($376+196)|0);
      var $378=HEAP32[(($377)>>2)];
      var $379=((($378)+(1))|0);
      var $380=_png_malloc($375, $379);
      var $381=$1;
      var $382=(($381+212)|0);
      HEAP32[(($382)>>2)]=$380;
      var $383=$1;
      var $384=(($383+196)|0);
      var $385=HEAP32[(($384)>>2)];
      var $386=((($385)+(1))|0);
      var $387=$1;
      var $388=(($387+620)|0);
      HEAP32[(($388)>>2)]=$386;
      __label__ = 82; break;
    case 82: 
      var $390=$1;
      var $391=(($390+212)|0);
      var $392=HEAP32[(($391)>>2)];
      var $393=$1;
      var $394=(($393+196)|0);
      var $395=HEAP32[(($394)>>2)];
      var $396=((($395)+(1))|0);
      _memset($392, 0, $396, 1);
      var $397=$1;
      var $398=(($397+88)|0);
      var $399=HEAP32[(($398)>>2)];
      var $400=$399 | 64;
      HEAP32[(($398)>>2)]=$400;
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_png_read_start_row["X"]=1;

function _png_set_bKGD($png_ptr, $info_ptr, $background) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      $1=$png_ptr;
      $2=$info_ptr;
      $3=$background;
      var $4=$1;
      var $5=(($4)|0)==0;
      if ($5) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      var $7=$2;
      var $8=(($7)|0)==0;
      if ($8) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      __label__ = 6; break;
    case 5: 
      var $11=$2;
      var $12=(($11+90)|0);
      var $13=$12;
      var $14=$3;
      var $15=$14;
      assert(10 % 1 === 0, 'memcpy given ' + 10 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');for (var $$src = $15, $$dest = $13, $$stop = $$src + 10; $$src < $$stop; $$src++, $$dest++) {
        HEAP8[$$dest] = HEAP8[$$src]
      };
      var $16=$2;
      var $17=(($16+8)|0);
      var $18=HEAP32[(($17)>>2)];
      var $19=$18 | 32;
      HEAP32[(($17)>>2)]=$19;
      __label__ = 6; break;
    case 6: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}


function _png_set_cHRM_fixed($png_ptr, $info_ptr, $white_x, $white_y, $red_x, $red_y, $green_x, $green_y, $blue_x, $blue_y) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $5;
      var $6;
      var $7;
      var $8;
      var $9;
      var $10;
      $1=$png_ptr;
      $2=$info_ptr;
      $3=$white_x;
      $4=$white_y;
      $5=$red_x;
      $6=$red_y;
      $7=$green_x;
      $8=$green_y;
      $9=$blue_x;
      $10=$blue_y;
      var $11=$1;
      var $12=(($11)|0)==0;
      if ($12) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      var $14=$2;
      var $15=(($14)|0)==0;
      if ($15) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      __label__ = 7; break;
    case 5: 
      var $18=$1;
      var $19=$3;
      var $20=$4;
      var $21=$5;
      var $22=$6;
      var $23=$7;
      var $24=$8;
      var $25=$9;
      var $26=$10;
      var $27=_png_check_cHRM_fixed($18, $19, $20, $21, $22, $23, $24, $25, $26);
      var $28=(($27)|0)!=0;
      if ($28) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      var $30=$3;
      var $31=$2;
      var $32=(($31+256)|0);
      HEAP32[(($32)>>2)]=$30;
      var $33=$4;
      var $34=$2;
      var $35=(($34+260)|0);
      HEAP32[(($35)>>2)]=$33;
      var $36=$5;
      var $37=$2;
      var $38=(($37+264)|0);
      HEAP32[(($38)>>2)]=$36;
      var $39=$6;
      var $40=$2;
      var $41=(($40+268)|0);
      HEAP32[(($41)>>2)]=$39;
      var $42=$7;
      var $43=$2;
      var $44=(($43+272)|0);
      HEAP32[(($44)>>2)]=$42;
      var $45=$8;
      var $46=$2;
      var $47=(($46+276)|0);
      HEAP32[(($47)>>2)]=$45;
      var $48=$9;
      var $49=$2;
      var $50=(($49+280)|0);
      HEAP32[(($50)>>2)]=$48;
      var $51=$10;
      var $52=$2;
      var $53=(($52+284)|0);
      HEAP32[(($53)>>2)]=$51;
      var $54=$3;
      var $55=(($54)|0);
      var $56=($55)/(100000);
      var $57=$56;
      var $58=$2;
      var $59=(($58+128)|0);
      HEAPF32[(($59)>>2)]=$57;
      var $60=$4;
      var $61=(($60)|0);
      var $62=($61)/(100000);
      var $63=$62;
      var $64=$2;
      var $65=(($64+132)|0);
      HEAPF32[(($65)>>2)]=$63;
      var $66=$5;
      var $67=(($66)|0);
      var $68=($67)/(100000);
      var $69=$68;
      var $70=$2;
      var $71=(($70+136)|0);
      HEAPF32[(($71)>>2)]=$69;
      var $72=$6;
      var $73=(($72)|0);
      var $74=($73)/(100000);
      var $75=$74;
      var $76=$2;
      var $77=(($76+140)|0);
      HEAPF32[(($77)>>2)]=$75;
      var $78=$7;
      var $79=(($78)|0);
      var $80=($79)/(100000);
      var $81=$80;
      var $82=$2;
      var $83=(($82+144)|0);
      HEAPF32[(($83)>>2)]=$81;
      var $84=$8;
      var $85=(($84)|0);
      var $86=($85)/(100000);
      var $87=$86;
      var $88=$2;
      var $89=(($88+148)|0);
      HEAPF32[(($89)>>2)]=$87;
      var $90=$9;
      var $91=(($90)|0);
      var $92=($91)/(100000);
      var $93=$92;
      var $94=$2;
      var $95=(($94+152)|0);
      HEAPF32[(($95)>>2)]=$93;
      var $96=$10;
      var $97=(($96)|0);
      var $98=($97)/(100000);
      var $99=$98;
      var $100=$2;
      var $101=(($100+156)|0);
      HEAPF32[(($101)>>2)]=$99;
      var $102=$2;
      var $103=(($102+8)|0);
      var $104=HEAP32[(($103)>>2)];
      var $105=$104 | 4;
      HEAP32[(($103)>>2)]=$105;
      __label__ = 7; break;
    case 7: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_png_set_cHRM_fixed["X"]=1;

function _png_set_gAMA($png_ptr, $info_ptr, $file_gamma) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $png_gamma;
      $1=$png_ptr;
      $2=$info_ptr;
      $3=$file_gamma;
      var $4=$1;
      var $5=(($4)|0)==0;
      if ($5) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      var $7=$2;
      var $8=(($7)|0)==0;
      if ($8) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      __label__ = 10; break;
    case 5: 
      var $11=$3;
      var $12=$11 > 21474.83;
      if ($12) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      var $14=$1;
      _png_warning($14, ((STRING_TABLE.__str298)|0));
      $png_gamma=21474.83;
      __label__ = 8; break;
    case 7: 
      var $16=$3;
      $png_gamma=$16;
      __label__ = 8; break;
    case 8: 
      var $18=$png_gamma;
      var $19=$18;
      var $20=$2;
      var $21=(($20+40)|0);
      HEAPF32[(($21)>>2)]=$19;
      var $22=$png_gamma;
      var $23=($22)*(100000);
      var $24=($23)+(0.5);
      var $25=(($24)&-1);
      var $26=$2;
      var $27=(($26+252)|0);
      HEAP32[(($27)>>2)]=$25;
      var $28=$2;
      var $29=(($28+8)|0);
      var $30=HEAP32[(($29)>>2)];
      var $31=$30 | 1;
      HEAP32[(($29)>>2)]=$31;
      var $32=$png_gamma;
      var $33=$32 == 0;
      if ($33) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      var $35=$1;
      _png_warning($35, ((STRING_TABLE.__str1299)|0));
      __label__ = 10; break;
    case 10: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}


function _png_set_oFFs($png_ptr, $info_ptr, $offset_x, $offset_y, $unit_type) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $5;
      $1=$png_ptr;
      $2=$info_ptr;
      $3=$offset_x;
      $4=$offset_y;
      $5=$unit_type;
      var $6=$1;
      var $7=(($6)|0)==0;
      if ($7) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      var $9=$2;
      var $10=(($9)|0)==0;
      if ($10) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      __label__ = 6; break;
    case 5: 
      var $13=$3;
      var $14=$2;
      var $15=(($14+100)|0);
      HEAP32[(($15)>>2)]=$13;
      var $16=$4;
      var $17=$2;
      var $18=(($17+104)|0);
      HEAP32[(($18)>>2)]=$16;
      var $19=$5;
      var $20=(($19) & 255);
      var $21=$2;
      var $22=(($21+108)|0);
      HEAP8[($22)]=$20;
      var $23=$2;
      var $24=(($23+8)|0);
      var $25=HEAP32[(($24)>>2)];
      var $26=$25 | 256;
      HEAP32[(($24)>>2)]=$26;
      __label__ = 6; break;
    case 6: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}


function _png_set_sCAL($png_ptr, $info_ptr, $unit, $width, $height) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $5;
      $1=$png_ptr;
      $2=$info_ptr;
      $3=$unit;
      $4=$width;
      $5=$height;
      var $6=$1;
      var $7=(($6)|0)==0;
      if ($7) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      var $9=$2;
      var $10=(($9)|0)==0;
      if ($10) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      __label__ = 6; break;
    case 5: 
      var $13=$3;
      var $14=(($13) & 255);
      var $15=$2;
      var $16=(($15+220)|0);
      HEAP8[($16)]=$14;
      var $17=$4;
      var $18=$2;
      var $19=(($18+224)|0);
      (tempDoubleF64[0]=$17,HEAP32[(($19)>>2)]=tempDoubleI32[0],HEAP32[((($19)+(4))>>2)]=tempDoubleI32[1]);
      var $20=$5;
      var $21=$2;
      var $22=(($21+232)|0);
      (tempDoubleF64[0]=$20,HEAP32[(($22)>>2)]=tempDoubleI32[0],HEAP32[((($22)+(4))>>2)]=tempDoubleI32[1]);
      var $23=$2;
      var $24=(($23+8)|0);
      var $25=HEAP32[(($24)>>2)];
      var $26=$25 | 16384;
      HEAP32[(($24)>>2)]=$26;
      __label__ = 6; break;
    case 6: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}


function _png_set_pHYs($png_ptr, $info_ptr, $res_x, $res_y, $unit_type) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $5;
      $1=$png_ptr;
      $2=$info_ptr;
      $3=$res_x;
      $4=$res_y;
      $5=$unit_type;
      var $6=$1;
      var $7=(($6)|0)==0;
      if ($7) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      var $9=$2;
      var $10=(($9)|0)==0;
      if ($10) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      __label__ = 6; break;
    case 5: 
      var $13=$3;
      var $14=$2;
      var $15=(($14+112)|0);
      HEAP32[(($15)>>2)]=$13;
      var $16=$4;
      var $17=$2;
      var $18=(($17+116)|0);
      HEAP32[(($18)>>2)]=$16;
      var $19=$5;
      var $20=(($19) & 255);
      var $21=$2;
      var $22=(($21+120)|0);
      HEAP8[($22)]=$20;
      var $23=$2;
      var $24=(($23+8)|0);
      var $25=HEAP32[(($24)>>2)];
      var $26=$25 | 128;
      HEAP32[(($24)>>2)]=$26;
      __label__ = 6; break;
    case 6: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}


function _png_set_sRGB($png_ptr, $info_ptr, $intent) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      $1=$png_ptr;
      $2=$info_ptr;
      $3=$intent;
      var $4=$1;
      var $5=(($4)|0)==0;
      if ($5) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      var $7=$2;
      var $8=(($7)|0)==0;
      if ($8) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      __label__ = 6; break;
    case 5: 
      var $11=$3;
      var $12=(($11) & 255);
      var $13=$2;
      var $14=(($13+44)|0);
      HEAP8[($14)]=$12;
      var $15=$2;
      var $16=(($15+8)|0);
      var $17=HEAP32[(($16)>>2)];
      var $18=$17 | 2048;
      HEAP32[(($16)>>2)]=$18;
      __label__ = 6; break;
    case 6: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}


function _png_set_gAMA_fixed($png_ptr, $info_ptr, $int_gamma) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $png_gamma;
      $1=$png_ptr;
      $2=$info_ptr;
      $3=$int_gamma;
      var $4=$1;
      var $5=(($4)|0)==0;
      if ($5) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      var $7=$2;
      var $8=(($7)|0)==0;
      if ($8) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      __label__ = 13; break;
    case 5: 
      var $11=$3;
      var $12=(($11)|0) > 2147483647;
      if ($12) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      var $14=$1;
      _png_warning($14, ((STRING_TABLE.__str298)|0));
      $png_gamma=2147483647;
      __label__ = 11; break;
    case 7: 
      var $16=$3;
      var $17=(($16)|0) < 0;
      if ($17) { __label__ = 8; break; } else { __label__ = 9; break; }
    case 8: 
      var $19=$1;
      _png_warning($19, ((STRING_TABLE.__str2300)|0));
      $png_gamma=0;
      __label__ = 10; break;
    case 9: 
      var $21=$3;
      $png_gamma=$21;
      __label__ = 10; break;
    case 10: 
      __label__ = 11; break;
    case 11: 
      var $24=$png_gamma;
      var $25=(($24)|0);
      var $26=($25)/(100000);
      var $27=$26;
      var $28=$2;
      var $29=(($28+40)|0);
      HEAPF32[(($29)>>2)]=$27;
      var $30=$png_gamma;
      var $31=$2;
      var $32=(($31+252)|0);
      HEAP32[(($32)>>2)]=$30;
      var $33=$2;
      var $34=(($33+8)|0);
      var $35=HEAP32[(($34)>>2)];
      var $36=$35 | 1;
      HEAP32[(($34)>>2)]=$36;
      var $37=$png_gamma;
      var $38=(($37)|0)==0;
      if ($38) { __label__ = 12; break; } else { __label__ = 13; break; }
    case 12: 
      var $40=$1;
      _png_warning($40, ((STRING_TABLE.__str1299)|0));
      __label__ = 13; break;
    case 13: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_png_set_gAMA_fixed["X"]=1;

function _png_set_hIST($png_ptr, $info_ptr, $hist) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $i;
      $1=$png_ptr;
      $2=$info_ptr;
      $3=$hist;
      var $4=$1;
      var $5=(($4)|0)==0;
      if ($5) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      var $7=$2;
      var $8=(($7)|0)==0;
      if ($8) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      __label__ = 15; break;
    case 5: 
      var $11=$2;
      var $12=(($11+20)|0);
      var $13=HEAPU16[(($12)>>1)];
      var $14=(($13)&65535);
      var $15=(($14)|0)==0;
      if ($15) { __label__ = 7; break; } else { __label__ = 6; break; }
    case 6: 
      var $17=$2;
      var $18=(($17+20)|0);
      var $19=HEAPU16[(($18)>>1)];
      var $20=(($19)&65535);
      var $21=(($20)|0) > 256;
      if ($21) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $23=$1;
      _png_warning($23, ((STRING_TABLE.__str3301)|0));
      __label__ = 15; break;
    case 8: 
      var $25=$1;
      var $26=$2;
      _png_free_data($25, $26, 8, 0);
      var $27=$1;
      var $28=_png_malloc_warn($27, 512);
      var $29=$28;
      var $30=$1;
      var $31=(($30+480)|0);
      HEAP32[(($31)>>2)]=$29;
      var $32=$1;
      var $33=(($32+480)|0);
      var $34=HEAP32[(($33)>>2)];
      var $35=(($34)|0)==0;
      if ($35) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      var $37=$1;
      _png_warning($37, ((STRING_TABLE.__str4302)|0));
      __label__ = 15; break;
    case 10: 
      $i=0;
      __label__ = 11; break;
    case 11: 
      var $40=$i;
      var $41=$2;
      var $42=(($41+20)|0);
      var $43=HEAPU16[(($42)>>1)];
      var $44=(($43)&65535);
      var $45=(($40)|0) < (($44)|0);
      if ($45) { __label__ = 12; break; } else { __label__ = 14; break; }
    case 12: 
      var $47=$i;
      var $48=$3;
      var $49=(($48+($47<<1))|0);
      var $50=HEAP16[(($49)>>1)];
      var $51=$i;
      var $52=$1;
      var $53=(($52+480)|0);
      var $54=HEAP32[(($53)>>2)];
      var $55=(($54+($51<<1))|0);
      HEAP16[(($55)>>1)]=$50;
      __label__ = 13; break;
    case 13: 
      var $57=$i;
      var $58=((($57)+(1))|0);
      $i=$58;
      __label__ = 11; break;
    case 14: 
      var $60=$1;
      var $61=(($60+480)|0);
      var $62=HEAP32[(($61)>>2)];
      var $63=$2;
      var $64=(($63+124)|0);
      HEAP32[(($64)>>2)]=$62;
      var $65=$2;
      var $66=(($65+8)|0);
      var $67=HEAP32[(($66)>>2)];
      var $68=$67 | 64;
      HEAP32[(($66)>>2)]=$68;
      var $69=$2;
      var $70=(($69+184)|0);
      var $71=HEAP32[(($70)>>2)];
      var $72=$71 | 8;
      HEAP32[(($70)>>2)]=$72;
      __label__ = 15; break;
    case 15: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_png_set_hIST["X"]=1;

function _png_set_IHDR($png_ptr, $info_ptr, $width, $height, $bit_depth, $color_type, $interlace_type, $compression_type, $filter_type) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $5;
      var $6;
      var $7;
      var $8;
      var $9;
      $1=$png_ptr;
      $2=$info_ptr;
      $3=$width;
      $4=$height;
      $5=$bit_depth;
      $6=$color_type;
      $7=$interlace_type;
      $8=$compression_type;
      $9=$filter_type;
      var $10=$1;
      var $11=(($10)|0)==0;
      if ($11) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      var $13=$2;
      var $14=(($13)|0)==0;
      if ($14) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      __label__ = 19; break;
    case 5: 
      var $17=$3;
      var $18=$2;
      var $19=(($18)|0);
      HEAP32[(($19)>>2)]=$17;
      var $20=$4;
      var $21=$2;
      var $22=(($21+4)|0);
      HEAP32[(($22)>>2)]=$20;
      var $23=$5;
      var $24=(($23) & 255);
      var $25=$2;
      var $26=(($25+24)|0);
      HEAP8[($26)]=$24;
      var $27=$6;
      var $28=(($27) & 255);
      var $29=$2;
      var $30=(($29+25)|0);
      HEAP8[($30)]=$28;
      var $31=$8;
      var $32=(($31) & 255);
      var $33=$2;
      var $34=(($33+26)|0);
      HEAP8[($34)]=$32;
      var $35=$9;
      var $36=(($35) & 255);
      var $37=$2;
      var $38=(($37+27)|0);
      HEAP8[($38)]=$36;
      var $39=$7;
      var $40=(($39) & 255);
      var $41=$2;
      var $42=(($41+28)|0);
      HEAP8[($42)]=$40;
      var $43=$1;
      var $44=$2;
      var $45=(($44)|0);
      var $46=HEAP32[(($45)>>2)];
      var $47=$2;
      var $48=(($47+4)|0);
      var $49=HEAP32[(($48)>>2)];
      var $50=$2;
      var $51=(($50+24)|0);
      var $52=HEAPU8[($51)];
      var $53=(($52)&255);
      var $54=$2;
      var $55=(($54+25)|0);
      var $56=HEAPU8[($55)];
      var $57=(($56)&255);
      var $58=$2;
      var $59=(($58+28)|0);
      var $60=HEAPU8[($59)];
      var $61=(($60)&255);
      var $62=$2;
      var $63=(($62+26)|0);
      var $64=HEAPU8[($63)];
      var $65=(($64)&255);
      var $66=$2;
      var $67=(($66+27)|0);
      var $68=HEAPU8[($67)];
      var $69=(($68)&255);
      _png_check_IHDR($43, $46, $49, $53, $57, $61, $65, $69);
      var $70=$2;
      var $71=(($70+25)|0);
      var $72=HEAPU8[($71)];
      var $73=(($72)&255);
      var $74=(($73)|0)==3;
      if ($74) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      var $76=$2;
      var $77=(($76+29)|0);
      HEAP8[($77)]=1;
      __label__ = 11; break;
    case 7: 
      var $79=$2;
      var $80=(($79+25)|0);
      var $81=HEAPU8[($80)];
      var $82=(($81)&255);
      var $83=$82 & 2;
      var $84=(($83)|0)!=0;
      if ($84) { __label__ = 8; break; } else { __label__ = 9; break; }
    case 8: 
      var $86=$2;
      var $87=(($86+29)|0);
      HEAP8[($87)]=3;
      __label__ = 10; break;
    case 9: 
      var $89=$2;
      var $90=(($89+29)|0);
      HEAP8[($90)]=1;
      __label__ = 10; break;
    case 10: 
      __label__ = 11; break;
    case 11: 
      var $93=$2;
      var $94=(($93+25)|0);
      var $95=HEAPU8[($94)];
      var $96=(($95)&255);
      var $97=$96 & 4;
      var $98=(($97)|0)!=0;
      if ($98) { __label__ = 12; break; } else { __label__ = 13; break; }
    case 12: 
      var $100=$2;
      var $101=(($100+29)|0);
      var $102=HEAP8[($101)];
      var $103=((($102)+(1))&255);
      HEAP8[($101)]=$103;
      __label__ = 13; break;
    case 13: 
      var $105=$2;
      var $106=(($105+29)|0);
      var $107=HEAPU8[($106)];
      var $108=(($107)&255);
      var $109=$2;
      var $110=(($109+24)|0);
      var $111=HEAPU8[($110)];
      var $112=(($111)&255);
      var $113=((($108)*($112))|0);
      var $114=(($113) & 255);
      var $115=$2;
      var $116=(($115+30)|0);
      HEAP8[($116)]=$114;
      var $117=$3;
      var $118=(($117)>>>0) > 536870782;
      if ($118) { __label__ = 14; break; } else { __label__ = 15; break; }
    case 14: 
      var $120=$2;
      var $121=(($120+12)|0);
      HEAP32[(($121)>>2)]=0;
      __label__ = 19; break;
    case 15: 
      var $123=$2;
      var $124=(($123+30)|0);
      var $125=HEAPU8[($124)];
      var $126=(($125)&255);
      var $127=(($126)|0) >= 8;
      if ($127) { __label__ = 16; break; } else { __label__ = 17; break; }
    case 16: 
      var $129=$3;
      var $130=$2;
      var $131=(($130+30)|0);
      var $132=HEAPU8[($131)];
      var $133=(($132)&255);
      var $134=$133 >>> 3;
      var $135=((($129)*($134))|0);
      var $146 = $135;__label__ = 18; break;
    case 17: 
      var $137=$3;
      var $138=$2;
      var $139=(($138+30)|0);
      var $140=HEAPU8[($139)];
      var $141=(($140)&255);
      var $142=((($137)*($141))|0);
      var $143=((($142)+(7))|0);
      var $144=$143 >>> 3;
      var $146 = $144;__label__ = 18; break;
    case 18: 
      var $146;
      var $147=$2;
      var $148=(($147+12)|0);
      HEAP32[(($148)>>2)]=$146;
      __label__ = 19; break;
    case 19: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_png_set_IHDR["X"]=1;

function _png_set_pCAL($png_ptr, $info_ptr, $purpose, $X0, $X1, $type, $nparams, $units, $params) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $5;
      var $6;
      var $7;
      var $8;
      var $9;
      var $length;
      var $i;
      $1=$png_ptr;
      $2=$info_ptr;
      $3=$purpose;
      $4=$X0;
      $5=$X1;
      $6=$type;
      $7=$nparams;
      $8=$units;
      $9=$params;
      var $10=$1;
      var $11=(($10)|0)==0;
      if ($11) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      var $13=$2;
      var $14=(($13)|0)==0;
      if ($14) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      __label__ = 18; break;
    case 5: 
      var $17=$3;
      var $18=_strlen($17);
      var $19=((($18)+(1))|0);
      $length=$19;
      var $20=$1;
      var $21=$length;
      var $22=_png_malloc_warn($20, $21);
      var $23=$2;
      var $24=(($23+160)|0);
      HEAP32[(($24)>>2)]=$22;
      var $25=$2;
      var $26=(($25+160)|0);
      var $27=HEAP32[(($26)>>2)];
      var $28=(($27)|0)==0;
      if ($28) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      var $30=$1;
      _png_warning($30, ((STRING_TABLE.__str5303)|0));
      __label__ = 18; break;
    case 7: 
      var $32=$2;
      var $33=(($32+160)|0);
      var $34=HEAP32[(($33)>>2)];
      var $35=$3;
      var $36=$length;
      assert($36 % 1 === 0, 'memcpy given ' + $36 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');_memcpy($34, $35, $36, 1);
      var $37=$4;
      var $38=$2;
      var $39=(($38+164)|0);
      HEAP32[(($39)>>2)]=$37;
      var $40=$5;
      var $41=$2;
      var $42=(($41+168)|0);
      HEAP32[(($42)>>2)]=$40;
      var $43=$6;
      var $44=(($43) & 255);
      var $45=$2;
      var $46=(($45+180)|0);
      HEAP8[($46)]=$44;
      var $47=$7;
      var $48=(($47) & 255);
      var $49=$2;
      var $50=(($49+181)|0);
      HEAP8[($50)]=$48;
      var $51=$8;
      var $52=_strlen($51);
      var $53=((($52)+(1))|0);
      $length=$53;
      var $54=$1;
      var $55=$length;
      var $56=_png_malloc_warn($54, $55);
      var $57=$2;
      var $58=(($57+172)|0);
      HEAP32[(($58)>>2)]=$56;
      var $59=$2;
      var $60=(($59+172)|0);
      var $61=HEAP32[(($60)>>2)];
      var $62=(($61)|0)==0;
      if ($62) { __label__ = 8; break; } else { __label__ = 9; break; }
    case 8: 
      var $64=$1;
      _png_warning($64, ((STRING_TABLE.__str6304)|0));
      __label__ = 18; break;
    case 9: 
      var $66=$2;
      var $67=(($66+172)|0);
      var $68=HEAP32[(($67)>>2)];
      var $69=$8;
      var $70=$length;
      assert($70 % 1 === 0, 'memcpy given ' + $70 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');_memcpy($68, $69, $70, 1);
      var $71=$1;
      var $72=$7;
      var $73=((($72)+(1))|0);
      var $74=((($73<<2))|0);
      var $75=_png_malloc_warn($71, $74);
      var $76=$75;
      var $77=$2;
      var $78=(($77+176)|0);
      HEAP32[(($78)>>2)]=$76;
      var $79=$2;
      var $80=(($79+176)|0);
      var $81=HEAP32[(($80)>>2)];
      var $82=(($81)|0)==0;
      if ($82) { __label__ = 10; break; } else { __label__ = 11; break; }
    case 10: 
      var $84=$1;
      _png_warning($84, ((STRING_TABLE.__str7305)|0));
      __label__ = 18; break;
    case 11: 
      var $86=$2;
      var $87=(($86+176)|0);
      var $88=HEAP32[(($87)>>2)];
      var $89=$88;
      var $90=$7;
      var $91=((($90)+(1))|0);
      var $92=((($91<<2))|0);
      _memset($89, 0, $92, 1);
      $i=0;
      __label__ = 12; break;
    case 12: 
      var $94=$i;
      var $95=$7;
      var $96=(($94)|0) < (($95)|0);
      if ($96) { __label__ = 13; break; } else { __label__ = 17; break; }
    case 13: 
      var $98=$i;
      var $99=$9;
      var $100=(($99+($98<<2))|0);
      var $101=HEAP32[(($100)>>2)];
      var $102=_strlen($101);
      var $103=((($102)+(1))|0);
      $length=$103;
      var $104=$1;
      var $105=$length;
      var $106=_png_malloc_warn($104, $105);
      var $107=$i;
      var $108=$2;
      var $109=(($108+176)|0);
      var $110=HEAP32[(($109)>>2)];
      var $111=(($110+($107<<2))|0);
      HEAP32[(($111)>>2)]=$106;
      var $112=$i;
      var $113=$2;
      var $114=(($113+176)|0);
      var $115=HEAP32[(($114)>>2)];
      var $116=(($115+($112<<2))|0);
      var $117=HEAP32[(($116)>>2)];
      var $118=(($117)|0)==0;
      if ($118) { __label__ = 14; break; } else { __label__ = 15; break; }
    case 14: 
      var $120=$1;
      _png_warning($120, ((STRING_TABLE.__str8306)|0));
      __label__ = 18; break;
    case 15: 
      var $122=$i;
      var $123=$2;
      var $124=(($123+176)|0);
      var $125=HEAP32[(($124)>>2)];
      var $126=(($125+($122<<2))|0);
      var $127=HEAP32[(($126)>>2)];
      var $128=$i;
      var $129=$9;
      var $130=(($129+($128<<2))|0);
      var $131=HEAP32[(($130)>>2)];
      var $132=$length;
      assert($132 % 1 === 0, 'memcpy given ' + $132 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');_memcpy($127, $131, $132, 1);
      __label__ = 16; break;
    case 16: 
      var $134=$i;
      var $135=((($134)+(1))|0);
      $i=$135;
      __label__ = 12; break;
    case 17: 
      var $137=$2;
      var $138=(($137+8)|0);
      var $139=HEAP32[(($138)>>2)];
      var $140=$139 | 1024;
      HEAP32[(($138)>>2)]=$140;
      var $141=$2;
      var $142=(($141+184)|0);
      var $143=HEAP32[(($142)>>2)];
      var $144=$143 | 128;
      HEAP32[(($142)>>2)]=$144;
      __label__ = 18; break;
    case 18: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_png_set_pCAL["X"]=1;

function _png_set_PLTE($png_ptr, $info_ptr, $palette, $num_palette) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      $1=$png_ptr;
      $2=$info_ptr;
      $3=$palette;
      $4=$num_palette;
      var $5=$1;
      var $6=(($5)|0)==0;
      if ($6) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      var $8=$2;
      var $9=(($8)|0)==0;
      if ($9) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      __label__ = 12; break;
    case 5: 
      var $12=$4;
      var $13=(($12)|0) < 0;
      if ($13) { __label__ = 7; break; } else { __label__ = 6; break; }
    case 6: 
      var $15=$4;
      var $16=(($15)|0) > 256;
      if ($16) { __label__ = 7; break; } else { __label__ = 11; break; }
    case 7: 
      var $18=$2;
      var $19=(($18+25)|0);
      var $20=HEAPU8[($19)];
      var $21=(($20)&255);
      var $22=(($21)|0)==3;
      if ($22) { __label__ = 8; break; } else { __label__ = 9; break; }
    case 8: 
      var $24=$1;
      _png_error($24, ((STRING_TABLE.__str9307)|0));
      __label__ = 10; break;
    case 9: 
      var $26=$1;
      _png_warning($26, ((STRING_TABLE.__str9307)|0));
      __label__ = 12; break;
    case 10: 
      __label__ = 11; break;
    case 11: 
      var $29=$1;
      var $30=$2;
      _png_free_data($29, $30, 4096, 0);
      var $31=$1;
      var $32=_png_calloc($31, 768);
      var $33=$32;
      var $34=$1;
      var $35=(($34+256)|0);
      HEAP32[(($35)>>2)]=$33;
      var $36=$1;
      var $37=(($36+256)|0);
      var $38=HEAP32[(($37)>>2)];
      var $39=$38;
      var $40=$3;
      var $41=$40;
      var $42=$4;
      var $43=((($42)*(3))|0);
      assert($43 % 1 === 0, 'memcpy given ' + $43 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');_memcpy($39, $41, $43, 1);
      var $44=$1;
      var $45=(($44+256)|0);
      var $46=HEAP32[(($45)>>2)];
      var $47=$2;
      var $48=(($47+16)|0);
      HEAP32[(($48)>>2)]=$46;
      var $49=$4;
      var $50=(($49) & 65535);
      var $51=$1;
      var $52=(($51+260)|0);
      HEAP16[(($52)>>1)]=$50;
      var $53=$2;
      var $54=(($53+20)|0);
      HEAP16[(($54)>>1)]=$50;
      var $55=$2;
      var $56=(($55+184)|0);
      var $57=HEAP32[(($56)>>2)];
      var $58=$57 | 4096;
      HEAP32[(($56)>>2)]=$58;
      var $59=$2;
      var $60=(($59+8)|0);
      var $61=HEAP32[(($60)>>2)];
      var $62=$61 | 8;
      HEAP32[(($60)>>2)]=$62;
      __label__ = 12; break;
    case 12: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_png_set_PLTE["X"]=1;

function _png_set_sBIT($png_ptr, $info_ptr, $sig_bit) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      $1=$png_ptr;
      $2=$info_ptr;
      $3=$sig_bit;
      var $4=$1;
      var $5=(($4)|0)==0;
      if ($5) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      var $7=$2;
      var $8=(($7)|0)==0;
      if ($8) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      __label__ = 6; break;
    case 5: 
      var $11=$2;
      var $12=(($11+68)|0);
      var $13=$12;
      var $14=$3;
      var $15=$14;
      assert(5 % 1 === 0, 'memcpy given ' + 5 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP8[($13)]=HEAP8[($15)];HEAP8[(($13)+(1))]=HEAP8[(($15)+(1))];HEAP8[(($13)+(2))]=HEAP8[(($15)+(2))];HEAP8[(($13)+(3))]=HEAP8[(($15)+(3))];HEAP8[(($13)+(4))]=HEAP8[(($15)+(4))];
      var $16=$2;
      var $17=(($16+8)|0);
      var $18=HEAP32[(($17)>>2)];
      var $19=$18 | 2;
      HEAP32[(($17)>>2)]=$19;
      __label__ = 6; break;
    case 6: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}


function _png_set_sRGB_gAMA_and_cHRM($png_ptr, $info_ptr, $intent) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $file_gamma;
      var $int_file_gamma;
      var $white_x;
      var $white_y;
      var $red_x;
      var $red_y;
      var $green_x;
      var $green_y;
      var $blue_x;
      var $blue_y;
      var $int_white_x;
      var $int_white_y;
      var $int_red_x;
      var $int_red_y;
      var $int_green_x;
      var $int_green_y;
      var $int_blue_x;
      var $int_blue_y;
      $1=$png_ptr;
      $2=$info_ptr;
      $3=$intent;
      var $4=$1;
      var $5=(($4)|0)==0;
      if ($5) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      var $7=$2;
      var $8=(($7)|0)==0;
      if ($8) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      __label__ = 6; break;
    case 5: 
      var $11=$1;
      var $12=$2;
      var $13=$3;
      _png_set_sRGB($11, $12, $13);
      $file_gamma=0.45454999804496765;
      var $14=$1;
      var $15=$2;
      var $16=$file_gamma;
      var $17=$16;
      _png_set_gAMA($14, $15, $17);
      $int_file_gamma=45455;
      var $18=$1;
      var $19=$2;
      var $20=$int_file_gamma;
      _png_set_gAMA_fixed($18, $19, $20);
      $int_white_x=31270;
      $int_white_y=32900;
      $int_red_x=64000;
      $int_red_y=33000;
      $int_green_x=30000;
      $int_green_y=60000;
      $int_blue_x=15000;
      $int_blue_y=6000;
      $white_x=0.3127000033855438;
      $white_y=0.32899999618530273;
      $red_x=0.6399999856948853;
      $red_y=0.33000001311302185;
      $green_x=0.30000001192092896;
      $green_y=0.6000000238418579;
      $blue_x=0.15000000596046448;
      $blue_y=0.05999999865889549;
      var $21=$1;
      var $22=$2;
      var $23=$int_white_x;
      var $24=$int_white_y;
      var $25=$int_red_x;
      var $26=$int_red_y;
      var $27=$int_green_x;
      var $28=$int_green_y;
      var $29=$int_blue_x;
      var $30=$int_blue_y;
      _png_set_cHRM_fixed($21, $22, $23, $24, $25, $26, $27, $28, $29, $30);
      var $31=$1;
      var $32=$2;
      var $33=$white_x;
      var $34=$33;
      var $35=$white_y;
      var $36=$35;
      var $37=$red_x;
      var $38=$37;
      var $39=$red_y;
      var $40=$39;
      var $41=$green_x;
      var $42=$41;
      var $43=$green_y;
      var $44=$43;
      var $45=$blue_x;
      var $46=$45;
      var $47=$blue_y;
      var $48=$47;
      _png_set_cHRM($31, $32, $34, $36, $38, $40, $42, $44, $46, $48);
      __label__ = 6; break;
    case 6: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_png_set_sRGB_gAMA_and_cHRM["X"]=1;

function _png_set_iCCP($png_ptr, $info_ptr, $name, $compression_type, $profile, $proflen) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $5;
      var $6;
      var $new_iccp_name;
      var $new_iccp_profile;
      var $length;
      $1=$png_ptr;
      $2=$info_ptr;
      $3=$name;
      $4=$compression_type;
      $5=$profile;
      $6=$proflen;
      var $7=$1;
      var $8=(($7)|0)==0;
      if ($8) { __label__ = 6; break; } else { __label__ = 3; break; }
    case 3: 
      var $10=$2;
      var $11=(($10)|0)==0;
      if ($11) { __label__ = 6; break; } else { __label__ = 4; break; }
    case 4: 
      var $13=$3;
      var $14=(($13)|0)==0;
      if ($14) { __label__ = 6; break; } else { __label__ = 5; break; }
    case 5: 
      var $16=$5;
      var $17=(($16)|0)==0;
      if ($17) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      __label__ = 12; break;
    case 7: 
      var $20=$3;
      var $21=_strlen($20);
      var $22=((($21)+(1))|0);
      $length=$22;
      var $23=$1;
      var $24=$length;
      var $25=_png_malloc_warn($23, $24);
      $new_iccp_name=$25;
      var $26=$new_iccp_name;
      var $27=(($26)|0)==0;
      if ($27) { __label__ = 8; break; } else { __label__ = 9; break; }
    case 8: 
      var $29=$1;
      _png_warning($29, ((STRING_TABLE.__str10308)|0));
      __label__ = 12; break;
    case 9: 
      var $31=$new_iccp_name;
      var $32=$3;
      var $33=$length;
      assert($33 % 1 === 0, 'memcpy given ' + $33 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');_memcpy($31, $32, $33, 1);
      var $34=$1;
      var $35=$6;
      var $36=_png_malloc_warn($34, $35);
      $new_iccp_profile=$36;
      var $37=$new_iccp_profile;
      var $38=(($37)|0)==0;
      if ($38) { __label__ = 10; break; } else { __label__ = 11; break; }
    case 10: 
      var $40=$1;
      var $41=$new_iccp_name;
      _png_free($40, $41);
      var $42=$1;
      _png_warning($42, ((STRING_TABLE.__str11309)|0));
      __label__ = 12; break;
    case 11: 
      var $44=$new_iccp_profile;
      var $45=$5;
      var $46=$6;
      assert($46 % 1 === 0, 'memcpy given ' + $46 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');_memcpy($44, $45, $46, 1);
      var $47=$1;
      var $48=$2;
      _png_free_data($47, $48, 16, 0);
      var $49=$6;
      var $50=$2;
      var $51=(($50+204)|0);
      HEAP32[(($51)>>2)]=$49;
      var $52=$new_iccp_name;
      var $53=$2;
      var $54=(($53+196)|0);
      HEAP32[(($54)>>2)]=$52;
      var $55=$new_iccp_profile;
      var $56=$2;
      var $57=(($56+200)|0);
      HEAP32[(($57)>>2)]=$55;
      var $58=$4;
      var $59=(($58) & 255);
      var $60=$2;
      var $61=(($60+208)|0);
      HEAP8[($61)]=$59;
      var $62=$2;
      var $63=(($62+184)|0);
      var $64=HEAP32[(($63)>>2)];
      var $65=$64 | 16;
      HEAP32[(($63)>>2)]=$65;
      var $66=$2;
      var $67=(($66+8)|0);
      var $68=HEAP32[(($67)>>2)];
      var $69=$68 | 4096;
      HEAP32[(($67)>>2)]=$69;
      __label__ = 12; break;
    case 12: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_png_set_iCCP["X"]=1;

function _png_set_text_2($png_ptr, $info_ptr, $text_ptr, $num_text) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $5;
      var $i;
      var $old_max_text;
      var $old_num_text;
      var $old_text;
      var $text_length;
      var $key_len;
      var $lang_len;
      var $lang_key_len;
      var $textp;
      $2=$png_ptr;
      $3=$info_ptr;
      $4=$text_ptr;
      $5=$num_text;
      var $6=$2;
      var $7=(($6)|0)==0;
      if ($7) { __label__ = 5; break; } else { __label__ = 3; break; }
    case 3: 
      var $9=$3;
      var $10=(($9)|0)==0;
      if ($10) { __label__ = 5; break; } else { __label__ = 4; break; }
    case 4: 
      var $12=$5;
      var $13=(($12)|0)==0;
      if ($13) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      $1=0;
      __label__ = 51; break;
    case 6: 
      var $16=$3;
      var $17=(($16+48)|0);
      var $18=HEAP32[(($17)>>2)];
      var $19=$5;
      var $20=((($18)+($19))|0);
      var $21=$3;
      var $22=(($21+52)|0);
      var $23=HEAP32[(($22)>>2)];
      var $24=(($20)|0) > (($23)|0);
      if ($24) { __label__ = 7; break; } else { __label__ = 15; break; }
    case 7: 
      var $26=$3;
      var $27=(($26+52)|0);
      var $28=HEAP32[(($27)>>2)];
      $old_max_text=$28;
      var $29=$3;
      var $30=(($29+48)|0);
      var $31=HEAP32[(($30)>>2)];
      $old_num_text=$31;
      var $32=$3;
      var $33=(($32+56)|0);
      var $34=HEAP32[(($33)>>2)];
      var $35=(($34)|0)!=0;
      if ($35) { __label__ = 8; break; } else { __label__ = 11; break; }
    case 8: 
      var $37=$3;
      var $38=(($37+48)|0);
      var $39=HEAP32[(($38)>>2)];
      var $40=$5;
      var $41=((($39)+($40))|0);
      var $42=((($41)+(8))|0);
      var $43=$3;
      var $44=(($43+52)|0);
      HEAP32[(($44)>>2)]=$42;
      var $45=$3;
      var $46=(($45+56)|0);
      var $47=HEAP32[(($46)>>2)];
      $old_text=$47;
      var $48=$2;
      var $49=$3;
      var $50=(($49+52)|0);
      var $51=HEAP32[(($50)>>2)];
      var $52=((($51)*(28))|0);
      var $53=_png_malloc_warn($48, $52);
      var $54=$53;
      var $55=$3;
      var $56=(($55+56)|0);
      HEAP32[(($56)>>2)]=$54;
      var $57=$3;
      var $58=(($57+56)|0);
      var $59=HEAP32[(($58)>>2)];
      var $60=(($59)|0)==0;
      if ($60) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      var $62=$old_max_text;
      var $63=$3;
      var $64=(($63+52)|0);
      HEAP32[(($64)>>2)]=$62;
      var $65=$old_text;
      var $66=$3;
      var $67=(($66+56)|0);
      HEAP32[(($67)>>2)]=$65;
      $1=1;
      __label__ = 51; break;
    case 10: 
      var $69=$3;
      var $70=(($69+56)|0);
      var $71=HEAP32[(($70)>>2)];
      var $72=$71;
      var $73=$old_text;
      var $74=$73;
      var $75=$old_max_text;
      var $76=((($75)*(28))|0);
      assert($76 % 1 === 0, 'memcpy given ' + $76 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');_memcpy($72, $74, $76, 1);
      var $77=$2;
      var $78=$old_text;
      var $79=$78;
      _png_free($77, $79);
      __label__ = 14; break;
    case 11: 
      var $81=$5;
      var $82=((($81)+(8))|0);
      var $83=$3;
      var $84=(($83+52)|0);
      HEAP32[(($84)>>2)]=$82;
      var $85=$3;
      var $86=(($85+48)|0);
      HEAP32[(($86)>>2)]=0;
      var $87=$2;
      var $88=$3;
      var $89=(($88+52)|0);
      var $90=HEAP32[(($89)>>2)];
      var $91=((($90)*(28))|0);
      var $92=_png_malloc_warn($87, $91);
      var $93=$92;
      var $94=$3;
      var $95=(($94+56)|0);
      HEAP32[(($95)>>2)]=$93;
      var $96=$3;
      var $97=(($96+56)|0);
      var $98=HEAP32[(($97)>>2)];
      var $99=(($98)|0)==0;
      if ($99) { __label__ = 12; break; } else { __label__ = 13; break; }
    case 12: 
      var $101=$old_num_text;
      var $102=$3;
      var $103=(($102+48)|0);
      HEAP32[(($103)>>2)]=$101;
      var $104=$old_max_text;
      var $105=$3;
      var $106=(($105+52)|0);
      HEAP32[(($106)>>2)]=$104;
      $1=1;
      __label__ = 51; break;
    case 13: 
      var $108=$3;
      var $109=(($108+184)|0);
      var $110=HEAP32[(($109)>>2)];
      var $111=$110 | 16384;
      HEAP32[(($109)>>2)]=$111;
      __label__ = 14; break;
    case 14: 
      __label__ = 15; break;
    case 15: 
      $i=0;
      __label__ = 16; break;
    case 16: 
      var $115=$i;
      var $116=$5;
      var $117=(($115)|0) < (($116)|0);
      if ($117) { __label__ = 17; break; } else { __label__ = 50; break; }
    case 17: 
      var $119=$3;
      var $120=(($119+48)|0);
      var $121=HEAP32[(($120)>>2)];
      var $122=$3;
      var $123=(($122+56)|0);
      var $124=HEAP32[(($123)>>2)];
      var $125=(($124+($121)*(28))|0);
      $textp=$125;
      var $126=$i;
      var $127=$4;
      var $128=(($127+($126)*(28))|0);
      var $129=(($128+4)|0);
      var $130=HEAP32[(($129)>>2)];
      var $131=(($130)|0)==0;
      if ($131) { __label__ = 18; break; } else { __label__ = 19; break; }
    case 18: 
      __label__ = 49; break;
    case 19: 
      var $134=$i;
      var $135=$4;
      var $136=(($135+($134)*(28))|0);
      var $137=(($136)|0);
      var $138=HEAP32[(($137)>>2)];
      var $139=(($138)|0) < -1;
      if ($139) { __label__ = 21; break; } else { __label__ = 20; break; }
    case 20: 
      var $141=$i;
      var $142=$4;
      var $143=(($142+($141)*(28))|0);
      var $144=(($143)|0);
      var $145=HEAP32[(($144)>>2)];
      var $146=(($145)|0) >= 3;
      if ($146) { __label__ = 21; break; } else { __label__ = 22; break; }
    case 21: 
      var $148=$2;
      _png_warning($148, ((STRING_TABLE.__str13311)|0));
      __label__ = 49; break;
    case 22: 
      var $150=$i;
      var $151=$4;
      var $152=(($151+($150)*(28))|0);
      var $153=(($152+4)|0);
      var $154=HEAP32[(($153)>>2)];
      var $155=_strlen($154);
      $key_len=$155;
      var $156=$i;
      var $157=$4;
      var $158=(($157+($156)*(28))|0);
      var $159=(($158)|0);
      var $160=HEAP32[(($159)>>2)];
      var $161=(($160)|0) <= 0;
      if ($161) { __label__ = 23; break; } else { __label__ = 24; break; }
    case 23: 
      $lang_len=0;
      $lang_key_len=0;
      __label__ = 31; break;
    case 24: 
      var $164=$i;
      var $165=$4;
      var $166=(($165+($164)*(28))|0);
      var $167=(($166+20)|0);
      var $168=HEAP32[(($167)>>2)];
      var $169=(($168)|0)!=0;
      if ($169) { __label__ = 25; break; } else { __label__ = 26; break; }
    case 25: 
      var $171=$i;
      var $172=$4;
      var $173=(($172+($171)*(28))|0);
      var $174=(($173+20)|0);
      var $175=HEAP32[(($174)>>2)];
      var $176=_strlen($175);
      $lang_len=$176;
      __label__ = 27; break;
    case 26: 
      $lang_len=0;
      __label__ = 27; break;
    case 27: 
      var $179=$i;
      var $180=$4;
      var $181=(($180+($179)*(28))|0);
      var $182=(($181+24)|0);
      var $183=HEAP32[(($182)>>2)];
      var $184=(($183)|0)!=0;
      if ($184) { __label__ = 28; break; } else { __label__ = 29; break; }
    case 28: 
      var $186=$i;
      var $187=$4;
      var $188=(($187+($186)*(28))|0);
      var $189=(($188+24)|0);
      var $190=HEAP32[(($189)>>2)];
      var $191=_strlen($190);
      $lang_key_len=$191;
      __label__ = 30; break;
    case 29: 
      $lang_key_len=0;
      __label__ = 30; break;
    case 30: 
      __label__ = 31; break;
    case 31: 
      var $195=$i;
      var $196=$4;
      var $197=(($196+($195)*(28))|0);
      var $198=(($197+8)|0);
      var $199=HEAP32[(($198)>>2)];
      var $200=(($199)|0)==0;
      if ($200) { __label__ = 33; break; } else { __label__ = 32; break; }
    case 32: 
      var $202=$i;
      var $203=$4;
      var $204=(($203+($202)*(28))|0);
      var $205=(($204+8)|0);
      var $206=HEAP32[(($205)>>2)];
      var $207=(($206)|0);
      var $208=HEAP8[($207)];
      var $209=(($208 << 24) >> 24);
      var $210=(($209)|0)==0;
      if ($210) { __label__ = 33; break; } else { __label__ = 37; break; }
    case 33: 
      $text_length=0;
      var $212=$i;
      var $213=$4;
      var $214=(($213+($212)*(28))|0);
      var $215=(($214)|0);
      var $216=HEAP32[(($215)>>2)];
      var $217=(($216)|0) > 0;
      if ($217) { __label__ = 34; break; } else { __label__ = 35; break; }
    case 34: 
      var $219=$textp;
      var $220=(($219)|0);
      HEAP32[(($220)>>2)]=1;
      __label__ = 36; break;
    case 35: 
      var $222=$textp;
      var $223=(($222)|0);
      HEAP32[(($223)>>2)]=-1;
      __label__ = 36; break;
    case 36: 
      __label__ = 38; break;
    case 37: 
      var $226=$i;
      var $227=$4;
      var $228=(($227+($226)*(28))|0);
      var $229=(($228+8)|0);
      var $230=HEAP32[(($229)>>2)];
      var $231=_strlen($230);
      $text_length=$231;
      var $232=$i;
      var $233=$4;
      var $234=(($233+($232)*(28))|0);
      var $235=(($234)|0);
      var $236=HEAP32[(($235)>>2)];
      var $237=$textp;
      var $238=(($237)|0);
      HEAP32[(($238)>>2)]=$236;
      __label__ = 38; break;
    case 38: 
      var $240=$2;
      var $241=$key_len;
      var $242=$text_length;
      var $243=((($241)+($242))|0);
      var $244=$lang_len;
      var $245=((($243)+($244))|0);
      var $246=$lang_key_len;
      var $247=((($245)+($246))|0);
      var $248=((($247)+(4))|0);
      var $249=_png_malloc_warn($240, $248);
      var $250=$textp;
      var $251=(($250+4)|0);
      HEAP32[(($251)>>2)]=$249;
      var $252=$textp;
      var $253=(($252+4)|0);
      var $254=HEAP32[(($253)>>2)];
      var $255=(($254)|0)==0;
      if ($255) { __label__ = 39; break; } else { __label__ = 40; break; }
    case 39: 
      $1=1;
      __label__ = 51; break;
    case 40: 
      var $258=$textp;
      var $259=(($258+4)|0);
      var $260=HEAP32[(($259)>>2)];
      var $261=$i;
      var $262=$4;
      var $263=(($262+($261)*(28))|0);
      var $264=(($263+4)|0);
      var $265=HEAP32[(($264)>>2)];
      var $266=$key_len;
      assert($266 % 1 === 0, 'memcpy given ' + $266 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');_memcpy($260, $265, $266, 1);
      var $267=$textp;
      var $268=(($267+4)|0);
      var $269=HEAP32[(($268)>>2)];
      var $270=$key_len;
      var $271=(($269+$270)|0);
      HEAP8[($271)]=0;
      var $272=$i;
      var $273=$4;
      var $274=(($273+($272)*(28))|0);
      var $275=(($274)|0);
      var $276=HEAP32[(($275)>>2)];
      var $277=(($276)|0) > 0;
      if ($277) { __label__ = 41; break; } else { __label__ = 42; break; }
    case 41: 
      var $279=$textp;
      var $280=(($279+4)|0);
      var $281=HEAP32[(($280)>>2)];
      var $282=$key_len;
      var $283=(($281+$282)|0);
      var $284=(($283+1)|0);
      var $285=$textp;
      var $286=(($285+20)|0);
      HEAP32[(($286)>>2)]=$284;
      var $287=$textp;
      var $288=(($287+20)|0);
      var $289=HEAP32[(($288)>>2)];
      var $290=$i;
      var $291=$4;
      var $292=(($291+($290)*(28))|0);
      var $293=(($292+20)|0);
      var $294=HEAP32[(($293)>>2)];
      var $295=$lang_len;
      assert($295 % 1 === 0, 'memcpy given ' + $295 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');_memcpy($289, $294, $295, 1);
      var $296=$textp;
      var $297=(($296+20)|0);
      var $298=HEAP32[(($297)>>2)];
      var $299=$lang_len;
      var $300=(($298+$299)|0);
      HEAP8[($300)]=0;
      var $301=$textp;
      var $302=(($301+20)|0);
      var $303=HEAP32[(($302)>>2)];
      var $304=$lang_len;
      var $305=(($303+$304)|0);
      var $306=(($305+1)|0);
      var $307=$textp;
      var $308=(($307+24)|0);
      HEAP32[(($308)>>2)]=$306;
      var $309=$textp;
      var $310=(($309+24)|0);
      var $311=HEAP32[(($310)>>2)];
      var $312=$i;
      var $313=$4;
      var $314=(($313+($312)*(28))|0);
      var $315=(($314+24)|0);
      var $316=HEAP32[(($315)>>2)];
      var $317=$lang_key_len;
      assert($317 % 1 === 0, 'memcpy given ' + $317 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');_memcpy($311, $316, $317, 1);
      var $318=$textp;
      var $319=(($318+24)|0);
      var $320=HEAP32[(($319)>>2)];
      var $321=$lang_key_len;
      var $322=(($320+$321)|0);
      HEAP8[($322)]=0;
      var $323=$textp;
      var $324=(($323+24)|0);
      var $325=HEAP32[(($324)>>2)];
      var $326=$lang_key_len;
      var $327=(($325+$326)|0);
      var $328=(($327+1)|0);
      var $329=$textp;
      var $330=(($329+8)|0);
      HEAP32[(($330)>>2)]=$328;
      __label__ = 43; break;
    case 42: 
      var $332=$textp;
      var $333=(($332+20)|0);
      HEAP32[(($333)>>2)]=0;
      var $334=$textp;
      var $335=(($334+24)|0);
      HEAP32[(($335)>>2)]=0;
      var $336=$textp;
      var $337=(($336+4)|0);
      var $338=HEAP32[(($337)>>2)];
      var $339=$key_len;
      var $340=(($338+$339)|0);
      var $341=(($340+1)|0);
      var $342=$textp;
      var $343=(($342+8)|0);
      HEAP32[(($343)>>2)]=$341;
      __label__ = 43; break;
    case 43: 
      var $345=$text_length;
      var $346=(($345)|0)!=0;
      if ($346) { __label__ = 44; break; } else { __label__ = 45; break; }
    case 44: 
      var $348=$textp;
      var $349=(($348+8)|0);
      var $350=HEAP32[(($349)>>2)];
      var $351=$i;
      var $352=$4;
      var $353=(($352+($351)*(28))|0);
      var $354=(($353+8)|0);
      var $355=HEAP32[(($354)>>2)];
      var $356=$text_length;
      assert($356 % 1 === 0, 'memcpy given ' + $356 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');_memcpy($350, $355, $356, 1);
      __label__ = 45; break;
    case 45: 
      var $358=$textp;
      var $359=(($358+8)|0);
      var $360=HEAP32[(($359)>>2)];
      var $361=$text_length;
      var $362=(($360+$361)|0);
      HEAP8[($362)]=0;
      var $363=$textp;
      var $364=(($363)|0);
      var $365=HEAP32[(($364)>>2)];
      var $366=(($365)|0) > 0;
      if ($366) { __label__ = 46; break; } else { __label__ = 47; break; }
    case 46: 
      var $368=$textp;
      var $369=(($368+12)|0);
      HEAP32[(($369)>>2)]=0;
      var $370=$text_length;
      var $371=$textp;
      var $372=(($371+16)|0);
      HEAP32[(($372)>>2)]=$370;
      __label__ = 48; break;
    case 47: 
      var $374=$text_length;
      var $375=$textp;
      var $376=(($375+12)|0);
      HEAP32[(($376)>>2)]=$374;
      var $377=$textp;
      var $378=(($377+16)|0);
      HEAP32[(($378)>>2)]=0;
      __label__ = 48; break;
    case 48: 
      var $380=$3;
      var $381=(($380+48)|0);
      var $382=HEAP32[(($381)>>2)];
      var $383=((($382)+(1))|0);
      HEAP32[(($381)>>2)]=$383;
      __label__ = 49; break;
    case 49: 
      var $385=$i;
      var $386=((($385)+(1))|0);
      $i=$386;
      __label__ = 16; break;
    case 50: 
      $1=0;
      __label__ = 51; break;
    case 51: 
      var $389=$1;
      ;
      return $389;
    default: assert(0, "bad label: " + __label__);
  }
}
_png_set_text_2["X"]=1;

function _png_set_tIME($png_ptr, $info_ptr, $mod_time) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      $1=$png_ptr;
      $2=$info_ptr;
      $3=$mod_time;
      var $4=$1;
      var $5=(($4)|0)==0;
      if ($5) { __label__ = 5; break; } else { __label__ = 3; break; }
    case 3: 
      var $7=$2;
      var $8=(($7)|0)==0;
      if ($8) { __label__ = 5; break; } else { __label__ = 4; break; }
    case 4: 
      var $10=$1;
      var $11=(($10+84)|0);
      var $12=HEAP32[(($11)>>2)];
      var $13=$12 & 512;
      var $14=(($13)|0)!=0;
      if ($14) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      __label__ = 7; break;
    case 6: 
      var $17=$2;
      var $18=(($17+60)|0);
      var $19=$18;
      var $20=$3;
      var $21=$20;
      assert(8 % 1 === 0, 'memcpy given ' + 8 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP8[($19)]=HEAP8[($21)];HEAP8[(($19)+(1))]=HEAP8[(($21)+(1))];HEAP8[(($19)+(2))]=HEAP8[(($21)+(2))];HEAP8[(($19)+(3))]=HEAP8[(($21)+(3))];HEAP8[(($19)+(4))]=HEAP8[(($21)+(4))];HEAP8[(($19)+(5))]=HEAP8[(($21)+(5))];HEAP8[(($19)+(6))]=HEAP8[(($21)+(6))];HEAP8[(($19)+(7))]=HEAP8[(($21)+(7))];
      var $22=$2;
      var $23=(($22+8)|0);
      var $24=HEAP32[(($23)>>2)];
      var $25=$24 | 512;
      HEAP32[(($23)>>2)]=$25;
      __label__ = 7; break;
    case 7: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}


function _png_set_tRNS($png_ptr, $info_ptr, $trans_alpha, $num_trans, $trans_color) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $5;
      var $sample_max;
      $1=$png_ptr;
      $2=$info_ptr;
      $3=$trans_alpha;
      $4=$num_trans;
      $5=$trans_color;
      var $6=$1;
      var $7=(($6)|0)==0;
      if ($7) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      var $9=$2;
      var $10=(($9)|0)==0;
      if ($10) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      __label__ = 23; break;
    case 5: 
      var $13=$3;
      var $14=(($13)|0)!=0;
      if ($14) { __label__ = 6; break; } else { __label__ = 10; break; }
    case 6: 
      var $16=$1;
      var $17=$2;
      _png_free_data($16, $17, 8192, 0);
      var $18=$1;
      var $19=_png_malloc($18, 256);
      var $20=$2;
      var $21=(($20+76)|0);
      HEAP32[(($21)>>2)]=$19;
      var $22=$1;
      var $23=(($22+372)|0);
      HEAP32[(($23)>>2)]=$19;
      var $24=$4;
      var $25=(($24)|0) > 0;
      if ($25) { __label__ = 7; break; } else { __label__ = 9; break; }
    case 7: 
      var $27=$4;
      var $28=(($27)|0) <= 256;
      if ($28) { __label__ = 8; break; } else { __label__ = 9; break; }
    case 8: 
      var $30=$2;
      var $31=(($30+76)|0);
      var $32=HEAP32[(($31)>>2)];
      var $33=$3;
      var $34=$4;
      assert($34 % 1 === 0, 'memcpy given ' + $34 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');_memcpy($32, $33, $34, 1);
      __label__ = 9; break;
    case 9: 
      __label__ = 10; break;
    case 10: 
      var $37=$5;
      var $38=(($37)|0)!=0;
      if ($38) { __label__ = 11; break; } else { __label__ = 21; break; }
    case 11: 
      var $40=$2;
      var $41=(($40+24)|0);
      var $42=HEAPU8[($41)];
      var $43=(($42)&255);
      var $44=1 << $43;
      $sample_max=$44;
      var $45=$2;
      var $46=(($45+25)|0);
      var $47=HEAPU8[($46)];
      var $48=(($47)&255);
      var $49=(($48)|0)==0;
      if ($49) { __label__ = 12; break; } else { __label__ = 13; break; }
    case 12: 
      var $51=$5;
      var $52=(($51+8)|0);
      var $53=HEAPU16[(($52)>>1)];
      var $54=(($53)&65535);
      var $55=$sample_max;
      var $56=(($54)|0) > (($55)|0);
      if ($56) { __label__ = 17; break; } else { __label__ = 13; break; }
    case 13: 
      var $58=$2;
      var $59=(($58+25)|0);
      var $60=HEAPU8[($59)];
      var $61=(($60)&255);
      var $62=(($61)|0)==2;
      if ($62) { __label__ = 14; break; } else { __label__ = 18; break; }
    case 14: 
      var $64=$5;
      var $65=(($64+2)|0);
      var $66=HEAPU16[(($65)>>1)];
      var $67=(($66)&65535);
      var $68=$sample_max;
      var $69=(($67)|0) > (($68)|0);
      if ($69) { __label__ = 17; break; } else { __label__ = 15; break; }
    case 15: 
      var $71=$5;
      var $72=(($71+4)|0);
      var $73=HEAPU16[(($72)>>1)];
      var $74=(($73)&65535);
      var $75=$sample_max;
      var $76=(($74)|0) > (($75)|0);
      if ($76) { __label__ = 17; break; } else { __label__ = 16; break; }
    case 16: 
      var $78=$5;
      var $79=(($78+6)|0);
      var $80=HEAPU16[(($79)>>1)];
      var $81=(($80)&65535);
      var $82=$sample_max;
      var $83=(($81)|0) > (($82)|0);
      if ($83) { __label__ = 17; break; } else { __label__ = 18; break; }
    case 17: 
      var $85=$1;
      _png_warning($85, ((STRING_TABLE.__str14312)|0));
      __label__ = 18; break;
    case 18: 
      var $87=$2;
      var $88=(($87+80)|0);
      var $89=$88;
      var $90=$5;
      var $91=$90;
      assert(10 % 1 === 0, 'memcpy given ' + 10 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');for (var $$src = $91, $$dest = $89, $$stop = $$src + 10; $$src < $$stop; $$src++, $$dest++) {
        HEAP8[$$dest] = HEAP8[$$src]
      };
      var $92=$4;
      var $93=(($92)|0)==0;
      if ($93) { __label__ = 19; break; } else { __label__ = 20; break; }
    case 19: 
      $4=1;
      __label__ = 20; break;
    case 20: 
      __label__ = 21; break;
    case 21: 
      var $97=$4;
      var $98=(($97) & 65535);
      var $99=$2;
      var $100=(($99+22)|0);
      HEAP16[(($100)>>1)]=$98;
      var $101=$4;
      var $102=(($101)|0)!=0;
      if ($102) { __label__ = 22; break; } else { __label__ = 23; break; }
    case 22: 
      var $104=$2;
      var $105=(($104+8)|0);
      var $106=HEAP32[(($105)>>2)];
      var $107=$106 | 16;
      HEAP32[(($105)>>2)]=$107;
      var $108=$2;
      var $109=(($108+184)|0);
      var $110=HEAP32[(($109)>>2)];
      var $111=$110 | 8192;
      HEAP32[(($109)>>2)]=$111;
      __label__ = 23; break;
    case 23: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_png_set_tRNS["X"]=1;

function _png_set_interlace_handling($png_ptr) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      $2=$png_ptr;
      var $3=$2;
      var $4=(($3)|0)!=0;
      if ($4) { __label__ = 3; break; } else { __label__ = 5; break; }
    case 3: 
      var $6=$2;
      var $7=(($6+271)|0);
      var $8=HEAPU8[($7)];
      var $9=(($8)&255);
      var $10=(($9)|0)!=0;
      if ($10) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      var $12=$2;
      var $13=(($12+92)|0);
      var $14=HEAP32[(($13)>>2)];
      var $15=$14 | 2;
      HEAP32[(($13)>>2)]=$15;
      $1=7;
      __label__ = 6; break;
    case 5: 
      $1=1;
      __label__ = 6; break;
    case 6: 
      var $18=$1;
      ;
      return $18;
    default: assert(0, "bad label: " + __label__);
  }
}


function _png_do_invert($row_info, $row) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $rp;
      var $i;
      var $istop;
      var $rp1;
      var $i2;
      var $istop3;
      var $rp4;
      var $i5;
      var $istop6;
      $1=$row_info;
      $2=$row;
      var $3=$1;
      var $4=(($3+8)|0);
      var $5=HEAPU8[($4)];
      var $6=(($5)&255);
      var $7=(($6)|0)==0;
      if ($7) { __label__ = 3; break; } else { __label__ = 8; break; }
    case 3: 
      var $9=$2;
      $rp=$9;
      var $10=$1;
      var $11=(($10+4)|0);
      var $12=HEAP32[(($11)>>2)];
      $istop=$12;
      $i=0;
      __label__ = 4; break;
    case 4: 
      var $14=$i;
      var $15=$istop;
      var $16=(($14)>>>0) < (($15)>>>0);
      if ($16) { __label__ = 5; break; } else { __label__ = 7; break; }
    case 5: 
      var $18=$rp;
      var $19=HEAPU8[($18)];
      var $20=(($19)&255);
      var $21=$20 ^ -1;
      var $22=(($21) & 255);
      var $23=$rp;
      HEAP8[($23)]=$22;
      var $24=$rp;
      var $25=(($24+1)|0);
      $rp=$25;
      __label__ = 6; break;
    case 6: 
      var $27=$i;
      var $28=((($27)+(1))|0);
      $i=$28;
      __label__ = 4; break;
    case 7: 
      __label__ = 24; break;
    case 8: 
      var $31=$1;
      var $32=(($31+8)|0);
      var $33=HEAPU8[($32)];
      var $34=(($33)&255);
      var $35=(($34)|0)==4;
      if ($35) { __label__ = 9; break; } else { __label__ = 15; break; }
    case 9: 
      var $37=$1;
      var $38=(($37+9)|0);
      var $39=HEAPU8[($38)];
      var $40=(($39)&255);
      var $41=(($40)|0)==8;
      if ($41) { __label__ = 10; break; } else { __label__ = 15; break; }
    case 10: 
      var $43=$2;
      $rp1=$43;
      var $44=$1;
      var $45=(($44+4)|0);
      var $46=HEAP32[(($45)>>2)];
      $istop3=$46;
      $i2=0;
      __label__ = 11; break;
    case 11: 
      var $48=$i2;
      var $49=$istop3;
      var $50=(($48)>>>0) < (($49)>>>0);
      if ($50) { __label__ = 12; break; } else { __label__ = 14; break; }
    case 12: 
      var $52=$rp1;
      var $53=HEAPU8[($52)];
      var $54=(($53)&255);
      var $55=$54 ^ -1;
      var $56=(($55) & 255);
      var $57=$rp1;
      HEAP8[($57)]=$56;
      var $58=$rp1;
      var $59=(($58+2)|0);
      $rp1=$59;
      __label__ = 13; break;
    case 13: 
      var $61=$i2;
      var $62=((($61)+(2))|0);
      $i2=$62;
      __label__ = 11; break;
    case 14: 
      __label__ = 23; break;
    case 15: 
      var $65=$1;
      var $66=(($65+8)|0);
      var $67=HEAPU8[($66)];
      var $68=(($67)&255);
      var $69=(($68)|0)==4;
      if ($69) { __label__ = 16; break; } else { __label__ = 22; break; }
    case 16: 
      var $71=$1;
      var $72=(($71+9)|0);
      var $73=HEAPU8[($72)];
      var $74=(($73)&255);
      var $75=(($74)|0)==16;
      if ($75) { __label__ = 17; break; } else { __label__ = 22; break; }
    case 17: 
      var $77=$2;
      $rp4=$77;
      var $78=$1;
      var $79=(($78+4)|0);
      var $80=HEAP32[(($79)>>2)];
      $istop6=$80;
      $i5=0;
      __label__ = 18; break;
    case 18: 
      var $82=$i5;
      var $83=$istop6;
      var $84=(($82)>>>0) < (($83)>>>0);
      if ($84) { __label__ = 19; break; } else { __label__ = 21; break; }
    case 19: 
      var $86=$rp4;
      var $87=HEAPU8[($86)];
      var $88=(($87)&255);
      var $89=$88 ^ -1;
      var $90=(($89) & 255);
      var $91=$rp4;
      HEAP8[($91)]=$90;
      var $92=$rp4;
      var $93=(($92+1)|0);
      var $94=HEAPU8[($93)];
      var $95=(($94)&255);
      var $96=$95 ^ -1;
      var $97=(($96) & 255);
      var $98=$rp4;
      var $99=(($98+1)|0);
      HEAP8[($99)]=$97;
      var $100=$rp4;
      var $101=(($100+4)|0);
      $rp4=$101;
      __label__ = 20; break;
    case 20: 
      var $103=$i5;
      var $104=((($103)+(4))|0);
      $i5=$104;
      __label__ = 18; break;
    case 21: 
      __label__ = 22; break;
    case 22: 
      __label__ = 23; break;
    case 23: 
      __label__ = 24; break;
    case 24: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_png_do_invert["X"]=1;

function _png_do_swap($row_info, $row) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $rp;
      var $i;
      var $istop;
      var $t;
      $1=$row_info;
      $2=$row;
      var $3=$1;
      var $4=(($3+9)|0);
      var $5=HEAPU8[($4)];
      var $6=(($5)&255);
      var $7=(($6)|0)==16;
      if ($7) { __label__ = 3; break; } else { __label__ = 8; break; }
    case 3: 
      var $9=$2;
      $rp=$9;
      var $10=$1;
      var $11=(($10)|0);
      var $12=HEAP32[(($11)>>2)];
      var $13=$1;
      var $14=(($13+10)|0);
      var $15=HEAPU8[($14)];
      var $16=(($15)&255);
      var $17=((($12)*($16))|0);
      $istop=$17;
      $i=0;
      __label__ = 4; break;
    case 4: 
      var $19=$i;
      var $20=$istop;
      var $21=(($19)>>>0) < (($20)>>>0);
      if ($21) { __label__ = 5; break; } else { __label__ = 7; break; }
    case 5: 
      var $23=$rp;
      var $24=HEAP8[($23)];
      $t=$24;
      var $25=$rp;
      var $26=(($25+1)|0);
      var $27=HEAP8[($26)];
      var $28=$rp;
      HEAP8[($28)]=$27;
      var $29=$t;
      var $30=$rp;
      var $31=(($30+1)|0);
      HEAP8[($31)]=$29;
      __label__ = 6; break;
    case 6: 
      var $33=$i;
      var $34=((($33)+(1))|0);
      $i=$34;
      var $35=$rp;
      var $36=(($35+2)|0);
      $rp=$36;
      __label__ = 4; break;
    case 7: 
      __label__ = 8; break;
    case 8: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_png_do_swap["X"]=1;

function _png_do_packswap($row_info, $row) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $rp;
      var $end;
      var $table;
      $1=$row_info;
      $2=$row;
      var $3=$1;
      var $4=(($3+9)|0);
      var $5=HEAPU8[($4)];
      var $6=(($5)&255);
      var $7=(($6)|0) < 8;
      if ($7) { __label__ = 3; break; } else { __label__ = 17; break; }
    case 3: 
      var $9=$2;
      var $10=$1;
      var $11=(($10+4)|0);
      var $12=HEAP32[(($11)>>2)];
      var $13=(($9+$12)|0);
      $end=$13;
      var $14=$1;
      var $15=(($14+9)|0);
      var $16=HEAPU8[($15)];
      var $17=(($16)&255);
      var $18=(($17)|0)==1;
      if ($18) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      $table=((STRING_TABLE._onebppswaptable)|0);
      __label__ = 12; break;
    case 5: 
      var $21=$1;
      var $22=(($21+9)|0);
      var $23=HEAPU8[($22)];
      var $24=(($23)&255);
      var $25=(($24)|0)==2;
      if ($25) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      $table=((STRING_TABLE._twobppswaptable)|0);
      __label__ = 11; break;
    case 7: 
      var $28=$1;
      var $29=(($28+9)|0);
      var $30=HEAPU8[($29)];
      var $31=(($30)&255);
      var $32=(($31)|0)==4;
      if ($32) { __label__ = 8; break; } else { __label__ = 9; break; }
    case 8: 
      $table=((STRING_TABLE._fourbppswaptable)|0);
      __label__ = 10; break;
    case 9: 
      __label__ = 17; break;
    case 10: 
      __label__ = 11; break;
    case 11: 
      __label__ = 12; break;
    case 12: 
      var $38=$2;
      $rp=$38;
      __label__ = 13; break;
    case 13: 
      var $40=$rp;
      var $41=$end;
      var $42=(($40)>>>0) < (($41)>>>0);
      if ($42) { __label__ = 14; break; } else { __label__ = 16; break; }
    case 14: 
      var $44=$rp;
      var $45=HEAPU8[($44)];
      var $46=(($45)&255);
      var $47=$table;
      var $48=(($47+$46)|0);
      var $49=HEAP8[($48)];
      var $50=$rp;
      HEAP8[($50)]=$49;
      __label__ = 15; break;
    case 15: 
      var $52=$rp;
      var $53=(($52+1)|0);
      $rp=$53;
      __label__ = 13; break;
    case 16: 
      __label__ = 17; break;
    case 17: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_png_do_packswap["X"]=1;

function _png_set_sPLT($png_ptr, $info_ptr, $entries, $nentries) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $np;
      var $i;
      var $to;
      var $from;
      var $length;
      $1=$png_ptr;
      $2=$info_ptr;
      $3=$entries;
      $4=$nentries;
      var $5=$1;
      var $6=(($5)|0)==0;
      if ($6) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      var $8=$2;
      var $9=(($8)|0)==0;
      if ($9) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      __label__ = 16; break;
    case 5: 
      var $12=$1;
      var $13=$2;
      var $14=(($13+216)|0);
      var $15=HEAP32[(($14)>>2)];
      var $16=$4;
      var $17=((($15)+($16))|0);
      var $18=((($17<<4))|0);
      var $19=_png_malloc_warn($12, $18);
      var $20=$19;
      $np=$20;
      var $21=$np;
      var $22=(($21)|0)==0;
      if ($22) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      var $24=$1;
      _png_warning($24, ((STRING_TABLE.__str15313)|0));
      __label__ = 16; break;
    case 7: 
      var $26=$np;
      var $27=$26;
      var $28=$2;
      var $29=(($28+212)|0);
      var $30=HEAP32[(($29)>>2)];
      var $31=$30;
      var $32=$2;
      var $33=(($32+216)|0);
      var $34=HEAP32[(($33)>>2)];
      var $35=((($34<<4))|0);
      assert($35 % 1 === 0, 'memcpy given ' + $35 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');_memcpy($27, $31, $35, 1);
      var $36=$1;
      var $37=$2;
      var $38=(($37+212)|0);
      var $39=HEAP32[(($38)>>2)];
      var $40=$39;
      _png_free($36, $40);
      var $41=$2;
      var $42=(($41+212)|0);
      HEAP32[(($42)>>2)]=0;
      $i=0;
      __label__ = 8; break;
    case 8: 
      var $44=$i;
      var $45=$4;
      var $46=(($44)|0) < (($45)|0);
      if ($46) { __label__ = 9; break; } else { __label__ = 15; break; }
    case 9: 
      var $48=$np;
      var $49=$2;
      var $50=(($49+216)|0);
      var $51=HEAP32[(($50)>>2)];
      var $52=(($48+($51<<4))|0);
      var $53=$i;
      var $54=(($52+($53<<4))|0);
      $to=$54;
      var $55=$3;
      var $56=$i;
      var $57=(($55+($56<<4))|0);
      $from=$57;
      var $58=$from;
      var $59=(($58)|0);
      var $60=HEAP32[(($59)>>2)];
      var $61=_strlen($60);
      var $62=((($61)+(1))|0);
      $length=$62;
      var $63=$1;
      var $64=$length;
      var $65=_png_malloc_warn($63, $64);
      var $66=$to;
      var $67=(($66)|0);
      HEAP32[(($67)>>2)]=$65;
      var $68=$to;
      var $69=(($68)|0);
      var $70=HEAP32[(($69)>>2)];
      var $71=(($70)|0)==0;
      if ($71) { __label__ = 10; break; } else { __label__ = 11; break; }
    case 10: 
      var $73=$1;
      _png_warning($73, ((STRING_TABLE.__str16314)|0));
      __label__ = 14; break;
    case 11: 
      var $75=$to;
      var $76=(($75)|0);
      var $77=HEAP32[(($76)>>2)];
      var $78=$from;
      var $79=(($78)|0);
      var $80=HEAP32[(($79)>>2)];
      var $81=$length;
      assert($81 % 1 === 0, 'memcpy given ' + $81 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');_memcpy($77, $80, $81, 1);
      var $82=$1;
      var $83=$from;
      var $84=(($83+12)|0);
      var $85=HEAP32[(($84)>>2)];
      var $86=((($85)*(10))|0);
      var $87=_png_malloc_warn($82, $86);
      var $88=$87;
      var $89=$to;
      var $90=(($89+8)|0);
      HEAP32[(($90)>>2)]=$88;
      var $91=$to;
      var $92=(($91+8)|0);
      var $93=HEAP32[(($92)>>2)];
      var $94=(($93)|0)==0;
      if ($94) { __label__ = 12; break; } else { __label__ = 13; break; }
    case 12: 
      var $96=$1;
      _png_warning($96, ((STRING_TABLE.__str16314)|0));
      var $97=$1;
      var $98=$to;
      var $99=(($98)|0);
      var $100=HEAP32[(($99)>>2)];
      _png_free($97, $100);
      var $101=$to;
      var $102=(($101)|0);
      HEAP32[(($102)>>2)]=0;
      __label__ = 14; break;
    case 13: 
      var $104=$to;
      var $105=(($104+8)|0);
      var $106=HEAP32[(($105)>>2)];
      var $107=$106;
      var $108=$from;
      var $109=(($108+8)|0);
      var $110=HEAP32[(($109)>>2)];
      var $111=$110;
      var $112=$from;
      var $113=(($112+12)|0);
      var $114=HEAP32[(($113)>>2)];
      var $115=((($114)*(10))|0);
      assert($115 % 1 === 0, 'memcpy given ' + $115 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');_memcpy($107, $111, $115, 1);
      var $116=$from;
      var $117=(($116+12)|0);
      var $118=HEAP32[(($117)>>2)];
      var $119=$to;
      var $120=(($119+12)|0);
      HEAP32[(($120)>>2)]=$118;
      var $121=$from;
      var $122=(($121+4)|0);
      var $123=HEAP8[($122)];
      var $124=$to;
      var $125=(($124+4)|0);
      HEAP8[($125)]=$123;
      __label__ = 14; break;
    case 14: 
      var $127=$i;
      var $128=((($127)+(1))|0);
      $i=$128;
      __label__ = 8; break;
    case 15: 
      var $130=$np;
      var $131=$2;
      var $132=(($131+212)|0);
      HEAP32[(($132)>>2)]=$130;
      var $133=$4;
      var $134=$2;
      var $135=(($134+216)|0);
      var $136=HEAP32[(($135)>>2)];
      var $137=((($136)+($133))|0);
      HEAP32[(($135)>>2)]=$137;
      var $138=$2;
      var $139=(($138+8)|0);
      var $140=HEAP32[(($139)>>2)];
      var $141=$140 | 8192;
      HEAP32[(($139)>>2)]=$141;
      var $142=$2;
      var $143=(($142+184)|0);
      var $144=HEAP32[(($143)>>2)];
      var $145=$144 | 32;
      HEAP32[(($143)>>2)]=$145;
      __label__ = 16; break;
    case 16: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_png_set_sPLT["X"]=1;

function _png_set_unknown_chunks($png_ptr, $info_ptr, $unknowns, $num_unknowns) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $np;
      var $i;
      var $to;
      var $from;
      $1=$png_ptr;
      $2=$info_ptr;
      $3=$unknowns;
      $4=$num_unknowns;
      var $5=$1;
      var $6=(($5)|0)==0;
      if ($6) { __label__ = 5; break; } else { __label__ = 3; break; }
    case 3: 
      var $8=$2;
      var $9=(($8)|0)==0;
      if ($9) { __label__ = 5; break; } else { __label__ = 4; break; }
    case 4: 
      var $11=$4;
      var $12=(($11)|0)==0;
      if ($12) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      __label__ = 19; break;
    case 6: 
      var $15=$1;
      var $16=$2;
      var $17=(($16+192)|0);
      var $18=HEAP32[(($17)>>2)];
      var $19=$4;
      var $20=((($18)+($19))|0);
      var $21=((($20)*(20))|0);
      var $22=_png_malloc_warn($15, $21);
      var $23=$22;
      $np=$23;
      var $24=$np;
      var $25=(($24)|0)==0;
      if ($25) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $27=$1;
      _png_warning($27, ((STRING_TABLE.__str17315)|0));
      __label__ = 19; break;
    case 8: 
      var $29=$np;
      var $30=$29;
      var $31=$2;
      var $32=(($31+188)|0);
      var $33=HEAP32[(($32)>>2)];
      var $34=$33;
      var $35=$2;
      var $36=(($35+192)|0);
      var $37=HEAP32[(($36)>>2)];
      var $38=((($37)*(20))|0);
      assert($38 % 1 === 0, 'memcpy given ' + $38 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');_memcpy($30, $34, $38, 1);
      var $39=$1;
      var $40=$2;
      var $41=(($40+188)|0);
      var $42=HEAP32[(($41)>>2)];
      var $43=$42;
      _png_free($39, $43);
      var $44=$2;
      var $45=(($44+188)|0);
      HEAP32[(($45)>>2)]=0;
      $i=0;
      __label__ = 9; break;
    case 9: 
      var $47=$i;
      var $48=$4;
      var $49=(($47)|0) < (($48)|0);
      if ($49) { __label__ = 10; break; } else { __label__ = 18; break; }
    case 10: 
      var $51=$np;
      var $52=$2;
      var $53=(($52+192)|0);
      var $54=HEAP32[(($53)>>2)];
      var $55=(($51+($54)*(20))|0);
      var $56=$i;
      var $57=(($55+($56)*(20))|0);
      $to=$57;
      var $58=$3;
      var $59=$i;
      var $60=(($58+($59)*(20))|0);
      $from=$60;
      var $61=$to;
      var $62=(($61)|0);
      var $63=(($62)|0);
      var $64=$from;
      var $65=(($64)|0);
      var $66=(($65)|0);
      assert(5 % 1 === 0, 'memcpy given ' + 5 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP8[($63)]=HEAP8[($66)];HEAP8[(($63)+(1))]=HEAP8[(($66)+(1))];HEAP8[(($63)+(2))]=HEAP8[(($66)+(2))];HEAP8[(($63)+(3))]=HEAP8[(($66)+(3))];HEAP8[(($63)+(4))]=HEAP8[(($66)+(4))];
      var $67=$to;
      var $68=(($67)|0);
      var $69=(($68+4)|0);
      HEAP8[($69)]=0;
      var $70=$from;
      var $71=(($70+12)|0);
      var $72=HEAP32[(($71)>>2)];
      var $73=$to;
      var $74=(($73+12)|0);
      HEAP32[(($74)>>2)]=$72;
      var $75=$1;
      var $76=(($75+84)|0);
      var $77=HEAP32[(($76)>>2)];
      var $78=$77 & 255;
      var $79=(($78) & 255);
      var $80=$to;
      var $81=(($80+16)|0);
      HEAP8[($81)]=$79;
      var $82=$from;
      var $83=(($82+12)|0);
      var $84=HEAP32[(($83)>>2)];
      var $85=(($84)|0)==0;
      if ($85) { __label__ = 11; break; } else { __label__ = 12; break; }
    case 11: 
      var $87=$to;
      var $88=(($87+8)|0);
      HEAP32[(($88)>>2)]=0;
      __label__ = 16; break;
    case 12: 
      var $90=$1;
      var $91=$from;
      var $92=(($91+12)|0);
      var $93=HEAP32[(($92)>>2)];
      var $94=_png_malloc_warn($90, $93);
      var $95=$to;
      var $96=(($95+8)|0);
      HEAP32[(($96)>>2)]=$94;
      var $97=$to;
      var $98=(($97+8)|0);
      var $99=HEAP32[(($98)>>2)];
      var $100=(($99)|0)==0;
      if ($100) { __label__ = 13; break; } else { __label__ = 14; break; }
    case 13: 
      var $102=$1;
      _png_warning($102, ((STRING_TABLE.__str17315)|0));
      var $103=$to;
      var $104=(($103+12)|0);
      HEAP32[(($104)>>2)]=0;
      __label__ = 15; break;
    case 14: 
      var $106=$to;
      var $107=(($106+8)|0);
      var $108=HEAP32[(($107)>>2)];
      var $109=$from;
      var $110=(($109+8)|0);
      var $111=HEAP32[(($110)>>2)];
      var $112=$from;
      var $113=(($112+12)|0);
      var $114=HEAP32[(($113)>>2)];
      assert($114 % 1 === 0, 'memcpy given ' + $114 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');_memcpy($108, $111, $114, 1);
      __label__ = 15; break;
    case 15: 
      __label__ = 16; break;
    case 16: 
      __label__ = 17; break;
    case 17: 
      var $118=$i;
      var $119=((($118)+(1))|0);
      $i=$119;
      __label__ = 9; break;
    case 18: 
      var $121=$np;
      var $122=$2;
      var $123=(($122+188)|0);
      HEAP32[(($123)>>2)]=$121;
      var $124=$4;
      var $125=$2;
      var $126=(($125+192)|0);
      var $127=HEAP32[(($126)>>2)];
      var $128=((($127)+($124))|0);
      HEAP32[(($126)>>2)]=$128;
      var $129=$2;
      var $130=(($129+184)|0);
      var $131=HEAP32[(($130)>>2)];
      var $132=$131 | 512;
      HEAP32[(($130)>>2)]=$132;
      __label__ = 19; break;
    case 19: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_png_set_unknown_chunks["X"]=1;

function _png_do_strip_filler($row_info, $row, $flags) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $sp;
      var $dp;
      var $row_width;
      var $i;
      $1=$row_info;
      $2=$row;
      $3=$flags;
      var $4=$2;
      $sp=$4;
      var $5=$2;
      $dp=$5;
      var $6=$1;
      var $7=(($6)|0);
      var $8=HEAP32[(($7)>>2)];
      $row_width=$8;
      var $9=$1;
      var $10=(($9+8)|0);
      var $11=HEAPU8[($10)];
      var $12=(($11)&255);
      var $13=(($12)|0)==2;
      if ($13) { __label__ = 5; break; } else { __label__ = 3; break; }
    case 3: 
      var $15=$1;
      var $16=(($15+8)|0);
      var $17=HEAPU8[($16)];
      var $18=(($17)&255);
      var $19=(($18)|0)==6;
      if ($19) { __label__ = 4; break; } else { __label__ = 32; break; }
    case 4: 
      var $21=$3;
      var $22=$21 & 4194304;
      var $23=(($22)|0)!=0;
      if ($23) { __label__ = 5; break; } else { __label__ = 32; break; }
    case 5: 
      var $25=$1;
      var $26=(($25+10)|0);
      var $27=HEAPU8[($26)];
      var $28=(($27)&255);
      var $29=(($28)|0)==4;
      if ($29) { __label__ = 6; break; } else { __label__ = 32; break; }
    case 6: 
      var $31=$1;
      var $32=(($31+9)|0);
      var $33=HEAPU8[($32)];
      var $34=(($33)&255);
      var $35=(($34)|0)==8;
      if ($35) { __label__ = 7; break; } else { __label__ = 19; break; }
    case 7: 
      var $37=$3;
      var $38=$37 & 128;
      var $39=(($38)|0)!=0;
      if ($39) { __label__ = 8; break; } else { __label__ = 13; break; }
    case 8: 
      var $41=$dp;
      var $42=(($41+3)|0);
      $dp=$42;
      var $43=$sp;
      var $44=(($43+4)|0);
      $sp=$44;
      $i=1;
      __label__ = 9; break;
    case 9: 
      var $46=$i;
      var $47=$row_width;
      var $48=(($46)>>>0) < (($47)>>>0);
      if ($48) { __label__ = 10; break; } else { __label__ = 12; break; }
    case 10: 
      var $50=$sp;
      var $51=(($50+1)|0);
      $sp=$51;
      var $52=HEAP8[($50)];
      var $53=$dp;
      var $54=(($53+1)|0);
      $dp=$54;
      HEAP8[($53)]=$52;
      var $55=$sp;
      var $56=(($55+1)|0);
      $sp=$56;
      var $57=HEAP8[($55)];
      var $58=$dp;
      var $59=(($58+1)|0);
      $dp=$59;
      HEAP8[($58)]=$57;
      var $60=$sp;
      var $61=(($60+1)|0);
      $sp=$61;
      var $62=HEAP8[($60)];
      var $63=$dp;
      var $64=(($63+1)|0);
      $dp=$64;
      HEAP8[($63)]=$62;
      var $65=$sp;
      var $66=(($65+1)|0);
      $sp=$66;
      __label__ = 11; break;
    case 11: 
      var $68=$i;
      var $69=((($68)+(1))|0);
      $i=$69;
      __label__ = 9; break;
    case 12: 
      __label__ = 18; break;
    case 13: 
      $i=0;
      __label__ = 14; break;
    case 14: 
      var $73=$i;
      var $74=$row_width;
      var $75=(($73)>>>0) < (($74)>>>0);
      if ($75) { __label__ = 15; break; } else { __label__ = 17; break; }
    case 15: 
      var $77=$sp;
      var $78=(($77+1)|0);
      $sp=$78;
      var $79=$sp;
      var $80=(($79+1)|0);
      $sp=$80;
      var $81=HEAP8[($79)];
      var $82=$dp;
      var $83=(($82+1)|0);
      $dp=$83;
      HEAP8[($82)]=$81;
      var $84=$sp;
      var $85=(($84+1)|0);
      $sp=$85;
      var $86=HEAP8[($84)];
      var $87=$dp;
      var $88=(($87+1)|0);
      $dp=$88;
      HEAP8[($87)]=$86;
      var $89=$sp;
      var $90=(($89+1)|0);
      $sp=$90;
      var $91=HEAP8[($89)];
      var $92=$dp;
      var $93=(($92+1)|0);
      $dp=$93;
      HEAP8[($92)]=$91;
      __label__ = 16; break;
    case 16: 
      var $95=$i;
      var $96=((($95)+(1))|0);
      $i=$96;
      __label__ = 14; break;
    case 17: 
      __label__ = 18; break;
    case 18: 
      var $99=$1;
      var $100=(($99+11)|0);
      HEAP8[($100)]=24;
      var $101=$row_width;
      var $102=((($101)*(3))|0);
      var $103=$1;
      var $104=(($103+4)|0);
      HEAP32[(($104)>>2)]=$102;
      __label__ = 31; break;
    case 19: 
      var $106=$3;
      var $107=$106 & 128;
      var $108=(($107)|0)!=0;
      if ($108) { __label__ = 20; break; } else { __label__ = 25; break; }
    case 20: 
      var $110=$sp;
      var $111=(($110+8)|0);
      $sp=$111;
      var $112=$dp;
      var $113=(($112+6)|0);
      $dp=$113;
      $i=1;
      __label__ = 21; break;
    case 21: 
      var $115=$i;
      var $116=$row_width;
      var $117=(($115)>>>0) < (($116)>>>0);
      if ($117) { __label__ = 22; break; } else { __label__ = 24; break; }
    case 22: 
      var $119=$sp;
      var $120=(($119+1)|0);
      $sp=$120;
      var $121=HEAP8[($119)];
      var $122=$dp;
      var $123=(($122+1)|0);
      $dp=$123;
      HEAP8[($122)]=$121;
      var $124=$sp;
      var $125=(($124+1)|0);
      $sp=$125;
      var $126=HEAP8[($124)];
      var $127=$dp;
      var $128=(($127+1)|0);
      $dp=$128;
      HEAP8[($127)]=$126;
      var $129=$sp;
      var $130=(($129+1)|0);
      $sp=$130;
      var $131=HEAP8[($129)];
      var $132=$dp;
      var $133=(($132+1)|0);
      $dp=$133;
      HEAP8[($132)]=$131;
      var $134=$sp;
      var $135=(($134+1)|0);
      $sp=$135;
      var $136=HEAP8[($134)];
      var $137=$dp;
      var $138=(($137+1)|0);
      $dp=$138;
      HEAP8[($137)]=$136;
      var $139=$sp;
      var $140=(($139+1)|0);
      $sp=$140;
      var $141=HEAP8[($139)];
      var $142=$dp;
      var $143=(($142+1)|0);
      $dp=$143;
      HEAP8[($142)]=$141;
      var $144=$sp;
      var $145=(($144+1)|0);
      $sp=$145;
      var $146=HEAP8[($144)];
      var $147=$dp;
      var $148=(($147+1)|0);
      $dp=$148;
      HEAP8[($147)]=$146;
      var $149=$sp;
      var $150=(($149+2)|0);
      $sp=$150;
      __label__ = 23; break;
    case 23: 
      var $152=$i;
      var $153=((($152)+(1))|0);
      $i=$153;
      __label__ = 21; break;
    case 24: 
      __label__ = 30; break;
    case 25: 
      $i=0;
      __label__ = 26; break;
    case 26: 
      var $157=$i;
      var $158=$row_width;
      var $159=(($157)>>>0) < (($158)>>>0);
      if ($159) { __label__ = 27; break; } else { __label__ = 29; break; }
    case 27: 
      var $161=$sp;
      var $162=(($161+2)|0);
      $sp=$162;
      var $163=$sp;
      var $164=(($163+1)|0);
      $sp=$164;
      var $165=HEAP8[($163)];
      var $166=$dp;
      var $167=(($166+1)|0);
      $dp=$167;
      HEAP8[($166)]=$165;
      var $168=$sp;
      var $169=(($168+1)|0);
      $sp=$169;
      var $170=HEAP8[($168)];
      var $171=$dp;
      var $172=(($171+1)|0);
      $dp=$172;
      HEAP8[($171)]=$170;
      var $173=$sp;
      var $174=(($173+1)|0);
      $sp=$174;
      var $175=HEAP8[($173)];
      var $176=$dp;
      var $177=(($176+1)|0);
      $dp=$177;
      HEAP8[($176)]=$175;
      var $178=$sp;
      var $179=(($178+1)|0);
      $sp=$179;
      var $180=HEAP8[($178)];
      var $181=$dp;
      var $182=(($181+1)|0);
      $dp=$182;
      HEAP8[($181)]=$180;
      var $183=$sp;
      var $184=(($183+1)|0);
      $sp=$184;
      var $185=HEAP8[($183)];
      var $186=$dp;
      var $187=(($186+1)|0);
      $dp=$187;
      HEAP8[($186)]=$185;
      var $188=$sp;
      var $189=(($188+1)|0);
      $sp=$189;
      var $190=HEAP8[($188)];
      var $191=$dp;
      var $192=(($191+1)|0);
      $dp=$192;
      HEAP8[($191)]=$190;
      __label__ = 28; break;
    case 28: 
      var $194=$i;
      var $195=((($194)+(1))|0);
      $i=$195;
      __label__ = 26; break;
    case 29: 
      __label__ = 30; break;
    case 30: 
      var $198=$1;
      var $199=(($198+11)|0);
      HEAP8[($199)]=48;
      var $200=$row_width;
      var $201=((($200)*(6))|0);
      var $202=$1;
      var $203=(($202+4)|0);
      HEAP32[(($203)>>2)]=$201;
      __label__ = 31; break;
    case 31: 
      var $205=$1;
      var $206=(($205+10)|0);
      HEAP8[($206)]=3;
      __label__ = 63; break;
    case 32: 
      var $208=$1;
      var $209=(($208+8)|0);
      var $210=HEAPU8[($209)];
      var $211=(($210)&255);
      var $212=(($211)|0)==0;
      if ($212) { __label__ = 35; break; } else { __label__ = 33; break; }
    case 33: 
      var $214=$1;
      var $215=(($214+8)|0);
      var $216=HEAPU8[($215)];
      var $217=(($216)&255);
      var $218=(($217)|0)==4;
      if ($218) { __label__ = 34; break; } else { __label__ = 62; break; }
    case 34: 
      var $220=$3;
      var $221=$220 & 4194304;
      var $222=(($221)|0)!=0;
      if ($222) { __label__ = 35; break; } else { __label__ = 62; break; }
    case 35: 
      var $224=$1;
      var $225=(($224+10)|0);
      var $226=HEAPU8[($225)];
      var $227=(($226)&255);
      var $228=(($227)|0)==2;
      if ($228) { __label__ = 36; break; } else { __label__ = 62; break; }
    case 36: 
      var $230=$1;
      var $231=(($230+9)|0);
      var $232=HEAPU8[($231)];
      var $233=(($232)&255);
      var $234=(($233)|0)==8;
      if ($234) { __label__ = 37; break; } else { __label__ = 49; break; }
    case 37: 
      var $236=$3;
      var $237=$236 & 128;
      var $238=(($237)|0)!=0;
      if ($238) { __label__ = 38; break; } else { __label__ = 43; break; }
    case 38: 
      $i=0;
      __label__ = 39; break;
    case 39: 
      var $241=$i;
      var $242=$row_width;
      var $243=(($241)>>>0) < (($242)>>>0);
      if ($243) { __label__ = 40; break; } else { __label__ = 42; break; }
    case 40: 
      var $245=$sp;
      var $246=(($245+1)|0);
      $sp=$246;
      var $247=HEAP8[($245)];
      var $248=$dp;
      var $249=(($248+1)|0);
      $dp=$249;
      HEAP8[($248)]=$247;
      var $250=$sp;
      var $251=(($250+1)|0);
      $sp=$251;
      __label__ = 41; break;
    case 41: 
      var $253=$i;
      var $254=((($253)+(1))|0);
      $i=$254;
      __label__ = 39; break;
    case 42: 
      __label__ = 48; break;
    case 43: 
      $i=0;
      __label__ = 44; break;
    case 44: 
      var $258=$i;
      var $259=$row_width;
      var $260=(($258)>>>0) < (($259)>>>0);
      if ($260) { __label__ = 45; break; } else { __label__ = 47; break; }
    case 45: 
      var $262=$sp;
      var $263=(($262+1)|0);
      $sp=$263;
      var $264=$sp;
      var $265=(($264+1)|0);
      $sp=$265;
      var $266=HEAP8[($264)];
      var $267=$dp;
      var $268=(($267+1)|0);
      $dp=$268;
      HEAP8[($267)]=$266;
      __label__ = 46; break;
    case 46: 
      var $270=$i;
      var $271=((($270)+(1))|0);
      $i=$271;
      __label__ = 44; break;
    case 47: 
      __label__ = 48; break;
    case 48: 
      var $274=$1;
      var $275=(($274+11)|0);
      HEAP8[($275)]=8;
      var $276=$row_width;
      var $277=$1;
      var $278=(($277+4)|0);
      HEAP32[(($278)>>2)]=$276;
      __label__ = 61; break;
    case 49: 
      var $280=$3;
      var $281=$280 & 128;
      var $282=(($281)|0)!=0;
      if ($282) { __label__ = 50; break; } else { __label__ = 55; break; }
    case 50: 
      var $284=$sp;
      var $285=(($284+4)|0);
      $sp=$285;
      var $286=$dp;
      var $287=(($286+2)|0);
      $dp=$287;
      $i=1;
      __label__ = 51; break;
    case 51: 
      var $289=$i;
      var $290=$row_width;
      var $291=(($289)>>>0) < (($290)>>>0);
      if ($291) { __label__ = 52; break; } else { __label__ = 54; break; }
    case 52: 
      var $293=$sp;
      var $294=(($293+1)|0);
      $sp=$294;
      var $295=HEAP8[($293)];
      var $296=$dp;
      var $297=(($296+1)|0);
      $dp=$297;
      HEAP8[($296)]=$295;
      var $298=$sp;
      var $299=(($298+1)|0);
      $sp=$299;
      var $300=HEAP8[($298)];
      var $301=$dp;
      var $302=(($301+1)|0);
      $dp=$302;
      HEAP8[($301)]=$300;
      var $303=$sp;
      var $304=(($303+2)|0);
      $sp=$304;
      __label__ = 53; break;
    case 53: 
      var $306=$i;
      var $307=((($306)+(1))|0);
      $i=$307;
      __label__ = 51; break;
    case 54: 
      __label__ = 60; break;
    case 55: 
      $i=0;
      __label__ = 56; break;
    case 56: 
      var $311=$i;
      var $312=$row_width;
      var $313=(($311)>>>0) < (($312)>>>0);
      if ($313) { __label__ = 57; break; } else { __label__ = 59; break; }
    case 57: 
      var $315=$sp;
      var $316=(($315+2)|0);
      $sp=$316;
      var $317=$sp;
      var $318=(($317+1)|0);
      $sp=$318;
      var $319=HEAP8[($317)];
      var $320=$dp;
      var $321=(($320+1)|0);
      $dp=$321;
      HEAP8[($320)]=$319;
      var $322=$sp;
      var $323=(($322+1)|0);
      $sp=$323;
      var $324=HEAP8[($322)];
      var $325=$dp;
      var $326=(($325+1)|0);
      $dp=$326;
      HEAP8[($325)]=$324;
      __label__ = 58; break;
    case 58: 
      var $328=$i;
      var $329=((($328)+(1))|0);
      $i=$329;
      __label__ = 56; break;
    case 59: 
      __label__ = 60; break;
    case 60: 
      var $332=$1;
      var $333=(($332+11)|0);
      HEAP8[($333)]=16;
      var $334=$row_width;
      var $335=((($334<<1))|0);
      var $336=$1;
      var $337=(($336+4)|0);
      HEAP32[(($337)>>2)]=$335;
      __label__ = 61; break;
    case 61: 
      var $339=$1;
      var $340=(($339+10)|0);
      HEAP8[($340)]=1;
      __label__ = 62; break;
    case 62: 
      __label__ = 63; break;
    case 63: 
      var $343=$3;
      var $344=$343 & 4194304;
      var $345=(($344)|0)!=0;
      if ($345) { __label__ = 64; break; } else { __label__ = 65; break; }
    case 64: 
      var $347=$1;
      var $348=(($347+8)|0);
      var $349=HEAPU8[($348)];
      var $350=(($349)&255);
      var $351=$350 & -5;
      var $352=(($351) & 255);
      HEAP8[($348)]=$352;
      __label__ = 65; break;
    case 65: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_png_do_strip_filler["X"]=1;

function _png_do_bgr($row_info, $row) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $row_width;
      var $rp;
      var $i;
      var $save;
      var $rp1;
      var $i2;
      var $save3;
      var $rp4;
      var $i5;
      var $save6;
      var $rp7;
      var $i8;
      var $save9;
      $1=$row_info;
      $2=$row;
      var $3=$1;
      var $4=(($3+8)|0);
      var $5=HEAPU8[($4)];
      var $6=(($5)&255);
      var $7=$6 & 2;
      var $8=(($7)|0)!=0;
      if ($8) { __label__ = 3; break; } else { __label__ = 35; break; }
    case 3: 
      var $10=$1;
      var $11=(($10)|0);
      var $12=HEAP32[(($11)>>2)];
      $row_width=$12;
      var $13=$1;
      var $14=(($13+9)|0);
      var $15=HEAPU8[($14)];
      var $16=(($15)&255);
      var $17=(($16)|0)==8;
      if ($17) { __label__ = 4; break; } else { __label__ = 18; break; }
    case 4: 
      var $19=$1;
      var $20=(($19+8)|0);
      var $21=HEAPU8[($20)];
      var $22=(($21)&255);
      var $23=(($22)|0)==2;
      if ($23) { __label__ = 5; break; } else { __label__ = 10; break; }
    case 5: 
      $i=0;
      var $25=$2;
      $rp=$25;
      __label__ = 6; break;
    case 6: 
      var $27=$i;
      var $28=$row_width;
      var $29=(($27)>>>0) < (($28)>>>0);
      if ($29) { __label__ = 7; break; } else { __label__ = 9; break; }
    case 7: 
      var $31=$rp;
      var $32=HEAP8[($31)];
      $save=$32;
      var $33=$rp;
      var $34=(($33+2)|0);
      var $35=HEAP8[($34)];
      var $36=$rp;
      HEAP8[($36)]=$35;
      var $37=$save;
      var $38=$rp;
      var $39=(($38+2)|0);
      HEAP8[($39)]=$37;
      __label__ = 8; break;
    case 8: 
      var $41=$i;
      var $42=((($41)+(1))|0);
      $i=$42;
      var $43=$rp;
      var $44=(($43+3)|0);
      $rp=$44;
      __label__ = 6; break;
    case 9: 
      __label__ = 17; break;
    case 10: 
      var $47=$1;
      var $48=(($47+8)|0);
      var $49=HEAPU8[($48)];
      var $50=(($49)&255);
      var $51=(($50)|0)==6;
      if ($51) { __label__ = 11; break; } else { __label__ = 16; break; }
    case 11: 
      $i2=0;
      var $53=$2;
      $rp1=$53;
      __label__ = 12; break;
    case 12: 
      var $55=$i2;
      var $56=$row_width;
      var $57=(($55)>>>0) < (($56)>>>0);
      if ($57) { __label__ = 13; break; } else { __label__ = 15; break; }
    case 13: 
      var $59=$rp1;
      var $60=HEAP8[($59)];
      $save3=$60;
      var $61=$rp1;
      var $62=(($61+2)|0);
      var $63=HEAP8[($62)];
      var $64=$rp1;
      HEAP8[($64)]=$63;
      var $65=$save3;
      var $66=$rp1;
      var $67=(($66+2)|0);
      HEAP8[($67)]=$65;
      __label__ = 14; break;
    case 14: 
      var $69=$i2;
      var $70=((($69)+(1))|0);
      $i2=$70;
      var $71=$rp1;
      var $72=(($71+4)|0);
      $rp1=$72;
      __label__ = 12; break;
    case 15: 
      __label__ = 16; break;
    case 16: 
      __label__ = 17; break;
    case 17: 
      __label__ = 34; break;
    case 18: 
      var $77=$1;
      var $78=(($77+9)|0);
      var $79=HEAPU8[($78)];
      var $80=(($79)&255);
      var $81=(($80)|0)==16;
      if ($81) { __label__ = 19; break; } else { __label__ = 33; break; }
    case 19: 
      var $83=$1;
      var $84=(($83+8)|0);
      var $85=HEAPU8[($84)];
      var $86=(($85)&255);
      var $87=(($86)|0)==2;
      if ($87) { __label__ = 20; break; } else { __label__ = 25; break; }
    case 20: 
      $i5=0;
      var $89=$2;
      $rp4=$89;
      __label__ = 21; break;
    case 21: 
      var $91=$i5;
      var $92=$row_width;
      var $93=(($91)>>>0) < (($92)>>>0);
      if ($93) { __label__ = 22; break; } else { __label__ = 24; break; }
    case 22: 
      var $95=$rp4;
      var $96=HEAP8[($95)];
      $save6=$96;
      var $97=$rp4;
      var $98=(($97+4)|0);
      var $99=HEAP8[($98)];
      var $100=$rp4;
      HEAP8[($100)]=$99;
      var $101=$save6;
      var $102=$rp4;
      var $103=(($102+4)|0);
      HEAP8[($103)]=$101;
      var $104=$rp4;
      var $105=(($104+1)|0);
      var $106=HEAP8[($105)];
      $save6=$106;
      var $107=$rp4;
      var $108=(($107+5)|0);
      var $109=HEAP8[($108)];
      var $110=$rp4;
      var $111=(($110+1)|0);
      HEAP8[($111)]=$109;
      var $112=$save6;
      var $113=$rp4;
      var $114=(($113+5)|0);
      HEAP8[($114)]=$112;
      __label__ = 23; break;
    case 23: 
      var $116=$i5;
      var $117=((($116)+(1))|0);
      $i5=$117;
      var $118=$rp4;
      var $119=(($118+6)|0);
      $rp4=$119;
      __label__ = 21; break;
    case 24: 
      __label__ = 32; break;
    case 25: 
      var $122=$1;
      var $123=(($122+8)|0);
      var $124=HEAPU8[($123)];
      var $125=(($124)&255);
      var $126=(($125)|0)==6;
      if ($126) { __label__ = 26; break; } else { __label__ = 31; break; }
    case 26: 
      $i8=0;
      var $128=$2;
      $rp7=$128;
      __label__ = 27; break;
    case 27: 
      var $130=$i8;
      var $131=$row_width;
      var $132=(($130)>>>0) < (($131)>>>0);
      if ($132) { __label__ = 28; break; } else { __label__ = 30; break; }
    case 28: 
      var $134=$rp7;
      var $135=HEAP8[($134)];
      $save9=$135;
      var $136=$rp7;
      var $137=(($136+4)|0);
      var $138=HEAP8[($137)];
      var $139=$rp7;
      HEAP8[($139)]=$138;
      var $140=$save9;
      var $141=$rp7;
      var $142=(($141+4)|0);
      HEAP8[($142)]=$140;
      var $143=$rp7;
      var $144=(($143+1)|0);
      var $145=HEAP8[($144)];
      $save9=$145;
      var $146=$rp7;
      var $147=(($146+5)|0);
      var $148=HEAP8[($147)];
      var $149=$rp7;
      var $150=(($149+1)|0);
      HEAP8[($150)]=$148;
      var $151=$save9;
      var $152=$rp7;
      var $153=(($152+5)|0);
      HEAP8[($153)]=$151;
      __label__ = 29; break;
    case 29: 
      var $155=$i8;
      var $156=((($155)+(1))|0);
      $i8=$156;
      var $157=$rp7;
      var $158=(($157+8)|0);
      $rp7=$158;
      __label__ = 27; break;
    case 30: 
      __label__ = 31; break;
    case 31: 
      __label__ = 32; break;
    case 32: 
      __label__ = 33; break;
    case 33: 
      __label__ = 34; break;
    case 34: 
      __label__ = 35; break;
    case 35: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_png_do_bgr["X"]=1;

function _HPDF_Annotation_New($mmgr, $xref, $type, $rect_0, $rect_1, $rect_2, $rect_3) {
  var __stackBase__  = STACKTOP; STACKTOP += 16; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $rect=__stackBase__;
      var $annot;
      var $array;
      var $ret;
      var $tmp;
      $2=$mmgr;
      $3=$xref;
      $4=$type;
      var $5=(($rect)|0);
      HEAPF32[(($5)>>2)]=$rect_0;
      var $6=(($rect+4)|0);
      HEAPF32[(($6)>>2)]=$rect_1;
      var $7=(($rect+8)|0);
      HEAPF32[(($7)>>2)]=$rect_2;
      var $8=(($rect+12)|0);
      HEAPF32[(($8)>>2)]=$rect_3;
      $ret=0;
      var $9=$2;
      var $10=_HPDF_Dict_New($9);
      $annot=$10;
      var $11=$annot;
      var $12=(($11)|0)!=0;
      if ($12) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=0;
      __label__ = 15; break;
    case 4: 
      var $15=$3;
      var $16=$annot;
      var $17=$16;
      var $18=_HPDF_Xref_Add($15, $17);
      var $19=(($18)|0)!=0;
      if ($19) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      $1=0;
      __label__ = 15; break;
    case 6: 
      var $22=$2;
      var $23=_HPDF_Array_New($22);
      $array=$23;
      var $24=$array;
      var $25=(($24)|0)!=0;
      if ($25) { __label__ = 8; break; } else { __label__ = 7; break; }
    case 7: 
      $1=0;
      __label__ = 15; break;
    case 8: 
      var $28=$annot;
      var $29=$array;
      var $30=$29;
      var $31=_HPDF_Dict_Add($28, ((STRING_TABLE.__str510)|0), $30);
      var $32=(($31)|0)!=0;
      if ($32) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      $1=0;
      __label__ = 15; break;
    case 10: 
      var $35=(($rect+12)|0);
      var $36=HEAPF32[(($35)>>2)];
      var $37=(($rect+4)|0);
      var $38=HEAPF32[(($37)>>2)];
      var $39=$36 < $38;
      if ($39) { __label__ = 11; break; } else { __label__ = 12; break; }
    case 11: 
      var $41=(($rect+12)|0);
      var $42=HEAPF32[(($41)>>2)];
      $tmp=$42;
      var $43=(($rect+4)|0);
      var $44=HEAPF32[(($43)>>2)];
      var $45=(($rect+12)|0);
      HEAPF32[(($45)>>2)]=$44;
      var $46=$tmp;
      var $47=(($rect+4)|0);
      HEAPF32[(($47)>>2)]=$46;
      __label__ = 12; break;
    case 12: 
      var $49=$array;
      var $50=(($rect)|0);
      var $51=HEAPF32[(($50)>>2)];
      var $52=_HPDF_Array_AddReal($49, $51);
      var $53=$ret;
      var $54=((($53)+($52))|0);
      $ret=$54;
      var $55=$array;
      var $56=(($rect+4)|0);
      var $57=HEAPF32[(($56)>>2)];
      var $58=_HPDF_Array_AddReal($55, $57);
      var $59=$ret;
      var $60=((($59)+($58))|0);
      $ret=$60;
      var $61=$array;
      var $62=(($rect+8)|0);
      var $63=HEAPF32[(($62)>>2)];
      var $64=_HPDF_Array_AddReal($61, $63);
      var $65=$ret;
      var $66=((($65)+($64))|0);
      $ret=$66;
      var $67=$array;
      var $68=(($rect+12)|0);
      var $69=HEAPF32[(($68)>>2)];
      var $70=_HPDF_Array_AddReal($67, $69);
      var $71=$ret;
      var $72=((($71)+($70))|0);
      $ret=$72;
      var $73=$annot;
      var $74=_HPDF_Dict_AddName($73, ((STRING_TABLE.__str1511)|0), ((STRING_TABLE.__str2512)|0));
      var $75=$ret;
      var $76=((($75)+($74))|0);
      $ret=$76;
      var $77=$annot;
      var $78=$4;
      var $79=((_HPDF_ANNOT_TYPE_NAMES+($78<<2))|0);
      var $80=HEAP32[(($79)>>2)];
      var $81=_HPDF_Dict_AddName($77, ((STRING_TABLE.__str3513)|0), $80);
      var $82=$ret;
      var $83=((($82)+($81))|0);
      $ret=$83;
      var $84=$ret;
      var $85=(($84)|0)!=0;
      if ($85) { __label__ = 13; break; } else { __label__ = 14; break; }
    case 13: 
      $1=0;
      __label__ = 15; break;
    case 14: 
      var $88=$annot;
      var $89=(($88)|0);
      var $90=(($89+6)|0);
      var $91=HEAPU16[(($90)>>1)];
      var $92=(($91)&65535);
      var $93=$92 | 2048;
      var $94=(($93) & 65535);
      HEAP16[(($90)>>1)]=$94;
      var $95=$annot;
      $1=$95;
      __label__ = 15; break;
    case 15: 
      var $97=$1;
      STACKTOP = __stackBase__;
      return $97;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Annotation_New["X"]=1;

function _HPDF_LinkAnnot_New($mmgr, $xref, $rect_0, $rect_1, $rect_2, $rect_3, $dst) {
  var __stackBase__  = STACKTOP; STACKTOP += 16; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $rect=__stackBase__;
      var $4;
      var $annot;
      $2=$mmgr;
      $3=$xref;
      var $5=(($rect)|0);
      HEAPF32[(($5)>>2)]=$rect_0;
      var $6=(($rect+4)|0);
      HEAPF32[(($6)>>2)]=$rect_1;
      var $7=(($rect+8)|0);
      HEAPF32[(($7)>>2)]=$rect_2;
      var $8=(($rect+12)|0);
      HEAPF32[(($8)>>2)]=$rect_3;
      $4=$dst;
      var $9=$2;
      var $10=$3;
      var $11=(($rect)|0);
      var $12=HEAPF32[(($11)>>2)];
      var $13=(($rect+4)|0);
      var $14=HEAPF32[(($13)>>2)];
      var $15=(($rect+8)|0);
      var $16=HEAPF32[(($15)>>2)];
      var $17=(($rect+12)|0);
      var $18=HEAPF32[(($17)>>2)];
      var $19=_HPDF_Annotation_New($9, $10, 1, $12, $14, $16, $18);
      $annot=$19;
      var $20=$annot;
      var $21=(($20)|0)!=0;
      if ($21) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=0;
      __label__ = 7; break;
    case 4: 
      var $24=$annot;
      var $25=$4;
      var $26=$25;
      var $27=_HPDF_Dict_Add($24, ((STRING_TABLE.__str12522)|0), $26);
      var $28=(($27)|0)!=0;
      if ($28) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      $1=0;
      __label__ = 7; break;
    case 6: 
      var $31=$annot;
      $1=$31;
      __label__ = 7; break;
    case 7: 
      var $33=$1;
      STACKTOP = __stackBase__;
      return $33;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_URILinkAnnot_New($mmgr, $xref, $rect_0, $rect_1, $rect_2, $rect_3, $uri) {
  var __stackBase__  = STACKTOP; STACKTOP += 16; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $rect=__stackBase__;
      var $4;
      var $annot;
      var $action;
      var $ret;
      $2=$mmgr;
      $3=$xref;
      var $5=(($rect)|0);
      HEAPF32[(($5)>>2)]=$rect_0;
      var $6=(($rect+4)|0);
      HEAPF32[(($6)>>2)]=$rect_1;
      var $7=(($rect+8)|0);
      HEAPF32[(($7)>>2)]=$rect_2;
      var $8=(($rect+12)|0);
      HEAPF32[(($8)>>2)]=$rect_3;
      $4=$uri;
      var $9=$2;
      var $10=$3;
      var $11=(($rect)|0);
      var $12=HEAPF32[(($11)>>2)];
      var $13=(($rect+4)|0);
      var $14=HEAPF32[(($13)>>2)];
      var $15=(($rect+8)|0);
      var $16=HEAPF32[(($15)>>2)];
      var $17=(($rect+12)|0);
      var $18=HEAPF32[(($17)>>2)];
      var $19=_HPDF_Annotation_New($9, $10, 1, $12, $14, $16, $18);
      $annot=$19;
      var $20=$annot;
      var $21=(($20)|0)!=0;
      if ($21) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=0;
      __label__ = 11; break;
    case 4: 
      var $24=$2;
      var $25=_HPDF_Dict_New($24);
      $action=$25;
      var $26=$action;
      var $27=(($26)|0)!=0;
      if ($27) { __label__ = 6; break; } else { __label__ = 5; break; }
    case 5: 
      $1=0;
      __label__ = 11; break;
    case 6: 
      var $30=$annot;
      var $31=$action;
      var $32=$31;
      var $33=_HPDF_Dict_Add($30, ((STRING_TABLE.__str13523)|0), $32);
      $ret=$33;
      var $34=$ret;
      var $35=(($34)|0)!=0;
      if ($35) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      $1=0;
      __label__ = 11; break;
    case 8: 
      var $38=$action;
      var $39=_HPDF_Dict_AddName($38, ((STRING_TABLE.__str1511)|0), ((STRING_TABLE.__str14524)|0));
      var $40=$ret;
      var $41=((($40)+($39))|0);
      $ret=$41;
      var $42=$action;
      var $43=_HPDF_Dict_AddName($42, ((STRING_TABLE.__str7517)|0), ((STRING_TABLE.__str15525)|0));
      var $44=$ret;
      var $45=((($44)+($43))|0);
      $ret=$45;
      var $46=$action;
      var $47=$2;
      var $48=$4;
      var $49=_HPDF_String_New($47, $48, 0);
      var $50=$49;
      var $51=_HPDF_Dict_Add($46, ((STRING_TABLE.__str15525)|0), $50);
      var $52=$ret;
      var $53=((($52)+($51))|0);
      $ret=$53;
      var $54=$ret;
      var $55=(($54)|0)!=0;
      if ($55) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      $1=0;
      __label__ = 11; break;
    case 10: 
      var $58=$annot;
      $1=$58;
      __label__ = 11; break;
    case 11: 
      var $60=$1;
      STACKTOP = __stackBase__;
      return $60;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_URILinkAnnot_New["X"]=1;

function _HPDF_LinkAnnot_SetBorderStyle($annot, $width, $dash_on, $dash_off) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $5;
      var $array;
      var $ret;
      var $dash;
      $2=$annot;
      $3=$width;
      $4=$dash_on;
      $5=$dash_off;
      var $6=$2;
      var $7=_CheckSubType($6, 1);
      var $8=(($7)|0)!=0;
      if ($8) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=4124;
      __label__ = 22; break;
    case 4: 
      var $11=$3;
      var $12=$11 < 0;
      if ($12) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $14=$2;
      var $15=(($14+12)|0);
      var $16=HEAP32[(($15)>>2)];
      var $17=_HPDF_RaiseError($16, 4153, 0);
      $1=$17;
      __label__ = 22; break;
    case 6: 
      var $19=$2;
      var $20=(($19+8)|0);
      var $21=HEAP32[(($20)>>2)];
      var $22=_HPDF_Array_New($21);
      $array=$22;
      var $23=$array;
      var $24=(($23)|0)!=0;
      if ($24) { __label__ = 8; break; } else { __label__ = 7; break; }
    case 7: 
      var $26=$2;
      var $27=(($26+12)|0);
      var $28=HEAP32[(($27)>>2)];
      var $29=_HPDF_CheckError($28);
      $1=$29;
      __label__ = 22; break;
    case 8: 
      var $31=$2;
      var $32=$array;
      var $33=$32;
      var $34=_HPDF_Dict_Add($31, ((STRING_TABLE.__str6516)|0), $33);
      $ret=$34;
      var $35=(($34)|0)!=0;
      if ($35) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      var $37=$2;
      var $38=(($37+12)|0);
      var $39=HEAP32[(($38)>>2)];
      var $40=_HPDF_CheckError($39);
      $1=$40;
      __label__ = 22; break;
    case 10: 
      var $42=$array;
      var $43=_HPDF_Array_AddNumber($42, 0);
      var $44=$ret;
      var $45=((($44)+($43))|0);
      $ret=$45;
      var $46=$array;
      var $47=_HPDF_Array_AddNumber($46, 0);
      var $48=$ret;
      var $49=((($48)+($47))|0);
      $ret=$49;
      var $50=$array;
      var $51=$3;
      var $52=_HPDF_Array_AddReal($50, $51);
      var $53=$ret;
      var $54=((($53)+($52))|0);
      $ret=$54;
      var $55=$ret;
      var $56=(($55)|0)!=0;
      if ($56) { __label__ = 11; break; } else { __label__ = 12; break; }
    case 11: 
      var $58=$2;
      var $59=(($58+12)|0);
      var $60=HEAP32[(($59)>>2)];
      var $61=_HPDF_CheckError($60);
      $1=$61;
      __label__ = 22; break;
    case 12: 
      var $63=$4;
      var $64=(($63)&65535);
      var $65=(($64)|0)!=0;
      if ($65) { __label__ = 13; break; } else { __label__ = 19; break; }
    case 13: 
      var $67=$5;
      var $68=(($67)&65535);
      var $69=(($68)|0)!=0;
      if ($69) { __label__ = 14; break; } else { __label__ = 19; break; }
    case 14: 
      var $71=$2;
      var $72=(($71+8)|0);
      var $73=HEAP32[(($72)>>2)];
      var $74=_HPDF_Array_New($73);
      $dash=$74;
      var $75=$dash;
      var $76=(($75)|0)!=0;
      if ($76) { __label__ = 16; break; } else { __label__ = 15; break; }
    case 15: 
      var $78=$2;
      var $79=(($78+12)|0);
      var $80=HEAP32[(($79)>>2)];
      var $81=_HPDF_CheckError($80);
      $1=$81;
      __label__ = 22; break;
    case 16: 
      var $83=$array;
      var $84=$dash;
      var $85=$84;
      var $86=_HPDF_Array_Add($83, $85);
      $ret=$86;
      var $87=(($86)|0)!=0;
      if ($87) { __label__ = 17; break; } else { __label__ = 18; break; }
    case 17: 
      var $89=$2;
      var $90=(($89+12)|0);
      var $91=HEAP32[(($90)>>2)];
      var $92=_HPDF_CheckError($91);
      $1=$92;
      __label__ = 22; break;
    case 18: 
      var $94=$dash;
      var $95=$4;
      var $96=(($95)&65535);
      var $97=_HPDF_Array_AddNumber($94, $96);
      var $98=$ret;
      var $99=((($98)+($97))|0);
      $ret=$99;
      var $100=$dash;
      var $101=$5;
      var $102=(($101)&65535);
      var $103=_HPDF_Array_AddNumber($100, $102);
      var $104=$ret;
      var $105=((($104)+($103))|0);
      $ret=$105;
      __label__ = 19; break;
    case 19: 
      var $107=$ret;
      var $108=(($107)|0)!=0;
      if ($108) { __label__ = 20; break; } else { __label__ = 21; break; }
    case 20: 
      var $110=$2;
      var $111=(($110+12)|0);
      var $112=HEAP32[(($111)>>2)];
      var $113=_HPDF_CheckError($112);
      $1=$113;
      __label__ = 22; break;
    case 21: 
      var $115=$ret;
      $1=$115;
      __label__ = 22; break;
    case 22: 
      var $117=$1;
      ;
      return $117;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_LinkAnnot_SetBorderStyle["X"]=1;

function _CheckSubType($annot, $type) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $subtype;
      $2=$annot;
      $3=$type;
      var $4=$2;
      var $5=_HPDF_Annotation_Validate($4);
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=0;
      __label__ = 8; break;
    case 4: 
      var $9=$2;
      var $10=_HPDF_Dict_GetItem($9, ((STRING_TABLE.__str3513)|0), 6);
      var $11=$10;
      $subtype=$11;
      var $12=$subtype;
      var $13=(($12)|0)!=0;
      if ($13) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $15=$subtype;
      var $16=(($15+12)|0);
      var $17=(($16)|0);
      var $18=$3;
      var $19=((_HPDF_ANNOT_TYPE_NAMES+($18<<2))|0);
      var $20=HEAP32[(($19)>>2)];
      var $21=_HPDF_StrCmp($17, $20);
      var $22=(($21)|0)!=0;
      if ($22) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      var $24=$2;
      var $25=(($24+12)|0);
      var $26=HEAP32[(($25)>>2)];
      var $27=_HPDF_RaiseError($26, 4124, 0);
      $1=0;
      __label__ = 8; break;
    case 7: 
      $1=1;
      __label__ = 8; break;
    case 8: 
      var $30=$1;
      ;
      return $30;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_LinkAnnot_SetHighlightMode($annot, $mode) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $ret;
      $2=$annot;
      $3=$mode;
      var $4=$2;
      var $5=_CheckSubType($4, 1);
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=4124;
      __label__ = 12; break;
    case 4: 
      var $9=$3;
      if ((($9)|0) == 0) {
        __label__ = 5; break;
      }
      else if ((($9)|0) == 2) {
        __label__ = 6; break;
      }
      else if ((($9)|0) == 3) {
        __label__ = 7; break;
      }
      else {
      __label__ = 8; break;
      }
      
    case 5: 
      var $11=$2;
      var $12=_HPDF_Dict_AddName($11, ((STRING_TABLE.__str16526)|0), ((STRING_TABLE.__str17527)|0));
      $ret=$12;
      __label__ = 9; break;
    case 6: 
      var $14=$2;
      var $15=_HPDF_Dict_AddName($14, ((STRING_TABLE.__str16526)|0), ((STRING_TABLE.__str18528)|0));
      $ret=$15;
      __label__ = 9; break;
    case 7: 
      var $17=$2;
      var $18=_HPDF_Dict_AddName($17, ((STRING_TABLE.__str16526)|0), ((STRING_TABLE.__str19529)|0));
      $ret=$18;
      __label__ = 9; break;
    case 8: 
      var $20=$2;
      var $21=_HPDF_Dict_RemoveElement($20, ((STRING_TABLE.__str16526)|0));
      $ret=0;
      __label__ = 9; break;
    case 9: 
      var $23=$ret;
      var $24=(($23)|0)!=0;
      if ($24) { __label__ = 10; break; } else { __label__ = 11; break; }
    case 10: 
      var $26=$2;
      var $27=(($26+12)|0);
      var $28=HEAP32[(($27)>>2)];
      var $29=_HPDF_CheckError($28);
      $1=$29;
      __label__ = 12; break;
    case 11: 
      var $31=$ret;
      $1=$31;
      __label__ = 12; break;
    case 12: 
      var $33=$1;
      ;
      return $33;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_3DAnnot_New($mmgr, $xref, $rect_0, $rect_1, $rect_2, $rect_3, $u3d) {
  var __stackBase__  = STACKTOP; STACKTOP += 16; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $rect=__stackBase__;
      var $4;
      var $annot;
      var $action;
      var $appearance;
      var $stream;
      var $ret;
      $2=$mmgr;
      $3=$xref;
      var $5=(($rect)|0);
      HEAPF32[(($5)>>2)]=$rect_0;
      var $6=(($rect+4)|0);
      HEAPF32[(($6)>>2)]=$rect_1;
      var $7=(($rect+8)|0);
      HEAPF32[(($7)>>2)]=$rect_2;
      var $8=(($rect+12)|0);
      HEAPF32[(($8)>>2)]=$rect_3;
      $4=$u3d;
      var $9=$2;
      var $10=$3;
      var $11=(($rect)|0);
      var $12=HEAPF32[(($11)>>2)];
      var $13=(($rect+4)|0);
      var $14=HEAPF32[(($13)>>2)];
      var $15=(($rect+8)|0);
      var $16=HEAPF32[(($15)>>2)];
      var $17=(($rect+12)|0);
      var $18=HEAPF32[(($17)>>2)];
      var $19=_HPDF_Annotation_New($9, $10, 13, $12, $14, $16, $18);
      $annot=$19;
      var $20=$annot;
      var $21=(($20)|0)!=0;
      if ($21) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=0;
      __label__ = 21; break;
    case 4: 
      var $24=$annot;
      var $25=_HPDF_Dict_AddName($24, ((STRING_TABLE.__str20530)|0), ((STRING_TABLE.__str21531)|0));
      var $26=$2;
      var $27=_HPDF_Dict_New($26);
      $action=$27;
      var $28=$action;
      var $29=(($28)|0)!=0;
      if ($29) { __label__ = 6; break; } else { __label__ = 5; break; }
    case 5: 
      $1=0;
      __label__ = 21; break;
    case 6: 
      var $32=$annot;
      var $33=$action;
      var $34=$33;
      var $35=_HPDF_Dict_Add($32, ((STRING_TABLE.__str22532)|0), $34);
      $ret=$35;
      var $36=$ret;
      var $37=(($36)|0)!=0;
      if ($37) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      $1=0;
      __label__ = 21; break;
    case 8: 
      var $40=$action;
      var $41=_HPDF_Dict_AddName($40, ((STRING_TABLE.__str13523)|0), ((STRING_TABLE.__str23533)|0));
      var $42=$ret;
      var $43=((($42)+($41))|0);
      $ret=$43;
      var $44=$action;
      var $45=_HPDF_Dict_AddBoolean($44, ((STRING_TABLE.__str24534)|0), 0);
      var $46=$ret;
      var $47=((($46)+($45))|0);
      $ret=$47;
      var $48=$ret;
      var $49=(($48)|0)!=0;
      if ($49) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      $1=0;
      __label__ = 21; break;
    case 10: 
      var $52=$annot;
      var $53=$4;
      var $54=$53;
      var $55=_HPDF_Dict_Add($52, ((STRING_TABLE.__str25535)|0), $54);
      var $56=(($55)|0)!=0;
      if ($56) { __label__ = 11; break; } else { __label__ = 12; break; }
    case 11: 
      $1=0;
      __label__ = 21; break;
    case 12: 
      var $59=$2;
      var $60=_HPDF_Dict_New($59);
      $appearance=$60;
      var $61=$appearance;
      var $62=(($61)|0)!=0;
      if ($62) { __label__ = 14; break; } else { __label__ = 13; break; }
    case 13: 
      $1=0;
      __label__ = 21; break;
    case 14: 
      var $65=$annot;
      var $66=$appearance;
      var $67=$66;
      var $68=_HPDF_Dict_Add($65, ((STRING_TABLE.__str26536)|0), $67);
      $ret=$68;
      var $69=$ret;
      var $70=(($69)|0)!=0;
      if ($70) { __label__ = 15; break; } else { __label__ = 16; break; }
    case 15: 
      $1=0;
      __label__ = 21; break;
    case 16: 
      var $73=$2;
      var $74=_HPDF_Dict_New($73);
      $stream=$74;
      var $75=$stream;
      var $76=(($75)|0)!=0;
      if ($76) { __label__ = 18; break; } else { __label__ = 17; break; }
    case 17: 
      $1=0;
      __label__ = 21; break;
    case 18: 
      var $79=$appearance;
      var $80=$stream;
      var $81=$80;
      var $82=_HPDF_Dict_Add($79, ((STRING_TABLE.__str17527)|0), $81);
      $ret=$82;
      var $83=$ret;
      var $84=(($83)|0)!=0;
      if ($84) { __label__ = 19; break; } else { __label__ = 20; break; }
    case 19: 
      $1=0;
      __label__ = 21; break;
    case 20: 
      var $87=$annot;
      $1=$87;
      __label__ = 21; break;
    case 21: 
      var $89=$1;
      STACKTOP = __stackBase__;
      return $89;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_3DAnnot_New["X"]=1;

function _HPDF_3DAnnot_Set3DView($annot) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $b;
      $2=$annot;
      var $3=$2;
      var $4=_CheckSubType($3, 13);
      var $5=(($4)|0)!=0;
      if ($5) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=4124;
      __label__ = 7; break;
    case 4: 
      var $8=$2;
      var $9=(($8+8)|0);
      var $10=HEAP32[(($9)>>2)];
      var $11=_HPDF_Boolean_New($10, 0);
      $b=$11;
      var $12=$b;
      var $13=(($12)|0)!=0;
      if ($13) { __label__ = 6; break; } else { __label__ = 5; break; }
    case 5: 
      var $15=$2;
      var $16=(($15+12)|0);
      var $17=HEAP32[(($16)>>2)];
      var $18=_HPDF_CheckError($17);
      $1=$18;
      __label__ = 7; break;
    case 6: 
      var $20=$2;
      var $21=$b;
      var $22=$21;
      var $23=_HPDF_Dict_Add($20, ((STRING_TABLE.__str25535)|0), $22);
      $1=$23;
      __label__ = 7; break;
    case 7: 
      var $25=$1;
      ;
      return $25;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_TextAnnot_New($mmgr, $xref, $rect_0, $rect_1, $rect_2, $rect_3, $text, $encoder) {
  var __stackBase__  = STACKTOP; STACKTOP += 16; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $rect=__stackBase__;
      var $4;
      var $5;
      var $annot;
      var $s;
      $2=$mmgr;
      $3=$xref;
      var $6=(($rect)|0);
      HEAPF32[(($6)>>2)]=$rect_0;
      var $7=(($rect+4)|0);
      HEAPF32[(($7)>>2)]=$rect_1;
      var $8=(($rect+8)|0);
      HEAPF32[(($8)>>2)]=$rect_2;
      var $9=(($rect+12)|0);
      HEAPF32[(($9)>>2)]=$rect_3;
      $4=$text;
      $5=$encoder;
      var $10=$2;
      var $11=$3;
      var $12=(($rect)|0);
      var $13=HEAPF32[(($12)>>2)];
      var $14=(($rect+4)|0);
      var $15=HEAPF32[(($14)>>2)];
      var $16=(($rect+8)|0);
      var $17=HEAPF32[(($16)>>2)];
      var $18=(($rect+12)|0);
      var $19=HEAPF32[(($18)>>2)];
      var $20=_HPDF_Annotation_New($10, $11, 0, $13, $15, $17, $19);
      $annot=$20;
      var $21=$annot;
      var $22=(($21)|0)!=0;
      if ($22) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=0;
      __label__ = 9; break;
    case 4: 
      var $25=$2;
      var $26=$4;
      var $27=$5;
      var $28=_HPDF_String_New($25, $26, $27);
      $s=$28;
      var $29=$s;
      var $30=(($29)|0)!=0;
      if ($30) { __label__ = 6; break; } else { __label__ = 5; break; }
    case 5: 
      $1=0;
      __label__ = 9; break;
    case 6: 
      var $33=$annot;
      var $34=$s;
      var $35=$34;
      var $36=_HPDF_Dict_Add($33, ((STRING_TABLE.__str20530)|0), $35);
      var $37=(($36)|0)!=0;
      if ($37) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      $1=0;
      __label__ = 9; break;
    case 8: 
      var $40=$annot;
      $1=$40;
      __label__ = 9; break;
    case 9: 
      var $42=$1;
      STACKTOP = __stackBase__;
      return $42;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_TextAnnot_New["X"]=1;

function _HPDF_TextAnnot_SetIcon($annot, $icon) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      $2=$annot;
      $3=$icon;
      var $4=$2;
      var $5=_CheckSubType($4, 0);
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=4124;
      __label__ = 10; break;
    case 4: 
      var $9=$3;
      var $10=(($9)>>>0) < 0;
      if ($10) { __label__ = 6; break; } else { __label__ = 5; break; }
    case 5: 
      var $12=$3;
      var $13=(($12)>>>0) >= 7;
      if ($13) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      var $15=$2;
      var $16=(($15+12)|0);
      var $17=HEAP32[(($16)>>2)];
      var $18=$3;
      var $19=_HPDF_RaiseError($17, 4210, $18);
      $1=$19;
      __label__ = 10; break;
    case 7: 
      var $21=$2;
      var $22=$3;
      var $23=((_HPDF_ANNOT_ICON_NAMES_NAMES+($22<<2))|0);
      var $24=HEAP32[(($23)>>2)];
      var $25=_HPDF_Dict_AddName($21, ((STRING_TABLE.__str27537)|0), $24);
      var $26=(($25)|0)!=0;
      if ($26) { __label__ = 8; break; } else { __label__ = 9; break; }
    case 8: 
      var $28=$2;
      var $29=(($28+12)|0);
      var $30=HEAP32[(($29)>>2)];
      var $31=_HPDF_CheckError($30);
      $1=$31;
      __label__ = 10; break;
    case 9: 
      $1=0;
      __label__ = 10; break;
    case 10: 
      var $34=$1;
      ;
      return $34;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Annotation_Validate($annot) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      $2=$annot;
      var $3=$2;
      var $4=(($3)|0)!=0;
      if ($4) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=0;
      __label__ = 7; break;
    case 4: 
      var $7=$2;
      var $8=(($7)|0);
      var $9=(($8+6)|0);
      var $10=HEAPU16[(($9)>>1)];
      var $11=(($10)&65535);
      var $12=(($11)|0)!=2065;
      if ($12) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      $1=0;
      __label__ = 7; break;
    case 6: 
      $1=1;
      __label__ = 7; break;
    case 7: 
      var $16=$1;
      ;
      return $16;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_TextAnnot_SetOpened($annot, $opened) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $b;
      $2=$annot;
      $3=$opened;
      var $4=$2;
      var $5=_CheckSubType($4, 0);
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=4124;
      __label__ = 7; break;
    case 4: 
      var $9=$2;
      var $10=(($9+8)|0);
      var $11=HEAP32[(($10)>>2)];
      var $12=$3;
      var $13=_HPDF_Boolean_New($11, $12);
      $b=$13;
      var $14=$b;
      var $15=(($14)|0)!=0;
      if ($15) { __label__ = 6; break; } else { __label__ = 5; break; }
    case 5: 
      var $17=$2;
      var $18=(($17+12)|0);
      var $19=HEAP32[(($18)>>2)];
      var $20=_HPDF_CheckError($19);
      $1=$20;
      __label__ = 7; break;
    case 6: 
      var $22=$2;
      var $23=$b;
      var $24=$23;
      var $25=_HPDF_Dict_Add($22, ((STRING_TABLE.__str28538)|0), $24);
      $1=$25;
      __label__ = 7; break;
    case 7: 
      var $27=$1;
      ;
      return $27;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Array_New($mmgr) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $obj;
      $1=$mmgr;
      var $2=$1;
      var $3=_HPDF_GetMem($2, 20);
      var $4=$3;
      $obj=$4;
      var $5=$obj;
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 3; break; } else { __label__ = 6; break; }
    case 3: 
      var $8=$obj;
      var $9=$8;
      var $10=_HPDF_MemSet($9, 0, 20);
      var $11=$obj;
      var $12=(($11)|0);
      var $13=(($12+6)|0);
      HEAP16[(($13)>>1)]=16;
      var $14=$1;
      var $15=$obj;
      var $16=(($15+8)|0);
      HEAP32[(($16)>>2)]=$14;
      var $17=$1;
      var $18=(($17)|0);
      var $19=HEAP32[(($18)>>2)];
      var $20=$obj;
      var $21=(($20+12)|0);
      HEAP32[(($21)>>2)]=$19;
      var $22=$1;
      var $23=_HPDF_List_New($22, 20);
      var $24=$obj;
      var $25=(($24+16)|0);
      HEAP32[(($25)>>2)]=$23;
      var $26=$obj;
      var $27=(($26+16)|0);
      var $28=HEAP32[(($27)>>2)];
      var $29=(($28)|0)!=0;
      if ($29) { __label__ = 5; break; } else { __label__ = 4; break; }
    case 4: 
      var $31=$1;
      var $32=$obj;
      var $33=$32;
      _HPDF_FreeMem($31, $33);
      $obj=0;
      __label__ = 5; break;
    case 5: 
      __label__ = 6; break;
    case 6: 
      var $36=$obj;
      ;
      return $36;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Box_Array_New($mmgr, $box_0, $box_1, $box_2, $box_3) {
  var __stackBase__  = STACKTOP; STACKTOP += 16; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $box=__stackBase__;
      var $obj;
      var $ret;
      $2=$mmgr;
      var $3=(($box)|0);
      HEAPF32[(($3)>>2)]=$box_0;
      var $4=(($box+4)|0);
      HEAPF32[(($4)>>2)]=$box_1;
      var $5=(($box+8)|0);
      HEAPF32[(($5)>>2)]=$box_2;
      var $6=(($box+12)|0);
      HEAPF32[(($6)>>2)]=$box_3;
      $ret=0;
      var $7=$2;
      var $8=_HPDF_Array_New($7);
      $obj=$8;
      var $9=$obj;
      var $10=(($9)|0)!=0;
      if ($10) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=0;
      __label__ = 7; break;
    case 4: 
      var $13=$obj;
      var $14=$2;
      var $15=(($box)|0);
      var $16=HEAPF32[(($15)>>2)];
      var $17=_HPDF_Real_New($14, $16);
      var $18=$17;
      var $19=_HPDF_Array_Add($13, $18);
      var $20=$ret;
      var $21=((($20)+($19))|0);
      $ret=$21;
      var $22=$obj;
      var $23=$2;
      var $24=(($box+4)|0);
      var $25=HEAPF32[(($24)>>2)];
      var $26=_HPDF_Real_New($23, $25);
      var $27=$26;
      var $28=_HPDF_Array_Add($22, $27);
      var $29=$ret;
      var $30=((($29)+($28))|0);
      $ret=$30;
      var $31=$obj;
      var $32=$2;
      var $33=(($box+8)|0);
      var $34=HEAPF32[(($33)>>2)];
      var $35=_HPDF_Real_New($32, $34);
      var $36=$35;
      var $37=_HPDF_Array_Add($31, $36);
      var $38=$ret;
      var $39=((($38)+($37))|0);
      $ret=$39;
      var $40=$obj;
      var $41=$2;
      var $42=(($box+12)|0);
      var $43=HEAPF32[(($42)>>2)];
      var $44=_HPDF_Real_New($41, $43);
      var $45=$44;
      var $46=_HPDF_Array_Add($40, $45);
      var $47=$ret;
      var $48=((($47)+($46))|0);
      $ret=$48;
      var $49=$ret;
      var $50=(($49)|0)!=0;
      if ($50) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $52=$obj;
      _HPDF_Array_Free($52);
      $1=0;
      __label__ = 7; break;
    case 6: 
      var $54=$obj;
      $1=$54;
      __label__ = 7; break;
    case 7: 
      var $56=$1;
      STACKTOP = __stackBase__;
      return $56;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Box_Array_New["X"]=1;

function _HPDF_Array_Add($array, $obj) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $header;
      var $ret;
      var $proxy;
      $2=$array;
      $3=$obj;
      var $4=$3;
      var $5=(($4)|0)!=0;
      if ($5) { __label__ = 6; break; } else { __label__ = 3; break; }
    case 3: 
      var $7=$2;
      var $8=(($7+12)|0);
      var $9=HEAP32[(($8)>>2)];
      var $10=_HPDF_Error_GetCode($9);
      var $11=(($10)|0)==0;
      if ($11) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      var $13=$2;
      var $14=(($13+12)|0);
      var $15=HEAP32[(($14)>>2)];
      var $16=_HPDF_SetError($15, 4147, 0);
      $1=$16;
      __label__ = 18; break;
    case 5: 
      $1=4147;
      __label__ = 18; break;
    case 6: 
      var $19=$3;
      var $20=$19;
      $header=$20;
      var $21=$header;
      var $22=(($21)|0);
      var $23=HEAP32[(($22)>>2)];
      var $24=$23 & -2147483648;
      var $25=(($24)|0)!=0;
      if ($25) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $27=$2;
      var $28=(($27+12)|0);
      var $29=HEAP32[(($28)>>2)];
      var $30=_HPDF_SetError($29, 4147, 0);
      $1=$30;
      __label__ = 18; break;
    case 8: 
      var $32=$2;
      var $33=(($32+16)|0);
      var $34=HEAP32[(($33)>>2)];
      var $35=(($34+16)|0);
      var $36=HEAPU32[(($35)>>2)];
      var $37=(($36)>>>0) >= 8191;
      if ($37) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      var $39=$2;
      var $40=(($39+8)|0);
      var $41=HEAP32[(($40)>>2)];
      var $42=$3;
      _HPDF_Obj_Free($41, $42);
      var $43=$2;
      var $44=(($43+12)|0);
      var $45=HEAP32[(($44)>>2)];
      var $46=_HPDF_SetError($45, 4097, 0);
      $1=$46;
      __label__ = 18; break;
    case 10: 
      var $48=$header;
      var $49=(($48)|0);
      var $50=HEAP32[(($49)>>2)];
      var $51=$50 & 1073741824;
      var $52=(($51)|0)!=0;
      if ($52) { __label__ = 11; break; } else { __label__ = 14; break; }
    case 11: 
      var $54=$2;
      var $55=(($54+8)|0);
      var $56=HEAP32[(($55)>>2)];
      var $57=$3;
      var $58=_HPDF_Proxy_New($56, $57);
      $proxy=$58;
      var $59=$proxy;
      var $60=(($59)|0)!=0;
      if ($60) { __label__ = 13; break; } else { __label__ = 12; break; }
    case 12: 
      var $62=$2;
      var $63=(($62+8)|0);
      var $64=HEAP32[(($63)>>2)];
      var $65=$3;
      _HPDF_Obj_Free($64, $65);
      var $66=$2;
      var $67=(($66+12)|0);
      var $68=HEAP32[(($67)>>2)];
      var $69=_HPDF_Error_GetCode($68);
      $1=$69;
      __label__ = 18; break;
    case 13: 
      var $71=$proxy;
      var $72=(($71)|0);
      var $73=(($72)|0);
      var $74=HEAP32[(($73)>>2)];
      var $75=$74 | -2147483648;
      HEAP32[(($73)>>2)]=$75;
      var $76=$proxy;
      var $77=$76;
      $3=$77;
      __label__ = 15; break;
    case 14: 
      var $79=$header;
      var $80=(($79)|0);
      var $81=HEAP32[(($80)>>2)];
      var $82=$81 | -2147483648;
      HEAP32[(($80)>>2)]=$82;
      __label__ = 15; break;
    case 15: 
      var $84=$2;
      var $85=(($84+16)|0);
      var $86=HEAP32[(($85)>>2)];
      var $87=$3;
      var $88=_HPDF_List_Add($86, $87);
      $ret=$88;
      var $89=$ret;
      var $90=(($89)|0)!=0;
      if ($90) { __label__ = 16; break; } else { __label__ = 17; break; }
    case 16: 
      var $92=$2;
      var $93=(($92+8)|0);
      var $94=HEAP32[(($93)>>2)];
      var $95=$3;
      _HPDF_Obj_Free($94, $95);
      __label__ = 17; break;
    case 17: 
      var $97=$ret;
      $1=$97;
      __label__ = 18; break;
    case 18: 
      var $99=$1;
      ;
      return $99;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Array_Add["X"]=1;

function _HPDF_Array_Free($array) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      $1=$array;
      var $2=$1;
      var $3=(($2)|0)!=0;
      if ($3) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      __label__ = 5; break;
    case 4: 
      var $6=$1;
      _HPDF_Array_Clear($6);
      var $7=$1;
      var $8=(($7+16)|0);
      var $9=HEAP32[(($8)>>2)];
      _HPDF_List_Free($9);
      var $10=$1;
      var $11=(($10)|0);
      var $12=(($11+6)|0);
      HEAP16[(($12)>>1)]=0;
      var $13=$1;
      var $14=(($13+8)|0);
      var $15=HEAP32[(($14)>>2)];
      var $16=$1;
      var $17=$16;
      _HPDF_FreeMem($15, $17);
      __label__ = 5; break;
    case 5: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Array_Clear($array) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $i;
      var $obj;
      $1=$array;
      var $2=$1;
      var $3=(($2)|0)!=0;
      if ($3) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      __label__ = 11; break;
    case 4: 
      $i=0;
      __label__ = 5; break;
    case 5: 
      var $7=$i;
      var $8=$1;
      var $9=(($8+16)|0);
      var $10=HEAP32[(($9)>>2)];
      var $11=(($10+16)|0);
      var $12=HEAPU32[(($11)>>2)];
      var $13=(($7)>>>0) < (($12)>>>0);
      if ($13) { __label__ = 6; break; } else { __label__ = 10; break; }
    case 6: 
      var $15=$1;
      var $16=(($15+16)|0);
      var $17=HEAP32[(($16)>>2)];
      var $18=$i;
      var $19=_HPDF_List_ItemAt($17, $18);
      $obj=$19;
      var $20=$obj;
      var $21=(($20)|0)!=0;
      if ($21) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $23=$1;
      var $24=(($23+8)|0);
      var $25=HEAP32[(($24)>>2)];
      var $26=$obj;
      _HPDF_Obj_Free($25, $26);
      __label__ = 8; break;
    case 8: 
      __label__ = 9; break;
    case 9: 
      var $29=$i;
      var $30=((($29)+(1))|0);
      $i=$30;
      __label__ = 5; break;
    case 10: 
      var $32=$1;
      var $33=(($32+16)|0);
      var $34=HEAP32[(($33)>>2)];
      _HPDF_List_Clear($34);
      __label__ = 11; break;
    case 11: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Array_Write($array, $stream, $e) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $i;
      var $ret;
      var $element;
      $2=$array;
      $3=$stream;
      $4=$e;
      var $5=$3;
      var $6=_HPDF_Stream_WriteStr($5, ((STRING_TABLE.__str560)|0));
      $ret=$6;
      var $7=$ret;
      var $8=(($7)|0)!=0;
      if ($8) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $10=$ret;
      $1=$10;
      __label__ = 13; break;
    case 4: 
      $i=0;
      __label__ = 5; break;
    case 5: 
      var $13=$i;
      var $14=$2;
      var $15=(($14+16)|0);
      var $16=HEAP32[(($15)>>2)];
      var $17=(($16+16)|0);
      var $18=HEAPU32[(($17)>>2)];
      var $19=(($13)>>>0) < (($18)>>>0);
      if ($19) { __label__ = 6; break; } else { __label__ = 12; break; }
    case 6: 
      var $21=$2;
      var $22=(($21+16)|0);
      var $23=HEAP32[(($22)>>2)];
      var $24=$i;
      var $25=_HPDF_List_ItemAt($23, $24);
      $element=$25;
      var $26=$element;
      var $27=$3;
      var $28=$4;
      var $29=_HPDF_Obj_Write($26, $27, $28);
      $ret=$29;
      var $30=$ret;
      var $31=(($30)|0)!=0;
      if ($31) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $33=$ret;
      $1=$33;
      __label__ = 13; break;
    case 8: 
      var $35=$3;
      var $36=_HPDF_Stream_WriteChar($35, 32);
      $ret=$36;
      var $37=$ret;
      var $38=(($37)|0)!=0;
      if ($38) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      var $40=$ret;
      $1=$40;
      __label__ = 13; break;
    case 10: 
      __label__ = 11; break;
    case 11: 
      var $43=$i;
      var $44=((($43)+(1))|0);
      $i=$44;
      __label__ = 5; break;
    case 12: 
      var $46=$3;
      var $47=_HPDF_Stream_WriteChar($46, 93);
      $ret=$47;
      var $48=$ret;
      $1=$48;
      __label__ = 13; break;
    case 13: 
      var $50=$1;
      ;
      return $50;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Array_Write["X"]=1;

function _HPDF_Array_AddNumber($array, $value) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $n;
      $2=$array;
      $3=$value;
      var $4=$2;
      var $5=(($4+8)|0);
      var $6=HEAP32[(($5)>>2)];
      var $7=$3;
      var $8=_HPDF_Number_New($6, $7);
      $n=$8;
      var $9=$n;
      var $10=(($9)|0)!=0;
      if ($10) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      var $12=$2;
      var $13=(($12+12)|0);
      var $14=HEAP32[(($13)>>2)];
      var $15=_HPDF_Error_GetCode($14);
      $1=$15;
      __label__ = 5; break;
    case 4: 
      var $17=$2;
      var $18=$n;
      var $19=$18;
      var $20=_HPDF_Array_Add($17, $19);
      $1=$20;
      __label__ = 5; break;
    case 5: 
      var $22=$1;
      ;
      return $22;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Array_AddReal($array, $value) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $r;
      $2=$array;
      $3=$value;
      var $4=$2;
      var $5=(($4+8)|0);
      var $6=HEAP32[(($5)>>2)];
      var $7=$3;
      var $8=_HPDF_Real_New($6, $7);
      $r=$8;
      var $9=$r;
      var $10=(($9)|0)!=0;
      if ($10) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      var $12=$2;
      var $13=(($12+12)|0);
      var $14=HEAP32[(($13)>>2)];
      var $15=_HPDF_Error_GetCode($14);
      $1=$15;
      __label__ = 5; break;
    case 4: 
      var $17=$2;
      var $18=$r;
      var $19=$18;
      var $20=_HPDF_Array_Add($17, $19);
      $1=$20;
      __label__ = 5; break;
    case 5: 
      var $22=$1;
      ;
      return $22;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Array_AddName($array, $value) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $n;
      $2=$array;
      $3=$value;
      var $4=$2;
      var $5=(($4+8)|0);
      var $6=HEAP32[(($5)>>2)];
      var $7=$3;
      var $8=_HPDF_Name_New($6, $7);
      $n=$8;
      var $9=$n;
      var $10=(($9)|0)!=0;
      if ($10) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      var $12=$2;
      var $13=(($12+12)|0);
      var $14=HEAP32[(($13)>>2)];
      var $15=_HPDF_Error_GetCode($14);
      $1=$15;
      __label__ = 5; break;
    case 4: 
      var $17=$2;
      var $18=$n;
      var $19=$18;
      var $20=_HPDF_Array_Add($17, $19);
      $1=$20;
      __label__ = 5; break;
    case 5: 
      var $22=$1;
      ;
      return $22;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Array_Insert($array, $target, $obj) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $header;
      var $ret;
      var $i;
      var $proxy;
      var $ptr;
      var $obj_ptr;
      $2=$array;
      $3=$target;
      $4=$obj;
      var $5=$4;
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 6; break; } else { __label__ = 3; break; }
    case 3: 
      var $8=$2;
      var $9=(($8+12)|0);
      var $10=HEAP32[(($9)>>2)];
      var $11=_HPDF_Error_GetCode($10);
      var $12=(($11)|0)==0;
      if ($12) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      var $14=$2;
      var $15=(($14+12)|0);
      var $16=HEAP32[(($15)>>2)];
      var $17=_HPDF_SetError($16, 4147, 0);
      $1=$17;
      __label__ = 27; break;
    case 5: 
      $1=4147;
      __label__ = 27; break;
    case 6: 
      var $20=$4;
      var $21=$20;
      $header=$21;
      var $22=$header;
      var $23=(($22)|0);
      var $24=HEAP32[(($23)>>2)];
      var $25=$24 & -2147483648;
      var $26=(($25)|0)!=0;
      if ($26) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $28=$2;
      var $29=(($28+12)|0);
      var $30=HEAP32[(($29)>>2)];
      var $31=_HPDF_SetError($30, 4147, 0);
      $1=$31;
      __label__ = 27; break;
    case 8: 
      var $33=$2;
      var $34=(($33+16)|0);
      var $35=HEAP32[(($34)>>2)];
      var $36=(($35+16)|0);
      var $37=HEAPU32[(($36)>>2)];
      var $38=(($37)>>>0) >= 8191;
      if ($38) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      var $40=$2;
      var $41=(($40+8)|0);
      var $42=HEAP32[(($41)>>2)];
      var $43=$4;
      _HPDF_Obj_Free($42, $43);
      var $44=$2;
      var $45=(($44+12)|0);
      var $46=HEAP32[(($45)>>2)];
      var $47=_HPDF_SetError($46, 4097, 0);
      $1=$47;
      __label__ = 27; break;
    case 10: 
      var $49=$header;
      var $50=(($49)|0);
      var $51=HEAP32[(($50)>>2)];
      var $52=$51 & 1073741824;
      var $53=(($52)|0)!=0;
      if ($53) { __label__ = 11; break; } else { __label__ = 14; break; }
    case 11: 
      var $55=$2;
      var $56=(($55+8)|0);
      var $57=HEAP32[(($56)>>2)];
      var $58=$4;
      var $59=_HPDF_Proxy_New($57, $58);
      $proxy=$59;
      var $60=$proxy;
      var $61=(($60)|0)!=0;
      if ($61) { __label__ = 13; break; } else { __label__ = 12; break; }
    case 12: 
      var $63=$2;
      var $64=(($63+8)|0);
      var $65=HEAP32[(($64)>>2)];
      var $66=$4;
      _HPDF_Obj_Free($65, $66);
      var $67=$2;
      var $68=(($67+12)|0);
      var $69=HEAP32[(($68)>>2)];
      var $70=_HPDF_Error_GetCode($69);
      $1=$70;
      __label__ = 27; break;
    case 13: 
      var $72=$proxy;
      var $73=(($72)|0);
      var $74=(($73)|0);
      var $75=HEAP32[(($74)>>2)];
      var $76=$75 | -2147483648;
      HEAP32[(($74)>>2)]=$76;
      var $77=$proxy;
      var $78=$77;
      $4=$78;
      __label__ = 15; break;
    case 14: 
      var $80=$header;
      var $81=(($80)|0);
      var $82=HEAP32[(($81)>>2)];
      var $83=$82 | -2147483648;
      HEAP32[(($81)>>2)]=$83;
      __label__ = 15; break;
    case 15: 
      $i=0;
      __label__ = 16; break;
    case 16: 
      var $86=$i;
      var $87=$2;
      var $88=(($87+16)|0);
      var $89=HEAP32[(($88)>>2)];
      var $90=(($89+16)|0);
      var $91=HEAPU32[(($90)>>2)];
      var $92=(($86)>>>0) < (($91)>>>0);
      if ($92) { __label__ = 17; break; } else { __label__ = 26; break; }
    case 17: 
      var $94=$2;
      var $95=(($94+16)|0);
      var $96=HEAP32[(($95)>>2)];
      var $97=$i;
      var $98=_HPDF_List_ItemAt($96, $97);
      $ptr=$98;
      var $99=$4;
      var $100=$99;
      $header=$100;
      var $101=$header;
      var $102=(($101+6)|0);
      var $103=HEAPU16[(($102)>>1)];
      var $104=(($103)&65535);
      var $105=(($104)|0)==18;
      if ($105) { __label__ = 18; break; } else { __label__ = 19; break; }
    case 18: 
      var $107=$ptr;
      var $108=$107;
      var $109=(($108+8)|0);
      var $110=HEAP32[(($109)>>2)];
      $obj_ptr=$110;
      __label__ = 20; break;
    case 19: 
      var $112=$ptr;
      $obj_ptr=$112;
      __label__ = 20; break;
    case 20: 
      var $114=$obj_ptr;
      var $115=$3;
      var $116=(($114)|0)==(($115)|0);
      if ($116) { __label__ = 21; break; } else { __label__ = 24; break; }
    case 21: 
      var $118=$2;
      var $119=(($118+16)|0);
      var $120=HEAP32[(($119)>>2)];
      var $121=$ptr;
      var $122=$4;
      var $123=_HPDF_List_Insert($120, $121, $122);
      $ret=$123;
      var $124=$ret;
      var $125=(($124)|0)!=0;
      if ($125) { __label__ = 22; break; } else { __label__ = 23; break; }
    case 22: 
      var $127=$2;
      var $128=(($127+8)|0);
      var $129=HEAP32[(($128)>>2)];
      var $130=$4;
      _HPDF_Obj_Free($129, $130);
      __label__ = 23; break;
    case 23: 
      var $132=$ret;
      $1=$132;
      __label__ = 27; break;
    case 24: 
      __label__ = 25; break;
    case 25: 
      var $135=$i;
      var $136=((($135)+(1))|0);
      $i=$136;
      __label__ = 16; break;
    case 26: 
      var $138=$2;
      var $139=(($138+8)|0);
      var $140=HEAP32[(($139)>>2)];
      var $141=$4;
      _HPDF_Obj_Free($140, $141);
      $1=4162;
      __label__ = 27; break;
    case 27: 
      var $143=$1;
      ;
      return $143;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Array_Insert["X"]=1;

function _HPDF_Array_GetItem($array, $index, $obj_class) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $obj;
      var $header;
      $2=$array;
      $3=$index;
      $4=$obj_class;
      var $5=$2;
      var $6=(($5+16)|0);
      var $7=HEAP32[(($6)>>2)];
      var $8=$3;
      var $9=_HPDF_List_ItemAt($7, $8);
      $obj=$9;
      var $10=$obj;
      var $11=(($10)|0)!=0;
      if ($11) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      var $13=$2;
      var $14=(($13+12)|0);
      var $15=HEAP32[(($14)>>2)];
      var $16=_HPDF_SetError($15, 4098, 0);
      $1=0;
      __label__ = 9; break;
    case 4: 
      var $18=$obj;
      var $19=$18;
      $header=$19;
      var $20=$header;
      var $21=(($20+6)|0);
      var $22=HEAPU16[(($21)>>1)];
      var $23=(($22)&65535);
      var $24=(($23)|0)==18;
      if ($24) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $26=$obj;
      var $27=$26;
      var $28=(($27+8)|0);
      var $29=HEAP32[(($28)>>2)];
      $obj=$29;
      var $30=$obj;
      var $31=$30;
      $header=$31;
      __label__ = 6; break;
    case 6: 
      var $33=$header;
      var $34=(($33+6)|0);
      var $35=HEAPU16[(($34)>>1)];
      var $36=(($35)&65535);
      var $37=$36 & 255;
      var $38=$4;
      var $39=(($38)&65535);
      var $40=(($37)|0)!=(($39)|0);
      if ($40) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $42=$2;
      var $43=(($42+12)|0);
      var $44=HEAP32[(($43)>>2)];
      var $45=_HPDF_SetError($44, 4099, 0);
      $1=0;
      __label__ = 9; break;
    case 8: 
      var $47=$obj;
      $1=$47;
      __label__ = 9; break;
    case 9: 
      var $49=$1;
      ;
      return $49;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Array_GetItem["X"]=1;

function _HPDF_Binary_New($mmgr, $value, $len) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $obj;
      $2=$mmgr;
      $3=$value;
      $4=$len;
      var $5=$2;
      var $6=_HPDF_GetMem($5, 24);
      var $7=$6;
      $obj=$7;
      var $8=$obj;
      var $9=(($8)|0)!=0;
      if ($9) { __label__ = 3; break; } else { __label__ = 6; break; }
    case 3: 
      var $11=$obj;
      var $12=(($11)|0);
      var $13=$12;
      var $14=_HPDF_MemSet($13, 0, 8);
      var $15=$obj;
      var $16=(($15)|0);
      var $17=(($16+6)|0);
      HEAP16[(($17)>>1)]=8;
      var $18=$2;
      var $19=$obj;
      var $20=(($19+8)|0);
      HEAP32[(($20)>>2)]=$18;
      var $21=$2;
      var $22=(($21)|0);
      var $23=HEAP32[(($22)>>2)];
      var $24=$obj;
      var $25=(($24+12)|0);
      HEAP32[(($25)>>2)]=$23;
      var $26=$obj;
      var $27=(($26+16)|0);
      HEAP32[(($27)>>2)]=0;
      var $28=$obj;
      var $29=(($28+20)|0);
      HEAP32[(($29)>>2)]=0;
      var $30=$obj;
      var $31=$3;
      var $32=$4;
      var $33=_HPDF_Binary_SetValue($30, $31, $32);
      var $34=(($33)|0)!=0;
      if ($34) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      var $36=$2;
      var $37=$obj;
      var $38=$37;
      _HPDF_FreeMem($36, $38);
      $1=0;
      __label__ = 7; break;
    case 5: 
      __label__ = 6; break;
    case 6: 
      var $41=$obj;
      $1=$41;
      __label__ = 7; break;
    case 7: 
      var $43=$1;
      ;
      return $43;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Binary_New["X"]=1;

function _HPDF_Binary_SetValue($obj, $value, $len) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      $2=$obj;
      $3=$value;
      $4=$len;
      var $5=$4;
      var $6=(($5)>>>0) > 65535;
      if ($6) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $8=$2;
      var $9=(($8+12)|0);
      var $10=HEAP32[(($9)>>2)];
      var $11=_HPDF_SetError($10, 4100, 0);
      $1=$11;
      __label__ = 9; break;
    case 4: 
      var $13=$2;
      var $14=(($13+16)|0);
      var $15=HEAP32[(($14)>>2)];
      var $16=(($15)|0)!=0;
      if ($16) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $18=$2;
      var $19=(($18+8)|0);
      var $20=HEAP32[(($19)>>2)];
      var $21=$2;
      var $22=(($21+16)|0);
      var $23=HEAP32[(($22)>>2)];
      _HPDF_FreeMem($20, $23);
      var $24=$2;
      var $25=(($24+20)|0);
      HEAP32[(($25)>>2)]=0;
      __label__ = 6; break;
    case 6: 
      var $27=$2;
      var $28=(($27+8)|0);
      var $29=HEAP32[(($28)>>2)];
      var $30=$4;
      var $31=_HPDF_GetMem($29, $30);
      var $32=$2;
      var $33=(($32+16)|0);
      HEAP32[(($33)>>2)]=$31;
      var $34=$2;
      var $35=(($34+16)|0);
      var $36=HEAP32[(($35)>>2)];
      var $37=(($36)|0)!=0;
      if ($37) { __label__ = 8; break; } else { __label__ = 7; break; }
    case 7: 
      var $39=$2;
      var $40=(($39+12)|0);
      var $41=HEAP32[(($40)>>2)];
      var $42=_HPDF_Error_GetCode($41);
      $1=$42;
      __label__ = 9; break;
    case 8: 
      var $44=$2;
      var $45=(($44+16)|0);
      var $46=HEAP32[(($45)>>2)];
      var $47=$3;
      var $48=$4;
      var $49=_HPDF_MemCpy($46, $47, $48);
      var $50=$4;
      var $51=$2;
      var $52=(($51+20)|0);
      HEAP32[(($52)>>2)]=$50;
      $1=0;
      __label__ = 9; break;
    case 9: 
      var $54=$1;
      ;
      return $54;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Binary_SetValue["X"]=1;

function _HPDF_Binary_Write($obj, $stream, $e) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $ret;
      $2=$obj;
      $3=$stream;
      $4=$e;
      var $5=$2;
      var $6=(($5+20)|0);
      var $7=HEAP32[(($6)>>2)];
      var $8=(($7)|0)==0;
      if ($8) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $10=$3;
      var $11=_HPDF_Stream_WriteStr($10, ((STRING_TABLE.__str569)|0));
      $1=$11;
      __label__ = 11; break;
    case 4: 
      var $13=$3;
      var $14=_HPDF_Stream_WriteChar($13, 60);
      $ret=$14;
      var $15=(($14)|0)!=0;
      if ($15) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $17=$ret;
      $1=$17;
      __label__ = 11; break;
    case 6: 
      var $19=$4;
      var $20=(($19)|0)!=0;
      if ($20) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $22=$4;
      _HPDF_Encrypt_Reset($22);
      __label__ = 8; break;
    case 8: 
      var $24=$3;
      var $25=$2;
      var $26=(($25+16)|0);
      var $27=HEAP32[(($26)>>2)];
      var $28=$2;
      var $29=(($28+20)|0);
      var $30=HEAP32[(($29)>>2)];
      var $31=$4;
      var $32=_HPDF_Stream_WriteBinary($24, $27, $30, $31);
      $ret=$32;
      var $33=(($32)|0)!=0;
      if ($33) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      var $35=$ret;
      $1=$35;
      __label__ = 11; break;
    case 10: 
      var $37=$3;
      var $38=_HPDF_Stream_WriteChar($37, 62);
      $1=$38;
      __label__ = 11; break;
    case 11: 
      var $40=$1;
      ;
      return $40;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Binary_Write["X"]=1;

function _HPDF_Binary_Free($obj) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      $1=$obj;
      var $2=$1;
      var $3=(($2)|0)!=0;
      if ($3) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      __label__ = 7; break;
    case 4: 
      var $6=$1;
      var $7=(($6+16)|0);
      var $8=HEAP32[(($7)>>2)];
      var $9=(($8)|0)!=0;
      if ($9) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $11=$1;
      var $12=(($11+8)|0);
      var $13=HEAP32[(($12)>>2)];
      var $14=$1;
      var $15=(($14+16)|0);
      var $16=HEAP32[(($15)>>2)];
      _HPDF_FreeMem($13, $16);
      __label__ = 6; break;
    case 6: 
      var $18=$1;
      var $19=(($18+8)|0);
      var $20=HEAP32[(($19)>>2)];
      var $21=$1;
      var $22=$21;
      _HPDF_FreeMem($20, $22);
      __label__ = 7; break;
    case 7: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Boolean_New($mmgr, $value) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $obj;
      $1=$mmgr;
      $2=$value;
      var $3=$1;
      var $4=_HPDF_GetMem($3, 12);
      var $5=$4;
      $obj=$5;
      var $6=$obj;
      var $7=(($6)|0)!=0;
      if ($7) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $9=$obj;
      var $10=(($9)|0);
      var $11=$10;
      var $12=_HPDF_MemSet($11, 0, 8);
      var $13=$obj;
      var $14=(($13)|0);
      var $15=(($14+6)|0);
      HEAP16[(($15)>>1)]=3;
      var $16=$2;
      var $17=$obj;
      var $18=(($17+8)|0);
      HEAP32[(($18)>>2)]=$16;
      __label__ = 4; break;
    case 4: 
      var $20=$obj;
      ;
      return $20;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Boolean_Write($obj, $stream) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $ret;
      $1=$obj;
      $2=$stream;
      var $3=$1;
      var $4=(($3+8)|0);
      var $5=HEAP32[(($4)>>2)];
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $8=$2;
      var $9=_HPDF_Stream_WriteStr($8, ((STRING_TABLE.__str570)|0));
      $ret=$9;
      __label__ = 5; break;
    case 4: 
      var $11=$2;
      var $12=_HPDF_Stream_WriteStr($11, ((STRING_TABLE.__str1571)|0));
      $ret=$12;
      __label__ = 5; break;
    case 5: 
      var $14=$ret;
      ;
      return $14;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Catalog_New($mmgr, $xref) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $catalog;
      var $ret;
      $2=$mmgr;
      $3=$xref;
      $ret=0;
      var $4=$2;
      var $5=_HPDF_Dict_New($4);
      $catalog=$5;
      var $6=$catalog;
      var $7=(($6)|0)!=0;
      if ($7) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=0;
      __label__ = 9; break;
    case 4: 
      var $10=$catalog;
      var $11=(($10)|0);
      var $12=(($11+6)|0);
      var $13=HEAPU16[(($12)>>1)];
      var $14=(($13)&65535);
      var $15=$14 | 512;
      var $16=(($15) & 65535);
      HEAP16[(($12)>>1)]=$16;
      var $17=$3;
      var $18=$catalog;
      var $19=$18;
      var $20=_HPDF_Xref_Add($17, $19);
      var $21=(($20)|0)!=0;
      if ($21) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      $1=0;
      __label__ = 9; break;
    case 6: 
      var $24=$catalog;
      var $25=_HPDF_Dict_AddName($24, ((STRING_TABLE.__str574)|0), ((STRING_TABLE.__str1575)|0));
      var $26=$ret;
      var $27=((($26)+($25))|0);
      $ret=$27;
      var $28=$catalog;
      var $29=$2;
      var $30=$3;
      var $31=_HPDF_Pages_New($29, 0, $30);
      var $32=$31;
      var $33=_HPDF_Dict_Add($28, ((STRING_TABLE.__str2576)|0), $32);
      var $34=$ret;
      var $35=((($34)+($33))|0);
      $ret=$35;
      var $36=$ret;
      var $37=(($36)|0)!=0;
      if ($37) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      $1=0;
      __label__ = 9; break;
    case 8: 
      var $40=$catalog;
      $1=$40;
      __label__ = 9; break;
    case 9: 
      var $42=$1;
      ;
      return $42;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Catalog_New["X"]=1;

function _HPDF_Catalog_GetRoot($catalog) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $pages;
      $2=$catalog;
      var $3=$2;
      var $4=(($3)|0)!=0;
      if ($4) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=0;
      __label__ = 8; break;
    case 4: 
      var $7=$2;
      var $8=_HPDF_Dict_GetItem($7, ((STRING_TABLE.__str2576)|0), 17);
      var $9=$8;
      $pages=$9;
      var $10=$pages;
      var $11=(($10)|0)!=0;
      if ($11) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $13=$pages;
      var $14=(($13)|0);
      var $15=(($14+6)|0);
      var $16=HEAPU16[(($15)>>1)];
      var $17=(($16)&65535);
      var $18=(($17)|0)!=785;
      if ($18) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      var $20=$2;
      var $21=(($20+12)|0);
      var $22=HEAP32[(($21)>>2)];
      var $23=_HPDF_SetError($22, 4171, 0);
      __label__ = 7; break;
    case 7: 
      var $25=$pages;
      $1=$25;
      __label__ = 8; break;
    case 8: 
      var $27=$1;
      ;
      return $27;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Catalog_GetPageLayout($catalog) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $layout;
      var $i;
      $2=$catalog;
      $i=0;
      var $3=$2;
      var $4=_HPDF_Dict_GetItem($3, ((STRING_TABLE.__str3577)|0), 6);
      var $5=$4;
      $layout=$5;
      var $6=$layout;
      var $7=(($6)|0)!=0;
      if ($7) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=4;
      __label__ = 10; break;
    case 4: 
      __label__ = 5; break;
    case 5: 
      var $11=$i;
      var $12=((_HPDF_PAGE_LAYOUT_NAMES+($11<<2))|0);
      var $13=HEAP32[(($12)>>2)];
      var $14=(($13)|0)!=0;
      if ($14) { __label__ = 6; break; } else { __label__ = 9; break; }
    case 6: 
      var $16=$layout;
      var $17=(($16+12)|0);
      var $18=(($17)|0);
      var $19=$i;
      var $20=((_HPDF_PAGE_LAYOUT_NAMES+($19<<2))|0);
      var $21=HEAP32[(($20)>>2)];
      var $22=_HPDF_StrCmp($18, $21);
      var $23=(($22)|0)==0;
      if ($23) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $25=$i;
      $1=$25;
      __label__ = 10; break;
    case 8: 
      var $27=$i;
      var $28=((($27)+(1))|0);
      $i=$28;
      __label__ = 5; break;
    case 9: 
      $1=4;
      __label__ = 10; break;
    case 10: 
      var $31=$1;
      ;
      return $31;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Catalog_SetPageLayout($catalog, $layout) {
  ;
  var __label__;

  var $1;
  var $2;
  $1=$catalog;
  $2=$layout;
  var $3=$1;
  var $4=$2;
  var $5=((_HPDF_PAGE_LAYOUT_NAMES+($4<<2))|0);
  var $6=HEAP32[(($5)>>2)];
  var $7=_HPDF_Dict_AddName($3, ((STRING_TABLE.__str3577)|0), $6);
  ;
  return $7;
}


function _HPDF_Catalog_GetPageMode($catalog) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $mode;
      var $i;
      $2=$catalog;
      $i=0;
      var $3=$2;
      var $4=_HPDF_Dict_GetItem($3, ((STRING_TABLE.__str4578)|0), 6);
      var $5=$4;
      $mode=$5;
      var $6=$mode;
      var $7=(($6)|0)!=0;
      if ($7) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=0;
      __label__ = 10; break;
    case 4: 
      __label__ = 5; break;
    case 5: 
      var $11=$i;
      var $12=((_HPDF_PAGE_MODE_NAMES+($11<<2))|0);
      var $13=HEAP32[(($12)>>2)];
      var $14=(($13)|0)!=0;
      if ($14) { __label__ = 6; break; } else { __label__ = 9; break; }
    case 6: 
      var $16=$mode;
      var $17=(($16+12)|0);
      var $18=(($17)|0);
      var $19=$i;
      var $20=((_HPDF_PAGE_MODE_NAMES+($19<<2))|0);
      var $21=HEAP32[(($20)>>2)];
      var $22=_HPDF_StrCmp($18, $21);
      var $23=(($22)|0)==0;
      if ($23) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $25=$i;
      $1=$25;
      __label__ = 10; break;
    case 8: 
      var $27=$i;
      var $28=((($27)+(1))|0);
      $i=$28;
      __label__ = 5; break;
    case 9: 
      $1=0;
      __label__ = 10; break;
    case 10: 
      var $31=$1;
      ;
      return $31;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Catalog_SetPageMode($catalog, $mode) {
  ;
  var __label__;

  var $1;
  var $2;
  $1=$catalog;
  $2=$mode;
  var $3=$1;
  var $4=$2;
  var $5=((_HPDF_PAGE_MODE_NAMES+($4<<2))|0);
  var $6=HEAP32[(($5)>>2)];
  var $7=_HPDF_Dict_AddName($3, ((STRING_TABLE.__str4578)|0), $6);
  ;
  return $7;
}


function _HPDF_Catalog_SetOpenAction($catalog, $open_action) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      $2=$catalog;
      $3=$open_action;
      var $4=$3;
      var $5=(($4)|0)!=0;
      if ($5) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      var $7=$2;
      var $8=_HPDF_Dict_RemoveElement($7, ((STRING_TABLE.__str5579)|0));
      $1=0;
      __label__ = 5; break;
    case 4: 
      var $10=$2;
      var $11=$3;
      var $12=$11;
      var $13=_HPDF_Dict_Add($10, ((STRING_TABLE.__str5579)|0), $12);
      $1=$13;
      __label__ = 5; break;
    case 5: 
      var $15=$1;
      ;
      return $15;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Catalog_AddPageLabel($catalog, $page_num, $page_label) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $ret;
      var $nums;
      var $labels;
      $2=$catalog;
      $3=$page_num;
      $4=$page_label;
      var $5=$2;
      var $6=_HPDF_Dict_GetItem($5, ((STRING_TABLE.__str6580)|0), 17);
      var $7=$6;
      $labels=$7;
      var $8=$labels;
      var $9=(($8)|0)!=0;
      if ($9) { __label__ = 8; break; } else { __label__ = 3; break; }
    case 3: 
      var $11=$2;
      var $12=(($11+8)|0);
      var $13=HEAP32[(($12)>>2)];
      var $14=_HPDF_Dict_New($13);
      $labels=$14;
      var $15=$labels;
      var $16=(($15)|0)!=0;
      if ($16) { __label__ = 5; break; } else { __label__ = 4; break; }
    case 4: 
      var $18=$2;
      var $19=(($18+12)|0);
      var $20=HEAP32[(($19)>>2)];
      var $21=(($20)|0);
      var $22=HEAP32[(($21)>>2)];
      $1=$22;
      __label__ = 17; break;
    case 5: 
      var $24=$2;
      var $25=$labels;
      var $26=$25;
      var $27=_HPDF_Dict_Add($24, ((STRING_TABLE.__str6580)|0), $26);
      $ret=$27;
      var $28=(($27)|0)!=0;
      if ($28) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      var $30=$ret;
      $1=$30;
      __label__ = 17; break;
    case 7: 
      __label__ = 8; break;
    case 8: 
      var $33=$labels;
      var $34=_HPDF_Dict_GetItem($33, ((STRING_TABLE.__str7581)|0), 16);
      var $35=$34;
      $nums=$35;
      var $36=$nums;
      var $37=(($36)|0)!=0;
      if ($37) { __label__ = 14; break; } else { __label__ = 9; break; }
    case 9: 
      var $39=$2;
      var $40=(($39+8)|0);
      var $41=HEAP32[(($40)>>2)];
      var $42=_HPDF_Array_New($41);
      $nums=$42;
      var $43=$nums;
      var $44=(($43)|0)!=0;
      if ($44) { __label__ = 11; break; } else { __label__ = 10; break; }
    case 10: 
      var $46=$2;
      var $47=(($46+12)|0);
      var $48=HEAP32[(($47)>>2)];
      var $49=(($48)|0);
      var $50=HEAP32[(($49)>>2)];
      $1=$50;
      __label__ = 17; break;
    case 11: 
      var $52=$labels;
      var $53=$nums;
      var $54=$53;
      var $55=_HPDF_Dict_Add($52, ((STRING_TABLE.__str7581)|0), $54);
      $ret=$55;
      var $56=(($55)|0)!=0;
      if ($56) { __label__ = 12; break; } else { __label__ = 13; break; }
    case 12: 
      var $58=$ret;
      $1=$58;
      __label__ = 17; break;
    case 13: 
      __label__ = 14; break;
    case 14: 
      var $61=$nums;
      var $62=$3;
      var $63=_HPDF_Array_AddNumber($61, $62);
      $ret=$63;
      var $64=(($63)|0)!=0;
      if ($64) { __label__ = 15; break; } else { __label__ = 16; break; }
    case 15: 
      var $66=$ret;
      $1=$66;
      __label__ = 17; break;
    case 16: 
      var $68=$nums;
      var $69=$4;
      var $70=$69;
      var $71=_HPDF_Array_Add($68, $70);
      $1=$71;
      __label__ = 17; break;
    case 17: 
      var $73=$1;
      ;
      return $73;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Catalog_AddPageLabel["X"]=1;

function _HPDF_Catalog_SetViewerPreference($catalog, $value) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $ret;
      var $preferences;
      $2=$catalog;
      $3=$value;
      var $4=$3;
      var $5=(($4)|0)!=0;
      if ($5) { __label__ = 6; break; } else { __label__ = 3; break; }
    case 3: 
      var $7=$2;
      var $8=_HPDF_Dict_RemoveElement($7, ((STRING_TABLE.__str8582)|0));
      $ret=$8;
      var $9=$ret;
      var $10=(($9)|0)==4104;
      if ($10) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      $ret=0;
      __label__ = 5; break;
    case 5: 
      var $13=$ret;
      $1=$13;
      __label__ = 56; break;
    case 6: 
      var $15=$2;
      var $16=(($15+8)|0);
      var $17=HEAP32[(($16)>>2)];
      var $18=_HPDF_Dict_New($17);
      $preferences=$18;
      var $19=$preferences;
      var $20=(($19)|0)!=0;
      if ($20) { __label__ = 8; break; } else { __label__ = 7; break; }
    case 7: 
      var $22=$2;
      var $23=(($22+12)|0);
      var $24=HEAP32[(($23)>>2)];
      var $25=(($24)|0);
      var $26=HEAP32[(($25)>>2)];
      $1=$26;
      __label__ = 56; break;
    case 8: 
      var $28=$2;
      var $29=$preferences;
      var $30=$29;
      var $31=_HPDF_Dict_Add($28, ((STRING_TABLE.__str8582)|0), $30);
      $ret=$31;
      var $32=(($31)|0)!=0;
      if ($32) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      var $34=$ret;
      $1=$34;
      __label__ = 56; break;
    case 10: 
      var $36=$3;
      var $37=$36 & 1;
      var $38=(($37)|0)!=0;
      if ($38) { __label__ = 11; break; } else { __label__ = 14; break; }
    case 11: 
      var $40=$preferences;
      var $41=_HPDF_Dict_AddBoolean($40, ((STRING_TABLE.__str9583)|0), 1);
      $ret=$41;
      var $42=(($41)|0)!=0;
      if ($42) { __label__ = 12; break; } else { __label__ = 13; break; }
    case 12: 
      var $44=$ret;
      $1=$44;
      __label__ = 56; break;
    case 13: 
      __label__ = 19; break;
    case 14: 
      var $47=$preferences;
      var $48=_HPDF_Dict_RemoveElement($47, ((STRING_TABLE.__str9583)|0));
      $ret=$48;
      var $49=(($48)|0)!=0;
      if ($49) { __label__ = 15; break; } else { __label__ = 18; break; }
    case 15: 
      var $51=$ret;
      var $52=(($51)|0)!=4104;
      if ($52) { __label__ = 16; break; } else { __label__ = 17; break; }
    case 16: 
      var $54=$ret;
      $1=$54;
      __label__ = 56; break;
    case 17: 
      __label__ = 18; break;
    case 18: 
      __label__ = 19; break;
    case 19: 
      var $58=$3;
      var $59=$58 & 2;
      var $60=(($59)|0)!=0;
      if ($60) { __label__ = 20; break; } else { __label__ = 23; break; }
    case 20: 
      var $62=$preferences;
      var $63=_HPDF_Dict_AddBoolean($62, ((STRING_TABLE.__str10584)|0), 1);
      $ret=$63;
      var $64=(($63)|0)!=0;
      if ($64) { __label__ = 21; break; } else { __label__ = 22; break; }
    case 21: 
      var $66=$ret;
      $1=$66;
      __label__ = 56; break;
    case 22: 
      __label__ = 28; break;
    case 23: 
      var $69=$preferences;
      var $70=_HPDF_Dict_RemoveElement($69, ((STRING_TABLE.__str10584)|0));
      $ret=$70;
      var $71=(($70)|0)!=0;
      if ($71) { __label__ = 24; break; } else { __label__ = 27; break; }
    case 24: 
      var $73=$ret;
      var $74=(($73)|0)!=4104;
      if ($74) { __label__ = 25; break; } else { __label__ = 26; break; }
    case 25: 
      var $76=$ret;
      $1=$76;
      __label__ = 56; break;
    case 26: 
      __label__ = 27; break;
    case 27: 
      __label__ = 28; break;
    case 28: 
      var $80=$3;
      var $81=$80 & 4;
      var $82=(($81)|0)!=0;
      if ($82) { __label__ = 29; break; } else { __label__ = 32; break; }
    case 29: 
      var $84=$preferences;
      var $85=_HPDF_Dict_AddBoolean($84, ((STRING_TABLE.__str11585)|0), 1);
      $ret=$85;
      var $86=(($85)|0)!=0;
      if ($86) { __label__ = 30; break; } else { __label__ = 31; break; }
    case 30: 
      var $88=$ret;
      $1=$88;
      __label__ = 56; break;
    case 31: 
      __label__ = 37; break;
    case 32: 
      var $91=$preferences;
      var $92=_HPDF_Dict_RemoveElement($91, ((STRING_TABLE.__str11585)|0));
      $ret=$92;
      var $93=(($92)|0)!=0;
      if ($93) { __label__ = 33; break; } else { __label__ = 36; break; }
    case 33: 
      var $95=$ret;
      var $96=(($95)|0)!=4104;
      if ($96) { __label__ = 34; break; } else { __label__ = 35; break; }
    case 34: 
      var $98=$ret;
      $1=$98;
      __label__ = 56; break;
    case 35: 
      __label__ = 36; break;
    case 36: 
      __label__ = 37; break;
    case 37: 
      var $102=$3;
      var $103=$102 & 8;
      var $104=(($103)|0)!=0;
      if ($104) { __label__ = 38; break; } else { __label__ = 41; break; }
    case 38: 
      var $106=$preferences;
      var $107=_HPDF_Dict_AddBoolean($106, ((STRING_TABLE.__str12586)|0), 1);
      $ret=$107;
      var $108=(($107)|0)!=0;
      if ($108) { __label__ = 39; break; } else { __label__ = 40; break; }
    case 39: 
      var $110=$ret;
      $1=$110;
      __label__ = 56; break;
    case 40: 
      __label__ = 46; break;
    case 41: 
      var $113=$preferences;
      var $114=_HPDF_Dict_RemoveElement($113, ((STRING_TABLE.__str12586)|0));
      $ret=$114;
      var $115=(($114)|0)!=0;
      if ($115) { __label__ = 42; break; } else { __label__ = 45; break; }
    case 42: 
      var $117=$ret;
      var $118=(($117)|0)!=4104;
      if ($118) { __label__ = 43; break; } else { __label__ = 44; break; }
    case 43: 
      var $120=$ret;
      $1=$120;
      __label__ = 56; break;
    case 44: 
      __label__ = 45; break;
    case 45: 
      __label__ = 46; break;
    case 46: 
      var $124=$3;
      var $125=$124 & 16;
      var $126=(($125)|0)!=0;
      if ($126) { __label__ = 47; break; } else { __label__ = 50; break; }
    case 47: 
      var $128=$preferences;
      var $129=_HPDF_Dict_AddBoolean($128, ((STRING_TABLE.__str13587)|0), 1);
      $ret=$129;
      var $130=(($129)|0)!=0;
      if ($130) { __label__ = 48; break; } else { __label__ = 49; break; }
    case 48: 
      var $132=$ret;
      $1=$132;
      __label__ = 56; break;
    case 49: 
      __label__ = 55; break;
    case 50: 
      var $135=$preferences;
      var $136=_HPDF_Dict_RemoveElement($135, ((STRING_TABLE.__str13587)|0));
      $ret=$136;
      var $137=(($136)|0)!=0;
      if ($137) { __label__ = 51; break; } else { __label__ = 54; break; }
    case 51: 
      var $139=$ret;
      var $140=(($139)|0)!=4104;
      if ($140) { __label__ = 52; break; } else { __label__ = 53; break; }
    case 52: 
      var $142=$ret;
      $1=$142;
      __label__ = 56; break;
    case 53: 
      __label__ = 54; break;
    case 54: 
      __label__ = 55; break;
    case 55: 
      $1=0;
      __label__ = 56; break;
    case 56: 
      var $147=$1;
      ;
      return $147;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Catalog_SetViewerPreference["X"]=1;

function _HPDF_Catalog_GetViewerPreference($catalog) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $preferences;
      var $value;
      var $obj;
      $2=$catalog;
      $value=0;
      var $3=$2;
      var $4=_HPDF_Dict_GetItem($3, ((STRING_TABLE.__str8582)|0), 17);
      var $5=$4;
      $preferences=$5;
      var $6=$preferences;
      var $7=(($6)|0)!=0;
      if ($7) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=0;
      __label__ = 25; break;
    case 4: 
      var $10=$preferences;
      var $11=_HPDF_Dict_GetItem($10, ((STRING_TABLE.__str9583)|0), 3);
      var $12=$11;
      $obj=$12;
      var $13=$obj;
      var $14=(($13)|0)!=0;
      if ($14) { __label__ = 5; break; } else { __label__ = 8; break; }
    case 5: 
      var $16=$obj;
      var $17=(($16+8)|0);
      var $18=HEAP32[(($17)>>2)];
      var $19=(($18)|0)!=0;
      if ($19) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      var $21=$value;
      var $22=((($21)+(1))|0);
      $value=$22;
      __label__ = 7; break;
    case 7: 
      __label__ = 8; break;
    case 8: 
      var $25=$preferences;
      var $26=_HPDF_Dict_GetItem($25, ((STRING_TABLE.__str10584)|0), 3);
      var $27=$26;
      $obj=$27;
      var $28=$obj;
      var $29=(($28)|0)!=0;
      if ($29) { __label__ = 9; break; } else { __label__ = 12; break; }
    case 9: 
      var $31=$obj;
      var $32=(($31+8)|0);
      var $33=HEAP32[(($32)>>2)];
      var $34=(($33)|0)!=0;
      if ($34) { __label__ = 10; break; } else { __label__ = 11; break; }
    case 10: 
      var $36=$value;
      var $37=((($36)+(2))|0);
      $value=$37;
      __label__ = 11; break;
    case 11: 
      __label__ = 12; break;
    case 12: 
      var $40=$preferences;
      var $41=_HPDF_Dict_GetItem($40, ((STRING_TABLE.__str11585)|0), 3);
      var $42=$41;
      $obj=$42;
      var $43=$obj;
      var $44=(($43)|0)!=0;
      if ($44) { __label__ = 13; break; } else { __label__ = 16; break; }
    case 13: 
      var $46=$obj;
      var $47=(($46+8)|0);
      var $48=HEAP32[(($47)>>2)];
      var $49=(($48)|0)!=0;
      if ($49) { __label__ = 14; break; } else { __label__ = 15; break; }
    case 14: 
      var $51=$value;
      var $52=((($51)+(4))|0);
      $value=$52;
      __label__ = 15; break;
    case 15: 
      __label__ = 16; break;
    case 16: 
      var $55=$preferences;
      var $56=_HPDF_Dict_GetItem($55, ((STRING_TABLE.__str12586)|0), 3);
      var $57=$56;
      $obj=$57;
      var $58=$obj;
      var $59=(($58)|0)!=0;
      if ($59) { __label__ = 17; break; } else { __label__ = 20; break; }
    case 17: 
      var $61=$obj;
      var $62=(($61+8)|0);
      var $63=HEAP32[(($62)>>2)];
      var $64=(($63)|0)!=0;
      if ($64) { __label__ = 18; break; } else { __label__ = 19; break; }
    case 18: 
      var $66=$value;
      var $67=((($66)+(8))|0);
      $value=$67;
      __label__ = 19; break;
    case 19: 
      __label__ = 20; break;
    case 20: 
      var $70=$preferences;
      var $71=_HPDF_Dict_GetItem($70, ((STRING_TABLE.__str13587)|0), 3);
      var $72=$71;
      $obj=$72;
      var $73=$obj;
      var $74=(($73)|0)!=0;
      if ($74) { __label__ = 21; break; } else { __label__ = 24; break; }
    case 21: 
      var $76=$obj;
      var $77=(($76+8)|0);
      var $78=HEAP32[(($77)>>2)];
      var $79=(($78)|0)!=0;
      if ($79) { __label__ = 22; break; } else { __label__ = 23; break; }
    case 22: 
      var $81=$value;
      var $82=((($81)+(16))|0);
      $value=$82;
      __label__ = 23; break;
    case 23: 
      __label__ = 24; break;
    case 24: 
      var $85=$value;
      $1=$85;
      __label__ = 25; break;
    case 25: 
      var $87=$1;
      ;
      return $87;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Catalog_GetViewerPreference["X"]=1;

function _HPDF_Destination_New($mmgr, $target, $xref) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $dst;
      $2=$mmgr;
      $3=$target;
      $4=$xref;
      var $5=$3;
      var $6=_HPDF_Page_Validate($5);
      var $7=(($6)|0)!=0;
      if ($7) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      var $9=$2;
      var $10=(($9)|0);
      var $11=HEAP32[(($10)>>2)];
      var $12=_HPDF_SetError($11, 4151, 0);
      $1=0;
      __label__ = 13; break;
    case 4: 
      var $14=$2;
      var $15=_HPDF_Array_New($14);
      $dst=$15;
      var $16=$dst;
      var $17=(($16)|0)!=0;
      if ($17) { __label__ = 6; break; } else { __label__ = 5; break; }
    case 5: 
      $1=0;
      __label__ = 13; break;
    case 6: 
      var $20=$dst;
      var $21=(($20)|0);
      var $22=(($21+6)|0);
      var $23=HEAPU16[(($22)>>1)];
      var $24=(($23)&65535);
      var $25=$24 | 1792;
      var $26=(($25) & 65535);
      HEAP16[(($22)>>1)]=$26;
      var $27=$4;
      var $28=$dst;
      var $29=$28;
      var $30=_HPDF_Xref_Add($27, $29);
      var $31=(($30)|0)!=0;
      if ($31) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      $1=0;
      __label__ = 13; break;
    case 8: 
      var $34=$dst;
      var $35=$3;
      var $36=$35;
      var $37=_HPDF_Array_Add($34, $36);
      var $38=(($37)|0)!=0;
      if ($38) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      $1=0;
      __label__ = 13; break;
    case 10: 
      var $41=$dst;
      var $42=HEAP32[((((_HPDF_DESTINATION_TYPE_NAMES+4)|0))>>2)];
      var $43=_HPDF_Array_AddName($41, $42);
      var $44=(($43)|0)!=0;
      if ($44) { __label__ = 11; break; } else { __label__ = 12; break; }
    case 11: 
      $1=0;
      __label__ = 13; break;
    case 12: 
      var $47=$dst;
      $1=$47;
      __label__ = 13; break;
    case 13: 
      var $49=$1;
      ;
      return $49;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Destination_New["X"]=1;

function _HPDF_Destination_Validate($dst) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $header;
      var $target;
      $2=$dst;
      var $3=$2;
      var $4=$3;
      $header=$4;
      var $5=$2;
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $8=$header;
      var $9=(($8+6)|0);
      var $10=HEAPU16[(($9)>>1)];
      var $11=(($10)&65535);
      var $12=(($11)|0)!=1808;
      if ($12) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      $1=0;
      __label__ = 10; break;
    case 5: 
      var $15=$2;
      var $16=(($15+16)|0);
      var $17=HEAP32[(($16)>>2)];
      var $18=(($17+16)|0);
      var $19=HEAPU32[(($18)>>2)];
      var $20=(($19)>>>0) < 2;
      if ($20) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      $1=0;
      __label__ = 10; break;
    case 7: 
      var $23=$2;
      var $24=_HPDF_Array_GetItem($23, 0, 17);
      var $25=$24;
      $target=$25;
      var $26=$target;
      var $27=_HPDF_Page_Validate($26);
      var $28=(($27)|0)!=0;
      if ($28) { __label__ = 9; break; } else { __label__ = 8; break; }
    case 8: 
      var $30=$2;
      var $31=(($30+12)|0);
      var $32=HEAP32[(($31)>>2)];
      var $33=_HPDF_SetError($32, 4151, 0);
      $1=0;
      __label__ = 10; break;
    case 9: 
      $1=1;
      __label__ = 10; break;
    case 10: 
      var $36=$1;
      ;
      return $36;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Destination_SetXYZ($dst, $left, $top, $zoom) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $5;
      var $ret;
      var $target;
      $2=$dst;
      $3=$left;
      $4=$top;
      $5=$zoom;
      $ret=0;
      var $6=$2;
      var $7=_HPDF_Destination_Validate($6);
      var $8=(($7)|0)!=0;
      if ($8) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=4131;
      __label__ = 14; break;
    case 4: 
      var $11=$3;
      var $12=$11 < 0;
      if ($12) { __label__ = 8; break; } else { __label__ = 5; break; }
    case 5: 
      var $14=$4;
      var $15=$14 < 0;
      if ($15) { __label__ = 8; break; } else { __label__ = 6; break; }
    case 6: 
      var $17=$5;
      var $18=$17;
      var $19=$18 < 0.08;
      if ($19) { __label__ = 8; break; } else { __label__ = 7; break; }
    case 7: 
      var $21=$5;
      var $22=$21 > 32;
      if ($22) { __label__ = 8; break; } else { __label__ = 9; break; }
    case 8: 
      var $24=$2;
      var $25=(($24+12)|0);
      var $26=HEAP32[(($25)>>2)];
      var $27=_HPDF_RaiseError($26, 4153, 0);
      $1=$27;
      __label__ = 14; break;
    case 9: 
      var $29=$2;
      var $30=_HPDF_Array_GetItem($29, 0, 17);
      var $31=$30;
      $target=$31;
      var $32=$2;
      var $33=(($32+16)|0);
      var $34=HEAP32[(($33)>>2)];
      var $35=(($34+16)|0);
      var $36=HEAPU32[(($35)>>2)];
      var $37=(($36)>>>0) > 1;
      if ($37) { __label__ = 10; break; } else { __label__ = 11; break; }
    case 10: 
      var $39=$2;
      _HPDF_Array_Clear($39);
      var $40=$2;
      var $41=$target;
      var $42=$41;
      var $43=_HPDF_Array_Add($40, $42);
      var $44=$ret;
      var $45=((($44)+($43))|0);
      $ret=$45;
      __label__ = 11; break;
    case 11: 
      var $47=$2;
      var $48=HEAP32[((((_HPDF_DESTINATION_TYPE_NAMES)|0))>>2)];
      var $49=_HPDF_Array_AddName($47, $48);
      var $50=$ret;
      var $51=((($50)+($49))|0);
      $ret=$51;
      var $52=$2;
      var $53=$3;
      var $54=_HPDF_Array_AddReal($52, $53);
      var $55=$ret;
      var $56=((($55)+($54))|0);
      $ret=$56;
      var $57=$2;
      var $58=$4;
      var $59=_HPDF_Array_AddReal($57, $58);
      var $60=$ret;
      var $61=((($60)+($59))|0);
      $ret=$61;
      var $62=$2;
      var $63=$5;
      var $64=_HPDF_Array_AddReal($62, $63);
      var $65=$ret;
      var $66=((($65)+($64))|0);
      $ret=$66;
      var $67=$ret;
      var $68=(($67)|0)!=0;
      if ($68) { __label__ = 12; break; } else { __label__ = 13; break; }
    case 12: 
      var $70=$2;
      var $71=(($70+12)|0);
      var $72=HEAP32[(($71)>>2)];
      var $73=_HPDF_CheckError($72);
      $1=$73;
      __label__ = 14; break;
    case 13: 
      $1=0;
      __label__ = 14; break;
    case 14: 
      var $76=$1;
      ;
      return $76;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Destination_SetXYZ["X"]=1;

function _HPDF_Destination_SetFit($dst) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $ret;
      var $target;
      $2=$dst;
      $ret=0;
      var $3=$2;
      var $4=_HPDF_Destination_Validate($3);
      var $5=(($4)|0)!=0;
      if ($5) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=4131;
      __label__ = 9; break;
    case 4: 
      var $8=$2;
      var $9=_HPDF_Array_GetItem($8, 0, 17);
      var $10=$9;
      $target=$10;
      var $11=$2;
      var $12=(($11+16)|0);
      var $13=HEAP32[(($12)>>2)];
      var $14=(($13+16)|0);
      var $15=HEAPU32[(($14)>>2)];
      var $16=(($15)>>>0) > 1;
      if ($16) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $18=$2;
      _HPDF_Array_Clear($18);
      var $19=$2;
      var $20=$target;
      var $21=$20;
      var $22=_HPDF_Array_Add($19, $21);
      var $23=$ret;
      var $24=((($23)+($22))|0);
      $ret=$24;
      __label__ = 6; break;
    case 6: 
      var $26=$2;
      var $27=HEAP32[((((_HPDF_DESTINATION_TYPE_NAMES+4)|0))>>2)];
      var $28=_HPDF_Array_AddName($26, $27);
      var $29=$ret;
      var $30=((($29)+($28))|0);
      $ret=$30;
      var $31=$ret;
      var $32=(($31)|0)!=0;
      if ($32) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $34=$2;
      var $35=(($34+12)|0);
      var $36=HEAP32[(($35)>>2)];
      var $37=_HPDF_CheckError($36);
      $1=$37;
      __label__ = 9; break;
    case 8: 
      $1=0;
      __label__ = 9; break;
    case 9: 
      var $40=$1;
      ;
      return $40;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Destination_SetFit["X"]=1;

function _HPDF_Destination_SetFitH($dst, $top) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $ret;
      var $target;
      $2=$dst;
      $3=$top;
      $ret=0;
      var $4=$2;
      var $5=_HPDF_Destination_Validate($4);
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=4131;
      __label__ = 9; break;
    case 4: 
      var $9=$2;
      var $10=_HPDF_Array_GetItem($9, 0, 17);
      var $11=$10;
      $target=$11;
      var $12=$2;
      var $13=(($12+16)|0);
      var $14=HEAP32[(($13)>>2)];
      var $15=(($14+16)|0);
      var $16=HEAPU32[(($15)>>2)];
      var $17=(($16)>>>0) > 1;
      if ($17) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $19=$2;
      _HPDF_Array_Clear($19);
      var $20=$2;
      var $21=$target;
      var $22=$21;
      var $23=_HPDF_Array_Add($20, $22);
      var $24=$ret;
      var $25=((($24)+($23))|0);
      $ret=$25;
      __label__ = 6; break;
    case 6: 
      var $27=$2;
      var $28=HEAP32[((((_HPDF_DESTINATION_TYPE_NAMES+8)|0))>>2)];
      var $29=_HPDF_Array_AddName($27, $28);
      var $30=$ret;
      var $31=((($30)+($29))|0);
      $ret=$31;
      var $32=$2;
      var $33=$3;
      var $34=_HPDF_Array_AddReal($32, $33);
      var $35=$ret;
      var $36=((($35)+($34))|0);
      $ret=$36;
      var $37=$ret;
      var $38=(($37)|0)!=0;
      if ($38) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $40=$2;
      var $41=(($40+12)|0);
      var $42=HEAP32[(($41)>>2)];
      var $43=_HPDF_CheckError($42);
      $1=$43;
      __label__ = 9; break;
    case 8: 
      $1=0;
      __label__ = 9; break;
    case 9: 
      var $46=$1;
      ;
      return $46;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Destination_SetFitH["X"]=1;

function _HPDF_Destination_SetFitV($dst, $left) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $ret;
      var $target;
      $2=$dst;
      $3=$left;
      $ret=0;
      var $4=$2;
      var $5=_HPDF_Destination_Validate($4);
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=4131;
      __label__ = 9; break;
    case 4: 
      var $9=$2;
      var $10=_HPDF_Array_GetItem($9, 0, 17);
      var $11=$10;
      $target=$11;
      var $12=$2;
      var $13=(($12+16)|0);
      var $14=HEAP32[(($13)>>2)];
      var $15=(($14+16)|0);
      var $16=HEAPU32[(($15)>>2)];
      var $17=(($16)>>>0) > 1;
      if ($17) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $19=$2;
      _HPDF_Array_Clear($19);
      var $20=$2;
      var $21=$target;
      var $22=$21;
      var $23=_HPDF_Array_Add($20, $22);
      var $24=$ret;
      var $25=((($24)+($23))|0);
      $ret=$25;
      __label__ = 6; break;
    case 6: 
      var $27=$2;
      var $28=HEAP32[((((_HPDF_DESTINATION_TYPE_NAMES+12)|0))>>2)];
      var $29=_HPDF_Array_AddName($27, $28);
      var $30=$ret;
      var $31=((($30)+($29))|0);
      $ret=$31;
      var $32=$2;
      var $33=$3;
      var $34=_HPDF_Array_AddReal($32, $33);
      var $35=$ret;
      var $36=((($35)+($34))|0);
      $ret=$36;
      var $37=$ret;
      var $38=(($37)|0)!=0;
      if ($38) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $40=$2;
      var $41=(($40+12)|0);
      var $42=HEAP32[(($41)>>2)];
      var $43=_HPDF_CheckError($42);
      $1=$43;
      __label__ = 9; break;
    case 8: 
      $1=0;
      __label__ = 9; break;
    case 9: 
      var $46=$1;
      ;
      return $46;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Destination_SetFitV["X"]=1;

function _HPDF_Destination_SetFitR($dst, $left, $bottom, $right, $top) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $5;
      var $6;
      var $ret;
      var $target;
      $2=$dst;
      $3=$left;
      $4=$bottom;
      $5=$right;
      $6=$top;
      $ret=0;
      var $7=$2;
      var $8=_HPDF_Destination_Validate($7);
      var $9=(($8)|0)!=0;
      if ($9) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=4131;
      __label__ = 9; break;
    case 4: 
      var $12=$2;
      var $13=_HPDF_Array_GetItem($12, 0, 17);
      var $14=$13;
      $target=$14;
      var $15=$2;
      var $16=(($15+16)|0);
      var $17=HEAP32[(($16)>>2)];
      var $18=(($17+16)|0);
      var $19=HEAPU32[(($18)>>2)];
      var $20=(($19)>>>0) > 1;
      if ($20) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $22=$2;
      _HPDF_Array_Clear($22);
      var $23=$2;
      var $24=$target;
      var $25=$24;
      var $26=_HPDF_Array_Add($23, $25);
      var $27=$ret;
      var $28=((($27)+($26))|0);
      $ret=$28;
      __label__ = 6; break;
    case 6: 
      var $30=$2;
      var $31=HEAP32[((((_HPDF_DESTINATION_TYPE_NAMES+16)|0))>>2)];
      var $32=_HPDF_Array_AddName($30, $31);
      var $33=$ret;
      var $34=((($33)+($32))|0);
      $ret=$34;
      var $35=$2;
      var $36=$3;
      var $37=_HPDF_Array_AddReal($35, $36);
      var $38=$ret;
      var $39=((($38)+($37))|0);
      $ret=$39;
      var $40=$2;
      var $41=$4;
      var $42=_HPDF_Array_AddReal($40, $41);
      var $43=$ret;
      var $44=((($43)+($42))|0);
      $ret=$44;
      var $45=$2;
      var $46=$5;
      var $47=_HPDF_Array_AddReal($45, $46);
      var $48=$ret;
      var $49=((($48)+($47))|0);
      $ret=$49;
      var $50=$2;
      var $51=$6;
      var $52=_HPDF_Array_AddReal($50, $51);
      var $53=$ret;
      var $54=((($53)+($52))|0);
      $ret=$54;
      var $55=$ret;
      var $56=(($55)|0)!=0;
      if ($56) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $58=$2;
      var $59=(($58+12)|0);
      var $60=HEAP32[(($59)>>2)];
      var $61=_HPDF_CheckError($60);
      $1=$61;
      __label__ = 9; break;
    case 8: 
      $1=0;
      __label__ = 9; break;
    case 9: 
      var $64=$1;
      ;
      return $64;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Destination_SetFitR["X"]=1;

function _HPDF_Destination_SetFitB($dst) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $ret;
      var $target;
      $2=$dst;
      $ret=0;
      var $3=$2;
      var $4=_HPDF_Destination_Validate($3);
      var $5=(($4)|0)!=0;
      if ($5) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=4131;
      __label__ = 9; break;
    case 4: 
      var $8=$2;
      var $9=_HPDF_Array_GetItem($8, 0, 17);
      var $10=$9;
      $target=$10;
      var $11=$2;
      var $12=(($11+16)|0);
      var $13=HEAP32[(($12)>>2)];
      var $14=(($13+16)|0);
      var $15=HEAPU32[(($14)>>2)];
      var $16=(($15)>>>0) > 1;
      if ($16) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $18=$2;
      _HPDF_Array_Clear($18);
      var $19=$2;
      var $20=$target;
      var $21=$20;
      var $22=_HPDF_Array_Add($19, $21);
      var $23=$ret;
      var $24=((($23)+($22))|0);
      $ret=$24;
      __label__ = 6; break;
    case 6: 
      var $26=$2;
      var $27=HEAP32[((((_HPDF_DESTINATION_TYPE_NAMES+20)|0))>>2)];
      var $28=_HPDF_Array_AddName($26, $27);
      var $29=$ret;
      var $30=((($29)+($28))|0);
      $ret=$30;
      var $31=$ret;
      var $32=(($31)|0)!=0;
      if ($32) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $34=$2;
      var $35=(($34+12)|0);
      var $36=HEAP32[(($35)>>2)];
      var $37=_HPDF_CheckError($36);
      $1=$37;
      __label__ = 9; break;
    case 8: 
      $1=0;
      __label__ = 9; break;
    case 9: 
      var $40=$1;
      ;
      return $40;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Destination_SetFitB["X"]=1;

function _HPDF_Destination_SetFitBH($dst, $top) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $ret;
      var $target;
      $2=$dst;
      $3=$top;
      $ret=0;
      var $4=$2;
      var $5=_HPDF_Destination_Validate($4);
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=4131;
      __label__ = 9; break;
    case 4: 
      var $9=$2;
      var $10=_HPDF_Array_GetItem($9, 0, 17);
      var $11=$10;
      $target=$11;
      var $12=$2;
      var $13=(($12+16)|0);
      var $14=HEAP32[(($13)>>2)];
      var $15=(($14+16)|0);
      var $16=HEAPU32[(($15)>>2)];
      var $17=(($16)>>>0) > 1;
      if ($17) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $19=$2;
      _HPDF_Array_Clear($19);
      var $20=$2;
      var $21=$target;
      var $22=$21;
      var $23=_HPDF_Array_Add($20, $22);
      var $24=$ret;
      var $25=((($24)+($23))|0);
      $ret=$25;
      __label__ = 6; break;
    case 6: 
      var $27=$2;
      var $28=HEAP32[((((_HPDF_DESTINATION_TYPE_NAMES+24)|0))>>2)];
      var $29=_HPDF_Array_AddName($27, $28);
      var $30=$ret;
      var $31=((($30)+($29))|0);
      $ret=$31;
      var $32=$2;
      var $33=$3;
      var $34=_HPDF_Array_AddReal($32, $33);
      var $35=$ret;
      var $36=((($35)+($34))|0);
      $ret=$36;
      var $37=$ret;
      var $38=(($37)|0)!=0;
      if ($38) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $40=$2;
      var $41=(($40+12)|0);
      var $42=HEAP32[(($41)>>2)];
      var $43=_HPDF_CheckError($42);
      $1=$43;
      __label__ = 9; break;
    case 8: 
      $1=0;
      __label__ = 9; break;
    case 9: 
      var $46=$1;
      ;
      return $46;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Destination_SetFitBH["X"]=1;

function _HPDF_Destination_SetFitBV($dst, $left) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $ret;
      var $target;
      $2=$dst;
      $3=$left;
      $ret=0;
      var $4=$2;
      var $5=_HPDF_Destination_Validate($4);
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=4131;
      __label__ = 9; break;
    case 4: 
      var $9=$2;
      var $10=_HPDF_Array_GetItem($9, 0, 17);
      var $11=$10;
      $target=$11;
      var $12=$2;
      var $13=(($12+16)|0);
      var $14=HEAP32[(($13)>>2)];
      var $15=(($14+16)|0);
      var $16=HEAPU32[(($15)>>2)];
      var $17=(($16)>>>0) > 1;
      if ($17) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $19=$2;
      _HPDF_Array_Clear($19);
      var $20=$2;
      var $21=$target;
      var $22=$21;
      var $23=_HPDF_Array_Add($20, $22);
      var $24=$ret;
      var $25=((($24)+($23))|0);
      $ret=$25;
      __label__ = 6; break;
    case 6: 
      var $27=$2;
      var $28=HEAP32[((((_HPDF_DESTINATION_TYPE_NAMES+28)|0))>>2)];
      var $29=_HPDF_Array_AddName($27, $28);
      var $30=$ret;
      var $31=((($30)+($29))|0);
      $ret=$31;
      var $32=$2;
      var $33=$3;
      var $34=_HPDF_Array_AddReal($32, $33);
      var $35=$ret;
      var $36=((($35)+($34))|0);
      $ret=$36;
      var $37=$ret;
      var $38=(($37)|0)!=0;
      if ($38) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $40=$2;
      var $41=(($40+12)|0);
      var $42=HEAP32[(($41)>>2)];
      var $43=_HPDF_CheckError($42);
      $1=$43;
      __label__ = 9; break;
    case 8: 
      $1=0;
      __label__ = 9; break;
    case 9: 
      var $46=$1;
      ;
      return $46;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Destination_SetFitBV["X"]=1;

function _HPDF_Dict_New($mmgr) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $obj;
      $1=$mmgr;
      var $2=$1;
      var $3=_HPDF_GetMem($2, 48);
      var $4=$3;
      $obj=$4;
      var $5=$obj;
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 3; break; } else { __label__ = 6; break; }
    case 3: 
      var $8=$obj;
      var $9=$8;
      var $10=_HPDF_MemSet($9, 0, 48);
      var $11=$obj;
      var $12=(($11)|0);
      var $13=(($12+6)|0);
      HEAP16[(($13)>>1)]=17;
      var $14=$1;
      var $15=$obj;
      var $16=(($15+8)|0);
      HEAP32[(($16)>>2)]=$14;
      var $17=$1;
      var $18=(($17)|0);
      var $19=HEAP32[(($18)>>2)];
      var $20=$obj;
      var $21=(($20+12)|0);
      HEAP32[(($21)>>2)]=$19;
      var $22=$1;
      var $23=_HPDF_List_New($22, 20);
      var $24=$obj;
      var $25=(($24+16)|0);
      HEAP32[(($25)>>2)]=$23;
      var $26=$obj;
      var $27=(($26+40)|0);
      HEAP32[(($27)>>2)]=0;
      var $28=$obj;
      var $29=(($28+16)|0);
      var $30=HEAP32[(($29)>>2)];
      var $31=(($30)|0)!=0;
      if ($31) { __label__ = 5; break; } else { __label__ = 4; break; }
    case 4: 
      var $33=$1;
      var $34=$obj;
      var $35=$34;
      _HPDF_FreeMem($33, $35);
      $obj=0;
      __label__ = 5; break;
    case 5: 
      __label__ = 6; break;
    case 6: 
      var $38=$obj;
      ;
      return $38;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_DictStream_New($mmgr, $xref) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $obj;
      var $length;
      var $ret;
      $2=$mmgr;
      $3=$xref;
      $ret=0;
      var $4=$2;
      var $5=_HPDF_Dict_New($4);
      $obj=$5;
      var $6=$obj;
      var $7=(($6)|0)!=0;
      if ($7) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=0;
      __label__ = 15; break;
    case 4: 
      var $10=$3;
      var $11=$obj;
      var $12=$11;
      var $13=_HPDF_Xref_Add($10, $12);
      var $14=$ret;
      var $15=((($14)+($13))|0);
      $ret=$15;
      var $16=$ret;
      var $17=(($16)|0)!=0;
      if ($17) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      $1=0;
      __label__ = 15; break;
    case 6: 
      var $20=$2;
      var $21=_HPDF_Number_New($20, 0);
      $length=$21;
      var $22=$length;
      var $23=(($22)|0)!=0;
      if ($23) { __label__ = 8; break; } else { __label__ = 7; break; }
    case 7: 
      $1=0;
      __label__ = 15; break;
    case 8: 
      var $26=$3;
      var $27=$length;
      var $28=$27;
      var $29=_HPDF_Xref_Add($26, $28);
      $ret=$29;
      var $30=$ret;
      var $31=(($30)|0)!=0;
      if ($31) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      $1=0;
      __label__ = 15; break;
    case 10: 
      var $34=$obj;
      var $35=$length;
      var $36=$35;
      var $37=_HPDF_Dict_Add($34, ((STRING_TABLE.__str607)|0), $36);
      $ret=$37;
      var $38=$ret;
      var $39=(($38)|0)!=0;
      if ($39) { __label__ = 11; break; } else { __label__ = 12; break; }
    case 11: 
      $1=0;
      __label__ = 15; break;
    case 12: 
      var $42=$2;
      var $43=_HPDF_MemStream_New($42, 4096);
      var $44=$obj;
      var $45=(($44+36)|0);
      HEAP32[(($45)>>2)]=$43;
      var $46=$obj;
      var $47=(($46+36)|0);
      var $48=HEAP32[(($47)>>2)];
      var $49=(($48)|0)!=0;
      if ($49) { __label__ = 14; break; } else { __label__ = 13; break; }
    case 13: 
      $1=0;
      __label__ = 15; break;
    case 14: 
      var $52=$obj;
      $1=$52;
      __label__ = 15; break;
    case 15: 
      var $54=$1;
      ;
      return $54;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_DictStream_New["X"]=1;

function _HPDF_Dict_Add($dict, $key, $obj) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $header;
      var $ret;
      var $element;
      var $proxy;
      $2=$dict;
      $3=$key;
      $4=$obj;
      $ret=0;
      var $5=$4;
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 6; break; } else { __label__ = 3; break; }
    case 3: 
      var $8=$2;
      var $9=(($8+12)|0);
      var $10=HEAP32[(($9)>>2)];
      var $11=_HPDF_Error_GetCode($10);
      var $12=(($11)|0)==0;
      if ($12) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      var $14=$2;
      var $15=(($14+12)|0);
      var $16=HEAP32[(($15)>>2)];
      var $17=_HPDF_SetError($16, 4147, 0);
      $1=$17;
      __label__ = 29; break;
    case 5: 
      $1=4147;
      __label__ = 29; break;
    case 6: 
      var $20=$4;
      var $21=$20;
      $header=$21;
      var $22=$header;
      var $23=(($22)|0);
      var $24=HEAP32[(($23)>>2)];
      var $25=$24 & -2147483648;
      var $26=(($25)|0)!=0;
      if ($26) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $28=$2;
      var $29=(($28+12)|0);
      var $30=HEAP32[(($29)>>2)];
      var $31=_HPDF_SetError($30, 4147, 0);
      $1=$31;
      __label__ = 29; break;
    case 8: 
      var $33=$3;
      var $34=(($33)|0)!=0;
      if ($34) { __label__ = 10; break; } else { __label__ = 9; break; }
    case 9: 
      var $36=$2;
      var $37=(($36+8)|0);
      var $38=HEAP32[(($37)>>2)];
      var $39=$4;
      _HPDF_Obj_Free($38, $39);
      var $40=$2;
      var $41=(($40+12)|0);
      var $42=HEAP32[(($41)>>2)];
      var $43=_HPDF_SetError($42, 4147, 0);
      $1=$43;
      __label__ = 29; break;
    case 10: 
      var $45=$2;
      var $46=(($45+16)|0);
      var $47=HEAP32[(($46)>>2)];
      var $48=(($47+16)|0);
      var $49=HEAPU32[(($48)>>2)];
      var $50=(($49)>>>0) >= 4095;
      if ($50) { __label__ = 11; break; } else { __label__ = 12; break; }
    case 11: 
      var $52=$2;
      var $53=(($52+8)|0);
      var $54=HEAP32[(($53)>>2)];
      var $55=$4;
      _HPDF_Obj_Free($54, $55);
      var $56=$2;
      var $57=(($56+12)|0);
      var $58=HEAP32[(($57)>>2)];
      var $59=_HPDF_SetError($58, 4103, 0);
      $1=$59;
      __label__ = 29; break;
    case 12: 
      var $61=$2;
      var $62=$3;
      var $63=_GetElement($61, $62);
      $element=$63;
      var $64=$element;
      var $65=(($64)|0)!=0;
      if ($65) { __label__ = 13; break; } else { __label__ = 14; break; }
    case 13: 
      var $67=$2;
      var $68=(($67+8)|0);
      var $69=HEAP32[(($68)>>2)];
      var $70=$element;
      var $71=(($70+128)|0);
      var $72=HEAP32[(($71)>>2)];
      _HPDF_Obj_Free($69, $72);
      var $73=$element;
      var $74=(($73+128)|0);
      HEAP32[(($74)>>2)]=0;
      __label__ = 23; break;
    case 14: 
      var $76=$2;
      var $77=(($76+8)|0);
      var $78=HEAP32[(($77)>>2)];
      var $79=_HPDF_GetMem($78, 132);
      var $80=$79;
      $element=$80;
      var $81=$element;
      var $82=(($81)|0)!=0;
      if ($82) { __label__ = 18; break; } else { __label__ = 15; break; }
    case 15: 
      var $84=$header;
      var $85=(($84)|0);
      var $86=HEAP32[(($85)>>2)];
      var $87=$86 & 1073741824;
      var $88=(($87)|0)!=0;
      if ($88) { __label__ = 17; break; } else { __label__ = 16; break; }
    case 16: 
      var $90=$2;
      var $91=(($90+8)|0);
      var $92=HEAP32[(($91)>>2)];
      var $93=$4;
      _HPDF_Obj_Free($92, $93);
      __label__ = 17; break;
    case 17: 
      var $95=$2;
      var $96=(($95+12)|0);
      var $97=HEAP32[(($96)>>2)];
      var $98=_HPDF_Error_GetCode($97);
      $1=$98;
      __label__ = 29; break;
    case 18: 
      var $100=$element;
      var $101=(($100)|0);
      var $102=(($101)|0);
      var $103=$3;
      var $104=$element;
      var $105=(($104)|0);
      var $106=(($105)|0);
      var $107=(($106+127)|0);
      var $108=(($107+1)|0);
      var $109=_HPDF_StrCpy($102, $103, $108);
      var $110=$element;
      var $111=(($110+128)|0);
      HEAP32[(($111)>>2)]=0;
      var $112=$2;
      var $113=(($112+16)|0);
      var $114=HEAP32[(($113)>>2)];
      var $115=$element;
      var $116=$115;
      var $117=_HPDF_List_Add($114, $116);
      $ret=$117;
      var $118=$ret;
      var $119=(($118)|0)!=0;
      if ($119) { __label__ = 19; break; } else { __label__ = 22; break; }
    case 19: 
      var $121=$header;
      var $122=(($121)|0);
      var $123=HEAP32[(($122)>>2)];
      var $124=$123 & 1073741824;
      var $125=(($124)|0)!=0;
      if ($125) { __label__ = 21; break; } else { __label__ = 20; break; }
    case 20: 
      var $127=$2;
      var $128=(($127+8)|0);
      var $129=HEAP32[(($128)>>2)];
      var $130=$4;
      _HPDF_Obj_Free($129, $130);
      __label__ = 21; break;
    case 21: 
      var $132=$2;
      var $133=(($132+8)|0);
      var $134=HEAP32[(($133)>>2)];
      var $135=$element;
      var $136=$135;
      _HPDF_FreeMem($134, $136);
      var $137=$2;
      var $138=(($137+12)|0);
      var $139=HEAP32[(($138)>>2)];
      var $140=_HPDF_Error_GetCode($139);
      $1=$140;
      __label__ = 29; break;
    case 22: 
      __label__ = 23; break;
    case 23: 
      var $143=$header;
      var $144=(($143)|0);
      var $145=HEAP32[(($144)>>2)];
      var $146=$145 & 1073741824;
      var $147=(($146)|0)!=0;
      if ($147) { __label__ = 24; break; } else { __label__ = 27; break; }
    case 24: 
      var $149=$2;
      var $150=(($149+8)|0);
      var $151=HEAP32[(($150)>>2)];
      var $152=$4;
      var $153=_HPDF_Proxy_New($151, $152);
      $proxy=$153;
      var $154=$proxy;
      var $155=(($154)|0)!=0;
      if ($155) { __label__ = 26; break; } else { __label__ = 25; break; }
    case 25: 
      var $157=$2;
      var $158=(($157+12)|0);
      var $159=HEAP32[(($158)>>2)];
      var $160=_HPDF_Error_GetCode($159);
      $1=$160;
      __label__ = 29; break;
    case 26: 
      var $162=$proxy;
      var $163=$162;
      var $164=$element;
      var $165=(($164+128)|0);
      HEAP32[(($165)>>2)]=$163;
      var $166=$proxy;
      var $167=(($166)|0);
      var $168=(($167)|0);
      var $169=HEAP32[(($168)>>2)];
      var $170=$169 | -2147483648;
      HEAP32[(($168)>>2)]=$170;
      __label__ = 28; break;
    case 27: 
      var $172=$4;
      var $173=$element;
      var $174=(($173+128)|0);
      HEAP32[(($174)>>2)]=$172;
      var $175=$header;
      var $176=(($175)|0);
      var $177=HEAP32[(($176)>>2)];
      var $178=$177 | -2147483648;
      HEAP32[(($176)>>2)]=$178;
      __label__ = 28; break;
    case 28: 
      var $180=$ret;
      $1=$180;
      __label__ = 29; break;
    case 29: 
      var $182=$1;
      ;
      return $182;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Dict_Add["X"]=1;

function _HPDF_Dict_Free($dict) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $i;
      var $element;
      $1=$dict;
      var $2=$1;
      var $3=(($2)|0)!=0;
      if ($3) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      __label__ = 15; break;
    case 4: 
      var $6=$1;
      var $7=(($6+32)|0);
      var $8=HEAP32[(($7)>>2)];
      var $9=(($8)|0)!=0;
      if ($9) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $11=$1;
      var $12=(($11+32)|0);
      var $13=HEAP32[(($12)>>2)];
      var $14=$1;
      FUNCTION_TABLE[$13]($14);
      __label__ = 6; break;
    case 6: 
      $i=0;
      __label__ = 7; break;
    case 7: 
      var $17=$i;
      var $18=$1;
      var $19=(($18+16)|0);
      var $20=HEAP32[(($19)>>2)];
      var $21=(($20+16)|0);
      var $22=HEAPU32[(($21)>>2)];
      var $23=(($17)>>>0) < (($22)>>>0);
      if ($23) { __label__ = 8; break; } else { __label__ = 12; break; }
    case 8: 
      var $25=$1;
      var $26=(($25+16)|0);
      var $27=HEAP32[(($26)>>2)];
      var $28=$i;
      var $29=_HPDF_List_ItemAt($27, $28);
      var $30=$29;
      $element=$30;
      var $31=$element;
      var $32=(($31)|0)!=0;
      if ($32) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      var $34=$1;
      var $35=(($34+8)|0);
      var $36=HEAP32[(($35)>>2)];
      var $37=$element;
      var $38=(($37+128)|0);
      var $39=HEAP32[(($38)>>2)];
      _HPDF_Obj_Free($36, $39);
      var $40=$1;
      var $41=(($40+8)|0);
      var $42=HEAP32[(($41)>>2)];
      var $43=$element;
      var $44=$43;
      _HPDF_FreeMem($42, $44);
      __label__ = 10; break;
    case 10: 
      __label__ = 11; break;
    case 11: 
      var $47=$i;
      var $48=((($47)+(1))|0);
      $i=$48;
      __label__ = 7; break;
    case 12: 
      var $50=$1;
      var $51=(($50+36)|0);
      var $52=HEAP32[(($51)>>2)];
      var $53=(($52)|0)!=0;
      if ($53) { __label__ = 13; break; } else { __label__ = 14; break; }
    case 13: 
      var $55=$1;
      var $56=(($55+36)|0);
      var $57=HEAP32[(($56)>>2)];
      _HPDF_Stream_Free($57);
      __label__ = 14; break;
    case 14: 
      var $59=$1;
      var $60=(($59+16)|0);
      var $61=HEAP32[(($60)>>2)];
      _HPDF_List_Free($61);
      var $62=$1;
      var $63=(($62)|0);
      var $64=(($63+6)|0);
      HEAP16[(($64)>>1)]=0;
      var $65=$1;
      var $66=(($65+8)|0);
      var $67=HEAP32[(($66)>>2)];
      var $68=$1;
      var $69=$68;
      _HPDF_FreeMem($67, $69);
      __label__ = 15; break;
    case 15: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Dict_Free["X"]=1;

function _HPDF_GetVersion() {
  ;
  var __label__;

  ;
  return ((STRING_TABLE.__str630)|0);
}


function _HPDF_Doc_Validate($pdf) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      $2=$pdf;
      var $3=$2;
      var $4=(($3)|0)!=0;
      if ($4) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $6=$2;
      var $7=(($6)|0);
      var $8=HEAP32[(($7)>>2)];
      var $9=(($8)|0)!=1095779398;
      if ($9) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      $1=0;
      __label__ = 6; break;
    case 5: 
      $1=1;
      __label__ = 6; break;
    case 6: 
      var $13=$1;
      ;
      return $13;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Dict_Write($dict, $stream, $e) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $i;
      var $ret;
      var $array;
      var $element;
      var $header;
      var $strptr;
      var $length;
      $2=$dict;
      $3=$stream;
      $4=$e;
      var $5=$3;
      var $6=_HPDF_Stream_WriteStr($5, ((STRING_TABLE.__str1608)|0));
      $ret=$6;
      var $7=$ret;
      var $8=(($7)|0)!=0;
      if ($8) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $10=$ret;
      $1=$10;
      __label__ = 65; break;
    case 4: 
      var $12=$2;
      var $13=(($12+20)|0);
      var $14=HEAP32[(($13)>>2)];
      var $15=(($14)|0)!=0;
      if ($15) { __label__ = 5; break; } else { __label__ = 8; break; }
    case 5: 
      var $17=$2;
      var $18=(($17+20)|0);
      var $19=HEAP32[(($18)>>2)];
      var $20=$2;
      var $21=FUNCTION_TABLE[$19]($20);
      $ret=$21;
      var $22=(($21)|0)!=0;
      if ($22) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      var $24=$ret;
      $1=$24;
      __label__ = 65; break;
    case 7: 
      __label__ = 8; break;
    case 8: 
      var $27=$2;
      var $28=(($27)|0);
      var $29=(($28+6)|0);
      var $30=HEAPU16[(($29)>>1)];
      var $31=(($30)&65535);
      var $32=(($31)|0)==2321;
      if ($32) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      $4=0;
      __label__ = 10; break;
    case 10: 
      var $35=$2;
      var $36=(($35+36)|0);
      var $37=HEAP32[(($36)>>2)];
      var $38=(($37)|0)!=0;
      if ($38) { __label__ = 11; break; } else { __label__ = 25; break; }
    case 11: 
      var $40=$2;
      var $41=(($40+40)|0);
      var $42=HEAP32[(($41)>>2)];
      var $43=(($42)|0)==0;
      if ($43) { __label__ = 12; break; } else { __label__ = 13; break; }
    case 12: 
      var $45=$2;
      var $46=_HPDF_Dict_RemoveElement($45, ((STRING_TABLE.__str2609)|0));
      __label__ = 24; break;
    case 13: 
      var $48=$2;
      var $49=_HPDF_Dict_GetItem($48, ((STRING_TABLE.__str2609)|0), 16);
      var $50=$49;
      $array=$50;
      var $51=$array;
      var $52=(($51)|0)!=0;
      if ($52) { __label__ = 19; break; } else { __label__ = 14; break; }
    case 14: 
      var $54=$2;
      var $55=(($54+8)|0);
      var $56=HEAP32[(($55)>>2)];
      var $57=_HPDF_Array_New($56);
      $array=$57;
      var $58=$array;
      var $59=(($58)|0)!=0;
      if ($59) { __label__ = 16; break; } else { __label__ = 15; break; }
    case 15: 
      var $61=$2;
      var $62=(($61+12)|0);
      var $63=HEAP32[(($62)>>2)];
      var $64=_HPDF_Error_GetCode($63);
      $1=$64;
      __label__ = 65; break;
    case 16: 
      var $66=$2;
      var $67=$array;
      var $68=$67;
      var $69=_HPDF_Dict_Add($66, ((STRING_TABLE.__str2609)|0), $68);
      $ret=$69;
      var $70=$ret;
      var $71=(($70)|0)!=0;
      if ($71) { __label__ = 17; break; } else { __label__ = 18; break; }
    case 17: 
      var $73=$ret;
      $1=$73;
      __label__ = 65; break;
    case 18: 
      __label__ = 19; break;
    case 19: 
      var $76=$array;
      _HPDF_Array_Clear($76);
      var $77=$2;
      var $78=(($77+40)|0);
      var $79=HEAP32[(($78)>>2)];
      var $80=$79 & 1024;
      var $81=(($80)|0)!=0;
      if ($81) { __label__ = 20; break; } else { __label__ = 21; break; }
    case 20: 
      var $83=$array;
      var $84=_HPDF_Array_AddName($83, ((STRING_TABLE.__str3610)|0));
      __label__ = 21; break;
    case 21: 
      var $86=$2;
      var $87=(($86+40)|0);
      var $88=HEAP32[(($87)>>2)];
      var $89=$88 & 2048;
      var $90=(($89)|0)!=0;
      if ($90) { __label__ = 22; break; } else { __label__ = 23; break; }
    case 22: 
      var $92=$array;
      var $93=_HPDF_Array_AddName($92, ((STRING_TABLE.__str4611)|0));
      __label__ = 23; break;
    case 23: 
      __label__ = 24; break;
    case 24: 
      __label__ = 25; break;
    case 25: 
      $i=0;
      __label__ = 26; break;
    case 26: 
      var $98=$i;
      var $99=$2;
      var $100=(($99+16)|0);
      var $101=HEAP32[(($100)>>2)];
      var $102=(($101+16)|0);
      var $103=HEAPU32[(($102)>>2)];
      var $104=(($98)>>>0) < (($103)>>>0);
      if ($104) { __label__ = 27; break; } else { __label__ = 42; break; }
    case 27: 
      var $106=$2;
      var $107=(($106+16)|0);
      var $108=HEAP32[(($107)>>2)];
      var $109=$i;
      var $110=_HPDF_List_ItemAt($108, $109);
      var $111=$110;
      $element=$111;
      var $112=$element;
      var $113=(($112+128)|0);
      var $114=HEAP32[(($113)>>2)];
      var $115=$114;
      $header=$115;
      var $116=$element;
      var $117=(($116+128)|0);
      var $118=HEAP32[(($117)>>2)];
      var $119=(($118)|0)!=0;
      if ($119) { __label__ = 29; break; } else { __label__ = 28; break; }
    case 28: 
      var $121=$2;
      var $122=(($121+12)|0);
      var $123=HEAP32[(($122)>>2)];
      var $124=_HPDF_SetError($123, 4147, 0);
      $1=$124;
      __label__ = 65; break;
    case 29: 
      var $126=$header;
      var $127=(($126)|0);
      var $128=HEAP32[(($127)>>2)];
      var $129=$128 & 268435456;
      var $130=(($129)|0)!=0;
      if ($130) { __label__ = 30; break; } else { __label__ = 31; break; }
    case 30: 
      __label__ = 40; break;
    case 31: 
      var $133=$3;
      var $134=$element;
      var $135=(($134)|0);
      var $136=(($135)|0);
      var $137=_HPDF_Stream_WriteEscapeName($133, $136);
      $ret=$137;
      var $138=$ret;
      var $139=(($138)|0)!=0;
      if ($139) { __label__ = 32; break; } else { __label__ = 33; break; }
    case 32: 
      var $141=$ret;
      $1=$141;
      __label__ = 65; break;
    case 33: 
      var $143=$3;
      var $144=_HPDF_Stream_WriteChar($143, 32);
      $ret=$144;
      var $145=$ret;
      var $146=(($145)|0)!=0;
      if ($146) { __label__ = 34; break; } else { __label__ = 35; break; }
    case 34: 
      var $148=$ret;
      $1=$148;
      __label__ = 65; break;
    case 35: 
      var $150=$element;
      var $151=(($150+128)|0);
      var $152=HEAP32[(($151)>>2)];
      var $153=$3;
      var $154=$4;
      var $155=_HPDF_Obj_Write($152, $153, $154);
      $ret=$155;
      var $156=$ret;
      var $157=(($156)|0)!=0;
      if ($157) { __label__ = 36; break; } else { __label__ = 37; break; }
    case 36: 
      var $159=$ret;
      $1=$159;
      __label__ = 65; break;
    case 37: 
      var $161=$3;
      var $162=_HPDF_Stream_WriteStr($161, ((STRING_TABLE.__str5612)|0));
      $ret=$162;
      var $163=$ret;
      var $164=(($163)|0)!=0;
      if ($164) { __label__ = 38; break; } else { __label__ = 39; break; }
    case 38: 
      var $166=$ret;
      $1=$166;
      __label__ = 65; break;
    case 39: 
      __label__ = 40; break;
    case 40: 
      __label__ = 41; break;
    case 41: 
      var $170=$i;
      var $171=((($170)+(1))|0);
      $i=$171;
      __label__ = 26; break;
    case 42: 
      var $173=$2;
      var $174=(($173+24)|0);
      var $175=HEAP32[(($174)>>2)];
      var $176=(($175)|0)!=0;
      if ($176) { __label__ = 43; break; } else { __label__ = 46; break; }
    case 43: 
      var $178=$2;
      var $179=(($178+24)|0);
      var $180=HEAP32[(($179)>>2)];
      var $181=$2;
      var $182=$3;
      var $183=FUNCTION_TABLE[$180]($181, $182);
      $ret=$183;
      var $184=(($183)|0)!=0;
      if ($184) { __label__ = 44; break; } else { __label__ = 45; break; }
    case 44: 
      var $186=$ret;
      $1=$186;
      __label__ = 65; break;
    case 45: 
      __label__ = 46; break;
    case 46: 
      var $189=$3;
      var $190=_HPDF_Stream_WriteStr($189, ((STRING_TABLE.__str6613)|0));
      $ret=$190;
      var $191=(($190)|0)!=0;
      if ($191) { __label__ = 47; break; } else { __label__ = 48; break; }
    case 47: 
      var $193=$ret;
      $1=$193;
      __label__ = 65; break;
    case 48: 
      var $195=$2;
      var $196=(($195+36)|0);
      var $197=HEAP32[(($196)>>2)];
      var $198=(($197)|0)!=0;
      if ($198) { __label__ = 49; break; } else { __label__ = 60; break; }
    case 49: 
      var $200=$2;
      var $201=_HPDF_Dict_GetItem($200, ((STRING_TABLE.__str607)|0), 4);
      var $202=$201;
      $length=$202;
      var $203=$length;
      var $204=(($203)|0)!=0;
      if ($204) { __label__ = 51; break; } else { __label__ = 50; break; }
    case 50: 
      var $206=$2;
      var $207=(($206+12)|0);
      var $208=HEAP32[(($207)>>2)];
      var $209=_HPDF_SetError($208, 4106, 0);
      $1=$209;
      __label__ = 65; break;
    case 51: 
      var $211=$length;
      var $212=(($211)|0);
      var $213=(($212)|0);
      var $214=HEAP32[(($213)>>2)];
      var $215=$214 & 1073741824;
      var $216=(($215)|0)!=0;
      if ($216) { __label__ = 53; break; } else { __label__ = 52; break; }
    case 52: 
      var $218=$2;
      var $219=(($218+12)|0);
      var $220=HEAP32[(($219)>>2)];
      var $221=_HPDF_SetError($220, 4105, 0);
      $1=$221;
      __label__ = 65; break;
    case 53: 
      var $223=$3;
      var $224=_HPDF_Stream_WriteStr($223, ((STRING_TABLE.__str7614)|0));
      $ret=$224;
      var $225=(($224)|0)!=0;
      if ($225) { __label__ = 54; break; } else { __label__ = 55; break; }
    case 54: 
      var $227=$ret;
      $1=$227;
      __label__ = 65; break;
    case 55: 
      var $229=$3;
      var $230=(($229+16)|0);
      var $231=HEAP32[(($230)>>2)];
      $strptr=$231;
      var $232=$4;
      var $233=(($232)|0)!=0;
      if ($233) { __label__ = 56; break; } else { __label__ = 57; break; }
    case 56: 
      var $235=$4;
      _HPDF_Encrypt_Reset($235);
      __label__ = 57; break;
    case 57: 
      var $237=$2;
      var $238=(($237+36)|0);
      var $239=HEAP32[(($238)>>2)];
      var $240=$3;
      var $241=$2;
      var $242=(($241+40)|0);
      var $243=HEAP32[(($242)>>2)];
      var $244=$4;
      var $245=_HPDF_Stream_WriteToStream($239, $240, $243, $244);
      $ret=$245;
      var $246=(($245)|0)!=0;
      if ($246) { __label__ = 58; break; } else { __label__ = 59; break; }
    case 58: 
      var $248=$ret;
      $1=$248;
      __label__ = 65; break;
    case 59: 
      var $250=$length;
      var $251=$3;
      var $252=(($251+16)|0);
      var $253=HEAP32[(($252)>>2)];
      var $254=$strptr;
      var $255=((($253)-($254))|0);
      _HPDF_Number_SetValue($250, $255);
      var $256=$3;
      var $257=_HPDF_Stream_WriteStr($256, ((STRING_TABLE.__str8615)|0));
      $ret=$257;
      __label__ = 60; break;
    case 60: 
      var $259=$2;
      var $260=(($259+28)|0);
      var $261=HEAP32[(($260)>>2)];
      var $262=(($261)|0)!=0;
      if ($262) { __label__ = 61; break; } else { __label__ = 64; break; }
    case 61: 
      var $264=$2;
      var $265=(($264+28)|0);
      var $266=HEAP32[(($265)>>2)];
      var $267=$2;
      var $268=FUNCTION_TABLE[$266]($267);
      $ret=$268;
      var $269=(($268)|0)!=0;
      if ($269) { __label__ = 62; break; } else { __label__ = 63; break; }
    case 62: 
      var $271=$ret;
      $1=$271;
      __label__ = 65; break;
    case 63: 
      __label__ = 64; break;
    case 64: 
      var $274=$ret;
      $1=$274;
      __label__ = 65; break;
    case 65: 
      var $276=$1;
      ;
      return $276;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Dict_Write["X"]=1;

function _HPDF_Dict_RemoveElement($dict, $key) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $i;
      var $element;
      $2=$dict;
      $3=$key;
      $i=0;
      __label__ = 3; break;
    case 3: 
      var $5=$i;
      var $6=$2;
      var $7=(($6+16)|0);
      var $8=HEAP32[(($7)>>2)];
      var $9=(($8+16)|0);
      var $10=HEAPU32[(($9)>>2)];
      var $11=(($5)>>>0) < (($10)>>>0);
      if ($11) { __label__ = 4; break; } else { __label__ = 8; break; }
    case 4: 
      var $13=$2;
      var $14=(($13+16)|0);
      var $15=HEAP32[(($14)>>2)];
      var $16=$i;
      var $17=_HPDF_List_ItemAt($15, $16);
      var $18=$17;
      $element=$18;
      var $19=$3;
      var $20=$element;
      var $21=(($20)|0);
      var $22=(($21)|0);
      var $23=_HPDF_StrCmp($19, $22);
      var $24=(($23)|0)==0;
      if ($24) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $26=$2;
      var $27=(($26+16)|0);
      var $28=HEAP32[(($27)>>2)];
      var $29=$element;
      var $30=$29;
      var $31=_HPDF_List_Remove($28, $30);
      var $32=$2;
      var $33=(($32+8)|0);
      var $34=HEAP32[(($33)>>2)];
      var $35=$element;
      var $36=(($35+128)|0);
      var $37=HEAP32[(($36)>>2)];
      _HPDF_Obj_Free($34, $37);
      var $38=$2;
      var $39=(($38+8)|0);
      var $40=HEAP32[(($39)>>2)];
      var $41=$element;
      var $42=$41;
      _HPDF_FreeMem($40, $42);
      $1=0;
      __label__ = 9; break;
    case 6: 
      __label__ = 7; break;
    case 7: 
      var $45=$i;
      var $46=((($45)+(1))|0);
      $i=$46;
      __label__ = 3; break;
    case 8: 
      $1=4104;
      __label__ = 9; break;
    case 9: 
      var $49=$1;
      ;
      return $49;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Dict_RemoveElement["X"]=1;

function _HPDF_Dict_GetItem($dict, $key, $obj_class) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $element;
      var $obj;
      var $header;
      var $p;
      $2=$dict;
      $3=$key;
      $4=$obj_class;
      var $5=$2;
      var $6=$3;
      var $7=_GetElement($5, $6);
      $element=$7;
      var $8=$element;
      var $9=(($8)|0)!=0;
      if ($9) { __label__ = 3; break; } else { __label__ = 10; break; }
    case 3: 
      var $11=$3;
      var $12=$element;
      var $13=(($12)|0);
      var $14=(($13)|0);
      var $15=_HPDF_StrCmp($11, $14);
      var $16=(($15)|0)==0;
      if ($16) { __label__ = 4; break; } else { __label__ = 10; break; }
    case 4: 
      var $18=$element;
      var $19=(($18+128)|0);
      var $20=HEAP32[(($19)>>2)];
      var $21=$20;
      $header=$21;
      var $22=$header;
      var $23=(($22+6)|0);
      var $24=HEAPU16[(($23)>>1)];
      var $25=(($24)&65535);
      var $26=(($25)|0)==18;
      if ($26) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $28=$element;
      var $29=(($28+128)|0);
      var $30=HEAP32[(($29)>>2)];
      var $31=$30;
      $p=$31;
      var $32=$p;
      var $33=(($32+8)|0);
      var $34=HEAP32[(($33)>>2)];
      var $35=$34;
      $header=$35;
      var $36=$p;
      var $37=(($36+8)|0);
      var $38=HEAP32[(($37)>>2)];
      $obj=$38;
      __label__ = 7; break;
    case 6: 
      var $40=$element;
      var $41=(($40+128)|0);
      var $42=HEAP32[(($41)>>2)];
      $obj=$42;
      __label__ = 7; break;
    case 7: 
      var $44=$header;
      var $45=(($44+6)|0);
      var $46=HEAPU16[(($45)>>1)];
      var $47=(($46)&65535);
      var $48=$47 & 255;
      var $49=$4;
      var $50=(($49)&65535);
      var $51=(($48)|0)!=(($50)|0);
      if ($51) { __label__ = 8; break; } else { __label__ = 9; break; }
    case 8: 
      var $53=$2;
      var $54=(($53+12)|0);
      var $55=HEAP32[(($54)>>2)];
      var $56=_HPDF_SetError($55, 4105, 0);
      $1=0;
      __label__ = 11; break;
    case 9: 
      var $58=$obj;
      $1=$58;
      __label__ = 11; break;
    case 10: 
      $1=0;
      __label__ = 11; break;
    case 11: 
      var $61=$1;
      ;
      return $61;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Dict_GetItem["X"]=1;

function _GetElement($dict, $key) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $i;
      var $element;
      $2=$dict;
      $3=$key;
      $i=0;
      __label__ = 3; break;
    case 3: 
      var $5=$i;
      var $6=$2;
      var $7=(($6+16)|0);
      var $8=HEAP32[(($7)>>2)];
      var $9=(($8+16)|0);
      var $10=HEAPU32[(($9)>>2)];
      var $11=(($5)>>>0) < (($10)>>>0);
      if ($11) { __label__ = 4; break; } else { __label__ = 8; break; }
    case 4: 
      var $13=$2;
      var $14=(($13+16)|0);
      var $15=HEAP32[(($14)>>2)];
      var $16=$i;
      var $17=_HPDF_List_ItemAt($15, $16);
      var $18=$17;
      $element=$18;
      var $19=$3;
      var $20=$element;
      var $21=(($20)|0);
      var $22=(($21)|0);
      var $23=_HPDF_StrCmp($19, $22);
      var $24=(($23)|0)==0;
      if ($24) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $26=$element;
      $1=$26;
      __label__ = 9; break;
    case 6: 
      __label__ = 7; break;
    case 7: 
      var $29=$i;
      var $30=((($29)+(1))|0);
      $i=$30;
      __label__ = 3; break;
    case 8: 
      $1=0;
      __label__ = 9; break;
    case 9: 
      var $33=$1;
      ;
      return $33;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Dict_AddName($dict, $key, $value) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $name;
      $2=$dict;
      $3=$key;
      $4=$value;
      var $5=$2;
      var $6=(($5+8)|0);
      var $7=HEAP32[(($6)>>2)];
      var $8=$4;
      var $9=_HPDF_Name_New($7, $8);
      $name=$9;
      var $10=$name;
      var $11=(($10)|0)!=0;
      if ($11) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      var $13=$2;
      var $14=(($13+12)|0);
      var $15=HEAP32[(($14)>>2)];
      var $16=_HPDF_Error_GetCode($15);
      $1=$16;
      __label__ = 5; break;
    case 4: 
      var $18=$2;
      var $19=$3;
      var $20=$name;
      var $21=$20;
      var $22=_HPDF_Dict_Add($18, $19, $21);
      $1=$22;
      __label__ = 5; break;
    case 5: 
      var $24=$1;
      ;
      return $24;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Dict_AddNumber($dict, $key, $value) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $number;
      $2=$dict;
      $3=$key;
      $4=$value;
      var $5=$2;
      var $6=(($5+8)|0);
      var $7=HEAP32[(($6)>>2)];
      var $8=$4;
      var $9=_HPDF_Number_New($7, $8);
      $number=$9;
      var $10=$number;
      var $11=(($10)|0)!=0;
      if ($11) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      var $13=$2;
      var $14=(($13+12)|0);
      var $15=HEAP32[(($14)>>2)];
      var $16=_HPDF_Error_GetCode($15);
      $1=$16;
      __label__ = 5; break;
    case 4: 
      var $18=$2;
      var $19=$3;
      var $20=$number;
      var $21=$20;
      var $22=_HPDF_Dict_Add($18, $19, $21);
      $1=$22;
      __label__ = 5; break;
    case 5: 
      var $24=$1;
      ;
      return $24;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Dict_AddReal($dict, $key, $value) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $real;
      $2=$dict;
      $3=$key;
      $4=$value;
      var $5=$2;
      var $6=(($5+8)|0);
      var $7=HEAP32[(($6)>>2)];
      var $8=$4;
      var $9=_HPDF_Real_New($7, $8);
      $real=$9;
      var $10=$real;
      var $11=(($10)|0)!=0;
      if ($11) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      var $13=$2;
      var $14=(($13+12)|0);
      var $15=HEAP32[(($14)>>2)];
      var $16=_HPDF_Error_GetCode($15);
      $1=$16;
      __label__ = 5; break;
    case 4: 
      var $18=$2;
      var $19=$3;
      var $20=$real;
      var $21=$20;
      var $22=_HPDF_Dict_Add($18, $19, $21);
      $1=$22;
      __label__ = 5; break;
    case 5: 
      var $24=$1;
      ;
      return $24;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Dict_AddBoolean($dict, $key, $value) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $obj;
      $2=$dict;
      $3=$key;
      $4=$value;
      var $5=$2;
      var $6=(($5+8)|0);
      var $7=HEAP32[(($6)>>2)];
      var $8=$4;
      var $9=_HPDF_Boolean_New($7, $8);
      $obj=$9;
      var $10=$obj;
      var $11=(($10)|0)!=0;
      if ($11) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      var $13=$2;
      var $14=(($13+12)|0);
      var $15=HEAP32[(($14)>>2)];
      var $16=_HPDF_Error_GetCode($15);
      $1=$16;
      __label__ = 5; break;
    case 4: 
      var $18=$2;
      var $19=$3;
      var $20=$obj;
      var $21=$20;
      var $22=_HPDF_Dict_Add($18, $19, $21);
      $1=$22;
      __label__ = 5; break;
    case 5: 
      var $24=$1;
      ;
      return $24;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Dict_GetKeyByObj($dict, $obj) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $i;
      var $header;
      var $element;
      var $p;
      $2=$dict;
      $3=$obj;
      $i=0;
      __label__ = 3; break;
    case 3: 
      var $5=$i;
      var $6=$2;
      var $7=(($6+16)|0);
      var $8=HEAP32[(($7)>>2)];
      var $9=(($8+16)|0);
      var $10=HEAPU32[(($9)>>2)];
      var $11=(($5)>>>0) < (($10)>>>0);
      if ($11) { __label__ = 4; break; } else { __label__ = 13; break; }
    case 4: 
      var $13=$2;
      var $14=(($13+16)|0);
      var $15=HEAP32[(($14)>>2)];
      var $16=$i;
      var $17=_HPDF_List_ItemAt($15, $16);
      var $18=$17;
      $element=$18;
      var $19=$element;
      var $20=(($19+128)|0);
      var $21=HEAP32[(($20)>>2)];
      var $22=$21;
      $header=$22;
      var $23=$header;
      var $24=(($23+6)|0);
      var $25=HEAPU16[(($24)>>1)];
      var $26=(($25)&65535);
      var $27=(($26)|0)==18;
      if ($27) { __label__ = 5; break; } else { __label__ = 8; break; }
    case 5: 
      var $29=$element;
      var $30=(($29+128)|0);
      var $31=HEAP32[(($30)>>2)];
      var $32=$31;
      $p=$32;
      var $33=$p;
      var $34=(($33+8)|0);
      var $35=HEAP32[(($34)>>2)];
      var $36=$3;
      var $37=(($35)|0)==(($36)|0);
      if ($37) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      var $39=$element;
      var $40=(($39)|0);
      var $41=(($40)|0);
      $1=$41;
      __label__ = 14; break;
    case 7: 
      __label__ = 11; break;
    case 8: 
      var $44=$element;
      var $45=(($44+128)|0);
      var $46=HEAP32[(($45)>>2)];
      var $47=$3;
      var $48=(($46)|0)==(($47)|0);
      if ($48) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      var $50=$element;
      var $51=(($50)|0);
      var $52=(($51)|0);
      $1=$52;
      __label__ = 14; break;
    case 10: 
      __label__ = 11; break;
    case 11: 
      __label__ = 12; break;
    case 12: 
      var $56=$i;
      var $57=((($56)+(1))|0);
      $i=$57;
      __label__ = 3; break;
    case 13: 
      $1=0;
      __label__ = 14; break;
    case 14: 
      var $60=$1;
      ;
      return $60;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Dict_GetKeyByObj["X"]=1;

function _HPDF_HasDoc($pdf) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      $2=$pdf;
      var $3=$2;
      var $4=(($3)|0)!=0;
      if ($4) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $6=$2;
      var $7=(($6)|0);
      var $8=HEAP32[(($7)>>2)];
      var $9=(($8)|0)!=1095779398;
      if ($9) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      $1=0;
      __label__ = 9; break;
    case 5: 
      var $12=$2;
      var $13=(($12+12)|0);
      var $14=HEAP32[(($13)>>2)];
      var $15=(($14)|0)!=0;
      if ($15) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      var $17=$2;
      var $18=(($17+40)|0);
      var $19=(($18)|0);
      var $20=HEAP32[(($19)>>2)];
      var $21=(($20)|0)!=0;
      if ($21) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $23=$2;
      var $24=(($23+40)|0);
      var $25=_HPDF_RaiseError($24, 4133, 0);
      $1=0;
      __label__ = 9; break;
    case 8: 
      $1=1;
      __label__ = 9; break;
    case 9: 
      var $28=$1;
      ;
      return $28;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_New($user_error_fn, $user_data) {
  ;
  var __label__;

  var $1;
  var $2;
  $1=$user_error_fn;
  $2=$user_data;
  var $3=$1;
  var $4=$2;
  var $5=_HPDF_NewEx($3, 0, 0, 0, $4);
  ;
  return $5;
}


function _HPDF_NewEx($user_error_fn, $user_alloc_fn, $user_free_fn, $mem_pool_buf_size, $user_data) {
  var __stackBase__  = STACKTOP; STACKTOP += 16; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $5;
      var $6;
      var $pdf;
      var $mmgr;
      var $tmp_error=__stackBase__;
      $2=$user_error_fn;
      $3=$user_alloc_fn;
      $4=$user_free_fn;
      $5=$mem_pool_buf_size;
      $6=$user_data;
      var $7=$6;
      _HPDF_Error_Init($tmp_error, $7);
      var $8=$5;
      var $9=$3;
      var $10=$4;
      var $11=_HPDF_MMgr_New($tmp_error, $8, $9, $10);
      $mmgr=$11;
      var $12=$mmgr;
      var $13=(($12)|0)!=0;
      if ($13) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      var $15=_HPDF_CheckError($tmp_error);
      $1=0;
      __label__ = 9; break;
    case 4: 
      var $17=$mmgr;
      var $18=_HPDF_GetMem($17, 116);
      var $19=$18;
      $pdf=$19;
      var $20=$pdf;
      var $21=(($20)|0)!=0;
      if ($21) { __label__ = 6; break; } else { __label__ = 5; break; }
    case 5: 
      var $23=$mmgr;
      _HPDF_MMgr_Free($23);
      var $24=_HPDF_CheckError($tmp_error);
      $1=0;
      __label__ = 9; break;
    case 6: 
      var $26=$pdf;
      var $27=$26;
      var $28=_HPDF_MemSet($27, 0, 116);
      var $29=$pdf;
      var $30=(($29)|0);
      HEAP32[(($30)>>2)]=1095779398;
      var $31=$mmgr;
      var $32=$pdf;
      var $33=(($32+8)|0);
      HEAP32[(($33)>>2)]=$31;
      var $34=$pdf;
      var $35=(($34+4)|0);
      HEAP32[(($35)>>2)]=1;
      var $36=$pdf;
      var $37=(($36+88)|0);
      HEAP32[(($37)>>2)]=0;
      var $38=$pdf;
      var $39=(($38+40)|0);
      var $40=$39;
      var $41=$tmp_error;
      assert(16 % 1 === 0, 'memcpy given ' + 16 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP32[(($40)>>2)]=HEAP32[(($41)>>2)];HEAP32[((($40)+(4))>>2)]=HEAP32[((($41)+(4))>>2)];HEAP32[((($40)+(8))>>2)]=HEAP32[((($41)+(8))>>2)];HEAP32[((($40)+(12))>>2)]=HEAP32[((($41)+(12))>>2)];
      var $42=$pdf;
      var $43=(($42+40)|0);
      var $44=$mmgr;
      var $45=(($44)|0);
      HEAP32[(($45)>>2)]=$43;
      var $46=$pdf;
      var $47=_HPDF_NewDoc($46);
      var $48=(($47)|0)!=0;
      if ($48) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $50=$pdf;
      _HPDF_Free($50);
      var $51=_HPDF_CheckError($tmp_error);
      $1=0;
      __label__ = 9; break;
    case 8: 
      var $53=$2;
      var $54=$pdf;
      var $55=(($54+40)|0);
      var $56=(($55+8)|0);
      HEAP32[(($56)>>2)]=$53;
      var $57=$pdf;
      $1=$57;
      __label__ = 9; break;
    case 9: 
      var $59=$1;
      STACKTOP = __stackBase__;
      return $59;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_NewEx["X"]=1;

function _HPDF_NewDoc($pdf) {
  var __stackBase__  = STACKTOP; STACKTOP += 512; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $buf=__stackBase__;
      var $ptr;
      var $eptr;
      var $version;
      $2=$pdf;
      var $3=(($buf)|0);
      $ptr=$3;
      var $4=(($buf)|0);
      var $5=(($4+512)|0);
      var $6=((($5)-(1))|0);
      $eptr=$6;
      var $7=$2;
      var $8=_HPDF_Doc_Validate($7);
      var $9=(($8)|0)!=0;
      if ($9) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=4108;
      __label__ = 25; break;
    case 4: 
      var $12=$2;
      _HPDF_FreeDoc($12);
      var $13=$2;
      var $14=(($13+8)|0);
      var $15=HEAP32[(($14)>>2)];
      var $16=_HPDF_Xref_New($15, 0);
      var $17=$2;
      var $18=(($17+20)|0);
      HEAP32[(($18)>>2)]=$16;
      var $19=$2;
      var $20=(($19+20)|0);
      var $21=HEAP32[(($20)>>2)];
      var $22=(($21)|0)!=0;
      if ($22) { __label__ = 6; break; } else { __label__ = 5; break; }
    case 5: 
      var $24=$2;
      var $25=(($24+40)|0);
      var $26=_HPDF_CheckError($25);
      $1=$26;
      __label__ = 25; break;
    case 6: 
      var $28=$2;
      var $29=(($28+20)|0);
      var $30=HEAP32[(($29)>>2)];
      var $31=(($30+24)|0);
      var $32=HEAP32[(($31)>>2)];
      var $33=$2;
      var $34=(($33+60)|0);
      HEAP32[(($34)>>2)]=$32;
      var $35=$2;
      var $36=(($35+8)|0);
      var $37=HEAP32[(($36)>>2)];
      var $38=_HPDF_List_New($37, 20);
      var $39=$2;
      var $40=(($39+64)|0);
      HEAP32[(($40)>>2)]=$38;
      var $41=$2;
      var $42=(($41+64)|0);
      var $43=HEAP32[(($42)>>2)];
      var $44=(($43)|0)!=0;
      if ($44) { __label__ = 8; break; } else { __label__ = 7; break; }
    case 7: 
      var $46=$2;
      var $47=(($46+40)|0);
      var $48=_HPDF_CheckError($47);
      $1=$48;
      __label__ = 25; break;
    case 8: 
      var $50=$2;
      var $51=(($50+76)|0);
      var $52=HEAP32[(($51)>>2)];
      var $53=(($52)|0)!=0;
      if ($53) { __label__ = 12; break; } else { __label__ = 9; break; }
    case 9: 
      var $55=$2;
      var $56=(($55+8)|0);
      var $57=HEAP32[(($56)>>2)];
      var $58=_HPDF_List_New($57, 20);
      var $59=$2;
      var $60=(($59+76)|0);
      HEAP32[(($60)>>2)]=$58;
      var $61=$2;
      var $62=(($61+76)|0);
      var $63=HEAP32[(($62)>>2)];
      var $64=(($63)|0)!=0;
      if ($64) { __label__ = 11; break; } else { __label__ = 10; break; }
    case 10: 
      var $66=$2;
      var $67=(($66+40)|0);
      var $68=_HPDF_CheckError($67);
      $1=$68;
      __label__ = 25; break;
    case 11: 
      __label__ = 12; break;
    case 12: 
      var $71=$2;
      var $72=(($71+80)|0);
      var $73=HEAP32[(($72)>>2)];
      var $74=(($73)|0)!=0;
      if ($74) { __label__ = 16; break; } else { __label__ = 13; break; }
    case 13: 
      var $76=$2;
      var $77=(($76+8)|0);
      var $78=HEAP32[(($77)>>2)];
      var $79=_HPDF_List_New($78, 20);
      var $80=$2;
      var $81=(($80+80)|0);
      HEAP32[(($81)>>2)]=$79;
      var $82=$2;
      var $83=(($82+80)|0);
      var $84=HEAP32[(($83)>>2)];
      var $85=(($84)|0)!=0;
      if ($85) { __label__ = 15; break; } else { __label__ = 14; break; }
    case 14: 
      var $87=$2;
      var $88=(($87+40)|0);
      var $89=_HPDF_CheckError($88);
      $1=$89;
      __label__ = 25; break;
    case 15: 
      __label__ = 16; break;
    case 16: 
      var $92=$2;
      var $93=(($92+8)|0);
      var $94=HEAP32[(($93)>>2)];
      var $95=$2;
      var $96=(($95+20)|0);
      var $97=HEAP32[(($96)>>2)];
      var $98=_HPDF_Catalog_New($94, $97);
      var $99=$2;
      var $100=(($99+12)|0);
      HEAP32[(($100)>>2)]=$98;
      var $101=$2;
      var $102=(($101+12)|0);
      var $103=HEAP32[(($102)>>2)];
      var $104=(($103)|0)!=0;
      if ($104) { __label__ = 18; break; } else { __label__ = 17; break; }
    case 17: 
      var $106=$2;
      var $107=(($106+40)|0);
      var $108=_HPDF_CheckError($107);
      $1=$108;
      __label__ = 25; break;
    case 18: 
      var $110=$2;
      var $111=(($110+12)|0);
      var $112=HEAP32[(($111)>>2)];
      var $113=_HPDF_Catalog_GetRoot($112);
      var $114=$2;
      var $115=(($114+24)|0);
      HEAP32[(($115)>>2)]=$113;
      var $116=$2;
      var $117=(($116+24)|0);
      var $118=HEAP32[(($117)>>2)];
      var $119=(($118)|0)!=0;
      if ($119) { __label__ = 20; break; } else { __label__ = 19; break; }
    case 19: 
      var $121=$2;
      var $122=(($121+40)|0);
      var $123=_HPDF_CheckError($122);
      $1=$123;
      __label__ = 25; break;
    case 20: 
      var $125=$2;
      var $126=(($125+8)|0);
      var $127=HEAP32[(($126)>>2)];
      var $128=_HPDF_List_New($127, 256);
      var $129=$2;
      var $130=(($129+36)|0);
      HEAP32[(($130)>>2)]=$128;
      var $131=$2;
      var $132=(($131+36)|0);
      var $133=HEAP32[(($132)>>2)];
      var $134=(($133)|0)!=0;
      if ($134) { __label__ = 22; break; } else { __label__ = 21; break; }
    case 21: 
      var $136=$2;
      var $137=(($136+40)|0);
      var $138=_HPDF_CheckError($137);
      $1=$138;
      __label__ = 25; break;
    case 22: 
      var $140=$2;
      var $141=(($140+24)|0);
      var $142=HEAP32[(($141)>>2)];
      var $143=$2;
      var $144=(($143+28)|0);
      HEAP32[(($144)>>2)]=$142;
      var $145=$ptr;
      var $146=$eptr;
      var $147=_HPDF_StrCpy($145, ((STRING_TABLE.__str1631)|0), $146);
      $ptr=$147;
      var $148=_HPDF_GetVersion();
      $version=$148;
      var $149=$ptr;
      var $150=$version;
      var $151=$eptr;
      var $152=_HPDF_StrCpy($149, $150, $151);
      var $153=$2;
      var $154=(($buf)|0);
      var $155=_HPDF_SetInfoAttr($153, 4, $154);
      var $156=(($155)|0)!=0;
      if ($156) { __label__ = 23; break; } else { __label__ = 24; break; }
    case 23: 
      var $158=$2;
      var $159=(($158+40)|0);
      var $160=_HPDF_CheckError($159);
      $1=$160;
      __label__ = 25; break;
    case 24: 
      $1=0;
      __label__ = 25; break;
    case 25: 
      var $163=$1;
      STACKTOP = __stackBase__;
      return $163;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_NewDoc["X"]=1;

function _HPDF_Free($pdf) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $mmgr;
      $1=$pdf;
      var $2=$1;
      var $3=(($2)|0)!=0;
      if ($3) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $5=$1;
      var $6=(($5+8)|0);
      var $7=HEAP32[(($6)>>2)];
      $mmgr=$7;
      var $8=$1;
      _HPDF_FreeDocAll($8);
      var $9=$1;
      var $10=(($9)|0);
      HEAP32[(($10)>>2)]=0;
      var $11=$mmgr;
      var $12=$1;
      var $13=$12;
      _HPDF_FreeMem($11, $13);
      var $14=$mmgr;
      _HPDF_MMgr_Free($14);
      __label__ = 4; break;
    case 4: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_FreeDocAll($pdf) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      $1=$pdf;
      var $2=$1;
      var $3=_HPDF_Doc_Validate($2);
      var $4=(($3)|0)!=0;
      if ($4) { __label__ = 3; break; } else { __label__ = 8; break; }
    case 3: 
      var $6=$1;
      _HPDF_FreeDoc($6);
      var $7=$1;
      var $8=(($7+76)|0);
      var $9=HEAP32[(($8)>>2)];
      var $10=(($9)|0)!=0;
      if ($10) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      var $12=$1;
      _FreeFontDefList($12);
      __label__ = 5; break;
    case 5: 
      var $14=$1;
      var $15=(($14+80)|0);
      var $16=HEAP32[(($15)>>2)];
      var $17=(($16)|0)!=0;
      if ($17) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      var $19=$1;
      _FreeEncoderList($19);
      __label__ = 7; break;
    case 7: 
      var $21=$1;
      var $22=(($21+88)|0);
      HEAP32[(($22)>>2)]=0;
      var $23=$1;
      var $24=(($23+40)|0);
      _HPDF_Error_Reset($24);
      __label__ = 8; break;
    case 8: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_FreeDoc($pdf) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      $1=$pdf;
      var $2=$1;
      var $3=_HPDF_Doc_Validate($2);
      var $4=(($3)|0)!=0;
      if ($4) { __label__ = 3; break; } else { __label__ = 14; break; }
    case 3: 
      var $6=$1;
      var $7=(($6+20)|0);
      var $8=HEAP32[(($7)>>2)];
      var $9=(($8)|0)!=0;
      if ($9) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      var $11=$1;
      var $12=(($11+20)|0);
      var $13=HEAP32[(($12)>>2)];
      _HPDF_Xref_Free($13);
      var $14=$1;
      var $15=(($14+20)|0);
      HEAP32[(($15)>>2)]=0;
      __label__ = 5; break;
    case 5: 
      var $17=$1;
      var $18=(($17+64)|0);
      var $19=HEAP32[(($18)>>2)];
      var $20=(($19)|0)!=0;
      if ($20) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      var $22=$1;
      var $23=(($22+64)|0);
      var $24=HEAP32[(($23)>>2)];
      _HPDF_List_Free($24);
      var $25=$1;
      var $26=(($25+64)|0);
      HEAP32[(($26)>>2)]=0;
      __label__ = 7; break;
    case 7: 
      var $28=$1;
      var $29=(($28+76)|0);
      var $30=HEAP32[(($29)>>2)];
      var $31=(($30)|0)!=0;
      if ($31) { __label__ = 8; break; } else { __label__ = 9; break; }
    case 8: 
      var $33=$1;
      _CleanupFontDefList($33);
      __label__ = 9; break;
    case 9: 
      var $35=$1;
      var $36=(($35+68)|0);
      var $37=(($36)|0);
      var $38=_HPDF_MemSet($37, 0, 6);
      var $39=$1;
      var $40=(($39+4)|0);
      HEAP32[(($40)>>2)]=1;
      var $41=$1;
      var $42=(($41+16)|0);
      HEAP32[(($42)>>2)]=0;
      var $43=$1;
      var $44=(($43+12)|0);
      HEAP32[(($44)>>2)]=0;
      var $45=$1;
      var $46=(($45+24)|0);
      HEAP32[(($46)>>2)]=0;
      var $47=$1;
      var $48=(($47+28)|0);
      HEAP32[(($48)>>2)]=0;
      var $49=$1;
      var $50=(($49+32)|0);
      HEAP32[(($50)>>2)]=0;
      var $51=$1;
      var $52=(($51+92)|0);
      HEAP32[(($52)>>2)]=0;
      var $53=$1;
      var $54=(($53+108)|0);
      HEAP32[(($54)>>2)]=0;
      var $55=$1;
      var $56=(($55+84)|0);
      HEAP32[(($56)>>2)]=0;
      var $57=$1;
      var $58=(($57+100)|0);
      HEAP32[(($58)>>2)]=0;
      var $59=$1;
      var $60=(($59+104)|0);
      HEAP32[(($60)>>2)]=0;
      var $61=$1;
      var $62=(($61+36)|0);
      var $63=HEAP32[(($62)>>2)];
      var $64=(($63)|0)!=0;
      if ($64) { __label__ = 10; break; } else { __label__ = 11; break; }
    case 10: 
      var $66=$1;
      var $67=(($66+36)|0);
      var $68=HEAP32[(($67)>>2)];
      _HPDF_List_Free($68);
      var $69=$1;
      var $70=(($69+36)|0);
      HEAP32[(($70)>>2)]=0;
      __label__ = 11; break;
    case 11: 
      var $72=$1;
      var $73=(($72+96)|0);
      HEAP32[(($73)>>2)]=0;
      var $74=$1;
      var $75=(($74+56)|0);
      HEAP32[(($75)>>2)]=0;
      var $76=$1;
      var $77=(($76+40)|0);
      _HPDF_Error_Reset($77);
      var $78=$1;
      var $79=(($78+112)|0);
      var $80=HEAP32[(($79)>>2)];
      var $81=(($80)|0)!=0;
      if ($81) { __label__ = 12; break; } else { __label__ = 13; break; }
    case 12: 
      var $83=$1;
      var $84=(($83+112)|0);
      var $85=HEAP32[(($84)>>2)];
      _HPDF_Stream_Free($85);
      var $86=$1;
      var $87=(($86+112)|0);
      HEAP32[(($87)>>2)]=0;
      __label__ = 13; break;
    case 13: 
      __label__ = 14; break;
    case 14: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_FreeDoc["X"]=1;

function _HPDF_SetInfoAttr($pdf, $type, $value) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $ret;
      var $info;
      $2=$pdf;
      $3=$type;
      $4=$value;
      var $5=$2;
      var $6=_GetInfo($5);
      $info=$6;
      var $7=$info;
      var $8=(($7)|0)!=0;
      if ($8) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      var $10=$2;
      var $11=(($10+40)|0);
      var $12=_HPDF_CheckError($11);
      $1=$12;
      __label__ = 7; break;
    case 4: 
      var $14=$info;
      var $15=$3;
      var $16=$4;
      var $17=$2;
      var $18=(($17+84)|0);
      var $19=HEAP32[(($18)>>2)];
      var $20=_HPDF_Info_SetInfoAttr($14, $15, $16, $19);
      $ret=$20;
      var $21=$ret;
      var $22=(($21)|0)!=0;
      if ($22) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $24=$2;
      var $25=(($24+40)|0);
      var $26=_HPDF_CheckError($25);
      $1=$26;
      __label__ = 7; break;
    case 6: 
      var $28=$ret;
      $1=$28;
      __label__ = 7; break;
    case 7: 
      var $30=$1;
      ;
      return $30;
    default: assert(0, "bad label: " + __label__);
  }
}


function _CleanupFontDefList($pdf) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $list;
      var $i;
      var $def;
      $1=$pdf;
      var $2=$1;
      var $3=(($2+76)|0);
      var $4=HEAP32[(($3)>>2)];
      $list=$4;
      $i=0;
      __label__ = 3; break;
    case 3: 
      var $6=$i;
      var $7=$list;
      var $8=(($7+16)|0);
      var $9=HEAPU32[(($8)>>2)];
      var $10=(($6)>>>0) < (($9)>>>0);
      if ($10) { __label__ = 4; break; } else { __label__ = 6; break; }
    case 4: 
      var $12=$list;
      var $13=$i;
      var $14=_HPDF_List_ItemAt($12, $13);
      var $15=$14;
      $def=$15;
      var $16=$def;
      _HPDF_FontDef_Cleanup($16);
      __label__ = 5; break;
    case 5: 
      var $18=$i;
      var $19=((($18)+(1))|0);
      $i=$19;
      __label__ = 3; break;
    case 6: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}


function _FreeFontDefList($pdf) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $list;
      var $i;
      var $def;
      $1=$pdf;
      var $2=$1;
      var $3=(($2+76)|0);
      var $4=HEAP32[(($3)>>2)];
      $list=$4;
      $i=0;
      __label__ = 3; break;
    case 3: 
      var $6=$i;
      var $7=$list;
      var $8=(($7+16)|0);
      var $9=HEAPU32[(($8)>>2)];
      var $10=(($6)>>>0) < (($9)>>>0);
      if ($10) { __label__ = 4; break; } else { __label__ = 6; break; }
    case 4: 
      var $12=$list;
      var $13=$i;
      var $14=_HPDF_List_ItemAt($12, $13);
      var $15=$14;
      $def=$15;
      var $16=$def;
      _HPDF_FontDef_Free($16);
      __label__ = 5; break;
    case 5: 
      var $18=$i;
      var $19=((($18)+(1))|0);
      $i=$19;
      __label__ = 3; break;
    case 6: 
      var $21=$list;
      _HPDF_List_Free($21);
      var $22=$1;
      var $23=(($22+76)|0);
      HEAP32[(($23)>>2)]=0;
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}


function _FreeEncoderList($pdf) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $list;
      var $i;
      var $encoder;
      $1=$pdf;
      var $2=$1;
      var $3=(($2+80)|0);
      var $4=HEAP32[(($3)>>2)];
      $list=$4;
      $i=0;
      __label__ = 3; break;
    case 3: 
      var $6=$i;
      var $7=$list;
      var $8=(($7+16)|0);
      var $9=HEAPU32[(($8)>>2)];
      var $10=(($6)>>>0) < (($9)>>>0);
      if ($10) { __label__ = 4; break; } else { __label__ = 6; break; }
    case 4: 
      var $12=$list;
      var $13=$i;
      var $14=_HPDF_List_ItemAt($12, $13);
      var $15=$14;
      $encoder=$15;
      var $16=$encoder;
      _HPDF_Encoder_Free($16);
      __label__ = 5; break;
    case 5: 
      var $18=$i;
      var $19=((($18)+(1))|0);
      $i=$19;
      __label__ = 3; break;
    case 6: 
      var $21=$list;
      _HPDF_List_Free($21);
      var $22=$1;
      var $23=(($22+80)|0);
      HEAP32[(($23)>>2)]=0;
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_SetPagesConfiguration($pdf, $page_per_pages) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      $2=$pdf;
      $3=$page_per_pages;
      var $4=$2;
      var $5=_HPDF_HasDoc($4);
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=4133;
      __label__ = 13; break;
    case 4: 
      var $9=$2;
      var $10=(($9+32)|0);
      var $11=HEAP32[(($10)>>2)];
      var $12=(($11)|0)!=0;
      if ($12) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $14=$2;
      var $15=(($14+40)|0);
      var $16=_HPDF_RaiseError($15, 4134, 0);
      $1=$16;
      __label__ = 13; break;
    case 6: 
      var $18=$3;
      var $19=(($18)>>>0) > 8191;
      if ($19) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $21=$2;
      var $22=(($21+40)|0);
      var $23=_HPDF_RaiseError($22, 4153, 0);
      $1=$23;
      __label__ = 13; break;
    case 8: 
      var $25=$2;
      var $26=(($25+28)|0);
      var $27=HEAP32[(($26)>>2)];
      var $28=$2;
      var $29=(($28+24)|0);
      var $30=HEAP32[(($29)>>2)];
      var $31=(($27)|0)==(($30)|0);
      if ($31) { __label__ = 9; break; } else { __label__ = 12; break; }
    case 9: 
      var $33=$2;
      var $34=$2;
      var $35=(($34+24)|0);
      var $36=HEAP32[(($35)>>2)];
      var $37=_HPDF_Doc_AddPagesTo($33, $36);
      var $38=$2;
      var $39=(($38+28)|0);
      HEAP32[(($39)>>2)]=$37;
      var $40=$2;
      var $41=(($40+28)|0);
      var $42=HEAP32[(($41)>>2)];
      var $43=(($42)|0)!=0;
      if ($43) { __label__ = 11; break; } else { __label__ = 10; break; }
    case 10: 
      var $45=$2;
      var $46=(($45+40)|0);
      var $47=(($46)|0);
      var $48=HEAP32[(($47)>>2)];
      $1=$48;
      __label__ = 13; break;
    case 11: 
      var $50=$2;
      var $51=(($50+108)|0);
      HEAP32[(($51)>>2)]=0;
      __label__ = 12; break;
    case 12: 
      var $53=$3;
      var $54=$2;
      var $55=(($54+104)|0);
      HEAP32[(($55)>>2)]=$53;
      $1=0;
      __label__ = 13; break;
    case 13: 
      var $57=$1;
      ;
      return $57;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_SetPagesConfiguration["X"]=1;

function _HPDF_Doc_AddPagesTo($pdf, $parent) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $pages;
      $2=$pdf;
      $3=$parent;
      var $4=$2;
      var $5=_HPDF_HasDoc($4);
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=0;
      __label__ = 12; break;
    case 4: 
      var $9=$3;
      var $10=_HPDF_Pages_Validate($9);
      var $11=(($10)|0)!=0;
      if ($11) { __label__ = 6; break; } else { __label__ = 5; break; }
    case 5: 
      var $13=$2;
      var $14=(($13+40)|0);
      var $15=_HPDF_RaiseError($14, 4152, 0);
      $1=0;
      __label__ = 12; break;
    case 6: 
      var $17=$2;
      var $18=(($17+8)|0);
      var $19=HEAP32[(($18)>>2)];
      var $20=$3;
      var $21=(($20+8)|0);
      var $22=HEAP32[(($21)>>2)];
      var $23=(($19)|0)!=(($22)|0);
      if ($23) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $25=$2;
      var $26=(($25+40)|0);
      var $27=_HPDF_RaiseError($26, 4152, 0);
      $1=0;
      __label__ = 12; break;
    case 8: 
      var $29=$2;
      var $30=(($29+8)|0);
      var $31=HEAP32[(($30)>>2)];
      var $32=$3;
      var $33=$2;
      var $34=(($33+20)|0);
      var $35=HEAP32[(($34)>>2)];
      var $36=_HPDF_Pages_New($31, $32, $35);
      $pages=$36;
      var $37=$pages;
      var $38=(($37)|0)!=0;
      if ($38) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      var $40=$pages;
      var $41=$2;
      var $42=(($41+28)|0);
      HEAP32[(($42)>>2)]=$40;
      __label__ = 11; break;
    case 10: 
      var $44=$2;
      var $45=(($44+40)|0);
      var $46=_HPDF_CheckError($45);
      __label__ = 11; break;
    case 11: 
      var $48=$pages;
      $1=$48;
      __label__ = 12; break;
    case 12: 
      var $50=$1;
      ;
      return $50;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Doc_AddPagesTo["X"]=1;

function _HPDF_Doc_SetEncryptOn($pdf) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      $2=$pdf;
      var $3=$2;
      var $4=(($3+92)|0);
      var $5=HEAP32[(($4)>>2)];
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      $1=0;
      __label__ = 13; break;
    case 4: 
      var $9=$2;
      var $10=(($9+96)|0);
      var $11=HEAP32[(($10)>>2)];
      var $12=(($11)|0)!=0;
      if ($12) { __label__ = 6; break; } else { __label__ = 5; break; }
    case 5: 
      var $14=$2;
      var $15=(($14+40)|0);
      var $16=_HPDF_SetError($15, 4107, 0);
      $1=$16;
      __label__ = 13; break;
    case 6: 
      var $18=$2;
      var $19=(($18+96)|0);
      var $20=HEAP32[(($19)>>2)];
      var $21=(($20)|0);
      var $22=(($21)|0);
      var $23=HEAP32[(($22)>>2)];
      var $24=(($23)|0)==0;
      if ($24) { __label__ = 7; break; } else { __label__ = 10; break; }
    case 7: 
      var $26=$2;
      var $27=(($26+20)|0);
      var $28=HEAP32[(($27)>>2)];
      var $29=$2;
      var $30=(($29+96)|0);
      var $31=HEAP32[(($30)>>2)];
      var $32=$31;
      var $33=_HPDF_Xref_Add($28, $32);
      var $34=(($33)|0)!=0;
      if ($34) { __label__ = 8; break; } else { __label__ = 9; break; }
    case 8: 
      var $36=$2;
      var $37=(($36+40)|0);
      var $38=(($37)|0);
      var $39=HEAP32[(($38)>>2)];
      $1=$39;
      __label__ = 13; break;
    case 9: 
      __label__ = 10; break;
    case 10: 
      var $42=$2;
      var $43=(($42+60)|0);
      var $44=HEAP32[(($43)>>2)];
      var $45=$2;
      var $46=(($45+96)|0);
      var $47=HEAP32[(($46)>>2)];
      var $48=$47;
      var $49=_HPDF_Dict_Add($44, ((STRING_TABLE.__str2632)|0), $48);
      var $50=(($49)|0)!=0;
      if ($50) { __label__ = 11; break; } else { __label__ = 12; break; }
    case 11: 
      var $52=$2;
      var $53=(($52+40)|0);
      var $54=(($53)|0);
      var $55=HEAP32[(($54)>>2)];
      $1=$55;
      __label__ = 13; break;
    case 12: 
      var $57=$2;
      var $58=(($57+92)|0);
      HEAP32[(($58)>>2)]=1;
      $1=0;
      __label__ = 13; break;
    case 13: 
      var $60=$1;
      ;
      return $60;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Doc_SetEncryptOn["X"]=1;

function _HPDF_SetPassword($pdf, $owner_passwd, $user_passwd) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      $2=$pdf;
      $3=$owner_passwd;
      $4=$user_passwd;
      var $5=$2;
      var $6=_HPDF_HasDoc($5);
      var $7=(($6)|0)!=0;
      if ($7) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=4108;
      __label__ = 11; break;
    case 4: 
      var $10=$2;
      var $11=(($10+96)|0);
      var $12=HEAP32[(($11)>>2)];
      var $13=(($12)|0)!=0;
      if ($13) { __label__ = 8; break; } else { __label__ = 5; break; }
    case 5: 
      var $15=$2;
      var $16=(($15+8)|0);
      var $17=HEAP32[(($16)>>2)];
      var $18=$2;
      var $19=(($18+20)|0);
      var $20=HEAP32[(($19)>>2)];
      var $21=_HPDF_EncryptDict_New($17, $20);
      var $22=$2;
      var $23=(($22+96)|0);
      HEAP32[(($23)>>2)]=$21;
      var $24=$2;
      var $25=(($24+96)|0);
      var $26=HEAP32[(($25)>>2)];
      var $27=(($26)|0)!=0;
      if ($27) { __label__ = 7; break; } else { __label__ = 6; break; }
    case 6: 
      var $29=$2;
      var $30=(($29+40)|0);
      var $31=_HPDF_CheckError($30);
      $1=$31;
      __label__ = 11; break;
    case 7: 
      __label__ = 8; break;
    case 8: 
      var $34=$2;
      var $35=(($34+96)|0);
      var $36=HEAP32[(($35)>>2)];
      var $37=$3;
      var $38=$4;
      var $39=_HPDF_EncryptDict_SetPassword($36, $37, $38);
      var $40=(($39)|0)!=0;
      if ($40) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      var $42=$2;
      var $43=(($42+40)|0);
      var $44=_HPDF_CheckError($43);
      $1=$44;
      __label__ = 11; break;
    case 10: 
      var $46=$2;
      var $47=_HPDF_Doc_SetEncryptOn($46);
      $1=$47;
      __label__ = 11; break;
    case 11: 
      var $49=$1;
      ;
      return $49;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_SetPassword["X"]=1;

function _HPDF_SetPermission($pdf, $permission) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $e;
      $2=$pdf;
      $3=$permission;
      var $4=$2;
      var $5=_HPDF_HasDoc($4);
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=4108;
      __label__ = 8; break;
    case 4: 
      var $9=$2;
      var $10=(($9+96)|0);
      var $11=HEAP32[(($10)>>2)];
      var $12=_HPDF_EncryptDict_GetAttr($11);
      $e=$12;
      var $13=$e;
      var $14=(($13)|0)!=0;
      if ($14) { __label__ = 6; break; } else { __label__ = 5; break; }
    case 5: 
      var $16=$2;
      var $17=(($16+40)|0);
      var $18=_HPDF_RaiseError($17, 4107, 0);
      $1=$18;
      __label__ = 8; break;
    case 6: 
      var $20=$3;
      var $21=$e;
      var $22=(($21+136)|0);
      HEAP32[(($22)>>2)]=$20;
      __label__ = 7; break;
    case 7: 
      $1=0;
      __label__ = 8; break;
    case 8: 
      var $25=$1;
      ;
      return $25;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_SetEncryptionMode($pdf, $mode, $key_len) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $e;
      $2=$pdf;
      $3=$mode;
      $4=$key_len;
      var $5=$2;
      var $6=_HPDF_Doc_Validate($5);
      var $7=(($6)|0)!=0;
      if ($7) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=4108;
      __label__ = 18; break;
    case 4: 
      var $10=$2;
      var $11=(($10+96)|0);
      var $12=HEAP32[(($11)>>2)];
      var $13=_HPDF_EncryptDict_GetAttr($12);
      $e=$13;
      var $14=$e;
      var $15=(($14)|0)!=0;
      if ($15) { __label__ = 6; break; } else { __label__ = 5; break; }
    case 5: 
      var $17=$2;
      var $18=(($17+40)|0);
      var $19=_HPDF_RaiseError($18, 4107, 0);
      $1=$19;
      __label__ = 18; break;
    case 6: 
      var $21=$3;
      var $22=(($21)|0)==2;
      if ($22) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $24=$e;
      var $25=(($24+4)|0);
      HEAP32[(($25)>>2)]=5;
      __label__ = 16; break;
    case 8: 
      var $27=$2;
      var $28=(($27+4)|0);
      HEAP32[(($28)>>2)]=2;
      var $29=$4;
      var $30=(($29)>>>0) >= 5;
      if ($30) { __label__ = 9; break; } else { __label__ = 11; break; }
    case 9: 
      var $32=$4;
      var $33=(($32)>>>0) <= 16;
      if ($33) { __label__ = 10; break; } else { __label__ = 11; break; }
    case 10: 
      var $35=$4;
      var $36=$e;
      var $37=(($36+4)|0);
      HEAP32[(($37)>>2)]=$35;
      __label__ = 15; break;
    case 11: 
      var $39=$4;
      var $40=(($39)|0)==0;
      if ($40) { __label__ = 12; break; } else { __label__ = 13; break; }
    case 12: 
      var $42=$e;
      var $43=(($42+4)|0);
      HEAP32[(($43)>>2)]=16;
      __label__ = 14; break;
    case 13: 
      var $45=$2;
      var $46=(($45+40)|0);
      var $47=_HPDF_RaiseError($46, 4140, 0);
      $1=$47;
      __label__ = 18; break;
    case 14: 
      __label__ = 15; break;
    case 15: 
      __label__ = 16; break;
    case 16: 
      var $51=$3;
      var $52=$e;
      var $53=(($52)|0);
      HEAP32[(($53)>>2)]=$51;
      __label__ = 17; break;
    case 17: 
      $1=0;
      __label__ = 18; break;
    case 18: 
      var $56=$1;
      ;
      return $56;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_SetEncryptionMode["X"]=1;

function _HPDF_Doc_PrepareEncryption($pdf) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $e;
      var $info;
      var $id;
      $2=$pdf;
      var $3=$2;
      var $4=(($3+96)|0);
      var $5=HEAP32[(($4)>>2)];
      var $6=_HPDF_EncryptDict_GetAttr($5);
      $e=$6;
      var $7=$2;
      var $8=_GetInfo($7);
      $info=$8;
      var $9=$e;
      var $10=(($9)|0)!=0;
      if ($10) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=4107;
      __label__ = 19; break;
    case 4: 
      var $13=$info;
      var $14=(($13)|0)!=0;
      if ($14) { __label__ = 6; break; } else { __label__ = 5; break; }
    case 5: 
      var $16=$2;
      var $17=(($16+40)|0);
      var $18=(($17)|0);
      var $19=HEAP32[(($18)>>2)];
      $1=$19;
      __label__ = 19; break;
    case 6: 
      var $21=$2;
      var $22=(($21+96)|0);
      var $23=HEAP32[(($22)>>2)];
      var $24=$info;
      var $25=$2;
      var $26=(($25+20)|0);
      var $27=HEAP32[(($26)>>2)];
      var $28=_HPDF_EncryptDict_Prepare($23, $24, $27);
      var $29=(($28)|0)!=0;
      if ($29) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $31=$2;
      var $32=(($31+40)|0);
      var $33=(($32)|0);
      var $34=HEAP32[(($33)>>2)];
      $1=$34;
      __label__ = 19; break;
    case 8: 
      var $36=$2;
      var $37=(($36+60)|0);
      var $38=HEAP32[(($37)>>2)];
      var $39=_HPDF_Dict_GetItem($38, ((STRING_TABLE.__str3633)|0), 16);
      var $40=$39;
      $id=$40;
      var $41=$id;
      var $42=(($41)|0)!=0;
      if ($42) { __label__ = 13; break; } else { __label__ = 9; break; }
    case 9: 
      var $44=$2;
      var $45=(($44+8)|0);
      var $46=HEAP32[(($45)>>2)];
      var $47=_HPDF_Array_New($46);
      $id=$47;
      var $48=$id;
      var $49=(($48)|0)!=0;
      if ($49) { __label__ = 10; break; } else { __label__ = 11; break; }
    case 10: 
      var $51=$2;
      var $52=(($51+60)|0);
      var $53=HEAP32[(($52)>>2)];
      var $54=$id;
      var $55=$54;
      var $56=_HPDF_Dict_Add($53, ((STRING_TABLE.__str3633)|0), $55);
      var $57=(($56)|0)!=0;
      if ($57) { __label__ = 11; break; } else { __label__ = 12; break; }
    case 11: 
      var $59=$2;
      var $60=(($59+40)|0);
      var $61=(($60)|0);
      var $62=HEAP32[(($61)>>2)];
      $1=$62;
      __label__ = 19; break;
    case 12: 
      __label__ = 14; break;
    case 13: 
      var $65=$id;
      _HPDF_Array_Clear($65);
      __label__ = 14; break;
    case 14: 
      var $67=$id;
      var $68=$2;
      var $69=(($68+8)|0);
      var $70=HEAP32[(($69)>>2)];
      var $71=$e;
      var $72=(($71+140)|0);
      var $73=(($72)|0);
      var $74=_HPDF_Binary_New($70, $73, 16);
      var $75=$74;
      var $76=_HPDF_Array_Add($67, $75);
      var $77=(($76)|0)!=0;
      if ($77) { __label__ = 15; break; } else { __label__ = 16; break; }
    case 15: 
      var $79=$2;
      var $80=(($79+40)|0);
      var $81=(($80)|0);
      var $82=HEAP32[(($81)>>2)];
      $1=$82;
      __label__ = 19; break;
    case 16: 
      var $84=$id;
      var $85=$2;
      var $86=(($85+8)|0);
      var $87=HEAP32[(($86)>>2)];
      var $88=$e;
      var $89=(($88+140)|0);
      var $90=(($89)|0);
      var $91=_HPDF_Binary_New($87, $90, 16);
      var $92=$91;
      var $93=_HPDF_Array_Add($84, $92);
      var $94=(($93)|0)!=0;
      if ($94) { __label__ = 17; break; } else { __label__ = 18; break; }
    case 17: 
      var $96=$2;
      var $97=(($96+40)|0);
      var $98=(($97)|0);
      var $99=HEAP32[(($98)>>2)];
      $1=$99;
      __label__ = 19; break;
    case 18: 
      $1=0;
      __label__ = 19; break;
    case 19: 
      var $102=$1;
      ;
      return $102;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Doc_PrepareEncryption["X"]=1;

function _GetInfo($pdf) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      $2=$pdf;
      var $3=$2;
      var $4=_HPDF_HasDoc($3);
      var $5=(($4)|0)!=0;
      if ($5) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=0;
      __label__ = 10; break;
    case 4: 
      var $8=$2;
      var $9=(($8+56)|0);
      var $10=HEAP32[(($9)>>2)];
      var $11=(($10)|0)!=0;
      if ($11) { __label__ = 9; break; } else { __label__ = 5; break; }
    case 5: 
      var $13=$2;
      var $14=(($13+8)|0);
      var $15=HEAP32[(($14)>>2)];
      var $16=_HPDF_Dict_New($15);
      var $17=$2;
      var $18=(($17+56)|0);
      HEAP32[(($18)>>2)]=$16;
      var $19=$2;
      var $20=(($19+56)|0);
      var $21=HEAP32[(($20)>>2)];
      var $22=(($21)|0)!=0;
      if ($22) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      var $24=$2;
      var $25=(($24+20)|0);
      var $26=HEAP32[(($25)>>2)];
      var $27=$2;
      var $28=(($27+56)|0);
      var $29=HEAP32[(($28)>>2)];
      var $30=$29;
      var $31=_HPDF_Xref_Add($26, $30);
      var $32=(($31)|0)!=0;
      if ($32) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $34=$2;
      var $35=(($34+56)|0);
      HEAP32[(($35)>>2)]=0;
      __label__ = 8; break;
    case 8: 
      __label__ = 9; break;
    case 9: 
      var $38=$2;
      var $39=(($38+56)|0);
      var $40=HEAP32[(($39)>>2)];
      $1=$40;
      __label__ = 10; break;
    case 10: 
      var $42=$1;
      ;
      return $42;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_SaveToStream($pdf) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      $2=$pdf;
      var $3=$2;
      var $4=_HPDF_HasDoc($3);
      var $5=(($4)|0)!=0;
      if ($5) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=4133;
      __label__ = 11; break;
    case 4: 
      var $8=$2;
      var $9=(($8+112)|0);
      var $10=HEAP32[(($9)>>2)];
      var $11=(($10)|0)!=0;
      if ($11) { __label__ = 6; break; } else { __label__ = 5; break; }
    case 5: 
      var $13=$2;
      var $14=(($13+8)|0);
      var $15=HEAP32[(($14)>>2)];
      var $16=_HPDF_MemStream_New($15, 4096);
      var $17=$2;
      var $18=(($17+112)|0);
      HEAP32[(($18)>>2)]=$16;
      __label__ = 6; break;
    case 6: 
      var $20=$2;
      var $21=(($20+112)|0);
      var $22=HEAP32[(($21)>>2)];
      var $23=_HPDF_Stream_Validate($22);
      var $24=(($23)|0)!=0;
      if ($24) { __label__ = 8; break; } else { __label__ = 7; break; }
    case 7: 
      var $26=$2;
      var $27=(($26+40)|0);
      var $28=_HPDF_RaiseError($27, 4156, 0);
      $1=$28;
      __label__ = 11; break;
    case 8: 
      var $30=$2;
      var $31=(($30+112)|0);
      var $32=HEAP32[(($31)>>2)];
      _HPDF_MemStream_FreeData($32);
      var $33=$2;
      var $34=$2;
      var $35=(($34+112)|0);
      var $36=HEAP32[(($35)>>2)];
      var $37=_InternalSaveToStream($33, $36);
      var $38=(($37)|0)!=0;
      if ($38) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      var $40=$2;
      var $41=(($40+40)|0);
      var $42=_HPDF_CheckError($41);
      $1=$42;
      __label__ = 11; break;
    case 10: 
      $1=0;
      __label__ = 11; break;
    case 11: 
      var $45=$1;
      ;
      return $45;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_SaveToStream["X"]=1;

function _InternalSaveToStream($pdf, $stream) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $ret;
      var $e;
      $2=$pdf;
      $3=$stream;
      var $4=$2;
      var $5=$3;
      var $6=_WriteHeader($4, $5);
      $ret=$6;
      var $7=(($6)|0)!=0;
      if ($7) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $9=$ret;
      $1=$9;
      __label__ = 16; break;
    case 4: 
      var $11=$2;
      var $12=_PrepareTrailer($11);
      $ret=$12;
      var $13=(($12)|0)!=0;
      if ($13) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $15=$ret;
      $1=$15;
      __label__ = 16; break;
    case 6: 
      var $17=$2;
      var $18=(($17+92)|0);
      var $19=HEAP32[(($18)>>2)];
      var $20=(($19)|0)!=0;
      if ($20) { __label__ = 7; break; } else { __label__ = 12; break; }
    case 7: 
      var $22=$2;
      var $23=(($22+96)|0);
      var $24=HEAP32[(($23)>>2)];
      var $25=_HPDF_EncryptDict_GetAttr($24);
      $e=$25;
      var $26=$2;
      var $27=_HPDF_Doc_PrepareEncryption($26);
      $ret=$27;
      var $28=(($27)|0)!=0;
      if ($28) { __label__ = 8; break; } else { __label__ = 9; break; }
    case 8: 
      var $30=$ret;
      $1=$30;
      __label__ = 16; break;
    case 9: 
      var $32=$2;
      var $33=(($32+20)|0);
      var $34=HEAP32[(($33)>>2)];
      var $35=$3;
      var $36=$e;
      var $37=_HPDF_Xref_WriteToStream($34, $35, $36);
      $ret=$37;
      var $38=(($37)|0)!=0;
      if ($38) { __label__ = 10; break; } else { __label__ = 11; break; }
    case 10: 
      var $40=$ret;
      $1=$40;
      __label__ = 16; break;
    case 11: 
      __label__ = 15; break;
    case 12: 
      var $43=$2;
      var $44=(($43+20)|0);
      var $45=HEAP32[(($44)>>2)];
      var $46=$3;
      var $47=_HPDF_Xref_WriteToStream($45, $46, 0);
      $ret=$47;
      var $48=(($47)|0)!=0;
      if ($48) { __label__ = 13; break; } else { __label__ = 14; break; }
    case 13: 
      var $50=$ret;
      $1=$50;
      __label__ = 16; break;
    case 14: 
      __label__ = 15; break;
    case 15: 
      $1=0;
      __label__ = 16; break;
    case 16: 
      var $54=$1;
      ;
      return $54;
    default: assert(0, "bad label: " + __label__);
  }
}
_InternalSaveToStream["X"]=1;

function _HPDF_GetContents($pdf, $buf, $size) {
  var __stackBase__  = STACKTOP; STACKTOP += 4; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $stream;
      var $isize=__stackBase__;
      var $ret;
      $2=$pdf;
      $3=$buf;
      $4=$size;
      var $5=$2;
      var $6=_HPDF_HasDoc($5);
      var $7=(($6)|0)!=0;
      if ($7) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=4133;
      __label__ = 9; break;
    case 4: 
      var $10=$2;
      var $11=(($10+8)|0);
      var $12=HEAP32[(($11)>>2)];
      var $13=_HPDF_MemStream_New($12, 4096);
      $stream=$13;
      var $14=$stream;
      var $15=(($14)|0)!=0;
      if ($15) { __label__ = 6; break; } else { __label__ = 5; break; }
    case 5: 
      var $17=$2;
      var $18=(($17+40)|0);
      var $19=_HPDF_CheckError($18);
      $1=$19;
      __label__ = 9; break;
    case 6: 
      var $21=$2;
      var $22=$stream;
      var $23=_InternalSaveToStream($21, $22);
      var $24=(($23)|0)!=0;
      if ($24) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $26=$stream;
      _HPDF_Stream_Free($26);
      var $27=$2;
      var $28=(($27+40)|0);
      var $29=_HPDF_CheckError($28);
      $1=$29;
      __label__ = 9; break;
    case 8: 
      var $31=$stream;
      var $32=$3;
      var $33=_HPDF_Stream_Read($31, $32, $isize);
      $ret=$33;
      var $34=HEAP32[(($isize)>>2)];
      var $35=$4;
      HEAP32[(($35)>>2)]=$34;
      var $36=$stream;
      _HPDF_Stream_Free($36);
      var $37=$ret;
      $1=$37;
      __label__ = 9; break;
    case 9: 
      var $39=$1;
      STACKTOP = __stackBase__;
      return $39;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_GetContents["X"]=1;

function _HPDF_GetStreamSize($pdf) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      $2=$pdf;
      var $3=$2;
      var $4=_HPDF_HasDoc($3);
      var $5=(($4)|0)!=0;
      if ($5) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=4133;
      __label__ = 7; break;
    case 4: 
      var $8=$2;
      var $9=(($8+112)|0);
      var $10=HEAP32[(($9)>>2)];
      var $11=_HPDF_Stream_Validate($10);
      var $12=(($11)|0)!=0;
      if ($12) { __label__ = 6; break; } else { __label__ = 5; break; }
    case 5: 
      $1=0;
      __label__ = 7; break;
    case 6: 
      var $15=$2;
      var $16=(($15+112)|0);
      var $17=HEAP32[(($16)>>2)];
      var $18=_HPDF_Stream_Size($17);
      $1=$18;
      __label__ = 7; break;
    case 7: 
      var $20=$1;
      ;
      return $20;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_ReadFromStream($pdf, $buf, $size) {
  var __stackBase__  = STACKTOP; STACKTOP += 4; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $isize=__stackBase__;
      var $ret;
      $2=$pdf;
      $3=$buf;
      $4=$size;
      var $5=$4;
      var $6=HEAP32[(($5)>>2)];
      HEAP32[(($isize)>>2)]=$6;
      var $7=$2;
      var $8=_HPDF_HasDoc($7);
      var $9=(($8)|0)!=0;
      if ($9) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=4133;
      __label__ = 11; break;
    case 4: 
      var $12=$2;
      var $13=(($12+112)|0);
      var $14=HEAP32[(($13)>>2)];
      var $15=_HPDF_Stream_Validate($14);
      var $16=(($15)|0)!=0;
      if ($16) { __label__ = 6; break; } else { __label__ = 5; break; }
    case 5: 
      var $18=$2;
      var $19=(($18+40)|0);
      var $20=_HPDF_RaiseError($19, 4149, 0);
      $1=$20;
      __label__ = 11; break;
    case 6: 
      var $22=$4;
      var $23=HEAP32[(($22)>>2)];
      var $24=(($23)|0)==0;
      if ($24) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $26=$2;
      var $27=(($26+40)|0);
      var $28=_HPDF_RaiseError($27, 4153, 0);
      $1=$28;
      __label__ = 11; break;
    case 8: 
      var $30=$2;
      var $31=(($30+112)|0);
      var $32=HEAP32[(($31)>>2)];
      var $33=$3;
      var $34=_HPDF_Stream_Read($32, $33, $isize);
      $ret=$34;
      var $35=HEAP32[(($isize)>>2)];
      var $36=$4;
      HEAP32[(($36)>>2)]=$35;
      var $37=$ret;
      var $38=(($37)|0)!=0;
      if ($38) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      var $40=$2;
      var $41=(($40+40)|0);
      var $42=_HPDF_CheckError($41);
      __label__ = 10; break;
    case 10: 
      var $44=$ret;
      $1=$44;
      __label__ = 11; break;
    case 11: 
      var $46=$1;
      STACKTOP = __stackBase__;
      return $46;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_ReadFromStream["X"]=1;

function _HPDF_ResetStream($pdf) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      $2=$pdf;
      var $3=$2;
      var $4=_HPDF_HasDoc($3);
      var $5=(($4)|0)!=0;
      if ($5) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=4133;
      __label__ = 7; break;
    case 4: 
      var $8=$2;
      var $9=(($8+112)|0);
      var $10=HEAP32[(($9)>>2)];
      var $11=_HPDF_Stream_Validate($10);
      var $12=(($11)|0)!=0;
      if ($12) { __label__ = 6; break; } else { __label__ = 5; break; }
    case 5: 
      var $14=$2;
      var $15=(($14+40)|0);
      var $16=_HPDF_RaiseError($15, 4149, 0);
      $1=$16;
      __label__ = 7; break;
    case 6: 
      var $18=$2;
      var $19=(($18+112)|0);
      var $20=HEAP32[(($19)>>2)];
      var $21=_HPDF_Stream_Seek($20, 0, 0);
      $1=$21;
      __label__ = 7; break;
    case 7: 
      var $23=$1;
      ;
      return $23;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_SaveToFile($pdf, $file_name) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $stream;
      $2=$pdf;
      $3=$file_name;
      var $4=$2;
      var $5=_HPDF_HasDoc($4);
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=4133;
      __label__ = 7; break;
    case 4: 
      var $9=$2;
      var $10=(($9+8)|0);
      var $11=HEAP32[(($10)>>2)];
      var $12=$3;
      var $13=_HPDF_FileWriter_New($11, $12);
      $stream=$13;
      var $14=$stream;
      var $15=(($14)|0)!=0;
      if ($15) { __label__ = 6; break; } else { __label__ = 5; break; }
    case 5: 
      var $17=$2;
      var $18=(($17+40)|0);
      var $19=_HPDF_CheckError($18);
      $1=$19;
      __label__ = 7; break;
    case 6: 
      var $21=$2;
      var $22=$stream;
      var $23=_InternalSaveToStream($21, $22);
      var $24=$stream;
      _HPDF_Stream_Free($24);
      var $25=$2;
      var $26=(($25+40)|0);
      var $27=_HPDF_CheckError($26);
      $1=$27;
      __label__ = 7; break;
    case 7: 
      var $29=$1;
      ;
      return $29;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_GetCurrentPage($pdf) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      $2=$pdf;
      var $3=$2;
      var $4=_HPDF_HasDoc($3);
      var $5=(($4)|0)!=0;
      if ($5) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=0;
      __label__ = 5; break;
    case 4: 
      var $8=$2;
      var $9=(($8+32)|0);
      var $10=HEAP32[(($9)>>2)];
      $1=$10;
      __label__ = 5; break;
    case 5: 
      var $12=$1;
      ;
      return $12;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_GetPageByIndex($pdf, $index) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $ret;
      $2=$pdf;
      $3=$index;
      var $4=$2;
      var $5=_HPDF_HasDoc($4);
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=0;
      __label__ = 7; break;
    case 4: 
      var $9=$2;
      var $10=(($9+36)|0);
      var $11=HEAP32[(($10)>>2)];
      var $12=$3;
      var $13=_HPDF_List_ItemAt($11, $12);
      var $14=$13;
      $ret=$14;
      var $15=$ret;
      var $16=(($15)|0)!=0;
      if ($16) { __label__ = 6; break; } else { __label__ = 5; break; }
    case 5: 
      var $18=$2;
      var $19=(($18+40)|0);
      var $20=_HPDF_RaiseError($19, 4199, 0);
      $1=0;
      __label__ = 7; break;
    case 6: 
      var $22=$ret;
      $1=$22;
      __label__ = 7; break;
    case 7: 
      var $24=$1;
      ;
      return $24;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_AddPage($pdf) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $page;
      var $ret;
      $2=$pdf;
      var $3=$2;
      var $4=_HPDF_HasDoc($3);
      var $5=(($4)|0)!=0;
      if ($5) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=0;
      __label__ = 19; break;
    case 4: 
      var $8=$2;
      var $9=(($8+104)|0);
      var $10=HEAP32[(($9)>>2)];
      var $11=(($10)|0)!=0;
      if ($11) { __label__ = 5; break; } else { __label__ = 10; break; }
    case 5: 
      var $13=$2;
      var $14=(($13+104)|0);
      var $15=HEAPU32[(($14)>>2)];
      var $16=$2;
      var $17=(($16+108)|0);
      var $18=HEAPU32[(($17)>>2)];
      var $19=(($15)>>>0) <= (($18)>>>0);
      if ($19) { __label__ = 6; break; } else { __label__ = 9; break; }
    case 6: 
      var $21=$2;
      var $22=$2;
      var $23=(($22+24)|0);
      var $24=HEAP32[(($23)>>2)];
      var $25=_HPDF_Doc_AddPagesTo($21, $24);
      var $26=$2;
      var $27=(($26+28)|0);
      HEAP32[(($27)>>2)]=$25;
      var $28=$2;
      var $29=(($28+28)|0);
      var $30=HEAP32[(($29)>>2)];
      var $31=(($30)|0)!=0;
      if ($31) { __label__ = 8; break; } else { __label__ = 7; break; }
    case 7: 
      $1=0;
      __label__ = 19; break;
    case 8: 
      var $34=$2;
      var $35=(($34+108)|0);
      HEAP32[(($35)>>2)]=0;
      __label__ = 9; break;
    case 9: 
      __label__ = 10; break;
    case 10: 
      var $38=$2;
      var $39=(($38+8)|0);
      var $40=HEAP32[(($39)>>2)];
      var $41=$2;
      var $42=(($41+20)|0);
      var $43=HEAP32[(($42)>>2)];
      var $44=_HPDF_Page_New($40, $43);
      $page=$44;
      var $45=$page;
      var $46=(($45)|0)!=0;
      if ($46) { __label__ = 12; break; } else { __label__ = 11; break; }
    case 11: 
      var $48=$2;
      var $49=(($48+40)|0);
      var $50=_HPDF_CheckError($49);
      $1=0;
      __label__ = 19; break;
    case 12: 
      var $52=$2;
      var $53=(($52+28)|0);
      var $54=HEAP32[(($53)>>2)];
      var $55=$page;
      var $56=_HPDF_Pages_AddKids($54, $55);
      $ret=$56;
      var $57=(($56)|0)!=0;
      if ($57) { __label__ = 13; break; } else { __label__ = 14; break; }
    case 13: 
      var $59=$2;
      var $60=(($59+40)|0);
      var $61=$ret;
      var $62=_HPDF_RaiseError($60, $61, 0);
      $1=0;
      __label__ = 19; break;
    case 14: 
      var $64=$2;
      var $65=(($64+36)|0);
      var $66=HEAP32[(($65)>>2)];
      var $67=$page;
      var $68=$67;
      var $69=_HPDF_List_Add($66, $68);
      $ret=$69;
      var $70=(($69)|0)!=0;
      if ($70) { __label__ = 15; break; } else { __label__ = 16; break; }
    case 15: 
      var $72=$2;
      var $73=(($72+40)|0);
      var $74=$ret;
      var $75=_HPDF_RaiseError($73, $74, 0);
      $1=0;
      __label__ = 19; break;
    case 16: 
      var $77=$page;
      var $78=$2;
      var $79=(($78+32)|0);
      HEAP32[(($79)>>2)]=$77;
      var $80=$2;
      var $81=(($80+88)|0);
      var $82=HEAP32[(($81)>>2)];
      var $83=$82 & 1;
      var $84=(($83)|0)!=0;
      if ($84) { __label__ = 17; break; } else { __label__ = 18; break; }
    case 17: 
      var $86=$page;
      _HPDF_Page_SetFilter($86, 1024);
      __label__ = 18; break;
    case 18: 
      var $88=$2;
      var $89=(($88+108)|0);
      var $90=HEAP32[(($89)>>2)];
      var $91=((($90)+(1))|0);
      HEAP32[(($89)>>2)]=$91;
      var $92=$page;
      $1=$92;
      __label__ = 19; break;
    case 19: 
      var $94=$1;
      ;
      return $94;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_AddPage["X"]=1;

function _HPDF_InsertPage($pdf, $target) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $page;
      var $ret;
      $2=$pdf;
      $3=$target;
      var $4=$2;
      var $5=_HPDF_HasDoc($4);
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=0;
      __label__ = 17; break;
    case 4: 
      var $9=$3;
      var $10=_HPDF_Page_Validate($9);
      var $11=(($10)|0)!=0;
      if ($11) { __label__ = 6; break; } else { __label__ = 5; break; }
    case 5: 
      var $13=$2;
      var $14=(($13+40)|0);
      var $15=_HPDF_RaiseError($14, 4151, 0);
      $1=0;
      __label__ = 17; break;
    case 6: 
      var $17=$2;
      var $18=(($17+8)|0);
      var $19=HEAP32[(($18)>>2)];
      var $20=$3;
      var $21=(($20+8)|0);
      var $22=HEAP32[(($21)>>2)];
      var $23=(($19)|0)!=(($22)|0);
      if ($23) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $25=$2;
      var $26=(($25+40)|0);
      var $27=_HPDF_RaiseError($26, 4151, 0);
      $1=0;
      __label__ = 17; break;
    case 8: 
      var $29=$2;
      var $30=(($29+8)|0);
      var $31=HEAP32[(($30)>>2)];
      var $32=$2;
      var $33=(($32+20)|0);
      var $34=HEAP32[(($33)>>2)];
      var $35=_HPDF_Page_New($31, $34);
      $page=$35;
      var $36=$page;
      var $37=(($36)|0)!=0;
      if ($37) { __label__ = 10; break; } else { __label__ = 9; break; }
    case 9: 
      var $39=$2;
      var $40=(($39+40)|0);
      var $41=_HPDF_CheckError($40);
      $1=0;
      __label__ = 17; break;
    case 10: 
      var $43=$page;
      var $44=$3;
      var $45=_HPDF_Page_InsertBefore($43, $44);
      $ret=$45;
      var $46=(($45)|0)!=0;
      if ($46) { __label__ = 11; break; } else { __label__ = 12; break; }
    case 11: 
      var $48=$2;
      var $49=(($48+40)|0);
      var $50=$ret;
      var $51=_HPDF_RaiseError($49, $50, 0);
      $1=0;
      __label__ = 17; break;
    case 12: 
      var $53=$2;
      var $54=(($53+36)|0);
      var $55=HEAP32[(($54)>>2)];
      var $56=$3;
      var $57=$56;
      var $58=$page;
      var $59=$58;
      var $60=_HPDF_List_Insert($55, $57, $59);
      $ret=$60;
      var $61=(($60)|0)!=0;
      if ($61) { __label__ = 13; break; } else { __label__ = 14; break; }
    case 13: 
      var $63=$2;
      var $64=(($63+40)|0);
      var $65=$ret;
      var $66=_HPDF_RaiseError($64, $65, 0);
      $1=0;
      __label__ = 17; break;
    case 14: 
      var $68=$2;
      var $69=(($68+88)|0);
      var $70=HEAP32[(($69)>>2)];
      var $71=$70 & 1;
      var $72=(($71)|0)!=0;
      if ($72) { __label__ = 15; break; } else { __label__ = 16; break; }
    case 15: 
      var $74=$page;
      _HPDF_Page_SetFilter($74, 1024);
      __label__ = 16; break;
    case 16: 
      var $76=$page;
      $1=$76;
      __label__ = 17; break;
    case 17: 
      var $78=$1;
      ;
      return $78;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_InsertPage["X"]=1;

function _HPDF_SetErrorHandler($pdf, $user_error_fn) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      $2=$pdf;
      $3=$user_error_fn;
      var $4=$2;
      var $5=_HPDF_Doc_Validate($4);
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=4133;
      __label__ = 5; break;
    case 4: 
      var $9=$3;
      var $10=$2;
      var $11=(($10+40)|0);
      var $12=(($11+8)|0);
      HEAP32[(($12)>>2)]=$9;
      $1=0;
      __label__ = 5; break;
    case 5: 
      var $14=$1;
      ;
      return $14;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Doc_FindFontDef($pdf, $font_name) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $list;
      var $i;
      var $def;
      $2=$pdf;
      $3=$font_name;
      var $4=$2;
      var $5=(($4+76)|0);
      var $6=HEAP32[(($5)>>2)];
      $list=$6;
      $i=0;
      __label__ = 3; break;
    case 3: 
      var $8=$i;
      var $9=$list;
      var $10=(($9+16)|0);
      var $11=HEAPU32[(($10)>>2)];
      var $12=(($8)>>>0) < (($11)>>>0);
      if ($12) { __label__ = 4; break; } else { __label__ = 13; break; }
    case 4: 
      var $14=$list;
      var $15=$i;
      var $16=_HPDF_List_ItemAt($14, $15);
      var $17=$16;
      $def=$17;
      var $18=$3;
      var $19=$def;
      var $20=(($19+4)|0);
      var $21=(($20)|0);
      var $22=_HPDF_StrCmp($18, $21);
      var $23=(($22)|0)==0;
      if ($23) { __label__ = 5; break; } else { __label__ = 11; break; }
    case 5: 
      var $25=$def;
      var $26=(($25+140)|0);
      var $27=HEAP32[(($26)>>2)];
      var $28=(($27)|0)==3;
      if ($28) { __label__ = 6; break; } else { __label__ = 10; break; }
    case 6: 
      var $30=$def;
      var $31=(($30+152)|0);
      var $32=HEAP32[(($31)>>2)];
      var $33=(($32)|0)!=0;
      if ($33) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $35=$def;
      var $36=(($35+152)|0);
      var $37=HEAP32[(($36)>>2)];
      var $38=$def;
      var $39=FUNCTION_TABLE[$37]($38);
      var $40=(($39)|0)!=0;
      if ($40) { __label__ = 8; break; } else { __label__ = 9; break; }
    case 8: 
      $1=0;
      __label__ = 14; break;
    case 9: 
      __label__ = 10; break;
    case 10: 
      var $44=$def;
      $1=$44;
      __label__ = 14; break;
    case 11: 
      __label__ = 12; break;
    case 12: 
      var $47=$i;
      var $48=((($47)+(1))|0);
      $i=$48;
      __label__ = 3; break;
    case 13: 
      $1=0;
      __label__ = 14; break;
    case 14: 
      var $51=$1;
      ;
      return $51;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Doc_FindFontDef["X"]=1;

function _HPDF_Doc_RegisterFontDef($pdf, $fontdef) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $ret;
      $2=$pdf;
      $3=$fontdef;
      var $4=$3;
      var $5=(($4)|0)!=0;
      if ($5) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      var $7=$2;
      var $8=(($7+40)|0);
      var $9=_HPDF_SetError($8, 4147, 0);
      $1=$9;
      __label__ = 9; break;
    case 4: 
      var $11=$2;
      var $12=$3;
      var $13=(($12+4)|0);
      var $14=(($13)|0);
      var $15=_HPDF_Doc_FindFontDef($11, $14);
      var $16=(($15)|0)!=0;
      if ($16) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $18=$3;
      _HPDF_FontDef_Free($18);
      var $19=$2;
      var $20=(($19+40)|0);
      var $21=_HPDF_SetError($20, 4110, 0);
      $1=$21;
      __label__ = 9; break;
    case 6: 
      var $23=$2;
      var $24=(($23+76)|0);
      var $25=HEAP32[(($24)>>2)];
      var $26=$3;
      var $27=$26;
      var $28=_HPDF_List_Add($25, $27);
      $ret=$28;
      var $29=(($28)|0)!=0;
      if ($29) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $31=$3;
      _HPDF_FontDef_Free($31);
      var $32=$2;
      var $33=(($32+40)|0);
      var $34=$ret;
      var $35=_HPDF_SetError($33, $34, 0);
      $1=$35;
      __label__ = 9; break;
    case 8: 
      $1=0;
      __label__ = 9; break;
    case 9: 
      var $38=$1;
      ;
      return $38;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_GetFontDef($pdf, $font_name) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $ret;
      var $def;
      $2=$pdf;
      $3=$font_name;
      var $4=$2;
      var $5=_HPDF_HasDoc($4);
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=0;
      __label__ = 11; break;
    case 4: 
      var $9=$2;
      var $10=$3;
      var $11=_HPDF_Doc_FindFontDef($9, $10);
      $def=$11;
      var $12=$def;
      var $13=(($12)|0)!=0;
      if ($13) { __label__ = 10; break; } else { __label__ = 5; break; }
    case 5: 
      var $15=$2;
      var $16=(($15+8)|0);
      var $17=HEAP32[(($16)>>2)];
      var $18=$3;
      var $19=_HPDF_Base14FontDef_New($17, $18);
      $def=$19;
      var $20=$def;
      var $21=(($20)|0)!=0;
      if ($21) { __label__ = 7; break; } else { __label__ = 6; break; }
    case 6: 
      $1=0;
      __label__ = 11; break;
    case 7: 
      var $24=$2;
      var $25=(($24+76)|0);
      var $26=HEAP32[(($25)>>2)];
      var $27=$def;
      var $28=$27;
      var $29=_HPDF_List_Add($26, $28);
      $ret=$29;
      var $30=(($29)|0)!=0;
      if ($30) { __label__ = 8; break; } else { __label__ = 9; break; }
    case 8: 
      var $32=$def;
      _HPDF_FontDef_Free($32);
      var $33=$2;
      var $34=(($33+40)|0);
      var $35=$ret;
      var $36=_HPDF_RaiseError($34, $35, 0);
      $def=0;
      __label__ = 9; break;
    case 9: 
      __label__ = 10; break;
    case 10: 
      var $39=$def;
      $1=$39;
      __label__ = 11; break;
    case 11: 
      var $41=$1;
      ;
      return $41;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_GetFontDef["X"]=1;

function _HPDF_Doc_FindEncoder($pdf, $encoding_name) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $list;
      var $i;
      var $encoder;
      $2=$pdf;
      $3=$encoding_name;
      var $4=$2;
      var $5=(($4+80)|0);
      var $6=HEAP32[(($5)>>2)];
      $list=$6;
      $i=0;
      __label__ = 3; break;
    case 3: 
      var $8=$i;
      var $9=$list;
      var $10=(($9+16)|0);
      var $11=HEAPU32[(($10)>>2)];
      var $12=(($8)>>>0) < (($11)>>>0);
      if ($12) { __label__ = 4; break; } else { __label__ = 13; break; }
    case 4: 
      var $14=$list;
      var $15=$i;
      var $16=_HPDF_List_ItemAt($14, $15);
      var $17=$16;
      $encoder=$17;
      var $18=$3;
      var $19=$encoder;
      var $20=(($19+4)|0);
      var $21=(($20)|0);
      var $22=_HPDF_StrCmp($18, $21);
      var $23=(($22)|0)==0;
      if ($23) { __label__ = 5; break; } else { __label__ = 11; break; }
    case 5: 
      var $25=$encoder;
      var $26=(($25+140)|0);
      var $27=HEAP32[(($26)>>2)];
      var $28=(($27)|0)==2;
      if ($28) { __label__ = 6; break; } else { __label__ = 10; break; }
    case 6: 
      var $30=$encoder;
      var $31=(($30+160)|0);
      var $32=HEAP32[(($31)>>2)];
      var $33=(($32)|0)!=0;
      if ($33) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $35=$encoder;
      var $36=(($35+160)|0);
      var $37=HEAP32[(($36)>>2)];
      var $38=$encoder;
      var $39=FUNCTION_TABLE[$37]($38);
      var $40=(($39)|0)!=0;
      if ($40) { __label__ = 8; break; } else { __label__ = 9; break; }
    case 8: 
      $1=0;
      __label__ = 14; break;
    case 9: 
      __label__ = 10; break;
    case 10: 
      var $44=$encoder;
      $1=$44;
      __label__ = 14; break;
    case 11: 
      __label__ = 12; break;
    case 12: 
      var $47=$i;
      var $48=((($47)+(1))|0);
      $i=$48;
      __label__ = 3; break;
    case 13: 
      $1=0;
      __label__ = 14; break;
    case 14: 
      var $51=$1;
      ;
      return $51;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Doc_FindEncoder["X"]=1;

function _HPDF_Doc_RegisterEncoder($pdf, $encoder) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $ret;
      $2=$pdf;
      $3=$encoder;
      var $4=$3;
      var $5=(($4)|0)!=0;
      if ($5) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      var $7=$2;
      var $8=(($7+40)|0);
      var $9=_HPDF_SetError($8, 4147, 0);
      $1=$9;
      __label__ = 9; break;
    case 4: 
      var $11=$2;
      var $12=$3;
      var $13=(($12+4)|0);
      var $14=(($13)|0);
      var $15=_HPDF_Doc_FindEncoder($11, $14);
      var $16=(($15)|0)!=0;
      if ($16) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $18=$3;
      _HPDF_Encoder_Free($18);
      var $19=$2;
      var $20=(($19+40)|0);
      var $21=_HPDF_SetError($20, 4110, 0);
      $1=$21;
      __label__ = 9; break;
    case 6: 
      var $23=$2;
      var $24=(($23+80)|0);
      var $25=HEAP32[(($24)>>2)];
      var $26=$3;
      var $27=$26;
      var $28=_HPDF_List_Add($25, $27);
      $ret=$28;
      var $29=(($28)|0)!=0;
      if ($29) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $31=$3;
      _HPDF_Encoder_Free($31);
      var $32=$2;
      var $33=(($32+40)|0);
      var $34=$ret;
      var $35=_HPDF_SetError($33, $34, 0);
      $1=$35;
      __label__ = 9; break;
    case 8: 
      $1=0;
      __label__ = 9; break;
    case 9: 
      var $38=$1;
      ;
      return $38;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_GetEncoder($pdf, $encoding_name) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $encoder;
      var $ret;
      $2=$pdf;
      $3=$encoding_name;
      var $4=$2;
      var $5=_HPDF_HasDoc($4);
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=0;
      __label__ = 11; break;
    case 4: 
      var $9=$2;
      var $10=$3;
      var $11=_HPDF_Doc_FindEncoder($9, $10);
      $encoder=$11;
      var $12=$encoder;
      var $13=(($12)|0)!=0;
      if ($13) { __label__ = 10; break; } else { __label__ = 5; break; }
    case 5: 
      var $15=$2;
      var $16=(($15+8)|0);
      var $17=HEAP32[(($16)>>2)];
      var $18=$3;
      var $19=_HPDF_BasicEncoder_New($17, $18);
      $encoder=$19;
      var $20=$encoder;
      var $21=(($20)|0)!=0;
      if ($21) { __label__ = 7; break; } else { __label__ = 6; break; }
    case 6: 
      var $23=$2;
      var $24=(($23+40)|0);
      var $25=_HPDF_CheckError($24);
      $1=0;
      __label__ = 11; break;
    case 7: 
      var $27=$2;
      var $28=(($27+80)|0);
      var $29=HEAP32[(($28)>>2)];
      var $30=$encoder;
      var $31=$30;
      var $32=_HPDF_List_Add($29, $31);
      $ret=$32;
      var $33=(($32)|0)!=0;
      if ($33) { __label__ = 8; break; } else { __label__ = 9; break; }
    case 8: 
      var $35=$encoder;
      _HPDF_Encoder_Free($35);
      var $36=$2;
      var $37=(($36+40)|0);
      var $38=$ret;
      var $39=_HPDF_RaiseError($37, $38, 0);
      $1=0;
      __label__ = 11; break;
    case 9: 
      __label__ = 10; break;
    case 10: 
      var $42=$encoder;
      $1=$42;
      __label__ = 11; break;
    case 11: 
      var $44=$1;
      ;
      return $44;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_GetEncoder["X"]=1;

function _HPDF_GetCurrentEncoder($pdf) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      $2=$pdf;
      var $3=$2;
      var $4=_HPDF_HasDoc($3);
      var $5=(($4)|0)!=0;
      if ($5) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=0;
      __label__ = 5; break;
    case 4: 
      var $8=$2;
      var $9=(($8+84)|0);
      var $10=HEAP32[(($9)>>2)];
      $1=$10;
      __label__ = 5; break;
    case 5: 
      var $12=$1;
      ;
      return $12;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_SetCurrentEncoder($pdf, $encoding_name) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $encoder;
      $2=$pdf;
      $3=$encoding_name;
      var $4=$2;
      var $5=_HPDF_HasDoc($4);
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      var $8=$2;
      var $9=_HPDF_GetError($8);
      $1=$9;
      __label__ = 7; break;
    case 4: 
      var $11=$2;
      var $12=$3;
      var $13=_HPDF_GetEncoder($11, $12);
      $encoder=$13;
      var $14=$encoder;
      var $15=(($14)|0)!=0;
      if ($15) { __label__ = 6; break; } else { __label__ = 5; break; }
    case 5: 
      var $17=$2;
      var $18=_HPDF_GetError($17);
      $1=$18;
      __label__ = 7; break;
    case 6: 
      var $20=$encoder;
      var $21=$2;
      var $22=(($21+84)|0);
      HEAP32[(($22)>>2)]=$20;
      $1=0;
      __label__ = 7; break;
    case 7: 
      var $24=$1;
      ;
      return $24;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_GetError($pdf) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      $2=$pdf;
      var $3=$2;
      var $4=_HPDF_Doc_Validate($3);
      var $5=(($4)|0)!=0;
      if ($5) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=4133;
      __label__ = 5; break;
    case 4: 
      var $8=$2;
      var $9=(($8+40)|0);
      var $10=_HPDF_Error_GetCode($9);
      $1=$10;
      __label__ = 5; break;
    case 5: 
      var $12=$1;
      ;
      return $12;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Doc_FindFont($pdf, $font_name, $encoding_name) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $i;
      var $font;
      var $attr;
      $2=$pdf;
      $3=$font_name;
      $4=$encoding_name;
      $i=0;
      __label__ = 3; break;
    case 3: 
      var $6=$i;
      var $7=$2;
      var $8=(($7+64)|0);
      var $9=HEAP32[(($8)>>2)];
      var $10=(($9+16)|0);
      var $11=HEAPU32[(($10)>>2)];
      var $12=(($6)>>>0) < (($11)>>>0);
      if ($12) { __label__ = 4; break; } else { __label__ = 9; break; }
    case 4: 
      var $14=$2;
      var $15=(($14+64)|0);
      var $16=HEAP32[(($15)>>2)];
      var $17=$i;
      var $18=_HPDF_List_ItemAt($16, $17);
      var $19=$18;
      $font=$19;
      var $20=$font;
      var $21=(($20+44)|0);
      var $22=HEAP32[(($21)>>2)];
      var $23=$22;
      $attr=$23;
      var $24=$attr;
      var $25=(($24+16)|0);
      var $26=HEAP32[(($25)>>2)];
      var $27=(($26+4)|0);
      var $28=(($27)|0);
      var $29=$3;
      var $30=_HPDF_StrCmp($28, $29);
      var $31=(($30)|0)==0;
      if ($31) { __label__ = 5; break; } else { __label__ = 7; break; }
    case 5: 
      var $33=$attr;
      var $34=(($33+20)|0);
      var $35=HEAP32[(($34)>>2)];
      var $36=(($35+4)|0);
      var $37=(($36)|0);
      var $38=$4;
      var $39=_HPDF_StrCmp($37, $38);
      var $40=(($39)|0)==0;
      if ($40) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      var $42=$font;
      $1=$42;
      __label__ = 10; break;
    case 7: 
      __label__ = 8; break;
    case 8: 
      var $45=$i;
      var $46=((($45)+(1))|0);
      $i=$46;
      __label__ = 3; break;
    case 9: 
      $1=0;
      __label__ = 10; break;
    case 10: 
      var $49=$1;
      ;
      return $49;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Doc_FindFont["X"]=1;

function _HPDF_GetFont($pdf, $font_name, $encoding_name) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $fontdef;
      var $encoder;
      var $font;
      var $attr;
      $2=$pdf;
      $3=$font_name;
      $4=$encoding_name;
      $fontdef=0;
      $encoder=0;
      var $5=$2;
      var $6=_HPDF_HasDoc($5);
      var $7=(($6)|0)!=0;
      if ($7) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=0;
      __label__ = 48; break;
    case 4: 
      var $10=$3;
      var $11=(($10)|0)!=0;
      if ($11) { __label__ = 6; break; } else { __label__ = 5; break; }
    case 5: 
      var $13=$2;
      var $14=(($13+40)|0);
      var $15=_HPDF_RaiseError($14, 4143, 0);
      $1=0;
      __label__ = 48; break;
    case 6: 
      var $17=$4;
      var $18=(($17)|0)!=0;
      if ($18) { __label__ = 17; break; } else { __label__ = 7; break; }
    case 7: 
      var $20=$2;
      var $21=$3;
      var $22=_HPDF_GetFontDef($20, $21);
      $fontdef=$22;
      var $23=$fontdef;
      var $24=(($23)|0)!=0;
      if ($24) { __label__ = 8; break; } else { __label__ = 13; break; }
    case 8: 
      var $26=$fontdef;
      var $27=(($26+208)|0);
      var $28=HEAP32[(($27)>>2)];
      var $29=$28;
      $attr=$29;
      var $30=$fontdef;
      var $31=(($30+140)|0);
      var $32=HEAP32[(($31)>>2)];
      var $33=(($32)|0)==0;
      if ($33) { __label__ = 9; break; } else { __label__ = 11; break; }
    case 9: 
      var $35=$attr;
      var $36=(($35+20)|0);
      var $37=(($36)|0);
      var $38=_HPDF_StrCmp($37, ((STRING_TABLE.__str4634)|0));
      var $39=(($38)|0)==0;
      if ($39) { __label__ = 10; break; } else { __label__ = 11; break; }
    case 10: 
      var $41=$2;
      var $42=_HPDF_GetEncoder($41, ((STRING_TABLE.__str4634)|0));
      $encoder=$42;
      __label__ = 12; break;
    case 11: 
      var $44=$2;
      var $45=_HPDF_GetEncoder($44, ((STRING_TABLE.__str5635)|0));
      $encoder=$45;
      __label__ = 12; break;
    case 12: 
      __label__ = 14; break;
    case 13: 
      var $48=$2;
      var $49=(($48+40)|0);
      var $50=_HPDF_CheckError($49);
      $1=0;
      __label__ = 48; break;
    case 14: 
      var $52=$encoder;
      var $53=(($52)|0)!=0;
      if ($53) { __label__ = 16; break; } else { __label__ = 15; break; }
    case 15: 
      var $55=$2;
      var $56=(($55+40)|0);
      var $57=_HPDF_CheckError($56);
      $1=0;
      __label__ = 48; break;
    case 16: 
      var $59=$2;
      var $60=$3;
      var $61=$encoder;
      var $62=(($61+4)|0);
      var $63=(($62)|0);
      var $64=_HPDF_Doc_FindFont($59, $60, $63);
      $font=$64;
      __label__ = 18; break;
    case 17: 
      var $66=$2;
      var $67=$3;
      var $68=$4;
      var $69=_HPDF_Doc_FindFont($66, $67, $68);
      $font=$69;
      __label__ = 18; break;
    case 18: 
      var $71=$font;
      var $72=(($71)|0)!=0;
      if ($72) { __label__ = 19; break; } else { __label__ = 20; break; }
    case 19: 
      var $74=$font;
      $1=$74;
      __label__ = 48; break;
    case 20: 
      var $76=$fontdef;
      var $77=(($76)|0)!=0;
      if ($77) { __label__ = 24; break; } else { __label__ = 21; break; }
    case 21: 
      var $79=$2;
      var $80=$3;
      var $81=_HPDF_GetFontDef($79, $80);
      $fontdef=$81;
      var $82=$fontdef;
      var $83=(($82)|0)!=0;
      if ($83) { __label__ = 23; break; } else { __label__ = 22; break; }
    case 22: 
      var $85=$2;
      var $86=(($85+40)|0);
      var $87=_HPDF_CheckError($86);
      $1=0;
      __label__ = 48; break;
    case 23: 
      __label__ = 24; break;
    case 24: 
      var $90=$encoder;
      var $91=(($90)|0)!=0;
      if ($91) { __label__ = 28; break; } else { __label__ = 25; break; }
    case 25: 
      var $93=$2;
      var $94=$4;
      var $95=_HPDF_GetEncoder($93, $94);
      $encoder=$95;
      var $96=$encoder;
      var $97=(($96)|0)!=0;
      if ($97) { __label__ = 27; break; } else { __label__ = 26; break; }
    case 26: 
      $1=0;
      __label__ = 48; break;
    case 27: 
      __label__ = 28; break;
    case 28: 
      var $101=$fontdef;
      var $102=(($101+140)|0);
      var $103=HEAP32[(($102)>>2)];
      if ((($103)|0) == 0) {
        __label__ = 29; break;
      }
      else if ((($103)|0) == 1) {
        __label__ = 32; break;
      }
      else if ((($103)|0) == 2) {
        __label__ = 38; break;
      }
      else {
      __label__ = 41; break;
      }
      
    case 29: 
      var $105=$2;
      var $106=(($105+8)|0);
      var $107=HEAP32[(($106)>>2)];
      var $108=$fontdef;
      var $109=$encoder;
      var $110=$2;
      var $111=(($110+20)|0);
      var $112=HEAP32[(($111)>>2)];
      var $113=_HPDF_Type1Font_New($107, $108, $109, $112);
      $font=$113;
      var $114=$font;
      var $115=(($114)|0)!=0;
      if ($115) { __label__ = 30; break; } else { __label__ = 31; break; }
    case 30: 
      var $117=$2;
      var $118=(($117+64)|0);
      var $119=HEAP32[(($118)>>2)];
      var $120=$font;
      var $121=$120;
      var $122=_HPDF_List_Add($119, $121);
      __label__ = 31; break;
    case 31: 
      __label__ = 42; break;
    case 32: 
      var $125=$encoder;
      var $126=(($125+140)|0);
      var $127=HEAP32[(($126)>>2)];
      var $128=(($127)|0)==1;
      if ($128) { __label__ = 33; break; } else { __label__ = 34; break; }
    case 33: 
      var $130=$2;
      var $131=(($130+8)|0);
      var $132=HEAP32[(($131)>>2)];
      var $133=$fontdef;
      var $134=$encoder;
      var $135=$2;
      var $136=(($135+20)|0);
      var $137=HEAP32[(($136)>>2)];
      var $138=_HPDF_Type0Font_New($132, $133, $134, $137);
      $font=$138;
      __label__ = 35; break;
    case 34: 
      var $140=$2;
      var $141=(($140+8)|0);
      var $142=HEAP32[(($141)>>2)];
      var $143=$fontdef;
      var $144=$encoder;
      var $145=$2;
      var $146=(($145+20)|0);
      var $147=HEAP32[(($146)>>2)];
      var $148=_HPDF_TTFont_New($142, $143, $144, $147);
      $font=$148;
      __label__ = 35; break;
    case 35: 
      var $150=$font;
      var $151=(($150)|0)!=0;
      if ($151) { __label__ = 36; break; } else { __label__ = 37; break; }
    case 36: 
      var $153=$2;
      var $154=(($153+64)|0);
      var $155=HEAP32[(($154)>>2)];
      var $156=$font;
      var $157=$156;
      var $158=_HPDF_List_Add($155, $157);
      __label__ = 37; break;
    case 37: 
      __label__ = 42; break;
    case 38: 
      var $161=$2;
      var $162=(($161+8)|0);
      var $163=HEAP32[(($162)>>2)];
      var $164=$fontdef;
      var $165=$encoder;
      var $166=$2;
      var $167=(($166+20)|0);
      var $168=HEAP32[(($167)>>2)];
      var $169=_HPDF_Type0Font_New($163, $164, $165, $168);
      $font=$169;
      var $170=$font;
      var $171=(($170)|0)!=0;
      if ($171) { __label__ = 39; break; } else { __label__ = 40; break; }
    case 39: 
      var $173=$2;
      var $174=(($173+64)|0);
      var $175=HEAP32[(($174)>>2)];
      var $176=$font;
      var $177=$176;
      var $178=_HPDF_List_Add($175, $177);
      __label__ = 40; break;
    case 40: 
      __label__ = 42; break;
    case 41: 
      var $181=$2;
      var $182=(($181+40)|0);
      var $183=_HPDF_RaiseError($182, 4193, 0);
      $1=0;
      __label__ = 48; break;
    case 42: 
      var $185=$font;
      var $186=(($185)|0)!=0;
      if ($186) { __label__ = 44; break; } else { __label__ = 43; break; }
    case 43: 
      var $188=$2;
      var $189=(($188+40)|0);
      var $190=_HPDF_CheckError($189);
      __label__ = 44; break;
    case 44: 
      var $192=$font;
      var $193=(($192)|0)!=0;
      if ($193) { __label__ = 45; break; } else { __label__ = 47; break; }
    case 45: 
      var $195=$2;
      var $196=(($195+88)|0);
      var $197=HEAP32[(($196)>>2)];
      var $198=$197 & 4;
      var $199=(($198)|0)!=0;
      if ($199) { __label__ = 46; break; } else { __label__ = 47; break; }
    case 46: 
      var $201=$font;
      var $202=(($201+40)|0);
      HEAP32[(($202)>>2)]=1024;
      __label__ = 47; break;
    case 47: 
      var $204=$font;
      $1=$204;
      __label__ = 48; break;
    case 48: 
      var $206=$1;
      ;
      return $206;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_GetFont["X"]=1;

function _HPDF_LoadType1FontFromFile($pdf, $afm_file_name, $data_file_name) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $afm;
      var $pfm;
      var $ret;
      $2=$pdf;
      $3=$afm_file_name;
      $4=$data_file_name;
      $pfm=0;
      var $5=$2;
      var $6=_HPDF_HasDoc($5);
      var $7=(($6)|0)!=0;
      if ($7) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=0;
      __label__ = 18; break;
    case 4: 
      var $10=$2;
      var $11=(($10+8)|0);
      var $12=HEAP32[(($11)>>2)];
      var $13=$3;
      var $14=_HPDF_FileReader_New($12, $13);
      $afm=$14;
      var $15=$4;
      var $16=(($15)|0)!=0;
      if ($16) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $18=$2;
      var $19=(($18+8)|0);
      var $20=HEAP32[(($19)>>2)];
      var $21=$4;
      var $22=_HPDF_FileReader_New($20, $21);
      $pfm=$22;
      __label__ = 6; break;
    case 6: 
      var $24=$afm;
      var $25=_HPDF_Stream_Validate($24);
      var $26=(($25)|0)!=0;
      if ($26) { __label__ = 7; break; } else { __label__ = 10; break; }
    case 7: 
      var $28=$4;
      var $29=(($28)|0)!=0;
      if ($29) { __label__ = 8; break; } else { __label__ = 9; break; }
    case 8: 
      var $31=$pfm;
      var $32=_HPDF_Stream_Validate($31);
      var $33=(($32)|0)!=0;
      if ($33) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      var $35=$2;
      var $36=$afm;
      var $37=$pfm;
      var $38=_LoadType1FontFromStream($35, $36, $37);
      $ret=$38;
      __label__ = 11; break;
    case 10: 
      $ret=0;
      __label__ = 11; break;
    case 11: 
      var $41=$afm;
      var $42=(($41)|0)!=0;
      if ($42) { __label__ = 12; break; } else { __label__ = 13; break; }
    case 12: 
      var $44=$afm;
      _HPDF_Stream_Free($44);
      __label__ = 13; break;
    case 13: 
      var $46=$pfm;
      var $47=(($46)|0)!=0;
      if ($47) { __label__ = 14; break; } else { __label__ = 15; break; }
    case 14: 
      var $49=$pfm;
      _HPDF_Stream_Free($49);
      __label__ = 15; break;
    case 15: 
      var $51=$ret;
      var $52=(($51)|0)!=0;
      if ($52) { __label__ = 17; break; } else { __label__ = 16; break; }
    case 16: 
      var $54=$2;
      var $55=(($54+40)|0);
      var $56=_HPDF_CheckError($55);
      __label__ = 17; break;
    case 17: 
      var $58=$ret;
      $1=$58;
      __label__ = 18; break;
    case 18: 
      var $60=$1;
      ;
      return $60;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_LoadType1FontFromFile["X"]=1;

function _LoadType1FontFromStream($pdf, $afmdata, $pfmdata) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $def;
      var $tmpdef;
      $2=$pdf;
      $3=$afmdata;
      $4=$pfmdata;
      var $5=$2;
      var $6=_HPDF_HasDoc($5);
      var $7=(($6)|0)!=0;
      if ($7) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=0;
      __label__ = 11; break;
    case 4: 
      var $10=$2;
      var $11=(($10+8)|0);
      var $12=HEAP32[(($11)>>2)];
      var $13=$3;
      var $14=$4;
      var $15=_HPDF_Type1FontDef_Load($12, $13, $14);
      $def=$15;
      var $16=$def;
      var $17=(($16)|0)!=0;
      if ($17) { __label__ = 5; break; } else { __label__ = 10; break; }
    case 5: 
      var $19=$2;
      var $20=$def;
      var $21=(($20+4)|0);
      var $22=(($21)|0);
      var $23=_HPDF_Doc_FindFontDef($19, $22);
      $tmpdef=$23;
      var $24=$tmpdef;
      var $25=(($24)|0)!=0;
      if ($25) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      var $27=$def;
      _HPDF_FontDef_Free($27);
      var $28=$2;
      var $29=(($28+40)|0);
      var $30=_HPDF_SetError($29, 4121, 0);
      $1=0;
      __label__ = 11; break;
    case 7: 
      var $32=$2;
      var $33=(($32+76)|0);
      var $34=HEAP32[(($33)>>2)];
      var $35=$def;
      var $36=$35;
      var $37=_HPDF_List_Add($34, $36);
      var $38=(($37)|0)!=0;
      if ($38) { __label__ = 8; break; } else { __label__ = 9; break; }
    case 8: 
      var $40=$def;
      _HPDF_FontDef_Free($40);
      $1=0;
      __label__ = 11; break;
    case 9: 
      var $42=$def;
      var $43=(($42+4)|0);
      var $44=(($43)|0);
      $1=$44;
      __label__ = 11; break;
    case 10: 
      $1=0;
      __label__ = 11; break;
    case 11: 
      var $47=$1;
      ;
      return $47;
    default: assert(0, "bad label: " + __label__);
  }
}
_LoadType1FontFromStream["X"]=1;

function _HPDF_GetTTFontDefFromFile($pdf, $file_name, $embedding) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $font_data;
      var $def;
      $2=$pdf;
      $3=$file_name;
      $4=$embedding;
      var $5=$2;
      var $6=(($5+8)|0);
      var $7=HEAP32[(($6)>>2)];
      var $8=$3;
      var $9=_HPDF_FileReader_New($7, $8);
      $font_data=$9;
      var $10=$font_data;
      var $11=_HPDF_Stream_Validate($10);
      var $12=(($11)|0)!=0;
      if ($12) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $14=$2;
      var $15=(($14+8)|0);
      var $16=HEAP32[(($15)>>2)];
      var $17=$font_data;
      var $18=$4;
      var $19=_HPDF_TTFontDef_Load($16, $17, $18);
      $def=$19;
      __label__ = 5; break;
    case 4: 
      var $21=$2;
      var $22=(($21+40)|0);
      var $23=_HPDF_CheckError($22);
      $1=0;
      __label__ = 6; break;
    case 5: 
      var $25=$def;
      $1=$25;
      __label__ = 6; break;
    case 6: 
      var $27=$1;
      ;
      return $27;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_LoadTTFontFromFile($pdf, $file_name, $embedding) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $font_data;
      var $ret;
      $2=$pdf;
      $3=$file_name;
      $4=$embedding;
      var $5=$2;
      var $6=_HPDF_HasDoc($5);
      var $7=(($6)|0)!=0;
      if ($7) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=0;
      __label__ = 10; break;
    case 4: 
      var $10=$2;
      var $11=(($10+8)|0);
      var $12=HEAP32[(($11)>>2)];
      var $13=$3;
      var $14=_HPDF_FileReader_New($12, $13);
      $font_data=$14;
      var $15=$font_data;
      var $16=_HPDF_Stream_Validate($15);
      var $17=(($16)|0)!=0;
      if ($17) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $19=$2;
      var $20=$font_data;
      var $21=$4;
      var $22=$3;
      var $23=_LoadTTFontFromStream($19, $20, $21, $22);
      $ret=$23;
      __label__ = 7; break;
    case 6: 
      $ret=0;
      __label__ = 7; break;
    case 7: 
      var $26=$ret;
      var $27=(($26)|0)!=0;
      if ($27) { __label__ = 9; break; } else { __label__ = 8; break; }
    case 8: 
      var $29=$2;
      var $30=(($29+40)|0);
      var $31=_HPDF_CheckError($30);
      __label__ = 9; break;
    case 9: 
      var $33=$ret;
      $1=$33;
      __label__ = 10; break;
    case 10: 
      var $35=$1;
      ;
      return $35;
    default: assert(0, "bad label: " + __label__);
  }
}


function _LoadTTFontFromStream($pdf, $font_data, $embedding, $file_name) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $5;
      var $def;
      var $tmpdef;
      var $i;
      $2=$pdf;
      $3=$font_data;
      $4=$embedding;
      $5=$file_name;
      var $6=$2;
      var $7=(($6+8)|0);
      var $8=HEAP32[(($7)>>2)];
      var $9=$3;
      var $10=$4;
      var $11=_HPDF_TTFontDef_Load($8, $9, $10);
      $def=$11;
      var $12=$def;
      var $13=(($12)|0)!=0;
      if ($13) { __label__ = 3; break; } else { __label__ = 8; break; }
    case 3: 
      var $15=$2;
      var $16=$def;
      var $17=(($16+4)|0);
      var $18=(($17)|0);
      var $19=_HPDF_Doc_FindFontDef($15, $18);
      $tmpdef=$19;
      var $20=$tmpdef;
      var $21=(($20)|0)!=0;
      if ($21) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      var $23=$def;
      _HPDF_FontDef_Free($23);
      var $24=$2;
      var $25=(($24+40)|0);
      var $26=_HPDF_SetError($25, 4121, 0);
      $1=0;
      __label__ = 22; break;
    case 5: 
      var $28=$2;
      var $29=(($28+76)|0);
      var $30=HEAP32[(($29)>>2)];
      var $31=$def;
      var $32=$31;
      var $33=_HPDF_List_Add($30, $32);
      var $34=(($33)|0)!=0;
      if ($34) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      var $36=$def;
      _HPDF_FontDef_Free($36);
      $1=0;
      __label__ = 22; break;
    case 7: 
      __label__ = 9; break;
    case 8: 
      $1=0;
      __label__ = 22; break;
    case 9: 
      var $40=$4;
      var $41=(($40)|0)!=0;
      if ($41) { __label__ = 10; break; } else { __label__ = 21; break; }
    case 10: 
      var $43=$2;
      var $44=(($43+68)|0);
      var $45=(($44)|0);
      var $46=HEAPU8[($45)];
      var $47=(($46)&255);
      var $48=(($47)|0)==0;
      if ($48) { __label__ = 11; break; } else { __label__ = 12; break; }
    case 11: 
      var $50=$2;
      var $51=(($50+68)|0);
      var $52=(($51)|0);
      var $53=_HPDF_MemCpy($52, ((STRING_TABLE.__str7637)|0), 6);
      __label__ = 20; break;
    case 12: 
      $i=5;
      __label__ = 13; break;
    case 13: 
      var $56=$i;
      var $57=(($56)|0) >= 0;
      if ($57) { __label__ = 14; break; } else { __label__ = 19; break; }
    case 14: 
      var $59=$i;
      var $60=$2;
      var $61=(($60+68)|0);
      var $62=(($61+$59)|0);
      var $63=HEAPU8[($62)];
      var $64=(($63)&255);
      var $65=((($64)+(1))|0);
      var $66=(($65) & 255);
      HEAP8[($62)]=$66;
      var $67=$i;
      var $68=$2;
      var $69=(($68+68)|0);
      var $70=(($69+$67)|0);
      var $71=HEAPU8[($70)];
      var $72=(($71)&255);
      var $73=(($72)|0) > 90;
      if ($73) { __label__ = 15; break; } else { __label__ = 16; break; }
    case 15: 
      var $75=$i;
      var $76=$2;
      var $77=(($76+68)|0);
      var $78=(($77+$75)|0);
      HEAP8[($78)]=65;
      __label__ = 17; break;
    case 16: 
      __label__ = 19; break;
    case 17: 
      __label__ = 18; break;
    case 18: 
      var $82=$i;
      var $83=((($82)-(1))|0);
      $i=$83;
      __label__ = 13; break;
    case 19: 
      __label__ = 20; break;
    case 20: 
      var $86=$def;
      var $87=$2;
      var $88=(($87+68)|0);
      var $89=(($88)|0);
      _HPDF_TTFontDef_SetTagName($86, $89);
      __label__ = 21; break;
    case 21: 
      var $91=$def;
      var $92=(($91+4)|0);
      var $93=(($92)|0);
      $1=$93;
      __label__ = 22; break;
    case 22: 
      var $95=$1;
      ;
      return $95;
    default: assert(0, "bad label: " + __label__);
  }
}
_LoadTTFontFromStream["X"]=1;

function _HPDF_LoadTTFontFromFile2($pdf, $file_name, $index, $embedding) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $5;
      var $font_data;
      var $ret;
      $2=$pdf;
      $3=$file_name;
      $4=$index;
      $5=$embedding;
      var $6=$2;
      var $7=_HPDF_HasDoc($6);
      var $8=(($7)|0)!=0;
      if ($8) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=0;
      __label__ = 10; break;
    case 4: 
      var $11=$2;
      var $12=(($11+8)|0);
      var $13=HEAP32[(($12)>>2)];
      var $14=$3;
      var $15=_HPDF_FileReader_New($13, $14);
      $font_data=$15;
      var $16=$font_data;
      var $17=_HPDF_Stream_Validate($16);
      var $18=(($17)|0)!=0;
      if ($18) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $20=$2;
      var $21=$font_data;
      var $22=$4;
      var $23=$5;
      var $24=$3;
      var $25=_LoadTTFontFromStream2($20, $21, $22, $23, $24);
      $ret=$25;
      __label__ = 7; break;
    case 6: 
      $ret=0;
      __label__ = 7; break;
    case 7: 
      var $28=$ret;
      var $29=(($28)|0)!=0;
      if ($29) { __label__ = 9; break; } else { __label__ = 8; break; }
    case 8: 
      var $31=$2;
      var $32=(($31+40)|0);
      var $33=_HPDF_CheckError($32);
      __label__ = 9; break;
    case 9: 
      var $35=$ret;
      $1=$35;
      __label__ = 10; break;
    case 10: 
      var $37=$1;
      ;
      return $37;
    default: assert(0, "bad label: " + __label__);
  }
}


function _LoadTTFontFromStream2($pdf, $font_data, $index, $embedding, $file_name) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $5;
      var $6;
      var $def;
      var $tmpdef;
      var $i;
      $2=$pdf;
      $3=$font_data;
      $4=$index;
      $5=$embedding;
      $6=$file_name;
      var $7=$2;
      var $8=(($7+8)|0);
      var $9=HEAP32[(($8)>>2)];
      var $10=$3;
      var $11=$4;
      var $12=$5;
      var $13=_HPDF_TTFontDef_Load2($9, $10, $11, $12);
      $def=$13;
      var $14=$def;
      var $15=(($14)|0)!=0;
      if ($15) { __label__ = 3; break; } else { __label__ = 8; break; }
    case 3: 
      var $17=$2;
      var $18=$def;
      var $19=(($18+4)|0);
      var $20=(($19)|0);
      var $21=_HPDF_Doc_FindFontDef($17, $20);
      $tmpdef=$21;
      var $22=$tmpdef;
      var $23=(($22)|0)!=0;
      if ($23) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      var $25=$def;
      _HPDF_FontDef_Free($25);
      var $26=$2;
      var $27=(($26+40)|0);
      var $28=_HPDF_SetError($27, 4121, 0);
      $1=0;
      __label__ = 22; break;
    case 5: 
      var $30=$2;
      var $31=(($30+76)|0);
      var $32=HEAP32[(($31)>>2)];
      var $33=$def;
      var $34=$33;
      var $35=_HPDF_List_Add($32, $34);
      var $36=(($35)|0)!=0;
      if ($36) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      var $38=$def;
      _HPDF_FontDef_Free($38);
      $1=0;
      __label__ = 22; break;
    case 7: 
      __label__ = 9; break;
    case 8: 
      $1=0;
      __label__ = 22; break;
    case 9: 
      var $42=$5;
      var $43=(($42)|0)!=0;
      if ($43) { __label__ = 10; break; } else { __label__ = 21; break; }
    case 10: 
      var $45=$2;
      var $46=(($45+68)|0);
      var $47=(($46)|0);
      var $48=HEAPU8[($47)];
      var $49=(($48)&255);
      var $50=(($49)|0)==0;
      if ($50) { __label__ = 11; break; } else { __label__ = 12; break; }
    case 11: 
      var $52=$2;
      var $53=(($52+68)|0);
      var $54=(($53)|0);
      var $55=_HPDF_MemCpy($54, ((STRING_TABLE.__str7637)|0), 6);
      __label__ = 20; break;
    case 12: 
      $i=5;
      __label__ = 13; break;
    case 13: 
      var $58=$i;
      var $59=(($58)|0) >= 0;
      if ($59) { __label__ = 14; break; } else { __label__ = 19; break; }
    case 14: 
      var $61=$i;
      var $62=$2;
      var $63=(($62+68)|0);
      var $64=(($63+$61)|0);
      var $65=HEAPU8[($64)];
      var $66=(($65)&255);
      var $67=((($66)+(1))|0);
      var $68=(($67) & 255);
      HEAP8[($64)]=$68;
      var $69=$i;
      var $70=$2;
      var $71=(($70+68)|0);
      var $72=(($71+$69)|0);
      var $73=HEAPU8[($72)];
      var $74=(($73)&255);
      var $75=(($74)|0) > 90;
      if ($75) { __label__ = 15; break; } else { __label__ = 16; break; }
    case 15: 
      var $77=$i;
      var $78=$2;
      var $79=(($78+68)|0);
      var $80=(($79+$77)|0);
      HEAP8[($80)]=65;
      __label__ = 17; break;
    case 16: 
      __label__ = 19; break;
    case 17: 
      __label__ = 18; break;
    case 18: 
      var $84=$i;
      var $85=((($84)-(1))|0);
      $i=$85;
      __label__ = 13; break;
    case 19: 
      __label__ = 20; break;
    case 20: 
      var $88=$def;
      var $89=$2;
      var $90=(($89+68)|0);
      var $91=(($90)|0);
      _HPDF_TTFontDef_SetTagName($88, $91);
      __label__ = 21; break;
    case 21: 
      var $93=$def;
      var $94=(($93+4)|0);
      var $95=(($94)|0);
      $1=$95;
      __label__ = 22; break;
    case 22: 
      var $97=$1;
      ;
      return $97;
    default: assert(0, "bad label: " + __label__);
  }
}
_LoadTTFontFromStream2["X"]=1;

function _HPDF_LoadRawImageFromFile($pdf, $filename, $width, $height, $color_space) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $5;
      var $6;
      var $imagedata;
      var $image;
      $2=$pdf;
      $3=$filename;
      $4=$width;
      $5=$height;
      $6=$color_space;
      var $7=$2;
      var $8=_HPDF_HasDoc($7);
      var $9=(($8)|0)!=0;
      if ($9) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=0;
      __label__ = 13; break;
    case 4: 
      var $12=$2;
      var $13=(($12+8)|0);
      var $14=HEAP32[(($13)>>2)];
      var $15=$3;
      var $16=_HPDF_FileReader_New($14, $15);
      $imagedata=$16;
      var $17=$imagedata;
      var $18=_HPDF_Stream_Validate($17);
      var $19=(($18)|0)!=0;
      if ($19) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $21=$2;
      var $22=(($21+8)|0);
      var $23=HEAP32[(($22)>>2)];
      var $24=$imagedata;
      var $25=$2;
      var $26=(($25+20)|0);
      var $27=HEAP32[(($26)>>2)];
      var $28=$4;
      var $29=$5;
      var $30=$6;
      var $31=_HPDF_Image_LoadRawImage($23, $24, $27, $28, $29, $30);
      $image=$31;
      __label__ = 7; break;
    case 6: 
      $image=0;
      __label__ = 7; break;
    case 7: 
      var $34=$imagedata;
      _HPDF_Stream_Free($34);
      var $35=$image;
      var $36=(($35)|0)!=0;
      if ($36) { __label__ = 9; break; } else { __label__ = 8; break; }
    case 8: 
      var $38=$2;
      var $39=(($38+40)|0);
      var $40=_HPDF_CheckError($39);
      __label__ = 9; break;
    case 9: 
      var $42=$image;
      var $43=(($42)|0)!=0;
      if ($43) { __label__ = 10; break; } else { __label__ = 12; break; }
    case 10: 
      var $45=$2;
      var $46=(($45+88)|0);
      var $47=HEAP32[(($46)>>2)];
      var $48=$47 & 2;
      var $49=(($48)|0)!=0;
      if ($49) { __label__ = 11; break; } else { __label__ = 12; break; }
    case 11: 
      var $51=$image;
      var $52=(($51+40)|0);
      HEAP32[(($52)>>2)]=1024;
      __label__ = 12; break;
    case 12: 
      var $54=$image;
      $1=$54;
      __label__ = 13; break;
    case 13: 
      var $56=$1;
      ;
      return $56;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_LoadRawImageFromFile["X"]=1;

function _HPDF_LoadRawImageFromMem($pdf, $buf, $width, $height, $color_space, $bits_per_component) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $5;
      var $6;
      var $7;
      var $image;
      $2=$pdf;
      $3=$buf;
      $4=$width;
      $5=$height;
      $6=$color_space;
      $7=$bits_per_component;
      var $8=$2;
      var $9=_HPDF_HasDoc($8);
      var $10=(($9)|0)!=0;
      if ($10) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=0;
      __label__ = 10; break;
    case 4: 
      var $13=$2;
      var $14=(($13+8)|0);
      var $15=HEAP32[(($14)>>2)];
      var $16=$3;
      var $17=$2;
      var $18=(($17+20)|0);
      var $19=HEAP32[(($18)>>2)];
      var $20=$4;
      var $21=$5;
      var $22=$6;
      var $23=$7;
      var $24=_HPDF_Image_LoadRawImageFromMem($15, $16, $19, $20, $21, $22, $23);
      $image=$24;
      var $25=$image;
      var $26=(($25)|0)!=0;
      if ($26) { __label__ = 6; break; } else { __label__ = 5; break; }
    case 5: 
      var $28=$2;
      var $29=(($28+40)|0);
      var $30=_HPDF_CheckError($29);
      __label__ = 6; break;
    case 6: 
      var $32=$image;
      var $33=(($32)|0)!=0;
      if ($33) { __label__ = 7; break; } else { __label__ = 9; break; }
    case 7: 
      var $35=$2;
      var $36=(($35+88)|0);
      var $37=HEAP32[(($36)>>2)];
      var $38=$37 & 2;
      var $39=(($38)|0)!=0;
      if ($39) { __label__ = 8; break; } else { __label__ = 9; break; }
    case 8: 
      var $41=$image;
      var $42=(($41+40)|0);
      HEAP32[(($42)>>2)]=1024;
      __label__ = 9; break;
    case 9: 
      var $44=$image;
      $1=$44;
      __label__ = 10; break;
    case 10: 
      var $46=$1;
      ;
      return $46;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_LoadRawImageFromMem["X"]=1;

function _HPDF_LoadJpegImageFromFile($pdf, $filename) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $imagedata;
      var $image;
      $2=$pdf;
      $3=$filename;
      var $4=$2;
      var $5=_HPDF_HasDoc($4);
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=0;
      __label__ = 10; break;
    case 4: 
      var $9=$2;
      var $10=(($9+8)|0);
      var $11=HEAP32[(($10)>>2)];
      var $12=$3;
      var $13=_HPDF_FileReader_New($11, $12);
      $imagedata=$13;
      var $14=$imagedata;
      var $15=_HPDF_Stream_Validate($14);
      var $16=(($15)|0)!=0;
      if ($16) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $18=$2;
      var $19=(($18+8)|0);
      var $20=HEAP32[(($19)>>2)];
      var $21=$imagedata;
      var $22=$2;
      var $23=(($22+20)|0);
      var $24=HEAP32[(($23)>>2)];
      var $25=_HPDF_Image_LoadJpegImage($20, $21, $24);
      $image=$25;
      __label__ = 7; break;
    case 6: 
      $image=0;
      __label__ = 7; break;
    case 7: 
      var $28=$imagedata;
      _HPDF_Stream_Free($28);
      var $29=$image;
      var $30=(($29)|0)!=0;
      if ($30) { __label__ = 9; break; } else { __label__ = 8; break; }
    case 8: 
      var $32=$2;
      var $33=(($32+40)|0);
      var $34=_HPDF_CheckError($33);
      __label__ = 9; break;
    case 9: 
      var $36=$image;
      $1=$36;
      __label__ = 10; break;
    case 10: 
      var $38=$1;
      ;
      return $38;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_LoadJpegImageFromMem($pdf, $buffer, $size) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $image;
      $2=$pdf;
      $3=$buffer;
      $4=$size;
      var $5=$2;
      var $6=_HPDF_HasDoc($5);
      var $7=(($6)|0)!=0;
      if ($7) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=0;
      __label__ = 7; break;
    case 4: 
      var $10=$2;
      var $11=(($10+8)|0);
      var $12=HEAP32[(($11)>>2)];
      var $13=$3;
      var $14=$4;
      var $15=$2;
      var $16=(($15+20)|0);
      var $17=HEAP32[(($16)>>2)];
      var $18=_HPDF_Image_LoadJpegImageFromMem($12, $13, $14, $17);
      $image=$18;
      var $19=$image;
      var $20=(($19)|0)!=0;
      if ($20) { __label__ = 6; break; } else { __label__ = 5; break; }
    case 5: 
      var $22=$2;
      var $23=(($22+40)|0);
      var $24=_HPDF_CheckError($23);
      __label__ = 6; break;
    case 6: 
      var $26=$image;
      $1=$26;
      __label__ = 7; break;
    case 7: 
      var $28=$1;
      ;
      return $28;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_GetPageLayout($pdf) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      $2=$pdf;
      var $3=$2;
      var $4=_HPDF_HasDoc($3);
      var $5=(($4)|0)!=0;
      if ($5) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=0;
      __label__ = 5; break;
    case 4: 
      var $8=$2;
      var $9=(($8+12)|0);
      var $10=HEAP32[(($9)>>2)];
      var $11=_HPDF_Catalog_GetPageLayout($10);
      $1=$11;
      __label__ = 5; break;
    case 5: 
      var $13=$1;
      ;
      return $13;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_SetPageLayout($pdf, $layout) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $ret;
      $2=$pdf;
      $3=$layout;
      var $4=$2;
      var $5=_HPDF_HasDoc($4);
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=4133;
      __label__ = 10; break;
    case 4: 
      var $9=$3;
      var $10=(($9)>>>0) < 0;
      if ($10) { __label__ = 6; break; } else { __label__ = 5; break; }
    case 5: 
      var $12=$3;
      var $13=(($12)>>>0) >= 4;
      if ($13) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      var $15=$2;
      var $16=(($15+40)|0);
      var $17=$3;
      var $18=_HPDF_RaiseError($16, 4201, $17);
      $1=$18;
      __label__ = 10; break;
    case 7: 
      var $20=$2;
      var $21=(($20+12)|0);
      var $22=HEAP32[(($21)>>2)];
      var $23=$3;
      var $24=_HPDF_Catalog_SetPageLayout($22, $23);
      $ret=$24;
      var $25=$ret;
      var $26=(($25)|0)!=0;
      if ($26) { __label__ = 8; break; } else { __label__ = 9; break; }
    case 8: 
      var $28=$2;
      var $29=(($28+40)|0);
      var $30=_HPDF_CheckError($29);
      __label__ = 9; break;
    case 9: 
      $1=0;
      __label__ = 10; break;
    case 10: 
      var $33=$1;
      ;
      return $33;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_GetPageMode($pdf) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      $2=$pdf;
      var $3=$2;
      var $4=_HPDF_HasDoc($3);
      var $5=(($4)|0)!=0;
      if ($5) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=0;
      __label__ = 5; break;
    case 4: 
      var $8=$2;
      var $9=(($8+12)|0);
      var $10=HEAP32[(($9)>>2)];
      var $11=_HPDF_Catalog_GetPageMode($10);
      $1=$11;
      __label__ = 5; break;
    case 5: 
      var $13=$1;
      ;
      return $13;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_SetPageMode($pdf, $mode) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $ret;
      $2=$pdf;
      $3=$mode;
      var $4=$2;
      var $5=_HPDF_HasDoc($4);
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=4133;
      __label__ = 10; break;
    case 4: 
      var $9=$3;
      var $10=(($9)>>>0) < 0;
      if ($10) { __label__ = 6; break; } else { __label__ = 5; break; }
    case 5: 
      var $12=$3;
      var $13=(($12)>>>0) >= 4;
      if ($13) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      var $15=$2;
      var $16=(($15+40)|0);
      var $17=$3;
      var $18=_HPDF_RaiseError($16, 4208, $17);
      $1=$18;
      __label__ = 10; break;
    case 7: 
      var $20=$2;
      var $21=(($20+12)|0);
      var $22=HEAP32[(($21)>>2)];
      var $23=$3;
      var $24=_HPDF_Catalog_SetPageMode($22, $23);
      $ret=$24;
      var $25=$ret;
      var $26=(($25)|0)!=0;
      if ($26) { __label__ = 8; break; } else { __label__ = 9; break; }
    case 8: 
      var $28=$2;
      var $29=(($28+40)|0);
      var $30=_HPDF_CheckError($29);
      $1=$30;
      __label__ = 10; break;
    case 9: 
      $1=0;
      __label__ = 10; break;
    case 10: 
      var $33=$1;
      ;
      return $33;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_SetOpenAction($pdf, $open_action) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $ret;
      $2=$pdf;
      $3=$open_action;
      var $4=$2;
      var $5=_HPDF_HasDoc($4);
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=4133;
      __label__ = 10; break;
    case 4: 
      var $9=$3;
      var $10=(($9)|0)!=0;
      if ($10) { __label__ = 5; break; } else { __label__ = 7; break; }
    case 5: 
      var $12=$3;
      var $13=_HPDF_Destination_Validate($12);
      var $14=(($13)|0)!=0;
      if ($14) { __label__ = 7; break; } else { __label__ = 6; break; }
    case 6: 
      var $16=$2;
      var $17=(($16+40)|0);
      var $18=_HPDF_RaiseError($17, 4131, 0);
      $1=$18;
      __label__ = 10; break;
    case 7: 
      var $20=$2;
      var $21=(($20+12)|0);
      var $22=HEAP32[(($21)>>2)];
      var $23=$3;
      var $24=_HPDF_Catalog_SetOpenAction($22, $23);
      $ret=$24;
      var $25=$ret;
      var $26=(($25)|0)!=0;
      if ($26) { __label__ = 8; break; } else { __label__ = 9; break; }
    case 8: 
      var $28=$2;
      var $29=(($28+40)|0);
      var $30=_HPDF_CheckError($29);
      $1=$30;
      __label__ = 10; break;
    case 9: 
      $1=0;
      __label__ = 10; break;
    case 10: 
      var $33=$1;
      ;
      return $33;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_GetViewerPreference($pdf) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      $2=$pdf;
      var $3=$2;
      var $4=_HPDF_HasDoc($3);
      var $5=(($4)|0)!=0;
      if ($5) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=0;
      __label__ = 5; break;
    case 4: 
      var $8=$2;
      var $9=(($8+12)|0);
      var $10=HEAP32[(($9)>>2)];
      var $11=_HPDF_Catalog_GetViewerPreference($10);
      $1=$11;
      __label__ = 5; break;
    case 5: 
      var $13=$1;
      ;
      return $13;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_SetViewerPreference($pdf, $value) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $ret;
      $2=$pdf;
      $3=$value;
      var $4=$2;
      var $5=_HPDF_HasDoc($4);
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=4133;
      __label__ = 7; break;
    case 4: 
      var $9=$2;
      var $10=(($9+12)|0);
      var $11=HEAP32[(($10)>>2)];
      var $12=$3;
      var $13=_HPDF_Catalog_SetViewerPreference($11, $12);
      $ret=$13;
      var $14=$ret;
      var $15=(($14)|0)!=0;
      if ($15) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $17=$2;
      var $18=(($17+40)|0);
      var $19=_HPDF_CheckError($18);
      $1=$19;
      __label__ = 7; break;
    case 6: 
      $1=0;
      __label__ = 7; break;
    case 7: 
      var $22=$1;
      ;
      return $22;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_AddPageLabel($pdf, $page_num, $style, $first_page, $prefix) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $5;
      var $6;
      var $page_label;
      var $ret;
      $2=$pdf;
      $3=$page_num;
      $4=$style;
      $5=$first_page;
      $6=$prefix;
      var $7=$2;
      var $8=_HPDF_HasDoc($7);
      var $9=(($8)|0)!=0;
      if ($9) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=4133;
      __label__ = 12; break;
    case 4: 
      var $12=$2;
      var $13=$4;
      var $14=$5;
      var $15=$6;
      var $16=_HPDF_PageLabel_New($12, $13, $14, $15);
      $page_label=$16;
      var $17=$page_label;
      var $18=(($17)|0)!=0;
      if ($18) { __label__ = 6; break; } else { __label__ = 5; break; }
    case 5: 
      var $20=$2;
      var $21=(($20+40)|0);
      var $22=_HPDF_CheckError($21);
      $1=$22;
      __label__ = 12; break;
    case 6: 
      var $24=$4;
      var $25=(($24)>>>0) < 0;
      if ($25) { __label__ = 8; break; } else { __label__ = 7; break; }
    case 7: 
      var $27=$4;
      var $28=(($27)>>>0) >= 5;
      if ($28) { __label__ = 8; break; } else { __label__ = 9; break; }
    case 8: 
      var $30=$2;
      var $31=(($30+40)|0);
      var $32=$4;
      var $33=_HPDF_RaiseError($31, 4209, $32);
      $1=$33;
      __label__ = 12; break;
    case 9: 
      var $35=$2;
      var $36=(($35+12)|0);
      var $37=HEAP32[(($36)>>2)];
      var $38=$3;
      var $39=$page_label;
      var $40=_HPDF_Catalog_AddPageLabel($37, $38, $39);
      $ret=$40;
      var $41=$ret;
      var $42=(($41)|0)!=0;
      if ($42) { __label__ = 10; break; } else { __label__ = 11; break; }
    case 10: 
      var $44=$2;
      var $45=(($44+40)|0);
      var $46=_HPDF_CheckError($45);
      $1=$46;
      __label__ = 12; break;
    case 11: 
      $1=0;
      __label__ = 12; break;
    case 12: 
      var $49=$1;
      ;
      return $49;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_AddPageLabel["X"]=1;

function _HPDF_GetInfoAttr($pdf, $type) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $ret;
      var $info;
      $1=$pdf;
      $2=$type;
      $ret=0;
      var $3=$1;
      var $4=_GetInfo($3);
      $info=$4;
      var $5=$info;
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $8=$info;
      var $9=$2;
      var $10=_HPDF_Info_GetInfoAttr($8, $9);
      $ret=$10;
      __label__ = 5; break;
    case 4: 
      var $12=$1;
      var $13=(($12+40)|0);
      var $14=_HPDF_CheckError($13);
      __label__ = 5; break;
    case 5: 
      var $16=$ret;
      ;
      return $16;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_SetInfoDateAttr($pdf, $type, $value) {
  var __stackBase__  = STACKTOP; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var tempParam = $value; $value = STACKTOP;STACKTOP += 36;assert(STACKTOP < STACK_ROOT + STACK_MAX, "Ran out of stack");for (var $$src = tempParam>>2, $$dest = $value>>2, $$stop = $$src + 9; $$src < $$stop; $$src++, $$dest++) {
  HEAP32[$$dest] = HEAP32[$$src]
};
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $ret;
      var $info;
      $2=$pdf;
      $3=$type;
      var $4=$2;
      var $5=_GetInfo($4);
      $info=$5;
      var $6=$info;
      var $7=(($6)|0)!=0;
      if ($7) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      var $9=$2;
      var $10=(($9+40)|0);
      var $11=_HPDF_CheckError($10);
      $1=$11;
      __label__ = 7; break;
    case 4: 
      var $13=$info;
      var $14=$3;
      var $15=_HPDF_Info_SetInfoDateAttr($13, $14, $value);
      $ret=$15;
      var $16=$ret;
      var $17=(($16)|0)!=0;
      if ($17) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $19=$2;
      var $20=(($19+40)|0);
      var $21=_HPDF_CheckError($20);
      $1=$21;
      __label__ = 7; break;
    case 6: 
      var $23=$ret;
      $1=$23;
      __label__ = 7; break;
    case 7: 
      var $25=$1;
      STACKTOP = __stackBase__;
      return $25;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_BasicEncoder_ToUnicode($encoder, $code) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $attr;
      $2=$encoder;
      $3=$code;
      var $4=$2;
      var $5=(($4+164)|0);
      var $6=HEAP32[(($5)>>2)];
      var $7=$6;
      $attr=$7;
      var $8=$3;
      var $9=(($8)&65535);
      var $10=(($9)|0) > 255;
      if ($10) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      $1=0;
      __label__ = 5; break;
    case 4: 
      var $13=$3;
      var $14=(($13)&65535);
      var $15=$attr;
      var $16=(($15+130)|0);
      var $17=(($16+($14<<1))|0);
      var $18=HEAP16[(($17)>>1)];
      $1=$18;
      __label__ = 5; break;
    case 5: 
      var $20=$1;
      ;
      return $20;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_CreateOutline($pdf, $parent, $title, $encoder) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $5;
      var $outline;
      var $ret;
      $2=$pdf;
      $3=$parent;
      $4=$title;
      $5=$encoder;
      var $6=$2;
      var $7=_HPDF_HasDoc($6);
      var $8=(($7)|0)!=0;
      if ($8) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=0;
      __label__ = 20; break;
    case 4: 
      var $11=$3;
      var $12=(($11)|0)!=0;
      if ($12) { __label__ = 14; break; } else { __label__ = 5; break; }
    case 5: 
      var $14=$2;
      var $15=(($14+16)|0);
      var $16=HEAP32[(($15)>>2)];
      var $17=(($16)|0)!=0;
      if ($17) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      var $19=$2;
      var $20=(($19+16)|0);
      var $21=HEAP32[(($20)>>2)];
      $3=$21;
      __label__ = 13; break;
    case 7: 
      var $23=$2;
      var $24=(($23+8)|0);
      var $25=HEAP32[(($24)>>2)];
      var $26=$2;
      var $27=(($26+20)|0);
      var $28=HEAP32[(($27)>>2)];
      var $29=_HPDF_OutlineRoot_New($25, $28);
      var $30=$2;
      var $31=(($30+16)|0);
      HEAP32[(($31)>>2)]=$29;
      var $32=$2;
      var $33=(($32+16)|0);
      var $34=HEAP32[(($33)>>2)];
      var $35=(($34)|0)!=0;
      if ($35) { __label__ = 8; break; } else { __label__ = 11; break; }
    case 8: 
      var $37=$2;
      var $38=(($37+12)|0);
      var $39=HEAP32[(($38)>>2)];
      var $40=$2;
      var $41=(($40+16)|0);
      var $42=HEAP32[(($41)>>2)];
      var $43=$42;
      var $44=_HPDF_Dict_Add($39, ((STRING_TABLE.__str6636)|0), $43);
      $ret=$44;
      var $45=$ret;
      var $46=(($45)|0)!=0;
      if ($46) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      var $48=$2;
      var $49=(($48+40)|0);
      var $50=_HPDF_CheckError($49);
      var $51=$2;
      var $52=(($51+16)|0);
      HEAP32[(($52)>>2)]=0;
      $1=0;
      __label__ = 20; break;
    case 10: 
      var $54=$2;
      var $55=(($54+16)|0);
      var $56=HEAP32[(($55)>>2)];
      $3=$56;
      __label__ = 12; break;
    case 11: 
      var $58=$2;
      var $59=(($58+40)|0);
      var $60=_HPDF_CheckError($59);
      $1=0;
      __label__ = 20; break;
    case 12: 
      __label__ = 13; break;
    case 13: 
      __label__ = 14; break;
    case 14: 
      var $64=$3;
      var $65=_HPDF_Outline_Validate($64);
      var $66=(($65)|0)!=0;
      if ($66) { __label__ = 15; break; } else { __label__ = 16; break; }
    case 15: 
      var $68=$2;
      var $69=(($68+8)|0);
      var $70=HEAP32[(($69)>>2)];
      var $71=$3;
      var $72=(($71+8)|0);
      var $73=HEAP32[(($72)>>2)];
      var $74=(($70)|0)!=(($73)|0);
      if ($74) { __label__ = 16; break; } else { __label__ = 17; break; }
    case 16: 
      var $76=$2;
      var $77=(($76+40)|0);
      var $78=_HPDF_RaiseError($77, 4150, 0);
      $1=0;
      __label__ = 20; break;
    case 17: 
      var $80=$2;
      var $81=(($80+8)|0);
      var $82=HEAP32[(($81)>>2)];
      var $83=$3;
      var $84=$4;
      var $85=$5;
      var $86=$2;
      var $87=(($86+20)|0);
      var $88=HEAP32[(($87)>>2)];
      var $89=_HPDF_Outline_New($82, $83, $84, $85, $88);
      $outline=$89;
      var $90=$outline;
      var $91=(($90)|0)!=0;
      if ($91) { __label__ = 19; break; } else { __label__ = 18; break; }
    case 18: 
      var $93=$2;
      var $94=(($93+40)|0);
      var $95=_HPDF_CheckError($94);
      __label__ = 19; break;
    case 19: 
      var $97=$outline;
      $1=$97;
      __label__ = 20; break;
    case 20: 
      var $99=$1;
      ;
      return $99;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_CreateOutline["X"]=1;

function _HPDF_CreateExtGState($pdf) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $ext_gstate;
      $2=$pdf;
      var $3=$2;
      var $4=_HPDF_HasDoc($3);
      var $5=(($4)|0)!=0;
      if ($5) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=0;
      __label__ = 7; break;
    case 4: 
      var $8=$2;
      var $9=(($8+4)|0);
      HEAP32[(($9)>>2)]=2;
      var $10=$2;
      var $11=(($10+8)|0);
      var $12=HEAP32[(($11)>>2)];
      var $13=$2;
      var $14=(($13+20)|0);
      var $15=HEAP32[(($14)>>2)];
      var $16=_HPDF_ExtGState_New($12, $15);
      $ext_gstate=$16;
      var $17=$ext_gstate;
      var $18=(($17)|0)!=0;
      if ($18) { __label__ = 6; break; } else { __label__ = 5; break; }
    case 5: 
      var $20=$2;
      var $21=(($20+40)|0);
      var $22=_HPDF_CheckError($21);
      __label__ = 6; break;
    case 6: 
      var $24=$ext_gstate;
      $1=$24;
      __label__ = 7; break;
    case 7: 
      var $26=$1;
      ;
      return $26;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_SetCompressionMode($pdf, $mode) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      $2=$pdf;
      $3=$mode;
      var $4=$2;
      var $5=_HPDF_Doc_Validate($4);
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=4133;
      __label__ = 7; break;
    case 4: 
      var $9=$3;
      var $10=$3;
      var $11=$10 & 255;
      var $12=(($9)|0)!=(($11)|0);
      if ($12) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $14=$2;
      var $15=(($14+40)|0);
      var $16=_HPDF_RaiseError($15, 4129, 0);
      $1=$16;
      __label__ = 7; break;
    case 6: 
      var $18=$3;
      var $19=$2;
      var $20=(($19+88)|0);
      HEAP32[(($20)>>2)]=$18;
      $1=0;
      __label__ = 7; break;
    case 7: 
      var $22=$1;
      ;
      return $22;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_GetErrorDetail($pdf) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      $2=$pdf;
      var $3=$2;
      var $4=_HPDF_Doc_Validate($3);
      var $5=(($4)|0)!=0;
      if ($5) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=4133;
      __label__ = 5; break;
    case 4: 
      var $8=$2;
      var $9=(($8+40)|0);
      var $10=_HPDF_Error_GetDetailCode($9);
      $1=$10;
      __label__ = 5; break;
    case 5: 
      var $12=$1;
      ;
      return $12;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_ResetError($pdf) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      $1=$pdf;
      var $2=$1;
      var $3=_HPDF_Doc_Validate($2);
      var $4=(($3)|0)!=0;
      if ($4) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      __label__ = 5; break;
    case 4: 
      var $7=$1;
      var $8=(($7+40)|0);
      _HPDF_Error_Reset($8);
      __label__ = 5; break;
    case 5: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}


function _WriteHeader($pdf, $stream) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $idx;
      $2=$pdf;
      $3=$stream;
      var $4=$2;
      var $5=(($4+4)|0);
      var $6=HEAP32[(($5)>>2)];
      $idx=$6;
      var $7=$3;
      var $8=$idx;
      var $9=((_HPDF_VERSION_STR+($8<<2))|0);
      var $10=HEAP32[(($9)>>2)];
      var $11=_HPDF_Stream_WriteStr($7, $10);
      var $12=(($11)|0)!=0;
      if ($12) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $14=$2;
      var $15=(($14+40)|0);
      var $16=(($15)|0);
      var $17=HEAP32[(($16)>>2)];
      $1=$17;
      __label__ = 5; break;
    case 4: 
      $1=0;
      __label__ = 5; break;
    case 5: 
      var $20=$1;
      ;
      return $20;
    default: assert(0, "bad label: " + __label__);
  }
}


function _PrepareTrailer($pdf) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      $2=$pdf;
      var $3=$2;
      var $4=(($3+60)|0);
      var $5=HEAP32[(($4)>>2)];
      var $6=$2;
      var $7=(($6+12)|0);
      var $8=HEAP32[(($7)>>2)];
      var $9=$8;
      var $10=_HPDF_Dict_Add($5, ((STRING_TABLE.__str8638)|0), $9);
      var $11=(($10)|0)!=0;
      if ($11) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $13=$2;
      var $14=(($13+40)|0);
      var $15=(($14)|0);
      var $16=HEAP32[(($15)>>2)];
      $1=$16;
      __label__ = 7; break;
    case 4: 
      var $18=$2;
      var $19=(($18+60)|0);
      var $20=HEAP32[(($19)>>2)];
      var $21=$2;
      var $22=(($21+56)|0);
      var $23=HEAP32[(($22)>>2)];
      var $24=$23;
      var $25=_HPDF_Dict_Add($20, ((STRING_TABLE.__str9639)|0), $24);
      var $26=(($25)|0)!=0;
      if ($26) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $28=$2;
      var $29=(($28+40)|0);
      var $30=(($29)|0);
      var $31=HEAP32[(($30)>>2)];
      $1=$31;
      __label__ = 7; break;
    case 6: 
      $1=0;
      __label__ = 7; break;
    case 7: 
      var $34=$1;
      ;
      return $34;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_LoadPngImageFromMem($pdf, $buffer, $size) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $imagedata;
      var $image;
      $2=$pdf;
      $3=$buffer;
      $4=$size;
      var $5=$2;
      var $6=_HPDF_HasDoc($5);
      var $7=(($6)|0)!=0;
      if ($7) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=0;
      __label__ = 11; break;
    case 4: 
      var $10=$2;
      var $11=(($10+8)|0);
      var $12=HEAP32[(($11)>>2)];
      var $13=$4;
      var $14=_HPDF_MemStream_New($12, $13);
      $imagedata=$14;
      var $15=$imagedata;
      var $16=_HPDF_Stream_Validate($15);
      var $17=(($16)|0)!=0;
      if ($17) { __label__ = 6; break; } else { __label__ = 5; break; }
    case 5: 
      var $19=$2;
      var $20=(($19+40)|0);
      var $21=_HPDF_RaiseError($20, 4156, 0);
      $1=0;
      __label__ = 11; break;
    case 6: 
      var $23=$imagedata;
      var $24=$3;
      var $25=$4;
      var $26=_HPDF_Stream_Write($23, $24, $25);
      var $27=(($26)|0)!=0;
      if ($27) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $29=$imagedata;
      _HPDF_Stream_Free($29);
      $1=0;
      __label__ = 11; break;
    case 8: 
      var $31=$2;
      var $32=$imagedata;
      var $33=_LoadPngImageFromStream($31, $32, 0);
      $image=$33;
      var $34=$imagedata;
      _HPDF_Stream_Free($34);
      var $35=$image;
      var $36=(($35)|0)!=0;
      if ($36) { __label__ = 10; break; } else { __label__ = 9; break; }
    case 9: 
      var $38=$2;
      var $39=(($38+40)|0);
      var $40=_HPDF_CheckError($39);
      __label__ = 10; break;
    case 10: 
      var $42=$image;
      $1=$42;
      __label__ = 11; break;
    case 11: 
      var $44=$1;
      ;
      return $44;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_LoadPngImageFromMem["X"]=1;

function _LoadPngImageFromStream($pdf, $imagedata, $delayed_loading) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $image;
      $1=$pdf;
      $2=$imagedata;
      $3=$delayed_loading;
      var $4=$1;
      var $5=(($4+8)|0);
      var $6=HEAP32[(($5)>>2)];
      var $7=$2;
      var $8=$1;
      var $9=(($8+20)|0);
      var $10=HEAP32[(($9)>>2)];
      var $11=$3;
      var $12=_HPDF_Image_LoadPngImage($6, $7, $10, $11);
      $image=$12;
      var $13=$image;
      var $14=(($13)|0)!=0;
      if ($14) { __label__ = 3; break; } else { __label__ = 5; break; }
    case 3: 
      var $16=$1;
      var $17=(($16+88)|0);
      var $18=HEAP32[(($17)>>2)];
      var $19=$18 & 2;
      var $20=(($19)|0)!=0;
      if ($20) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      var $22=$image;
      var $23=(($22+40)|0);
      HEAP32[(($23)>>2)]=1024;
      __label__ = 5; break;
    case 5: 
      var $25=$image;
      ;
      return $25;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_LoadPngImageFromFile($pdf, $filename) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $imagedata;
      var $image;
      $2=$pdf;
      $3=$filename;
      var $4=$2;
      var $5=_HPDF_HasDoc($4);
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=0;
      __label__ = 12; break;
    case 4: 
      var $9=$2;
      var $10=(($9+8)|0);
      var $11=HEAP32[(($10)>>2)];
      var $12=$3;
      var $13=_HPDF_FileReader_New($11, $12);
      $imagedata=$13;
      var $14=$imagedata;
      var $15=_HPDF_Stream_Validate($14);
      var $16=(($15)|0)!=0;
      if ($16) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $18=$2;
      var $19=$imagedata;
      var $20=_LoadPngImageFromStream($18, $19, 0);
      $image=$20;
      __label__ = 7; break;
    case 6: 
      $image=0;
      __label__ = 7; break;
    case 7: 
      var $23=$imagedata;
      var $24=(($23)|0)!=0;
      if ($24) { __label__ = 8; break; } else { __label__ = 9; break; }
    case 8: 
      var $26=$imagedata;
      _HPDF_Stream_Free($26);
      __label__ = 9; break;
    case 9: 
      var $28=$image;
      var $29=(($28)|0)!=0;
      if ($29) { __label__ = 11; break; } else { __label__ = 10; break; }
    case 10: 
      var $31=$2;
      var $32=(($31+40)|0);
      var $33=_HPDF_CheckError($32);
      __label__ = 11; break;
    case 11: 
      var $35=$image;
      $1=$35;
      __label__ = 12; break;
    case 12: 
      var $37=$1;
      ;
      return $37;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_LoadPngImageFromFile2($pdf, $filename) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $imagedata;
      var $image;
      var $fname;
      $2=$pdf;
      $3=$filename;
      var $4=$2;
      var $5=_HPDF_HasDoc($4);
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=0;
      __label__ = 16; break;
    case 4: 
      var $9=$2;
      var $10=(($9+8)|0);
      var $11=HEAP32[(($10)>>2)];
      var $12=$3;
      var $13=_HPDF_FileReader_New($11, $12);
      $imagedata=$13;
      var $14=$imagedata;
      var $15=_HPDF_Stream_Validate($14);
      var $16=(($15)|0)!=0;
      if ($16) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $18=$2;
      var $19=$imagedata;
      var $20=_LoadPngImageFromStream($18, $19, 1);
      $image=$20;
      __label__ = 7; break;
    case 6: 
      $image=0;
      __label__ = 7; break;
    case 7: 
      var $23=$imagedata;
      var $24=(($23)|0)!=0;
      if ($24) { __label__ = 8; break; } else { __label__ = 9; break; }
    case 8: 
      var $26=$imagedata;
      _HPDF_Stream_Free($26);
      __label__ = 9; break;
    case 9: 
      var $28=$image;
      var $29=(($28)|0)!=0;
      if ($29) { __label__ = 11; break; } else { __label__ = 10; break; }
    case 10: 
      var $31=$2;
      var $32=(($31+40)|0);
      var $33=_HPDF_CheckError($32);
      $1=0;
      __label__ = 16; break;
    case 11: 
      var $35=$2;
      var $36=(($35+8)|0);
      var $37=HEAP32[(($36)>>2)];
      var $38=$3;
      var $39=_HPDF_String_New($37, $38, 0);
      $fname=$39;
      var $40=$fname;
      var $41=(($40)|0)!=0;
      if ($41) { __label__ = 13; break; } else { __label__ = 12; break; }
    case 12: 
      var $43=$2;
      var $44=(($43+40)|0);
      var $45=_HPDF_CheckError($44);
      $1=0;
      __label__ = 16; break;
    case 13: 
      var $47=$fname;
      var $48=(($47)|0);
      var $49=(($48)|0);
      var $50=HEAP32[(($49)>>2)];
      var $51=$50 | 268435456;
      HEAP32[(($49)>>2)]=$51;
      var $52=$image;
      var $53=$fname;
      var $54=$53;
      var $55=_HPDF_Dict_Add($52, ((STRING_TABLE.__str647)|0), $54);
      var $56=(($55)|0)!=0;
      if ($56) { __label__ = 14; break; } else { __label__ = 15; break; }
    case 14: 
      var $58=$2;
      var $59=(($58+40)|0);
      var $60=_HPDF_CheckError($59);
      $1=0;
      __label__ = 16; break;
    case 15: 
      var $62=$image;
      $1=$62;
      __label__ = 16; break;
    case 16: 
      var $64=$1;
      ;
      return $64;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_LoadPngImageFromFile2["X"]=1;

function _HPDF_BasicEncoder_New($mmgr, $encoding_name) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $encoder;
      var $encoder_attr;
      var $data;
      var $eptr;
      $2=$mmgr;
      $3=$encoding_name;
      var $4=$2;
      var $5=(($4)|0)==0;
      if ($5) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      $1=0;
      __label__ = 18; break;
    case 4: 
      var $8=$3;
      var $9=_HPDF_BasicEncoder_FindBuiltinData($8);
      $data=$9;
      var $10=$data;
      var $11=(($10)|0);
      var $12=HEAP32[(($11)>>2)];
      var $13=(($12)|0)!=0;
      if ($13) { __label__ = 6; break; } else { __label__ = 5; break; }
    case 5: 
      var $15=$2;
      var $16=(($15)|0);
      var $17=HEAP32[(($16)>>2)];
      var $18=_HPDF_SetError($17, 4139, 0);
      $1=0;
      __label__ = 18; break;
    case 6: 
      var $20=$2;
      var $21=_HPDF_GetMem($20, 168);
      var $22=$21;
      $encoder=$22;
      var $23=$encoder;
      var $24=(($23)|0)!=0;
      if ($24) { __label__ = 8; break; } else { __label__ = 7; break; }
    case 7: 
      $1=0;
      __label__ = 18; break;
    case 8: 
      var $27=$encoder;
      var $28=$27;
      var $29=_HPDF_MemSet($28, 0, 168);
      var $30=$encoder;
      var $31=(($30+4)|0);
      var $32=(($31)|0);
      var $33=(($32+127)|0);
      $eptr=$33;
      var $34=$encoder;
      var $35=(($34+4)|0);
      var $36=(($35)|0);
      var $37=$data;
      var $38=(($37)|0);
      var $39=HEAP32[(($38)>>2)];
      var $40=$eptr;
      var $41=_HPDF_StrCpy($36, $39, $40);
      var $42=$2;
      var $43=$encoder;
      var $44=(($43+132)|0);
      HEAP32[(($44)>>2)]=$42;
      var $45=$2;
      var $46=(($45)|0);
      var $47=HEAP32[(($46)>>2)];
      var $48=$encoder;
      var $49=(($48+136)|0);
      HEAP32[(($49)>>2)]=$47;
      var $50=$encoder;
      var $51=(($50+140)|0);
      HEAP32[(($51)>>2)]=0;
      var $52=$encoder;
      var $53=(($52+148)|0);
      HEAP32[(($53)>>2)]=14;
      var $54=$encoder;
      var $55=(($54+152)|0);
      HEAP32[(($55)>>2)]=16;
      var $56=$encoder;
      var $57=(($56+156)|0);
      HEAP32[(($57)>>2)]=18;
      var $58=$2;
      var $59=_HPDF_GetMem($58, 904);
      var $60=$59;
      $encoder_attr=$60;
      var $61=$encoder_attr;
      var $62=(($61)|0)!=0;
      if ($62) { __label__ = 10; break; } else { __label__ = 9; break; }
    case 9: 
      var $64=$encoder;
      var $65=(($64+132)|0);
      var $66=HEAP32[(($65)>>2)];
      var $67=$encoder;
      var $68=$67;
      _HPDF_FreeMem($66, $68);
      $1=0;
      __label__ = 18; break;
    case 10: 
      var $70=$encoder;
      var $71=(($70)|0);
      HEAP32[(($71)>>2)]=1162756932;
      var $72=$encoder_attr;
      var $73=$72;
      var $74=$encoder;
      var $75=(($74+164)|0);
      HEAP32[(($75)>>2)]=$73;
      var $76=$encoder_attr;
      var $77=$76;
      var $78=_HPDF_MemSet($77, 0, 904);
      var $79=$encoder_attr;
      var $80=(($79+128)|0);
      HEAP8[($80)]=32;
      var $81=$encoder_attr;
      var $82=(($81+129)|0);
      HEAP8[($82)]=-1;
      var $83=$encoder_attr;
      var $84=(($83+644)|0);
      HEAP32[(($84)>>2)]=0;
      var $85=$encoder_attr;
      var $86=(($85)|0);
      var $87=(($86)|0);
      var $88=(($87+127)|0);
      $eptr=$88;
      var $89=$data;
      var $90=(($89+4)|0);
      var $91=HEAP32[(($90)>>2)];
      if ((($91)|0) == 0) {
        __label__ = 11; break;
      }
      else if ((($91)|0) == 1) {
        __label__ = 12; break;
      }
      else if ((($91)|0) == 2) {
        __label__ = 13; break;
      }
      else {
      __label__ = 14; break;
      }
      
    case 11: 
      var $93=$encoder_attr;
      var $94=(($93)|0);
      var $95=(($94)|0);
      var $96=$eptr;
      var $97=_HPDF_StrCpy($95, ((STRING_TABLE.__str649)|0), $96);
      var $98=$encoder;
      _HPDF_BasicEncoder_CopyMap($98, ((_HPDF_UNICODE_MAP_STANDARD)|0));
      __label__ = 15; break;
    case 12: 
      var $100=$encoder_attr;
      var $101=(($100)|0);
      var $102=(($101)|0);
      var $103=$eptr;
      var $104=_HPDF_StrCpy($102, ((STRING_TABLE.__str1650)|0), $103);
      var $105=$encoder;
      _HPDF_BasicEncoder_CopyMap($105, ((_HPDF_UNICODE_MAP_WIN_ANSI)|0));
      __label__ = 15; break;
    case 13: 
      var $107=$encoder_attr;
      var $108=(($107)|0);
      var $109=(($108)|0);
      var $110=$eptr;
      var $111=_HPDF_StrCpy($109, ((STRING_TABLE.__str2651)|0), $110);
      var $112=$encoder;
      _HPDF_BasicEncoder_CopyMap($112, ((_HPDF_UNICODE_MAP_MAC_ROMAN)|0));
      __label__ = 15; break;
    case 14: 
      var $114=$encoder_attr;
      var $115=(($114)|0);
      var $116=(($115)|0);
      var $117=$eptr;
      var $118=_HPDF_StrCpy($116, ((STRING_TABLE.__str3652)|0), $117);
      var $119=$encoder;
      _HPDF_BasicEncoder_CopyMap($119, ((_HPDF_UNICODE_MAP_FONT_SPECIFIC)|0));
      __label__ = 15; break;
    case 15: 
      var $121=$data;
      var $122=(($121+8)|0);
      var $123=HEAP32[(($122)>>2)];
      var $124=(($123)|0)!=0;
      if ($124) { __label__ = 16; break; } else { __label__ = 17; break; }
    case 16: 
      var $126=$encoder;
      var $127=$data;
      var $128=(($127+8)|0);
      var $129=HEAP32[(($128)>>2)];
      var $130=_HPDF_BasicEncoder_OverrideMap($126, $129);
      __label__ = 17; break;
    case 17: 
      var $132=$encoder;
      $1=$132;
      __label__ = 18; break;
    case 18: 
      var $134=$1;
      ;
      return $134;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_BasicEncoder_New["X"]=1;

function _HPDF_BasicEncoder_FindBuiltinData($encoding_name) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $i;
      $1=$encoding_name;
      $i=0;
      __label__ = 3; break;
    case 3: 
      var $3=$i;
      var $4=((_HPDF_BUILTIN_ENCODINGS+($3)*(12))|0);
      var $5=(($4)|0);
      var $6=HEAP32[(($5)>>2)];
      var $7=(($6)|0)!=0;
      if ($7) { __label__ = 4; break; } else { __label__ = 7; break; }
    case 4: 
      var $9=$i;
      var $10=((_HPDF_BUILTIN_ENCODINGS+($9)*(12))|0);
      var $11=(($10)|0);
      var $12=HEAP32[(($11)>>2)];
      var $13=$1;
      var $14=_HPDF_StrCmp($12, $13);
      var $15=(($14)|0)==0;
      if ($15) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      __label__ = 7; break;
    case 6: 
      var $18=$i;
      var $19=((($18)+(1))|0);
      $i=$19;
      __label__ = 3; break;
    case 7: 
      var $21=$i;
      var $22=((_HPDF_BUILTIN_ENCODINGS+($21)*(12))|0);
      ;
      return $22;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_CMapEncoder_Write($encoder, $out) {
  ;
  var __label__;

  var $1;
  var $2;
  var $ret;
  $1=$encoder;
  $2=$out;
  $ret=0;
  var $3=$ret;
  ;
  return $3;
}


function _HPDF_BasicEncoder_CopyMap($encoder, $map) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $i;
      var $dst;
      $1=$encoder;
      $2=$map;
      var $3=$1;
      var $4=(($3+164)|0);
      var $5=HEAP32[(($4)>>2)];
      var $6=$5;
      var $7=(($6+130)|0);
      var $8=(($7)|0);
      var $9=(($8+64)|0);
      $dst=$9;
      $i=0;
      __label__ = 3; break;
    case 3: 
      var $11=$i;
      var $12=(($11)>>>0) <= 223;
      if ($12) { __label__ = 4; break; } else { __label__ = 6; break; }
    case 4: 
      var $14=$2;
      var $15=(($14+2)|0);
      $2=$15;
      var $16=HEAP16[(($14)>>1)];
      var $17=$dst;
      var $18=(($17+2)|0);
      $dst=$18;
      HEAP16[(($17)>>1)]=$16;
      __label__ = 5; break;
    case 5: 
      var $20=$i;
      var $21=((($20)+(1))|0);
      $i=$21;
      __label__ = 3; break;
    case 6: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_UnicodeToGryphName($unicode) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $map;
      $2=$unicode;
      $map=((_HPDF_UNICODE_GRYPH_NAME_MAP)|0);
      __label__ = 3; break;
    case 3: 
      var $4=$map;
      var $5=(($4)|0);
      var $6=HEAPU16[(($5)>>1)];
      var $7=(($6)&65535);
      var $8=$2;
      var $9=(($8)&65535);
      var $10=(($7)|0) <= (($9)|0);
      if ($10) { __label__ = 4; break; } else { __label__ = 7; break; }
    case 4: 
      var $12=$map;
      var $13=(($12)|0);
      var $14=HEAPU16[(($13)>>1)];
      var $15=(($14)&65535);
      var $16=$2;
      var $17=(($16)&65535);
      var $18=(($15)|0)==(($17)|0);
      if ($18) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $20=$map;
      var $21=(($20+4)|0);
      var $22=HEAP32[(($21)>>2)];
      $1=$22;
      __label__ = 8; break;
    case 6: 
      var $24=$map;
      var $25=(($24+8)|0);
      $map=$25;
      __label__ = 3; break;
    case 7: 
      var $27=HEAP32[((((_HPDF_UNICODE_GRYPH_NAME_MAP+4)|0))>>2)];
      $1=$27;
      __label__ = 8; break;
    case 8: 
      var $29=$1;
      ;
      return $29;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Encoder_Validate($encoder) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      $2=$encoder;
      var $3=$2;
      var $4=(($3)|0)!=0;
      if ($4) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $6=$2;
      var $7=(($6)|0);
      var $8=HEAP32[(($7)>>2)];
      var $9=(($8)|0)!=1162756932;
      if ($9) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      $1=0;
      __label__ = 6; break;
    case 5: 
      $1=1;
      __label__ = 6; break;
    case 6: 
      var $13=$1;
      ;
      return $13;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_CMapEncoder_ToUnicode($encoder, $code) {
  ;
  var __label__;

  var $1;
  var $2;
  var $l;
  var $h;
  var $attr;
  $1=$encoder;
  $2=$code;
  var $3=$2;
  var $4=(($3) & 255);
  $l=$4;
  var $5=$2;
  var $6=(($5)&65535);
  var $7=$6 >> 8;
  var $8=(($7) & 255);
  $h=$8;
  var $9=$1;
  var $10=(($9+164)|0);
  var $11=HEAP32[(($10)>>2)];
  var $12=$11;
  $attr=$12;
  var $13=$h;
  var $14=(($13)&255);
  var $15=$l;
  var $16=(($15)&255);
  var $17=$attr;
  var $18=(($17)|0);
  var $19=(($18+($16<<9))|0);
  var $20=(($19+($14<<1))|0);
  var $21=HEAP16[(($20)>>1)];
  ;
  return $21;
}


function _HPDF_BasicEncoder_Write($encoder, $out) {
  var __stackBase__  = STACKTOP; STACKTOP += 256; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $ret;
      var $attr;
      var $i;
      var $tmp=__stackBase__;
      var $ptmp;
      var $char_name;
      $2=$encoder;
      $3=$out;
      var $4=$2;
      var $5=(($4+164)|0);
      var $6=HEAP32[(($5)>>2)];
      var $7=$6;
      $attr=$7;
      var $8=$attr;
      var $9=(($8)|0);
      var $10=(($9)|0);
      var $11=_HPDF_StrCmp($10, ((STRING_TABLE.__str3652)|0));
      var $12=(($11)|0)==0;
      if ($12) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      $1=0;
      __label__ = 28; break;
    case 4: 
      var $15=$attr;
      var $16=(($15+644)|0);
      var $17=HEAP32[(($16)>>2)];
      var $18=(($17)|0)==1;
      if ($18) { __label__ = 5; break; } else { __label__ = 8; break; }
    case 5: 
      var $20=$3;
      var $21=_HPDF_Stream_WriteStr($20, ((STRING_TABLE.__str4653)|0));
      $ret=$21;
      var $22=$ret;
      var $23=(($22)|0)!=0;
      if ($23) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      var $25=$ret;
      $1=$25;
      __label__ = 28; break;
    case 7: 
      __label__ = 11; break;
    case 8: 
      var $28=$3;
      var $29=_HPDF_Stream_WriteStr($28, ((STRING_TABLE.__str5654)|0));
      $ret=$29;
      var $30=$ret;
      var $31=(($30)|0)!=0;
      if ($31) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      var $33=$ret;
      $1=$33;
      __label__ = 28; break;
    case 10: 
      __label__ = 11; break;
    case 11: 
      var $36=$3;
      var $37=$attr;
      var $38=(($37)|0);
      var $39=(($38)|0);
      var $40=_HPDF_Stream_WriteEscapeName($36, $39);
      $ret=$40;
      var $41=$ret;
      var $42=(($41)|0)!=0;
      if ($42) { __label__ = 12; break; } else { __label__ = 13; break; }
    case 12: 
      var $44=$ret;
      $1=$44;
      __label__ = 28; break;
    case 13: 
      var $46=$3;
      var $47=_HPDF_Stream_WriteStr($46, ((STRING_TABLE.__str6655)|0));
      $ret=$47;
      var $48=$ret;
      var $49=(($48)|0)!=0;
      if ($49) { __label__ = 14; break; } else { __label__ = 15; break; }
    case 14: 
      var $51=$ret;
      $1=$51;
      __label__ = 28; break;
    case 15: 
      var $53=$attr;
      var $54=(($53+644)|0);
      var $55=HEAP32[(($54)>>2)];
      var $56=(($55)|0)==1;
      if ($56) { __label__ = 16; break; } else { __label__ = 27; break; }
    case 16: 
      var $58=$3;
      var $59=_HPDF_Stream_WriteStr($58, ((STRING_TABLE.__str7656)|0));
      $ret=$59;
      var $60=$ret;
      var $61=(($60)|0)!=0;
      if ($61) { __label__ = 17; break; } else { __label__ = 18; break; }
    case 17: 
      var $63=$ret;
      $1=$63;
      __label__ = 28; break;
    case 18: 
      var $65=$attr;
      var $66=(($65+128)|0);
      var $67=HEAPU8[($66)];
      var $68=(($67)&255);
      $i=$68;
      __label__ = 19; break;
    case 19: 
      var $70=$i;
      var $71=$attr;
      var $72=(($71+129)|0);
      var $73=HEAPU8[($72)];
      var $74=(($73)&255);
      var $75=(($70)|0) <= (($74)|0);
      if ($75) { __label__ = 20; break; } else { __label__ = 26; break; }
    case 20: 
      var $77=$i;
      var $78=$attr;
      var $79=(($78+648)|0);
      var $80=(($79+$77)|0);
      var $81=HEAPU8[($80)];
      var $82=(($81)&255);
      var $83=(($82)|0)==1;
      if ($83) { __label__ = 21; break; } else { __label__ = 24; break; }
    case 21: 
      var $85=(($tmp)|0);
      $ptmp=$85;
      var $86=$i;
      var $87=$attr;
      var $88=(($87+130)|0);
      var $89=(($88+($86<<1))|0);
      var $90=HEAP16[(($89)>>1)];
      var $91=_HPDF_UnicodeToGryphName($90);
      $char_name=$91;
      var $92=$ptmp;
      var $93=$i;
      var $94=(($tmp)|0);
      var $95=(($94+512)|0);
      var $96=((($95)-(1))|0);
      var $97=_HPDF_IToA($92, $93, $96);
      $ptmp=$97;
      var $98=$ptmp;
      var $99=(($98+1)|0);
      $ptmp=$99;
      HEAP8[($98)]=32;
      var $100=$ptmp;
      var $101=(($100+1)|0);
      $ptmp=$101;
      HEAP8[($100)]=47;
      var $102=$ptmp;
      var $103=$char_name;
      var $104=(($tmp)|0);
      var $105=(($104+512)|0);
      var $106=((($105)-(1))|0);
      var $107=_HPDF_StrCpy($102, $103, $106);
      $ptmp=$107;
      var $108=$ptmp;
      var $109=(($108+1)|0);
      $ptmp=$109;
      HEAP8[($108)]=32;
      var $110=$ptmp;
      HEAP8[($110)]=0;
      var $111=$3;
      var $112=(($tmp)|0);
      var $113=_HPDF_Stream_WriteStr($111, $112);
      $ret=$113;
      var $114=$ret;
      var $115=(($114)|0)!=0;
      if ($115) { __label__ = 22; break; } else { __label__ = 23; break; }
    case 22: 
      var $117=$ret;
      $1=$117;
      __label__ = 28; break;
    case 23: 
      __label__ = 24; break;
    case 24: 
      __label__ = 25; break;
    case 25: 
      var $121=$i;
      var $122=((($121)+(1))|0);
      $i=$122;
      __label__ = 19; break;
    case 26: 
      var $124=$3;
      var $125=_HPDF_Stream_WriteStr($124, ((STRING_TABLE.__str8657)|0));
      $ret=$125;
      __label__ = 27; break;
    case 27: 
      var $127=$ret;
      $1=$127;
      __label__ = 28; break;
    case 28: 
      var $129=$1;
      STACKTOP = __stackBase__;
      return $129;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_BasicEncoder_Write["X"]=1;

function _HPDF_BasicEncoder_Free($encoder) {
  ;
  var __label__;

  var $1;
  $1=$encoder;
  var $2=$1;
  var $3=(($2+132)|0);
  var $4=HEAP32[(($3)>>2)];
  var $5=$1;
  var $6=(($5+164)|0);
  var $7=HEAP32[(($6)>>2)];
  _HPDF_FreeMem($4, $7);
  var $8=$1;
  var $9=(($8+164)|0);
  HEAP32[(($9)>>2)]=0;
  ;
  return;
}


function _HPDF_BasicEncoder_OverrideMap($encoder, $map) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $i;
      var $data;
      var $dst;
      var $flgs;
      $2=$encoder;
      $3=$map;
      var $4=$2;
      var $5=(($4+164)|0);
      var $6=HEAP32[(($5)>>2)];
      var $7=$6;
      $data=$7;
      var $8=$data;
      var $9=(($8+644)|0);
      var $10=HEAP32[(($9)>>2)];
      var $11=(($10)|0)!=0;
      if ($11) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $13=$2;
      var $14=(($13+136)|0);
      var $15=HEAP32[(($14)>>2)];
      var $16=_HPDF_SetError($15, 4149, 0);
      $1=$16;
      __label__ = 11; break;
    case 4: 
      var $18=$data;
      var $19=(($18+130)|0);
      var $20=(($19)|0);
      var $21=(($20+64)|0);
      $dst=$21;
      var $22=$data;
      var $23=(($22+648)|0);
      var $24=(($23)|0);
      var $25=(($24+32)|0);
      $flgs=$25;
      $i=0;
      __label__ = 5; break;
    case 5: 
      var $27=$i;
      var $28=(($27)>>>0) <= 223;
      if ($28) { __label__ = 6; break; } else { __label__ = 10; break; }
    case 6: 
      var $30=$3;
      var $31=HEAPU16[(($30)>>1)];
      var $32=(($31)&65535);
      var $33=$dst;
      var $34=HEAPU16[(($33)>>1)];
      var $35=(($34)&65535);
      var $36=(($32)|0)!=(($35)|0);
      if ($36) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $38=$3;
      var $39=HEAP16[(($38)>>1)];
      var $40=$dst;
      HEAP16[(($40)>>1)]=$39;
      var $41=$flgs;
      HEAP8[($41)]=1;
      __label__ = 8; break;
    case 8: 
      var $43=$3;
      var $44=(($43+2)|0);
      $3=$44;
      var $45=$dst;
      var $46=(($45+2)|0);
      $dst=$46;
      var $47=$flgs;
      var $48=(($47+1)|0);
      $flgs=$48;
      __label__ = 9; break;
    case 9: 
      var $50=$i;
      var $51=((($50)+(1))|0);
      $i=$51;
      __label__ = 5; break;
    case 10: 
      var $53=$data;
      var $54=(($53+644)|0);
      HEAP32[(($54)>>2)]=1;
      $1=0;
      __label__ = 11; break;
    case 11: 
      var $56=$1;
      ;
      return $56;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_BasicEncoder_OverrideMap["X"]=1;

function _HPDF_Encoder_ToUnicode($encoder, $code) {
  ;
  var __label__;

  var $1;
  var $2;
  $1=$encoder;
  $2=$code;
  var $3=$1;
  var $4=(($3+148)|0);
  var $5=HEAP32[(($4)>>2)];
  var $6=$1;
  var $7=$2;
  var $8=FUNCTION_TABLE[$5]($6, $7);
  ;
  return $8;
}


function _HPDF_Encoder_Free($encoder) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      $1=$encoder;
      var $2=$1;
      var $3=(($2)|0)!=0;
      if ($3) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      __label__ = 7; break;
    case 4: 
      var $6=$1;
      var $7=(($6+156)|0);
      var $8=HEAP32[(($7)>>2)];
      var $9=(($8)|0)!=0;
      if ($9) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $11=$1;
      var $12=(($11+156)|0);
      var $13=HEAP32[(($12)>>2)];
      var $14=$1;
      FUNCTION_TABLE[$13]($14);
      __label__ = 6; break;
    case 6: 
      var $16=$1;
      var $17=(($16+132)|0);
      var $18=HEAP32[(($17)>>2)];
      var $19=$1;
      var $20=$19;
      _HPDF_FreeMem($18, $20);
      __label__ = 7; break;
    case 7: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_GryphNameToUnicode($gryph_name) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $map;
      $2=$gryph_name;
      $map=((_HPDF_UNICODE_GRYPH_NAME_MAP)|0);
      __label__ = 3; break;
    case 3: 
      var $4=$map;
      var $5=(($4)|0);
      var $6=HEAPU16[(($5)>>1)];
      var $7=(($6)&65535);
      var $8=(($7)|0)!=65535;
      if ($8) { __label__ = 4; break; } else { __label__ = 7; break; }
    case 4: 
      var $10=$2;
      var $11=$map;
      var $12=(($11+4)|0);
      var $13=HEAP32[(($12)>>2)];
      var $14=_HPDF_StrCmp($10, $13);
      var $15=(($14)|0)==0;
      if ($15) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $17=$map;
      var $18=(($17)|0);
      var $19=HEAP16[(($18)>>1)];
      $1=$19;
      __label__ = 8; break;
    case 6: 
      var $21=$map;
      var $22=(($21+8)|0);
      $map=$22;
      __label__ = 3; break;
    case 7: 
      $1=0;
      __label__ = 8; break;
    case 8: 
      var $25=$1;
      ;
      return $25;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_CMapEncoder_New($mmgr, $name, $init_fn) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $encoder;
      $2=$mmgr;
      $3=$name;
      $4=$init_fn;
      var $5=$2;
      var $6=(($5)|0)==0;
      if ($6) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      $1=0;
      __label__ = 7; break;
    case 4: 
      var $9=$2;
      var $10=_HPDF_GetMem($9, 168);
      var $11=$10;
      $encoder=$11;
      var $12=$encoder;
      var $13=(($12)|0)!=0;
      if ($13) { __label__ = 6; break; } else { __label__ = 5; break; }
    case 5: 
      $1=0;
      __label__ = 7; break;
    case 6: 
      var $16=$encoder;
      var $17=$16;
      var $18=_HPDF_MemSet($17, 0, 168);
      var $19=$encoder;
      var $20=(($19+4)|0);
      var $21=(($20)|0);
      var $22=$3;
      var $23=$encoder;
      var $24=(($23+4)|0);
      var $25=(($24)|0);
      var $26=(($25+127)|0);
      var $27=_HPDF_StrCpy($21, $22, $26);
      var $28=$2;
      var $29=$encoder;
      var $30=(($29+132)|0);
      HEAP32[(($30)>>2)]=$28;
      var $31=$2;
      var $32=(($31)|0);
      var $33=HEAP32[(($32)>>2)];
      var $34=$encoder;
      var $35=(($34+136)|0);
      HEAP32[(($35)>>2)]=$33;
      var $36=$encoder;
      var $37=(($36+140)|0);
      HEAP32[(($37)>>2)]=2;
      var $38=$encoder;
      var $39=(($38+144)|0);
      HEAP32[(($39)>>2)]=20;
      var $40=$encoder;
      var $41=(($40+148)|0);
      HEAP32[(($41)>>2)]=22;
      var $42=$encoder;
      var $43=(($42+152)|0);
      HEAP32[(($43)>>2)]=24;
      var $44=$encoder;
      var $45=(($44+156)|0);
      HEAP32[(($45)>>2)]=26;
      var $46=$4;
      var $47=$encoder;
      var $48=(($47+160)|0);
      HEAP32[(($48)>>2)]=$46;
      var $49=$encoder;
      var $50=(($49)|0);
      HEAP32[(($50)>>2)]=1162756932;
      var $51=$encoder;
      $1=$51;
      __label__ = 7; break;
    case 7: 
      var $53=$1;
      ;
      return $53;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_CMapEncoder_New["X"]=1;

function _HPDF_CMapEncoder_ByteType($encoder, $state) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $attr;
      $2=$encoder;
      $3=$state;
      var $4=$2;
      var $5=(($4+164)|0);
      var $6=HEAP32[(($5)>>2)];
      var $7=$6;
      $attr=$7;
      var $8=$3;
      var $9=(($8+4)|0);
      var $10=HEAPU32[(($9)>>2)];
      var $11=$3;
      var $12=(($11+8)|0);
      var $13=HEAPU32[(($12)>>2)];
      var $14=(($10)>>>0) >= (($13)>>>0);
      if ($14) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      $1=3;
      __label__ = 14; break;
    case 4: 
      var $17=$3;
      var $18=(($17+12)|0);
      var $19=HEAP32[(($18)>>2)];
      var $20=(($19)|0)==1;
      if ($20) { __label__ = 5; break; } else { __label__ = 9; break; }
    case 5: 
      var $22=$attr;
      var $23=(($22+262680)|0);
      var $24=HEAP32[(($23)>>2)];
      var $25=$2;
      var $26=$3;
      var $27=(($26+4)|0);
      var $28=HEAP32[(($27)>>2)];
      var $29=$3;
      var $30=(($29)|0);
      var $31=HEAP32[(($30)>>2)];
      var $32=(($31+$28)|0);
      var $33=HEAP8[($32)];
      var $34=FUNCTION_TABLE[$24]($25, $33);
      var $35=(($34)|0)!=0;
      if ($35) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      var $37=$3;
      var $38=(($37+12)|0);
      HEAP32[(($38)>>2)]=2;
      __label__ = 8; break;
    case 7: 
      var $40=$3;
      var $41=(($40+12)|0);
      HEAP32[(($41)>>2)]=3;
      __label__ = 8; break;
    case 8: 
      __label__ = 13; break;
    case 9: 
      var $44=$attr;
      var $45=(($44+262676)|0);
      var $46=HEAP32[(($45)>>2)];
      var $47=$2;
      var $48=$3;
      var $49=(($48+4)|0);
      var $50=HEAP32[(($49)>>2)];
      var $51=$3;
      var $52=(($51)|0);
      var $53=HEAP32[(($52)>>2)];
      var $54=(($53+$50)|0);
      var $55=HEAP8[($54)];
      var $56=FUNCTION_TABLE[$46]($47, $55);
      var $57=(($56)|0)!=0;
      if ($57) { __label__ = 10; break; } else { __label__ = 11; break; }
    case 10: 
      var $59=$3;
      var $60=(($59+12)|0);
      HEAP32[(($60)>>2)]=1;
      __label__ = 12; break;
    case 11: 
      var $62=$3;
      var $63=(($62+12)|0);
      HEAP32[(($63)>>2)]=0;
      __label__ = 12; break;
    case 12: 
      __label__ = 13; break;
    case 13: 
      var $66=$3;
      var $67=(($66+4)|0);
      var $68=HEAP32[(($67)>>2)];
      var $69=((($68)+(1))|0);
      HEAP32[(($67)>>2)]=$69;
      var $70=$3;
      var $71=(($70+12)|0);
      var $72=HEAP32[(($71)>>2)];
      $1=$72;
      __label__ = 14; break;
    case 14: 
      var $74=$1;
      ;
      return $74;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_CMapEncoder_ByteType["X"]=1;

function _HPDF_CMapEncoder_Free($encoder) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $attr;
      var $i;
      var $data;
      $1=$encoder;
      var $2=$1;
      var $3=(($2+164)|0);
      var $4=HEAP32[(($3)>>2)];
      var $5=$4;
      $attr=$5;
      var $6=$attr;
      var $7=(($6)|0)!=0;
      if ($7) { __label__ = 3; break; } else { __label__ = 9; break; }
    case 3: 
      var $9=$attr;
      var $10=(($9+262400)|0);
      var $11=HEAP32[(($10)>>2)];
      var $12=(($11)|0)!=0;
      if ($12) { __label__ = 4; break; } else { __label__ = 9; break; }
    case 4: 
      $i=0;
      __label__ = 5; break;
    case 5: 
      var $15=$i;
      var $16=$attr;
      var $17=(($16+262400)|0);
      var $18=HEAP32[(($17)>>2)];
      var $19=(($18+16)|0);
      var $20=HEAPU32[(($19)>>2)];
      var $21=(($15)>>>0) < (($20)>>>0);
      if ($21) { __label__ = 6; break; } else { __label__ = 8; break; }
    case 6: 
      var $23=$attr;
      var $24=(($23+262400)|0);
      var $25=HEAP32[(($24)>>2)];
      var $26=$i;
      var $27=_HPDF_List_ItemAt($25, $26);
      var $28=$27;
      $data=$28;
      var $29=$1;
      var $30=(($29+132)|0);
      var $31=HEAP32[(($30)>>2)];
      var $32=$data;
      var $33=$32;
      _HPDF_FreeMem($31, $33);
      __label__ = 7; break;
    case 7: 
      var $35=$i;
      var $36=((($35)+(1))|0);
      $i=$36;
      __label__ = 5; break;
    case 8: 
      var $38=$attr;
      var $39=(($38+262400)|0);
      var $40=HEAP32[(($39)>>2)];
      _HPDF_List_Free($40);
      __label__ = 9; break;
    case 9: 
      var $42=$attr;
      var $43=(($42)|0)!=0;
      if ($43) { __label__ = 10; break; } else { __label__ = 16; break; }
    case 10: 
      var $45=$attr;
      var $46=(($45+262404)|0);
      var $47=HEAP32[(($46)>>2)];
      var $48=(($47)|0)!=0;
      if ($48) { __label__ = 11; break; } else { __label__ = 16; break; }
    case 11: 
      $i=0;
      __label__ = 12; break;
    case 12: 
      var $51=$i;
      var $52=$attr;
      var $53=(($52+262404)|0);
      var $54=HEAP32[(($53)>>2)];
      var $55=(($54+16)|0);
      var $56=HEAPU32[(($55)>>2)];
      var $57=(($51)>>>0) < (($56)>>>0);
      if ($57) { __label__ = 13; break; } else { __label__ = 15; break; }
    case 13: 
      var $59=$attr;
      var $60=(($59+262404)|0);
      var $61=HEAP32[(($60)>>2)];
      var $62=$i;
      var $63=_HPDF_List_ItemAt($61, $62);
      var $64=$63;
      $data=$64;
      var $65=$1;
      var $66=(($65+132)|0);
      var $67=HEAP32[(($66)>>2)];
      var $68=$data;
      var $69=$68;
      _HPDF_FreeMem($67, $69);
      __label__ = 14; break;
    case 14: 
      var $71=$i;
      var $72=((($71)+(1))|0);
      $i=$72;
      __label__ = 12; break;
    case 15: 
      var $74=$attr;
      var $75=(($74+262404)|0);
      var $76=HEAP32[(($75)>>2)];
      _HPDF_List_Free($76);
      __label__ = 16; break;
    case 16: 
      var $78=$attr;
      var $79=(($78)|0)!=0;
      if ($79) { __label__ = 17; break; } else { __label__ = 23; break; }
    case 17: 
      var $81=$attr;
      var $82=(($81+262408)|0);
      var $83=HEAP32[(($82)>>2)];
      var $84=(($83)|0)!=0;
      if ($84) { __label__ = 18; break; } else { __label__ = 23; break; }
    case 18: 
      $i=0;
      __label__ = 19; break;
    case 19: 
      var $87=$i;
      var $88=$attr;
      var $89=(($88+262408)|0);
      var $90=HEAP32[(($89)>>2)];
      var $91=(($90+16)|0);
      var $92=HEAPU32[(($91)>>2)];
      var $93=(($87)>>>0) < (($92)>>>0);
      if ($93) { __label__ = 20; break; } else { __label__ = 22; break; }
    case 20: 
      var $95=$attr;
      var $96=(($95+262408)|0);
      var $97=HEAP32[(($96)>>2)];
      var $98=$i;
      var $99=_HPDF_List_ItemAt($97, $98);
      var $100=$99;
      $data=$100;
      var $101=$1;
      var $102=(($101+132)|0);
      var $103=HEAP32[(($102)>>2)];
      var $104=$data;
      var $105=$104;
      _HPDF_FreeMem($103, $105);
      __label__ = 21; break;
    case 21: 
      var $107=$i;
      var $108=((($107)+(1))|0);
      $i=$108;
      __label__ = 19; break;
    case 22: 
      var $110=$attr;
      var $111=(($110+262408)|0);
      var $112=HEAP32[(($111)>>2)];
      _HPDF_List_Free($112);
      __label__ = 23; break;
    case 23: 
      var $114=$1;
      var $115=(($114+132)|0);
      var $116=HEAP32[(($115)>>2)];
      var $117=$1;
      var $118=(($117+164)|0);
      var $119=HEAP32[(($118)>>2)];
      _HPDF_FreeMem($116, $119);
      var $120=$1;
      var $121=(($120+164)|0);
      HEAP32[(($121)>>2)]=0;
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_CMapEncoder_Free["X"]=1;

function _HPDF_CMapEncoder_ToCID($encoder, $code) {
  ;
  var __label__;

  var $1;
  var $2;
  var $l;
  var $h;
  var $attr;
  $1=$encoder;
  $2=$code;
  var $3=$2;
  var $4=(($3) & 255);
  $l=$4;
  var $5=$2;
  var $6=(($5)&65535);
  var $7=$6 >> 8;
  var $8=(($7) & 255);
  $h=$8;
  var $9=$1;
  var $10=(($9+164)|0);
  var $11=HEAP32[(($10)>>2)];
  var $12=$11;
  $attr=$12;
  var $13=$h;
  var $14=(($13)&255);
  var $15=$l;
  var $16=(($15)&255);
  var $17=$attr;
  var $18=(($17+131072)|0);
  var $19=(($18+($16<<9))|0);
  var $20=(($19+($14<<1))|0);
  var $21=HEAP16[(($20)>>1)];
  ;
  return $21;
}


function _HPDF_Encoder_SetParseText($encoder, $state, $text, $len) {
  ;
  var __label__;

  var $1;
  var $2;
  var $3;
  var $4;
  $1=$encoder;
  $2=$state;
  $3=$text;
  $4=$len;
  var $5=$3;
  var $6=$2;
  var $7=(($6)|0);
  HEAP32[(($7)>>2)]=$5;
  var $8=$2;
  var $9=(($8+4)|0);
  HEAP32[(($9)>>2)]=0;
  var $10=$4;
  var $11=$2;
  var $12=(($11+8)|0);
  HEAP32[(($12)>>2)]=$10;
  var $13=$2;
  var $14=(($13+12)|0);
  HEAP32[(($14)>>2)]=0;
  ;
  return;
}


function _HPDF_CMapEncoder_SetUnicodeArray($encoder, $array) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $attr;
      var $l;
      var $h;
      $1=$encoder;
      $2=$array;
      var $3=$1;
      var $4=(($3+164)|0);
      var $5=HEAP32[(($4)>>2)];
      var $6=$5;
      $attr=$6;
      var $7=$2;
      var $8=(($7)|0)!=0;
      if ($8) { __label__ = 3; break; } else { __label__ = 7; break; }
    case 3: 
      __label__ = 4; break;
    case 4: 
      var $11=$2;
      var $12=(($11+2)|0);
      var $13=HEAPU16[(($12)>>1)];
      var $14=(($13)&65535);
      var $15=(($14)|0)!=65535;
      if ($15) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $17=$2;
      var $18=(($17)|0);
      var $19=HEAP16[(($18)>>1)];
      var $20=(($19) & 255);
      $l=$20;
      var $21=$2;
      var $22=(($21)|0);
      var $23=HEAPU16[(($22)>>1)];
      var $24=(($23)&65535);
      var $25=$24 >> 8;
      var $26=(($25) & 255);
      $h=$26;
      var $27=$2;
      var $28=(($27+2)|0);
      var $29=HEAP16[(($28)>>1)];
      var $30=$h;
      var $31=(($30)&255);
      var $32=$l;
      var $33=(($32)&255);
      var $34=$attr;
      var $35=(($34)|0);
      var $36=(($35+($33<<9))|0);
      var $37=(($36+($31<<1))|0);
      HEAP16[(($37)>>1)]=$29;
      var $38=$2;
      var $39=(($38+4)|0);
      $2=$39;
      __label__ = 4; break;
    case 6: 
      __label__ = 7; break;
    case 7: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_CMapEncoder_SetUnicodeArray["X"]=1;

function _HPDF_CMapEncoder_InitAttr($encoder) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $encoder_attr;
      var $i;
      var $j;
      $2=$encoder;
      var $3=$2;
      var $4=(($3+164)|0);
      var $5=HEAP32[(($4)>>2)];
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      $1=4135;
      __label__ = 21; break;
    case 4: 
      var $9=$2;
      var $10=(($9+132)|0);
      var $11=HEAP32[(($10)>>2)];
      var $12=_HPDF_GetMem($11, 262700);
      var $13=$12;
      $encoder_attr=$13;
      var $14=$encoder_attr;
      var $15=(($14)|0)!=0;
      if ($15) { __label__ = 6; break; } else { __label__ = 5; break; }
    case 5: 
      var $17=$2;
      var $18=(($17+136)|0);
      var $19=HEAP32[(($18)>>2)];
      var $20=(($19)|0);
      var $21=HEAP32[(($20)>>2)];
      $1=$21;
      __label__ = 21; break;
    case 6: 
      var $23=$encoder_attr;
      var $24=$23;
      var $25=_HPDF_MemSet($24, 0, 262700);
      var $26=$encoder_attr;
      var $27=$26;
      var $28=$2;
      var $29=(($28+164)|0);
      HEAP32[(($29)>>2)]=$27;
      var $30=$encoder_attr;
      var $31=(($30+262412)|0);
      HEAP32[(($31)>>2)]=0;
      $i=0;
      __label__ = 7; break;
    case 7: 
      var $33=$i;
      var $34=(($33)>>>0) <= 255;
      if ($34) { __label__ = 8; break; } else { __label__ = 14; break; }
    case 8: 
      $j=0;
      __label__ = 9; break;
    case 9: 
      var $37=$j;
      var $38=(($37)>>>0) <= 255;
      if ($38) { __label__ = 10; break; } else { __label__ = 12; break; }
    case 10: 
      var $40=$j;
      var $41=$i;
      var $42=$encoder_attr;
      var $43=(($42)|0);
      var $44=(($43+($41<<9))|0);
      var $45=(($44+($40<<1))|0);
      HEAP16[(($45)>>1)]=9633;
      __label__ = 11; break;
    case 11: 
      var $47=$j;
      var $48=((($47)+(1))|0);
      $j=$48;
      __label__ = 9; break;
    case 12: 
      __label__ = 13; break;
    case 13: 
      var $51=$i;
      var $52=((($51)+(1))|0);
      $i=$52;
      __label__ = 7; break;
    case 14: 
      var $54=$2;
      var $55=(($54+132)|0);
      var $56=HEAP32[(($55)>>2)];
      var $57=_HPDF_List_New($56, 128);
      var $58=$encoder_attr;
      var $59=(($58+262400)|0);
      HEAP32[(($59)>>2)]=$57;
      var $60=$encoder_attr;
      var $61=(($60+262400)|0);
      var $62=HEAP32[(($61)>>2)];
      var $63=(($62)|0)!=0;
      if ($63) { __label__ = 16; break; } else { __label__ = 15; break; }
    case 15: 
      var $65=$2;
      var $66=(($65+136)|0);
      var $67=HEAP32[(($66)>>2)];
      var $68=(($67)|0);
      var $69=HEAP32[(($68)>>2)];
      $1=$69;
      __label__ = 21; break;
    case 16: 
      var $71=$2;
      var $72=(($71+132)|0);
      var $73=HEAP32[(($72)>>2)];
      var $74=_HPDF_List_New($73, 20);
      var $75=$encoder_attr;
      var $76=(($75+262404)|0);
      HEAP32[(($76)>>2)]=$74;
      var $77=$encoder_attr;
      var $78=(($77+262404)|0);
      var $79=HEAP32[(($78)>>2)];
      var $80=(($79)|0)!=0;
      if ($80) { __label__ = 18; break; } else { __label__ = 17; break; }
    case 17: 
      var $82=$2;
      var $83=(($82+136)|0);
      var $84=HEAP32[(($83)>>2)];
      var $85=(($84)|0);
      var $86=HEAP32[(($85)>>2)];
      $1=$86;
      __label__ = 21; break;
    case 18: 
      var $88=$2;
      var $89=(($88+132)|0);
      var $90=HEAP32[(($89)>>2)];
      var $91=_HPDF_List_New($90, 20);
      var $92=$encoder_attr;
      var $93=(($92+262408)|0);
      HEAP32[(($93)>>2)]=$91;
      var $94=$encoder_attr;
      var $95=(($94+262408)|0);
      var $96=HEAP32[(($95)>>2)];
      var $97=(($96)|0)!=0;
      if ($97) { __label__ = 20; break; } else { __label__ = 19; break; }
    case 19: 
      var $99=$2;
      var $100=(($99+136)|0);
      var $101=HEAP32[(($100)>>2)];
      var $102=(($101)|0);
      var $103=HEAP32[(($102)>>2)];
      $1=$103;
      __label__ = 21; break;
    case 20: 
      $1=0;
      __label__ = 21; break;
    case 21: 
      var $106=$1;
      ;
      return $106;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_CMapEncoder_InitAttr["X"]=1;

function _HPDF_Encoder_ByteType($encoder, $state) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      $2=$encoder;
      $3=$state;
      var $4=$2;
      var $5=(($4+144)|0);
      var $6=HEAP32[(($5)>>2)];
      var $7=(($6)|0)!=0;
      if ($7) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $9=$2;
      var $10=(($9+144)|0);
      var $11=HEAP32[(($10)>>2)];
      var $12=$2;
      var $13=$3;
      var $14=FUNCTION_TABLE[$11]($12, $13);
      $1=$14;
      __label__ = 5; break;
    case 4: 
      $1=0;
      __label__ = 5; break;
    case 5: 
      var $17=$1;
      ;
      return $17;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_CMapEncoder_AddCMap($encoder, $range) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $attr;
      var $code;
      var $cid;
      var $prange;
      var $ret;
      var $l;
      var $h;
      $2=$encoder;
      $3=$range;
      var $4=$2;
      var $5=(($4+164)|0);
      var $6=HEAP32[(($5)>>2)];
      var $7=$6;
      $attr=$7;
      __label__ = 3; break;
    case 3: 
      var $9=$3;
      var $10=(($9)|0);
      var $11=HEAPU16[(($10)>>1)];
      var $12=(($11)&65535);
      var $13=(($12)|0)!=65535;
      if ($13) { __label__ = 4; break; } else { var $21 = 0;__label__ = 5; break; }
    case 4: 
      var $15=$3;
      var $16=(($15+2)|0);
      var $17=HEAPU16[(($16)>>1)];
      var $18=(($17)&65535);
      var $19=(($18)|0)!=65535;
      var $21 = $19;__label__ = 5; break;
    case 5: 
      var $21;
      if ($21) { __label__ = 6; break; } else { __label__ = 14; break; }
    case 6: 
      var $23=$3;
      var $24=(($23)|0);
      var $25=HEAP16[(($24)>>1)];
      $code=$25;
      var $26=$3;
      var $27=(($26+4)|0);
      var $28=HEAP16[(($27)>>1)];
      $cid=$28;
      __label__ = 7; break;
    case 7: 
      var $30=$code;
      var $31=(($30)&65535);
      var $32=$3;
      var $33=(($32+2)|0);
      var $34=HEAPU16[(($33)>>1)];
      var $35=(($34)&65535);
      var $36=(($31)|0) <= (($35)|0);
      if ($36) { __label__ = 8; break; } else { __label__ = 9; break; }
    case 8: 
      var $38=$code;
      var $39=(($38) & 255);
      $l=$39;
      var $40=$code;
      var $41=(($40)&65535);
      var $42=$41 >> 8;
      var $43=(($42) & 255);
      $h=$43;
      var $44=$cid;
      var $45=$h;
      var $46=(($45)&255);
      var $47=$l;
      var $48=(($47)&255);
      var $49=$attr;
      var $50=(($49+131072)|0);
      var $51=(($50+($48<<9))|0);
      var $52=(($51+($46<<1))|0);
      HEAP16[(($52)>>1)]=$44;
      var $53=$code;
      var $54=((($53)+(1))&65535);
      $code=$54;
      var $55=$cid;
      var $56=((($55)+(1))&65535);
      $cid=$56;
      __label__ = 7; break;
    case 9: 
      var $58=$2;
      var $59=(($58+132)|0);
      var $60=HEAP32[(($59)>>2)];
      var $61=_HPDF_GetMem($60, 6);
      var $62=$61;
      $prange=$62;
      var $63=$prange;
      var $64=(($63)|0)!=0;
      if ($64) { __label__ = 11; break; } else { __label__ = 10; break; }
    case 10: 
      var $66=$2;
      var $67=(($66+136)|0);
      var $68=HEAP32[(($67)>>2)];
      var $69=(($68)|0);
      var $70=HEAP32[(($69)>>2)];
      $1=$70;
      __label__ = 15; break;
    case 11: 
      var $72=$3;
      var $73=(($72)|0);
      var $74=HEAP16[(($73)>>1)];
      var $75=$prange;
      var $76=(($75)|0);
      HEAP16[(($76)>>1)]=$74;
      var $77=$3;
      var $78=(($77+2)|0);
      var $79=HEAP16[(($78)>>1)];
      var $80=$prange;
      var $81=(($80+2)|0);
      HEAP16[(($81)>>1)]=$79;
      var $82=$3;
      var $83=(($82+4)|0);
      var $84=HEAP16[(($83)>>1)];
      var $85=$prange;
      var $86=(($85+4)|0);
      HEAP16[(($86)>>1)]=$84;
      var $87=$attr;
      var $88=(($87+262400)|0);
      var $89=HEAP32[(($88)>>2)];
      var $90=$prange;
      var $91=$90;
      var $92=_HPDF_List_Add($89, $91);
      $ret=$92;
      var $93=(($92)|0)!=0;
      if ($93) { __label__ = 12; break; } else { __label__ = 13; break; }
    case 12: 
      var $95=$2;
      var $96=(($95+132)|0);
      var $97=HEAP32[(($96)>>2)];
      var $98=$prange;
      var $99=$98;
      _HPDF_FreeMem($97, $99);
      var $100=$ret;
      $1=$100;
      __label__ = 15; break;
    case 13: 
      var $102=$3;
      var $103=(($102+6)|0);
      $3=$103;
      __label__ = 3; break;
    case 14: 
      $1=0;
      __label__ = 15; break;
    case 15: 
      var $106=$1;
      ;
      return $106;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_CMapEncoder_AddCMap["X"]=1;

function _HPDF_CMapEncoder_AddNotDefRange($encoder, $range) {
  var __stackBase__  = STACKTOP; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var tempParam = $range; $range = STACKTOP;STACKTOP += 6;STACKTOP = ((((STACKTOP)+3)>>2)<<2);assert(STACKTOP < STACK_ROOT + STACK_MAX, "Ran out of stack");HEAP32[(($range)>>2)]=HEAP32[((tempParam)>>2)];HEAP16[((($range)+(4))>>1)]=HEAP16[(((tempParam)+(4))>>1)];
  var __label__;

  var $1;
  var $attr;
  $1=$encoder;
  var $2=$1;
  var $3=(($2+164)|0);
  var $4=HEAP32[(($3)>>2)];
  var $5=$4;
  $attr=$5;
  var $6=$1;
  var $7=(($6+132)|0);
  var $8=HEAP32[(($7)>>2)];
  var $9=$attr;
  var $10=(($9+262404)|0);
  var $11=HEAP32[(($10)>>2)];
  var $12=_AddCidRainge($8, $range, $11);
  STACKTOP = __stackBase__;
  return $12;
}


function _AddCidRainge($mmgr, $range, $target) {
  var __stackBase__  = STACKTOP; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var tempParam = $range; $range = STACKTOP;STACKTOP += 6;STACKTOP = ((((STACKTOP)+3)>>2)<<2);assert(STACKTOP < STACK_ROOT + STACK_MAX, "Ran out of stack");HEAP32[(($range)>>2)]=HEAP32[((tempParam)>>2)];HEAP16[((($range)+(4))>>1)]=HEAP16[(((tempParam)+(4))>>1)];
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $prange;
      var $ret;
      $2=$mmgr;
      $3=$target;
      var $4=$2;
      var $5=_HPDF_GetMem($4, 6);
      var $6=$5;
      $prange=$6;
      var $7=$prange;
      var $8=(($7)|0)!=0;
      if ($8) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      var $10=$2;
      var $11=(($10)|0);
      var $12=HEAP32[(($11)>>2)];
      var $13=(($12)|0);
      var $14=HEAP32[(($13)>>2)];
      $1=$14;
      __label__ = 7; break;
    case 4: 
      var $16=(($range)|0);
      var $17=HEAP16[(($16)>>1)];
      var $18=$prange;
      var $19=(($18)|0);
      HEAP16[(($19)>>1)]=$17;
      var $20=(($range+2)|0);
      var $21=HEAP16[(($20)>>1)];
      var $22=$prange;
      var $23=(($22+2)|0);
      HEAP16[(($23)>>1)]=$21;
      var $24=(($range+4)|0);
      var $25=HEAP16[(($24)>>1)];
      var $26=$prange;
      var $27=(($26+4)|0);
      HEAP16[(($27)>>1)]=$25;
      var $28=$3;
      var $29=$prange;
      var $30=$29;
      var $31=_HPDF_List_Add($28, $30);
      $ret=$31;
      var $32=(($31)|0)!=0;
      if ($32) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $34=$2;
      var $35=$prange;
      var $36=$35;
      _HPDF_FreeMem($34, $36);
      var $37=$ret;
      $1=$37;
      __label__ = 7; break;
    case 6: 
      $1=0;
      __label__ = 7; break;
    case 7: 
      var $40=$1;
      STACKTOP = __stackBase__;
      return $40;
    default: assert(0, "bad label: " + __label__);
  }
}
_AddCidRainge["X"]=1;

function _HPDF_CMapEncoder_AddCodeSpaceRange($encoder, $range) {
  var __stackBase__  = STACKTOP; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var tempParam = $range; $range = STACKTOP;STACKTOP += 6;STACKTOP = ((((STACKTOP)+3)>>2)<<2);assert(STACKTOP < STACK_ROOT + STACK_MAX, "Ran out of stack");HEAP32[(($range)>>2)]=HEAP32[((tempParam)>>2)];HEAP16[((($range)+(4))>>1)]=HEAP16[(((tempParam)+(4))>>1)];
  var __label__;

  var $1;
  var $attr;
  $1=$encoder;
  var $2=$1;
  var $3=(($2+164)|0);
  var $4=HEAP32[(($3)>>2)];
  var $5=$4;
  $attr=$5;
  var $6=$1;
  var $7=(($6+132)|0);
  var $8=HEAP32[(($7)>>2)];
  var $9=$attr;
  var $10=(($9+262408)|0);
  var $11=HEAP32[(($10)>>2)];
  var $12=_AddCidRainge($8, $range, $11);
  STACKTOP = __stackBase__;
  return $12;
}


function _HPDF_CMapEncoder_AddJWWLineHead($encoder, $code) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $attr;
      var $i;
      var $j;
      $2=$encoder;
      $3=$code;
      var $4=$2;
      var $5=(($4+164)|0);
      var $6=HEAP32[(($5)>>2)];
      var $7=$6;
      $attr=$7;
      $i=0;
      __label__ = 3; break;
    case 3: 
      var $9=$i;
      var $10=(($9)>>>0) < 128;
      if ($10) { __label__ = 4; break; } else { __label__ = 18; break; }
    case 4: 
      var $12=$3;
      var $13=HEAPU16[(($12)>>1)];
      var $14=(($13)&65535);
      var $15=(($14)|0)==0;
      if ($15) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      __label__ = 18; break;
    case 6: 
      $j=0;
      __label__ = 7; break;
    case 7: 
      var $19=$j;
      var $20=(($19)>>>0) < 128;
      if ($20) { __label__ = 8; break; } else { __label__ = 16; break; }
    case 8: 
      var $22=$j;
      var $23=$attr;
      var $24=(($23+262144)|0);
      var $25=(($24+($22<<1))|0);
      var $26=HEAPU16[(($25)>>1)];
      var $27=(($26)&65535);
      var $28=$3;
      var $29=HEAPU16[(($28)>>1)];
      var $30=(($29)&65535);
      var $31=(($27)|0)==(($30)|0);
      if ($31) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      __label__ = 16; break;
    case 10: 
      var $34=$j;
      var $35=$attr;
      var $36=(($35+262144)|0);
      var $37=(($36+($34<<1))|0);
      var $38=HEAPU16[(($37)>>1)];
      var $39=(($38)&65535);
      var $40=(($39)|0)==0;
      if ($40) { __label__ = 11; break; } else { __label__ = 12; break; }
    case 11: 
      var $42=$3;
      var $43=HEAP16[(($42)>>1)];
      var $44=$j;
      var $45=$attr;
      var $46=(($45+262144)|0);
      var $47=(($46+($44<<1))|0);
      HEAP16[(($47)>>1)]=$43;
      __label__ = 16; break;
    case 12: 
      var $49=$j;
      var $50=(($49)|0)==127;
      if ($50) { __label__ = 13; break; } else { __label__ = 14; break; }
    case 13: 
      var $52=$2;
      var $53=(($52+136)|0);
      var $54=HEAP32[(($53)>>2)];
      var $55=$i;
      var $56=_HPDF_SetError($54, 4111, $55);
      $1=$56;
      __label__ = 19; break;
    case 14: 
      __label__ = 15; break;
    case 15: 
      var $59=$j;
      var $60=((($59)+(1))|0);
      $j=$60;
      __label__ = 7; break;
    case 16: 
      var $62=$3;
      var $63=(($62+2)|0);
      $3=$63;
      __label__ = 17; break;
    case 17: 
      var $65=$i;
      var $66=((($65)+(1))|0);
      $i=$66;
      __label__ = 3; break;
    case 18: 
      $1=0;
      __label__ = 19; break;
    case 19: 
      var $69=$1;
      ;
      return $69;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_CMapEncoder_AddJWWLineHead["X"]=1;

function _HPDF_Encoder_CheckJWWLineHead($encoder, $code) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $attr;
      var $j;
      $2=$encoder;
      $3=$code;
      var $4=$2;
      var $5=_HPDF_Encoder_Validate($4);
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=0;
      __label__ = 15; break;
    case 4: 
      var $9=$2;
      var $10=(($9+140)|0);
      var $11=HEAP32[(($10)>>2)];
      var $12=(($11)|0)!=1;
      if ($12) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      $1=0;
      __label__ = 15; break;
    case 6: 
      var $15=$2;
      var $16=(($15+164)|0);
      var $17=HEAP32[(($16)>>2)];
      var $18=$17;
      $attr=$18;
      $j=0;
      __label__ = 7; break;
    case 7: 
      var $20=$j;
      var $21=(($20)>>>0) < 128;
      if ($21) { __label__ = 8; break; } else { __label__ = 14; break; }
    case 8: 
      var $23=$3;
      var $24=(($23)&65535);
      var $25=$j;
      var $26=$attr;
      var $27=(($26+262144)|0);
      var $28=(($27+($25<<1))|0);
      var $29=HEAPU16[(($28)>>1)];
      var $30=(($29)&65535);
      var $31=(($24)|0)==(($30)|0);
      if ($31) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      $1=1;
      __label__ = 15; break;
    case 10: 
      var $34=$j;
      var $35=$attr;
      var $36=(($35+262144)|0);
      var $37=(($36+($34<<1))|0);
      var $38=HEAPU16[(($37)>>1)];
      var $39=(($38)&65535);
      var $40=(($39)|0)==0;
      if ($40) { __label__ = 11; break; } else { __label__ = 12; break; }
    case 11: 
      $1=0;
      __label__ = 15; break;
    case 12: 
      __label__ = 13; break;
    case 13: 
      var $44=$j;
      var $45=((($44)+(1))|0);
      $j=$45;
      __label__ = 7; break;
    case 14: 
      $1=0;
      __label__ = 15; break;
    case 15: 
      var $48=$1;
      ;
      return $48;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Encoder_CheckJWWLineHead["X"]=1;

function _HPDF_Encoder_GetUnicode($encoder, $code) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      $2=$encoder;
      $3=$code;
      var $4=$2;
      var $5=_HPDF_Encoder_Validate($4);
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=0;
      __label__ = 5; break;
    case 4: 
      var $9=$2;
      var $10=$3;
      var $11=_HPDF_Encoder_ToUnicode($9, $10);
      $1=$11;
      __label__ = 5; break;
    case 5: 
      var $13=$1;
      ;
      return $13;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Encoder_GetByteType($encoder, $text, $index) {
  var __stackBase__  = STACKTOP; STACKTOP += 16; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $parse_state=__stackBase__;
      var $btype;
      $2=$encoder;
      $3=$text;
      $4=$index;
      var $5=$2;
      var $6=_HPDF_Encoder_Validate($5);
      var $7=(($6)|0)!=0;
      if ($7) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=3;
      __label__ = 13; break;
    case 4: 
      var $10=$2;
      var $11=(($10+140)|0);
      var $12=HEAP32[(($11)>>2)];
      var $13=(($12)|0)!=1;
      if ($13) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      $1=0;
      __label__ = 13; break;
    case 6: 
      var $16=$2;
      var $17=$3;
      var $18=$4;
      var $19=((($18)+(1))|0);
      _HPDF_Encoder_SetParseText($16, $parse_state, $17, $19);
      __label__ = 7; break;
    case 7: 
      var $21=$2;
      var $22=_HPDF_CMapEncoder_ByteType($21, $parse_state);
      $btype=$22;
      var $23=$4;
      var $24=(($23)|0)==0;
      if ($24) { __label__ = 8; break; } else { __label__ = 9; break; }
    case 8: 
      __label__ = 12; break;
    case 9: 
      var $27=$3;
      var $28=(($27+1)|0);
      $3=$28;
      var $29=$3;
      var $30=HEAP8[($29)];
      var $31=(($30 << 24) >> 24)!=0;
      if ($31) { __label__ = 11; break; } else { __label__ = 10; break; }
    case 10: 
      $1=3;
      __label__ = 13; break;
    case 11: 
      var $34=$4;
      var $35=((($34)-(1))|0);
      $4=$35;
      __label__ = 7; break;
    case 12: 
      var $37=$btype;
      $1=$37;
      __label__ = 13; break;
    case 13: 
      var $39=$1;
      STACKTOP = __stackBase__;
      return $39;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Encoder_GetByteType["X"]=1;

function _HPDF_Encoder_GetType($encoder) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      $2=$encoder;
      var $3=$2;
      var $4=_HPDF_Encoder_Validate($3);
      var $5=(($4)|0)!=0;
      if ($5) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=3;
      __label__ = 5; break;
    case 4: 
      var $8=$2;
      var $9=(($8+140)|0);
      var $10=HEAP32[(($9)>>2)];
      $1=$10;
      __label__ = 5; break;
    case 5: 
      var $12=$1;
      ;
      return $12;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Encoder_GetWritingMode($encoder) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $attr;
      $2=$encoder;
      var $3=$2;
      var $4=_HPDF_Encoder_Validate($3);
      var $5=(($4)|0)!=0;
      if ($5) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=0;
      __label__ = 7; break;
    case 4: 
      var $8=$2;
      var $9=(($8+140)|0);
      var $10=HEAP32[(($9)>>2)];
      var $11=(($10)|0)==1;
      if ($11) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $13=$2;
      var $14=(($13+164)|0);
      var $15=HEAP32[(($14)>>2)];
      var $16=$15;
      $attr=$16;
      var $17=$attr;
      var $18=(($17+262412)|0);
      var $19=HEAP32[(($18)>>2)];
      $1=$19;
      __label__ = 7; break;
    case 6: 
      $1=0;
      __label__ = 7; break;
    case 7: 
      var $22=$1;
      ;
      return $22;
    default: assert(0, "bad label: " + __label__);
  }
}


function _GB_EUC_IsLeadByte($encoder, $b) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      $1=$encoder;
      $2=$b;
      var $3=$2;
      var $4=(($3)&255);
      var $5=(($4)|0) >= 161;
      if ($5) { __label__ = 3; break; } else { var $11 = 0;__label__ = 4; break; }
    case 3: 
      var $7=$2;
      var $8=(($7)&255);
      var $9=(($8)|0) <= 254;
      var $11 = $9;__label__ = 4; break;
    case 4: 
      var $11;
      var $12=(($11)&1);
      ;
      return $12;
    default: assert(0, "bad label: " + __label__);
  }
}


function _GB_EUC_IsTrialByte($encoder, $b) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      $1=$encoder;
      $2=$b;
      var $3=$2;
      var $4=(($3)&255);
      var $5=(($4)|0) >= 161;
      if ($5) { __label__ = 3; break; } else { var $11 = 0;__label__ = 4; break; }
    case 3: 
      var $7=$2;
      var $8=(($7)&255);
      var $9=(($8)|0) <= 254;
      var $11 = $9;__label__ = 4; break;
    case 4: 
      var $11;
      var $12=(($11)&1);
      ;
      return $12;
    default: assert(0, "bad label: " + __label__);
  }
}


function _GBK_EUC_IsLeadByte($encoder, $b) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      $1=$encoder;
      $2=$b;
      var $3=$2;
      var $4=(($3)&255);
      var $5=(($4)|0) >= 129;
      if ($5) { __label__ = 3; break; } else { var $11 = 0;__label__ = 4; break; }
    case 3: 
      var $7=$2;
      var $8=(($7)&255);
      var $9=(($8)|0) <= 254;
      var $11 = $9;__label__ = 4; break;
    case 4: 
      var $11;
      var $12=(($11)&1);
      ;
      return $12;
    default: assert(0, "bad label: " + __label__);
  }
}


function _GBK_EUC_IsTrialByte($encoder, $b) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      $1=$encoder;
      $2=$b;
      var $3=$2;
      var $4=(($3)&255);
      var $5=(($4)|0) >= 64;
      if ($5) { __label__ = 3; break; } else { var $11 = 0;__label__ = 4; break; }
    case 3: 
      var $7=$2;
      var $8=(($7)&255);
      var $9=(($8)|0) <= 254;
      var $11 = $9;__label__ = 4; break;
    case 4: 
      var $11;
      var $12=(($11)&1);
      ;
      return $12;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_UseCNSEncodings($pdf) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $encoder;
      var $ret;
      $2=$pdf;
      var $3=$2;
      var $4=_HPDF_HasDoc($3);
      var $5=(($4)|0)!=0;
      if ($5) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=4133;
      __label__ = 13; break;
    case 4: 
      var $8=$2;
      var $9=(($8+8)|0);
      var $10=HEAP32[(($9)>>2)];
      var $11=_HPDF_CMapEncoder_New($10, ((STRING_TABLE.__str1073)|0), 40);
      $encoder=$11;
      var $12=$2;
      var $13=$encoder;
      var $14=_HPDF_Doc_RegisterEncoder($12, $13);
      $ret=$14;
      var $15=(($14)|0)!=0;
      if ($15) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $17=$ret;
      $1=$17;
      __label__ = 13; break;
    case 6: 
      var $19=$2;
      var $20=(($19+8)|0);
      var $21=HEAP32[(($20)>>2)];
      var $22=_HPDF_CMapEncoder_New($21, ((STRING_TABLE.__str11074)|0), 42);
      $encoder=$22;
      var $23=$2;
      var $24=$encoder;
      var $25=_HPDF_Doc_RegisterEncoder($23, $24);
      $ret=$25;
      var $26=(($25)|0)!=0;
      if ($26) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $28=$ret;
      $1=$28;
      __label__ = 13; break;
    case 8: 
      var $30=$2;
      var $31=(($30+8)|0);
      var $32=HEAP32[(($31)>>2)];
      var $33=_HPDF_CMapEncoder_New($32, ((STRING_TABLE.__str21075)|0), 44);
      $encoder=$33;
      var $34=$2;
      var $35=$encoder;
      var $36=_HPDF_Doc_RegisterEncoder($34, $35);
      $ret=$36;
      var $37=(($36)|0)!=0;
      if ($37) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      var $39=$ret;
      $1=$39;
      __label__ = 13; break;
    case 10: 
      var $41=$2;
      var $42=(($41+8)|0);
      var $43=HEAP32[(($42)>>2)];
      var $44=_HPDF_CMapEncoder_New($43, ((STRING_TABLE.__str31076)|0), 46);
      $encoder=$44;
      var $45=$2;
      var $46=$encoder;
      var $47=_HPDF_Doc_RegisterEncoder($45, $46);
      $ret=$47;
      var $48=(($47)|0)!=0;
      if ($48) { __label__ = 11; break; } else { __label__ = 12; break; }
    case 11: 
      var $50=$ret;
      $1=$50;
      __label__ = 13; break;
    case 12: 
      $1=0;
      __label__ = 13; break;
    case 13: 
      var $53=$1;
      ;
      return $53;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_UseCNSEncodings["X"]=1;

function _GBK_EUC_H_Init($encoder) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $attr;
      var $ret;
      $2=$encoder;
      var $3=$2;
      var $4=_HPDF_CMapEncoder_InitAttr($3);
      $ret=$4;
      var $5=(($4)|0)!=0;
      if ($5) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $7=$ret;
      $1=$7;
      __label__ = 11; break;
    case 4: 
      var $9=$2;
      var $10=(($9+164)|0);
      var $11=HEAP32[(($10)>>2)];
      var $12=$11;
      $attr=$12;
      var $13=$2;
      var $14=_HPDF_CMapEncoder_AddCMap($13, ((_CMAP_ARRAY_GBK_EUC_H)|0));
      var $15=(($14)|0)!=0;
      if ($15) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $17=$2;
      var $18=(($17+136)|0);
      var $19=HEAP32[(($18)>>2)];
      var $20=(($19)|0);
      var $21=HEAP32[(($20)>>2)];
      $1=$21;
      __label__ = 11; break;
    case 6: 
      var $23=$2;
      var $24=_GBK_EUC_AddCodeSpaceRange($23);
      $ret=$24;
      var $25=(($24)|0)!=0;
      if ($25) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $27=$ret;
      $1=$27;
      __label__ = 11; break;
    case 8: 
      var $29=$2;
      var $30=_HPDF_CMapEncoder_AddNotDefRange($29, _GBK_EUC_NOTDEF_RANGE);
      var $31=(($30)|0)!=0;
      if ($31) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      var $33=$2;
      var $34=(($33+136)|0);
      var $35=HEAP32[(($34)>>2)];
      var $36=(($35)|0);
      var $37=HEAP32[(($36)>>2)];
      $1=$37;
      __label__ = 11; break;
    case 10: 
      var $39=$2;
      _HPDF_CMapEncoder_SetUnicodeArray($39, ((_CP936_UNICODE_ARRAY)|0));
      var $40=$attr;
      var $41=(($40+262676)|0);
      HEAP32[(($41)>>2)]=28;
      var $42=$attr;
      var $43=(($42+262680)|0);
      HEAP32[(($43)>>2)]=30;
      var $44=$attr;
      var $45=(($44+262416)|0);
      var $46=(($45)|0);
      var $47=$attr;
      var $48=(($47+262416)|0);
      var $49=(($48)|0);
      var $50=(($49+127)|0);
      var $51=_HPDF_StrCpy($46, ((STRING_TABLE.__str41077)|0), $50);
      var $52=$attr;
      var $53=(($52+262544)|0);
      var $54=(($53)|0);
      var $55=$attr;
      var $56=(($55+262544)|0);
      var $57=(($56)|0);
      var $58=(($57+127)|0);
      var $59=_HPDF_StrCpy($54, ((STRING_TABLE.__str51078)|0), $58);
      var $60=$attr;
      var $61=(($60+262672)|0);
      HEAP32[(($61)>>2)]=2;
      var $62=$attr;
      var $63=(($62+262684)|0);
      HEAP32[(($63)>>2)]=-1;
      var $64=$attr;
      var $65=(($64+262688)|0);
      var $66=(($65)|0);
      HEAP32[(($66)>>2)]=1;
      var $67=$attr;
      var $68=(($67+262688)|0);
      var $69=(($68+4)|0);
      HEAP32[(($69)>>2)]=10;
      var $70=$attr;
      var $71=(($70+262688)|0);
      var $72=(($71+8)|0);
      HEAP32[(($72)>>2)]=25377;
      var $73=$2;
      var $74=(($73+140)|0);
      HEAP32[(($74)>>2)]=1;
      $1=0;
      __label__ = 11; break;
    case 11: 
      var $76=$1;
      ;
      return $76;
    default: assert(0, "bad label: " + __label__);
  }
}
_GBK_EUC_H_Init["X"]=1;

function _GBK_EUC_V_Init($encoder) {
  var __stackBase__  = STACKTOP; STACKTOP += 8; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $attr;
      var $ret;
      var $3=__stackBase__;
      $2=$encoder;
      var $4=$2;
      var $5=_HPDF_CMapEncoder_InitAttr($4);
      $ret=$5;
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $8=$ret;
      $1=$8;
      __label__ = 13; break;
    case 4: 
      var $10=$2;
      var $11=(($10+164)|0);
      var $12=HEAP32[(($11)>>2)];
      var $13=$12;
      $attr=$13;
      var $14=$2;
      var $15=_HPDF_CMapEncoder_AddCMap($14, ((_CMAP_ARRAY_GBK_EUC_H)|0));
      $ret=$15;
      var $16=(($15)|0)!=0;
      if ($16) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $18=$ret;
      $1=$18;
      __label__ = 13; break;
    case 6: 
      var $20=$2;
      var $21=_HPDF_CMapEncoder_AddCMap($20, ((_CMAP_ARRAY_GBK_EUC_V)|0));
      $ret=$21;
      var $22=(($21)|0)!=0;
      if ($22) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $24=$ret;
      $1=$24;
      __label__ = 13; break;
    case 8: 
      var $26=$2;
      var $27=_GBK_EUC_AddCodeSpaceRange($26);
      $ret=$27;
      var $28=(($27)|0)!=0;
      if ($28) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      var $30=$ret;
      $1=$30;
      __label__ = 13; break;
    case 10: 
      var $32=$2;
      var $33=$3;
      assert(6 % 1 === 0, 'memcpy given ' + 6 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP16[(($33)>>1)]=HEAP16[((_GBK_EUC_NOTDEF_RANGE)>>1)];HEAP16[((($33)+(2))>>1)]=HEAP16[(((_GBK_EUC_NOTDEF_RANGE)+(2))>>1)];HEAP16[((($33)+(4))>>1)]=HEAP16[(((_GBK_EUC_NOTDEF_RANGE)+(4))>>1)];
      var $34=_HPDF_CMapEncoder_AddNotDefRange($32, $3);
      var $35=(($34)|0)!=0;
      if ($35) { __label__ = 11; break; } else { __label__ = 12; break; }
    case 11: 
      var $37=$2;
      var $38=(($37+136)|0);
      var $39=HEAP32[(($38)>>2)];
      var $40=(($39)|0);
      var $41=HEAP32[(($40)>>2)];
      $1=$41;
      __label__ = 13; break;
    case 12: 
      var $43=$2;
      _HPDF_CMapEncoder_SetUnicodeArray($43, ((_CP936_UNICODE_ARRAY)|0));
      var $44=$attr;
      var $45=(($44+262676)|0);
      HEAP32[(($45)>>2)]=28;
      var $46=$attr;
      var $47=(($46+262680)|0);
      HEAP32[(($47)>>2)]=30;
      var $48=$attr;
      var $49=(($48+262416)|0);
      var $50=(($49)|0);
      var $51=$attr;
      var $52=(($51+262416)|0);
      var $53=(($52)|0);
      var $54=(($53+127)|0);
      var $55=_HPDF_StrCpy($50, ((STRING_TABLE.__str41077)|0), $54);
      var $56=$attr;
      var $57=(($56+262544)|0);
      var $58=(($57)|0);
      var $59=$attr;
      var $60=(($59+262544)|0);
      var $61=(($60)|0);
      var $62=(($61+127)|0);
      var $63=_HPDF_StrCpy($58, ((STRING_TABLE.__str51078)|0), $62);
      var $64=$attr;
      var $65=(($64+262672)|0);
      HEAP32[(($65)>>2)]=2;
      var $66=$attr;
      var $67=(($66+262684)|0);
      HEAP32[(($67)>>2)]=-1;
      var $68=$attr;
      var $69=(($68+262688)|0);
      var $70=(($69)|0);
      HEAP32[(($70)>>2)]=1;
      var $71=$attr;
      var $72=(($71+262688)|0);
      var $73=(($72+4)|0);
      HEAP32[(($73)>>2)]=10;
      var $74=$attr;
      var $75=(($74+262688)|0);
      var $76=(($75+8)|0);
      HEAP32[(($76)>>2)]=25378;
      var $77=$attr;
      var $78=(($77+262412)|0);
      HEAP32[(($78)>>2)]=1;
      var $79=$2;
      var $80=(($79+140)|0);
      HEAP32[(($80)>>2)]=1;
      $1=0;
      __label__ = 13; break;
    case 13: 
      var $82=$1;
      STACKTOP = __stackBase__;
      return $82;
    default: assert(0, "bad label: " + __label__);
  }
}
_GBK_EUC_V_Init["X"]=1;

function _GB_EUC_H_Init($encoder) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $attr;
      var $ret;
      $2=$encoder;
      var $3=$2;
      var $4=_HPDF_CMapEncoder_InitAttr($3);
      $ret=$4;
      var $5=(($4)|0)!=0;
      if ($5) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $7=$ret;
      $1=$7;
      __label__ = 11; break;
    case 4: 
      var $9=$2;
      var $10=(($9+164)|0);
      var $11=HEAP32[(($10)>>2)];
      var $12=$11;
      $attr=$12;
      var $13=$2;
      var $14=_HPDF_CMapEncoder_AddCMap($13, ((_CMAP_ARRAY_GB_EUC_H)|0));
      var $15=(($14)|0)!=0;
      if ($15) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $17=$2;
      var $18=(($17+136)|0);
      var $19=HEAP32[(($18)>>2)];
      var $20=(($19)|0);
      var $21=HEAP32[(($20)>>2)];
      $1=$21;
      __label__ = 11; break;
    case 6: 
      var $23=$2;
      var $24=_GB_EUC_AddCodeSpaceRange($23);
      $ret=$24;
      var $25=(($24)|0)!=0;
      if ($25) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $27=$ret;
      $1=$27;
      __label__ = 11; break;
    case 8: 
      var $29=$2;
      var $30=_HPDF_CMapEncoder_AddNotDefRange($29, _GB_EUC_NOTDEF_RANGE);
      var $31=(($30)|0)!=0;
      if ($31) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      var $33=$2;
      var $34=(($33+136)|0);
      var $35=HEAP32[(($34)>>2)];
      var $36=(($35)|0);
      var $37=HEAP32[(($36)>>2)];
      $1=$37;
      __label__ = 11; break;
    case 10: 
      var $39=$2;
      _HPDF_CMapEncoder_SetUnicodeArray($39, ((_EUC_CN_UNICODE_ARRAY)|0));
      var $40=$attr;
      var $41=(($40+262676)|0);
      HEAP32[(($41)>>2)]=32;
      var $42=$attr;
      var $43=(($42+262680)|0);
      HEAP32[(($43)>>2)]=34;
      var $44=$attr;
      var $45=(($44+262416)|0);
      var $46=(($45)|0);
      var $47=$attr;
      var $48=(($47+262416)|0);
      var $49=(($48)|0);
      var $50=(($49+127)|0);
      var $51=_HPDF_StrCpy($46, ((STRING_TABLE.__str41077)|0), $50);
      var $52=$attr;
      var $53=(($52+262544)|0);
      var $54=(($53)|0);
      var $55=$attr;
      var $56=(($55+262544)|0);
      var $57=(($56)|0);
      var $58=(($57+127)|0);
      var $59=_HPDF_StrCpy($54, ((STRING_TABLE.__str51078)|0), $58);
      var $60=$attr;
      var $61=(($60+262672)|0);
      HEAP32[(($61)>>2)]=0;
      var $62=$attr;
      var $63=(($62+262684)|0);
      HEAP32[(($63)>>2)]=100;
      var $64=$attr;
      var $65=(($64+262688)|0);
      var $66=(($65)|0);
      HEAP32[(($66)>>2)]=1;
      var $67=$attr;
      var $68=(($67+262688)|0);
      var $69=(($68+4)|0);
      HEAP32[(($69)>>2)]=10;
      var $70=$attr;
      var $71=(($70+262688)|0);
      var $72=(($71+8)|0);
      HEAP32[(($72)>>2)]=25360;
      var $73=$2;
      var $74=(($73+140)|0);
      HEAP32[(($74)>>2)]=1;
      $1=0;
      __label__ = 11; break;
    case 11: 
      var $76=$1;
      ;
      return $76;
    default: assert(0, "bad label: " + __label__);
  }
}
_GB_EUC_H_Init["X"]=1;

function _GB_EUC_V_Init($encoder) {
  var __stackBase__  = STACKTOP; STACKTOP += 8; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $attr;
      var $ret;
      var $3=__stackBase__;
      $2=$encoder;
      var $4=$2;
      var $5=_HPDF_CMapEncoder_InitAttr($4);
      $ret=$5;
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $8=$ret;
      $1=$8;
      __label__ = 13; break;
    case 4: 
      var $10=$2;
      var $11=(($10+164)|0);
      var $12=HEAP32[(($11)>>2)];
      var $13=$12;
      $attr=$13;
      var $14=$2;
      var $15=_HPDF_CMapEncoder_AddCMap($14, ((_CMAP_ARRAY_GB_EUC_H)|0));
      var $16=(($15)|0)!=0;
      if ($16) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $18=$2;
      var $19=(($18+136)|0);
      var $20=HEAP32[(($19)>>2)];
      var $21=(($20)|0);
      var $22=HEAP32[(($21)>>2)];
      $1=$22;
      __label__ = 13; break;
    case 6: 
      var $24=$2;
      var $25=_HPDF_CMapEncoder_AddCMap($24, ((_CMAP_ARRAY_GB_EUC_V)|0));
      var $26=(($25)|0)!=0;
      if ($26) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $28=$2;
      var $29=(($28+136)|0);
      var $30=HEAP32[(($29)>>2)];
      var $31=(($30)|0);
      var $32=HEAP32[(($31)>>2)];
      $1=$32;
      __label__ = 13; break;
    case 8: 
      var $34=$2;
      var $35=_GB_EUC_AddCodeSpaceRange($34);
      $ret=$35;
      var $36=(($35)|0)!=0;
      if ($36) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      var $38=$ret;
      $1=$38;
      __label__ = 13; break;
    case 10: 
      var $40=$2;
      var $41=$3;
      assert(6 % 1 === 0, 'memcpy given ' + 6 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP16[(($41)>>1)]=HEAP16[((_GB_EUC_NOTDEF_RANGE)>>1)];HEAP16[((($41)+(2))>>1)]=HEAP16[(((_GB_EUC_NOTDEF_RANGE)+(2))>>1)];HEAP16[((($41)+(4))>>1)]=HEAP16[(((_GB_EUC_NOTDEF_RANGE)+(4))>>1)];
      var $42=_HPDF_CMapEncoder_AddNotDefRange($40, $3);
      var $43=(($42)|0)!=0;
      if ($43) { __label__ = 11; break; } else { __label__ = 12; break; }
    case 11: 
      var $45=$2;
      var $46=(($45+136)|0);
      var $47=HEAP32[(($46)>>2)];
      var $48=(($47)|0);
      var $49=HEAP32[(($48)>>2)];
      $1=$49;
      __label__ = 13; break;
    case 12: 
      var $51=$2;
      _HPDF_CMapEncoder_SetUnicodeArray($51, ((_EUC_CN_UNICODE_ARRAY)|0));
      var $52=$attr;
      var $53=(($52+262676)|0);
      HEAP32[(($53)>>2)]=32;
      var $54=$attr;
      var $55=(($54+262680)|0);
      HEAP32[(($55)>>2)]=34;
      var $56=$attr;
      var $57=(($56+262416)|0);
      var $58=(($57)|0);
      var $59=$attr;
      var $60=(($59+262416)|0);
      var $61=(($60)|0);
      var $62=(($61+127)|0);
      var $63=_HPDF_StrCpy($58, ((STRING_TABLE.__str41077)|0), $62);
      var $64=$attr;
      var $65=(($64+262544)|0);
      var $66=(($65)|0);
      var $67=$attr;
      var $68=(($67+262544)|0);
      var $69=(($68)|0);
      var $70=(($69+127)|0);
      var $71=_HPDF_StrCpy($66, ((STRING_TABLE.__str51078)|0), $70);
      var $72=$attr;
      var $73=(($72+262672)|0);
      HEAP32[(($73)>>2)]=0;
      var $74=$attr;
      var $75=(($74+262412)|0);
      HEAP32[(($75)>>2)]=1;
      var $76=$attr;
      var $77=(($76+262684)|0);
      HEAP32[(($77)>>2)]=310;
      var $78=$attr;
      var $79=(($78+262688)|0);
      var $80=(($79)|0);
      HEAP32[(($80)>>2)]=1;
      var $81=$attr;
      var $82=(($81+262688)|0);
      var $83=(($82+4)|0);
      HEAP32[(($83)>>2)]=10;
      var $84=$attr;
      var $85=(($84+262688)|0);
      var $86=(($85+8)|0);
      HEAP32[(($86)>>2)]=25361;
      var $87=$2;
      var $88=(($87+140)|0);
      HEAP32[(($88)>>2)]=1;
      $1=0;
      __label__ = 13; break;
    case 13: 
      var $90=$1;
      STACKTOP = __stackBase__;
      return $90;
    default: assert(0, "bad label: " + __label__);
  }
}
_GB_EUC_V_Init["X"]=1;

function _GB_EUC_AddCodeSpaceRange($encoder) {
  var __stackBase__  = STACKTOP; STACKTOP += 16; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $code_space_range1=__stackBase__;
      var $code_space_range2=(__stackBase__)+(8);
      $2=$encoder;
      var $3=$code_space_range1;
      assert(6 % 1 === 0, 'memcpy given ' + 6 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP16[(($3)>>1)]=HEAP16[((_GB_EUC_AddCodeSpaceRange_code_space_range1)>>1)];HEAP16[((($3)+(2))>>1)]=HEAP16[(((_GB_EUC_AddCodeSpaceRange_code_space_range1)+(2))>>1)];HEAP16[((($3)+(4))>>1)]=HEAP16[(((_GB_EUC_AddCodeSpaceRange_code_space_range1)+(4))>>1)];
      var $4=$code_space_range2;
      assert(6 % 1 === 0, 'memcpy given ' + 6 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP16[(($4)>>1)]=HEAP16[((_GB_EUC_AddCodeSpaceRange_code_space_range2)>>1)];HEAP16[((($4)+(2))>>1)]=HEAP16[(((_GB_EUC_AddCodeSpaceRange_code_space_range2)+(2))>>1)];HEAP16[((($4)+(4))>>1)]=HEAP16[(((_GB_EUC_AddCodeSpaceRange_code_space_range2)+(4))>>1)];
      var $5=$2;
      var $6=_HPDF_CMapEncoder_AddCodeSpaceRange($5, $code_space_range1);
      var $7=(($6)|0)!=0;
      if ($7) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $9=$2;
      var $10=(($9+136)|0);
      var $11=HEAP32[(($10)>>2)];
      var $12=(($11)|0);
      var $13=HEAP32[(($12)>>2)];
      $1=$13;
      __label__ = 7; break;
    case 4: 
      var $15=$2;
      var $16=_HPDF_CMapEncoder_AddCodeSpaceRange($15, $code_space_range2);
      var $17=(($16)|0)!=0;
      if ($17) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $19=$2;
      var $20=(($19+136)|0);
      var $21=HEAP32[(($20)>>2)];
      var $22=(($21)|0);
      var $23=HEAP32[(($22)>>2)];
      $1=$23;
      __label__ = 7; break;
    case 6: 
      $1=0;
      __label__ = 7; break;
    case 7: 
      var $26=$1;
      STACKTOP = __stackBase__;
      return $26;
    default: assert(0, "bad label: " + __label__);
  }
}


function _GBK_EUC_AddCodeSpaceRange($encoder) {
  var __stackBase__  = STACKTOP; STACKTOP += 16; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $code_space_range1=__stackBase__;
      var $code_space_range2=(__stackBase__)+(8);
      $2=$encoder;
      var $3=$code_space_range1;
      assert(6 % 1 === 0, 'memcpy given ' + 6 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP16[(($3)>>1)]=HEAP16[((_GBK_EUC_AddCodeSpaceRange_code_space_range1)>>1)];HEAP16[((($3)+(2))>>1)]=HEAP16[(((_GBK_EUC_AddCodeSpaceRange_code_space_range1)+(2))>>1)];HEAP16[((($3)+(4))>>1)]=HEAP16[(((_GBK_EUC_AddCodeSpaceRange_code_space_range1)+(4))>>1)];
      var $4=$code_space_range2;
      assert(6 % 1 === 0, 'memcpy given ' + 6 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP16[(($4)>>1)]=HEAP16[((_GBK_EUC_AddCodeSpaceRange_code_space_range2)>>1)];HEAP16[((($4)+(2))>>1)]=HEAP16[(((_GBK_EUC_AddCodeSpaceRange_code_space_range2)+(2))>>1)];HEAP16[((($4)+(4))>>1)]=HEAP16[(((_GBK_EUC_AddCodeSpaceRange_code_space_range2)+(4))>>1)];
      var $5=$2;
      var $6=_HPDF_CMapEncoder_AddCodeSpaceRange($5, $code_space_range1);
      var $7=(($6)|0)!=0;
      if ($7) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $9=$2;
      var $10=(($9+136)|0);
      var $11=HEAP32[(($10)>>2)];
      var $12=(($11)|0);
      var $13=HEAP32[(($12)>>2)];
      $1=$13;
      __label__ = 7; break;
    case 4: 
      var $15=$2;
      var $16=_HPDF_CMapEncoder_AddCodeSpaceRange($15, $code_space_range2);
      var $17=(($16)|0)!=0;
      if ($17) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $19=$2;
      var $20=(($19+136)|0);
      var $21=HEAP32[(($20)>>2)];
      var $22=(($21)|0);
      var $23=HEAP32[(($22)>>2)];
      $1=$23;
      __label__ = 7; break;
    case 6: 
      $1=0;
      __label__ = 7; break;
    case 7: 
      var $26=$1;
      STACKTOP = __stackBase__;
      return $26;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_UseCNTEncodings($pdf) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $encoder;
      var $ret;
      $2=$pdf;
      var $3=$2;
      var $4=_HPDF_HasDoc($3);
      var $5=(($4)|0)!=0;
      if ($5) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=4133;
      __label__ = 9; break;
    case 4: 
      var $8=$2;
      var $9=(($8+8)|0);
      var $10=HEAP32[(($9)>>2)];
      var $11=_HPDF_CMapEncoder_New($10, ((STRING_TABLE.__str1080)|0), 48);
      $encoder=$11;
      var $12=$2;
      var $13=$encoder;
      var $14=_HPDF_Doc_RegisterEncoder($12, $13);
      $ret=$14;
      var $15=(($14)|0)!=0;
      if ($15) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $17=$ret;
      $1=$17;
      __label__ = 9; break;
    case 6: 
      var $19=$2;
      var $20=(($19+8)|0);
      var $21=HEAP32[(($20)>>2)];
      var $22=_HPDF_CMapEncoder_New($21, ((STRING_TABLE.__str11081)|0), 50);
      $encoder=$22;
      var $23=$2;
      var $24=$encoder;
      var $25=_HPDF_Doc_RegisterEncoder($23, $24);
      $ret=$25;
      var $26=(($25)|0)!=0;
      if ($26) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $28=$ret;
      $1=$28;
      __label__ = 9; break;
    case 8: 
      $1=0;
      __label__ = 9; break;
    case 9: 
      var $31=$1;
      ;
      return $31;
    default: assert(0, "bad label: " + __label__);
  }
}


function _ETen_B5_H_Init($encoder) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $attr;
      var $ret;
      $2=$encoder;
      var $3=$2;
      var $4=_HPDF_CMapEncoder_InitAttr($3);
      $ret=$4;
      var $5=(($4)|0)!=0;
      if ($5) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $7=$ret;
      $1=$7;
      __label__ = 11; break;
    case 4: 
      var $9=$2;
      var $10=(($9+164)|0);
      var $11=HEAP32[(($10)>>2)];
      var $12=$11;
      $attr=$12;
      var $13=$2;
      var $14=_HPDF_CMapEncoder_AddCMap($13, ((_CMAP_ARRAY_ETen_B5_H)|0));
      var $15=(($14)|0)!=0;
      if ($15) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $17=$2;
      var $18=(($17+136)|0);
      var $19=HEAP32[(($18)>>2)];
      var $20=(($19)|0);
      var $21=HEAP32[(($20)>>2)];
      $1=$21;
      __label__ = 11; break;
    case 6: 
      var $23=$2;
      var $24=_ETen_B5_AddCodeSpaceRange($23);
      $ret=$24;
      var $25=(($24)|0)!=0;
      if ($25) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $27=$ret;
      $1=$27;
      __label__ = 11; break;
    case 8: 
      var $29=$2;
      var $30=_HPDF_CMapEncoder_AddNotDefRange($29, _ETen_B5_NOTDEF_RANGE);
      var $31=(($30)|0)!=0;
      if ($31) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      var $33=$2;
      var $34=(($33+136)|0);
      var $35=HEAP32[(($34)>>2)];
      var $36=(($35)|0);
      var $37=HEAP32[(($36)>>2)];
      $1=$37;
      __label__ = 11; break;
    case 10: 
      var $39=$2;
      _HPDF_CMapEncoder_SetUnicodeArray($39, ((_CP950_UNICODE_ARRAY)|0));
      var $40=$attr;
      var $41=(($40+262676)|0);
      HEAP32[(($41)>>2)]=36;
      var $42=$attr;
      var $43=(($42+262680)|0);
      HEAP32[(($43)>>2)]=38;
      var $44=$attr;
      var $45=(($44+262416)|0);
      var $46=(($45)|0);
      var $47=$attr;
      var $48=(($47+262416)|0);
      var $49=(($48)|0);
      var $50=(($49+127)|0);
      var $51=_HPDF_StrCpy($46, ((STRING_TABLE.__str21082)|0), $50);
      var $52=$attr;
      var $53=(($52+262544)|0);
      var $54=(($53)|0);
      var $55=$attr;
      var $56=(($55+262544)|0);
      var $57=(($56)|0);
      var $58=(($57+127)|0);
      var $59=_HPDF_StrCpy($54, ((STRING_TABLE.__str31083)|0), $58);
      var $60=$attr;
      var $61=(($60+262672)|0);
      HEAP32[(($61)>>2)]=0;
      var $62=$attr;
      var $63=(($62+262684)|0);
      HEAP32[(($63)>>2)]=200;
      var $64=$attr;
      var $65=(($64+262688)|0);
      var $66=(($65)|0);
      HEAP32[(($66)>>2)]=1;
      var $67=$attr;
      var $68=(($67+262688)|0);
      var $69=(($68+4)|0);
      HEAP32[(($69)>>2)]=10;
      var $70=$attr;
      var $71=(($70+262688)|0);
      var $72=(($71+8)|0);
      HEAP32[(($72)>>2)]=25390;
      var $73=$2;
      var $74=(($73+140)|0);
      HEAP32[(($74)>>2)]=1;
      $1=0;
      __label__ = 11; break;
    case 11: 
      var $76=$1;
      ;
      return $76;
    default: assert(0, "bad label: " + __label__);
  }
}
_ETen_B5_H_Init["X"]=1;

function _ETen_B5_IsLeadByte($encoder, $b) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      $1=$encoder;
      $2=$b;
      var $3=$2;
      var $4=(($3)&255);
      var $5=(($4)|0) >= 129;
      if ($5) { __label__ = 3; break; } else { var $11 = 0;__label__ = 4; break; }
    case 3: 
      var $7=$2;
      var $8=(($7)&255);
      var $9=(($8)|0) <= 254;
      var $11 = $9;__label__ = 4; break;
    case 4: 
      var $11;
      var $12=(($11)&1);
      ;
      return $12;
    default: assert(0, "bad label: " + __label__);
  }
}


function _ETen_B5_IsTrialByte($encoder, $b) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      $1=$encoder;
      $2=$b;
      var $3=$2;
      var $4=(($3)&255);
      var $5=(($4)|0) >= 64;
      if ($5) { __label__ = 3; break; } else { var $11 = 0;__label__ = 4; break; }
    case 3: 
      var $7=$2;
      var $8=(($7)&255);
      var $9=(($8)|0) <= 254;
      var $11 = $9;__label__ = 4; break;
    case 4: 
      var $11;
      var $12=(($11)&1);
      ;
      return $12;
    default: assert(0, "bad label: " + __label__);
  }
}


function _ETen_B5_V_Init($encoder) {
  var __stackBase__  = STACKTOP; STACKTOP += 8; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $attr;
      var $ret;
      var $3=__stackBase__;
      $2=$encoder;
      var $4=$2;
      var $5=_HPDF_CMapEncoder_InitAttr($4);
      $ret=$5;
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $8=$ret;
      $1=$8;
      __label__ = 13; break;
    case 4: 
      var $10=$2;
      var $11=(($10+164)|0);
      var $12=HEAP32[(($11)>>2)];
      var $13=$12;
      $attr=$13;
      var $14=$2;
      var $15=_HPDF_CMapEncoder_AddCMap($14, ((_CMAP_ARRAY_ETen_B5_H)|0));
      $ret=$15;
      var $16=(($15)|0)!=0;
      if ($16) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $18=$ret;
      $1=$18;
      __label__ = 13; break;
    case 6: 
      var $20=$2;
      var $21=_HPDF_CMapEncoder_AddCMap($20, ((_CMAP_ARRAY_ETen_B5_V)|0));
      $ret=$21;
      var $22=(($21)|0)!=0;
      if ($22) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $24=$ret;
      $1=$24;
      __label__ = 13; break;
    case 8: 
      var $26=$2;
      var $27=_ETen_B5_AddCodeSpaceRange($26);
      $ret=$27;
      var $28=(($27)|0)!=0;
      if ($28) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      var $30=$ret;
      $1=$30;
      __label__ = 13; break;
    case 10: 
      var $32=$2;
      var $33=$3;
      assert(6 % 1 === 0, 'memcpy given ' + 6 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP16[(($33)>>1)]=HEAP16[((_ETen_B5_NOTDEF_RANGE)>>1)];HEAP16[((($33)+(2))>>1)]=HEAP16[(((_ETen_B5_NOTDEF_RANGE)+(2))>>1)];HEAP16[((($33)+(4))>>1)]=HEAP16[(((_ETen_B5_NOTDEF_RANGE)+(4))>>1)];
      var $34=_HPDF_CMapEncoder_AddNotDefRange($32, $3);
      var $35=(($34)|0)!=0;
      if ($35) { __label__ = 11; break; } else { __label__ = 12; break; }
    case 11: 
      var $37=$2;
      var $38=(($37+136)|0);
      var $39=HEAP32[(($38)>>2)];
      var $40=(($39)|0);
      var $41=HEAP32[(($40)>>2)];
      $1=$41;
      __label__ = 13; break;
    case 12: 
      var $43=$2;
      _HPDF_CMapEncoder_SetUnicodeArray($43, ((_CP950_UNICODE_ARRAY)|0));
      var $44=$attr;
      var $45=(($44+262676)|0);
      HEAP32[(($45)>>2)]=36;
      var $46=$attr;
      var $47=(($46+262680)|0);
      HEAP32[(($47)>>2)]=38;
      var $48=$attr;
      var $49=(($48+262416)|0);
      var $50=(($49)|0);
      var $51=$attr;
      var $52=(($51+262416)|0);
      var $53=(($52)|0);
      var $54=(($53+127)|0);
      var $55=_HPDF_StrCpy($50, ((STRING_TABLE.__str21082)|0), $54);
      var $56=$attr;
      var $57=(($56+262544)|0);
      var $58=(($57)|0);
      var $59=$attr;
      var $60=(($59+262544)|0);
      var $61=(($60)|0);
      var $62=(($61+127)|0);
      var $63=_HPDF_StrCpy($58, ((STRING_TABLE.__str31083)|0), $62);
      var $64=$attr;
      var $65=(($64+262672)|0);
      HEAP32[(($65)>>2)]=0;
      var $66=$attr;
      var $67=(($66+262684)|0);
      HEAP32[(($67)>>2)]=920;
      var $68=$attr;
      var $69=(($68+262688)|0);
      var $70=(($69)|0);
      HEAP32[(($70)>>2)]=1;
      var $71=$attr;
      var $72=(($71+262688)|0);
      var $73=(($72+4)|0);
      HEAP32[(($73)>>2)]=10;
      var $74=$attr;
      var $75=(($74+262688)|0);
      var $76=(($75+8)|0);
      HEAP32[(($76)>>2)]=25391;
      var $77=$attr;
      var $78=(($77+262412)|0);
      HEAP32[(($78)>>2)]=1;
      var $79=$2;
      var $80=(($79+140)|0);
      HEAP32[(($80)>>2)]=1;
      $1=0;
      __label__ = 13; break;
    case 13: 
      var $82=$1;
      STACKTOP = __stackBase__;
      return $82;
    default: assert(0, "bad label: " + __label__);
  }
}
_ETen_B5_V_Init["X"]=1;

function _ETen_B5_AddCodeSpaceRange($encoder) {
  var __stackBase__  = STACKTOP; STACKTOP += 16; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $code_space_range1=__stackBase__;
      var $code_space_range2=(__stackBase__)+(8);
      $2=$encoder;
      var $3=$code_space_range1;
      assert(6 % 1 === 0, 'memcpy given ' + 6 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP16[(($3)>>1)]=HEAP16[((_ETen_B5_AddCodeSpaceRange_code_space_range1)>>1)];HEAP16[((($3)+(2))>>1)]=HEAP16[(((_ETen_B5_AddCodeSpaceRange_code_space_range1)+(2))>>1)];HEAP16[((($3)+(4))>>1)]=HEAP16[(((_ETen_B5_AddCodeSpaceRange_code_space_range1)+(4))>>1)];
      var $4=$code_space_range2;
      assert(6 % 1 === 0, 'memcpy given ' + 6 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP16[(($4)>>1)]=HEAP16[((_ETen_B5_AddCodeSpaceRange_code_space_range2)>>1)];HEAP16[((($4)+(2))>>1)]=HEAP16[(((_ETen_B5_AddCodeSpaceRange_code_space_range2)+(2))>>1)];HEAP16[((($4)+(4))>>1)]=HEAP16[(((_ETen_B5_AddCodeSpaceRange_code_space_range2)+(4))>>1)];
      var $5=$2;
      var $6=_HPDF_CMapEncoder_AddCodeSpaceRange($5, $code_space_range1);
      var $7=(($6)|0)!=0;
      if ($7) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $9=$2;
      var $10=(($9+136)|0);
      var $11=HEAP32[(($10)>>2)];
      var $12=(($11)|0);
      var $13=HEAP32[(($12)>>2)];
      $1=$13;
      __label__ = 7; break;
    case 4: 
      var $15=$2;
      var $16=_HPDF_CMapEncoder_AddCodeSpaceRange($15, $code_space_range2);
      var $17=(($16)|0)!=0;
      if ($17) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $19=$2;
      var $20=(($19+136)|0);
      var $21=HEAP32[(($20)>>2)];
      var $22=(($21)|0);
      var $23=HEAP32[(($22)>>2)];
      $1=$23;
      __label__ = 7; break;
    case 6: 
      $1=0;
      __label__ = 7; break;
    case 7: 
      var $26=$1;
      STACKTOP = __stackBase__;
      return $26;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_UseJPEncodings($pdf) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $encoder;
      var $ret;
      $2=$pdf;
      var $3=$2;
      var $4=_HPDF_Doc_Validate($3);
      var $5=(($4)|0)!=0;
      if ($5) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=4133;
      __label__ = 15; break;
    case 4: 
      var $8=$2;
      var $9=(($8+8)|0);
      var $10=HEAP32[(($9)>>2)];
      var $11=_HPDF_CMapEncoder_New($10, ((STRING_TABLE.__str1085)|0), 60);
      $encoder=$11;
      var $12=$2;
      var $13=$encoder;
      var $14=_HPDF_Doc_RegisterEncoder($12, $13);
      $ret=$14;
      var $15=(($14)|0)!=0;
      if ($15) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $17=$ret;
      $1=$17;
      __label__ = 15; break;
    case 6: 
      var $19=$2;
      var $20=(($19+8)|0);
      var $21=HEAP32[(($20)>>2)];
      var $22=_HPDF_CMapEncoder_New($21, ((STRING_TABLE.__str11086)|0), 62);
      $encoder=$22;
      var $23=$2;
      var $24=$encoder;
      var $25=_HPDF_Doc_RegisterEncoder($23, $24);
      $ret=$25;
      var $26=(($25)|0)!=0;
      if ($26) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $28=$ret;
      $1=$28;
      __label__ = 15; break;
    case 8: 
      var $30=$2;
      var $31=(($30+8)|0);
      var $32=HEAP32[(($31)>>2)];
      var $33=_HPDF_CMapEncoder_New($32, ((STRING_TABLE.__str21087)|0), 64);
      $encoder=$33;
      var $34=$2;
      var $35=$encoder;
      var $36=_HPDF_Doc_RegisterEncoder($34, $35);
      $ret=$36;
      var $37=(($36)|0)!=0;
      if ($37) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      var $39=$ret;
      $1=$39;
      __label__ = 15; break;
    case 10: 
      var $41=$2;
      var $42=(($41+8)|0);
      var $43=HEAP32[(($42)>>2)];
      var $44=_HPDF_CMapEncoder_New($43, ((STRING_TABLE.__str31088)|0), 66);
      $encoder=$44;
      var $45=$2;
      var $46=$encoder;
      var $47=_HPDF_Doc_RegisterEncoder($45, $46);
      $ret=$47;
      var $48=(($47)|0)!=0;
      if ($48) { __label__ = 11; break; } else { __label__ = 12; break; }
    case 11: 
      var $50=$ret;
      $1=$50;
      __label__ = 15; break;
    case 12: 
      var $52=$2;
      var $53=(($52+8)|0);
      var $54=HEAP32[(($53)>>2)];
      var $55=_HPDF_CMapEncoder_New($54, ((STRING_TABLE.__str41089)|0), 68);
      $encoder=$55;
      var $56=$2;
      var $57=$encoder;
      var $58=_HPDF_Doc_RegisterEncoder($56, $57);
      $ret=$58;
      var $59=(($58)|0)!=0;
      if ($59) { __label__ = 13; break; } else { __label__ = 14; break; }
    case 13: 
      var $61=$ret;
      $1=$61;
      __label__ = 15; break;
    case 14: 
      $1=0;
      __label__ = 15; break;
    case 15: 
      var $64=$1;
      ;
      return $64;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_UseJPEncodings["X"]=1;

function _MS_RKSJ_H_Init($encoder) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $attr;
      var $ret;
      $2=$encoder;
      var $3=$2;
      var $4=_HPDF_CMapEncoder_InitAttr($3);
      $ret=$4;
      var $5=(($4)|0)!=0;
      if ($5) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $7=$ret;
      $1=$7;
      __label__ = 11; break;
    case 4: 
      var $9=$2;
      var $10=(($9+164)|0);
      var $11=HEAP32[(($10)>>2)];
      var $12=$11;
      $attr=$12;
      var $13=$2;
      var $14=_HPDF_CMapEncoder_AddCMap($13, ((_CMAP_ARRAY_90ms_RKSJ_H)|0));
      var $15=(($14)|0)!=0;
      if ($15) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $17=$2;
      var $18=(($17+136)|0);
      var $19=HEAP32[(($18)>>2)];
      var $20=(($19)|0);
      var $21=HEAP32[(($20)>>2)];
      $1=$21;
      __label__ = 11; break;
    case 6: 
      var $23=$2;
      var $24=_RKSJ_AddCodeSpaceRange($23);
      $ret=$24;
      var $25=(($24)|0)!=0;
      if ($25) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $27=$ret;
      $1=$27;
      __label__ = 11; break;
    case 8: 
      var $29=$2;
      var $30=_HPDF_CMapEncoder_AddNotDefRange($29, _MS_RKSJ_NOTDEF_RANGE);
      var $31=(($30)|0)!=0;
      if ($31) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      var $33=$2;
      var $34=(($33+136)|0);
      var $35=HEAP32[(($34)>>2)];
      var $36=(($35)|0);
      var $37=HEAP32[(($36)>>2)];
      $1=$37;
      __label__ = 11; break;
    case 10: 
      var $39=$2;
      _HPDF_CMapEncoder_SetUnicodeArray($39, ((_CP932_UNICODE_ARRAY)|0));
      var $40=$attr;
      var $41=(($40+262676)|0);
      HEAP32[(($41)>>2)]=52;
      var $42=$attr;
      var $43=(($42+262680)|0);
      HEAP32[(($43)>>2)]=54;
      var $44=$attr;
      var $45=(($44+262416)|0);
      var $46=(($45)|0);
      var $47=$attr;
      var $48=(($47+262416)|0);
      var $49=(($48)|0);
      var $50=(($49+127)|0);
      var $51=_HPDF_StrCpy($46, ((STRING_TABLE.__str51090)|0), $50);
      var $52=$attr;
      var $53=(($52+262544)|0);
      var $54=(($53)|0);
      var $55=$attr;
      var $56=(($55+262544)|0);
      var $57=(($56)|0);
      var $58=(($57+127)|0);
      var $59=_HPDF_StrCpy($54, ((STRING_TABLE.__str61091)|0), $58);
      var $60=$attr;
      var $61=(($60+262672)|0);
      HEAP32[(($61)>>2)]=2;
      var $62=$attr;
      var $63=(($62+262684)|0);
      HEAP32[(($63)>>2)]=950;
      var $64=$attr;
      var $65=(($64+262688)|0);
      var $66=(($65)|0);
      HEAP32[(($66)>>2)]=1;
      var $67=$attr;
      var $68=(($67+262688)|0);
      var $69=(($68+4)|0);
      HEAP32[(($69)>>2)]=10;
      var $70=$attr;
      var $71=(($70+262688)|0);
      var $72=(($71+8)|0);
      HEAP32[(($72)>>2)]=25343;
      var $73=$2;
      var $74=(($73+140)|0);
      HEAP32[(($74)>>2)]=1;
      var $75=$2;
      var $76=_HPDF_CMapEncoder_AddJWWLineHead($75, ((_JWW_LINE_HEAD_SJIS)|0));
      $1=0;
      __label__ = 11; break;
    case 11: 
      var $78=$1;
      ;
      return $78;
    default: assert(0, "bad label: " + __label__);
  }
}
_MS_RKSJ_H_Init["X"]=1;

function _MS_RKSJ_V_Init($encoder) {
  var __stackBase__  = STACKTOP; STACKTOP += 8; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $attr;
      var $ret;
      var $3=__stackBase__;
      $2=$encoder;
      var $4=$2;
      var $5=_HPDF_CMapEncoder_InitAttr($4);
      $ret=$5;
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $8=$ret;
      $1=$8;
      __label__ = 13; break;
    case 4: 
      var $10=$2;
      var $11=(($10+164)|0);
      var $12=HEAP32[(($11)>>2)];
      var $13=$12;
      $attr=$13;
      var $14=$2;
      var $15=_HPDF_CMapEncoder_AddCMap($14, ((_CMAP_ARRAY_90ms_RKSJ_H)|0));
      $ret=$15;
      var $16=(($15)|0)!=0;
      if ($16) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $18=$ret;
      $1=$18;
      __label__ = 13; break;
    case 6: 
      var $20=$2;
      var $21=_HPDF_CMapEncoder_AddCMap($20, ((_CMAP_ARRAY_90ms_RKSJ_V)|0));
      $ret=$21;
      var $22=(($21)|0)!=0;
      if ($22) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $24=$ret;
      $1=$24;
      __label__ = 13; break;
    case 8: 
      var $26=$2;
      var $27=_RKSJ_AddCodeSpaceRange($26);
      $ret=$27;
      var $28=(($27)|0)!=0;
      if ($28) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      var $30=$ret;
      $1=$30;
      __label__ = 13; break;
    case 10: 
      var $32=$2;
      var $33=$3;
      assert(6 % 1 === 0, 'memcpy given ' + 6 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP16[(($33)>>1)]=HEAP16[((_MS_RKSJ_NOTDEF_RANGE)>>1)];HEAP16[((($33)+(2))>>1)]=HEAP16[(((_MS_RKSJ_NOTDEF_RANGE)+(2))>>1)];HEAP16[((($33)+(4))>>1)]=HEAP16[(((_MS_RKSJ_NOTDEF_RANGE)+(4))>>1)];
      var $34=_HPDF_CMapEncoder_AddNotDefRange($32, $3);
      var $35=(($34)|0)!=0;
      if ($35) { __label__ = 11; break; } else { __label__ = 12; break; }
    case 11: 
      var $37=$2;
      var $38=(($37+136)|0);
      var $39=HEAP32[(($38)>>2)];
      var $40=(($39)|0);
      var $41=HEAP32[(($40)>>2)];
      $1=$41;
      __label__ = 13; break;
    case 12: 
      var $43=$2;
      _HPDF_CMapEncoder_SetUnicodeArray($43, ((_CP932_UNICODE_ARRAY)|0));
      var $44=$attr;
      var $45=(($44+262676)|0);
      HEAP32[(($45)>>2)]=52;
      var $46=$attr;
      var $47=(($46+262680)|0);
      HEAP32[(($47)>>2)]=54;
      var $48=$attr;
      var $49=(($48+262416)|0);
      var $50=(($49)|0);
      var $51=$attr;
      var $52=(($51+262416)|0);
      var $53=(($52)|0);
      var $54=(($53+127)|0);
      var $55=_HPDF_StrCpy($50, ((STRING_TABLE.__str51090)|0), $54);
      var $56=$attr;
      var $57=(($56+262544)|0);
      var $58=(($57)|0);
      var $59=$attr;
      var $60=(($59+262544)|0);
      var $61=(($60)|0);
      var $62=(($61+127)|0);
      var $63=_HPDF_StrCpy($58, ((STRING_TABLE.__str61091)|0), $62);
      var $64=$attr;
      var $65=(($64+262672)|0);
      HEAP32[(($65)>>2)]=2;
      var $66=$attr;
      var $67=(($66+262684)|0);
      HEAP32[(($67)>>2)]=1020;
      var $68=$attr;
      var $69=(($68+262688)|0);
      var $70=(($69)|0);
      HEAP32[(($70)>>2)]=1;
      var $71=$attr;
      var $72=(($71+262688)|0);
      var $73=(($72+4)|0);
      HEAP32[(($73)>>2)]=10;
      var $74=$attr;
      var $75=(($74+262688)|0);
      var $76=(($75+8)|0);
      HEAP32[(($76)>>2)]=25344;
      var $77=$attr;
      var $78=(($77+262412)|0);
      HEAP32[(($78)>>2)]=1;
      var $79=$2;
      var $80=(($79+140)|0);
      HEAP32[(($80)>>2)]=1;
      var $81=$2;
      var $82=_HPDF_CMapEncoder_AddJWWLineHead($81, ((_JWW_LINE_HEAD_SJIS)|0));
      $1=0;
      __label__ = 13; break;
    case 13: 
      var $84=$1;
      STACKTOP = __stackBase__;
      return $84;
    default: assert(0, "bad label: " + __label__);
  }
}
_MS_RKSJ_V_Init["X"]=1;

function _MSP_RKSJ_H_Init($encoder) {
  var __stackBase__  = STACKTOP; STACKTOP += 8; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $attr;
      var $ret;
      var $3=__stackBase__;
      $2=$encoder;
      var $4=$2;
      var $5=_HPDF_CMapEncoder_InitAttr($4);
      $ret=$5;
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $8=$ret;
      $1=$8;
      __label__ = 11; break;
    case 4: 
      var $10=$2;
      var $11=(($10+164)|0);
      var $12=HEAP32[(($11)>>2)];
      var $13=$12;
      $attr=$13;
      var $14=$2;
      var $15=_HPDF_CMapEncoder_AddCMap($14, ((_CMAP_ARRAY_90msp_RKSJ_H)|0));
      $ret=$15;
      var $16=(($15)|0)!=0;
      if ($16) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $18=$ret;
      $1=$18;
      __label__ = 11; break;
    case 6: 
      var $20=$2;
      var $21=_RKSJ_AddCodeSpaceRange($20);
      $ret=$21;
      var $22=(($21)|0)!=0;
      if ($22) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $24=$ret;
      $1=$24;
      __label__ = 11; break;
    case 8: 
      var $26=$2;
      var $27=$3;
      assert(6 % 1 === 0, 'memcpy given ' + 6 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP16[(($27)>>1)]=HEAP16[((_MSP_RKSJ_NOTDEF_RANGE)>>1)];HEAP16[((($27)+(2))>>1)]=HEAP16[(((_MSP_RKSJ_NOTDEF_RANGE)+(2))>>1)];HEAP16[((($27)+(4))>>1)]=HEAP16[(((_MSP_RKSJ_NOTDEF_RANGE)+(4))>>1)];
      var $28=_HPDF_CMapEncoder_AddNotDefRange($26, $3);
      var $29=(($28)|0)!=0;
      if ($29) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      var $31=$2;
      var $32=(($31+136)|0);
      var $33=HEAP32[(($32)>>2)];
      var $34=(($33)|0);
      var $35=HEAP32[(($34)>>2)];
      $1=$35;
      __label__ = 11; break;
    case 10: 
      var $37=$2;
      _HPDF_CMapEncoder_SetUnicodeArray($37, ((_CP932_UNICODE_ARRAY)|0));
      var $38=$attr;
      var $39=(($38+262676)|0);
      HEAP32[(($39)>>2)]=52;
      var $40=$attr;
      var $41=(($40+262680)|0);
      HEAP32[(($41)>>2)]=54;
      var $42=$attr;
      var $43=(($42+262416)|0);
      var $44=(($43)|0);
      var $45=$attr;
      var $46=(($45+262416)|0);
      var $47=(($46)|0);
      var $48=(($47+127)|0);
      var $49=_HPDF_StrCpy($44, ((STRING_TABLE.__str51090)|0), $48);
      var $50=$attr;
      var $51=(($50+262544)|0);
      var $52=(($51)|0);
      var $53=$attr;
      var $54=(($53+262544)|0);
      var $55=(($54)|0);
      var $56=(($55+127)|0);
      var $57=_HPDF_StrCpy($52, ((STRING_TABLE.__str61091)|0), $56);
      var $58=$attr;
      var $59=(($58+262672)|0);
      HEAP32[(($59)>>2)]=2;
      var $60=$attr;
      var $61=(($60+262684)|0);
      HEAP32[(($61)>>2)]=950;
      var $62=$attr;
      var $63=(($62+262688)|0);
      var $64=(($63)|0);
      HEAP32[(($64)>>2)]=1;
      var $65=$attr;
      var $66=(($65+262688)|0);
      var $67=(($66+4)|0);
      HEAP32[(($67)>>2)]=10;
      var $68=$attr;
      var $69=(($68+262688)|0);
      var $70=(($69+8)|0);
      HEAP32[(($70)>>2)]=25445;
      var $71=$2;
      var $72=(($71+140)|0);
      HEAP32[(($72)>>2)]=1;
      var $73=$2;
      var $74=_HPDF_CMapEncoder_AddJWWLineHead($73, ((_JWW_LINE_HEAD_SJIS)|0));
      $1=0;
      __label__ = 11; break;
    case 11: 
      var $76=$1;
      STACKTOP = __stackBase__;
      return $76;
    default: assert(0, "bad label: " + __label__);
  }
}
_MSP_RKSJ_H_Init["X"]=1;

function _EUC_H_Init($encoder) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $attr;
      var $ret;
      $2=$encoder;
      var $3=$2;
      var $4=_HPDF_CMapEncoder_InitAttr($3);
      $ret=$4;
      var $5=(($4)|0)!=0;
      if ($5) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $7=$ret;
      $1=$7;
      __label__ = 11; break;
    case 4: 
      var $9=$2;
      var $10=(($9+164)|0);
      var $11=HEAP32[(($10)>>2)];
      var $12=$11;
      $attr=$12;
      var $13=$2;
      var $14=_HPDF_CMapEncoder_AddCMap($13, ((_CMAP_ARRAY_EUC_H)|0));
      var $15=(($14)|0)!=0;
      if ($15) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $17=$2;
      var $18=(($17+136)|0);
      var $19=HEAP32[(($18)>>2)];
      var $20=(($19)|0);
      var $21=HEAP32[(($20)>>2)];
      $1=$21;
      __label__ = 11; break;
    case 6: 
      var $23=$2;
      var $24=_EUC_AddCodeSpaceRange($23);
      $ret=$24;
      var $25=(($24)|0)!=0;
      if ($25) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $27=$ret;
      $1=$27;
      __label__ = 11; break;
    case 8: 
      var $29=$2;
      var $30=_HPDF_CMapEncoder_AddNotDefRange($29, _EUC_NOTDEF_RANGE);
      var $31=(($30)|0)!=0;
      if ($31) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      var $33=$2;
      var $34=(($33+136)|0);
      var $35=HEAP32[(($34)>>2)];
      var $36=(($35)|0);
      var $37=HEAP32[(($36)>>2)];
      $1=$37;
      __label__ = 11; break;
    case 10: 
      var $39=$2;
      _HPDF_CMapEncoder_SetUnicodeArray($39, ((_EUC_UNICODE_ARRAY)|0));
      var $40=$attr;
      var $41=(($40+262676)|0);
      HEAP32[(($41)>>2)]=56;
      var $42=$attr;
      var $43=(($42+262680)|0);
      HEAP32[(($43)>>2)]=58;
      var $44=$attr;
      var $45=(($44+262416)|0);
      var $46=(($45)|0);
      var $47=$attr;
      var $48=(($47+262416)|0);
      var $49=(($48)|0);
      var $50=(($49+127)|0);
      var $51=_HPDF_StrCpy($46, ((STRING_TABLE.__str51090)|0), $50);
      var $52=$attr;
      var $53=(($52+262544)|0);
      var $54=(($53)|0);
      var $55=$attr;
      var $56=(($55+262544)|0);
      var $57=(($56)|0);
      var $58=(($57+127)|0);
      var $59=_HPDF_StrCpy($54, ((STRING_TABLE.__str61091)|0), $58);
      var $60=$attr;
      var $61=(($60+262672)|0);
      HEAP32[(($61)>>2)]=1;
      var $62=$attr;
      var $63=(($62+262684)|0);
      HEAP32[(($63)>>2)]=680;
      var $64=$attr;
      var $65=(($64+262688)|0);
      var $66=(($65)|0);
      HEAP32[(($66)>>2)]=1;
      var $67=$attr;
      var $68=(($67+262688)|0);
      var $69=(($68+4)|0);
      HEAP32[(($69)>>2)]=10;
      var $70=$attr;
      var $71=(($70+262688)|0);
      var $72=(($71+8)|0);
      HEAP32[(($72)>>2)]=25329;
      var $73=$2;
      var $74=(($73+140)|0);
      HEAP32[(($74)>>2)]=1;
      var $75=$2;
      var $76=_HPDF_CMapEncoder_AddJWWLineHead($75, ((_JWW_LINE_HEAD_EUC)|0));
      $1=0;
      __label__ = 11; break;
    case 11: 
      var $78=$1;
      ;
      return $78;
    default: assert(0, "bad label: " + __label__);
  }
}
_EUC_H_Init["X"]=1;

function _EUC_V_Init($encoder) {
  var __stackBase__  = STACKTOP; STACKTOP += 8; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $attr;
      var $ret;
      var $3=__stackBase__;
      $2=$encoder;
      var $4=$2;
      var $5=_HPDF_CMapEncoder_InitAttr($4);
      $ret=$5;
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $8=$ret;
      $1=$8;
      __label__ = 13; break;
    case 4: 
      var $10=$2;
      var $11=(($10+164)|0);
      var $12=HEAP32[(($11)>>2)];
      var $13=$12;
      $attr=$13;
      var $14=$2;
      var $15=_HPDF_CMapEncoder_AddCMap($14, ((_CMAP_ARRAY_EUC_H)|0));
      var $16=(($15)|0)!=0;
      if ($16) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $18=$2;
      var $19=(($18+136)|0);
      var $20=HEAP32[(($19)>>2)];
      var $21=(($20)|0);
      var $22=HEAP32[(($21)>>2)];
      $1=$22;
      __label__ = 13; break;
    case 6: 
      var $24=$2;
      var $25=_HPDF_CMapEncoder_AddCMap($24, ((_CMAP_ARRAY_EUC_V)|0));
      var $26=(($25)|0)!=0;
      if ($26) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $28=$2;
      var $29=(($28+136)|0);
      var $30=HEAP32[(($29)>>2)];
      var $31=(($30)|0);
      var $32=HEAP32[(($31)>>2)];
      $1=$32;
      __label__ = 13; break;
    case 8: 
      var $34=$2;
      var $35=_EUC_AddCodeSpaceRange($34);
      $ret=$35;
      var $36=(($35)|0)!=0;
      if ($36) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      var $38=$ret;
      $1=$38;
      __label__ = 13; break;
    case 10: 
      var $40=$2;
      var $41=$3;
      assert(6 % 1 === 0, 'memcpy given ' + 6 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP16[(($41)>>1)]=HEAP16[((_EUC_NOTDEF_RANGE)>>1)];HEAP16[((($41)+(2))>>1)]=HEAP16[(((_EUC_NOTDEF_RANGE)+(2))>>1)];HEAP16[((($41)+(4))>>1)]=HEAP16[(((_EUC_NOTDEF_RANGE)+(4))>>1)];
      var $42=_HPDF_CMapEncoder_AddNotDefRange($40, $3);
      var $43=(($42)|0)!=0;
      if ($43) { __label__ = 11; break; } else { __label__ = 12; break; }
    case 11: 
      var $45=$2;
      var $46=(($45+136)|0);
      var $47=HEAP32[(($46)>>2)];
      var $48=(($47)|0);
      var $49=HEAP32[(($48)>>2)];
      $1=$49;
      __label__ = 13; break;
    case 12: 
      var $51=$2;
      _HPDF_CMapEncoder_SetUnicodeArray($51, ((_EUC_UNICODE_ARRAY)|0));
      var $52=$attr;
      var $53=(($52+262676)|0);
      HEAP32[(($53)>>2)]=56;
      var $54=$attr;
      var $55=(($54+262680)|0);
      HEAP32[(($55)>>2)]=58;
      var $56=$attr;
      var $57=(($56+262416)|0);
      var $58=(($57)|0);
      var $59=$attr;
      var $60=(($59+262416)|0);
      var $61=(($60)|0);
      var $62=(($61+127)|0);
      var $63=_HPDF_StrCpy($58, ((STRING_TABLE.__str51090)|0), $62);
      var $64=$attr;
      var $65=(($64+262544)|0);
      var $66=(($65)|0);
      var $67=$attr;
      var $68=(($67+262544)|0);
      var $69=(($68)|0);
      var $70=(($69+127)|0);
      var $71=_HPDF_StrCpy($66, ((STRING_TABLE.__str61091)|0), $70);
      var $72=$attr;
      var $73=(($72+262672)|0);
      HEAP32[(($73)>>2)]=1;
      var $74=$attr;
      var $75=(($74+262412)|0);
      HEAP32[(($75)>>2)]=1;
      var $76=$attr;
      var $77=(($76+262684)|0);
      HEAP32[(($77)>>2)]=800;
      var $78=$attr;
      var $79=(($78+262688)|0);
      var $80=(($79)|0);
      HEAP32[(($80)>>2)]=1;
      var $81=$attr;
      var $82=(($81+262688)|0);
      var $83=(($82+4)|0);
      HEAP32[(($83)>>2)]=10;
      var $84=$attr;
      var $85=(($84+262688)|0);
      var $86=(($85+8)|0);
      HEAP32[(($86)>>2)]=25330;
      var $87=$2;
      var $88=(($87+140)|0);
      HEAP32[(($88)>>2)]=1;
      var $89=$2;
      var $90=_HPDF_CMapEncoder_AddJWWLineHead($89, ((_JWW_LINE_HEAD_EUC)|0));
      $1=0;
      __label__ = 13; break;
    case 13: 
      var $92=$1;
      STACKTOP = __stackBase__;
      return $92;
    default: assert(0, "bad label: " + __label__);
  }
}
_EUC_V_Init["X"]=1;

function _EUC_IsLeadByte($encoder, $b) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      $1=$encoder;
      $2=$b;
      var $3=$2;
      var $4=(($3)&255);
      var $5=(($4)|0) >= 161;
      if ($5) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $7=$2;
      var $8=(($7)&255);
      var $9=(($8)|0) <= 254;
      if ($9) { var $15 = 1;__label__ = 5; break; } else { __label__ = 4; break; }
    case 4: 
      var $11=$2;
      var $12=(($11)&255);
      var $13=(($12)|0)==142;
      var $15 = $13;__label__ = 5; break;
    case 5: 
      var $15;
      var $16=(($15)&1);
      ;
      return $16;
    default: assert(0, "bad label: " + __label__);
  }
}


function _EUC_IsTrialByte($encoder, $b) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      $1=$encoder;
      $2=$b;
      var $3=$2;
      var $4=(($3)&255);
      var $5=(($4)|0) >= 160;
      if ($5) { __label__ = 3; break; } else { var $11 = 0;__label__ = 4; break; }
    case 3: 
      var $7=$2;
      var $8=(($7)&255);
      var $9=(($8)|0) <= 254;
      var $11 = $9;__label__ = 4; break;
    case 4: 
      var $11;
      var $12=(($11)&1);
      ;
      return $12;
    default: assert(0, "bad label: " + __label__);
  }
}


function _RKSJ_IsLeadByte($encoder, $b) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      $1=$encoder;
      $2=$b;
      var $3=$2;
      var $4=(($3)&255);
      var $5=(($4)|0) >= 129;
      if ($5) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $7=$2;
      var $8=(($7)&255);
      var $9=(($8)|0) <= 159;
      if ($9) { var $21 = 1;__label__ = 7; break; } else { __label__ = 4; break; }
    case 4: 
      var $11=$2;
      var $12=(($11)&255);
      var $13=(($12)|0) >= 224;
      if ($13) { __label__ = 5; break; } else { var $19 = 0;__label__ = 6; break; }
    case 5: 
      var $15=$2;
      var $16=(($15)&255);
      var $17=(($16)|0) <= 252;
      var $19 = $17;__label__ = 6; break;
    case 6: 
      var $19;
      var $21 = $19;__label__ = 7; break;
    case 7: 
      var $21;
      var $22=(($21)&1);
      ;
      return $22;
    default: assert(0, "bad label: " + __label__);
  }
}


function _RKSJ_IsTrialByte($encoder, $b) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      $1=$encoder;
      $2=$b;
      var $3=$2;
      var $4=(($3)&255);
      var $5=(($4)|0) >= 64;
      if ($5) { __label__ = 3; break; } else { var $15 = 0;__label__ = 5; break; }
    case 3: 
      var $7=$2;
      var $8=(($7)&255);
      var $9=(($8)|0) <= 252;
      if ($9) { __label__ = 4; break; } else { var $15 = 0;__label__ = 5; break; }
    case 4: 
      var $11=$2;
      var $12=(($11)&255);
      var $13=(($12)|0)!=127;
      var $15 = $13;__label__ = 5; break;
    case 5: 
      var $15;
      var $16=(($15)&1);
      ;
      return $16;
    default: assert(0, "bad label: " + __label__);
  }
}


function _EUC_AddCodeSpaceRange($encoder) {
  var __stackBase__  = STACKTOP; STACKTOP += 24; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $code_space_range1=__stackBase__;
      var $code_space_range2=(__stackBase__)+(8);
      var $code_space_range3=(__stackBase__)+(16);
      $2=$encoder;
      var $3=$code_space_range1;
      assert(6 % 1 === 0, 'memcpy given ' + 6 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP16[(($3)>>1)]=HEAP16[((_EUC_AddCodeSpaceRange_code_space_range1)>>1)];HEAP16[((($3)+(2))>>1)]=HEAP16[(((_EUC_AddCodeSpaceRange_code_space_range1)+(2))>>1)];HEAP16[((($3)+(4))>>1)]=HEAP16[(((_EUC_AddCodeSpaceRange_code_space_range1)+(4))>>1)];
      var $4=$code_space_range2;
      assert(6 % 1 === 0, 'memcpy given ' + 6 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP16[(($4)>>1)]=HEAP16[((_EUC_AddCodeSpaceRange_code_space_range2)>>1)];HEAP16[((($4)+(2))>>1)]=HEAP16[(((_EUC_AddCodeSpaceRange_code_space_range2)+(2))>>1)];HEAP16[((($4)+(4))>>1)]=HEAP16[(((_EUC_AddCodeSpaceRange_code_space_range2)+(4))>>1)];
      var $5=$code_space_range3;
      assert(6 % 1 === 0, 'memcpy given ' + 6 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP16[(($5)>>1)]=HEAP16[((_EUC_AddCodeSpaceRange_code_space_range3)>>1)];HEAP16[((($5)+(2))>>1)]=HEAP16[(((_EUC_AddCodeSpaceRange_code_space_range3)+(2))>>1)];HEAP16[((($5)+(4))>>1)]=HEAP16[(((_EUC_AddCodeSpaceRange_code_space_range3)+(4))>>1)];
      var $6=$2;
      var $7=_HPDF_CMapEncoder_AddCodeSpaceRange($6, $code_space_range1);
      var $8=(($7)|0)!=0;
      if ($8) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $10=$2;
      var $11=(($10+136)|0);
      var $12=HEAP32[(($11)>>2)];
      var $13=(($12)|0);
      var $14=HEAP32[(($13)>>2)];
      $1=$14;
      __label__ = 9; break;
    case 4: 
      var $16=$2;
      var $17=_HPDF_CMapEncoder_AddCodeSpaceRange($16, $code_space_range2);
      var $18=(($17)|0)!=0;
      if ($18) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $20=$2;
      var $21=(($20+136)|0);
      var $22=HEAP32[(($21)>>2)];
      var $23=(($22)|0);
      var $24=HEAP32[(($23)>>2)];
      $1=$24;
      __label__ = 9; break;
    case 6: 
      var $26=$2;
      var $27=_HPDF_CMapEncoder_AddCodeSpaceRange($26, $code_space_range3);
      var $28=(($27)|0)!=0;
      if ($28) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $30=$2;
      var $31=(($30+136)|0);
      var $32=HEAP32[(($31)>>2)];
      var $33=(($32)|0);
      var $34=HEAP32[(($33)>>2)];
      $1=$34;
      __label__ = 9; break;
    case 8: 
      $1=0;
      __label__ = 9; break;
    case 9: 
      var $37=$1;
      STACKTOP = __stackBase__;
      return $37;
    default: assert(0, "bad label: " + __label__);
  }
}


function _RKSJ_AddCodeSpaceRange($encoder) {
  var __stackBase__  = STACKTOP; STACKTOP += 32; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $code_space_range1=__stackBase__;
      var $code_space_range2=(__stackBase__)+(8);
      var $code_space_range3=(__stackBase__)+(16);
      var $code_space_range4=(__stackBase__)+(24);
      $2=$encoder;
      var $3=$code_space_range1;
      assert(6 % 1 === 0, 'memcpy given ' + 6 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP16[(($3)>>1)]=HEAP16[((_RKSJ_AddCodeSpaceRange_code_space_range1)>>1)];HEAP16[((($3)+(2))>>1)]=HEAP16[(((_RKSJ_AddCodeSpaceRange_code_space_range1)+(2))>>1)];HEAP16[((($3)+(4))>>1)]=HEAP16[(((_RKSJ_AddCodeSpaceRange_code_space_range1)+(4))>>1)];
      var $4=$code_space_range2;
      assert(6 % 1 === 0, 'memcpy given ' + 6 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP16[(($4)>>1)]=HEAP16[((_RKSJ_AddCodeSpaceRange_code_space_range2)>>1)];HEAP16[((($4)+(2))>>1)]=HEAP16[(((_RKSJ_AddCodeSpaceRange_code_space_range2)+(2))>>1)];HEAP16[((($4)+(4))>>1)]=HEAP16[(((_RKSJ_AddCodeSpaceRange_code_space_range2)+(4))>>1)];
      var $5=$code_space_range3;
      assert(6 % 1 === 0, 'memcpy given ' + 6 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP16[(($5)>>1)]=HEAP16[((_RKSJ_AddCodeSpaceRange_code_space_range3)>>1)];HEAP16[((($5)+(2))>>1)]=HEAP16[(((_RKSJ_AddCodeSpaceRange_code_space_range3)+(2))>>1)];HEAP16[((($5)+(4))>>1)]=HEAP16[(((_RKSJ_AddCodeSpaceRange_code_space_range3)+(4))>>1)];
      var $6=$code_space_range4;
      assert(6 % 1 === 0, 'memcpy given ' + 6 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP16[(($6)>>1)]=HEAP16[((_RKSJ_AddCodeSpaceRange_code_space_range4)>>1)];HEAP16[((($6)+(2))>>1)]=HEAP16[(((_RKSJ_AddCodeSpaceRange_code_space_range4)+(2))>>1)];HEAP16[((($6)+(4))>>1)]=HEAP16[(((_RKSJ_AddCodeSpaceRange_code_space_range4)+(4))>>1)];
      var $7=$2;
      var $8=_HPDF_CMapEncoder_AddCodeSpaceRange($7, $code_space_range1);
      var $9=(($8)|0)!=0;
      if ($9) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $11=$2;
      var $12=(($11+136)|0);
      var $13=HEAP32[(($12)>>2)];
      var $14=(($13)|0);
      var $15=HEAP32[(($14)>>2)];
      $1=$15;
      __label__ = 11; break;
    case 4: 
      var $17=$2;
      var $18=_HPDF_CMapEncoder_AddCodeSpaceRange($17, $code_space_range2);
      var $19=(($18)|0)!=0;
      if ($19) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $21=$2;
      var $22=(($21+136)|0);
      var $23=HEAP32[(($22)>>2)];
      var $24=(($23)|0);
      var $25=HEAP32[(($24)>>2)];
      $1=$25;
      __label__ = 11; break;
    case 6: 
      var $27=$2;
      var $28=_HPDF_CMapEncoder_AddCodeSpaceRange($27, $code_space_range3);
      var $29=(($28)|0)!=0;
      if ($29) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $31=$2;
      var $32=(($31+136)|0);
      var $33=HEAP32[(($32)>>2)];
      var $34=(($33)|0);
      var $35=HEAP32[(($34)>>2)];
      $1=$35;
      __label__ = 11; break;
    case 8: 
      var $37=$2;
      var $38=_HPDF_CMapEncoder_AddCodeSpaceRange($37, $code_space_range4);
      var $39=(($38)|0)!=0;
      if ($39) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      var $41=$2;
      var $42=(($41+136)|0);
      var $43=HEAP32[(($42)>>2)];
      var $44=(($43)|0);
      var $45=HEAP32[(($44)>>2)];
      $1=$45;
      __label__ = 11; break;
    case 10: 
      $1=0;
      __label__ = 11; break;
    case 11: 
      var $48=$1;
      STACKTOP = __stackBase__;
      return $48;
    default: assert(0, "bad label: " + __label__);
  }
}
_RKSJ_AddCodeSpaceRange["X"]=1;

function _HPDF_UseKREncodings($pdf) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $encoder;
      var $ret;
      $2=$pdf;
      var $3=$2;
      var $4=_HPDF_HasDoc($3);
      var $5=(($4)|0)!=0;
      if ($5) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=4133;
      __label__ = 15; break;
    case 4: 
      var $8=$2;
      var $9=(($8+8)|0);
      var $10=HEAP32[(($9)>>2)];
      var $11=_HPDF_CMapEncoder_New($10, ((STRING_TABLE.__str1093)|0), 78);
      $encoder=$11;
      var $12=$2;
      var $13=$encoder;
      var $14=_HPDF_Doc_RegisterEncoder($12, $13);
      $ret=$14;
      var $15=(($14)|0)!=0;
      if ($15) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $17=$ret;
      $1=$17;
      __label__ = 15; break;
    case 6: 
      var $19=$2;
      var $20=(($19+8)|0);
      var $21=HEAP32[(($20)>>2)];
      var $22=_HPDF_CMapEncoder_New($21, ((STRING_TABLE.__str11094)|0), 80);
      $encoder=$22;
      var $23=$2;
      var $24=$encoder;
      var $25=_HPDF_Doc_RegisterEncoder($23, $24);
      $ret=$25;
      var $26=(($25)|0)!=0;
      if ($26) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $28=$ret;
      $1=$28;
      __label__ = 15; break;
    case 8: 
      var $30=$2;
      var $31=(($30+8)|0);
      var $32=HEAP32[(($31)>>2)];
      var $33=_HPDF_CMapEncoder_New($32, ((STRING_TABLE.__str21095)|0), 82);
      $encoder=$33;
      var $34=$2;
      var $35=$encoder;
      var $36=_HPDF_Doc_RegisterEncoder($34, $35);
      $ret=$36;
      var $37=(($36)|0)!=0;
      if ($37) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      var $39=$ret;
      $1=$39;
      __label__ = 15; break;
    case 10: 
      var $41=$2;
      var $42=(($41+8)|0);
      var $43=HEAP32[(($42)>>2)];
      var $44=_HPDF_CMapEncoder_New($43, ((STRING_TABLE.__str31096)|0), 84);
      $encoder=$44;
      var $45=$2;
      var $46=$encoder;
      var $47=_HPDF_Doc_RegisterEncoder($45, $46);
      $ret=$47;
      var $48=(($47)|0)!=0;
      if ($48) { __label__ = 11; break; } else { __label__ = 12; break; }
    case 11: 
      var $50=$ret;
      $1=$50;
      __label__ = 15; break;
    case 12: 
      var $52=$2;
      var $53=(($52+8)|0);
      var $54=HEAP32[(($53)>>2)];
      var $55=_HPDF_CMapEncoder_New($54, ((STRING_TABLE.__str41097)|0), 86);
      $encoder=$55;
      var $56=$2;
      var $57=$encoder;
      var $58=_HPDF_Doc_RegisterEncoder($56, $57);
      $ret=$58;
      var $59=(($58)|0)!=0;
      if ($59) { __label__ = 13; break; } else { __label__ = 14; break; }
    case 13: 
      var $61=$ret;
      $1=$61;
      __label__ = 15; break;
    case 14: 
      $1=0;
      __label__ = 15; break;
    case 15: 
      var $64=$1;
      ;
      return $64;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_UseKREncodings["X"]=1;

function _KSCms_UHC_H_Init($encoder) {
  var __stackBase__  = STACKTOP; STACKTOP += 8; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $attr;
      var $ret;
      var $3=__stackBase__;
      $2=$encoder;
      var $4=$2;
      var $5=_HPDF_CMapEncoder_InitAttr($4);
      $ret=$5;
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $8=$ret;
      $1=$8;
      __label__ = 11; break;
    case 4: 
      var $10=$2;
      var $11=(($10+164)|0);
      var $12=HEAP32[(($11)>>2)];
      var $13=$12;
      $attr=$13;
      var $14=$2;
      var $15=_HPDF_CMapEncoder_AddCMap($14, ((_CMAP_ARRAY_KSCms_UHC_H)|0));
      var $16=(($15)|0)!=0;
      if ($16) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $18=$2;
      var $19=(($18+136)|0);
      var $20=HEAP32[(($19)>>2)];
      var $21=(($20)|0);
      var $22=HEAP32[(($21)>>2)];
      $1=$22;
      __label__ = 11; break;
    case 6: 
      var $24=$2;
      var $25=_KSCms_UHC_AddCodeSpaceRange($24);
      $ret=$25;
      var $26=(($25)|0)!=0;
      if ($26) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $28=$ret;
      $1=$28;
      __label__ = 11; break;
    case 8: 
      var $30=$2;
      var $31=$3;
      assert(6 % 1 === 0, 'memcpy given ' + 6 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP16[(($31)>>1)]=HEAP16[((_KSCms_UHC_NOTDEF_RANGE)>>1)];HEAP16[((($31)+(2))>>1)]=HEAP16[(((_KSCms_UHC_NOTDEF_RANGE)+(2))>>1)];HEAP16[((($31)+(4))>>1)]=HEAP16[(((_KSCms_UHC_NOTDEF_RANGE)+(4))>>1)];
      var $32=_HPDF_CMapEncoder_AddNotDefRange($30, $3);
      var $33=(($32)|0)!=0;
      if ($33) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      var $35=$2;
      var $36=(($35+136)|0);
      var $37=HEAP32[(($36)>>2)];
      var $38=(($37)|0);
      var $39=HEAP32[(($38)>>2)];
      $1=$39;
      __label__ = 11; break;
    case 10: 
      var $41=$2;
      _HPDF_CMapEncoder_SetUnicodeArray($41, ((_CP949_UNICODE_ARRAY)|0));
      var $42=$attr;
      var $43=(($42+262676)|0);
      HEAP32[(($43)>>2)]=70;
      var $44=$attr;
      var $45=(($44+262680)|0);
      HEAP32[(($45)>>2)]=72;
      var $46=$attr;
      var $47=(($46+262416)|0);
      var $48=(($47)|0);
      var $49=$attr;
      var $50=(($49+262416)|0);
      var $51=(($50)|0);
      var $52=(($51+127)|0);
      var $53=_HPDF_StrCpy($48, ((STRING_TABLE.__str51098)|0), $52);
      var $54=$attr;
      var $55=(($54+262544)|0);
      var $56=(($55)|0);
      var $57=$attr;
      var $58=(($57+262544)|0);
      var $59=(($58)|0);
      var $60=(($59+127)|0);
      var $61=_HPDF_StrCpy($56, ((STRING_TABLE.__str61099)|0), $60);
      var $62=$attr;
      var $63=(($62+262672)|0);
      HEAP32[(($63)>>2)]=1;
      var $64=$attr;
      var $65=(($64+262684)|0);
      HEAP32[(($65)>>2)]=430;
      var $66=$attr;
      var $67=(($66+262688)|0);
      var $68=(($67)|0);
      HEAP32[(($68)>>2)]=1;
      var $69=$attr;
      var $70=(($69+262688)|0);
      var $71=(($70+4)|0);
      HEAP32[(($71)>>2)]=10;
      var $72=$attr;
      var $73=(($72+262688)|0);
      var $74=(($73+8)|0);
      HEAP32[(($74)>>2)]=25409;
      var $75=$2;
      var $76=(($75+140)|0);
      HEAP32[(($76)>>2)]=1;
      $1=0;
      __label__ = 11; break;
    case 11: 
      var $78=$1;
      STACKTOP = __stackBase__;
      return $78;
    default: assert(0, "bad label: " + __label__);
  }
}
_KSCms_UHC_H_Init["X"]=1;

function _KSCms_UHC_HW_H_Init($encoder) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $attr;
      var $ret;
      $2=$encoder;
      var $3=$2;
      var $4=_HPDF_CMapEncoder_InitAttr($3);
      $ret=$4;
      var $5=(($4)|0)!=0;
      if ($5) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $7=$ret;
      $1=$7;
      __label__ = 11; break;
    case 4: 
      var $9=$2;
      var $10=(($9+164)|0);
      var $11=HEAP32[(($10)>>2)];
      var $12=$11;
      $attr=$12;
      var $13=$2;
      var $14=_HPDF_CMapEncoder_AddCMap($13, ((_CMAP_ARRAY_KSCms_UHC_HW_H)|0));
      var $15=(($14)|0)!=0;
      if ($15) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $17=$2;
      var $18=(($17+136)|0);
      var $19=HEAP32[(($18)>>2)];
      var $20=(($19)|0);
      var $21=HEAP32[(($20)>>2)];
      $1=$21;
      __label__ = 11; break;
    case 6: 
      var $23=$2;
      var $24=_KSCms_UHC_AddCodeSpaceRange($23);
      $ret=$24;
      var $25=(($24)|0)!=0;
      if ($25) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $27=$ret;
      $1=$27;
      __label__ = 11; break;
    case 8: 
      var $29=$2;
      var $30=_HPDF_CMapEncoder_AddNotDefRange($29, _KSCms_UHC_HW_NOTDEF_RANGE);
      var $31=(($30)|0)!=0;
      if ($31) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      var $33=$2;
      var $34=(($33+136)|0);
      var $35=HEAP32[(($34)>>2)];
      var $36=(($35)|0);
      var $37=HEAP32[(($36)>>2)];
      $1=$37;
      __label__ = 11; break;
    case 10: 
      var $39=$2;
      _HPDF_CMapEncoder_SetUnicodeArray($39, ((_CP949_UNICODE_ARRAY)|0));
      var $40=$attr;
      var $41=(($40+262676)|0);
      HEAP32[(($41)>>2)]=70;
      var $42=$attr;
      var $43=(($42+262680)|0);
      HEAP32[(($43)>>2)]=72;
      var $44=$attr;
      var $45=(($44+262416)|0);
      var $46=(($45)|0);
      var $47=$attr;
      var $48=(($47+262416)|0);
      var $49=(($48)|0);
      var $50=(($49+127)|0);
      var $51=_HPDF_StrCpy($46, ((STRING_TABLE.__str51098)|0), $50);
      var $52=$attr;
      var $53=(($52+262544)|0);
      var $54=(($53)|0);
      var $55=$attr;
      var $56=(($55+262544)|0);
      var $57=(($56)|0);
      var $58=(($57+127)|0);
      var $59=_HPDF_StrCpy($54, ((STRING_TABLE.__str61099)|0), $58);
      var $60=$attr;
      var $61=(($60+262672)|0);
      HEAP32[(($61)>>2)]=1;
      var $62=$attr;
      var $63=(($62+262684)|0);
      HEAP32[(($63)>>2)]=-1;
      var $64=$attr;
      var $65=(($64+262688)|0);
      var $66=(($65)|0);
      HEAP32[(($66)>>2)]=1;
      var $67=$attr;
      var $68=(($67+262688)|0);
      var $69=(($68+4)|0);
      HEAP32[(($69)>>2)]=10;
      var $70=$attr;
      var $71=(($70+262688)|0);
      var $72=(($71+8)|0);
      HEAP32[(($72)>>2)]=25416;
      var $73=$2;
      var $74=(($73+140)|0);
      HEAP32[(($74)>>2)]=1;
      $1=0;
      __label__ = 11; break;
    case 11: 
      var $76=$1;
      ;
      return $76;
    default: assert(0, "bad label: " + __label__);
  }
}
_KSCms_UHC_HW_H_Init["X"]=1;

function _KSCms_UHC_HW_V_Init($encoder) {
  var __stackBase__  = STACKTOP; STACKTOP += 8; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $attr;
      var $ret;
      var $3=__stackBase__;
      $2=$encoder;
      var $4=$2;
      var $5=_HPDF_CMapEncoder_InitAttr($4);
      $ret=$5;
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $8=$ret;
      $1=$8;
      __label__ = 13; break;
    case 4: 
      var $10=$2;
      var $11=(($10+164)|0);
      var $12=HEAP32[(($11)>>2)];
      var $13=$12;
      $attr=$13;
      var $14=$2;
      var $15=_HPDF_CMapEncoder_AddCMap($14, ((_CMAP_ARRAY_KSCms_UHC_HW_H)|0));
      $ret=$15;
      var $16=(($15)|0)!=0;
      if ($16) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $18=$ret;
      $1=$18;
      __label__ = 13; break;
    case 6: 
      var $20=$2;
      var $21=_HPDF_CMapEncoder_AddCMap($20, ((_CMAP_ARRAY_KSCms_UHC_HW_V)|0));
      $ret=$21;
      var $22=(($21)|0)!=0;
      if ($22) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $24=$ret;
      $1=$24;
      __label__ = 13; break;
    case 8: 
      var $26=$2;
      var $27=_KSCms_UHC_AddCodeSpaceRange($26);
      $ret=$27;
      var $28=(($27)|0)!=0;
      if ($28) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      var $30=$ret;
      $1=$30;
      __label__ = 13; break;
    case 10: 
      var $32=$2;
      var $33=$3;
      assert(6 % 1 === 0, 'memcpy given ' + 6 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP16[(($33)>>1)]=HEAP16[((_KSCms_UHC_HW_NOTDEF_RANGE)>>1)];HEAP16[((($33)+(2))>>1)]=HEAP16[(((_KSCms_UHC_HW_NOTDEF_RANGE)+(2))>>1)];HEAP16[((($33)+(4))>>1)]=HEAP16[(((_KSCms_UHC_HW_NOTDEF_RANGE)+(4))>>1)];
      var $34=_HPDF_CMapEncoder_AddNotDefRange($32, $3);
      var $35=(($34)|0)!=0;
      if ($35) { __label__ = 11; break; } else { __label__ = 12; break; }
    case 11: 
      var $37=$2;
      var $38=(($37+136)|0);
      var $39=HEAP32[(($38)>>2)];
      var $40=(($39)|0);
      var $41=HEAP32[(($40)>>2)];
      $1=$41;
      __label__ = 13; break;
    case 12: 
      var $43=$2;
      _HPDF_CMapEncoder_SetUnicodeArray($43, ((_CP949_UNICODE_ARRAY)|0));
      var $44=$attr;
      var $45=(($44+262676)|0);
      HEAP32[(($45)>>2)]=70;
      var $46=$attr;
      var $47=(($46+262680)|0);
      HEAP32[(($47)>>2)]=72;
      var $48=$attr;
      var $49=(($48+262416)|0);
      var $50=(($49)|0);
      var $51=$attr;
      var $52=(($51+262416)|0);
      var $53=(($52)|0);
      var $54=(($53+127)|0);
      var $55=_HPDF_StrCpy($50, ((STRING_TABLE.__str51098)|0), $54);
      var $56=$attr;
      var $57=(($56+262544)|0);
      var $58=(($57)|0);
      var $59=$attr;
      var $60=(($59+262544)|0);
      var $61=(($60)|0);
      var $62=(($61+127)|0);
      var $63=_HPDF_StrCpy($58, ((STRING_TABLE.__str61099)|0), $62);
      var $64=$attr;
      var $65=(($64+262672)|0);
      HEAP32[(($65)>>2)]=1;
      var $66=$attr;
      var $67=(($66+262684)|0);
      HEAP32[(($67)>>2)]=-1;
      var $68=$attr;
      var $69=(($68+262688)|0);
      var $70=(($69)|0);
      HEAP32[(($70)>>2)]=1;
      var $71=$attr;
      var $72=(($71+262688)|0);
      var $73=(($72+4)|0);
      HEAP32[(($73)>>2)]=10;
      var $74=$attr;
      var $75=(($74+262688)|0);
      var $76=(($75+8)|0);
      HEAP32[(($76)>>2)]=25417;
      var $77=$attr;
      var $78=(($77+262412)|0);
      HEAP32[(($78)>>2)]=1;
      var $79=$2;
      var $80=(($79+140)|0);
      HEAP32[(($80)>>2)]=1;
      $1=0;
      __label__ = 13; break;
    case 13: 
      var $82=$1;
      STACKTOP = __stackBase__;
      return $82;
    default: assert(0, "bad label: " + __label__);
  }
}
_KSCms_UHC_HW_V_Init["X"]=1;

function _KSC_EUC_H_Init($encoder) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $attr;
      var $ret;
      $2=$encoder;
      var $3=$2;
      var $4=_HPDF_CMapEncoder_InitAttr($3);
      $ret=$4;
      var $5=(($4)|0)!=0;
      if ($5) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $7=$ret;
      $1=$7;
      __label__ = 11; break;
    case 4: 
      var $9=$2;
      var $10=(($9+164)|0);
      var $11=HEAP32[(($10)>>2)];
      var $12=$11;
      $attr=$12;
      var $13=$2;
      var $14=_HPDF_CMapEncoder_AddCMap($13, ((_CMAP_ARRAY_KSC_EUC_H)|0));
      var $15=(($14)|0)!=0;
      if ($15) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $17=$2;
      var $18=(($17+136)|0);
      var $19=HEAP32[(($18)>>2)];
      var $20=(($19)|0);
      var $21=HEAP32[(($20)>>2)];
      $1=$21;
      __label__ = 11; break;
    case 6: 
      var $23=$2;
      var $24=_KSC_EUC_AddCodeSpaceRange($23);
      $ret=$24;
      var $25=(($24)|0)!=0;
      if ($25) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $27=$ret;
      $1=$27;
      __label__ = 11; break;
    case 8: 
      var $29=$2;
      var $30=_HPDF_CMapEncoder_AddNotDefRange($29, _KSC_EUC_NOTDEF_RANGE);
      var $31=(($30)|0)!=0;
      if ($31) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      var $33=$2;
      var $34=(($33+136)|0);
      var $35=HEAP32[(($34)>>2)];
      var $36=(($35)|0);
      var $37=HEAP32[(($36)>>2)];
      $1=$37;
      __label__ = 11; break;
    case 10: 
      var $39=$2;
      _HPDF_CMapEncoder_SetUnicodeArray($39, ((_KSC_EUC_UNICODE_ARRAY)|0));
      var $40=$attr;
      var $41=(($40+262676)|0);
      HEAP32[(($41)>>2)]=74;
      var $42=$attr;
      var $43=(($42+262680)|0);
      HEAP32[(($43)>>2)]=76;
      var $44=$attr;
      var $45=(($44+262416)|0);
      var $46=(($45)|0);
      var $47=$attr;
      var $48=(($47+262416)|0);
      var $49=(($48)|0);
      var $50=(($49+127)|0);
      var $51=_HPDF_StrCpy($46, ((STRING_TABLE.__str51098)|0), $50);
      var $52=$attr;
      var $53=(($52+262544)|0);
      var $54=(($53)|0);
      var $55=$attr;
      var $56=(($55+262544)|0);
      var $57=(($56)|0);
      var $58=(($57+127)|0);
      var $59=_HPDF_StrCpy($54, ((STRING_TABLE.__str61099)|0), $58);
      var $60=$attr;
      var $61=(($60+262672)|0);
      HEAP32[(($61)>>2)]=0;
      var $62=$attr;
      var $63=(($62+262684)|0);
      HEAP32[(($63)>>2)]=100;
      var $64=$attr;
      var $65=(($64+262688)|0);
      var $66=(($65)|0);
      HEAP32[(($66)>>2)]=1;
      var $67=$attr;
      var $68=(($67+262688)|0);
      var $69=(($68+4)|0);
      HEAP32[(($69)>>2)]=10;
      var $70=$attr;
      var $71=(($70+262688)|0);
      var $72=(($71+8)|0);
      HEAP32[(($72)>>2)]=25400;
      var $73=$2;
      var $74=(($73+140)|0);
      HEAP32[(($74)>>2)]=1;
      $1=0;
      __label__ = 11; break;
    case 11: 
      var $76=$1;
      ;
      return $76;
    default: assert(0, "bad label: " + __label__);
  }
}
_KSC_EUC_H_Init["X"]=1;

function _KSC_EUC_V_Init($encoder) {
  var __stackBase__  = STACKTOP; STACKTOP += 8; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $attr;
      var $ret;
      var $3=__stackBase__;
      $2=$encoder;
      var $4=$2;
      var $5=_HPDF_CMapEncoder_InitAttr($4);
      $ret=$5;
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $8=$ret;
      $1=$8;
      __label__ = 13; break;
    case 4: 
      var $10=$2;
      var $11=(($10+164)|0);
      var $12=HEAP32[(($11)>>2)];
      var $13=$12;
      $attr=$13;
      var $14=$2;
      var $15=_HPDF_CMapEncoder_AddCMap($14, ((_CMAP_ARRAY_KSC_EUC_H)|0));
      var $16=(($15)|0)!=0;
      if ($16) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $18=$2;
      var $19=(($18+136)|0);
      var $20=HEAP32[(($19)>>2)];
      var $21=(($20)|0);
      var $22=HEAP32[(($21)>>2)];
      $1=$22;
      __label__ = 13; break;
    case 6: 
      var $24=$2;
      var $25=_HPDF_CMapEncoder_AddCMap($24, ((_CMAP_ARRAY_KSC_EUC_V)|0));
      var $26=(($25)|0)!=0;
      if ($26) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $28=$2;
      var $29=(($28+136)|0);
      var $30=HEAP32[(($29)>>2)];
      var $31=(($30)|0);
      var $32=HEAP32[(($31)>>2)];
      $1=$32;
      __label__ = 13; break;
    case 8: 
      var $34=$2;
      var $35=_KSC_EUC_AddCodeSpaceRange($34);
      $ret=$35;
      var $36=(($35)|0)!=0;
      if ($36) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      var $38=$ret;
      $1=$38;
      __label__ = 13; break;
    case 10: 
      var $40=$2;
      var $41=$3;
      assert(6 % 1 === 0, 'memcpy given ' + 6 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP16[(($41)>>1)]=HEAP16[((_KSC_EUC_NOTDEF_RANGE)>>1)];HEAP16[((($41)+(2))>>1)]=HEAP16[(((_KSC_EUC_NOTDEF_RANGE)+(2))>>1)];HEAP16[((($41)+(4))>>1)]=HEAP16[(((_KSC_EUC_NOTDEF_RANGE)+(4))>>1)];
      var $42=_HPDF_CMapEncoder_AddNotDefRange($40, $3);
      var $43=(($42)|0)!=0;
      if ($43) { __label__ = 11; break; } else { __label__ = 12; break; }
    case 11: 
      var $45=$2;
      var $46=(($45+136)|0);
      var $47=HEAP32[(($46)>>2)];
      var $48=(($47)|0);
      var $49=HEAP32[(($48)>>2)];
      $1=$49;
      __label__ = 13; break;
    case 12: 
      var $51=$2;
      _HPDF_CMapEncoder_SetUnicodeArray($51, ((_KSC_EUC_UNICODE_ARRAY)|0));
      var $52=$attr;
      var $53=(($52+262676)|0);
      HEAP32[(($53)>>2)]=74;
      var $54=$attr;
      var $55=(($54+262680)|0);
      HEAP32[(($55)>>2)]=76;
      var $56=$attr;
      var $57=(($56+262416)|0);
      var $58=(($57)|0);
      var $59=$attr;
      var $60=(($59+262416)|0);
      var $61=(($60)|0);
      var $62=(($61+127)|0);
      var $63=_HPDF_StrCpy($58, ((STRING_TABLE.__str51098)|0), $62);
      var $64=$attr;
      var $65=(($64+262544)|0);
      var $66=(($65)|0);
      var $67=$attr;
      var $68=(($67+262544)|0);
      var $69=(($68)|0);
      var $70=(($69+127)|0);
      var $71=_HPDF_StrCpy($66, ((STRING_TABLE.__str61099)|0), $70);
      var $72=$attr;
      var $73=(($72+262672)|0);
      HEAP32[(($73)>>2)]=0;
      var $74=$attr;
      var $75=(($74+262412)|0);
      HEAP32[(($75)>>2)]=1;
      var $76=$attr;
      var $77=(($76+262684)|0);
      HEAP32[(($77)>>2)]=310;
      var $78=$attr;
      var $79=(($78+262688)|0);
      var $80=(($79)|0);
      HEAP32[(($80)>>2)]=1;
      var $81=$attr;
      var $82=(($81+262688)|0);
      var $83=(($82+4)|0);
      HEAP32[(($83)>>2)]=10;
      var $84=$attr;
      var $85=(($84+262688)|0);
      var $86=(($85+8)|0);
      HEAP32[(($86)>>2)]=25401;
      var $87=$2;
      var $88=(($87+140)|0);
      HEAP32[(($88)>>2)]=1;
      $1=0;
      __label__ = 13; break;
    case 13: 
      var $90=$1;
      STACKTOP = __stackBase__;
      return $90;
    default: assert(0, "bad label: " + __label__);
  }
}
_KSC_EUC_V_Init["X"]=1;

function _KSC_EUC_IsLeadByte($encoder, $b) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      $1=$encoder;
      $2=$b;
      var $3=$2;
      var $4=(($3)&255);
      var $5=(($4)|0) >= 161;
      if ($5) { __label__ = 3; break; } else { var $11 = 0;__label__ = 4; break; }
    case 3: 
      var $7=$2;
      var $8=(($7)&255);
      var $9=(($8)|0) <= 254;
      var $11 = $9;__label__ = 4; break;
    case 4: 
      var $11;
      var $12=(($11)&1);
      ;
      return $12;
    default: assert(0, "bad label: " + __label__);
  }
}


function _KSC_EUC_IsTrialByte($encoder, $b) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      $1=$encoder;
      $2=$b;
      var $3=$2;
      var $4=(($3)&255);
      var $5=(($4)|0) >= 160;
      if ($5) { __label__ = 3; break; } else { var $11 = 0;__label__ = 4; break; }
    case 3: 
      var $7=$2;
      var $8=(($7)&255);
      var $9=(($8)|0) <= 254;
      var $11 = $9;__label__ = 4; break;
    case 4: 
      var $11;
      var $12=(($11)&1);
      ;
      return $12;
    default: assert(0, "bad label: " + __label__);
  }
}


function _KSCms_UHC_IsLeadByte($encoder, $b) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      $1=$encoder;
      $2=$b;
      var $3=$2;
      var $4=(($3)&255);
      var $5=(($4)|0) >= 129;
      if ($5) { __label__ = 3; break; } else { var $11 = 0;__label__ = 4; break; }
    case 3: 
      var $7=$2;
      var $8=(($7)&255);
      var $9=(($8)|0) <= 254;
      var $11 = $9;__label__ = 4; break;
    case 4: 
      var $11;
      var $12=(($11)&1);
      ;
      return $12;
    default: assert(0, "bad label: " + __label__);
  }
}


function _KSCms_UHC_IsTrialByte($encoder, $b) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      $1=$encoder;
      $2=$b;
      var $3=$2;
      var $4=(($3)&255);
      var $5=(($4)|0) >= 65;
      if ($5) { __label__ = 3; break; } else { var $11 = 0;__label__ = 4; break; }
    case 3: 
      var $7=$2;
      var $8=(($7)&255);
      var $9=(($8)|0) <= 254;
      var $11 = $9;__label__ = 4; break;
    case 4: 
      var $11;
      var $12=(($11)&1);
      ;
      return $12;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_MD5Init($ctx) {
  ;
  var __label__;

  var $1;
  $1=$ctx;
  var $2=$1;
  var $3=(($2)|0);
  var $4=(($3)|0);
  HEAP32[(($4)>>2)]=1732584193;
  var $5=$1;
  var $6=(($5)|0);
  var $7=(($6+4)|0);
  HEAP32[(($7)>>2)]=-271733879;
  var $8=$1;
  var $9=(($8)|0);
  var $10=(($9+8)|0);
  HEAP32[(($10)>>2)]=-1732584194;
  var $11=$1;
  var $12=(($11)|0);
  var $13=(($12+12)|0);
  HEAP32[(($13)>>2)]=271733878;
  var $14=$1;
  var $15=(($14+16)|0);
  var $16=(($15)|0);
  HEAP32[(($16)>>2)]=0;
  var $17=$1;
  var $18=(($17+16)|0);
  var $19=(($18+4)|0);
  HEAP32[(($19)>>2)]=0;
  ;
  return;
}


function _MD5ByteReverse($buf, $longs) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $t;
      $1=$buf;
      $2=$longs;
      __label__ = 3; break;
    case 3: 
      var $4=$1;
      var $5=(($4+3)|0);
      var $6=HEAPU8[($5)];
      var $7=(($6)&255);
      var $8=$7 << 8;
      var $9=$1;
      var $10=(($9+2)|0);
      var $11=HEAPU8[($10)];
      var $12=(($11)&255);
      var $13=$8 | $12;
      var $14=$13 << 16;
      var $15=$1;
      var $16=(($15+1)|0);
      var $17=HEAPU8[($16)];
      var $18=(($17)&255);
      var $19=$18 << 8;
      var $20=$1;
      var $21=(($20)|0);
      var $22=HEAPU8[($21)];
      var $23=(($22)&255);
      var $24=$19 | $23;
      var $25=$14 | $24;
      $t=$25;
      var $26=$t;
      var $27=$1;
      var $28=$27;
      HEAP32[(($28)>>2)]=$26;
      var $29=$1;
      var $30=(($29+4)|0);
      $1=$30;
      __label__ = 4; break;
    case 4: 
      var $32=$2;
      var $33=((($32)-(1))|0);
      $2=$33;
      var $34=(($33)|0)!=0;
      if ($34) { __label__ = 3; break; } else { __label__ = 5; break; }
    case 5: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}


function _KSC_EUC_AddCodeSpaceRange($encoder) {
  var __stackBase__  = STACKTOP; STACKTOP += 16; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $code_space_range1=__stackBase__;
      var $code_space_range2=(__stackBase__)+(8);
      $2=$encoder;
      var $3=$code_space_range1;
      assert(6 % 1 === 0, 'memcpy given ' + 6 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP16[(($3)>>1)]=HEAP16[((_KSC_EUC_AddCodeSpaceRange_code_space_range1)>>1)];HEAP16[((($3)+(2))>>1)]=HEAP16[(((_KSC_EUC_AddCodeSpaceRange_code_space_range1)+(2))>>1)];HEAP16[((($3)+(4))>>1)]=HEAP16[(((_KSC_EUC_AddCodeSpaceRange_code_space_range1)+(4))>>1)];
      var $4=$code_space_range2;
      assert(6 % 1 === 0, 'memcpy given ' + 6 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP16[(($4)>>1)]=HEAP16[((_KSC_EUC_AddCodeSpaceRange_code_space_range2)>>1)];HEAP16[((($4)+(2))>>1)]=HEAP16[(((_KSC_EUC_AddCodeSpaceRange_code_space_range2)+(2))>>1)];HEAP16[((($4)+(4))>>1)]=HEAP16[(((_KSC_EUC_AddCodeSpaceRange_code_space_range2)+(4))>>1)];
      var $5=$2;
      var $6=_HPDF_CMapEncoder_AddCodeSpaceRange($5, $code_space_range1);
      var $7=(($6)|0)!=0;
      if ($7) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $9=$2;
      var $10=(($9+136)|0);
      var $11=HEAP32[(($10)>>2)];
      var $12=(($11)|0);
      var $13=HEAP32[(($12)>>2)];
      $1=$13;
      __label__ = 7; break;
    case 4: 
      var $15=$2;
      var $16=_HPDF_CMapEncoder_AddCodeSpaceRange($15, $code_space_range2);
      var $17=(($16)|0)!=0;
      if ($17) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $19=$2;
      var $20=(($19+136)|0);
      var $21=HEAP32[(($20)>>2)];
      var $22=(($21)|0);
      var $23=HEAP32[(($22)>>2)];
      $1=$23;
      __label__ = 7; break;
    case 6: 
      $1=0;
      __label__ = 7; break;
    case 7: 
      var $26=$1;
      STACKTOP = __stackBase__;
      return $26;
    default: assert(0, "bad label: " + __label__);
  }
}


function _KSCms_UHC_AddCodeSpaceRange($encoder) {
  var __stackBase__  = STACKTOP; STACKTOP += 16; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $code_space_range1=__stackBase__;
      var $code_space_range2=(__stackBase__)+(8);
      $2=$encoder;
      var $3=$code_space_range1;
      assert(6 % 1 === 0, 'memcpy given ' + 6 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP16[(($3)>>1)]=HEAP16[((_KSCms_UHC_AddCodeSpaceRange_code_space_range1)>>1)];HEAP16[((($3)+(2))>>1)]=HEAP16[(((_KSCms_UHC_AddCodeSpaceRange_code_space_range1)+(2))>>1)];HEAP16[((($3)+(4))>>1)]=HEAP16[(((_KSCms_UHC_AddCodeSpaceRange_code_space_range1)+(4))>>1)];
      var $4=$code_space_range2;
      assert(6 % 1 === 0, 'memcpy given ' + 6 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP16[(($4)>>1)]=HEAP16[((_KSCms_UHC_AddCodeSpaceRange_code_space_range2)>>1)];HEAP16[((($4)+(2))>>1)]=HEAP16[(((_KSCms_UHC_AddCodeSpaceRange_code_space_range2)+(2))>>1)];HEAP16[((($4)+(4))>>1)]=HEAP16[(((_KSCms_UHC_AddCodeSpaceRange_code_space_range2)+(4))>>1)];
      var $5=$2;
      var $6=_HPDF_CMapEncoder_AddCodeSpaceRange($5, $code_space_range1);
      var $7=(($6)|0)!=0;
      if ($7) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $9=$2;
      var $10=(($9+136)|0);
      var $11=HEAP32[(($10)>>2)];
      var $12=(($11)|0);
      var $13=HEAP32[(($12)>>2)];
      $1=$13;
      __label__ = 7; break;
    case 4: 
      var $15=$2;
      var $16=_HPDF_CMapEncoder_AddCodeSpaceRange($15, $code_space_range2);
      var $17=(($16)|0)!=0;
      if ($17) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $19=$2;
      var $20=(($19+136)|0);
      var $21=HEAP32[(($20)>>2)];
      var $22=(($21)|0);
      var $23=HEAP32[(($22)>>2)];
      $1=$23;
      __label__ = 7; break;
    case 6: 
      $1=0;
      __label__ = 7; break;
    case 7: 
      var $26=$1;
      STACKTOP = __stackBase__;
      return $26;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_MD5Update($ctx, $buf, $len) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $t;
      var $p;
      $1=$ctx;
      $2=$buf;
      $3=$len;
      var $4=$1;
      var $5=(($4+16)|0);
      var $6=(($5)|0);
      var $7=HEAP32[(($6)>>2)];
      $t=$7;
      var $8=$t;
      var $9=$3;
      var $10=$9 << 3;
      var $11=((($8)+($10))|0);
      var $12=$1;
      var $13=(($12+16)|0);
      var $14=(($13)|0);
      HEAP32[(($14)>>2)]=$11;
      var $15=$t;
      var $16=(($11)>>>0) < (($15)>>>0);
      if ($16) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $18=$1;
      var $19=(($18+16)|0);
      var $20=(($19+4)|0);
      var $21=HEAP32[(($20)>>2)];
      var $22=((($21)+(1))|0);
      HEAP32[(($20)>>2)]=$22;
      __label__ = 4; break;
    case 4: 
      var $24=$3;
      var $25=$24 >>> 29;
      var $26=$1;
      var $27=(($26+16)|0);
      var $28=(($27+4)|0);
      var $29=HEAP32[(($28)>>2)];
      var $30=((($29)+($25))|0);
      HEAP32[(($28)>>2)]=$30;
      var $31=$t;
      var $32=$31 >>> 3;
      var $33=$32 & 63;
      $t=$33;
      var $34=$t;
      var $35=(($34)|0)!=0;
      if ($35) { __label__ = 5; break; } else { __label__ = 8; break; }
    case 5: 
      var $37=$1;
      var $38=(($37+24)|0);
      var $39=(($38)|0);
      var $40=$t;
      var $41=(($39+$40)|0);
      $p=$41;
      var $42=$t;
      var $43=(((64)-($42))|0);
      $t=$43;
      var $44=$3;
      var $45=$t;
      var $46=(($44)>>>0) < (($45)>>>0);
      if ($46) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      var $48=$p;
      var $49=$2;
      var $50=$3;
      var $51=_HPDF_MemCpy($48, $49, $50);
      __label__ = 12; break;
    case 7: 
      var $53=$p;
      var $54=$2;
      var $55=$t;
      var $56=_HPDF_MemCpy($53, $54, $55);
      var $57=$1;
      var $58=(($57+24)|0);
      var $59=(($58)|0);
      _MD5ByteReverse($59, 16);
      var $60=$1;
      var $61=(($60)|0);
      var $62=(($61)|0);
      var $63=$1;
      var $64=(($63+24)|0);
      var $65=(($64)|0);
      var $66=$65;
      _MD5Transform($62, $66);
      var $67=$t;
      var $68=$2;
      var $69=(($68+$67)|0);
      $2=$69;
      var $70=$t;
      var $71=$3;
      var $72=((($71)-($70))|0);
      $3=$72;
      __label__ = 8; break;
    case 8: 
      __label__ = 9; break;
    case 9: 
      var $75=$3;
      var $76=(($75)>>>0) >= 64;
      if ($76) { __label__ = 10; break; } else { __label__ = 11; break; }
    case 10: 
      var $78=$1;
      var $79=(($78+24)|0);
      var $80=(($79)|0);
      var $81=$2;
      var $82=_HPDF_MemCpy($80, $81, 64);
      var $83=$1;
      var $84=(($83+24)|0);
      var $85=(($84)|0);
      _MD5ByteReverse($85, 16);
      var $86=$1;
      var $87=(($86)|0);
      var $88=(($87)|0);
      var $89=$1;
      var $90=(($89+24)|0);
      var $91=(($90)|0);
      var $92=$91;
      _MD5Transform($88, $92);
      var $93=$2;
      var $94=(($93+64)|0);
      $2=$94;
      var $95=$3;
      var $96=((($95)-(64))|0);
      $3=$96;
      __label__ = 9; break;
    case 11: 
      var $98=$1;
      var $99=(($98+24)|0);
      var $100=(($99)|0);
      var $101=$2;
      var $102=$3;
      var $103=_HPDF_MemCpy($100, $101, $102);
      __label__ = 12; break;
    case 12: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_MD5Update["X"]=1;

function _MD5Transform($buf, $in) {
  ;
  var __label__;

  var $1;
  var $2;
  var $a;
  var $b;
  var $c;
  var $d;
  $1=$buf;
  $2=$in;
  var $3=$1;
  var $4=(($3)|0);
  var $5=HEAP32[(($4)>>2)];
  $a=$5;
  var $6=$1;
  var $7=(($6+4)|0);
  var $8=HEAP32[(($7)>>2)];
  $b=$8;
  var $9=$1;
  var $10=(($9+8)|0);
  var $11=HEAP32[(($10)>>2)];
  $c=$11;
  var $12=$1;
  var $13=(($12+12)|0);
  var $14=HEAP32[(($13)>>2)];
  $d=$14;
  var $15=$d;
  var $16=$b;
  var $17=$c;
  var $18=$d;
  var $19=$17 ^ $18;
  var $20=$16 & $19;
  var $21=$15 ^ $20;
  var $22=$2;
  var $23=(($22)|0);
  var $24=HEAP32[(($23)>>2)];
  var $25=((($21)+($24))|0);
  var $26=((($25)-(680876936))|0);
  var $27=$a;
  var $28=((($27)+($26))|0);
  $a=$28;
  var $29=$a;
  var $30=$29 << 7;
  var $31=$a;
  var $32=$31 >>> 25;
  var $33=$30 | $32;
  $a=$33;
  var $34=$b;
  var $35=$a;
  var $36=((($35)+($34))|0);
  $a=$36;
  var $37=$c;
  var $38=$a;
  var $39=$b;
  var $40=$c;
  var $41=$39 ^ $40;
  var $42=$38 & $41;
  var $43=$37 ^ $42;
  var $44=$2;
  var $45=(($44+4)|0);
  var $46=HEAP32[(($45)>>2)];
  var $47=((($43)+($46))|0);
  var $48=((($47)-(389564586))|0);
  var $49=$d;
  var $50=((($49)+($48))|0);
  $d=$50;
  var $51=$d;
  var $52=$51 << 12;
  var $53=$d;
  var $54=$53 >>> 20;
  var $55=$52 | $54;
  $d=$55;
  var $56=$a;
  var $57=$d;
  var $58=((($57)+($56))|0);
  $d=$58;
  var $59=$b;
  var $60=$d;
  var $61=$a;
  var $62=$b;
  var $63=$61 ^ $62;
  var $64=$60 & $63;
  var $65=$59 ^ $64;
  var $66=$2;
  var $67=(($66+8)|0);
  var $68=HEAP32[(($67)>>2)];
  var $69=((($65)+($68))|0);
  var $70=((($69)+(606105819))|0);
  var $71=$c;
  var $72=((($71)+($70))|0);
  $c=$72;
  var $73=$c;
  var $74=$73 << 17;
  var $75=$c;
  var $76=$75 >>> 15;
  var $77=$74 | $76;
  $c=$77;
  var $78=$d;
  var $79=$c;
  var $80=((($79)+($78))|0);
  $c=$80;
  var $81=$a;
  var $82=$c;
  var $83=$d;
  var $84=$a;
  var $85=$83 ^ $84;
  var $86=$82 & $85;
  var $87=$81 ^ $86;
  var $88=$2;
  var $89=(($88+12)|0);
  var $90=HEAP32[(($89)>>2)];
  var $91=((($87)+($90))|0);
  var $92=((($91)-(1044525330))|0);
  var $93=$b;
  var $94=((($93)+($92))|0);
  $b=$94;
  var $95=$b;
  var $96=$95 << 22;
  var $97=$b;
  var $98=$97 >>> 10;
  var $99=$96 | $98;
  $b=$99;
  var $100=$c;
  var $101=$b;
  var $102=((($101)+($100))|0);
  $b=$102;
  var $103=$d;
  var $104=$b;
  var $105=$c;
  var $106=$d;
  var $107=$105 ^ $106;
  var $108=$104 & $107;
  var $109=$103 ^ $108;
  var $110=$2;
  var $111=(($110+16)|0);
  var $112=HEAP32[(($111)>>2)];
  var $113=((($109)+($112))|0);
  var $114=((($113)-(176418897))|0);
  var $115=$a;
  var $116=((($115)+($114))|0);
  $a=$116;
  var $117=$a;
  var $118=$117 << 7;
  var $119=$a;
  var $120=$119 >>> 25;
  var $121=$118 | $120;
  $a=$121;
  var $122=$b;
  var $123=$a;
  var $124=((($123)+($122))|0);
  $a=$124;
  var $125=$c;
  var $126=$a;
  var $127=$b;
  var $128=$c;
  var $129=$127 ^ $128;
  var $130=$126 & $129;
  var $131=$125 ^ $130;
  var $132=$2;
  var $133=(($132+20)|0);
  var $134=HEAP32[(($133)>>2)];
  var $135=((($131)+($134))|0);
  var $136=((($135)+(1200080426))|0);
  var $137=$d;
  var $138=((($137)+($136))|0);
  $d=$138;
  var $139=$d;
  var $140=$139 << 12;
  var $141=$d;
  var $142=$141 >>> 20;
  var $143=$140 | $142;
  $d=$143;
  var $144=$a;
  var $145=$d;
  var $146=((($145)+($144))|0);
  $d=$146;
  var $147=$b;
  var $148=$d;
  var $149=$a;
  var $150=$b;
  var $151=$149 ^ $150;
  var $152=$148 & $151;
  var $153=$147 ^ $152;
  var $154=$2;
  var $155=(($154+24)|0);
  var $156=HEAP32[(($155)>>2)];
  var $157=((($153)+($156))|0);
  var $158=((($157)-(1473231341))|0);
  var $159=$c;
  var $160=((($159)+($158))|0);
  $c=$160;
  var $161=$c;
  var $162=$161 << 17;
  var $163=$c;
  var $164=$163 >>> 15;
  var $165=$162 | $164;
  $c=$165;
  var $166=$d;
  var $167=$c;
  var $168=((($167)+($166))|0);
  $c=$168;
  var $169=$a;
  var $170=$c;
  var $171=$d;
  var $172=$a;
  var $173=$171 ^ $172;
  var $174=$170 & $173;
  var $175=$169 ^ $174;
  var $176=$2;
  var $177=(($176+28)|0);
  var $178=HEAP32[(($177)>>2)];
  var $179=((($175)+($178))|0);
  var $180=((($179)-(45705983))|0);
  var $181=$b;
  var $182=((($181)+($180))|0);
  $b=$182;
  var $183=$b;
  var $184=$183 << 22;
  var $185=$b;
  var $186=$185 >>> 10;
  var $187=$184 | $186;
  $b=$187;
  var $188=$c;
  var $189=$b;
  var $190=((($189)+($188))|0);
  $b=$190;
  var $191=$d;
  var $192=$b;
  var $193=$c;
  var $194=$d;
  var $195=$193 ^ $194;
  var $196=$192 & $195;
  var $197=$191 ^ $196;
  var $198=$2;
  var $199=(($198+32)|0);
  var $200=HEAP32[(($199)>>2)];
  var $201=((($197)+($200))|0);
  var $202=((($201)+(1770035416))|0);
  var $203=$a;
  var $204=((($203)+($202))|0);
  $a=$204;
  var $205=$a;
  var $206=$205 << 7;
  var $207=$a;
  var $208=$207 >>> 25;
  var $209=$206 | $208;
  $a=$209;
  var $210=$b;
  var $211=$a;
  var $212=((($211)+($210))|0);
  $a=$212;
  var $213=$c;
  var $214=$a;
  var $215=$b;
  var $216=$c;
  var $217=$215 ^ $216;
  var $218=$214 & $217;
  var $219=$213 ^ $218;
  var $220=$2;
  var $221=(($220+36)|0);
  var $222=HEAP32[(($221)>>2)];
  var $223=((($219)+($222))|0);
  var $224=((($223)-(1958414417))|0);
  var $225=$d;
  var $226=((($225)+($224))|0);
  $d=$226;
  var $227=$d;
  var $228=$227 << 12;
  var $229=$d;
  var $230=$229 >>> 20;
  var $231=$228 | $230;
  $d=$231;
  var $232=$a;
  var $233=$d;
  var $234=((($233)+($232))|0);
  $d=$234;
  var $235=$b;
  var $236=$d;
  var $237=$a;
  var $238=$b;
  var $239=$237 ^ $238;
  var $240=$236 & $239;
  var $241=$235 ^ $240;
  var $242=$2;
  var $243=(($242+40)|0);
  var $244=HEAP32[(($243)>>2)];
  var $245=((($241)+($244))|0);
  var $246=((($245)-(42063))|0);
  var $247=$c;
  var $248=((($247)+($246))|0);
  $c=$248;
  var $249=$c;
  var $250=$249 << 17;
  var $251=$c;
  var $252=$251 >>> 15;
  var $253=$250 | $252;
  $c=$253;
  var $254=$d;
  var $255=$c;
  var $256=((($255)+($254))|0);
  $c=$256;
  var $257=$a;
  var $258=$c;
  var $259=$d;
  var $260=$a;
  var $261=$259 ^ $260;
  var $262=$258 & $261;
  var $263=$257 ^ $262;
  var $264=$2;
  var $265=(($264+44)|0);
  var $266=HEAP32[(($265)>>2)];
  var $267=((($263)+($266))|0);
  var $268=((($267)-(1990404162))|0);
  var $269=$b;
  var $270=((($269)+($268))|0);
  $b=$270;
  var $271=$b;
  var $272=$271 << 22;
  var $273=$b;
  var $274=$273 >>> 10;
  var $275=$272 | $274;
  $b=$275;
  var $276=$c;
  var $277=$b;
  var $278=((($277)+($276))|0);
  $b=$278;
  var $279=$d;
  var $280=$b;
  var $281=$c;
  var $282=$d;
  var $283=$281 ^ $282;
  var $284=$280 & $283;
  var $285=$279 ^ $284;
  var $286=$2;
  var $287=(($286+48)|0);
  var $288=HEAP32[(($287)>>2)];
  var $289=((($285)+($288))|0);
  var $290=((($289)+(1804603682))|0);
  var $291=$a;
  var $292=((($291)+($290))|0);
  $a=$292;
  var $293=$a;
  var $294=$293 << 7;
  var $295=$a;
  var $296=$295 >>> 25;
  var $297=$294 | $296;
  $a=$297;
  var $298=$b;
  var $299=$a;
  var $300=((($299)+($298))|0);
  $a=$300;
  var $301=$c;
  var $302=$a;
  var $303=$b;
  var $304=$c;
  var $305=$303 ^ $304;
  var $306=$302 & $305;
  var $307=$301 ^ $306;
  var $308=$2;
  var $309=(($308+52)|0);
  var $310=HEAP32[(($309)>>2)];
  var $311=((($307)+($310))|0);
  var $312=((($311)-(40341101))|0);
  var $313=$d;
  var $314=((($313)+($312))|0);
  $d=$314;
  var $315=$d;
  var $316=$315 << 12;
  var $317=$d;
  var $318=$317 >>> 20;
  var $319=$316 | $318;
  $d=$319;
  var $320=$a;
  var $321=$d;
  var $322=((($321)+($320))|0);
  $d=$322;
  var $323=$b;
  var $324=$d;
  var $325=$a;
  var $326=$b;
  var $327=$325 ^ $326;
  var $328=$324 & $327;
  var $329=$323 ^ $328;
  var $330=$2;
  var $331=(($330+56)|0);
  var $332=HEAP32[(($331)>>2)];
  var $333=((($329)+($332))|0);
  var $334=((($333)-(1502002290))|0);
  var $335=$c;
  var $336=((($335)+($334))|0);
  $c=$336;
  var $337=$c;
  var $338=$337 << 17;
  var $339=$c;
  var $340=$339 >>> 15;
  var $341=$338 | $340;
  $c=$341;
  var $342=$d;
  var $343=$c;
  var $344=((($343)+($342))|0);
  $c=$344;
  var $345=$a;
  var $346=$c;
  var $347=$d;
  var $348=$a;
  var $349=$347 ^ $348;
  var $350=$346 & $349;
  var $351=$345 ^ $350;
  var $352=$2;
  var $353=(($352+60)|0);
  var $354=HEAP32[(($353)>>2)];
  var $355=((($351)+($354))|0);
  var $356=((($355)+(1236535329))|0);
  var $357=$b;
  var $358=((($357)+($356))|0);
  $b=$358;
  var $359=$b;
  var $360=$359 << 22;
  var $361=$b;
  var $362=$361 >>> 10;
  var $363=$360 | $362;
  $b=$363;
  var $364=$c;
  var $365=$b;
  var $366=((($365)+($364))|0);
  $b=$366;
  var $367=$c;
  var $368=$d;
  var $369=$b;
  var $370=$c;
  var $371=$369 ^ $370;
  var $372=$368 & $371;
  var $373=$367 ^ $372;
  var $374=$2;
  var $375=(($374+4)|0);
  var $376=HEAP32[(($375)>>2)];
  var $377=((($373)+($376))|0);
  var $378=((($377)-(165796510))|0);
  var $379=$a;
  var $380=((($379)+($378))|0);
  $a=$380;
  var $381=$a;
  var $382=$381 << 5;
  var $383=$a;
  var $384=$383 >>> 27;
  var $385=$382 | $384;
  $a=$385;
  var $386=$b;
  var $387=$a;
  var $388=((($387)+($386))|0);
  $a=$388;
  var $389=$b;
  var $390=$c;
  var $391=$a;
  var $392=$b;
  var $393=$391 ^ $392;
  var $394=$390 & $393;
  var $395=$389 ^ $394;
  var $396=$2;
  var $397=(($396+24)|0);
  var $398=HEAP32[(($397)>>2)];
  var $399=((($395)+($398))|0);
  var $400=((($399)-(1069501632))|0);
  var $401=$d;
  var $402=((($401)+($400))|0);
  $d=$402;
  var $403=$d;
  var $404=$403 << 9;
  var $405=$d;
  var $406=$405 >>> 23;
  var $407=$404 | $406;
  $d=$407;
  var $408=$a;
  var $409=$d;
  var $410=((($409)+($408))|0);
  $d=$410;
  var $411=$a;
  var $412=$b;
  var $413=$d;
  var $414=$a;
  var $415=$413 ^ $414;
  var $416=$412 & $415;
  var $417=$411 ^ $416;
  var $418=$2;
  var $419=(($418+44)|0);
  var $420=HEAP32[(($419)>>2)];
  var $421=((($417)+($420))|0);
  var $422=((($421)+(643717713))|0);
  var $423=$c;
  var $424=((($423)+($422))|0);
  $c=$424;
  var $425=$c;
  var $426=$425 << 14;
  var $427=$c;
  var $428=$427 >>> 18;
  var $429=$426 | $428;
  $c=$429;
  var $430=$d;
  var $431=$c;
  var $432=((($431)+($430))|0);
  $c=$432;
  var $433=$d;
  var $434=$a;
  var $435=$c;
  var $436=$d;
  var $437=$435 ^ $436;
  var $438=$434 & $437;
  var $439=$433 ^ $438;
  var $440=$2;
  var $441=(($440)|0);
  var $442=HEAP32[(($441)>>2)];
  var $443=((($439)+($442))|0);
  var $444=((($443)-(373897302))|0);
  var $445=$b;
  var $446=((($445)+($444))|0);
  $b=$446;
  var $447=$b;
  var $448=$447 << 20;
  var $449=$b;
  var $450=$449 >>> 12;
  var $451=$448 | $450;
  $b=$451;
  var $452=$c;
  var $453=$b;
  var $454=((($453)+($452))|0);
  $b=$454;
  var $455=$c;
  var $456=$d;
  var $457=$b;
  var $458=$c;
  var $459=$457 ^ $458;
  var $460=$456 & $459;
  var $461=$455 ^ $460;
  var $462=$2;
  var $463=(($462+20)|0);
  var $464=HEAP32[(($463)>>2)];
  var $465=((($461)+($464))|0);
  var $466=((($465)-(701558691))|0);
  var $467=$a;
  var $468=((($467)+($466))|0);
  $a=$468;
  var $469=$a;
  var $470=$469 << 5;
  var $471=$a;
  var $472=$471 >>> 27;
  var $473=$470 | $472;
  $a=$473;
  var $474=$b;
  var $475=$a;
  var $476=((($475)+($474))|0);
  $a=$476;
  var $477=$b;
  var $478=$c;
  var $479=$a;
  var $480=$b;
  var $481=$479 ^ $480;
  var $482=$478 & $481;
  var $483=$477 ^ $482;
  var $484=$2;
  var $485=(($484+40)|0);
  var $486=HEAP32[(($485)>>2)];
  var $487=((($483)+($486))|0);
  var $488=((($487)+(38016083))|0);
  var $489=$d;
  var $490=((($489)+($488))|0);
  $d=$490;
  var $491=$d;
  var $492=$491 << 9;
  var $493=$d;
  var $494=$493 >>> 23;
  var $495=$492 | $494;
  $d=$495;
  var $496=$a;
  var $497=$d;
  var $498=((($497)+($496))|0);
  $d=$498;
  var $499=$a;
  var $500=$b;
  var $501=$d;
  var $502=$a;
  var $503=$501 ^ $502;
  var $504=$500 & $503;
  var $505=$499 ^ $504;
  var $506=$2;
  var $507=(($506+60)|0);
  var $508=HEAP32[(($507)>>2)];
  var $509=((($505)+($508))|0);
  var $510=((($509)-(660478335))|0);
  var $511=$c;
  var $512=((($511)+($510))|0);
  $c=$512;
  var $513=$c;
  var $514=$513 << 14;
  var $515=$c;
  var $516=$515 >>> 18;
  var $517=$514 | $516;
  $c=$517;
  var $518=$d;
  var $519=$c;
  var $520=((($519)+($518))|0);
  $c=$520;
  var $521=$d;
  var $522=$a;
  var $523=$c;
  var $524=$d;
  var $525=$523 ^ $524;
  var $526=$522 & $525;
  var $527=$521 ^ $526;
  var $528=$2;
  var $529=(($528+16)|0);
  var $530=HEAP32[(($529)>>2)];
  var $531=((($527)+($530))|0);
  var $532=((($531)-(405537848))|0);
  var $533=$b;
  var $534=((($533)+($532))|0);
  $b=$534;
  var $535=$b;
  var $536=$535 << 20;
  var $537=$b;
  var $538=$537 >>> 12;
  var $539=$536 | $538;
  $b=$539;
  var $540=$c;
  var $541=$b;
  var $542=((($541)+($540))|0);
  $b=$542;
  var $543=$c;
  var $544=$d;
  var $545=$b;
  var $546=$c;
  var $547=$545 ^ $546;
  var $548=$544 & $547;
  var $549=$543 ^ $548;
  var $550=$2;
  var $551=(($550+36)|0);
  var $552=HEAP32[(($551)>>2)];
  var $553=((($549)+($552))|0);
  var $554=((($553)+(568446438))|0);
  var $555=$a;
  var $556=((($555)+($554))|0);
  $a=$556;
  var $557=$a;
  var $558=$557 << 5;
  var $559=$a;
  var $560=$559 >>> 27;
  var $561=$558 | $560;
  $a=$561;
  var $562=$b;
  var $563=$a;
  var $564=((($563)+($562))|0);
  $a=$564;
  var $565=$b;
  var $566=$c;
  var $567=$a;
  var $568=$b;
  var $569=$567 ^ $568;
  var $570=$566 & $569;
  var $571=$565 ^ $570;
  var $572=$2;
  var $573=(($572+56)|0);
  var $574=HEAP32[(($573)>>2)];
  var $575=((($571)+($574))|0);
  var $576=((($575)-(1019803690))|0);
  var $577=$d;
  var $578=((($577)+($576))|0);
  $d=$578;
  var $579=$d;
  var $580=$579 << 9;
  var $581=$d;
  var $582=$581 >>> 23;
  var $583=$580 | $582;
  $d=$583;
  var $584=$a;
  var $585=$d;
  var $586=((($585)+($584))|0);
  $d=$586;
  var $587=$a;
  var $588=$b;
  var $589=$d;
  var $590=$a;
  var $591=$589 ^ $590;
  var $592=$588 & $591;
  var $593=$587 ^ $592;
  var $594=$2;
  var $595=(($594+12)|0);
  var $596=HEAP32[(($595)>>2)];
  var $597=((($593)+($596))|0);
  var $598=((($597)-(187363961))|0);
  var $599=$c;
  var $600=((($599)+($598))|0);
  $c=$600;
  var $601=$c;
  var $602=$601 << 14;
  var $603=$c;
  var $604=$603 >>> 18;
  var $605=$602 | $604;
  $c=$605;
  var $606=$d;
  var $607=$c;
  var $608=((($607)+($606))|0);
  $c=$608;
  var $609=$d;
  var $610=$a;
  var $611=$c;
  var $612=$d;
  var $613=$611 ^ $612;
  var $614=$610 & $613;
  var $615=$609 ^ $614;
  var $616=$2;
  var $617=(($616+32)|0);
  var $618=HEAP32[(($617)>>2)];
  var $619=((($615)+($618))|0);
  var $620=((($619)+(1163531501))|0);
  var $621=$b;
  var $622=((($621)+($620))|0);
  $b=$622;
  var $623=$b;
  var $624=$623 << 20;
  var $625=$b;
  var $626=$625 >>> 12;
  var $627=$624 | $626;
  $b=$627;
  var $628=$c;
  var $629=$b;
  var $630=((($629)+($628))|0);
  $b=$630;
  var $631=$c;
  var $632=$d;
  var $633=$b;
  var $634=$c;
  var $635=$633 ^ $634;
  var $636=$632 & $635;
  var $637=$631 ^ $636;
  var $638=$2;
  var $639=(($638+52)|0);
  var $640=HEAP32[(($639)>>2)];
  var $641=((($637)+($640))|0);
  var $642=((($641)-(1444681467))|0);
  var $643=$a;
  var $644=((($643)+($642))|0);
  $a=$644;
  var $645=$a;
  var $646=$645 << 5;
  var $647=$a;
  var $648=$647 >>> 27;
  var $649=$646 | $648;
  $a=$649;
  var $650=$b;
  var $651=$a;
  var $652=((($651)+($650))|0);
  $a=$652;
  var $653=$b;
  var $654=$c;
  var $655=$a;
  var $656=$b;
  var $657=$655 ^ $656;
  var $658=$654 & $657;
  var $659=$653 ^ $658;
  var $660=$2;
  var $661=(($660+8)|0);
  var $662=HEAP32[(($661)>>2)];
  var $663=((($659)+($662))|0);
  var $664=((($663)-(51403784))|0);
  var $665=$d;
  var $666=((($665)+($664))|0);
  $d=$666;
  var $667=$d;
  var $668=$667 << 9;
  var $669=$d;
  var $670=$669 >>> 23;
  var $671=$668 | $670;
  $d=$671;
  var $672=$a;
  var $673=$d;
  var $674=((($673)+($672))|0);
  $d=$674;
  var $675=$a;
  var $676=$b;
  var $677=$d;
  var $678=$a;
  var $679=$677 ^ $678;
  var $680=$676 & $679;
  var $681=$675 ^ $680;
  var $682=$2;
  var $683=(($682+28)|0);
  var $684=HEAP32[(($683)>>2)];
  var $685=((($681)+($684))|0);
  var $686=((($685)+(1735328473))|0);
  var $687=$c;
  var $688=((($687)+($686))|0);
  $c=$688;
  var $689=$c;
  var $690=$689 << 14;
  var $691=$c;
  var $692=$691 >>> 18;
  var $693=$690 | $692;
  $c=$693;
  var $694=$d;
  var $695=$c;
  var $696=((($695)+($694))|0);
  $c=$696;
  var $697=$d;
  var $698=$a;
  var $699=$c;
  var $700=$d;
  var $701=$699 ^ $700;
  var $702=$698 & $701;
  var $703=$697 ^ $702;
  var $704=$2;
  var $705=(($704+48)|0);
  var $706=HEAP32[(($705)>>2)];
  var $707=((($703)+($706))|0);
  var $708=((($707)-(1926607734))|0);
  var $709=$b;
  var $710=((($709)+($708))|0);
  $b=$710;
  var $711=$b;
  var $712=$711 << 20;
  var $713=$b;
  var $714=$713 >>> 12;
  var $715=$712 | $714;
  $b=$715;
  var $716=$c;
  var $717=$b;
  var $718=((($717)+($716))|0);
  $b=$718;
  var $719=$b;
  var $720=$c;
  var $721=$719 ^ $720;
  var $722=$d;
  var $723=$721 ^ $722;
  var $724=$2;
  var $725=(($724+20)|0);
  var $726=HEAP32[(($725)>>2)];
  var $727=((($723)+($726))|0);
  var $728=((($727)-(378558))|0);
  var $729=$a;
  var $730=((($729)+($728))|0);
  $a=$730;
  var $731=$a;
  var $732=$731 << 4;
  var $733=$a;
  var $734=$733 >>> 28;
  var $735=$732 | $734;
  $a=$735;
  var $736=$b;
  var $737=$a;
  var $738=((($737)+($736))|0);
  $a=$738;
  var $739=$a;
  var $740=$b;
  var $741=$739 ^ $740;
  var $742=$c;
  var $743=$741 ^ $742;
  var $744=$2;
  var $745=(($744+32)|0);
  var $746=HEAP32[(($745)>>2)];
  var $747=((($743)+($746))|0);
  var $748=((($747)-(2022574463))|0);
  var $749=$d;
  var $750=((($749)+($748))|0);
  $d=$750;
  var $751=$d;
  var $752=$751 << 11;
  var $753=$d;
  var $754=$753 >>> 21;
  var $755=$752 | $754;
  $d=$755;
  var $756=$a;
  var $757=$d;
  var $758=((($757)+($756))|0);
  $d=$758;
  var $759=$d;
  var $760=$a;
  var $761=$759 ^ $760;
  var $762=$b;
  var $763=$761 ^ $762;
  var $764=$2;
  var $765=(($764+44)|0);
  var $766=HEAP32[(($765)>>2)];
  var $767=((($763)+($766))|0);
  var $768=((($767)+(1839030562))|0);
  var $769=$c;
  var $770=((($769)+($768))|0);
  $c=$770;
  var $771=$c;
  var $772=$771 << 16;
  var $773=$c;
  var $774=$773 >>> 16;
  var $775=$772 | $774;
  $c=$775;
  var $776=$d;
  var $777=$c;
  var $778=((($777)+($776))|0);
  $c=$778;
  var $779=$c;
  var $780=$d;
  var $781=$779 ^ $780;
  var $782=$a;
  var $783=$781 ^ $782;
  var $784=$2;
  var $785=(($784+56)|0);
  var $786=HEAP32[(($785)>>2)];
  var $787=((($783)+($786))|0);
  var $788=((($787)-(35309556))|0);
  var $789=$b;
  var $790=((($789)+($788))|0);
  $b=$790;
  var $791=$b;
  var $792=$791 << 23;
  var $793=$b;
  var $794=$793 >>> 9;
  var $795=$792 | $794;
  $b=$795;
  var $796=$c;
  var $797=$b;
  var $798=((($797)+($796))|0);
  $b=$798;
  var $799=$b;
  var $800=$c;
  var $801=$799 ^ $800;
  var $802=$d;
  var $803=$801 ^ $802;
  var $804=$2;
  var $805=(($804+4)|0);
  var $806=HEAP32[(($805)>>2)];
  var $807=((($803)+($806))|0);
  var $808=((($807)-(1530992060))|0);
  var $809=$a;
  var $810=((($809)+($808))|0);
  $a=$810;
  var $811=$a;
  var $812=$811 << 4;
  var $813=$a;
  var $814=$813 >>> 28;
  var $815=$812 | $814;
  $a=$815;
  var $816=$b;
  var $817=$a;
  var $818=((($817)+($816))|0);
  $a=$818;
  var $819=$a;
  var $820=$b;
  var $821=$819 ^ $820;
  var $822=$c;
  var $823=$821 ^ $822;
  var $824=$2;
  var $825=(($824+16)|0);
  var $826=HEAP32[(($825)>>2)];
  var $827=((($823)+($826))|0);
  var $828=((($827)+(1272893353))|0);
  var $829=$d;
  var $830=((($829)+($828))|0);
  $d=$830;
  var $831=$d;
  var $832=$831 << 11;
  var $833=$d;
  var $834=$833 >>> 21;
  var $835=$832 | $834;
  $d=$835;
  var $836=$a;
  var $837=$d;
  var $838=((($837)+($836))|0);
  $d=$838;
  var $839=$d;
  var $840=$a;
  var $841=$839 ^ $840;
  var $842=$b;
  var $843=$841 ^ $842;
  var $844=$2;
  var $845=(($844+28)|0);
  var $846=HEAP32[(($845)>>2)];
  var $847=((($843)+($846))|0);
  var $848=((($847)-(155497632))|0);
  var $849=$c;
  var $850=((($849)+($848))|0);
  $c=$850;
  var $851=$c;
  var $852=$851 << 16;
  var $853=$c;
  var $854=$853 >>> 16;
  var $855=$852 | $854;
  $c=$855;
  var $856=$d;
  var $857=$c;
  var $858=((($857)+($856))|0);
  $c=$858;
  var $859=$c;
  var $860=$d;
  var $861=$859 ^ $860;
  var $862=$a;
  var $863=$861 ^ $862;
  var $864=$2;
  var $865=(($864+40)|0);
  var $866=HEAP32[(($865)>>2)];
  var $867=((($863)+($866))|0);
  var $868=((($867)-(1094730640))|0);
  var $869=$b;
  var $870=((($869)+($868))|0);
  $b=$870;
  var $871=$b;
  var $872=$871 << 23;
  var $873=$b;
  var $874=$873 >>> 9;
  var $875=$872 | $874;
  $b=$875;
  var $876=$c;
  var $877=$b;
  var $878=((($877)+($876))|0);
  $b=$878;
  var $879=$b;
  var $880=$c;
  var $881=$879 ^ $880;
  var $882=$d;
  var $883=$881 ^ $882;
  var $884=$2;
  var $885=(($884+52)|0);
  var $886=HEAP32[(($885)>>2)];
  var $887=((($883)+($886))|0);
  var $888=((($887)+(681279174))|0);
  var $889=$a;
  var $890=((($889)+($888))|0);
  $a=$890;
  var $891=$a;
  var $892=$891 << 4;
  var $893=$a;
  var $894=$893 >>> 28;
  var $895=$892 | $894;
  $a=$895;
  var $896=$b;
  var $897=$a;
  var $898=((($897)+($896))|0);
  $a=$898;
  var $899=$a;
  var $900=$b;
  var $901=$899 ^ $900;
  var $902=$c;
  var $903=$901 ^ $902;
  var $904=$2;
  var $905=(($904)|0);
  var $906=HEAP32[(($905)>>2)];
  var $907=((($903)+($906))|0);
  var $908=((($907)-(358537222))|0);
  var $909=$d;
  var $910=((($909)+($908))|0);
  $d=$910;
  var $911=$d;
  var $912=$911 << 11;
  var $913=$d;
  var $914=$913 >>> 21;
  var $915=$912 | $914;
  $d=$915;
  var $916=$a;
  var $917=$d;
  var $918=((($917)+($916))|0);
  $d=$918;
  var $919=$d;
  var $920=$a;
  var $921=$919 ^ $920;
  var $922=$b;
  var $923=$921 ^ $922;
  var $924=$2;
  var $925=(($924+12)|0);
  var $926=HEAP32[(($925)>>2)];
  var $927=((($923)+($926))|0);
  var $928=((($927)-(722521979))|0);
  var $929=$c;
  var $930=((($929)+($928))|0);
  $c=$930;
  var $931=$c;
  var $932=$931 << 16;
  var $933=$c;
  var $934=$933 >>> 16;
  var $935=$932 | $934;
  $c=$935;
  var $936=$d;
  var $937=$c;
  var $938=((($937)+($936))|0);
  $c=$938;
  var $939=$c;
  var $940=$d;
  var $941=$939 ^ $940;
  var $942=$a;
  var $943=$941 ^ $942;
  var $944=$2;
  var $945=(($944+24)|0);
  var $946=HEAP32[(($945)>>2)];
  var $947=((($943)+($946))|0);
  var $948=((($947)+(76029189))|0);
  var $949=$b;
  var $950=((($949)+($948))|0);
  $b=$950;
  var $951=$b;
  var $952=$951 << 23;
  var $953=$b;
  var $954=$953 >>> 9;
  var $955=$952 | $954;
  $b=$955;
  var $956=$c;
  var $957=$b;
  var $958=((($957)+($956))|0);
  $b=$958;
  var $959=$b;
  var $960=$c;
  var $961=$959 ^ $960;
  var $962=$d;
  var $963=$961 ^ $962;
  var $964=$2;
  var $965=(($964+36)|0);
  var $966=HEAP32[(($965)>>2)];
  var $967=((($963)+($966))|0);
  var $968=((($967)-(640364487))|0);
  var $969=$a;
  var $970=((($969)+($968))|0);
  $a=$970;
  var $971=$a;
  var $972=$971 << 4;
  var $973=$a;
  var $974=$973 >>> 28;
  var $975=$972 | $974;
  $a=$975;
  var $976=$b;
  var $977=$a;
  var $978=((($977)+($976))|0);
  $a=$978;
  var $979=$a;
  var $980=$b;
  var $981=$979 ^ $980;
  var $982=$c;
  var $983=$981 ^ $982;
  var $984=$2;
  var $985=(($984+48)|0);
  var $986=HEAP32[(($985)>>2)];
  var $987=((($983)+($986))|0);
  var $988=((($987)-(421815835))|0);
  var $989=$d;
  var $990=((($989)+($988))|0);
  $d=$990;
  var $991=$d;
  var $992=$991 << 11;
  var $993=$d;
  var $994=$993 >>> 21;
  var $995=$992 | $994;
  $d=$995;
  var $996=$a;
  var $997=$d;
  var $998=((($997)+($996))|0);
  $d=$998;
  var $999=$d;
  var $1000=$a;
  var $1001=$999 ^ $1000;
  var $1002=$b;
  var $1003=$1001 ^ $1002;
  var $1004=$2;
  var $1005=(($1004+60)|0);
  var $1006=HEAP32[(($1005)>>2)];
  var $1007=((($1003)+($1006))|0);
  var $1008=((($1007)+(530742520))|0);
  var $1009=$c;
  var $1010=((($1009)+($1008))|0);
  $c=$1010;
  var $1011=$c;
  var $1012=$1011 << 16;
  var $1013=$c;
  var $1014=$1013 >>> 16;
  var $1015=$1012 | $1014;
  $c=$1015;
  var $1016=$d;
  var $1017=$c;
  var $1018=((($1017)+($1016))|0);
  $c=$1018;
  var $1019=$c;
  var $1020=$d;
  var $1021=$1019 ^ $1020;
  var $1022=$a;
  var $1023=$1021 ^ $1022;
  var $1024=$2;
  var $1025=(($1024+8)|0);
  var $1026=HEAP32[(($1025)>>2)];
  var $1027=((($1023)+($1026))|0);
  var $1028=((($1027)-(995338651))|0);
  var $1029=$b;
  var $1030=((($1029)+($1028))|0);
  $b=$1030;
  var $1031=$b;
  var $1032=$1031 << 23;
  var $1033=$b;
  var $1034=$1033 >>> 9;
  var $1035=$1032 | $1034;
  $b=$1035;
  var $1036=$c;
  var $1037=$b;
  var $1038=((($1037)+($1036))|0);
  $b=$1038;
  var $1039=$c;
  var $1040=$b;
  var $1041=$d;
  var $1042=$1041 ^ -1;
  var $1043=$1040 | $1042;
  var $1044=$1039 ^ $1043;
  var $1045=$2;
  var $1046=(($1045)|0);
  var $1047=HEAP32[(($1046)>>2)];
  var $1048=((($1044)+($1047))|0);
  var $1049=((($1048)-(198630844))|0);
  var $1050=$a;
  var $1051=((($1050)+($1049))|0);
  $a=$1051;
  var $1052=$a;
  var $1053=$1052 << 6;
  var $1054=$a;
  var $1055=$1054 >>> 26;
  var $1056=$1053 | $1055;
  $a=$1056;
  var $1057=$b;
  var $1058=$a;
  var $1059=((($1058)+($1057))|0);
  $a=$1059;
  var $1060=$b;
  var $1061=$a;
  var $1062=$c;
  var $1063=$1062 ^ -1;
  var $1064=$1061 | $1063;
  var $1065=$1060 ^ $1064;
  var $1066=$2;
  var $1067=(($1066+28)|0);
  var $1068=HEAP32[(($1067)>>2)];
  var $1069=((($1065)+($1068))|0);
  var $1070=((($1069)+(1126891415))|0);
  var $1071=$d;
  var $1072=((($1071)+($1070))|0);
  $d=$1072;
  var $1073=$d;
  var $1074=$1073 << 10;
  var $1075=$d;
  var $1076=$1075 >>> 22;
  var $1077=$1074 | $1076;
  $d=$1077;
  var $1078=$a;
  var $1079=$d;
  var $1080=((($1079)+($1078))|0);
  $d=$1080;
  var $1081=$a;
  var $1082=$d;
  var $1083=$b;
  var $1084=$1083 ^ -1;
  var $1085=$1082 | $1084;
  var $1086=$1081 ^ $1085;
  var $1087=$2;
  var $1088=(($1087+56)|0);
  var $1089=HEAP32[(($1088)>>2)];
  var $1090=((($1086)+($1089))|0);
  var $1091=((($1090)-(1416354905))|0);
  var $1092=$c;
  var $1093=((($1092)+($1091))|0);
  $c=$1093;
  var $1094=$c;
  var $1095=$1094 << 15;
  var $1096=$c;
  var $1097=$1096 >>> 17;
  var $1098=$1095 | $1097;
  $c=$1098;
  var $1099=$d;
  var $1100=$c;
  var $1101=((($1100)+($1099))|0);
  $c=$1101;
  var $1102=$d;
  var $1103=$c;
  var $1104=$a;
  var $1105=$1104 ^ -1;
  var $1106=$1103 | $1105;
  var $1107=$1102 ^ $1106;
  var $1108=$2;
  var $1109=(($1108+20)|0);
  var $1110=HEAP32[(($1109)>>2)];
  var $1111=((($1107)+($1110))|0);
  var $1112=((($1111)-(57434055))|0);
  var $1113=$b;
  var $1114=((($1113)+($1112))|0);
  $b=$1114;
  var $1115=$b;
  var $1116=$1115 << 21;
  var $1117=$b;
  var $1118=$1117 >>> 11;
  var $1119=$1116 | $1118;
  $b=$1119;
  var $1120=$c;
  var $1121=$b;
  var $1122=((($1121)+($1120))|0);
  $b=$1122;
  var $1123=$c;
  var $1124=$b;
  var $1125=$d;
  var $1126=$1125 ^ -1;
  var $1127=$1124 | $1126;
  var $1128=$1123 ^ $1127;
  var $1129=$2;
  var $1130=(($1129+48)|0);
  var $1131=HEAP32[(($1130)>>2)];
  var $1132=((($1128)+($1131))|0);
  var $1133=((($1132)+(1700485571))|0);
  var $1134=$a;
  var $1135=((($1134)+($1133))|0);
  $a=$1135;
  var $1136=$a;
  var $1137=$1136 << 6;
  var $1138=$a;
  var $1139=$1138 >>> 26;
  var $1140=$1137 | $1139;
  $a=$1140;
  var $1141=$b;
  var $1142=$a;
  var $1143=((($1142)+($1141))|0);
  $a=$1143;
  var $1144=$b;
  var $1145=$a;
  var $1146=$c;
  var $1147=$1146 ^ -1;
  var $1148=$1145 | $1147;
  var $1149=$1144 ^ $1148;
  var $1150=$2;
  var $1151=(($1150+12)|0);
  var $1152=HEAP32[(($1151)>>2)];
  var $1153=((($1149)+($1152))|0);
  var $1154=((($1153)-(1894986606))|0);
  var $1155=$d;
  var $1156=((($1155)+($1154))|0);
  $d=$1156;
  var $1157=$d;
  var $1158=$1157 << 10;
  var $1159=$d;
  var $1160=$1159 >>> 22;
  var $1161=$1158 | $1160;
  $d=$1161;
  var $1162=$a;
  var $1163=$d;
  var $1164=((($1163)+($1162))|0);
  $d=$1164;
  var $1165=$a;
  var $1166=$d;
  var $1167=$b;
  var $1168=$1167 ^ -1;
  var $1169=$1166 | $1168;
  var $1170=$1165 ^ $1169;
  var $1171=$2;
  var $1172=(($1171+40)|0);
  var $1173=HEAP32[(($1172)>>2)];
  var $1174=((($1170)+($1173))|0);
  var $1175=((($1174)-(1051523))|0);
  var $1176=$c;
  var $1177=((($1176)+($1175))|0);
  $c=$1177;
  var $1178=$c;
  var $1179=$1178 << 15;
  var $1180=$c;
  var $1181=$1180 >>> 17;
  var $1182=$1179 | $1181;
  $c=$1182;
  var $1183=$d;
  var $1184=$c;
  var $1185=((($1184)+($1183))|0);
  $c=$1185;
  var $1186=$d;
  var $1187=$c;
  var $1188=$a;
  var $1189=$1188 ^ -1;
  var $1190=$1187 | $1189;
  var $1191=$1186 ^ $1190;
  var $1192=$2;
  var $1193=(($1192+4)|0);
  var $1194=HEAP32[(($1193)>>2)];
  var $1195=((($1191)+($1194))|0);
  var $1196=((($1195)-(2054922799))|0);
  var $1197=$b;
  var $1198=((($1197)+($1196))|0);
  $b=$1198;
  var $1199=$b;
  var $1200=$1199 << 21;
  var $1201=$b;
  var $1202=$1201 >>> 11;
  var $1203=$1200 | $1202;
  $b=$1203;
  var $1204=$c;
  var $1205=$b;
  var $1206=((($1205)+($1204))|0);
  $b=$1206;
  var $1207=$c;
  var $1208=$b;
  var $1209=$d;
  var $1210=$1209 ^ -1;
  var $1211=$1208 | $1210;
  var $1212=$1207 ^ $1211;
  var $1213=$2;
  var $1214=(($1213+32)|0);
  var $1215=HEAP32[(($1214)>>2)];
  var $1216=((($1212)+($1215))|0);
  var $1217=((($1216)+(1873313359))|0);
  var $1218=$a;
  var $1219=((($1218)+($1217))|0);
  $a=$1219;
  var $1220=$a;
  var $1221=$1220 << 6;
  var $1222=$a;
  var $1223=$1222 >>> 26;
  var $1224=$1221 | $1223;
  $a=$1224;
  var $1225=$b;
  var $1226=$a;
  var $1227=((($1226)+($1225))|0);
  $a=$1227;
  var $1228=$b;
  var $1229=$a;
  var $1230=$c;
  var $1231=$1230 ^ -1;
  var $1232=$1229 | $1231;
  var $1233=$1228 ^ $1232;
  var $1234=$2;
  var $1235=(($1234+60)|0);
  var $1236=HEAP32[(($1235)>>2)];
  var $1237=((($1233)+($1236))|0);
  var $1238=((($1237)-(30611744))|0);
  var $1239=$d;
  var $1240=((($1239)+($1238))|0);
  $d=$1240;
  var $1241=$d;
  var $1242=$1241 << 10;
  var $1243=$d;
  var $1244=$1243 >>> 22;
  var $1245=$1242 | $1244;
  $d=$1245;
  var $1246=$a;
  var $1247=$d;
  var $1248=((($1247)+($1246))|0);
  $d=$1248;
  var $1249=$a;
  var $1250=$d;
  var $1251=$b;
  var $1252=$1251 ^ -1;
  var $1253=$1250 | $1252;
  var $1254=$1249 ^ $1253;
  var $1255=$2;
  var $1256=(($1255+24)|0);
  var $1257=HEAP32[(($1256)>>2)];
  var $1258=((($1254)+($1257))|0);
  var $1259=((($1258)-(1560198380))|0);
  var $1260=$c;
  var $1261=((($1260)+($1259))|0);
  $c=$1261;
  var $1262=$c;
  var $1263=$1262 << 15;
  var $1264=$c;
  var $1265=$1264 >>> 17;
  var $1266=$1263 | $1265;
  $c=$1266;
  var $1267=$d;
  var $1268=$c;
  var $1269=((($1268)+($1267))|0);
  $c=$1269;
  var $1270=$d;
  var $1271=$c;
  var $1272=$a;
  var $1273=$1272 ^ -1;
  var $1274=$1271 | $1273;
  var $1275=$1270 ^ $1274;
  var $1276=$2;
  var $1277=(($1276+52)|0);
  var $1278=HEAP32[(($1277)>>2)];
  var $1279=((($1275)+($1278))|0);
  var $1280=((($1279)+(1309151649))|0);
  var $1281=$b;
  var $1282=((($1281)+($1280))|0);
  $b=$1282;
  var $1283=$b;
  var $1284=$1283 << 21;
  var $1285=$b;
  var $1286=$1285 >>> 11;
  var $1287=$1284 | $1286;
  $b=$1287;
  var $1288=$c;
  var $1289=$b;
  var $1290=((($1289)+($1288))|0);
  $b=$1290;
  var $1291=$c;
  var $1292=$b;
  var $1293=$d;
  var $1294=$1293 ^ -1;
  var $1295=$1292 | $1294;
  var $1296=$1291 ^ $1295;
  var $1297=$2;
  var $1298=(($1297+16)|0);
  var $1299=HEAP32[(($1298)>>2)];
  var $1300=((($1296)+($1299))|0);
  var $1301=((($1300)-(145523070))|0);
  var $1302=$a;
  var $1303=((($1302)+($1301))|0);
  $a=$1303;
  var $1304=$a;
  var $1305=$1304 << 6;
  var $1306=$a;
  var $1307=$1306 >>> 26;
  var $1308=$1305 | $1307;
  $a=$1308;
  var $1309=$b;
  var $1310=$a;
  var $1311=((($1310)+($1309))|0);
  $a=$1311;
  var $1312=$b;
  var $1313=$a;
  var $1314=$c;
  var $1315=$1314 ^ -1;
  var $1316=$1313 | $1315;
  var $1317=$1312 ^ $1316;
  var $1318=$2;
  var $1319=(($1318+44)|0);
  var $1320=HEAP32[(($1319)>>2)];
  var $1321=((($1317)+($1320))|0);
  var $1322=((($1321)-(1120210379))|0);
  var $1323=$d;
  var $1324=((($1323)+($1322))|0);
  $d=$1324;
  var $1325=$d;
  var $1326=$1325 << 10;
  var $1327=$d;
  var $1328=$1327 >>> 22;
  var $1329=$1326 | $1328;
  $d=$1329;
  var $1330=$a;
  var $1331=$d;
  var $1332=((($1331)+($1330))|0);
  $d=$1332;
  var $1333=$a;
  var $1334=$d;
  var $1335=$b;
  var $1336=$1335 ^ -1;
  var $1337=$1334 | $1336;
  var $1338=$1333 ^ $1337;
  var $1339=$2;
  var $1340=(($1339+8)|0);
  var $1341=HEAP32[(($1340)>>2)];
  var $1342=((($1338)+($1341))|0);
  var $1343=((($1342)+(718787259))|0);
  var $1344=$c;
  var $1345=((($1344)+($1343))|0);
  $c=$1345;
  var $1346=$c;
  var $1347=$1346 << 15;
  var $1348=$c;
  var $1349=$1348 >>> 17;
  var $1350=$1347 | $1349;
  $c=$1350;
  var $1351=$d;
  var $1352=$c;
  var $1353=((($1352)+($1351))|0);
  $c=$1353;
  var $1354=$d;
  var $1355=$c;
  var $1356=$a;
  var $1357=$1356 ^ -1;
  var $1358=$1355 | $1357;
  var $1359=$1354 ^ $1358;
  var $1360=$2;
  var $1361=(($1360+36)|0);
  var $1362=HEAP32[(($1361)>>2)];
  var $1363=((($1359)+($1362))|0);
  var $1364=((($1363)-(343485551))|0);
  var $1365=$b;
  var $1366=((($1365)+($1364))|0);
  $b=$1366;
  var $1367=$b;
  var $1368=$1367 << 21;
  var $1369=$b;
  var $1370=$1369 >>> 11;
  var $1371=$1368 | $1370;
  $b=$1371;
  var $1372=$c;
  var $1373=$b;
  var $1374=((($1373)+($1372))|0);
  $b=$1374;
  var $1375=$a;
  var $1376=$1;
  var $1377=(($1376)|0);
  var $1378=HEAP32[(($1377)>>2)];
  var $1379=((($1378)+($1375))|0);
  HEAP32[(($1377)>>2)]=$1379;
  var $1380=$b;
  var $1381=$1;
  var $1382=(($1381+4)|0);
  var $1383=HEAP32[(($1382)>>2)];
  var $1384=((($1383)+($1380))|0);
  HEAP32[(($1382)>>2)]=$1384;
  var $1385=$c;
  var $1386=$1;
  var $1387=(($1386+8)|0);
  var $1388=HEAP32[(($1387)>>2)];
  var $1389=((($1388)+($1385))|0);
  HEAP32[(($1387)>>2)]=$1389;
  var $1390=$d;
  var $1391=$1;
  var $1392=(($1391+12)|0);
  var $1393=HEAP32[(($1392)>>2)];
  var $1394=((($1393)+($1390))|0);
  HEAP32[(($1392)>>2)]=$1394;
  ;
  return;
}
_MD5Transform["X"]=1;

function _ARC4Init($ctx, $key, $key_len) {
  var __stackBase__  = STACKTOP; STACKTOP += 256; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $tmp_array=__stackBase__;
      var $i;
      var $j;
      var $tmp;
      $1=$ctx;
      $2=$key;
      $3=$key_len;
      $j=0;
      $i=0;
      __label__ = 3; break;
    case 3: 
      var $5=$i;
      var $6=(($5)>>>0) < 256;
      if ($6) { __label__ = 4; break; } else { __label__ = 6; break; }
    case 4: 
      var $8=$i;
      var $9=(($8) & 255);
      var $10=$i;
      var $11=$1;
      var $12=(($11+2)|0);
      var $13=(($12+$10)|0);
      HEAP8[($13)]=$9;
      __label__ = 5; break;
    case 5: 
      var $15=$i;
      var $16=((($15)+(1))|0);
      $i=$16;
      __label__ = 3; break;
    case 6: 
      $i=0;
      __label__ = 7; break;
    case 7: 
      var $19=$i;
      var $20=(($19)>>>0) < 256;
      if ($20) { __label__ = 8; break; } else { __label__ = 10; break; }
    case 8: 
      var $22=$i;
      var $23=$3;
      var $24=((($22)>>>0))%((($23)>>>0));
      var $25=$2;
      var $26=(($25+$24)|0);
      var $27=HEAP8[($26)];
      var $28=$i;
      var $29=(($tmp_array+$28)|0);
      HEAP8[($29)]=$27;
      __label__ = 9; break;
    case 9: 
      var $31=$i;
      var $32=((($31)+(1))|0);
      $i=$32;
      __label__ = 7; break;
    case 10: 
      $i=0;
      __label__ = 11; break;
    case 11: 
      var $35=$i;
      var $36=(($35)>>>0) < 256;
      if ($36) { __label__ = 12; break; } else { __label__ = 14; break; }
    case 12: 
      var $38=$j;
      var $39=$i;
      var $40=$1;
      var $41=(($40+2)|0);
      var $42=(($41+$39)|0);
      var $43=HEAPU8[($42)];
      var $44=(($43)&255);
      var $45=((($38)+($44))|0);
      var $46=$i;
      var $47=(($tmp_array+$46)|0);
      var $48=HEAPU8[($47)];
      var $49=(($48)&255);
      var $50=((($45)+($49))|0);
      var $51=((($50)>>>0))%(256);
      $j=$51;
      var $52=$i;
      var $53=$1;
      var $54=(($53+2)|0);
      var $55=(($54+$52)|0);
      var $56=HEAP8[($55)];
      $tmp=$56;
      var $57=$j;
      var $58=$1;
      var $59=(($58+2)|0);
      var $60=(($59+$57)|0);
      var $61=HEAP8[($60)];
      var $62=$i;
      var $63=$1;
      var $64=(($63+2)|0);
      var $65=(($64+$62)|0);
      HEAP8[($65)]=$61;
      var $66=$tmp;
      var $67=$j;
      var $68=$1;
      var $69=(($68+2)|0);
      var $70=(($69+$67)|0);
      HEAP8[($70)]=$66;
      __label__ = 13; break;
    case 13: 
      var $72=$i;
      var $73=((($72)+(1))|0);
      $i=$73;
      __label__ = 11; break;
    case 14: 
      var $75=$1;
      var $76=(($75)|0);
      HEAP8[($76)]=0;
      var $77=$1;
      var $78=(($77+1)|0);
      HEAP8[($78)]=0;
      STACKTOP = __stackBase__;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_ARC4Init["X"]=1;

function _ARC4CryptBuf($ctx, $in, $out, $len) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $i;
      var $t;
      var $K;
      var $tmp;
      $1=$ctx;
      $2=$in;
      $3=$out;
      $4=$len;
      $i=0;
      __label__ = 3; break;
    case 3: 
      var $6=$i;
      var $7=$4;
      var $8=(($6)>>>0) < (($7)>>>0);
      if ($8) { __label__ = 4; break; } else { __label__ = 6; break; }
    case 4: 
      var $10=$1;
      var $11=(($10)|0);
      var $12=HEAPU8[($11)];
      var $13=(($12)&255);
      var $14=((($13)+(1))|0);
      var $15=((($14)|0))%(256);
      var $16=(($15) & 255);
      var $17=$1;
      var $18=(($17)|0);
      HEAP8[($18)]=$16;
      var $19=$1;
      var $20=(($19+1)|0);
      var $21=HEAPU8[($20)];
      var $22=(($21)&255);
      var $23=$1;
      var $24=(($23)|0);
      var $25=HEAPU8[($24)];
      var $26=(($25)&255);
      var $27=$1;
      var $28=(($27+2)|0);
      var $29=(($28+$26)|0);
      var $30=HEAPU8[($29)];
      var $31=(($30)&255);
      var $32=((($22)+($31))|0);
      var $33=((($32)|0))%(256);
      var $34=(($33) & 255);
      var $35=$1;
      var $36=(($35+1)|0);
      HEAP8[($36)]=$34;
      var $37=$1;
      var $38=(($37)|0);
      var $39=HEAPU8[($38)];
      var $40=(($39)&255);
      var $41=$1;
      var $42=(($41+2)|0);
      var $43=(($42+$40)|0);
      var $44=HEAP8[($43)];
      $tmp=$44;
      var $45=$1;
      var $46=(($45+1)|0);
      var $47=HEAPU8[($46)];
      var $48=(($47)&255);
      var $49=$1;
      var $50=(($49+2)|0);
      var $51=(($50+$48)|0);
      var $52=HEAP8[($51)];
      var $53=$1;
      var $54=(($53)|0);
      var $55=HEAPU8[($54)];
      var $56=(($55)&255);
      var $57=$1;
      var $58=(($57+2)|0);
      var $59=(($58+$56)|0);
      HEAP8[($59)]=$52;
      var $60=$tmp;
      var $61=$1;
      var $62=(($61+1)|0);
      var $63=HEAPU8[($62)];
      var $64=(($63)&255);
      var $65=$1;
      var $66=(($65+2)|0);
      var $67=(($66+$64)|0);
      HEAP8[($67)]=$60;
      var $68=$1;
      var $69=(($68)|0);
      var $70=HEAPU8[($69)];
      var $71=(($70)&255);
      var $72=$1;
      var $73=(($72+2)|0);
      var $74=(($73+$71)|0);
      var $75=HEAPU8[($74)];
      var $76=(($75)&255);
      var $77=$1;
      var $78=(($77+1)|0);
      var $79=HEAPU8[($78)];
      var $80=(($79)&255);
      var $81=$1;
      var $82=(($81+2)|0);
      var $83=(($82+$80)|0);
      var $84=HEAPU8[($83)];
      var $85=(($84)&255);
      var $86=((($76)+($85))|0);
      var $87=((($86)|0))%(256);
      $t=$87;
      var $88=$t;
      var $89=$1;
      var $90=(($89+2)|0);
      var $91=(($90+$88)|0);
      var $92=HEAP8[($91)];
      $K=$92;
      var $93=$i;
      var $94=$2;
      var $95=(($94+$93)|0);
      var $96=HEAPU8[($95)];
      var $97=(($96)&255);
      var $98=$K;
      var $99=(($98)&255);
      var $100=$97 ^ $99;
      var $101=(($100) & 255);
      var $102=$i;
      var $103=$3;
      var $104=(($103+$102)|0);
      HEAP8[($104)]=$101;
      __label__ = 5; break;
    case 5: 
      var $106=$i;
      var $107=((($106)+(1))|0);
      $i=$107;
      __label__ = 3; break;
    case 6: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_ARC4CryptBuf["X"]=1;

function _HPDF_MD5Final($digest, $ctx) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $count;
      var $p;
      $1=$digest;
      $2=$ctx;
      var $3=$2;
      var $4=(($3+16)|0);
      var $5=(($4)|0);
      var $6=HEAPU32[(($5)>>2)];
      var $7=$6 >>> 3;
      var $8=$7 & 63;
      $count=$8;
      var $9=$2;
      var $10=(($9+24)|0);
      var $11=(($10)|0);
      var $12=$count;
      var $13=(($11+$12)|0);
      $p=$13;
      var $14=$p;
      var $15=(($14+1)|0);
      $p=$15;
      HEAP8[($14)]=-128;
      var $16=$count;
      var $17=(((63)-($16))|0);
      $count=$17;
      var $18=$count;
      var $19=(($18)>>>0) < 8;
      if ($19) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $21=$p;
      var $22=$count;
      var $23=_HPDF_MemSet($21, 0, $22);
      var $24=$2;
      var $25=(($24+24)|0);
      var $26=(($25)|0);
      _MD5ByteReverse($26, 16);
      var $27=$2;
      var $28=(($27)|0);
      var $29=(($28)|0);
      var $30=$2;
      var $31=(($30+24)|0);
      var $32=(($31)|0);
      var $33=$32;
      _MD5Transform($29, $33);
      var $34=$2;
      var $35=(($34+24)|0);
      var $36=(($35)|0);
      var $37=_HPDF_MemSet($36, 0, 56);
      __label__ = 5; break;
    case 4: 
      var $39=$p;
      var $40=$count;
      var $41=((($40)-(8))|0);
      var $42=_HPDF_MemSet($39, 0, $41);
      __label__ = 5; break;
    case 5: 
      var $44=$2;
      var $45=(($44+24)|0);
      var $46=(($45)|0);
      _MD5ByteReverse($46, 14);
      var $47=$2;
      var $48=(($47+16)|0);
      var $49=(($48)|0);
      var $50=HEAP32[(($49)>>2)];
      var $51=$2;
      var $52=(($51+24)|0);
      var $53=(($52)|0);
      var $54=$53;
      var $55=(($54+56)|0);
      HEAP32[(($55)>>2)]=$50;
      var $56=$2;
      var $57=(($56+16)|0);
      var $58=(($57+4)|0);
      var $59=HEAP32[(($58)>>2)];
      var $60=$2;
      var $61=(($60+24)|0);
      var $62=(($61)|0);
      var $63=$62;
      var $64=(($63+60)|0);
      HEAP32[(($64)>>2)]=$59;
      var $65=$2;
      var $66=(($65)|0);
      var $67=(($66)|0);
      var $68=$2;
      var $69=(($68+24)|0);
      var $70=(($69)|0);
      var $71=$70;
      _MD5Transform($67, $71);
      var $72=$2;
      var $73=(($72)|0);
      var $74=(($73)|0);
      var $75=$74;
      _MD5ByteReverse($75, 4);
      var $76=$1;
      var $77=$2;
      var $78=(($77)|0);
      var $79=(($78)|0);
      var $80=$79;
      var $81=_HPDF_MemCpy($76, $80, 16);
      var $82=$2;
      var $83=$82;
      var $84=_HPDF_MemSet($83, 0, 4);
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_MD5Final["X"]=1;

function _HPDF_PadOrTrancatePasswd($pwd, $new_pwd) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $len;
      $1=$pwd;
      $2=$new_pwd;
      var $3=$1;
      var $4=_HPDF_StrLen($3, 33);
      $len=$4;
      var $5=$2;
      var $6=_HPDF_MemSet($5, 0, 32);
      var $7=$len;
      var $8=(($7)>>>0) >= 32;
      if ($8) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $10=$2;
      var $11=$1;
      var $12=_HPDF_MemCpy($10, $11, 32);
      __label__ = 7; break;
    case 4: 
      var $14=$len;
      var $15=(($14)>>>0) > 0;
      if ($15) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $17=$2;
      var $18=$1;
      var $19=$len;
      var $20=_HPDF_MemCpy($17, $18, $19);
      __label__ = 6; break;
    case 6: 
      var $22=$2;
      var $23=$len;
      var $24=(($22+$23)|0);
      var $25=$len;
      var $26=(((32)-($25))|0);
      var $27=_HPDF_MemCpy($24, ((STRING_TABLE._HPDF_PADDING_STRING)|0), $26);
      __label__ = 7; break;
    case 7: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Encrypt_Init($attr) {
  ;
  var __label__;

  var $1;
  $1=$attr;
  var $2=$1;
  var $3=$2;
  var $4=_HPDF_MemSet($3, 0, 452);
  var $5=$1;
  var $6=(($5)|0);
  HEAP32[(($6)>>2)]=2;
  var $7=$1;
  var $8=(($7+4)|0);
  HEAP32[(($8)>>2)]=5;
  var $9=$1;
  var $10=(($9+8)|0);
  var $11=(($10)|0);
  var $12=_HPDF_MemCpy($11, ((STRING_TABLE._HPDF_PADDING_STRING)|0), 32);
  var $13=$1;
  var $14=(($13+40)|0);
  var $15=(($14)|0);
  var $16=_HPDF_MemCpy($15, ((STRING_TABLE._HPDF_PADDING_STRING)|0), 32);
  var $17=$1;
  var $18=(($17+136)|0);
  HEAP32[(($18)>>2)]=-4;
  ;
  return;
}


function _HPDF_Encrypt_CreateOwnerKey($attr) {
  var __stackBase__  = STACKTOP; STACKTOP += 444; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $rc4_ctx=__stackBase__;
      var $md5_ctx=(__stackBase__)+(260);
      var $digest=(__stackBase__)+(348);
      var $tmppwd=(__stackBase__)+(364);
      var $i;
      var $tmppwd2=(__stackBase__)+(396);
      var $i1;
      var $j;
      var $new_key=(__stackBase__)+(428);
      $1=$attr;
      _HPDF_MD5Init($md5_ctx);
      var $2=$1;
      var $3=(($2+8)|0);
      var $4=(($3)|0);
      _HPDF_MD5Update($md5_ctx, $4, 32);
      var $5=(($digest)|0);
      _HPDF_MD5Final($5, $md5_ctx);
      var $6=$1;
      var $7=(($6)|0);
      var $8=HEAP32[(($7)>>2)];
      var $9=(($8)|0)==3;
      if ($9) { __label__ = 3; break; } else { __label__ = 8; break; }
    case 3: 
      $i=0;
      __label__ = 4; break;
    case 4: 
      var $12=$i;
      var $13=(($12)>>>0) < 50;
      if ($13) { __label__ = 5; break; } else { __label__ = 7; break; }
    case 5: 
      _HPDF_MD5Init($md5_ctx);
      var $15=(($digest)|0);
      var $16=$1;
      var $17=(($16+4)|0);
      var $18=HEAP32[(($17)>>2)];
      _HPDF_MD5Update($md5_ctx, $15, $18);
      var $19=(($digest)|0);
      _HPDF_MD5Final($19, $md5_ctx);
      __label__ = 6; break;
    case 6: 
      var $21=$i;
      var $22=((($21)+(1))|0);
      $i=$22;
      __label__ = 4; break;
    case 7: 
      __label__ = 8; break;
    case 8: 
      var $25=(($digest)|0);
      var $26=$1;
      var $27=(($26+4)|0);
      var $28=HEAP32[(($27)>>2)];
      _ARC4Init($rc4_ctx, $25, $28);
      var $29=$1;
      var $30=(($29+40)|0);
      var $31=(($30)|0);
      var $32=(($tmppwd)|0);
      _ARC4CryptBuf($rc4_ctx, $31, $32, 32);
      var $33=$1;
      var $34=(($33)|0);
      var $35=HEAP32[(($34)>>2)];
      var $36=(($35)|0)==3;
      if ($36) { __label__ = 9; break; } else { __label__ = 18; break; }
    case 9: 
      $i1=1;
      __label__ = 10; break;
    case 10: 
      var $39=$i1;
      var $40=(($39)>>>0) <= 19;
      if ($40) { __label__ = 11; break; } else { __label__ = 17; break; }
    case 11: 
      $j=0;
      __label__ = 12; break;
    case 12: 
      var $43=$j;
      var $44=$1;
      var $45=(($44+4)|0);
      var $46=HEAPU32[(($45)>>2)];
      var $47=(($43)>>>0) < (($46)>>>0);
      if ($47) { __label__ = 13; break; } else { __label__ = 15; break; }
    case 13: 
      var $49=$j;
      var $50=(($digest+$49)|0);
      var $51=HEAPU8[($50)];
      var $52=(($51)&255);
      var $53=$i1;
      var $54=$52 ^ $53;
      var $55=(($54) & 255);
      var $56=$j;
      var $57=(($new_key+$56)|0);
      HEAP8[($57)]=$55;
      __label__ = 14; break;
    case 14: 
      var $59=$j;
      var $60=((($59)+(1))|0);
      $j=$60;
      __label__ = 12; break;
    case 15: 
      var $62=(($tmppwd2)|0);
      var $63=(($tmppwd)|0);
      var $64=_HPDF_MemCpy($62, $63, 32);
      var $65=(($new_key)|0);
      var $66=$1;
      var $67=(($66+4)|0);
      var $68=HEAP32[(($67)>>2)];
      _ARC4Init($rc4_ctx, $65, $68);
      var $69=(($tmppwd2)|0);
      var $70=(($tmppwd)|0);
      _ARC4CryptBuf($rc4_ctx, $69, $70, 32);
      __label__ = 16; break;
    case 16: 
      var $72=$i1;
      var $73=((($72)+(1))|0);
      $i1=$73;
      __label__ = 10; break;
    case 17: 
      __label__ = 18; break;
    case 18: 
      var $76=$1;
      var $77=(($76+72)|0);
      var $78=(($77)|0);
      var $79=(($tmppwd)|0);
      var $80=_HPDF_MemCpy($78, $79, 32);
      STACKTOP = __stackBase__;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Encrypt_CreateOwnerKey["X"]=1;

function _HPDF_Encrypt_CreateEncryptionKey($attr) {
  var __stackBase__  = STACKTOP; STACKTOP += 92; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $md5_ctx=__stackBase__;
      var $tmp_flg=(__stackBase__)+(88);
      var $i;
      $1=$attr;
      _HPDF_MD5Init($md5_ctx);
      var $2=$1;
      var $3=(($2+40)|0);
      var $4=(($3)|0);
      _HPDF_MD5Update($md5_ctx, $4, 32);
      var $5=$1;
      var $6=(($5+72)|0);
      var $7=(($6)|0);
      _HPDF_MD5Update($md5_ctx, $7, 32);
      var $8=$1;
      var $9=(($8+136)|0);
      var $10=HEAP32[(($9)>>2)];
      var $11=(($10) & 255);
      var $12=(($tmp_flg)|0);
      HEAP8[($12)]=$11;
      var $13=$1;
      var $14=(($13+136)|0);
      var $15=HEAP32[(($14)>>2)];
      var $16=$15 >> 8;
      var $17=(($16) & 255);
      var $18=(($tmp_flg+1)|0);
      HEAP8[($18)]=$17;
      var $19=$1;
      var $20=(($19+136)|0);
      var $21=HEAP32[(($20)>>2)];
      var $22=$21 >> 16;
      var $23=(($22) & 255);
      var $24=(($tmp_flg+2)|0);
      HEAP8[($24)]=$23;
      var $25=$1;
      var $26=(($25+136)|0);
      var $27=HEAP32[(($26)>>2)];
      var $28=$27 >> 24;
      var $29=(($28) & 255);
      var $30=(($tmp_flg+3)|0);
      HEAP8[($30)]=$29;
      var $31=(($tmp_flg)|0);
      _HPDF_MD5Update($md5_ctx, $31, 4);
      var $32=$1;
      var $33=(($32+140)|0);
      var $34=(($33)|0);
      _HPDF_MD5Update($md5_ctx, $34, 16);
      var $35=$1;
      var $36=(($35+156)|0);
      var $37=(($36)|0);
      _HPDF_MD5Final($37, $md5_ctx);
      var $38=$1;
      var $39=(($38)|0);
      var $40=HEAP32[(($39)>>2)];
      var $41=(($40)|0)==3;
      if ($41) { __label__ = 3; break; } else { __label__ = 8; break; }
    case 3: 
      $i=0;
      __label__ = 4; break;
    case 4: 
      var $44=$i;
      var $45=(($44)>>>0) < 50;
      if ($45) { __label__ = 5; break; } else { __label__ = 7; break; }
    case 5: 
      _HPDF_MD5Init($md5_ctx);
      var $47=$1;
      var $48=(($47+156)|0);
      var $49=(($48)|0);
      var $50=$1;
      var $51=(($50+4)|0);
      var $52=HEAP32[(($51)>>2)];
      _HPDF_MD5Update($md5_ctx, $49, $52);
      var $53=$1;
      var $54=(($53+156)|0);
      var $55=(($54)|0);
      _HPDF_MD5Final($55, $md5_ctx);
      __label__ = 6; break;
    case 6: 
      var $57=$i;
      var $58=((($57)+(1))|0);
      $i=$58;
      __label__ = 4; break;
    case 7: 
      __label__ = 8; break;
    case 8: 
      STACKTOP = __stackBase__;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Encrypt_CreateEncryptionKey["X"]=1;

function _HPDF_Encrypt_CreateUserKey($attr) {
  var __stackBase__  = STACKTOP; STACKTOP += 396; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $ctx=__stackBase__;
      var $md5_ctx=(__stackBase__)+(260);
      var $digest=(__stackBase__)+(348);
      var $digest2=(__stackBase__)+(364);
      var $i;
      var $j;
      var $new_key=(__stackBase__)+(380);
      $1=$attr;
      var $2=$1;
      var $3=(($2+156)|0);
      var $4=(($3)|0);
      var $5=$1;
      var $6=(($5+4)|0);
      var $7=HEAP32[(($6)>>2)];
      _ARC4Init($ctx, $4, $7);
      var $8=$1;
      var $9=(($8+104)|0);
      var $10=(($9)|0);
      _ARC4CryptBuf($ctx, ((STRING_TABLE._HPDF_PADDING_STRING)|0), $10, 32);
      var $11=$1;
      var $12=(($11)|0);
      var $13=HEAP32[(($12)>>2)];
      var $14=(($13)|0)==3;
      if ($14) { __label__ = 3; break; } else { __label__ = 12; break; }
    case 3: 
      _HPDF_MD5Init($md5_ctx);
      _HPDF_MD5Update($md5_ctx, ((STRING_TABLE._HPDF_PADDING_STRING)|0), 32);
      var $16=$1;
      var $17=(($16+140)|0);
      var $18=(($17)|0);
      _HPDF_MD5Update($md5_ctx, $18, 16);
      var $19=(($digest)|0);
      _HPDF_MD5Final($19, $md5_ctx);
      var $20=$1;
      var $21=(($20+156)|0);
      var $22=(($21)|0);
      var $23=$1;
      var $24=(($23+4)|0);
      var $25=HEAP32[(($24)>>2)];
      _ARC4Init($ctx, $22, $25);
      var $26=(($digest)|0);
      var $27=(($digest2)|0);
      _ARC4CryptBuf($ctx, $26, $27, 16);
      $i=1;
      __label__ = 4; break;
    case 4: 
      var $29=$i;
      var $30=(($29)>>>0) <= 19;
      if ($30) { __label__ = 5; break; } else { __label__ = 11; break; }
    case 5: 
      $j=0;
      __label__ = 6; break;
    case 6: 
      var $33=$j;
      var $34=$1;
      var $35=(($34+4)|0);
      var $36=HEAPU32[(($35)>>2)];
      var $37=(($33)>>>0) < (($36)>>>0);
      if ($37) { __label__ = 7; break; } else { __label__ = 9; break; }
    case 7: 
      var $39=$j;
      var $40=$1;
      var $41=(($40+156)|0);
      var $42=(($41+$39)|0);
      var $43=HEAPU8[($42)];
      var $44=(($43)&255);
      var $45=$i;
      var $46=$44 ^ $45;
      var $47=(($46) & 255);
      var $48=$j;
      var $49=(($new_key+$48)|0);
      HEAP8[($49)]=$47;
      __label__ = 8; break;
    case 8: 
      var $51=$j;
      var $52=((($51)+(1))|0);
      $j=$52;
      __label__ = 6; break;
    case 9: 
      var $54=(($digest)|0);
      var $55=(($digest2)|0);
      var $56=_HPDF_MemCpy($54, $55, 16);
      var $57=(($new_key)|0);
      var $58=$1;
      var $59=(($58+4)|0);
      var $60=HEAP32[(($59)>>2)];
      _ARC4Init($ctx, $57, $60);
      var $61=(($digest)|0);
      var $62=(($digest2)|0);
      _ARC4CryptBuf($ctx, $61, $62, 16);
      __label__ = 10; break;
    case 10: 
      var $64=$i;
      var $65=((($64)+(1))|0);
      $i=$65;
      __label__ = 4; break;
    case 11: 
      var $67=$1;
      var $68=(($67+104)|0);
      var $69=(($68)|0);
      var $70=_HPDF_MemSet($69, 0, 32);
      var $71=$1;
      var $72=(($71+104)|0);
      var $73=(($72)|0);
      var $74=(($digest2)|0);
      var $75=_HPDF_MemCpy($73, $74, 16);
      __label__ = 12; break;
    case 12: 
      STACKTOP = __stackBase__;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Encrypt_CreateUserKey["X"]=1;

function _HPDF_Encrypt_InitKey($attr, $object_id, $gen_no) {
  var __stackBase__  = STACKTOP; STACKTOP += 88; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $ctx=__stackBase__;
      var $key_len;
      $1=$attr;
      $2=$object_id;
      $3=$gen_no;
      var $4=$2;
      var $5=(($4) & 255);
      var $6=$1;
      var $7=(($6+4)|0);
      var $8=HEAP32[(($7)>>2)];
      var $9=$1;
      var $10=(($9+156)|0);
      var $11=(($10+$8)|0);
      HEAP8[($11)]=$5;
      var $12=$2;
      var $13=$12 >>> 8;
      var $14=(($13) & 255);
      var $15=$1;
      var $16=(($15+4)|0);
      var $17=HEAP32[(($16)>>2)];
      var $18=((($17)+(1))|0);
      var $19=$1;
      var $20=(($19+156)|0);
      var $21=(($20+$18)|0);
      HEAP8[($21)]=$14;
      var $22=$2;
      var $23=$22 >>> 16;
      var $24=(($23) & 255);
      var $25=$1;
      var $26=(($25+4)|0);
      var $27=HEAP32[(($26)>>2)];
      var $28=((($27)+(2))|0);
      var $29=$1;
      var $30=(($29+156)|0);
      var $31=(($30+$28)|0);
      HEAP8[($31)]=$24;
      var $32=$3;
      var $33=(($32) & 255);
      var $34=$1;
      var $35=(($34+4)|0);
      var $36=HEAP32[(($35)>>2)];
      var $37=((($36)+(3))|0);
      var $38=$1;
      var $39=(($38+156)|0);
      var $40=(($39+$37)|0);
      HEAP8[($40)]=$33;
      var $41=$3;
      var $42=(($41)&65535);
      var $43=$42 >> 8;
      var $44=(($43) & 255);
      var $45=$1;
      var $46=(($45+4)|0);
      var $47=HEAP32[(($46)>>2)];
      var $48=((($47)+(4))|0);
      var $49=$1;
      var $50=(($49+156)|0);
      var $51=(($50+$48)|0);
      HEAP8[($51)]=$44;
      _HPDF_MD5Init($ctx);
      var $52=$1;
      var $53=(($52+156)|0);
      var $54=(($53)|0);
      var $55=$1;
      var $56=(($55+4)|0);
      var $57=HEAP32[(($56)>>2)];
      var $58=((($57)+(5))|0);
      _HPDF_MD5Update($ctx, $54, $58);
      var $59=$1;
      var $60=(($59+177)|0);
      var $61=(($60)|0);
      _HPDF_MD5Final($61, $ctx);
      var $62=$1;
      var $63=(($62+4)|0);
      var $64=HEAP32[(($63)>>2)];
      var $65=((($64)+(5))|0);
      var $66=(($65)>>>0) > 16;
      if ($66) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $74 = 16;__label__ = 5; break;
    case 4: 
      var $69=$1;
      var $70=(($69+4)|0);
      var $71=HEAP32[(($70)>>2)];
      var $72=((($71)+(5))|0);
      var $74 = $72;__label__ = 5; break;
    case 5: 
      var $74;
      $key_len=$74;
      var $75=$1;
      var $76=(($75+193)|0);
      var $77=$1;
      var $78=(($77+177)|0);
      var $79=(($78)|0);
      var $80=$key_len;
      _ARC4Init($76, $79, $80);
      STACKTOP = __stackBase__;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Encrypt_InitKey["X"]=1;

function _HPDF_Encrypt_Reset($attr) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $key_len;
      $1=$attr;
      var $2=$1;
      var $3=(($2+4)|0);
      var $4=HEAP32[(($3)>>2)];
      var $5=((($4)+(5))|0);
      var $6=(($5)>>>0) > 16;
      if ($6) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $14 = 16;__label__ = 5; break;
    case 4: 
      var $9=$1;
      var $10=(($9+4)|0);
      var $11=HEAP32[(($10)>>2)];
      var $12=((($11)+(5))|0);
      var $14 = $12;__label__ = 5; break;
    case 5: 
      var $14;
      $key_len=$14;
      var $15=$1;
      var $16=(($15+193)|0);
      var $17=$1;
      var $18=(($17+177)|0);
      var $19=(($18)|0);
      var $20=$key_len;
      _ARC4Init($16, $19, $20);
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Encrypt_CryptBuf($attr, $src, $dst, $len) {
  ;
  var __label__;

  var $1;
  var $2;
  var $3;
  var $4;
  $1=$attr;
  $2=$src;
  $3=$dst;
  $4=$len;
  var $5=$1;
  var $6=(($5+193)|0);
  var $7=$2;
  var $8=$3;
  var $9=$4;
  _ARC4CryptBuf($6, $7, $8, $9);
  ;
  return;
}


function _HPDF_EncryptDict_GetAttr($dict) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $header;
      $2=$dict;
      var $3=$2;
      var $4=$3;
      $header=$4;
      var $5=$2;
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 3; break; } else { __label__ = 6; break; }
    case 3: 
      var $8=$2;
      var $9=(($8+44)|0);
      var $10=HEAP32[(($9)>>2)];
      var $11=(($10)|0)!=0;
      if ($11) { __label__ = 4; break; } else { __label__ = 6; break; }
    case 4: 
      var $13=$header;
      var $14=(($13+6)|0);
      var $15=HEAPU16[(($14)>>1)];
      var $16=(($15)&65535);
      var $17=(($16)|0)==2321;
      if ($17) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $19=$2;
      var $20=(($19+44)|0);
      var $21=HEAP32[(($20)>>2)];
      var $22=$21;
      $1=$22;
      __label__ = 7; break;
    case 6: 
      $1=0;
      __label__ = 7; break;
    case 7: 
      var $25=$1;
      ;
      return $25;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Error_GetCode($error) {
  ;
  var __label__;

  var $1;
  $1=$error;
  var $2=$1;
  var $3=(($2)|0);
  var $4=HEAP32[(($3)>>2)];
  ;
  return $4;
}


function _HPDF_Error_GetDetailCode($error) {
  ;
  var __label__;

  var $1;
  $1=$error;
  var $2=$1;
  var $3=(($2+4)|0);
  var $4=HEAP32[(($3)>>2)];
  ;
  return $4;
}


function _HPDF_SetError($error, $error_no, $detail_no) {
  ;
  var __label__;

  var $1;
  var $2;
  var $3;
  $1=$error;
  $2=$error_no;
  $3=$detail_no;
  var $4=$2;
  var $5=$1;
  var $6=(($5)|0);
  HEAP32[(($6)>>2)]=$4;
  var $7=$3;
  var $8=$1;
  var $9=(($8+4)|0);
  HEAP32[(($9)>>2)]=$7;
  var $10=$2;
  ;
  return $10;
}


function _HPDF_Error_Reset($error) {
  ;
  var __label__;

  var $1;
  $1=$error;
  var $2=$1;
  var $3=(($2)|0);
  HEAP32[(($3)>>2)]=0;
  var $4=$1;
  var $5=(($4+4)|0);
  HEAP32[(($5)>>2)]=0;
  ;
  return;
}


function _HPDF_ExtGState_Validate($ext_gstate) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      $2=$ext_gstate;
      var $3=$2;
      var $4=(($3)|0)!=0;
      if ($4) { __label__ = 3; break; } else { __label__ = 5; break; }
    case 3: 
      var $6=$2;
      var $7=(($6)|0);
      var $8=(($7+6)|0);
      var $9=HEAPU16[(($8)>>1)];
      var $10=(($9)&65535);
      var $11=(($10)|0)!=2577;
      if ($11) { __label__ = 4; break; } else { __label__ = 6; break; }
    case 4: 
      var $13=$2;
      var $14=(($13)|0);
      var $15=(($14+6)|0);
      var $16=HEAPU16[(($15)>>1)];
      var $17=(($16)&65535);
      var $18=(($17)|0)!=2833;
      if ($18) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      $1=0;
      __label__ = 7; break;
    case 6: 
      $1=1;
      __label__ = 7; break;
    case 7: 
      var $22=$1;
      ;
      return $22;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_EncryptDict_New($mmgr, $xref) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $attr;
      var $dict;
      $2=$mmgr;
      $3=$xref;
      var $4=$2;
      var $5=_HPDF_Dict_New($4);
      $dict=$5;
      var $6=$dict;
      var $7=(($6)|0)!=0;
      if ($7) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=0;
      __label__ = 9; break;
    case 4: 
      var $10=$dict;
      var $11=(($10)|0);
      var $12=(($11+6)|0);
      var $13=HEAPU16[(($12)>>1)];
      var $14=(($13)&65535);
      var $15=$14 | 2304;
      var $16=(($15) & 65535);
      HEAP16[(($12)>>1)]=$16;
      var $17=$dict;
      var $18=(($17+32)|0);
      HEAP32[(($18)>>2)]=88;
      var $19=$dict;
      var $20=(($19+8)|0);
      var $21=HEAP32[(($20)>>2)];
      var $22=_HPDF_GetMem($21, 452);
      var $23=$22;
      $attr=$23;
      var $24=$attr;
      var $25=(($24)|0)!=0;
      if ($25) { __label__ = 6; break; } else { __label__ = 5; break; }
    case 5: 
      var $27=$dict;
      _HPDF_Dict_Free($27);
      $1=0;
      __label__ = 9; break;
    case 6: 
      var $29=$attr;
      var $30=$29;
      var $31=$dict;
      var $32=(($31+44)|0);
      HEAP32[(($32)>>2)]=$30;
      var $33=$attr;
      _HPDF_Encrypt_Init($33);
      var $34=$3;
      var $35=$dict;
      var $36=$35;
      var $37=_HPDF_Xref_Add($34, $36);
      var $38=(($37)|0)!=0;
      if ($38) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      $1=0;
      __label__ = 9; break;
    case 8: 
      var $41=$dict;
      $1=$41;
      __label__ = 9; break;
    case 9: 
      var $43=$1;
      ;
      return $43;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_EncryptDict_New["X"]=1;

function _HPDF_EncryptDict_OnFree($obj) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $attr;
      $1=$obj;
      var $2=$1;
      var $3=(($2+44)|0);
      var $4=HEAP32[(($3)>>2)];
      var $5=$4;
      $attr=$5;
      var $6=$attr;
      var $7=(($6)|0)!=0;
      if ($7) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $9=$1;
      var $10=(($9+8)|0);
      var $11=HEAP32[(($10)>>2)];
      var $12=$attr;
      var $13=$12;
      _HPDF_FreeMem($11, $13);
      __label__ = 4; break;
    case 4: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_EncryptDict_CreateID($dict, $info, $xref) {
  var __stackBase__  = STACKTOP; STACKTOP += 92; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $ctx=__stackBase__;
      var $attr;
      var $t=(__stackBase__)+(88);
      var $s;
      var $len;
      $1=$dict;
      $2=$info;
      $3=$xref;
      var $4=$1;
      var $5=(($4+44)|0);
      var $6=HEAP32[(($5)>>2)];
      var $7=$6;
      $attr=$7;
      var $8=_time(0);
      HEAP32[(($t)>>2)]=$8;
      _HPDF_MD5Init($ctx);
      var $9=$t;
      _HPDF_MD5Update($ctx, $9, 4);
      var $10=$2;
      var $11=(($10)|0)!=0;
      if ($11) { __label__ = 3; break; } else { __label__ = 16; break; }
    case 3: 
      var $13=$2;
      var $14=_HPDF_Info_GetInfoAttr($13, 2);
      $s=$14;
      var $15=$s;
      var $16=_HPDF_StrLen($15, -1);
      $len=$16;
      var $17=(($16)>>>0) > 0;
      if ($17) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      var $19=$s;
      var $20=$len;
      _HPDF_MD5Update($ctx, $19, $20);
      __label__ = 5; break;
    case 5: 
      var $22=$2;
      var $23=_HPDF_Info_GetInfoAttr($22, 3);
      $s=$23;
      var $24=$s;
      var $25=_HPDF_StrLen($24, -1);
      $len=$25;
      var $26=(($25)>>>0) > 0;
      if ($26) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      var $28=$s;
      var $29=$len;
      _HPDF_MD5Update($ctx, $28, $29);
      __label__ = 7; break;
    case 7: 
      var $31=$2;
      var $32=_HPDF_Info_GetInfoAttr($31, 4);
      $s=$32;
      var $33=$s;
      var $34=_HPDF_StrLen($33, -1);
      $len=$34;
      var $35=(($34)>>>0) > 0;
      if ($35) { __label__ = 8; break; } else { __label__ = 9; break; }
    case 8: 
      var $37=$s;
      var $38=$len;
      _HPDF_MD5Update($ctx, $37, $38);
      __label__ = 9; break;
    case 9: 
      var $40=$2;
      var $41=_HPDF_Info_GetInfoAttr($40, 5);
      $s=$41;
      var $42=$s;
      var $43=_HPDF_StrLen($42, -1);
      $len=$43;
      var $44=(($43)>>>0) > 0;
      if ($44) { __label__ = 10; break; } else { __label__ = 11; break; }
    case 10: 
      var $46=$s;
      var $47=$len;
      _HPDF_MD5Update($ctx, $46, $47);
      __label__ = 11; break;
    case 11: 
      var $49=$2;
      var $50=_HPDF_Info_GetInfoAttr($49, 6);
      $s=$50;
      var $51=$s;
      var $52=_HPDF_StrLen($51, -1);
      $len=$52;
      var $53=(($52)>>>0) > 0;
      if ($53) { __label__ = 12; break; } else { __label__ = 13; break; }
    case 12: 
      var $55=$s;
      var $56=$len;
      _HPDF_MD5Update($ctx, $55, $56);
      __label__ = 13; break;
    case 13: 
      var $58=$2;
      var $59=_HPDF_Info_GetInfoAttr($58, 7);
      $s=$59;
      var $60=$s;
      var $61=_HPDF_StrLen($60, -1);
      $len=$61;
      var $62=(($61)>>>0) > 0;
      if ($62) { __label__ = 14; break; } else { __label__ = 15; break; }
    case 14: 
      var $64=$s;
      var $65=$len;
      _HPDF_MD5Update($ctx, $64, $65);
      __label__ = 15; break;
    case 15: 
      var $67=$3;
      var $68=(($67+12)|0);
      var $69=HEAP32[(($68)>>2)];
      var $70=(($69+16)|0);
      var $71=$70;
      _HPDF_MD5Update($ctx, $71, 4);
      __label__ = 16; break;
    case 16: 
      var $73=$attr;
      var $74=(($73+140)|0);
      var $75=(($74)|0);
      _HPDF_MD5Final($75, $ctx);
      STACKTOP = __stackBase__;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_EncryptDict_CreateID["X"]=1;

function _HPDF_EncryptDict_Prepare($dict, $info, $xref) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $ret;
      var $attr;
      var $user_key;
      var $owner_key;
      $2=$dict;
      $3=$info;
      $4=$xref;
      var $5=$2;
      var $6=(($5+44)|0);
      var $7=HEAP32[(($6)>>2)];
      var $8=$7;
      $attr=$8;
      var $9=$2;
      var $10=$3;
      var $11=$4;
      _HPDF_EncryptDict_CreateID($9, $10, $11);
      var $12=$attr;
      _HPDF_Encrypt_CreateOwnerKey($12);
      var $13=$attr;
      _HPDF_Encrypt_CreateEncryptionKey($13);
      var $14=$attr;
      _HPDF_Encrypt_CreateUserKey($14);
      var $15=$2;
      var $16=(($15+8)|0);
      var $17=HEAP32[(($16)>>2)];
      var $18=$attr;
      var $19=(($18+72)|0);
      var $20=(($19)|0);
      var $21=_HPDF_Binary_New($17, $20, 32);
      $owner_key=$21;
      var $22=$owner_key;
      var $23=(($22)|0)!=0;
      if ($23) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      var $25=$2;
      var $26=(($25+12)|0);
      var $27=HEAP32[(($26)>>2)];
      var $28=_HPDF_Error_GetCode($27);
      $1=$28;
      __label__ = 18; break;
    case 4: 
      var $30=$2;
      var $31=$owner_key;
      var $32=$31;
      var $33=_HPDF_Dict_Add($30, ((STRING_TABLE.__str1103)|0), $32);
      $ret=$33;
      var $34=(($33)|0)!=0;
      if ($34) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $36=$ret;
      $1=$36;
      __label__ = 18; break;
    case 6: 
      var $38=$2;
      var $39=(($38+8)|0);
      var $40=HEAP32[(($39)>>2)];
      var $41=$attr;
      var $42=(($41+104)|0);
      var $43=(($42)|0);
      var $44=_HPDF_Binary_New($40, $43, 32);
      $user_key=$44;
      var $45=$user_key;
      var $46=(($45)|0)!=0;
      if ($46) { __label__ = 8; break; } else { __label__ = 7; break; }
    case 7: 
      var $48=$2;
      var $49=(($48+12)|0);
      var $50=HEAP32[(($49)>>2)];
      var $51=_HPDF_Error_GetCode($50);
      $1=$51;
      __label__ = 18; break;
    case 8: 
      var $53=$2;
      var $54=$user_key;
      var $55=$54;
      var $56=_HPDF_Dict_Add($53, ((STRING_TABLE.__str11104)|0), $55);
      $ret=$56;
      var $57=(($56)|0)!=0;
      if ($57) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      var $59=$ret;
      $1=$59;
      __label__ = 18; break;
    case 10: 
      var $61=$2;
      var $62=_HPDF_Dict_AddName($61, ((STRING_TABLE.__str21105)|0), ((STRING_TABLE.__str31106)|0));
      var $63=$ret;
      var $64=((($63)+($62))|0);
      $ret=$64;
      var $65=$attr;
      var $66=(($65)|0);
      var $67=HEAP32[(($66)>>2)];
      var $68=(($67)|0)==2;
      if ($68) { __label__ = 11; break; } else { __label__ = 12; break; }
    case 11: 
      var $70=$2;
      var $71=_HPDF_Dict_AddNumber($70, ((STRING_TABLE.__str41107)|0), 1);
      var $72=$ret;
      var $73=((($72)+($71))|0);
      $ret=$73;
      var $74=$2;
      var $75=_HPDF_Dict_AddNumber($74, ((STRING_TABLE.__str51108)|0), 2);
      var $76=$ret;
      var $77=((($76)+($75))|0);
      $ret=$77;
      __label__ = 15; break;
    case 12: 
      var $79=$attr;
      var $80=(($79)|0);
      var $81=HEAP32[(($80)>>2)];
      var $82=(($81)|0)==3;
      if ($82) { __label__ = 13; break; } else { __label__ = 14; break; }
    case 13: 
      var $84=$2;
      var $85=_HPDF_Dict_AddNumber($84, ((STRING_TABLE.__str41107)|0), 2);
      var $86=$ret;
      var $87=((($86)+($85))|0);
      $ret=$87;
      var $88=$2;
      var $89=_HPDF_Dict_AddNumber($88, ((STRING_TABLE.__str51108)|0), 3);
      var $90=$ret;
      var $91=((($90)+($89))|0);
      $ret=$91;
      var $92=$2;
      var $93=$attr;
      var $94=(($93+4)|0);
      var $95=HEAP32[(($94)>>2)];
      var $96=((($95<<3))|0);
      var $97=_HPDF_Dict_AddNumber($92, ((STRING_TABLE.__str61109)|0), $96);
      var $98=$ret;
      var $99=((($98)+($97))|0);
      $ret=$99;
      __label__ = 14; break;
    case 14: 
      __label__ = 15; break;
    case 15: 
      var $102=$2;
      var $103=$attr;
      var $104=(($103+136)|0);
      var $105=HEAP32[(($104)>>2)];
      var $106=_HPDF_Dict_AddNumber($102, ((STRING_TABLE.__str71110)|0), $105);
      var $107=$ret;
      var $108=((($107)+($106))|0);
      $ret=$108;
      var $109=$ret;
      var $110=(($109)|0)!=0;
      if ($110) { __label__ = 16; break; } else { __label__ = 17; break; }
    case 16: 
      var $112=$2;
      var $113=(($112+12)|0);
      var $114=HEAP32[(($113)>>2)];
      var $115=_HPDF_Error_GetCode($114);
      $1=$115;
      __label__ = 18; break;
    case 17: 
      $1=0;
      __label__ = 18; break;
    case 18: 
      var $118=$1;
      ;
      return $118;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_EncryptDict_Prepare["X"]=1;

function _HPDF_EncryptDict_SetPassword($dict, $owner_passwd, $user_passwd) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $attr;
      $2=$dict;
      $3=$owner_passwd;
      $4=$user_passwd;
      var $5=$2;
      var $6=(($5+44)|0);
      var $7=HEAP32[(($6)>>2)];
      var $8=$7;
      $attr=$8;
      var $9=$3;
      var $10=_HPDF_StrLen($9, 2);
      var $11=(($10)|0)==0;
      if ($11) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $13=$2;
      var $14=(($13+12)|0);
      var $15=HEAP32[(($14)>>2)];
      var $16=_HPDF_SetError($15, 4113, 0);
      $1=$16;
      __label__ = 9; break;
    case 4: 
      var $18=$3;
      var $19=(($18)|0)!=0;
      if ($19) { __label__ = 5; break; } else { __label__ = 8; break; }
    case 5: 
      var $21=$4;
      var $22=(($21)|0)!=0;
      if ($22) { __label__ = 6; break; } else { __label__ = 8; break; }
    case 6: 
      var $24=$3;
      var $25=$4;
      var $26=_HPDF_StrCmp($24, $25);
      var $27=(($26)|0)==0;
      if ($27) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $29=$2;
      var $30=(($29+12)|0);
      var $31=HEAP32[(($30)>>2)];
      var $32=_HPDF_SetError($31, 4113, 0);
      $1=$32;
      __label__ = 9; break;
    case 8: 
      var $34=$3;
      var $35=$attr;
      var $36=(($35+8)|0);
      var $37=(($36)|0);
      _HPDF_PadOrTrancatePasswd($34, $37);
      var $38=$4;
      var $39=$attr;
      var $40=(($39+40)|0);
      var $41=(($40)|0);
      _HPDF_PadOrTrancatePasswd($38, $41);
      $1=0;
      __label__ = 9; break;
    case 9: 
      var $43=$1;
      ;
      return $43;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_EncryptDict_SetPassword["X"]=1;

function _HPDF_Error_Init($error, $user_data) {
  ;
  var __label__;

  var $1;
  var $2;
  $1=$error;
  $2=$user_data;
  var $3=$1;
  var $4=$3;
  var $5=_HPDF_MemSet($4, 0, 16);
  var $6=$2;
  var $7=$1;
  var $8=(($7+12)|0);
  HEAP32[(($8)>>2)]=$6;
  ;
  return;
}


function _HPDF_CheckError($error) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      $1=$error;
      var $2=$1;
      var $3=(($2)|0);
      var $4=HEAP32[(($3)>>2)];
      var $5=(($4)|0)!=0;
      if ($5) { __label__ = 3; break; } else { __label__ = 5; break; }
    case 3: 
      var $7=$1;
      var $8=(($7+8)|0);
      var $9=HEAP32[(($8)>>2)];
      var $10=(($9)|0)!=0;
      if ($10) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      var $12=$1;
      var $13=(($12+8)|0);
      var $14=HEAP32[(($13)>>2)];
      var $15=$1;
      var $16=(($15)|0);
      var $17=HEAP32[(($16)>>2)];
      var $18=$1;
      var $19=(($18+4)|0);
      var $20=HEAP32[(($19)>>2)];
      var $21=$1;
      var $22=(($21+12)|0);
      var $23=HEAP32[(($22)>>2)];
      FUNCTION_TABLE[$14]($17, $20, $23);
      __label__ = 5; break;
    case 5: 
      var $25=$1;
      var $26=(($25)|0);
      var $27=HEAP32[(($26)>>2)];
      ;
      return $27;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_RaiseError($error, $error_no, $detail_no) {
  ;
  var __label__;

  var $1;
  var $2;
  var $3;
  $1=$error;
  $2=$error_no;
  $3=$detail_no;
  var $4=$1;
  var $5=$2;
  var $6=$3;
  var $7=_HPDF_SetError($4, $5, $6);
  var $8=$1;
  var $9=_HPDF_CheckError($8);
  ;
  return $9;
}


function _ExtGState_Check($ext_gstate) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      $2=$ext_gstate;
      var $3=$2;
      var $4=_HPDF_ExtGState_Validate($3);
      var $5=(($4)|0)!=0;
      if ($5) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=4147;
      __label__ = 7; break;
    case 4: 
      var $8=$2;
      var $9=(($8)|0);
      var $10=(($9+6)|0);
      var $11=HEAPU16[(($10)>>1)];
      var $12=(($11)&65535);
      var $13=(($12)|0)==2833;
      if ($13) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $15=$2;
      var $16=(($15+12)|0);
      var $17=HEAP32[(($16)>>2)];
      var $18=_HPDF_RaiseError($17, 4226, 0);
      $1=$18;
      __label__ = 7; break;
    case 6: 
      $1=0;
      __label__ = 7; break;
    case 7: 
      var $21=$1;
      ;
      return $21;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_ExtGState_New($mmgr, $xref) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $obj;
      $2=$mmgr;
      $3=$xref;
      var $4=$2;
      var $5=_HPDF_Dict_New($4);
      $obj=$5;
      var $6=$obj;
      var $7=(($6)|0)!=0;
      if ($7) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=0;
      __label__ = 9; break;
    case 4: 
      var $10=$3;
      var $11=$obj;
      var $12=$11;
      var $13=_HPDF_Xref_Add($10, $12);
      var $14=(($13)|0)!=0;
      if ($14) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      $1=0;
      __label__ = 9; break;
    case 6: 
      var $17=$obj;
      var $18=_HPDF_Dict_AddName($17, ((STRING_TABLE.__str1135)|0), ((STRING_TABLE.__str11136)|0));
      var $19=(($18)|0)!=0;
      if ($19) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      $1=0;
      __label__ = 9; break;
    case 8: 
      var $22=$obj;
      var $23=(($22)|0);
      var $24=(($23+6)|0);
      var $25=HEAPU16[(($24)>>1)];
      var $26=(($25)&65535);
      var $27=$26 | 2560;
      var $28=(($27) & 65535);
      HEAP16[(($24)>>1)]=$28;
      var $29=$obj;
      $1=$29;
      __label__ = 9; break;
    case 9: 
      var $31=$1;
      ;
      return $31;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_ExtGState_SetAlphaStroke($ext_gstate, $value) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $ret;
      $2=$ext_gstate;
      $3=$value;
      var $4=$2;
      var $5=_ExtGState_Check($4);
      $ret=$5;
      var $6=$ret;
      var $7=(($6)|0)!=0;
      if ($7) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $9=$ret;
      $1=$9;
      __label__ = 8; break;
    case 4: 
      var $11=$3;
      var $12=$11 < 0;
      if ($12) { __label__ = 6; break; } else { __label__ = 5; break; }
    case 5: 
      var $14=$3;
      var $15=$14 > 1;
      if ($15) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      var $17=$2;
      var $18=(($17+12)|0);
      var $19=HEAP32[(($18)>>2)];
      var $20=_HPDF_RaiseError($19, 4224, 0);
      $1=$20;
      __label__ = 8; break;
    case 7: 
      var $22=$2;
      var $23=$3;
      var $24=_HPDF_Dict_AddReal($22, ((STRING_TABLE.__str21137)|0), $23);
      $1=$24;
      __label__ = 8; break;
    case 8: 
      var $26=$1;
      ;
      return $26;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_ExtGState_SetAlphaFill($ext_gstate, $value) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $ret;
      $2=$ext_gstate;
      $3=$value;
      var $4=$2;
      var $5=_ExtGState_Check($4);
      $ret=$5;
      var $6=$ret;
      var $7=(($6)|0)!=0;
      if ($7) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $9=$ret;
      $1=$9;
      __label__ = 8; break;
    case 4: 
      var $11=$3;
      var $12=$11 < 0;
      if ($12) { __label__ = 6; break; } else { __label__ = 5; break; }
    case 5: 
      var $14=$3;
      var $15=$14 > 1;
      if ($15) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      var $17=$2;
      var $18=(($17+12)|0);
      var $19=HEAP32[(($18)>>2)];
      var $20=_HPDF_RaiseError($19, 4224, 0);
      $1=$20;
      __label__ = 8; break;
    case 7: 
      var $22=$2;
      var $23=$3;
      var $24=_HPDF_Dict_AddReal($22, ((STRING_TABLE.__str31138)|0), $23);
      $1=$24;
      __label__ = 8; break;
    case 8: 
      var $26=$1;
      ;
      return $26;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_ExtGState_SetBlendMode($ext_gstate, $bmode) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $ret;
      $2=$ext_gstate;
      $3=$bmode;
      var $4=$2;
      var $5=_ExtGState_Check($4);
      $ret=$5;
      var $6=$ret;
      var $7=(($6)|0)!=0;
      if ($7) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $9=$ret;
      $1=$9;
      __label__ = 8; break;
    case 4: 
      var $11=$3;
      var $12=(($11)|0) < 0;
      if ($12) { __label__ = 6; break; } else { __label__ = 5; break; }
    case 5: 
      var $14=$3;
      var $15=(($14)|0) > 12;
      if ($15) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      var $17=$2;
      var $18=(($17+12)|0);
      var $19=HEAP32[(($18)>>2)];
      var $20=_HPDF_RaiseError($19, 4224, 0);
      $1=$20;
      __label__ = 8; break;
    case 7: 
      var $22=$2;
      var $23=$3;
      var $24=((_HPDF_BM_NAMES+($23<<2))|0);
      var $25=HEAP32[(($24)>>2)];
      var $26=_HPDF_Dict_AddName($22, ((STRING_TABLE.__str41139)|0), $25);
      $1=$26;
      __label__ = 8; break;
    case 8: 
      var $28=$1;
      ;
      return $28;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Font_Validate($font) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      $2=$font;
      var $3=$2;
      var $4=(($3)|0)!=0;
      if ($4) { __label__ = 3; break; } else { __label__ = 5; break; }
    case 3: 
      var $6=$2;
      var $7=(($6+44)|0);
      var $8=HEAP32[(($7)>>2)];
      var $9=(($8)|0)!=0;
      if ($9) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      var $11=$2;
      var $12=(($11)|0);
      var $13=(($12+6)|0);
      var $14=HEAPU16[(($13)>>1)];
      var $15=(($14)&65535);
      var $16=(($15)|0)!=273;
      if ($16) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      $1=0;
      __label__ = 7; break;
    case 6: 
      $1=1;
      __label__ = 7; break;
    case 7: 
      var $20=$1;
      ;
      return $20;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Font_TextWidth($agg_result, $font, $text, $len) {
  var __stackBase__  = STACKTOP; STACKTOP += 32; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $tw=__stackBase__;
      var $attr;
      var $4=(__stackBase__)+(16);
      $1=$font;
      $2=$text;
      $3=$len;
      var $5=$tw;
      HEAP32[(($5)>>2)]=0; HEAP32[((($5)+(4))>>2)]=0; HEAP32[((($5)+(8))>>2)]=0; HEAP32[((($5)+(12))>>2)]=0;
      var $6=$1;
      var $7=_HPDF_Font_Validate($6);
      var $8=(($7)|0)!=0;
      if ($8) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      var $10=$agg_result;
      var $11=$tw;
      assert(16 % 1 === 0, 'memcpy given ' + 16 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP32[(($10)>>2)]=HEAP32[(($11)>>2)];HEAP32[((($10)+(4))>>2)]=HEAP32[((($11)+(4))>>2)];HEAP32[((($10)+(8))>>2)]=HEAP32[((($11)+(8))>>2)];HEAP32[((($10)+(12))>>2)]=HEAP32[((($11)+(12))>>2)];
      __label__ = 9; break;
    case 4: 
      var $13=$3;
      var $14=(($13)>>>0) > 65535;
      if ($14) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $16=$1;
      var $17=(($16+12)|0);
      var $18=HEAP32[(($17)>>2)];
      var $19=_HPDF_RaiseError($18, 4187, 0);
      var $20=$agg_result;
      var $21=$tw;
      assert(16 % 1 === 0, 'memcpy given ' + 16 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP32[(($20)>>2)]=HEAP32[(($21)>>2)];HEAP32[((($20)+(4))>>2)]=HEAP32[((($21)+(4))>>2)];HEAP32[((($20)+(8))>>2)]=HEAP32[((($21)+(8))>>2)];HEAP32[((($20)+(12))>>2)]=HEAP32[((($21)+(12))>>2)];
      __label__ = 9; break;
    case 6: 
      var $23=$1;
      var $24=(($23+44)|0);
      var $25=HEAP32[(($24)>>2)];
      var $26=$25;
      $attr=$26;
      var $27=$attr;
      var $28=(($27+8)|0);
      var $29=HEAP32[(($28)>>2)];
      var $30=(($29)|0)!=0;
      if ($30) { __label__ = 8; break; } else { __label__ = 7; break; }
    case 7: 
      var $32=$1;
      var $33=(($32+12)|0);
      var $34=HEAP32[(($33)>>2)];
      var $35=_HPDF_SetError($34, 4147, 0);
      var $36=$agg_result;
      var $37=$tw;
      assert(16 % 1 === 0, 'memcpy given ' + 16 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP32[(($36)>>2)]=HEAP32[(($37)>>2)];HEAP32[((($36)+(4))>>2)]=HEAP32[((($37)+(4))>>2)];HEAP32[((($36)+(8))>>2)]=HEAP32[((($37)+(8))>>2)];HEAP32[((($36)+(12))>>2)]=HEAP32[((($37)+(12))>>2)];
      __label__ = 9; break;
    case 8: 
      var $39=$attr;
      var $40=(($39+8)|0);
      var $41=HEAP32[(($40)>>2)];
      var $42=$1;
      var $43=$2;
      var $44=$3;
      FUNCTION_TABLE[$41]($4, $42, $43, $44);
      var $45=$tw;
      var $46=$4;
      assert(16 % 1 === 0, 'memcpy given ' + 16 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP32[(($45)>>2)]=HEAP32[(($46)>>2)];HEAP32[((($45)+(4))>>2)]=HEAP32[((($46)+(4))>>2)];HEAP32[((($45)+(8))>>2)]=HEAP32[((($46)+(8))>>2)];HEAP32[((($45)+(12))>>2)]=HEAP32[((($46)+(12))>>2)];
      var $47=$agg_result;
      var $48=$tw;
      assert(16 % 1 === 0, 'memcpy given ' + 16 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP32[(($47)>>2)]=HEAP32[(($48)>>2)];HEAP32[((($47)+(4))>>2)]=HEAP32[((($48)+(4))>>2)];HEAP32[((($47)+(8))>>2)]=HEAP32[((($48)+(8))>>2)];HEAP32[((($47)+(12))>>2)]=HEAP32[((($48)+(12))>>2)];
      __label__ = 9; break;
    case 9: 
      STACKTOP = __stackBase__;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Font_TextWidth["X"]=1;

function _HPDF_Font_MeasureText($font, $text, $len, $width, $font_size, $char_space, $word_space, $wordwrap, $real_width) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $5;
      var $6;
      var $7;
      var $8;
      var $9;
      var $10;
      var $attr;
      $2=$font;
      $3=$text;
      $4=$len;
      $5=$width;
      $6=$font_size;
      $7=$char_space;
      $8=$word_space;
      $9=$wordwrap;
      $10=$real_width;
      var $11=$2;
      var $12=_HPDF_Font_Validate($11);
      var $13=(($12)|0)!=0;
      if ($13) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=0;
      __label__ = 9; break;
    case 4: 
      var $16=$4;
      var $17=(($16)>>>0) > 65535;
      if ($17) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $19=$2;
      var $20=(($19+12)|0);
      var $21=HEAP32[(($20)>>2)];
      var $22=_HPDF_RaiseError($21, 4187, 0);
      $1=0;
      __label__ = 9; break;
    case 6: 
      var $24=$2;
      var $25=(($24+44)|0);
      var $26=HEAP32[(($25)>>2)];
      var $27=$26;
      $attr=$27;
      var $28=$attr;
      var $29=(($28+12)|0);
      var $30=HEAP32[(($29)>>2)];
      var $31=(($30)|0)!=0;
      if ($31) { __label__ = 8; break; } else { __label__ = 7; break; }
    case 7: 
      var $33=$2;
      var $34=(($33+12)|0);
      var $35=HEAP32[(($34)>>2)];
      var $36=_HPDF_RaiseError($35, 4147, 0);
      $1=0;
      __label__ = 9; break;
    case 8: 
      var $38=$attr;
      var $39=(($38+12)|0);
      var $40=HEAP32[(($39)>>2)];
      var $41=$2;
      var $42=$3;
      var $43=$4;
      var $44=$5;
      var $45=$6;
      var $46=$7;
      var $47=$8;
      var $48=$9;
      var $49=$10;
      var $50=FUNCTION_TABLE[$40]($41, $42, $43, $44, $45, $46, $47, $48, $49);
      $1=$50;
      __label__ = 9; break;
    case 9: 
      var $52=$1;
      ;
      return $52;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Font_MeasureText["X"]=1;

function _HPDF_Font_GetFontName($font) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $attr;
      $2=$font;
      var $3=$2;
      var $4=_HPDF_Font_Validate($3);
      var $5=(($4)|0)!=0;
      if ($5) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=0;
      __label__ = 5; break;
    case 4: 
      var $8=$2;
      var $9=(($8+44)|0);
      var $10=HEAP32[(($9)>>2)];
      var $11=$10;
      $attr=$11;
      var $12=$attr;
      var $13=(($12+16)|0);
      var $14=HEAP32[(($13)>>2)];
      var $15=(($14+4)|0);
      var $16=(($15)|0);
      $1=$16;
      __label__ = 5; break;
    case 5: 
      var $18=$1;
      ;
      return $18;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Font_GetEncodingName($font) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $attr;
      $2=$font;
      var $3=$2;
      var $4=_HPDF_Font_Validate($3);
      var $5=(($4)|0)!=0;
      if ($5) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=0;
      __label__ = 5; break;
    case 4: 
      var $8=$2;
      var $9=(($8+44)|0);
      var $10=HEAP32[(($9)>>2)];
      var $11=$10;
      $attr=$11;
      var $12=$attr;
      var $13=(($12+20)|0);
      var $14=HEAP32[(($13)>>2)];
      var $15=(($14+4)|0);
      var $16=(($15)|0);
      $1=$16;
      __label__ = 5; break;
    case 5: 
      var $18=$1;
      ;
      return $18;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Font_GetUnicodeWidth($font, $code) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $attr;
      var $fontdef;
      var $encoder_attr;
      var $l;
      var $h;
      var $cid;
      $2=$font;
      $3=$code;
      var $4=$2;
      var $5=_HPDF_Font_Validate($4);
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=0;
      __label__ = 23; break;
    case 4: 
      var $9=$2;
      var $10=(($9+44)|0);
      var $11=HEAP32[(($10)>>2)];
      var $12=$11;
      $attr=$12;
      var $13=$attr;
      var $14=(($13+16)|0);
      var $15=HEAP32[(($14)>>2)];
      $fontdef=$15;
      var $16=$fontdef;
      var $17=(($16+140)|0);
      var $18=HEAP32[(($17)>>2)];
      var $19=(($18)|0)==0;
      if ($19) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $21=$fontdef;
      var $22=$3;
      var $23=_HPDF_Type1FontDef_GetWidth($21, $22);
      var $24=(($23 << 16) >> 16);
      $1=$24;
      __label__ = 23; break;
    case 6: 
      var $26=$fontdef;
      var $27=(($26+140)|0);
      var $28=HEAP32[(($27)>>2)];
      var $29=(($28)|0)==1;
      if ($29) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $31=$fontdef;
      var $32=$3;
      var $33=_HPDF_TTFontDef_GetCharWidth($31, $32);
      var $34=(($33 << 16) >> 16);
      $1=$34;
      __label__ = 23; break;
    case 8: 
      var $36=$fontdef;
      var $37=(($36+140)|0);
      var $38=HEAP32[(($37)>>2)];
      var $39=(($38)|0)==2;
      if ($39) { __label__ = 9; break; } else { __label__ = 20; break; }
    case 9: 
      var $41=$attr;
      var $42=(($41+20)|0);
      var $43=HEAP32[(($42)>>2)];
      var $44=(($43+164)|0);
      var $45=HEAP32[(($44)>>2)];
      var $46=$45;
      $encoder_attr=$46;
      $l=0;
      __label__ = 10; break;
    case 10: 
      var $48=$l;
      var $49=(($48)>>>0) <= 255;
      if ($49) { __label__ = 11; break; } else { __label__ = 19; break; }
    case 11: 
      $h=0;
      __label__ = 12; break;
    case 12: 
      var $52=$h;
      var $53=(($52)>>>0) < 255;
      if ($53) { __label__ = 13; break; } else { __label__ = 17; break; }
    case 13: 
      var $55=$3;
      var $56=(($55)&65535);
      var $57=$h;
      var $58=$l;
      var $59=$encoder_attr;
      var $60=(($59)|0);
      var $61=(($60+($58<<9))|0);
      var $62=(($61+($57<<1))|0);
      var $63=HEAPU16[(($62)>>1)];
      var $64=(($63)&65535);
      var $65=(($56)|0)==(($64)|0);
      if ($65) { __label__ = 14; break; } else { __label__ = 15; break; }
    case 14: 
      var $67=$h;
      var $68=$l;
      var $69=$encoder_attr;
      var $70=(($69+131072)|0);
      var $71=(($70+($68<<9))|0);
      var $72=(($71+($67<<1))|0);
      var $73=HEAP16[(($72)>>1)];
      $cid=$73;
      var $74=$fontdef;
      var $75=$cid;
      var $76=_HPDF_CIDFontDef_GetCIDWidth($74, $75);
      var $77=(($76 << 16) >> 16);
      $1=$77;
      __label__ = 23; break;
    case 15: 
      __label__ = 16; break;
    case 16: 
      var $80=$h;
      var $81=((($80)+(1))|0);
      $h=$81;
      __label__ = 12; break;
    case 17: 
      __label__ = 18; break;
    case 18: 
      var $84=$l;
      var $85=((($84)+(1))|0);
      $l=$85;
      __label__ = 10; break;
    case 19: 
      __label__ = 20; break;
    case 20: 
      __label__ = 21; break;
    case 21: 
      __label__ = 22; break;
    case 22: 
      $1=0;
      __label__ = 23; break;
    case 23: 
      var $91=$1;
      ;
      return $91;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Font_GetUnicodeWidth["X"]=1;

function _HPDF_Font_GetBBox($agg_result, $font) {
  var __stackBase__  = STACKTOP; STACKTOP += 16; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $bbox=__stackBase__;
      $1=$font;
      var $2=$bbox;
      HEAP32[(($2)>>2)]=0; HEAP32[((($2)+(4))>>2)]=0; HEAP32[((($2)+(8))>>2)]=0; HEAP32[((($2)+(12))>>2)]=0;
      var $3=$1;
      var $4=_HPDF_Font_Validate($3);
      var $5=(($4)|0)!=0;
      if ($5) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $7=$1;
      var $8=(($7+44)|0);
      var $9=HEAP32[(($8)>>2)];
      var $10=$9;
      var $11=(($10+16)|0);
      var $12=HEAP32[(($11)>>2)];
      var $13=(($12+164)|0);
      var $14=$agg_result;
      var $15=$13;
      assert(16 % 1 === 0, 'memcpy given ' + 16 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP32[(($14)>>2)]=HEAP32[(($15)>>2)];HEAP32[((($14)+(4))>>2)]=HEAP32[((($15)+(4))>>2)];HEAP32[((($14)+(8))>>2)]=HEAP32[((($15)+(8))>>2)];HEAP32[((($14)+(12))>>2)]=HEAP32[((($15)+(12))>>2)];
      __label__ = 5; break;
    case 4: 
      var $17=$agg_result;
      var $18=$bbox;
      assert(16 % 1 === 0, 'memcpy given ' + 16 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP32[(($17)>>2)]=HEAP32[(($18)>>2)];HEAP32[((($17)+(4))>>2)]=HEAP32[((($18)+(4))>>2)];HEAP32[((($17)+(8))>>2)]=HEAP32[((($18)+(8))>>2)];HEAP32[((($17)+(12))>>2)]=HEAP32[((($18)+(12))>>2)];
      __label__ = 5; break;
    case 5: 
      STACKTOP = __stackBase__;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Font_GetAscent($font) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      $2=$font;
      var $3=$2;
      var $4=_HPDF_Font_Validate($3);
      var $5=(($4)|0)!=0;
      if ($5) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $7=$2;
      var $8=(($7+44)|0);
      var $9=HEAP32[(($8)>>2)];
      var $10=$9;
      var $11=(($10+16)|0);
      var $12=HEAP32[(($11)>>2)];
      var $13=(($12+156)|0);
      var $14=HEAP16[(($13)>>1)];
      var $15=(($14 << 16) >> 16);
      $1=$15;
      __label__ = 5; break;
    case 4: 
      $1=0;
      __label__ = 5; break;
    case 5: 
      var $18=$1;
      ;
      return $18;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Font_GetDescent($font) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      $2=$font;
      var $3=$2;
      var $4=_HPDF_Font_Validate($3);
      var $5=(($4)|0)!=0;
      if ($5) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $7=$2;
      var $8=(($7+44)|0);
      var $9=HEAP32[(($8)>>2)];
      var $10=$9;
      var $11=(($10+16)|0);
      var $12=HEAP32[(($11)>>2)];
      var $13=(($12+158)|0);
      var $14=HEAP16[(($13)>>1)];
      var $15=(($14 << 16) >> 16);
      $1=$15;
      __label__ = 5; break;
    case 4: 
      $1=0;
      __label__ = 5; break;
    case 5: 
      var $18=$1;
      ;
      return $18;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Font_GetXHeight($font) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      $2=$font;
      var $3=$2;
      var $4=_HPDF_Font_Validate($3);
      var $5=(($4)|0)!=0;
      if ($5) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $7=$2;
      var $8=(($7+44)|0);
      var $9=HEAP32[(($8)>>2)];
      var $10=$9;
      var $11=(($10+16)|0);
      var $12=HEAP32[(($11)>>2)];
      var $13=(($12+192)|0);
      var $14=HEAPU16[(($13)>>1)];
      var $15=(($14)&65535);
      $1=$15;
      __label__ = 5; break;
    case 4: 
      $1=0;
      __label__ = 5; break;
    case 5: 
      var $18=$1;
      ;
      return $18;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Font_GetCapHeight($font) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      $2=$font;
      var $3=$2;
      var $4=_HPDF_Font_Validate($3);
      var $5=(($4)|0)!=0;
      if ($5) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $7=$2;
      var $8=(($7+44)|0);
      var $9=HEAP32[(($8)>>2)];
      var $10=$9;
      var $11=(($10+16)|0);
      var $12=HEAP32[(($11)>>2)];
      var $13=(($12+194)|0);
      var $14=HEAPU16[(($13)>>1)];
      var $15=(($14)&65535);
      $1=$15;
      __label__ = 5; break;
    case 4: 
      $1=0;
      __label__ = 5; break;
    case 5: 
      var $18=$1;
      ;
      return $18;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Type0Font_New($mmgr, $fontdef, $encoder, $xref) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $5;
      var $font;
      var $attr;
      var $encoder_attr;
      var $ret;
      var $descendant_fonts;
      $2=$mmgr;
      $3=$fontdef;
      $4=$encoder;
      $5=$xref;
      $ret=0;
      var $6=$2;
      var $7=_HPDF_Dict_New($6);
      $font=$7;
      var $8=$font;
      var $9=(($8)|0)!=0;
      if ($9) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=0;
      __label__ = 34; break;
    case 4: 
      var $12=$font;
      var $13=(($12)|0);
      var $14=(($13+6)|0);
      var $15=HEAPU16[(($14)>>1)];
      var $16=(($15)&65535);
      var $17=$16 | 256;
      var $18=(($17) & 65535);
      HEAP16[(($14)>>1)]=$18;
      var $19=$4;
      var $20=(($19+140)|0);
      var $21=HEAP32[(($20)>>2)];
      var $22=(($21)|0)!=1;
      if ($22) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $24=$font;
      var $25=(($24+12)|0);
      var $26=HEAP32[(($25)>>2)];
      var $27=_HPDF_SetError($26, 4136, 0);
      $1=0;
      __label__ = 34; break;
    case 6: 
      var $29=$3;
      var $30=(($29+140)|0);
      var $31=HEAP32[(($30)>>2)];
      var $32=(($31)|0)!=2;
      if ($32) { __label__ = 7; break; } else { __label__ = 9; break; }
    case 7: 
      var $34=$3;
      var $35=(($34+140)|0);
      var $36=HEAP32[(($35)>>2)];
      var $37=(($36)|0)!=1;
      if ($37) { __label__ = 8; break; } else { __label__ = 9; break; }
    case 8: 
      var $39=$font;
      var $40=(($39+12)|0);
      var $41=HEAP32[(($40)>>2)];
      var $42=_HPDF_SetError($41, 4142, 0);
      $1=0;
      __label__ = 34; break;
    case 9: 
      var $44=$2;
      var $45=_HPDF_GetMem($44, 48);
      var $46=$45;
      $attr=$46;
      var $47=$attr;
      var $48=(($47)|0)!=0;
      if ($48) { __label__ = 11; break; } else { __label__ = 10; break; }
    case 10: 
      var $50=$font;
      _HPDF_Dict_Free($50);
      $1=0;
      __label__ = 34; break;
    case 11: 
      var $52=$font;
      var $53=(($52)|0);
      var $54=(($53+6)|0);
      var $55=HEAPU16[(($54)>>1)];
      var $56=(($55)&65535);
      var $57=$56 | 256;
      var $58=(($57) & 65535);
      HEAP16[(($54)>>1)]=$58;
      var $59=$font;
      var $60=(($59+24)|0);
      HEAP32[(($60)>>2)]=0;
      var $61=$font;
      var $62=(($61+32)|0);
      HEAP32[(($62)>>2)]=90;
      var $63=$attr;
      var $64=$63;
      var $65=$font;
      var $66=(($65+44)|0);
      HEAP32[(($66)>>2)]=$64;
      var $67=$4;
      var $68=(($67+164)|0);
      var $69=HEAP32[(($68)>>2)];
      var $70=$69;
      $encoder_attr=$70;
      var $71=$attr;
      var $72=$71;
      var $73=_HPDF_MemSet($72, 0, 48);
      var $74=$encoder_attr;
      var $75=(($74+262412)|0);
      var $76=HEAP32[(($75)>>2)];
      var $77=$attr;
      var $78=(($77+4)|0);
      HEAP32[(($78)>>2)]=$76;
      var $79=$attr;
      var $80=(($79+8)|0);
      HEAP32[(($80)>>2)]=92;
      var $81=$attr;
      var $82=(($81+12)|0);
      HEAP32[(($82)>>2)]=94;
      var $83=$3;
      var $84=$attr;
      var $85=(($84+16)|0);
      HEAP32[(($85)>>2)]=$83;
      var $86=$4;
      var $87=$attr;
      var $88=(($87+20)|0);
      HEAP32[(($88)>>2)]=$86;
      var $89=$5;
      var $90=$attr;
      var $91=(($90+32)|0);
      HEAP32[(($91)>>2)]=$89;
      var $92=$5;
      var $93=$font;
      var $94=$93;
      var $95=_HPDF_Xref_Add($92, $94);
      var $96=(($95)|0)!=0;
      if ($96) { __label__ = 12; break; } else { __label__ = 13; break; }
    case 12: 
      $1=0;
      __label__ = 34; break;
    case 13: 
      var $99=$font;
      var $100=_HPDF_Dict_AddName($99, ((STRING_TABLE.__str1156)|0), ((STRING_TABLE.__str11157)|0));
      var $101=$ret;
      var $102=((($101)+($100))|0);
      $ret=$102;
      var $103=$font;
      var $104=$3;
      var $105=(($104+4)|0);
      var $106=(($105)|0);
      var $107=_HPDF_Dict_AddName($103, ((STRING_TABLE.__str21158)|0), $106);
      var $108=$ret;
      var $109=((($108)+($107))|0);
      $ret=$109;
      var $110=$font;
      var $111=_HPDF_Dict_AddName($110, ((STRING_TABLE.__str31159)|0), ((STRING_TABLE.__str41160)|0));
      var $112=$ret;
      var $113=((($112)+($111))|0);
      $ret=$113;
      var $114=$3;
      var $115=(($114+140)|0);
      var $116=HEAP32[(($115)>>2)];
      var $117=(($116)|0)==2;
      if ($117) { __label__ = 14; break; } else { __label__ = 15; break; }
    case 14: 
      var $119=$font;
      var $120=$4;
      var $121=(($120+4)|0);
      var $122=(($121)|0);
      var $123=_HPDF_Dict_AddName($119, ((STRING_TABLE.__str51161)|0), $122);
      var $124=$ret;
      var $125=((($124)+($123))|0);
      $ret=$125;
      __label__ = 19; break;
    case 15: 
      var $127=$4;
      var $128=$5;
      var $129=_CreateCMap($127, $128);
      var $130=$attr;
      var $131=(($130+44)|0);
      HEAP32[(($131)>>2)]=$129;
      var $132=$attr;
      var $133=(($132+44)|0);
      var $134=HEAP32[(($133)>>2)];
      var $135=(($134)|0)!=0;
      if ($135) { __label__ = 16; break; } else { __label__ = 17; break; }
    case 16: 
      var $137=$font;
      var $138=$attr;
      var $139=(($138+44)|0);
      var $140=HEAP32[(($139)>>2)];
      var $141=$140;
      var $142=_HPDF_Dict_Add($137, ((STRING_TABLE.__str51161)|0), $141);
      var $143=$ret;
      var $144=((($143)+($142))|0);
      $ret=$144;
      __label__ = 18; break;
    case 17: 
      $1=0;
      __label__ = 34; break;
    case 18: 
      __label__ = 19; break;
    case 19: 
      var $148=$ret;
      var $149=(($148)|0)!=0;
      if ($149) { __label__ = 20; break; } else { __label__ = 21; break; }
    case 20: 
      $1=0;
      __label__ = 34; break;
    case 21: 
      var $152=$2;
      var $153=_HPDF_Array_New($152);
      $descendant_fonts=$153;
      var $154=$descendant_fonts;
      var $155=(($154)|0)!=0;
      if ($155) { __label__ = 23; break; } else { __label__ = 22; break; }
    case 22: 
      $1=0;
      __label__ = 34; break;
    case 23: 
      var $158=$font;
      var $159=$descendant_fonts;
      var $160=$159;
      var $161=_HPDF_Dict_Add($158, ((STRING_TABLE.__str61162)|0), $160);
      var $162=(($161)|0)!=0;
      if ($162) { __label__ = 24; break; } else { __label__ = 25; break; }
    case 24: 
      $1=0;
      __label__ = 34; break;
    case 25: 
      var $165=$3;
      var $166=(($165+140)|0);
      var $167=HEAP32[(($166)>>2)];
      var $168=(($167)|0)==2;
      if ($168) { __label__ = 26; break; } else { __label__ = 27; break; }
    case 26: 
      var $170=$font;
      var $171=$5;
      var $172=_CIDFontType0_New($170, $171);
      var $173=$attr;
      var $174=(($173+36)|0);
      HEAP32[(($174)>>2)]=$172;
      var $175=$attr;
      var $176=(($175)|0);
      HEAP32[(($176)>>2)]=3;
      __label__ = 28; break;
    case 27: 
      var $178=$font;
      var $179=$5;
      var $180=_CIDFontType2_New($178, $179);
      var $181=$attr;
      var $182=(($181+36)|0);
      HEAP32[(($182)>>2)]=$180;
      var $183=$attr;
      var $184=(($183)|0);
      HEAP32[(($184)>>2)]=4;
      __label__ = 28; break;
    case 28: 
      var $186=$attr;
      var $187=(($186+36)|0);
      var $188=HEAP32[(($187)>>2)];
      var $189=(($188)|0)!=0;
      if ($189) { __label__ = 30; break; } else { __label__ = 29; break; }
    case 29: 
      $1=0;
      __label__ = 34; break;
    case 30: 
      var $192=$descendant_fonts;
      var $193=$attr;
      var $194=(($193+36)|0);
      var $195=HEAP32[(($194)>>2)];
      var $196=$195;
      var $197=_HPDF_Array_Add($192, $196);
      var $198=(($197)|0)!=0;
      if ($198) { __label__ = 31; break; } else { __label__ = 32; break; }
    case 31: 
      $1=0;
      __label__ = 34; break;
    case 32: 
      __label__ = 33; break;
    case 33: 
      var $202=$font;
      $1=$202;
      __label__ = 34; break;
    case 34: 
      var $204=$1;
      ;
      return $204;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Type0Font_New["X"]=1;

function _OnFree_Func($obj) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $attr;
      $1=$obj;
      var $2=$1;
      var $3=(($2+44)|0);
      var $4=HEAP32[(($3)>>2)];
      var $5=$4;
      $attr=$5;
      var $6=$attr;
      var $7=(($6)|0)!=0;
      if ($7) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $9=$1;
      var $10=(($9+8)|0);
      var $11=HEAP32[(($10)>>2)];
      var $12=$attr;
      var $13=$12;
      _HPDF_FreeMem($11, $13);
      __label__ = 4; break;
    case 4: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}


function _TextWidth($agg_result, $font, $text, $len) {
  var __stackBase__  = STACKTOP; STACKTOP += 32; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $tw=__stackBase__;
      var $attr;
      var $parse_state=(__stackBase__)+(16);
      var $encoder;
      var $i;
      var $dw2;
      var $b;
      var $cid_fontdef_attr;
      var $btype;
      var $cid;
      var $unicode;
      var $code;
      var $w;
      $1=$font;
      $2=$text;
      $3=$len;
      var $4=$tw;
      HEAP32[(($4)>>2)]=0; HEAP32[((($4)+(4))>>2)]=0; HEAP32[((($4)+(8))>>2)]=0; HEAP32[((($4)+(12))>>2)]=0;
      var $5=$1;
      var $6=(($5+44)|0);
      var $7=HEAP32[(($6)>>2)];
      var $8=$7;
      $attr=$8;
      var $9=$attr;
      var $10=(($9+20)|0);
      var $11=HEAP32[(($10)>>2)];
      $encoder=$11;
      $i=0;
      $b=0;
      var $12=$attr;
      var $13=(($12+16)|0);
      var $14=HEAP32[(($13)>>2)];
      var $15=(($14+140)|0);
      var $16=HEAP32[(($15)>>2)];
      var $17=(($16)|0)==2;
      if ($17) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $19=$attr;
      var $20=(($19+16)|0);
      var $21=HEAP32[(($20)>>2)];
      var $22=(($21+208)|0);
      var $23=HEAP32[(($22)>>2)];
      var $24=$23;
      $cid_fontdef_attr=$24;
      var $25=$cid_fontdef_attr;
      var $26=(($25+6)|0);
      var $27=(($26+2)|0);
      var $28=HEAP16[(($27)>>1)];
      var $29=(($28 << 16) >> 16);
      $dw2=$29;
      __label__ = 5; break;
    case 4: 
      var $31=$attr;
      var $32=(($31+16)|0);
      var $33=HEAP32[(($32)>>2)];
      var $34=(($33+164)|0);
      var $35=(($34+4)|0);
      var $36=HEAPF32[(($35)>>2)];
      var $37=$attr;
      var $38=(($37+16)|0);
      var $39=HEAP32[(($38)>>2)];
      var $40=(($39+164)|0);
      var $41=(($40+12)|0);
      var $42=HEAPF32[(($41)>>2)];
      var $43=($36)-($42);
      var $44=(($43)&-1);
      $dw2=$44;
      __label__ = 5; break;
    case 5: 
      var $46=$encoder;
      var $47=$2;
      var $48=$3;
      _HPDF_Encoder_SetParseText($46, $parse_state, $47, $48);
      __label__ = 6; break;
    case 6: 
      var $50=$i;
      var $51=$3;
      var $52=(($50)>>>0) < (($51)>>>0);
      if ($52) { __label__ = 7; break; } else { __label__ = 25; break; }
    case 7: 
      var $54=$encoder;
      var $55=_HPDF_CMapEncoder_ByteType($54, $parse_state);
      $btype=$55;
      $w=0;
      var $56=$2;
      var $57=(($56+1)|0);
      $2=$57;
      var $58=HEAP8[($56)];
      $b=$58;
      var $59=$b;
      var $60=(($59)&255);
      $code=$60;
      var $61=$btype;
      var $62=(($61)|0)==1;
      if ($62) { __label__ = 8; break; } else { __label__ = 9; break; }
    case 8: 
      var $64=$code;
      var $65=(($64)&65535);
      var $66=$65 << 8;
      var $67=(($66) & 65535);
      $code=$67;
      var $68=$2;
      var $69=HEAPU8[($68)];
      var $70=(($69)&255);
      var $71=$code;
      var $72=(($71)&65535);
      var $73=((($72)+($70))|0);
      var $74=(($73) & 65535);
      $code=$74;
      __label__ = 9; break;
    case 9: 
      var $76=$btype;
      var $77=(($76)|0)!=2;
      if ($77) { __label__ = 10; break; } else { __label__ = 17; break; }
    case 10: 
      var $79=$attr;
      var $80=(($79+4)|0);
      var $81=HEAP32[(($80)>>2)];
      var $82=(($81)|0)==0;
      if ($82) { __label__ = 11; break; } else { __label__ = 15; break; }
    case 11: 
      var $84=$attr;
      var $85=(($84+16)|0);
      var $86=HEAP32[(($85)>>2)];
      var $87=(($86+140)|0);
      var $88=HEAP32[(($87)>>2)];
      var $89=(($88)|0)==2;
      if ($89) { __label__ = 12; break; } else { __label__ = 13; break; }
    case 12: 
      var $91=$encoder;
      var $92=$code;
      var $93=_HPDF_CMapEncoder_ToCID($91, $92);
      $cid=$93;
      var $94=$attr;
      var $95=(($94+16)|0);
      var $96=HEAP32[(($95)>>2)];
      var $97=$cid;
      var $98=_HPDF_CIDFontDef_GetCIDWidth($96, $97);
      var $99=(($98 << 16) >> 16);
      $w=$99;
      __label__ = 14; break;
    case 13: 
      var $101=$encoder;
      var $102=$code;
      var $103=_HPDF_CMapEncoder_ToUnicode($101, $102);
      $unicode=$103;
      var $104=$attr;
      var $105=(($104+16)|0);
      var $106=HEAP32[(($105)>>2)];
      var $107=$unicode;
      var $108=_HPDF_TTFontDef_GetCharWidth($106, $107);
      var $109=(($108 << 16) >> 16);
      $w=$109;
      __label__ = 14; break;
    case 14: 
      __label__ = 16; break;
    case 15: 
      var $112=$dw2;
      var $113=(((-$112))|0);
      $w=$113;
      __label__ = 16; break;
    case 16: 
      var $115=(($tw)|0);
      var $116=HEAP32[(($115)>>2)];
      var $117=((($116)+(1))|0);
      HEAP32[(($115)>>2)]=$117;
      __label__ = 17; break;
    case 17: 
      var $119=$code;
      var $120=(($119)&65535);
      var $121=(($120)|0)==0;
      if ($121) { __label__ = 23; break; } else { __label__ = 18; break; }
    case 18: 
      var $123=$code;
      var $124=(($123)&65535);
      var $125=(($124)|0)==9;
      if ($125) { __label__ = 23; break; } else { __label__ = 19; break; }
    case 19: 
      var $127=$code;
      var $128=(($127)&65535);
      var $129=(($128)|0)==10;
      if ($129) { __label__ = 23; break; } else { __label__ = 20; break; }
    case 20: 
      var $131=$code;
      var $132=(($131)&65535);
      var $133=(($132)|0)==12;
      if ($133) { __label__ = 23; break; } else { __label__ = 21; break; }
    case 21: 
      var $135=$code;
      var $136=(($135)&65535);
      var $137=(($136)|0)==13;
      if ($137) { __label__ = 23; break; } else { __label__ = 22; break; }
    case 22: 
      var $139=$code;
      var $140=(($139)&65535);
      var $141=(($140)|0)==32;
      if ($141) { __label__ = 23; break; } else { __label__ = 24; break; }
    case 23: 
      var $143=(($tw+4)|0);
      var $144=HEAP32[(($143)>>2)];
      var $145=((($144)+(1))|0);
      HEAP32[(($143)>>2)]=$145;
      var $146=(($tw+12)|0);
      var $147=HEAP32[(($146)>>2)];
      var $148=((($147)+(1))|0);
      HEAP32[(($146)>>2)]=$148;
      __label__ = 24; break;
    case 24: 
      var $150=$w;
      var $151=(($tw+8)|0);
      var $152=HEAP32[(($151)>>2)];
      var $153=((($152)+($150))|0);
      HEAP32[(($151)>>2)]=$153;
      var $154=$i;
      var $155=((($154)+(1))|0);
      $i=$155;
      __label__ = 6; break;
    case 25: 
      var $157=$b;
      var $158=(($157)&255);
      var $159=(($158)|0)==0;
      if ($159) { __label__ = 31; break; } else { __label__ = 26; break; }
    case 26: 
      var $161=$b;
      var $162=(($161)&255);
      var $163=(($162)|0)==9;
      if ($163) { __label__ = 31; break; } else { __label__ = 27; break; }
    case 27: 
      var $165=$b;
      var $166=(($165)&255);
      var $167=(($166)|0)==10;
      if ($167) { __label__ = 31; break; } else { __label__ = 28; break; }
    case 28: 
      var $169=$b;
      var $170=(($169)&255);
      var $171=(($170)|0)==12;
      if ($171) { __label__ = 31; break; } else { __label__ = 29; break; }
    case 29: 
      var $173=$b;
      var $174=(($173)&255);
      var $175=(($174)|0)==13;
      if ($175) { __label__ = 31; break; } else { __label__ = 30; break; }
    case 30: 
      var $177=$b;
      var $178=(($177)&255);
      var $179=(($178)|0)==32;
      if ($179) { __label__ = 31; break; } else { __label__ = 32; break; }
    case 31: 
      __label__ = 33; break;
    case 32: 
      var $182=(($tw+4)|0);
      var $183=HEAP32[(($182)>>2)];
      var $184=((($183)+(1))|0);
      HEAP32[(($182)>>2)]=$184;
      __label__ = 33; break;
    case 33: 
      var $186=$agg_result;
      var $187=$tw;
      assert(16 % 1 === 0, 'memcpy given ' + 16 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP32[(($186)>>2)]=HEAP32[(($187)>>2)];HEAP32[((($186)+(4))>>2)]=HEAP32[((($187)+(4))>>2)];HEAP32[((($186)+(8))>>2)]=HEAP32[((($187)+(8))>>2)];HEAP32[((($186)+(12))>>2)]=HEAP32[((($187)+(12))>>2)];
      STACKTOP = __stackBase__;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_TextWidth["X"]=1;

function _MeasureText($font, $text, $len, $width, $font_size, $char_space, $word_space, $wordwrap, $real_width) {
  var __stackBase__  = STACKTOP; STACKTOP += 16; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $5;
      var $6;
      var $7;
      var $8;
      var $9;
      var $10;
      var $w;
      var $tmp_len;
      var $i;
      var $attr;
      var $last_btype;
      var $encoder;
      var $parse_state=__stackBase__;
      var $dw2;
      var $cid_fontdef_attr;
      var $b;
      var $b2;
      var $btype;
      var $unicode;
      var $code;
      var $tmp_w;
      var $cid;
      $2=$font;
      $3=$text;
      $4=$len;
      $5=$width;
      $6=$font_size;
      $7=$char_space;
      $8=$word_space;
      $9=$wordwrap;
      $10=$real_width;
      $w=0;
      $tmp_len=0;
      var $11=$2;
      var $12=(($11+44)|0);
      var $13=HEAP32[(($12)>>2)];
      var $14=$13;
      $attr=$14;
      $last_btype=2;
      var $15=$attr;
      var $16=(($15+20)|0);
      var $17=HEAP32[(($16)>>2)];
      $encoder=$17;
      var $18=$attr;
      var $19=(($18+16)|0);
      var $20=HEAP32[(($19)>>2)];
      var $21=(($20+140)|0);
      var $22=HEAP32[(($21)>>2)];
      var $23=(($22)|0)==2;
      if ($23) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $25=$attr;
      var $26=(($25+16)|0);
      var $27=HEAP32[(($26)>>2)];
      var $28=(($27+208)|0);
      var $29=HEAP32[(($28)>>2)];
      var $30=$29;
      $cid_fontdef_attr=$30;
      var $31=$cid_fontdef_attr;
      var $32=(($31+6)|0);
      var $33=(($32+2)|0);
      var $34=HEAP16[(($33)>>1)];
      var $35=(($34 << 16) >> 16);
      $dw2=$35;
      __label__ = 5; break;
    case 4: 
      var $37=$attr;
      var $38=(($37+16)|0);
      var $39=HEAP32[(($38)>>2)];
      var $40=(($39+164)|0);
      var $41=(($40+4)|0);
      var $42=HEAPF32[(($41)>>2)];
      var $43=$attr;
      var $44=(($43+16)|0);
      var $45=HEAP32[(($44)>>2)];
      var $46=(($45+164)|0);
      var $47=(($46+12)|0);
      var $48=HEAPF32[(($47)>>2)];
      var $49=($42)-($48);
      var $50=(($49)&-1);
      $dw2=$50;
      __label__ = 5; break;
    case 5: 
      var $52=$encoder;
      var $53=$3;
      var $54=$4;
      _HPDF_Encoder_SetParseText($52, $parse_state, $53, $54);
      $i=0;
      __label__ = 6; break;
    case 6: 
      var $56=$i;
      var $57=$4;
      var $58=(($56)>>>0) < (($57)>>>0);
      if ($58) { __label__ = 7; break; } else { __label__ = 75; break; }
    case 7: 
      var $60=$3;
      var $61=(($60+1)|0);
      $3=$61;
      var $62=HEAP8[($60)];
      $b=$62;
      var $63=$3;
      var $64=HEAP8[($63)];
      $b2=$64;
      var $65=$encoder;
      var $66=_HPDF_Encoder_ByteType($65, $parse_state);
      $btype=$66;
      var $67=$b;
      var $68=(($67)&255);
      $code=$68;
      $tmp_w=0;
      var $69=$btype;
      var $70=(($69)|0)==1;
      if ($70) { __label__ = 8; break; } else { __label__ = 9; break; }
    case 8: 
      var $72=$code;
      var $73=(($72)&65535);
      var $74=$73 << 8;
      var $75=(($74) & 65535);
      $code=$75;
      var $76=$b2;
      var $77=(($76)&255);
      var $78=$code;
      var $79=(($78)&65535);
      var $80=((($79)+($77))|0);
      var $81=(($80) & 65535);
      $code=$81;
      __label__ = 9; break;
    case 9: 
      var $83=$9;
      var $84=(($83)|0)!=0;
      if ($84) { __label__ = 26; break; } else { __label__ = 10; break; }
    case 10: 
      var $86=$b;
      var $87=(($86)&255);
      var $88=(($87)|0)==0;
      if ($88) { __label__ = 16; break; } else { __label__ = 11; break; }
    case 11: 
      var $90=$b;
      var $91=(($90)&255);
      var $92=(($91)|0)==9;
      if ($92) { __label__ = 16; break; } else { __label__ = 12; break; }
    case 12: 
      var $94=$b;
      var $95=(($94)&255);
      var $96=(($95)|0)==10;
      if ($96) { __label__ = 16; break; } else { __label__ = 13; break; }
    case 13: 
      var $98=$b;
      var $99=(($98)&255);
      var $100=(($99)|0)==12;
      if ($100) { __label__ = 16; break; } else { __label__ = 14; break; }
    case 14: 
      var $102=$b;
      var $103=(($102)&255);
      var $104=(($103)|0)==13;
      if ($104) { __label__ = 16; break; } else { __label__ = 15; break; }
    case 15: 
      var $106=$b;
      var $107=(($106)&255);
      var $108=(($107)|0)==32;
      if ($108) { __label__ = 16; break; } else { __label__ = 19; break; }
    case 16: 
      var $110=$i;
      var $111=((($110)+(1))|0);
      $tmp_len=$111;
      var $112=$10;
      var $113=(($112)|0)!=0;
      if ($113) { __label__ = 17; break; } else { __label__ = 18; break; }
    case 17: 
      var $115=$w;
      var $116=$10;
      HEAPF32[(($116)>>2)]=$115;
      __label__ = 18; break;
    case 18: 
      __label__ = 25; break;
    case 19: 
      var $119=$btype;
      var $120=(($119)|0)==0;
      if ($120) { __label__ = 21; break; } else { __label__ = 20; break; }
    case 20: 
      var $122=$btype;
      var $123=(($122)|0)==1;
      if ($123) { __label__ = 21; break; } else { __label__ = 24; break; }
    case 21: 
      var $125=$i;
      $tmp_len=$125;
      var $126=$10;
      var $127=(($126)|0)!=0;
      if ($127) { __label__ = 22; break; } else { __label__ = 23; break; }
    case 22: 
      var $129=$w;
      var $130=$10;
      HEAPF32[(($130)>>2)]=$129;
      __label__ = 23; break;
    case 23: 
      __label__ = 24; break;
    case 24: 
      __label__ = 25; break;
    case 25: 
      __label__ = 45; break;
    case 26: 
      var $135=$b;
      var $136=(($135)&255);
      var $137=(($136)|0)==0;
      if ($137) { __label__ = 32; break; } else { __label__ = 27; break; }
    case 27: 
      var $139=$b;
      var $140=(($139)&255);
      var $141=(($140)|0)==9;
      if ($141) { __label__ = 32; break; } else { __label__ = 28; break; }
    case 28: 
      var $143=$b;
      var $144=(($143)&255);
      var $145=(($144)|0)==10;
      if ($145) { __label__ = 32; break; } else { __label__ = 29; break; }
    case 29: 
      var $147=$b;
      var $148=(($147)&255);
      var $149=(($148)|0)==12;
      if ($149) { __label__ = 32; break; } else { __label__ = 30; break; }
    case 30: 
      var $151=$b;
      var $152=(($151)&255);
      var $153=(($152)|0)==13;
      if ($153) { __label__ = 32; break; } else { __label__ = 31; break; }
    case 31: 
      var $155=$b;
      var $156=(($155)&255);
      var $157=(($156)|0)==32;
      if ($157) { __label__ = 32; break; } else { __label__ = 35; break; }
    case 32: 
      var $159=$i;
      var $160=((($159)+(1))|0);
      $tmp_len=$160;
      var $161=$10;
      var $162=(($161)|0)!=0;
      if ($162) { __label__ = 33; break; } else { __label__ = 34; break; }
    case 33: 
      var $164=$w;
      var $165=$10;
      HEAPF32[(($165)>>2)]=$164;
      __label__ = 34; break;
    case 34: 
      __label__ = 44; break;
    case 35: 
      var $168=$last_btype;
      var $169=(($168)|0)==2;
      if ($169) { __label__ = 38; break; } else { __label__ = 36; break; }
    case 36: 
      var $171=$btype;
      var $172=(($171)|0)==1;
      if ($172) { __label__ = 37; break; } else { __label__ = 43; break; }
    case 37: 
      var $174=$last_btype;
      var $175=(($174)|0)==0;
      if ($175) { __label__ = 38; break; } else { __label__ = 43; break; }
    case 38: 
      var $177=$encoder;
      var $178=$code;
      var $179=_HPDF_Encoder_CheckJWWLineHead($177, $178);
      var $180=(($179)|0)!=0;
      if ($180) { __label__ = 42; break; } else { __label__ = 39; break; }
    case 39: 
      var $182=$i;
      $tmp_len=$182;
      var $183=$10;
      var $184=(($183)|0)!=0;
      if ($184) { __label__ = 40; break; } else { __label__ = 41; break; }
    case 40: 
      var $186=$w;
      var $187=$10;
      HEAPF32[(($187)>>2)]=$186;
      __label__ = 41; break;
    case 41: 
      __label__ = 42; break;
    case 42: 
      __label__ = 43; break;
    case 43: 
      __label__ = 44; break;
    case 44: 
      __label__ = 45; break;
    case 45: 
      var $193=$b;
      var $194=(($193)&255);
      var $195=(($194)|0)==0;
      if ($195) { __label__ = 51; break; } else { __label__ = 46; break; }
    case 46: 
      var $197=$b;
      var $198=(($197)&255);
      var $199=(($198)|0)==9;
      if ($199) { __label__ = 51; break; } else { __label__ = 47; break; }
    case 47: 
      var $201=$b;
      var $202=(($201)&255);
      var $203=(($202)|0)==10;
      if ($203) { __label__ = 51; break; } else { __label__ = 48; break; }
    case 48: 
      var $205=$b;
      var $206=(($205)&255);
      var $207=(($206)|0)==12;
      if ($207) { __label__ = 51; break; } else { __label__ = 49; break; }
    case 49: 
      var $209=$b;
      var $210=(($209)&255);
      var $211=(($210)|0)==13;
      if ($211) { __label__ = 51; break; } else { __label__ = 50; break; }
    case 50: 
      var $213=$b;
      var $214=(($213)&255);
      var $215=(($214)|0)==32;
      if ($215) { __label__ = 51; break; } else { __label__ = 52; break; }
    case 51: 
      var $217=$8;
      var $218=$w;
      var $219=($218)+($217);
      $w=$219;
      __label__ = 52; break;
    case 52: 
      var $221=$btype;
      var $222=(($221)|0)!=2;
      if ($222) { __label__ = 53; break; } else { __label__ = 62; break; }
    case 53: 
      var $224=$attr;
      var $225=(($224+4)|0);
      var $226=HEAP32[(($225)>>2)];
      var $227=(($226)|0)==0;
      if ($227) { __label__ = 54; break; } else { __label__ = 58; break; }
    case 54: 
      var $229=$attr;
      var $230=(($229+16)|0);
      var $231=HEAP32[(($230)>>2)];
      var $232=(($231+140)|0);
      var $233=HEAP32[(($232)>>2)];
      var $234=(($233)|0)==2;
      if ($234) { __label__ = 55; break; } else { __label__ = 56; break; }
    case 55: 
      var $236=$encoder;
      var $237=$code;
      var $238=_HPDF_CMapEncoder_ToCID($236, $237);
      $cid=$238;
      var $239=$attr;
      var $240=(($239+16)|0);
      var $241=HEAP32[(($240)>>2)];
      var $242=$cid;
      var $243=_HPDF_CIDFontDef_GetCIDWidth($241, $242);
      $tmp_w=$243;
      __label__ = 57; break;
    case 56: 
      var $245=$encoder;
      var $246=$code;
      var $247=_HPDF_CMapEncoder_ToUnicode($245, $246);
      $unicode=$247;
      var $248=$attr;
      var $249=(($248+16)|0);
      var $250=HEAP32[(($249)>>2)];
      var $251=$unicode;
      var $252=_HPDF_TTFontDef_GetCharWidth($250, $251);
      $tmp_w=$252;
      __label__ = 57; break;
    case 57: 
      __label__ = 59; break;
    case 58: 
      var $255=$dw2;
      var $256=(((-$255))|0);
      var $257=(($256) & 65535);
      $tmp_w=$257;
      __label__ = 59; break;
    case 59: 
      var $259=$i;
      var $260=(($259)>>>0) > 0;
      if ($260) { __label__ = 60; break; } else { __label__ = 61; break; }
    case 60: 
      var $262=$7;
      var $263=$w;
      var $264=($263)+($262);
      $w=$264;
      __label__ = 61; break;
    case 61: 
      __label__ = 62; break;
    case 62: 
      var $267=$tmp_w;
      var $268=(($267)&65535);
      var $269=$6;
      var $270=$269;
      var $271=($268)*($270);
      var $272=($271)/(1000);
      var $273=$w;
      var $274=$273;
      var $275=($274)+($272);
      var $276=$275;
      $w=$276;
      var $277=$w;
      var $278=$5;
      var $279=$277 > $278;
      if ($279) { __label__ = 64; break; } else { __label__ = 63; break; }
    case 63: 
      var $281=$b;
      var $282=(($281)&255);
      var $283=(($282)|0)==10;
      if ($283) { __label__ = 64; break; } else { __label__ = 65; break; }
    case 64: 
      var $285=$tmp_len;
      $1=$285;
      __label__ = 78; break;
    case 65: 
      var $287=$b;
      var $288=(($287)&255);
      var $289=(($288)|0)==0;
      if ($289) { __label__ = 71; break; } else { __label__ = 66; break; }
    case 66: 
      var $291=$b;
      var $292=(($291)&255);
      var $293=(($292)|0)==9;
      if ($293) { __label__ = 71; break; } else { __label__ = 67; break; }
    case 67: 
      var $295=$b;
      var $296=(($295)&255);
      var $297=(($296)|0)==10;
      if ($297) { __label__ = 71; break; } else { __label__ = 68; break; }
    case 68: 
      var $299=$b;
      var $300=(($299)&255);
      var $301=(($300)|0)==12;
      if ($301) { __label__ = 71; break; } else { __label__ = 69; break; }
    case 69: 
      var $303=$b;
      var $304=(($303)&255);
      var $305=(($304)|0)==13;
      if ($305) { __label__ = 71; break; } else { __label__ = 70; break; }
    case 70: 
      var $307=$b;
      var $308=(($307)&255);
      var $309=(($308)|0)==32;
      if ($309) { __label__ = 71; break; } else { __label__ = 72; break; }
    case 71: 
      $last_btype=2;
      __label__ = 73; break;
    case 72: 
      var $312=$btype;
      $last_btype=$312;
      __label__ = 73; break;
    case 73: 
      __label__ = 74; break;
    case 74: 
      var $315=$i;
      var $316=((($315)+(1))|0);
      $i=$316;
      __label__ = 6; break;
    case 75: 
      var $318=$10;
      var $319=(($318)|0)!=0;
      if ($319) { __label__ = 76; break; } else { __label__ = 77; break; }
    case 76: 
      var $321=$w;
      var $322=$10;
      HEAPF32[(($322)>>2)]=$321;
      __label__ = 77; break;
    case 77: 
      var $324=$4;
      $1=$324;
      __label__ = 78; break;
    case 78: 
      var $326=$1;
      STACKTOP = __stackBase__;
      return $326;
    default: assert(0, "bad label: " + __label__);
  }
}
_MeasureText["X"]=1;

function _CreateCMap($encoder, $xref) {
  var __stackBase__  = STACKTOP; STACKTOP += 512; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $ret;
      var $cmap;
      var $attr;
      var $buf=__stackBase__;
      var $pbuf;
      var $eptr;
      var $i;
      var $phase;
      var $odd;
      var $sysinfo;
      var $range;
      var $range1;
      var $range2;
      $2=$encoder;
      $3=$xref;
      $ret=0;
      var $4=$2;
      var $5=(($4+132)|0);
      var $6=HEAP32[(($5)>>2)];
      var $7=$3;
      var $8=_HPDF_DictStream_New($6, $7);
      $cmap=$8;
      var $9=$2;
      var $10=(($9+164)|0);
      var $11=HEAP32[(($10)>>2)];
      var $12=$11;
      $attr=$12;
      var $13=(($buf)|0);
      var $14=(($13+512)|0);
      var $15=((($14)-(1))|0);
      $eptr=$15;
      var $16=$cmap;
      var $17=(($16)|0)!=0;
      if ($17) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=0;
      __label__ = 45; break;
    case 4: 
      var $20=$cmap;
      var $21=_HPDF_Dict_AddName($20, ((STRING_TABLE.__str1156)|0), ((STRING_TABLE.__str71163)|0));
      var $22=$ret;
      var $23=((($22)+($21))|0);
      $ret=$23;
      var $24=$cmap;
      var $25=$2;
      var $26=(($25+4)|0);
      var $27=(($26)|0);
      var $28=_HPDF_Dict_AddName($24, ((STRING_TABLE.__str81164)|0), $27);
      var $29=$ret;
      var $30=((($29)+($28))|0);
      $ret=$30;
      var $31=$2;
      var $32=(($31+132)|0);
      var $33=HEAP32[(($32)>>2)];
      var $34=_HPDF_Dict_New($33);
      $sysinfo=$34;
      var $35=$sysinfo;
      var $36=(($35)|0)!=0;
      if ($36) { __label__ = 6; break; } else { __label__ = 5; break; }
    case 5: 
      $1=0;
      __label__ = 45; break;
    case 6: 
      var $39=$cmap;
      var $40=$sysinfo;
      var $41=$40;
      var $42=_HPDF_Dict_Add($39, ((STRING_TABLE.__str91165)|0), $41);
      var $43=(($42)|0)!=0;
      if ($43) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      $1=0;
      __label__ = 45; break;
    case 8: 
      var $46=$sysinfo;
      var $47=$2;
      var $48=(($47+132)|0);
      var $49=HEAP32[(($48)>>2)];
      var $50=$attr;
      var $51=(($50+262416)|0);
      var $52=(($51)|0);
      var $53=_HPDF_String_New($49, $52, 0);
      var $54=$53;
      var $55=_HPDF_Dict_Add($46, ((STRING_TABLE.__str101166)|0), $54);
      var $56=$ret;
      var $57=((($56)+($55))|0);
      $ret=$57;
      var $58=$sysinfo;
      var $59=$2;
      var $60=(($59+132)|0);
      var $61=HEAP32[(($60)>>2)];
      var $62=$attr;
      var $63=(($62+262544)|0);
      var $64=(($63)|0);
      var $65=_HPDF_String_New($61, $64, 0);
      var $66=$65;
      var $67=_HPDF_Dict_Add($58, ((STRING_TABLE.__str111167)|0), $66);
      var $68=$ret;
      var $69=((($68)+($67))|0);
      $ret=$69;
      var $70=$sysinfo;
      var $71=$attr;
      var $72=(($71+262672)|0);
      var $73=HEAP32[(($72)>>2)];
      var $74=_HPDF_Dict_AddNumber($70, ((STRING_TABLE.__str121168)|0), $73);
      var $75=$ret;
      var $76=((($75)+($74))|0);
      $ret=$76;
      var $77=$cmap;
      var $78=$attr;
      var $79=(($78+262412)|0);
      var $80=HEAP32[(($79)>>2)];
      var $81=_HPDF_Dict_AddNumber($77, ((STRING_TABLE.__str131169)|0), $80);
      var $82=$ret;
      var $83=((($82)+($81))|0);
      $ret=$83;
      var $84=$cmap;
      var $85=(($84+36)|0);
      var $86=HEAP32[(($85)>>2)];
      var $87=_HPDF_Stream_WriteStr($86, ((STRING_TABLE.__str141170)|0));
      var $88=$ret;
      var $89=((($88)+($87))|0);
      $ret=$89;
      var $90=$cmap;
      var $91=(($90+36)|0);
      var $92=HEAP32[(($91)>>2)];
      var $93=_HPDF_Stream_WriteStr($92, ((STRING_TABLE.__str151171)|0));
      var $94=$ret;
      var $95=((($94)+($93))|0);
      $ret=$95;
      var $96=$cmap;
      var $97=(($96+36)|0);
      var $98=HEAP32[(($97)>>2)];
      var $99=_HPDF_Stream_WriteStr($98, ((STRING_TABLE.__str161172)|0));
      var $100=$ret;
      var $101=((($100)+($99))|0);
      $ret=$101;
      var $102=(($buf)|0);
      var $103=$eptr;
      var $104=_HPDF_StrCpy($102, ((STRING_TABLE.__str171173)|0), $103);
      $pbuf=$104;
      var $105=$pbuf;
      var $106=$2;
      var $107=(($106+4)|0);
      var $108=(($107)|0);
      var $109=$eptr;
      var $110=_HPDF_StrCpy($105, $108, $109);
      $pbuf=$110;
      var $111=$pbuf;
      var $112=$eptr;
      var $113=_HPDF_StrCpy($111, ((STRING_TABLE.__str181174)|0), $112);
      var $114=$cmap;
      var $115=(($114+36)|0);
      var $116=HEAP32[(($115)>>2)];
      var $117=(($buf)|0);
      var $118=_HPDF_Stream_WriteStr($116, $117);
      var $119=$ret;
      var $120=((($119)+($118))|0);
      $ret=$120;
      var $121=(($buf)|0);
      var $122=$eptr;
      var $123=_HPDF_StrCpy($121, ((STRING_TABLE.__str191175)|0), $122);
      $pbuf=$123;
      var $124=$pbuf;
      var $125=$2;
      var $126=(($125+4)|0);
      var $127=(($126)|0);
      var $128=$eptr;
      var $129=_HPDF_StrCpy($124, $127, $128);
      $pbuf=$129;
      var $130=$pbuf;
      var $131=(($130+1)|0);
      $pbuf=$131;
      HEAP8[($130)]=32;
      var $132=$pbuf;
      var $133=$attr;
      var $134=(($133+262416)|0);
      var $135=(($134)|0);
      var $136=$eptr;
      var $137=_HPDF_StrCpy($132, $135, $136);
      $pbuf=$137;
      var $138=$pbuf;
      var $139=(($138+1)|0);
      $pbuf=$139;
      HEAP8[($138)]=32;
      var $140=$pbuf;
      var $141=$attr;
      var $142=(($141+262544)|0);
      var $143=(($142)|0);
      var $144=$eptr;
      var $145=_HPDF_StrCpy($140, $143, $144);
      $pbuf=$145;
      var $146=$pbuf;
      var $147=(($146+1)|0);
      $pbuf=$147;
      HEAP8[($146)]=32;
      var $148=$pbuf;
      var $149=$attr;
      var $150=(($149+262672)|0);
      var $151=HEAP32[(($150)>>2)];
      var $152=$eptr;
      var $153=_HPDF_IToA($148, $151, $152);
      $pbuf=$153;
      var $154=$pbuf;
      var $155=$eptr;
      var $156=_HPDF_StrCpy($154, ((STRING_TABLE.__str181174)|0), $155);
      var $157=$cmap;
      var $158=(($157+36)|0);
      var $159=HEAP32[(($158)>>2)];
      var $160=(($buf)|0);
      var $161=_HPDF_Stream_WriteStr($159, $160);
      var $162=$ret;
      var $163=((($162)+($161))|0);
      $ret=$163;
      var $164=$cmap;
      var $165=(($164+36)|0);
      var $166=HEAP32[(($165)>>2)];
      var $167=_HPDF_Stream_WriteStr($166, ((STRING_TABLE.__str201176)|0));
      var $168=$ret;
      var $169=((($168)+($167))|0);
      $ret=$169;
      var $170=$cmap;
      var $171=(($170+36)|0);
      var $172=HEAP32[(($171)>>2)];
      var $173=_HPDF_Stream_WriteStr($172, ((STRING_TABLE.__str211177)|0));
      var $174=$ret;
      var $175=((($174)+($173))|0);
      $ret=$175;
      var $176=$cmap;
      var $177=(($176+36)|0);
      var $178=HEAP32[(($177)>>2)];
      var $179=_HPDF_Stream_WriteStr($178, ((STRING_TABLE.__str221178)|0));
      var $180=$ret;
      var $181=((($180)+($179))|0);
      $ret=$181;
      var $182=$cmap;
      var $183=(($182+36)|0);
      var $184=HEAP32[(($183)>>2)];
      var $185=_HPDF_Stream_WriteStr($184, ((STRING_TABLE.__str231179)|0));
      var $186=$ret;
      var $187=((($186)+($185))|0);
      $ret=$187;
      var $188=$cmap;
      var $189=(($188+36)|0);
      var $190=HEAP32[(($189)>>2)];
      var $191=_HPDF_Stream_WriteStr($190, ((STRING_TABLE.__str241180)|0));
      var $192=$ret;
      var $193=((($192)+($191))|0);
      $ret=$193;
      var $194=$cmap;
      var $195=(($194+36)|0);
      var $196=HEAP32[(($195)>>2)];
      var $197=_HPDF_Stream_WriteStr($196, ((STRING_TABLE.__str251181)|0));
      var $198=$ret;
      var $199=((($198)+($197))|0);
      $ret=$199;
      var $200=(($buf)|0);
      var $201=$eptr;
      var $202=_HPDF_StrCpy($200, ((STRING_TABLE.__str261182)|0), $201);
      $pbuf=$202;
      var $203=$pbuf;
      var $204=$attr;
      var $205=(($204+262416)|0);
      var $206=(($205)|0);
      var $207=$eptr;
      var $208=_HPDF_StrCpy($203, $206, $207);
      $pbuf=$208;
      var $209=$pbuf;
      var $210=$eptr;
      var $211=_HPDF_StrCpy($209, ((STRING_TABLE.__str271183)|0), $210);
      var $212=$cmap;
      var $213=(($212+36)|0);
      var $214=HEAP32[(($213)>>2)];
      var $215=(($buf)|0);
      var $216=_HPDF_Stream_WriteStr($214, $215);
      var $217=$ret;
      var $218=((($217)+($216))|0);
      $ret=$218;
      var $219=(($buf)|0);
      var $220=$eptr;
      var $221=_HPDF_StrCpy($219, ((STRING_TABLE.__str281184)|0), $220);
      $pbuf=$221;
      var $222=$pbuf;
      var $223=$attr;
      var $224=(($223+262544)|0);
      var $225=(($224)|0);
      var $226=$eptr;
      var $227=_HPDF_StrCpy($222, $225, $226);
      $pbuf=$227;
      var $228=$pbuf;
      var $229=$eptr;
      var $230=_HPDF_StrCpy($228, ((STRING_TABLE.__str271183)|0), $229);
      var $231=$cmap;
      var $232=(($231+36)|0);
      var $233=HEAP32[(($232)>>2)];
      var $234=(($buf)|0);
      var $235=_HPDF_Stream_WriteStr($233, $234);
      var $236=$ret;
      var $237=((($236)+($235))|0);
      $ret=$237;
      var $238=(($buf)|0);
      var $239=$eptr;
      var $240=_HPDF_StrCpy($238, ((STRING_TABLE.__str291185)|0), $239);
      $pbuf=$240;
      var $241=$pbuf;
      var $242=$attr;
      var $243=(($242+262672)|0);
      var $244=HEAP32[(($243)>>2)];
      var $245=$eptr;
      var $246=_HPDF_IToA($241, $244, $245);
      $pbuf=$246;
      var $247=$pbuf;
      var $248=$eptr;
      var $249=_HPDF_StrCpy($247, ((STRING_TABLE.__str301186)|0), $248);
      $pbuf=$249;
      var $250=$pbuf;
      var $251=$eptr;
      var $252=_HPDF_StrCpy($250, ((STRING_TABLE.__str311187)|0), $251);
      var $253=$cmap;
      var $254=(($253+36)|0);
      var $255=HEAP32[(($254)>>2)];
      var $256=(($buf)|0);
      var $257=_HPDF_Stream_WriteStr($255, $256);
      var $258=$ret;
      var $259=((($258)+($257))|0);
      $ret=$259;
      var $260=(($buf)|0);
      var $261=$eptr;
      var $262=_HPDF_StrCpy($260, ((STRING_TABLE.__str321188)|0), $261);
      $pbuf=$262;
      var $263=$pbuf;
      var $264=$2;
      var $265=(($264+4)|0);
      var $266=(($265)|0);
      var $267=$eptr;
      var $268=_HPDF_StrCpy($263, $266, $267);
      $pbuf=$268;
      var $269=$pbuf;
      var $270=$eptr;
      var $271=_HPDF_StrCpy($269, ((STRING_TABLE.__str301186)|0), $270);
      var $272=$cmap;
      var $273=(($272+36)|0);
      var $274=HEAP32[(($273)>>2)];
      var $275=(($buf)|0);
      var $276=_HPDF_Stream_WriteStr($274, $275);
      var $277=$ret;
      var $278=((($277)+($276))|0);
      $ret=$278;
      var $279=$cmap;
      var $280=(($279+36)|0);
      var $281=HEAP32[(($280)>>2)];
      var $282=_HPDF_Stream_WriteStr($281, ((STRING_TABLE.__str331189)|0));
      var $283=$ret;
      var $284=((($283)+($282))|0);
      $ret=$284;
      var $285=$cmap;
      var $286=(($285+36)|0);
      var $287=HEAP32[(($286)>>2)];
      var $288=_HPDF_Stream_WriteStr($287, ((STRING_TABLE.__str341190)|0));
      var $289=$ret;
      var $290=((($289)+($288))|0);
      $ret=$290;
      var $291=$attr;
      var $292=(($291+262684)|0);
      var $293=HEAP32[(($292)>>2)];
      var $294=(($293)|0) >= 0;
      if ($294) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      var $296=(($buf)|0);
      var $297=$eptr;
      var $298=_HPDF_StrCpy($296, ((STRING_TABLE.__str351191)|0), $297);
      $pbuf=$298;
      var $299=$pbuf;
      var $300=$attr;
      var $301=(($300+262684)|0);
      var $302=HEAP32[(($301)>>2)];
      var $303=$eptr;
      var $304=_HPDF_IToA($299, $302, $303);
      $pbuf=$304;
      var $305=$pbuf;
      var $306=$eptr;
      var $307=_HPDF_StrCpy($305, ((STRING_TABLE.__str361192)|0), $306);
      var $308=$cmap;
      var $309=(($308+36)|0);
      var $310=HEAP32[(($309)>>2)];
      var $311=(($buf)|0);
      var $312=_HPDF_Stream_WriteStr($310, $311);
      var $313=$ret;
      var $314=((($313)+($312))|0);
      $ret=$314;
      __label__ = 10; break;
    case 10: 
      var $316=(($buf)|0);
      var $317=$eptr;
      var $318=_HPDF_StrCpy($316, ((STRING_TABLE.__str371193)|0), $317);
      $pbuf=$318;
      var $319=$pbuf;
      var $320=$attr;
      var $321=(($320+262688)|0);
      var $322=(($321)|0);
      var $323=HEAP32[(($322)>>2)];
      var $324=$eptr;
      var $325=_HPDF_IToA($319, $323, $324);
      $pbuf=$325;
      var $326=$pbuf;
      var $327=(($326+1)|0);
      $pbuf=$327;
      HEAP8[($326)]=32;
      var $328=$pbuf;
      var $329=$attr;
      var $330=(($329+262688)|0);
      var $331=(($330+4)|0);
      var $332=HEAP32[(($331)>>2)];
      var $333=$eptr;
      var $334=_HPDF_IToA($328, $332, $333);
      $pbuf=$334;
      var $335=$pbuf;
      var $336=(($335+1)|0);
      $pbuf=$336;
      HEAP8[($335)]=32;
      var $337=$pbuf;
      var $338=$attr;
      var $339=(($338+262688)|0);
      var $340=(($339+8)|0);
      var $341=HEAP32[(($340)>>2)];
      var $342=$eptr;
      var $343=_HPDF_IToA($337, $341, $342);
      $pbuf=$343;
      var $344=$pbuf;
      var $345=$eptr;
      var $346=_HPDF_StrCpy($344, ((STRING_TABLE.__str381194)|0), $345);
      var $347=$cmap;
      var $348=(($347+36)|0);
      var $349=HEAP32[(($348)>>2)];
      var $350=(($buf)|0);
      var $351=_HPDF_Stream_WriteStr($349, $350);
      var $352=$ret;
      var $353=((($352)+($351))|0);
      $ret=$353;
      var $354=(($buf)|0);
      var $355=$eptr;
      var $356=_HPDF_StrCpy($354, ((STRING_TABLE.__str391195)|0), $355);
      $pbuf=$356;
      var $357=$pbuf;
      var $358=$attr;
      var $359=(($358+262412)|0);
      var $360=HEAP32[(($359)>>2)];
      var $361=$eptr;
      var $362=_HPDF_IToA($357, $360, $361);
      $pbuf=$362;
      var $363=$pbuf;
      var $364=$eptr;
      var $365=_HPDF_StrCpy($363, ((STRING_TABLE.__str361192)|0), $364);
      var $366=$cmap;
      var $367=(($366+36)|0);
      var $368=HEAP32[(($367)>>2)];
      var $369=(($buf)|0);
      var $370=_HPDF_Stream_WriteStr($368, $369);
      var $371=$ret;
      var $372=((($371)+($370))|0);
      $ret=$372;
      var $373=(($buf)|0);
      var $374=$attr;
      var $375=(($374+262408)|0);
      var $376=HEAP32[(($375)>>2)];
      var $377=(($376+16)|0);
      var $378=HEAP32[(($377)>>2)];
      var $379=$eptr;
      var $380=_HPDF_IToA($373, $378, $379);
      $pbuf=$380;
      var $381=$pbuf;
      var $382=$eptr;
      var $383=_HPDF_StrCpy($381, ((STRING_TABLE.__str401196)|0), $382);
      var $384=$cmap;
      var $385=(($384+36)|0);
      var $386=HEAP32[(($385)>>2)];
      var $387=(($buf)|0);
      var $388=_HPDF_Stream_WriteStr($386, $387);
      var $389=$ret;
      var $390=((($389)+($388))|0);
      $ret=$390;
      $i=0;
      __label__ = 11; break;
    case 11: 
      var $392=$i;
      var $393=$attr;
      var $394=(($393+262408)|0);
      var $395=HEAP32[(($394)>>2)];
      var $396=(($395+16)|0);
      var $397=HEAPU32[(($396)>>2)];
      var $398=(($392)>>>0) < (($397)>>>0);
      if ($398) { __label__ = 12; break; } else { __label__ = 16; break; }
    case 12: 
      var $400=$attr;
      var $401=(($400+262408)|0);
      var $402=HEAP32[(($401)>>2)];
      var $403=$i;
      var $404=_HPDF_List_ItemAt($402, $403);
      var $405=$404;
      $range=$405;
      var $406=(($buf)|0);
      var $407=$range;
      var $408=(($407)|0);
      var $409=HEAP16[(($408)>>1)];
      var $410=$eptr;
      var $411=_UINT16ToHex($406, $409, $410);
      $pbuf=$411;
      var $412=$pbuf;
      var $413=(($412+1)|0);
      $pbuf=$413;
      HEAP8[($412)]=32;
      var $414=$pbuf;
      var $415=$range;
      var $416=(($415+2)|0);
      var $417=HEAP16[(($416)>>1)];
      var $418=$eptr;
      var $419=_UINT16ToHex($414, $417, $418);
      $pbuf=$419;
      var $420=$pbuf;
      var $421=$eptr;
      var $422=_HPDF_StrCpy($420, ((STRING_TABLE.__str411197)|0), $421);
      var $423=$cmap;
      var $424=(($423+36)|0);
      var $425=HEAP32[(($424)>>2)];
      var $426=(($buf)|0);
      var $427=_HPDF_Stream_WriteStr($425, $426);
      var $428=$ret;
      var $429=((($428)+($427))|0);
      $ret=$429;
      var $430=$ret;
      var $431=(($430)|0)!=0;
      if ($431) { __label__ = 13; break; } else { __label__ = 14; break; }
    case 13: 
      $1=0;
      __label__ = 45; break;
    case 14: 
      __label__ = 15; break;
    case 15: 
      var $435=$i;
      var $436=((($435)+(1))|0);
      $i=$436;
      __label__ = 11; break;
    case 16: 
      var $438=(($buf)|0);
      var $439=$eptr;
      var $440=_HPDF_StrCpy($438, ((STRING_TABLE.__str421198)|0), $439);
      var $441=$cmap;
      var $442=(($441+36)|0);
      var $443=HEAP32[(($442)>>2)];
      var $444=(($buf)|0);
      var $445=_HPDF_Stream_WriteStr($443, $444);
      var $446=$ret;
      var $447=((($446)+($445))|0);
      $ret=$447;
      var $448=$ret;
      var $449=(($448)|0)!=0;
      if ($449) { __label__ = 17; break; } else { __label__ = 18; break; }
    case 17: 
      $1=0;
      __label__ = 45; break;
    case 18: 
      var $452=(($buf)|0);
      var $453=$attr;
      var $454=(($453+262404)|0);
      var $455=HEAP32[(($454)>>2)];
      var $456=(($455+16)|0);
      var $457=HEAP32[(($456)>>2)];
      var $458=$eptr;
      var $459=_HPDF_IToA($452, $457, $458);
      $pbuf=$459;
      var $460=$pbuf;
      var $461=$eptr;
      var $462=_HPDF_StrCpy($460, ((STRING_TABLE.__str431199)|0), $461);
      var $463=$cmap;
      var $464=(($463+36)|0);
      var $465=HEAP32[(($464)>>2)];
      var $466=(($buf)|0);
      var $467=_HPDF_Stream_WriteStr($465, $466);
      var $468=$ret;
      var $469=((($468)+($467))|0);
      $ret=$469;
      $i=0;
      __label__ = 19; break;
    case 19: 
      var $471=$i;
      var $472=$attr;
      var $473=(($472+262404)|0);
      var $474=HEAP32[(($473)>>2)];
      var $475=(($474+16)|0);
      var $476=HEAPU32[(($475)>>2)];
      var $477=(($471)>>>0) < (($476)>>>0);
      if ($477) { __label__ = 20; break; } else { __label__ = 24; break; }
    case 20: 
      var $479=$attr;
      var $480=(($479+262404)|0);
      var $481=HEAP32[(($480)>>2)];
      var $482=$i;
      var $483=_HPDF_List_ItemAt($481, $482);
      var $484=$483;
      $range1=$484;
      var $485=(($buf)|0);
      var $486=$range1;
      var $487=(($486)|0);
      var $488=HEAP16[(($487)>>1)];
      var $489=$eptr;
      var $490=_UINT16ToHex($485, $488, $489);
      $pbuf=$490;
      var $491=$pbuf;
      var $492=(($491+1)|0);
      $pbuf=$492;
      HEAP8[($491)]=32;
      var $493=$pbuf;
      var $494=$range1;
      var $495=(($494+2)|0);
      var $496=HEAP16[(($495)>>1)];
      var $497=$eptr;
      var $498=_UINT16ToHex($493, $496, $497);
      $pbuf=$498;
      var $499=$pbuf;
      var $500=(($499+1)|0);
      $pbuf=$500;
      HEAP8[($499)]=32;
      var $501=$pbuf;
      var $502=$range1;
      var $503=(($502+4)|0);
      var $504=HEAPU16[(($503)>>1)];
      var $505=(($504)&65535);
      var $506=$eptr;
      var $507=_HPDF_IToA($501, $505, $506);
      $pbuf=$507;
      var $508=$pbuf;
      var $509=$eptr;
      var $510=_HPDF_StrCpy($508, ((STRING_TABLE.__str411197)|0), $509);
      var $511=$cmap;
      var $512=(($511+36)|0);
      var $513=HEAP32[(($512)>>2)];
      var $514=(($buf)|0);
      var $515=_HPDF_Stream_WriteStr($513, $514);
      var $516=$ret;
      var $517=((($516)+($515))|0);
      $ret=$517;
      var $518=$ret;
      var $519=(($518)|0)!=0;
      if ($519) { __label__ = 21; break; } else { __label__ = 22; break; }
    case 21: 
      $1=0;
      __label__ = 45; break;
    case 22: 
      __label__ = 23; break;
    case 23: 
      var $523=$i;
      var $524=((($523)+(1))|0);
      $i=$524;
      __label__ = 19; break;
    case 24: 
      var $526=(($buf)|0);
      var $527=$eptr;
      var $528=_HPDF_StrCpy($526, ((STRING_TABLE.__str441200)|0), $527);
      var $529=$cmap;
      var $530=(($529+36)|0);
      var $531=HEAP32[(($530)>>2)];
      var $532=(($buf)|0);
      var $533=_HPDF_Stream_WriteStr($531, $532);
      var $534=$ret;
      var $535=((($534)+($533))|0);
      $ret=$535;
      var $536=$ret;
      var $537=(($536)|0)!=0;
      if ($537) { __label__ = 25; break; } else { __label__ = 26; break; }
    case 25: 
      $1=0;
      __label__ = 45; break;
    case 26: 
      var $540=$attr;
      var $541=(($540+262400)|0);
      var $542=HEAP32[(($541)>>2)];
      var $543=(($542+16)|0);
      var $544=HEAPU32[(($543)>>2)];
      var $545=Math.floor(((($544)>>>0))/(100));
      $phase=$545;
      var $546=$attr;
      var $547=(($546+262400)|0);
      var $548=HEAP32[(($547)>>2)];
      var $549=(($548+16)|0);
      var $550=HEAPU32[(($549)>>2)];
      var $551=((($550)>>>0))%(100);
      $odd=$551;
      var $552=$phase;
      var $553=(($552)>>>0) > 0;
      if ($553) { __label__ = 27; break; } else { __label__ = 28; break; }
    case 27: 
      var $555=(($buf)|0);
      var $556=$eptr;
      var $557=_HPDF_IToA($555, 100, $556);
      $pbuf=$557;
      __label__ = 29; break;
    case 28: 
      var $559=(($buf)|0);
      var $560=$odd;
      var $561=$eptr;
      var $562=_HPDF_IToA($559, $560, $561);
      $pbuf=$562;
      __label__ = 29; break;
    case 29: 
      var $564=$pbuf;
      var $565=$eptr;
      var $566=_HPDF_StrCpy($564, ((STRING_TABLE.__str451201)|0), $565);
      var $567=$cmap;
      var $568=(($567+36)|0);
      var $569=HEAP32[(($568)>>2)];
      var $570=(($buf)|0);
      var $571=_HPDF_Stream_WriteStr($569, $570);
      var $572=$ret;
      var $573=((($572)+($571))|0);
      $ret=$573;
      $i=0;
      __label__ = 30; break;
    case 30: 
      var $575=$i;
      var $576=$attr;
      var $577=(($576+262400)|0);
      var $578=HEAP32[(($577)>>2)];
      var $579=(($578+16)|0);
      var $580=HEAPU32[(($579)>>2)];
      var $581=(($575)>>>0) < (($580)>>>0);
      if ($581) { __label__ = 31; break; } else { __label__ = 40; break; }
    case 31: 
      var $583=$attr;
      var $584=(($583+262400)|0);
      var $585=HEAP32[(($584)>>2)];
      var $586=$i;
      var $587=_HPDF_List_ItemAt($585, $586);
      var $588=$587;
      $range2=$588;
      var $589=(($buf)|0);
      var $590=$range2;
      var $591=(($590)|0);
      var $592=HEAP16[(($591)>>1)];
      var $593=$eptr;
      var $594=_UINT16ToHex($589, $592, $593);
      $pbuf=$594;
      var $595=$pbuf;
      var $596=(($595+1)|0);
      $pbuf=$596;
      HEAP8[($595)]=32;
      var $597=$pbuf;
      var $598=$range2;
      var $599=(($598+2)|0);
      var $600=HEAP16[(($599)>>1)];
      var $601=$eptr;
      var $602=_UINT16ToHex($597, $600, $601);
      $pbuf=$602;
      var $603=$pbuf;
      var $604=(($603+1)|0);
      $pbuf=$604;
      HEAP8[($603)]=32;
      var $605=$pbuf;
      var $606=$range2;
      var $607=(($606+4)|0);
      var $608=HEAPU16[(($607)>>1)];
      var $609=(($608)&65535);
      var $610=$eptr;
      var $611=_HPDF_IToA($605, $609, $610);
      $pbuf=$611;
      var $612=$pbuf;
      var $613=$eptr;
      var $614=_HPDF_StrCpy($612, ((STRING_TABLE.__str411197)|0), $613);
      var $615=$cmap;
      var $616=(($615+36)|0);
      var $617=HEAP32[(($616)>>2)];
      var $618=(($buf)|0);
      var $619=_HPDF_Stream_WriteStr($617, $618);
      var $620=$ret;
      var $621=((($620)+($619))|0);
      $ret=$621;
      var $622=$i;
      var $623=((($622)+(1))|0);
      var $624=((($623)>>>0))%(100);
      var $625=(($624)|0)==0;
      if ($625) { __label__ = 32; break; } else { __label__ = 36; break; }
    case 32: 
      var $627=$phase;
      var $628=((($627)-(1))|0);
      $phase=$628;
      var $629=(($buf)|0);
      var $630=$eptr;
      var $631=_HPDF_StrCpy($629, ((STRING_TABLE.__str461202)|0), $630);
      $pbuf=$631;
      var $632=$phase;
      var $633=(($632)>>>0) > 0;
      if ($633) { __label__ = 33; break; } else { __label__ = 34; break; }
    case 33: 
      var $635=$pbuf;
      var $636=$eptr;
      var $637=_HPDF_IToA($635, 100, $636);
      $pbuf=$637;
      __label__ = 35; break;
    case 34: 
      var $639=$pbuf;
      var $640=$odd;
      var $641=$eptr;
      var $642=_HPDF_IToA($639, $640, $641);
      $pbuf=$642;
      __label__ = 35; break;
    case 35: 
      var $644=$pbuf;
      var $645=$eptr;
      var $646=_HPDF_StrCpy($644, ((STRING_TABLE.__str451201)|0), $645);
      var $647=$cmap;
      var $648=(($647+36)|0);
      var $649=HEAP32[(($648)>>2)];
      var $650=(($buf)|0);
      var $651=_HPDF_Stream_WriteStr($649, $650);
      var $652=$ret;
      var $653=((($652)+($651))|0);
      $ret=$653;
      __label__ = 36; break;
    case 36: 
      var $655=$ret;
      var $656=(($655)|0)!=0;
      if ($656) { __label__ = 37; break; } else { __label__ = 38; break; }
    case 37: 
      $1=0;
      __label__ = 45; break;
    case 38: 
      __label__ = 39; break;
    case 39: 
      var $660=$i;
      var $661=((($660)+(1))|0);
      $i=$661;
      __label__ = 30; break;
    case 40: 
      var $663=$odd;
      var $664=(($663)>>>0) > 0;
      if ($664) { __label__ = 41; break; } else { __label__ = 42; break; }
    case 41: 
      var $666=(($buf)|0);
      var $667=$eptr;
      var $668=_HPDF_StrCpy($666, ((STRING_TABLE.__str471203)|0), $667);
      $pbuf=$668;
      __label__ = 42; break;
    case 42: 
      var $670=$pbuf;
      var $671=$eptr;
      var $672=_HPDF_StrCpy($670, ((STRING_TABLE.__str481204)|0), $671);
      $pbuf=$672;
      var $673=$pbuf;
      var $674=$eptr;
      var $675=_HPDF_StrCpy($673, ((STRING_TABLE.__str491205)|0), $674);
      $pbuf=$675;
      var $676=$pbuf;
      var $677=$eptr;
      var $678=_HPDF_StrCpy($676, ((STRING_TABLE.__str501206)|0), $677);
      $pbuf=$678;
      var $679=$pbuf;
      var $680=$eptr;
      var $681=_HPDF_StrCpy($679, ((STRING_TABLE.__str511207)|0), $680);
      $pbuf=$681;
      var $682=$pbuf;
      var $683=$eptr;
      var $684=_HPDF_StrCpy($682, ((STRING_TABLE.__str521208)|0), $683);
      $pbuf=$684;
      var $685=$pbuf;
      var $686=$eptr;
      var $687=_HPDF_StrCpy($685, ((STRING_TABLE.__str531209)|0), $686);
      var $688=$cmap;
      var $689=(($688+36)|0);
      var $690=HEAP32[(($689)>>2)];
      var $691=(($buf)|0);
      var $692=_HPDF_Stream_WriteStr($690, $691);
      var $693=$ret;
      var $694=((($693)+($692))|0);
      $ret=$694;
      var $695=$ret;
      var $696=(($695)|0)!=0;
      if ($696) { __label__ = 43; break; } else { __label__ = 44; break; }
    case 43: 
      $1=0;
      __label__ = 45; break;
    case 44: 
      var $699=$cmap;
      $1=$699;
      __label__ = 45; break;
    case 45: 
      var $701=$1;
      STACKTOP = __stackBase__;
      return $701;
    default: assert(0, "bad label: " + __label__);
  }
}
_CreateCMap["X"]=1;

function _CIDFontType0_New($parent, $xref) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $ret;
      var $attr;
      var $fontdef;
      var $fontdef_attr;
      var $encoder;
      var $encoder_attr;
      var $save_cid;
      var $font;
      var $array;
      var $sub_array;
      var $i;
      var $descriptor;
      var $cid_system_info;
      var $w;
      $2=$parent;
      $3=$xref;
      $ret=0;
      var $4=$2;
      var $5=(($4+44)|0);
      var $6=HEAP32[(($5)>>2)];
      var $7=$6;
      $attr=$7;
      var $8=$attr;
      var $9=(($8+16)|0);
      var $10=HEAP32[(($9)>>2)];
      $fontdef=$10;
      var $11=$fontdef;
      var $12=(($11+208)|0);
      var $13=HEAP32[(($12)>>2)];
      var $14=$13;
      $fontdef_attr=$14;
      var $15=$attr;
      var $16=(($15+20)|0);
      var $17=HEAP32[(($16)>>2)];
      $encoder=$17;
      var $18=$encoder;
      var $19=(($18+164)|0);
      var $20=HEAP32[(($19)>>2)];
      var $21=$20;
      $encoder_attr=$21;
      $save_cid=0;
      $sub_array=0;
      var $22=$2;
      var $23=(($22+8)|0);
      var $24=HEAP32[(($23)>>2)];
      var $25=_HPDF_Dict_New($24);
      $font=$25;
      var $26=$font;
      var $27=(($26)|0)!=0;
      if ($27) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=0;
      __label__ = 48; break;
    case 4: 
      var $30=$3;
      var $31=$font;
      var $32=$31;
      var $33=_HPDF_Xref_Add($30, $32);
      var $34=(($33)|0)!=0;
      if ($34) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      $1=0;
      __label__ = 48; break;
    case 6: 
      var $37=$font;
      var $38=_HPDF_Dict_AddName($37, ((STRING_TABLE.__str1156)|0), ((STRING_TABLE.__str11157)|0));
      var $39=$ret;
      var $40=((($39)+($38))|0);
      $ret=$40;
      var $41=$font;
      var $42=_HPDF_Dict_AddName($41, ((STRING_TABLE.__str31159)|0), ((STRING_TABLE.__str721228)|0));
      var $43=$ret;
      var $44=((($43)+($42))|0);
      $ret=$44;
      var $45=$font;
      var $46=$fontdef_attr;
      var $47=(($46+4)|0);
      var $48=HEAP16[(($47)>>1)];
      var $49=(($48 << 16) >> 16);
      var $50=_HPDF_Dict_AddNumber($45, ((STRING_TABLE.__str551211)|0), $49);
      var $51=$ret;
      var $52=((($51)+($50))|0);
      $ret=$52;
      var $53=$font;
      var $54=$fontdef;
      var $55=(($54+4)|0);
      var $56=(($55)|0);
      var $57=_HPDF_Dict_AddName($53, ((STRING_TABLE.__str21158)|0), $56);
      var $58=$ret;
      var $59=((($58)+($57))|0);
      $ret=$59;
      var $60=$ret;
      var $61=(($60)|0)!=0;
      if ($61) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      $1=0;
      __label__ = 48; break;
    case 8: 
      var $64=$2;
      var $65=(($64+8)|0);
      var $66=HEAP32[(($65)>>2)];
      var $67=_HPDF_Array_New($66);
      $array=$67;
      var $68=$array;
      var $69=(($68)|0)!=0;
      if ($69) { __label__ = 10; break; } else { __label__ = 9; break; }
    case 9: 
      $1=0;
      __label__ = 48; break;
    case 10: 
      var $72=$font;
      var $73=$array;
      var $74=$73;
      var $75=_HPDF_Dict_Add($72, ((STRING_TABLE.__str561212)|0), $74);
      var $76=(($75)|0)!=0;
      if ($76) { __label__ = 11; break; } else { __label__ = 12; break; }
    case 11: 
      $1=0;
      __label__ = 48; break;
    case 12: 
      var $79=$array;
      var $80=$fontdef_attr;
      var $81=(($80+6)|0);
      var $82=(($81)|0);
      var $83=HEAP16[(($82)>>1)];
      var $84=(($83 << 16) >> 16);
      var $85=_HPDF_Array_AddNumber($79, $84);
      var $86=$ret;
      var $87=((($86)+($85))|0);
      $ret=$87;
      var $88=$array;
      var $89=$fontdef_attr;
      var $90=(($89+6)|0);
      var $91=(($90+2)|0);
      var $92=HEAP16[(($91)>>1)];
      var $93=(($92 << 16) >> 16);
      var $94=_HPDF_Array_AddNumber($88, $93);
      var $95=$ret;
      var $96=((($95)+($94))|0);
      $ret=$96;
      var $97=$ret;
      var $98=(($97)|0)!=0;
      if ($98) { __label__ = 13; break; } else { __label__ = 14; break; }
    case 13: 
      $1=0;
      __label__ = 48; break;
    case 14: 
      var $101=$2;
      var $102=(($101+8)|0);
      var $103=HEAP32[(($102)>>2)];
      var $104=_HPDF_Array_New($103);
      $array=$104;
      var $105=$array;
      var $106=(($105)|0)!=0;
      if ($106) { __label__ = 16; break; } else { __label__ = 15; break; }
    case 15: 
      $1=0;
      __label__ = 48; break;
    case 16: 
      var $109=$font;
      var $110=$array;
      var $111=$110;
      var $112=_HPDF_Dict_Add($109, ((STRING_TABLE.__str571213)|0), $111);
      var $113=(($112)|0)!=0;
      if ($113) { __label__ = 17; break; } else { __label__ = 18; break; }
    case 17: 
      $1=0;
      __label__ = 48; break;
    case 18: 
      $i=0;
      __label__ = 19; break;
    case 19: 
      var $117=$i;
      var $118=$fontdef_attr;
      var $119=(($118)|0);
      var $120=HEAP32[(($119)>>2)];
      var $121=(($120+16)|0);
      var $122=HEAPU32[(($121)>>2)];
      var $123=(($117)>>>0) < (($122)>>>0);
      if ($123) { __label__ = 20; break; } else { __label__ = 29; break; }
    case 20: 
      var $125=$fontdef_attr;
      var $126=(($125)|0);
      var $127=HEAP32[(($126)>>2)];
      var $128=$i;
      var $129=_HPDF_List_ItemAt($127, $128);
      var $130=$129;
      $w=$130;
      var $131=$w;
      var $132=(($131)|0);
      var $133=HEAPU16[(($132)>>1)];
      var $134=(($133)&65535);
      var $135=$save_cid;
      var $136=(($135)&65535);
      var $137=((($136)+(1))|0);
      var $138=(($134)|0)!=(($137)|0);
      if ($138) { __label__ = 22; break; } else { __label__ = 21; break; }
    case 21: 
      var $140=$sub_array;
      var $141=(($140)|0)!=0;
      if ($141) { __label__ = 25; break; } else { __label__ = 22; break; }
    case 22: 
      var $143=$2;
      var $144=(($143+8)|0);
      var $145=HEAP32[(($144)>>2)];
      var $146=_HPDF_Array_New($145);
      $sub_array=$146;
      var $147=$sub_array;
      var $148=(($147)|0)!=0;
      if ($148) { __label__ = 24; break; } else { __label__ = 23; break; }
    case 23: 
      $1=0;
      __label__ = 48; break;
    case 24: 
      var $151=$array;
      var $152=$w;
      var $153=(($152)|0);
      var $154=HEAPU16[(($153)>>1)];
      var $155=(($154)&65535);
      var $156=_HPDF_Array_AddNumber($151, $155);
      var $157=$ret;
      var $158=((($157)+($156))|0);
      $ret=$158;
      var $159=$array;
      var $160=$sub_array;
      var $161=$160;
      var $162=_HPDF_Array_Add($159, $161);
      var $163=$ret;
      var $164=((($163)+($162))|0);
      $ret=$164;
      __label__ = 25; break;
    case 25: 
      var $166=$sub_array;
      var $167=$w;
      var $168=(($167+2)|0);
      var $169=HEAP16[(($168)>>1)];
      var $170=(($169 << 16) >> 16);
      var $171=_HPDF_Array_AddNumber($166, $170);
      var $172=$ret;
      var $173=((($172)+($171))|0);
      $ret=$173;
      var $174=$w;
      var $175=(($174)|0);
      var $176=HEAP16[(($175)>>1)];
      $save_cid=$176;
      var $177=$ret;
      var $178=(($177)|0)!=0;
      if ($178) { __label__ = 26; break; } else { __label__ = 27; break; }
    case 26: 
      $1=0;
      __label__ = 48; break;
    case 27: 
      __label__ = 28; break;
    case 28: 
      var $182=$i;
      var $183=((($182)+(1))|0);
      $i=$183;
      __label__ = 19; break;
    case 29: 
      var $185=$2;
      var $186=(($185+8)|0);
      var $187=HEAP32[(($186)>>2)];
      var $188=_HPDF_Dict_New($187);
      $descriptor=$188;
      var $189=$descriptor;
      var $190=(($189)|0)!=0;
      if ($190) { __label__ = 31; break; } else { __label__ = 30; break; }
    case 30: 
      $1=0;
      __label__ = 48; break;
    case 31: 
      var $193=$3;
      var $194=$descriptor;
      var $195=$194;
      var $196=_HPDF_Xref_Add($193, $195);
      var $197=(($196)|0)!=0;
      if ($197) { __label__ = 32; break; } else { __label__ = 33; break; }
    case 32: 
      $1=0;
      __label__ = 48; break;
    case 33: 
      var $200=$font;
      var $201=$descriptor;
      var $202=$201;
      var $203=_HPDF_Dict_Add($200, ((STRING_TABLE.__str631219)|0), $202);
      var $204=(($203)|0)!=0;
      if ($204) { __label__ = 34; break; } else { __label__ = 35; break; }
    case 34: 
      $1=0;
      __label__ = 48; break;
    case 35: 
      var $207=$descriptor;
      var $208=_HPDF_Dict_AddName($207, ((STRING_TABLE.__str1156)|0), ((STRING_TABLE.__str631219)|0));
      var $209=$ret;
      var $210=((($209)+($208))|0);
      $ret=$210;
      var $211=$descriptor;
      var $212=$fontdef;
      var $213=(($212+4)|0);
      var $214=(($213)|0);
      var $215=_HPDF_Dict_AddName($211, ((STRING_TABLE.__str681224)|0), $214);
      var $216=$ret;
      var $217=((($216)+($215))|0);
      $ret=$217;
      var $218=$descriptor;
      var $219=$fontdef;
      var $220=(($219+156)|0);
      var $221=HEAP16[(($220)>>1)];
      var $222=(($221 << 16) >> 16);
      var $223=_HPDF_Dict_AddNumber($218, ((STRING_TABLE.__str641220)|0), $222);
      var $224=$ret;
      var $225=((($224)+($223))|0);
      $ret=$225;
      var $226=$descriptor;
      var $227=$fontdef;
      var $228=(($227+158)|0);
      var $229=HEAP16[(($228)>>1)];
      var $230=(($229 << 16) >> 16);
      var $231=_HPDF_Dict_AddNumber($226, ((STRING_TABLE.__str651221)|0), $230);
      var $232=$ret;
      var $233=((($232)+($231))|0);
      $ret=$233;
      var $234=$descriptor;
      var $235=$fontdef;
      var $236=(($235+194)|0);
      var $237=HEAPU16[(($236)>>1)];
      var $238=(($237)&65535);
      var $239=_HPDF_Dict_AddNumber($234, ((STRING_TABLE.__str731229)|0), $238);
      var $240=$ret;
      var $241=((($240)+($239))|0);
      $ret=$241;
      var $242=$descriptor;
      var $243=$fontdef;
      var $244=(($243+188)|0);
      var $245=HEAP16[(($244)>>1)];
      var $246=(($245 << 16) >> 16);
      var $247=_HPDF_Dict_AddNumber($242, ((STRING_TABLE.__str741230)|0), $246);
      var $248=$ret;
      var $249=((($248)+($247))|0);
      $ret=$249;
      var $250=$descriptor;
      var $251=$fontdef;
      var $252=(($251+160)|0);
      var $253=HEAP32[(($252)>>2)];
      var $254=_HPDF_Dict_AddNumber($250, ((STRING_TABLE.__str661222)|0), $253);
      var $255=$ret;
      var $256=((($255)+($254))|0);
      $ret=$256;
      var $257=$ret;
      var $258=(($257)|0)!=0;
      if ($258) { __label__ = 36; break; } else { __label__ = 37; break; }
    case 36: 
      $1=0;
      __label__ = 48; break;
    case 37: 
      var $261=$2;
      var $262=(($261+8)|0);
      var $263=HEAP32[(($262)>>2)];
      var $264=$fontdef;
      var $265=(($264+164)|0);
      var $266=(($265)|0);
      var $267=HEAPF32[(($266)>>2)];
      var $268=(($265+4)|0);
      var $269=HEAPF32[(($268)>>2)];
      var $270=(($265+8)|0);
      var $271=HEAPF32[(($270)>>2)];
      var $272=(($265+12)|0);
      var $273=HEAPF32[(($272)>>2)];
      var $274=_HPDF_Box_Array_New($263, $267, $269, $271, $273);
      $array=$274;
      var $275=$array;
      var $276=(($275)|0)!=0;
      if ($276) { __label__ = 39; break; } else { __label__ = 38; break; }
    case 38: 
      $1=0;
      __label__ = 48; break;
    case 39: 
      var $279=$descriptor;
      var $280=$array;
      var $281=$280;
      var $282=_HPDF_Dict_Add($279, ((STRING_TABLE.__str671223)|0), $281);
      var $283=$ret;
      var $284=((($283)+($282))|0);
      $ret=$284;
      var $285=$descriptor;
      var $286=$fontdef;
      var $287=(($286+180)|0);
      var $288=HEAP16[(($287)>>1)];
      var $289=(($288 << 16) >> 16);
      var $290=_HPDF_Dict_AddNumber($285, ((STRING_TABLE.__str691225)|0), $289);
      var $291=$ret;
      var $292=((($291)+($290))|0);
      $ret=$292;
      var $293=$descriptor;
      var $294=$fontdef;
      var $295=(($294+182)|0);
      var $296=HEAPU16[(($295)>>1)];
      var $297=(($296)&65535);
      var $298=_HPDF_Dict_AddNumber($293, ((STRING_TABLE.__str701226)|0), $297);
      var $299=$ret;
      var $300=((($299)+($298))|0);
      $ret=$300;
      var $301=$ret;
      var $302=(($301)|0)!=0;
      if ($302) { __label__ = 40; break; } else { __label__ = 41; break; }
    case 40: 
      $1=0;
      __label__ = 48; break;
    case 41: 
      var $305=$2;
      var $306=(($305+8)|0);
      var $307=HEAP32[(($306)>>2)];
      var $308=_HPDF_Dict_New($307);
      $cid_system_info=$308;
      var $309=$cid_system_info;
      var $310=(($309)|0)!=0;
      if ($310) { __label__ = 43; break; } else { __label__ = 42; break; }
    case 42: 
      $1=0;
      __label__ = 48; break;
    case 43: 
      var $313=$font;
      var $314=$cid_system_info;
      var $315=$314;
      var $316=_HPDF_Dict_Add($313, ((STRING_TABLE.__str91165)|0), $315);
      var $317=(($316)|0)!=0;
      if ($317) { __label__ = 44; break; } else { __label__ = 45; break; }
    case 44: 
      $1=0;
      __label__ = 48; break;
    case 45: 
      var $320=$cid_system_info;
      var $321=$2;
      var $322=(($321+8)|0);
      var $323=HEAP32[(($322)>>2)];
      var $324=$encoder_attr;
      var $325=(($324+262416)|0);
      var $326=(($325)|0);
      var $327=_HPDF_String_New($323, $326, 0);
      var $328=$327;
      var $329=_HPDF_Dict_Add($320, ((STRING_TABLE.__str101166)|0), $328);
      var $330=$ret;
      var $331=((($330)+($329))|0);
      $ret=$331;
      var $332=$cid_system_info;
      var $333=$2;
      var $334=(($333+8)|0);
      var $335=HEAP32[(($334)>>2)];
      var $336=$encoder_attr;
      var $337=(($336+262544)|0);
      var $338=(($337)|0);
      var $339=_HPDF_String_New($335, $338, 0);
      var $340=$339;
      var $341=_HPDF_Dict_Add($332, ((STRING_TABLE.__str111167)|0), $340);
      var $342=$ret;
      var $343=((($342)+($341))|0);
      $ret=$343;
      var $344=$cid_system_info;
      var $345=$encoder_attr;
      var $346=(($345+262672)|0);
      var $347=HEAP32[(($346)>>2)];
      var $348=_HPDF_Dict_AddNumber($344, ((STRING_TABLE.__str121168)|0), $347);
      var $349=$ret;
      var $350=((($349)+($348))|0);
      $ret=$350;
      var $351=$ret;
      var $352=(($351)|0)!=0;
      if ($352) { __label__ = 46; break; } else { __label__ = 47; break; }
    case 46: 
      $1=0;
      __label__ = 48; break;
    case 47: 
      var $355=$font;
      $1=$355;
      __label__ = 48; break;
    case 48: 
      var $357=$1;
      ;
      return $357;
    default: assert(0, "bad label: " + __label__);
  }
}
_CIDFontType0_New["X"]=1;

function _CIDFontType2_New($parent, $xref) {
  var __stackBase__  = STACKTOP; STACKTOP += 131076; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $ret;
      var $attr;
      var $fontdef;
      var $fontdef_attr;
      var $encoder;
      var $encoder_attr;
      var $font;
      var $array;
      var $i;
      var $tmp_map=__stackBase__;
      var $cid_system_info;
      var $max;
      var $j;
      var $cid;
      var $unicode;
      var $gid;
      var $dw;
      var $ptmp_map;
      var $tmp_array;
      var $w;
      var $u=(__stackBase__)+(131072);
      var $gid1;
      $2=$parent;
      $3=$xref;
      $ret=0;
      var $4=$2;
      var $5=(($4+44)|0);
      var $6=HEAP32[(($5)>>2)];
      var $7=$6;
      $attr=$7;
      var $8=$attr;
      var $9=(($8+16)|0);
      var $10=HEAP32[(($9)>>2)];
      $fontdef=$10;
      var $11=$fontdef;
      var $12=(($11+208)|0);
      var $13=HEAP32[(($12)>>2)];
      var $14=$13;
      $fontdef_attr=$14;
      var $15=$attr;
      var $16=(($15+20)|0);
      var $17=HEAP32[(($16)>>2)];
      $encoder=$17;
      var $18=$encoder;
      var $19=(($18+164)|0);
      var $20=HEAP32[(($19)>>2)];
      var $21=$20;
      $encoder_attr=$21;
      $max=0;
      var $22=$2;
      var $23=(($22+8)|0);
      var $24=HEAP32[(($23)>>2)];
      var $25=_HPDF_Dict_New($24);
      $font=$25;
      var $26=$font;
      var $27=(($26)|0)!=0;
      if ($27) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=0;
      __label__ = 69; break;
    case 4: 
      var $30=$3;
      var $31=$font;
      var $32=$31;
      var $33=_HPDF_Xref_Add($30, $32);
      var $34=(($33)|0)!=0;
      if ($34) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      $1=0;
      __label__ = 69; break;
    case 6: 
      var $37=$2;
      var $38=(($37+20)|0);
      HEAP32[(($38)>>2)]=96;
      var $39=$font;
      var $40=_HPDF_Dict_AddName($39, ((STRING_TABLE.__str1156)|0), ((STRING_TABLE.__str11157)|0));
      var $41=$ret;
      var $42=((($41)+($40))|0);
      $ret=$42;
      var $43=$font;
      var $44=_HPDF_Dict_AddName($43, ((STRING_TABLE.__str31159)|0), ((STRING_TABLE.__str541210)|0));
      var $45=$ret;
      var $46=((($45)+($44))|0);
      $ret=$46;
      var $47=$font;
      var $48=$fontdef;
      var $49=(($48+188)|0);
      var $50=HEAP16[(($49)>>1)];
      var $51=(($50 << 16) >> 16);
      var $52=_HPDF_Dict_AddNumber($47, ((STRING_TABLE.__str551211)|0), $51);
      var $53=$ret;
      var $54=((($53)+($52))|0);
      $ret=$54;
      var $55=$ret;
      var $56=(($55)|0)!=0;
      if ($56) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      $1=0;
      __label__ = 69; break;
    case 8: 
      var $59=$font;
      var $60=(($59+8)|0);
      var $61=HEAP32[(($60)>>2)];
      var $62=_HPDF_Array_New($61);
      $array=$62;
      var $63=$array;
      var $64=(($63)|0)!=0;
      if ($64) { __label__ = 10; break; } else { __label__ = 9; break; }
    case 9: 
      $1=0;
      __label__ = 69; break;
    case 10: 
      var $67=$font;
      var $68=$array;
      var $69=$68;
      var $70=_HPDF_Dict_Add($67, ((STRING_TABLE.__str561212)|0), $69);
      var $71=(($70)|0)!=0;
      if ($71) { __label__ = 11; break; } else { __label__ = 12; break; }
    case 11: 
      $1=0;
      __label__ = 69; break;
    case 12: 
      var $74=$array;
      var $75=$fontdef;
      var $76=(($75+164)|0);
      var $77=(($76+4)|0);
      var $78=HEAPF32[(($77)>>2)];
      var $79=(($78)&-1);
      var $80=_HPDF_Array_AddNumber($74, $79);
      var $81=$ret;
      var $82=((($81)+($80))|0);
      $ret=$82;
      var $83=$array;
      var $84=$fontdef;
      var $85=(($84+164)|0);
      var $86=(($85+4)|0);
      var $87=HEAPF32[(($86)>>2)];
      var $88=$fontdef;
      var $89=(($88+164)|0);
      var $90=(($89+12)|0);
      var $91=HEAPF32[(($90)>>2)];
      var $92=($87)-($91);
      var $93=(($92)&-1);
      var $94=_HPDF_Array_AddNumber($83, $93);
      var $95=$ret;
      var $96=((($95)+($94))|0);
      $ret=$96;
      var $97=(($tmp_map)|0);
      var $98=$97;
      var $99=_HPDF_MemSet($98, 0, 131072);
      var $100=$ret;
      var $101=(($100)|0)!=0;
      if ($101) { __label__ = 13; break; } else { __label__ = 14; break; }
    case 13: 
      $1=0;
      __label__ = 69; break;
    case 14: 
      $i=0;
      __label__ = 15; break;
    case 15: 
      var $105=$i;
      var $106=(($105)>>>0) < 256;
      if ($106) { __label__ = 16; break; } else { __label__ = 26; break; }
    case 16: 
      $j=0;
      __label__ = 17; break;
    case 17: 
      var $109=$j;
      var $110=(($109)>>>0) < 256;
      if ($110) { __label__ = 18; break; } else { __label__ = 24; break; }
    case 18: 
      var $112=$j;
      var $113=$i;
      var $114=$encoder_attr;
      var $115=(($114+131072)|0);
      var $116=(($115+($113<<9))|0);
      var $117=(($116+($112<<1))|0);
      var $118=HEAP16[(($117)>>1)];
      $cid=$118;
      var $119=$cid;
      var $120=(($119)&65535);
      var $121=(($120)|0)!=0;
      if ($121) { __label__ = 19; break; } else { __label__ = 22; break; }
    case 19: 
      var $123=$j;
      var $124=$i;
      var $125=$encoder_attr;
      var $126=(($125)|0);
      var $127=(($126+($124<<9))|0);
      var $128=(($127+($123<<1))|0);
      var $129=HEAP16[(($128)>>1)];
      $unicode=$129;
      var $130=$fontdef;
      var $131=$unicode;
      var $132=_HPDF_TTFontDef_GetGlyphid($130, $131);
      $gid=$132;
      var $133=$gid;
      var $134=$cid;
      var $135=(($134)&65535);
      var $136=(($tmp_map+($135<<1))|0);
      HEAP16[(($136)>>1)]=$133;
      var $137=$max;
      var $138=(($137)&65535);
      var $139=$cid;
      var $140=(($139)&65535);
      var $141=(($138)|0) < (($140)|0);
      if ($141) { __label__ = 20; break; } else { __label__ = 21; break; }
    case 20: 
      var $143=$cid;
      $max=$143;
      __label__ = 21; break;
    case 21: 
      __label__ = 22; break;
    case 22: 
      __label__ = 23; break;
    case 23: 
      var $147=$j;
      var $148=((($147)+(1))|0);
      $j=$148;
      __label__ = 17; break;
    case 24: 
      __label__ = 25; break;
    case 25: 
      var $151=$i;
      var $152=((($151)+(1))|0);
      $i=$152;
      __label__ = 15; break;
    case 26: 
      var $154=$max;
      var $155=(($154)&65535);
      var $156=(($155)|0) > 0;
      if ($156) { __label__ = 27; break; } else { __label__ = 61; break; }
    case 27: 
      var $158=$fontdef;
      var $159=(($158+188)|0);
      var $160=HEAP16[(($159)>>1)];
      $dw=$160;
      var $161=(($tmp_map)|0);
      $ptmp_map=$161;
      $tmp_array=0;
      var $162=$font;
      var $163=(($162+8)|0);
      var $164=HEAP32[(($163)>>2)];
      var $165=_HPDF_Array_New($164);
      $array=$165;
      var $166=$array;
      var $167=(($166)|0)!=0;
      if ($167) { __label__ = 29; break; } else { __label__ = 28; break; }
    case 28: 
      $1=0;
      __label__ = 69; break;
    case 29: 
      var $170=$font;
      var $171=$array;
      var $172=$171;
      var $173=_HPDF_Dict_Add($170, ((STRING_TABLE.__str571213)|0), $172);
      var $174=(($173)|0)!=0;
      if ($174) { __label__ = 30; break; } else { __label__ = 31; break; }
    case 30: 
      $1=0;
      __label__ = 69; break;
    case 31: 
      $i=0;
      __label__ = 32; break;
    case 32: 
      var $178=$i;
      var $179=$max;
      var $180=(($179)&65535);
      var $181=(($178)>>>0) < (($180)>>>0);
      if ($181) { __label__ = 33; break; } else { __label__ = 48; break; }
    case 33: 
      var $183=$fontdef;
      var $184=$ptmp_map;
      var $185=HEAP16[(($184)>>1)];
      var $186=_HPDF_TTFontDef_GetGidWidth($183, $185);
      var $187=(($186 << 16) >> 16);
      $w=$187;
      var $188=$w;
      var $189=$dw;
      var $190=(($189 << 16) >> 16);
      var $191=(($188)|0)!=(($190)|0);
      if ($191) { __label__ = 34; break; } else { __label__ = 45; break; }
    case 34: 
      var $193=$tmp_array;
      var $194=(($193)|0)!=0;
      if ($194) { __label__ = 42; break; } else { __label__ = 35; break; }
    case 35: 
      var $196=$array;
      var $197=$i;
      var $198=_HPDF_Array_AddNumber($196, $197);
      $ret=$198;
      var $199=(($198)|0)!=0;
      if ($199) { __label__ = 36; break; } else { __label__ = 37; break; }
    case 36: 
      $1=0;
      __label__ = 69; break;
    case 37: 
      var $202=$font;
      var $203=(($202+8)|0);
      var $204=HEAP32[(($203)>>2)];
      var $205=_HPDF_Array_New($204);
      $tmp_array=$205;
      var $206=$tmp_array;
      var $207=(($206)|0)!=0;
      if ($207) { __label__ = 39; break; } else { __label__ = 38; break; }
    case 38: 
      $1=0;
      __label__ = 69; break;
    case 39: 
      var $210=$array;
      var $211=$tmp_array;
      var $212=$211;
      var $213=_HPDF_Array_Add($210, $212);
      $ret=$213;
      var $214=(($213)|0)!=0;
      if ($214) { __label__ = 40; break; } else { __label__ = 41; break; }
    case 40: 
      $1=0;
      __label__ = 69; break;
    case 41: 
      __label__ = 42; break;
    case 42: 
      var $218=$tmp_array;
      var $219=$w;
      var $220=_HPDF_Array_AddNumber($218, $219);
      $ret=$220;
      var $221=(($220)|0)!=0;
      if ($221) { __label__ = 43; break; } else { __label__ = 44; break; }
    case 43: 
      $1=0;
      __label__ = 69; break;
    case 44: 
      __label__ = 46; break;
    case 45: 
      $tmp_array=0;
      __label__ = 46; break;
    case 46: 
      __label__ = 47; break;
    case 47: 
      var $227=$i;
      var $228=((($227)+(1))|0);
      $i=$228;
      var $229=$ptmp_map;
      var $230=(($229+2)|0);
      $ptmp_map=$230;
      __label__ = 32; break;
    case 48: 
      var $232=$fontdef_attr;
      var $233=(($232+340)|0);
      var $234=HEAP32[(($233)>>2)];
      var $235=(($234)|0)!=0;
      if ($235) { __label__ = 49; break; } else { __label__ = 60; break; }
    case 49: 
      var $237=$font;
      var $238=(($237+8)|0);
      var $239=HEAP32[(($238)>>2)];
      var $240=$3;
      var $241=_HPDF_DictStream_New($239, $240);
      var $242=$attr;
      var $243=(($242+40)|0);
      HEAP32[(($243)>>2)]=$241;
      var $244=$attr;
      var $245=(($244+40)|0);
      var $246=HEAP32[(($245)>>2)];
      var $247=(($246)|0)!=0;
      if ($247) { __label__ = 51; break; } else { __label__ = 50; break; }
    case 50: 
      $1=0;
      __label__ = 69; break;
    case 51: 
      var $250=$font;
      var $251=$attr;
      var $252=(($251+40)|0);
      var $253=HEAP32[(($252)>>2)];
      var $254=$253;
      var $255=_HPDF_Dict_Add($250, ((STRING_TABLE.__str581214)|0), $254);
      $ret=$255;
      var $256=(($255)|0)!=0;
      if ($256) { __label__ = 52; break; } else { __label__ = 53; break; }
    case 52: 
      $1=0;
      __label__ = 69; break;
    case 53: 
      $i=0;
      __label__ = 54; break;
    case 54: 
      var $260=$i;
      var $261=$max;
      var $262=(($261)&65535);
      var $263=(($260)>>>0) < (($262)>>>0);
      if ($263) { __label__ = 55; break; } else { __label__ = 57; break; }
    case 55: 
      var $265=$i;
      var $266=(($tmp_map+($265<<1))|0);
      var $267=HEAP16[(($266)>>1)];
      $gid1=$267;
      var $268=$gid1;
      var $269=(($268)&65535);
      var $270=$269 >> 8;
      var $271=(($270) & 255);
      var $272=(($u)|0);
      HEAP8[($272)]=$271;
      var $273=$gid1;
      var $274=(($273) & 255);
      var $275=(($u+1)|0);
      HEAP8[($275)]=$274;
      var $276=(($tmp_map)|0);
      var $277=$i;
      var $278=(($276+($277<<1))|0);
      var $279=$278;
      var $280=(($u)|0);
      var $281=_HPDF_MemCpy($279, $280, 2);
      __label__ = 56; break;
    case 56: 
      var $283=$i;
      var $284=((($283)+(1))|0);
      $i=$284;
      __label__ = 54; break;
    case 57: 
      var $286=$attr;
      var $287=(($286+40)|0);
      var $288=HEAP32[(($287)>>2)];
      var $289=(($288+36)|0);
      var $290=HEAP32[(($289)>>2)];
      var $291=(($tmp_map)|0);
      var $292=$291;
      var $293=$max;
      var $294=(($293)&65535);
      var $295=((($294<<1))|0);
      var $296=_HPDF_Stream_Write($290, $292, $295);
      $ret=$296;
      var $297=(($296)|0)!=0;
      if ($297) { __label__ = 58; break; } else { __label__ = 59; break; }
    case 58: 
      $1=0;
      __label__ = 69; break;
    case 59: 
      __label__ = 60; break;
    case 60: 
      __label__ = 62; break;
    case 61: 
      var $302=$font;
      var $303=(($302+12)|0);
      var $304=HEAP32[(($303)>>2)];
      var $305=_HPDF_SetError($304, 4141, 0);
      $1=0;
      __label__ = 69; break;
    case 62: 
      var $307=$2;
      var $308=(($307+8)|0);
      var $309=HEAP32[(($308)>>2)];
      var $310=_HPDF_Dict_New($309);
      $cid_system_info=$310;
      var $311=$cid_system_info;
      var $312=(($311)|0)!=0;
      if ($312) { __label__ = 64; break; } else { __label__ = 63; break; }
    case 63: 
      $1=0;
      __label__ = 69; break;
    case 64: 
      var $315=$font;
      var $316=$cid_system_info;
      var $317=$316;
      var $318=_HPDF_Dict_Add($315, ((STRING_TABLE.__str91165)|0), $317);
      var $319=(($318)|0)!=0;
      if ($319) { __label__ = 65; break; } else { __label__ = 66; break; }
    case 65: 
      $1=0;
      __label__ = 69; break;
    case 66: 
      var $322=$cid_system_info;
      var $323=$2;
      var $324=(($323+8)|0);
      var $325=HEAP32[(($324)>>2)];
      var $326=$encoder_attr;
      var $327=(($326+262416)|0);
      var $328=(($327)|0);
      var $329=_HPDF_String_New($325, $328, 0);
      var $330=$329;
      var $331=_HPDF_Dict_Add($322, ((STRING_TABLE.__str101166)|0), $330);
      var $332=$ret;
      var $333=((($332)+($331))|0);
      $ret=$333;
      var $334=$cid_system_info;
      var $335=$2;
      var $336=(($335+8)|0);
      var $337=HEAP32[(($336)>>2)];
      var $338=$encoder_attr;
      var $339=(($338+262544)|0);
      var $340=(($339)|0);
      var $341=_HPDF_String_New($337, $340, 0);
      var $342=$341;
      var $343=_HPDF_Dict_Add($334, ((STRING_TABLE.__str111167)|0), $342);
      var $344=$ret;
      var $345=((($344)+($343))|0);
      $ret=$345;
      var $346=$cid_system_info;
      var $347=$encoder_attr;
      var $348=(($347+262672)|0);
      var $349=HEAP32[(($348)>>2)];
      var $350=_HPDF_Dict_AddNumber($346, ((STRING_TABLE.__str121168)|0), $349);
      var $351=$ret;
      var $352=((($351)+($350))|0);
      $ret=$352;
      var $353=$ret;
      var $354=(($353)|0)!=0;
      if ($354) { __label__ = 67; break; } else { __label__ = 68; break; }
    case 67: 
      $1=0;
      __label__ = 69; break;
    case 68: 
      var $357=$font;
      $1=$357;
      __label__ = 69; break;
    case 69: 
      var $359=$1;
      STACKTOP = __stackBase__;
      return $359;
    default: assert(0, "bad label: " + __label__);
  }
}
_CIDFontType2_New["X"]=1;

function _UINT16ToHex($s, $val, $eptr) {
  var __stackBase__  = STACKTOP; STACKTOP += 12; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3=__stackBase__;
      var $4;
      var $b=(__stackBase__)+(4);
      var $val2=(__stackBase__)+(8);
      var $c;
      $2=$s;
      HEAP16[(($3)>>1)]=$val;
      $4=$eptr;
      var $5=$4;
      var $6=$2;
      var $7=$5;
      var $8=$6;
      var $9=((($7)-($8))|0);
      var $10=(($9)|0) < 7;
      if ($10) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $12=$2;
      $1=$12;
      __label__ = 19; break;
    case 4: 
      var $14=(($b)|0);
      var $15=$3;
      var $16=_HPDF_MemCpy($14, $15, 2);
      var $17=(($b)|0);
      var $18=HEAPU8[($17)];
      var $19=(($18)&255);
      var $20=(($19)&65535);
      var $21=$20 << 8;
      var $22=(($b+1)|0);
      var $23=HEAPU8[($22)];
      var $24=(($23)&255);
      var $25=(($24)&65535);
      var $26=$21 | $25;
      var $27=(($26) & 65535);
      HEAP16[(($val2)>>1)]=$27;
      var $28=(($b)|0);
      var $29=$val2;
      var $30=_HPDF_MemCpy($28, $29, 2);
      var $31=$2;
      var $32=(($31+1)|0);
      $2=$32;
      HEAP8[($31)]=60;
      var $33=(($b)|0);
      var $34=HEAPU8[($33)];
      var $35=(($34)&255);
      var $36=(($35)|0)!=0;
      if ($36) { __label__ = 5; break; } else { __label__ = 12; break; }
    case 5: 
      var $38=(($b)|0);
      var $39=HEAPU8[($38)];
      var $40=(($39)&255);
      var $41=$40 >> 4;
      var $42=(($41) & 255);
      $c=$42;
      var $43=$c;
      var $44=(($43 << 24) >> 24);
      var $45=(($44)|0) <= 9;
      if ($45) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      var $47=$c;
      var $48=(($47 << 24) >> 24);
      var $49=((($48)+(48))|0);
      var $50=(($49) & 255);
      $c=$50;
      __label__ = 8; break;
    case 7: 
      var $52=$c;
      var $53=(($52 << 24) >> 24);
      var $54=((($53)+(55))|0);
      var $55=(($54) & 255);
      $c=$55;
      __label__ = 8; break;
    case 8: 
      var $57=$c;
      var $58=$2;
      var $59=(($58+1)|0);
      $2=$59;
      HEAP8[($58)]=$57;
      var $60=(($b)|0);
      var $61=HEAPU8[($60)];
      var $62=(($61)&255);
      var $63=$62 & 15;
      var $64=(($63) & 255);
      $c=$64;
      var $65=$c;
      var $66=(($65 << 24) >> 24);
      var $67=(($66)|0) <= 9;
      if ($67) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      var $69=$c;
      var $70=(($69 << 24) >> 24);
      var $71=((($70)+(48))|0);
      var $72=(($71) & 255);
      $c=$72;
      __label__ = 11; break;
    case 10: 
      var $74=$c;
      var $75=(($74 << 24) >> 24);
      var $76=((($75)+(55))|0);
      var $77=(($76) & 255);
      $c=$77;
      __label__ = 11; break;
    case 11: 
      var $79=$c;
      var $80=$2;
      var $81=(($80+1)|0);
      $2=$81;
      HEAP8[($80)]=$79;
      __label__ = 12; break;
    case 12: 
      var $83=(($b+1)|0);
      var $84=HEAPU8[($83)];
      var $85=(($84)&255);
      var $86=$85 >> 4;
      var $87=(($86) & 255);
      $c=$87;
      var $88=$c;
      var $89=(($88 << 24) >> 24);
      var $90=(($89)|0) <= 9;
      if ($90) { __label__ = 13; break; } else { __label__ = 14; break; }
    case 13: 
      var $92=$c;
      var $93=(($92 << 24) >> 24);
      var $94=((($93)+(48))|0);
      var $95=(($94) & 255);
      $c=$95;
      __label__ = 15; break;
    case 14: 
      var $97=$c;
      var $98=(($97 << 24) >> 24);
      var $99=((($98)+(55))|0);
      var $100=(($99) & 255);
      $c=$100;
      __label__ = 15; break;
    case 15: 
      var $102=$c;
      var $103=$2;
      var $104=(($103+1)|0);
      $2=$104;
      HEAP8[($103)]=$102;
      var $105=(($b+1)|0);
      var $106=HEAPU8[($105)];
      var $107=(($106)&255);
      var $108=$107 & 15;
      var $109=(($108) & 255);
      $c=$109;
      var $110=$c;
      var $111=(($110 << 24) >> 24);
      var $112=(($111)|0) <= 9;
      if ($112) { __label__ = 16; break; } else { __label__ = 17; break; }
    case 16: 
      var $114=$c;
      var $115=(($114 << 24) >> 24);
      var $116=((($115)+(48))|0);
      var $117=(($116) & 255);
      $c=$117;
      __label__ = 18; break;
    case 17: 
      var $119=$c;
      var $120=(($119 << 24) >> 24);
      var $121=((($120)+(55))|0);
      var $122=(($121) & 255);
      $c=$122;
      __label__ = 18; break;
    case 18: 
      var $124=$c;
      var $125=$2;
      var $126=(($125+1)|0);
      $2=$126;
      HEAP8[($125)]=$124;
      var $127=$2;
      var $128=(($127+1)|0);
      $2=$128;
      HEAP8[($127)]=62;
      var $129=$2;
      HEAP8[($129)]=0;
      var $130=$2;
      $1=$130;
      __label__ = 19; break;
    case 19: 
      var $132=$1;
      STACKTOP = __stackBase__;
      return $132;
    default: assert(0, "bad label: " + __label__);
  }
}
_UINT16ToHex["X"]=1;

function _CIDFontType2_BeforeWrite_Func($obj) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $font_attr;
      var $def;
      var $def_attr;
      var $ret;
      var $descriptor;
      var $array;
      var $font_data;
      $2=$obj;
      var $3=$2;
      var $4=(($3+44)|0);
      var $5=HEAP32[(($4)>>2)];
      var $6=$5;
      $font_attr=$6;
      var $7=$font_attr;
      var $8=(($7+16)|0);
      var $9=HEAP32[(($8)>>2)];
      $def=$9;
      var $10=$def;
      var $11=(($10+208)|0);
      var $12=HEAP32[(($11)>>2)];
      var $13=$12;
      $def_attr=$13;
      $ret=0;
      var $14=$font_attr;
      var $15=(($14+40)|0);
      var $16=HEAP32[(($15)>>2)];
      var $17=(($16)|0)!=0;
      if ($17) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $19=$2;
      var $20=(($19+40)|0);
      var $21=HEAP32[(($20)>>2)];
      var $22=$font_attr;
      var $23=(($22+40)|0);
      var $24=HEAP32[(($23)>>2)];
      var $25=(($24+40)|0);
      HEAP32[(($25)>>2)]=$21;
      __label__ = 4; break;
    case 4: 
      var $27=$font_attr;
      var $28=(($27+44)|0);
      var $29=HEAP32[(($28)>>2)];
      var $30=(($29)|0)!=0;
      if ($30) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $32=$2;
      var $33=(($32+40)|0);
      var $34=HEAP32[(($33)>>2)];
      var $35=$font_attr;
      var $36=(($35+44)|0);
      var $37=HEAP32[(($36)>>2)];
      var $38=(($37+40)|0);
      HEAP32[(($38)>>2)]=$34;
      __label__ = 6; break;
    case 6: 
      var $40=$font_attr;
      var $41=(($40+16)|0);
      var $42=HEAP32[(($41)>>2)];
      var $43=(($42+196)|0);
      var $44=HEAP32[(($43)>>2)];
      var $45=(($44)|0)!=0;
      if ($45) { __label__ = 20; break; } else { __label__ = 7; break; }
    case 7: 
      var $47=$2;
      var $48=(($47+8)|0);
      var $49=HEAP32[(($48)>>2)];
      var $50=_HPDF_Dict_New($49);
      $descriptor=$50;
      var $51=$descriptor;
      var $52=(($51)|0)!=0;
      if ($52) { __label__ = 9; break; } else { __label__ = 8; break; }
    case 8: 
      var $54=$2;
      var $55=(($54+12)|0);
      var $56=HEAP32[(($55)>>2)];
      var $57=_HPDF_Error_GetCode($56);
      $1=$57;
      __label__ = 25; break;
    case 9: 
      var $59=$def_attr;
      var $60=(($59+340)|0);
      var $61=HEAP32[(($60)>>2)];
      var $62=(($61)|0)!=0;
      if ($62) { __label__ = 10; break; } else { __label__ = 17; break; }
    case 10: 
      var $64=$2;
      var $65=(($64+8)|0);
      var $66=HEAP32[(($65)>>2)];
      var $67=$font_attr;
      var $68=(($67+32)|0);
      var $69=HEAP32[(($68)>>2)];
      var $70=_HPDF_DictStream_New($66, $69);
      $font_data=$70;
      var $71=$font_data;
      var $72=(($71)|0)!=0;
      if ($72) { __label__ = 12; break; } else { __label__ = 11; break; }
    case 11: 
      var $74=$2;
      var $75=(($74+12)|0);
      var $76=HEAP32[(($75)>>2)];
      var $77=_HPDF_Error_GetCode($76);
      $1=$77;
      __label__ = 25; break;
    case 12: 
      var $79=$font_attr;
      var $80=(($79+16)|0);
      var $81=HEAP32[(($80)>>2)];
      var $82=$font_data;
      var $83=(($82+36)|0);
      var $84=HEAP32[(($83)>>2)];
      var $85=_HPDF_TTFontDef_SaveFontData($81, $84);
      var $86=(($85)|0)!=0;
      if ($86) { __label__ = 13; break; } else { __label__ = 14; break; }
    case 13: 
      var $88=$2;
      var $89=(($88+12)|0);
      var $90=HEAP32[(($89)>>2)];
      var $91=_HPDF_Error_GetCode($90);
      $1=$91;
      __label__ = 25; break;
    case 14: 
      var $93=$descriptor;
      var $94=$font_data;
      var $95=$94;
      var $96=_HPDF_Dict_Add($93, ((STRING_TABLE.__str591215)|0), $95);
      var $97=$ret;
      var $98=((($97)+($96))|0);
      $ret=$98;
      var $99=$font_data;
      var $100=$def_attr;
      var $101=(($100+336)|0);
      var $102=HEAP32[(($101)>>2)];
      var $103=_HPDF_Dict_AddNumber($99, ((STRING_TABLE.__str601216)|0), $102);
      var $104=$ret;
      var $105=((($104)+($103))|0);
      $ret=$105;
      var $106=$font_data;
      var $107=_HPDF_Dict_AddNumber($106, ((STRING_TABLE.__str611217)|0), 0);
      var $108=$ret;
      var $109=((($108)+($107))|0);
      $ret=$109;
      var $110=$font_data;
      var $111=_HPDF_Dict_AddNumber($110, ((STRING_TABLE.__str621218)|0), 0);
      var $112=$ret;
      var $113=((($112)+($111))|0);
      $ret=$113;
      var $114=$2;
      var $115=(($114+40)|0);
      var $116=HEAP32[(($115)>>2)];
      var $117=$font_data;
      var $118=(($117+40)|0);
      HEAP32[(($118)>>2)]=$116;
      var $119=$ret;
      var $120=(($119)|0)!=0;
      if ($120) { __label__ = 15; break; } else { __label__ = 16; break; }
    case 15: 
      var $122=$2;
      var $123=(($122+12)|0);
      var $124=HEAP32[(($123)>>2)];
      var $125=_HPDF_Error_GetCode($124);
      $1=$125;
      __label__ = 25; break;
    case 16: 
      __label__ = 17; break;
    case 17: 
      var $128=$font_attr;
      var $129=(($128+32)|0);
      var $130=HEAP32[(($129)>>2)];
      var $131=$descriptor;
      var $132=$131;
      var $133=_HPDF_Xref_Add($130, $132);
      var $134=$ret;
      var $135=((($134)+($133))|0);
      $ret=$135;
      var $136=$descriptor;
      var $137=_HPDF_Dict_AddName($136, ((STRING_TABLE.__str1156)|0), ((STRING_TABLE.__str631219)|0));
      var $138=$ret;
      var $139=((($138)+($137))|0);
      $ret=$139;
      var $140=$descriptor;
      var $141=$def;
      var $142=(($141+156)|0);
      var $143=HEAP16[(($142)>>1)];
      var $144=(($143 << 16) >> 16);
      var $145=_HPDF_Dict_AddNumber($140, ((STRING_TABLE.__str641220)|0), $144);
      var $146=$ret;
      var $147=((($146)+($145))|0);
      $ret=$147;
      var $148=$descriptor;
      var $149=$def;
      var $150=(($149+158)|0);
      var $151=HEAP16[(($150)>>1)];
      var $152=(($151 << 16) >> 16);
      var $153=_HPDF_Dict_AddNumber($148, ((STRING_TABLE.__str651221)|0), $152);
      var $154=$ret;
      var $155=((($154)+($153))|0);
      $ret=$155;
      var $156=$descriptor;
      var $157=$def;
      var $158=(($157+160)|0);
      var $159=HEAP32[(($158)>>2)];
      var $160=_HPDF_Dict_AddNumber($156, ((STRING_TABLE.__str661222)|0), $159);
      var $161=$ret;
      var $162=((($161)+($160))|0);
      $ret=$162;
      var $163=$2;
      var $164=(($163+8)|0);
      var $165=HEAP32[(($164)>>2)];
      var $166=$def;
      var $167=(($166+164)|0);
      var $168=(($167)|0);
      var $169=HEAPF32[(($168)>>2)];
      var $170=(($167+4)|0);
      var $171=HEAPF32[(($170)>>2)];
      var $172=(($167+8)|0);
      var $173=HEAPF32[(($172)>>2)];
      var $174=(($167+12)|0);
      var $175=HEAPF32[(($174)>>2)];
      var $176=_HPDF_Box_Array_New($165, $169, $171, $173, $175);
      $array=$176;
      var $177=$descriptor;
      var $178=$array;
      var $179=$178;
      var $180=_HPDF_Dict_Add($177, ((STRING_TABLE.__str671223)|0), $179);
      var $181=$ret;
      var $182=((($181)+($180))|0);
      $ret=$182;
      var $183=$descriptor;
      var $184=$def_attr;
      var $185=(($184)|0);
      var $186=(($185)|0);
      var $187=_HPDF_Dict_AddName($183, ((STRING_TABLE.__str681224)|0), $186);
      var $188=$ret;
      var $189=((($188)+($187))|0);
      $ret=$189;
      var $190=$descriptor;
      var $191=$def;
      var $192=(($191+180)|0);
      var $193=HEAP16[(($192)>>1)];
      var $194=(($193 << 16) >> 16);
      var $195=_HPDF_Dict_AddNumber($190, ((STRING_TABLE.__str691225)|0), $194);
      var $196=$ret;
      var $197=((($196)+($195))|0);
      $ret=$197;
      var $198=$descriptor;
      var $199=$def;
      var $200=(($199+182)|0);
      var $201=HEAPU16[(($200)>>1)];
      var $202=(($201)&65535);
      var $203=_HPDF_Dict_AddNumber($198, ((STRING_TABLE.__str701226)|0), $202);
      var $204=$ret;
      var $205=((($204)+($203))|0);
      $ret=$205;
      var $206=$descriptor;
      var $207=$def;
      var $208=(($207+192)|0);
      var $209=HEAPU16[(($208)>>1)];
      var $210=(($209)&65535);
      var $211=_HPDF_Dict_AddNumber($206, ((STRING_TABLE.__str711227)|0), $210);
      var $212=$ret;
      var $213=((($212)+($211))|0);
      $ret=$213;
      var $214=$ret;
      var $215=(($214)|0)!=0;
      if ($215) { __label__ = 18; break; } else { __label__ = 19; break; }
    case 18: 
      var $217=$2;
      var $218=(($217+12)|0);
      var $219=HEAP32[(($218)>>2)];
      var $220=_HPDF_Error_GetCode($219);
      $1=$220;
      __label__ = 25; break;
    case 19: 
      var $222=$descriptor;
      var $223=$font_attr;
      var $224=(($223+16)|0);
      var $225=HEAP32[(($224)>>2)];
      var $226=(($225+196)|0);
      HEAP32[(($226)>>2)]=$222;
      __label__ = 20; break;
    case 20: 
      var $228=$2;
      var $229=$def_attr;
      var $230=(($229)|0);
      var $231=(($230)|0);
      var $232=_HPDF_Dict_AddName($228, ((STRING_TABLE.__str21158)|0), $231);
      $ret=$232;
      var $233=(($232)|0)!=0;
      if ($233) { __label__ = 21; break; } else { __label__ = 22; break; }
    case 21: 
      var $235=$ret;
      $1=$235;
      __label__ = 25; break;
    case 22: 
      var $237=$font_attr;
      var $238=(($237+36)|0);
      var $239=HEAP32[(($238)>>2)];
      var $240=$def_attr;
      var $241=(($240)|0);
      var $242=(($241)|0);
      var $243=_HPDF_Dict_AddName($239, ((STRING_TABLE.__str21158)|0), $242);
      $ret=$243;
      var $244=(($243)|0)!=0;
      if ($244) { __label__ = 23; break; } else { __label__ = 24; break; }
    case 23: 
      var $246=$ret;
      $1=$246;
      __label__ = 25; break;
    case 24: 
      var $248=$font_attr;
      var $249=(($248+36)|0);
      var $250=HEAP32[(($249)>>2)];
      var $251=$font_attr;
      var $252=(($251+16)|0);
      var $253=HEAP32[(($252)>>2)];
      var $254=(($253+196)|0);
      var $255=HEAP32[(($254)>>2)];
      var $256=$255;
      var $257=_HPDF_Dict_Add($250, ((STRING_TABLE.__str631219)|0), $256);
      $1=$257;
      __label__ = 25; break;
    case 25: 
      var $259=$1;
      ;
      return $259;
    default: assert(0, "bad label: " + __label__);
  }
}
_CIDFontType2_BeforeWrite_Func["X"]=1;

function _HPDF_Base14FontDef_FindBuiltinData($font_name) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $i;
      $1=$font_name;
      $i=0;
      __label__ = 3; break;
    case 3: 
      var $3=$i;
      var $4=((_HPDF_BUILTIN_FONTS+($3)*(36))|0);
      var $5=(($4)|0);
      var $6=HEAP32[(($5)>>2)];
      var $7=(($6)|0)!=0;
      if ($7) { __label__ = 4; break; } else { __label__ = 7; break; }
    case 4: 
      var $9=$i;
      var $10=((_HPDF_BUILTIN_FONTS+($9)*(36))|0);
      var $11=(($10)|0);
      var $12=HEAP32[(($11)>>2)];
      var $13=$1;
      var $14=_HPDF_StrCmp($12, $13);
      var $15=(($14)|0)==0;
      if ($15) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      __label__ = 7; break;
    case 6: 
      var $18=$i;
      var $19=((($18)+(1))|0);
      $i=$19;
      __label__ = 3; break;
    case 7: 
      var $21=$i;
      var $22=((_HPDF_BUILTIN_FONTS+($21)*(36))|0);
      ;
      return $22;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Base14FontDef_New($mmgr, $font_name) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $fontdef;
      var $ret;
      var $data;
      var $eptr;
      var $attr;
      $2=$mmgr;
      $3=$font_name;
      var $4=$2;
      var $5=_HPDF_Type1FontDef_New($4);
      $fontdef=$5;
      var $6=$fontdef;
      var $7=(($6)|0)!=0;
      if ($7) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=0;
      __label__ = 11; break;
    case 4: 
      var $10=$3;
      var $11=_HPDF_Base14FontDef_FindBuiltinData($10);
      $data=$11;
      var $12=$data;
      var $13=(($12)|0);
      var $14=HEAP32[(($13)>>2)];
      var $15=(($14)|0)!=0;
      if ($15) { __label__ = 6; break; } else { __label__ = 5; break; }
    case 5: 
      var $17=$2;
      var $18=(($17)|0);
      var $19=HEAP32[(($18)>>2)];
      var $20=_HPDF_SetError($19, 4143, 0);
      var $21=$fontdef;
      _HPDF_FontDef_Free($21);
      $1=0;
      __label__ = 11; break;
    case 6: 
      var $23=$fontdef;
      var $24=(($23+4)|0);
      var $25=(($24)|0);
      var $26=(($25+127)|0);
      $eptr=$26;
      var $27=$fontdef;
      var $28=(($27+4)|0);
      var $29=(($28)|0);
      var $30=$data;
      var $31=(($30)|0);
      var $32=HEAP32[(($31)>>2)];
      var $33=$eptr;
      var $34=_HPDF_StrCpy($29, $32, $33);
      var $35=$fontdef;
      var $36=(($35+208)|0);
      var $37=HEAP32[(($36)>>2)];
      var $38=$37;
      $attr=$38;
      var $39=$attr;
      var $40=(($39+160)|0);
      HEAP32[(($40)>>2)]=1;
      var $41=$data;
      var $42=(($41+8)|0);
      var $43=HEAP32[(($42)>>2)];
      var $44=(($43)|0)!=0;
      if ($44) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $46=$attr;
      var $47=(($46+20)|0);
      var $48=(($47)|0);
      var $49=$attr;
      var $50=(($49+20)|0);
      var $51=(($50)|0);
      var $52=(($51+127)|0);
      var $53=_HPDF_StrCpy($48, ((STRING_TABLE.__str1233)|0), $52);
      __label__ = 8; break;
    case 8: 
      var $55=$fontdef;
      var $56=$data;
      var $57=(($56+4)|0);
      var $58=HEAP32[(($57)>>2)];
      var $59=_HPDF_Type1FontDef_SetWidths($55, $58);
      $ret=$59;
      var $60=$ret;
      var $61=(($60)|0)!=0;
      if ($61) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      var $63=$fontdef;
      _HPDF_FontDef_Free($63);
      $1=0;
      __label__ = 11; break;
    case 10: 
      var $65=$fontdef;
      var $66=(($65+164)|0);
      var $67=$data;
      var $68=(($67+20)|0);
      var $69=$66;
      var $70=$68;
      assert(16 % 1 === 0, 'memcpy given ' + 16 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP32[(($69)>>2)]=HEAP32[(($70)>>2)];HEAP32[((($69)+(4))>>2)]=HEAP32[((($70)+(4))>>2)];HEAP32[((($69)+(8))>>2)]=HEAP32[((($70)+(8))>>2)];HEAP32[((($69)+(12))>>2)]=HEAP32[((($70)+(12))>>2)];
      var $71=$data;
      var $72=(($71+12)|0);
      var $73=HEAP16[(($72)>>1)];
      var $74=$fontdef;
      var $75=(($74+156)|0);
      HEAP16[(($75)>>1)]=$73;
      var $76=$data;
      var $77=(($76+14)|0);
      var $78=HEAP16[(($77)>>1)];
      var $79=$fontdef;
      var $80=(($79+158)|0);
      HEAP16[(($80)>>1)]=$78;
      var $81=$data;
      var $82=(($81+16)|0);
      var $83=HEAP16[(($82)>>1)];
      var $84=$fontdef;
      var $85=(($84+192)|0);
      HEAP16[(($85)>>1)]=$83;
      var $86=$data;
      var $87=(($86+18)|0);
      var $88=HEAP16[(($87)>>1)];
      var $89=$fontdef;
      var $90=(($89+194)|0);
      HEAP16[(($90)>>1)]=$88;
      var $91=$fontdef;
      var $92=(($91+204)|0);
      HEAP32[(($92)>>2)]=1;
      var $93=$fontdef;
      $1=$93;
      __label__ = 11; break;
    case 11: 
      var $95=$1;
      ;
      return $95;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Base14FontDef_New["X"]=1;

function _HPDF_FontDef_Cleanup($fontdef) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      $1=$fontdef;
      var $2=$1;
      var $3=(($2)|0)!=0;
      if ($3) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      __label__ = 7; break;
    case 4: 
      var $6=$1;
      var $7=(($6+144)|0);
      var $8=$7;
      var $9=HEAP32[(($8)>>2)];
      var $10=(($9)|0)!=0;
      if ($10) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $12=$1;
      var $13=(($12+144)|0);
      var $14=$13;
      var $15=HEAP32[(($14)>>2)];
      var $16=$1;
      FUNCTION_TABLE[$15]($16);
      __label__ = 6; break;
    case 6: 
      var $18=$1;
      var $19=(($18+196)|0);
      HEAP32[(($19)>>2)]=0;
      __label__ = 7; break;
    case 7: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_FontDef_Free($fontdef) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      $1=$fontdef;
      var $2=$1;
      var $3=(($2)|0)!=0;
      if ($3) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      __label__ = 7; break;
    case 4: 
      var $6=$1;
      var $7=(($6+148)|0);
      var $8=$7;
      var $9=HEAP32[(($8)>>2)];
      var $10=(($9)|0)!=0;
      if ($10) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $12=$1;
      var $13=(($12+148)|0);
      var $14=$13;
      var $15=HEAP32[(($14)>>2)];
      var $16=$1;
      FUNCTION_TABLE[$15]($16);
      __label__ = 6; break;
    case 6: 
      var $18=$1;
      var $19=(($18+132)|0);
      var $20=HEAP32[(($19)>>2)];
      var $21=$1;
      var $22=$21;
      _HPDF_FreeMem($20, $22);
      __label__ = 7; break;
    case 7: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_CIDFontDef_FreeWidth($fontdef) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $attr;
      var $i;
      var $w;
      $1=$fontdef;
      var $2=$1;
      var $3=(($2+208)|0);
      var $4=HEAP32[(($3)>>2)];
      var $5=$4;
      $attr=$5;
      $i=0;
      __label__ = 3; break;
    case 3: 
      var $7=$i;
      var $8=$attr;
      var $9=(($8)|0);
      var $10=HEAP32[(($9)>>2)];
      var $11=(($10+16)|0);
      var $12=HEAPU32[(($11)>>2)];
      var $13=(($7)>>>0) < (($12)>>>0);
      if ($13) { __label__ = 4; break; } else { __label__ = 6; break; }
    case 4: 
      var $15=$attr;
      var $16=(($15)|0);
      var $17=HEAP32[(($16)>>2)];
      var $18=$i;
      var $19=_HPDF_List_ItemAt($17, $18);
      var $20=$19;
      $w=$20;
      var $21=$1;
      var $22=(($21+132)|0);
      var $23=HEAP32[(($22)>>2)];
      var $24=$w;
      var $25=$24;
      _HPDF_FreeMem($23, $25);
      __label__ = 5; break;
    case 5: 
      var $27=$i;
      var $28=((($27)+(1))|0);
      $i=$28;
      __label__ = 3; break;
    case 6: 
      var $30=$attr;
      var $31=(($30)|0);
      var $32=HEAP32[(($31)>>2)];
      _HPDF_List_Free($32);
      var $33=$attr;
      var $34=(($33)|0);
      HEAP32[(($34)>>2)]=0;
      var $35=$1;
      var $36=(($35+204)|0);
      HEAP32[(($36)>>2)]=0;
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_CIDFontDef_New($mmgr, $name, $init_fn) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $fontdef;
      var $fontdef_attr;
      $2=$mmgr;
      $3=$name;
      $4=$init_fn;
      var $5=$2;
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=0;
      __label__ = 11; break;
    case 4: 
      var $9=$2;
      var $10=_HPDF_GetMem($9, 212);
      var $11=$10;
      $fontdef=$11;
      var $12=$fontdef;
      var $13=(($12)|0)!=0;
      if ($13) { __label__ = 6; break; } else { __label__ = 5; break; }
    case 5: 
      $1=0;
      __label__ = 11; break;
    case 6: 
      var $16=$fontdef;
      var $17=$16;
      var $18=_HPDF_MemSet($17, 0, 212);
      var $19=$fontdef;
      var $20=(($19)|0);
      HEAP32[(($20)>>2)]=1179602516;
      var $21=$fontdef;
      var $22=(($21+4)|0);
      var $23=(($22)|0);
      var $24=$3;
      var $25=$fontdef;
      var $26=(($25+4)|0);
      var $27=(($26)|0);
      var $28=(($27+127)|0);
      var $29=_HPDF_StrCpy($23, $24, $28);
      var $30=$2;
      var $31=$fontdef;
      var $32=(($31+132)|0);
      HEAP32[(($32)>>2)]=$30;
      var $33=$2;
      var $34=(($33)|0);
      var $35=HEAP32[(($34)>>2)];
      var $36=$fontdef;
      var $37=(($36+136)|0);
      HEAP32[(($37)>>2)]=$35;
      var $38=$fontdef;
      var $39=(($38+140)|0);
      HEAP32[(($39)>>2)]=3;
      var $40=$fontdef;
      var $41=(($40+148)|0);
      var $42=$41;
      HEAP32[(($42)>>2)]=98;
      var $43=$4;
      var $44=$fontdef;
      var $45=(($44+152)|0);
      HEAP32[(($45)>>2)]=$43;
      var $46=$fontdef;
      var $47=(($46+204)|0);
      HEAP32[(($47)>>2)]=0;
      var $48=$2;
      var $49=_HPDF_GetMem($48, 12);
      var $50=$49;
      $fontdef_attr=$50;
      var $51=$fontdef_attr;
      var $52=(($51)|0)!=0;
      if ($52) { __label__ = 8; break; } else { __label__ = 7; break; }
    case 7: 
      var $54=$fontdef;
      var $55=(($54+132)|0);
      var $56=HEAP32[(($55)>>2)];
      var $57=$fontdef;
      var $58=$57;
      _HPDF_FreeMem($56, $58);
      $1=0;
      __label__ = 11; break;
    case 8: 
      var $60=$fontdef_attr;
      var $61=$60;
      var $62=$fontdef;
      var $63=(($62+208)|0);
      HEAP32[(($63)>>2)]=$61;
      var $64=$fontdef_attr;
      var $65=$64;
      var $66=_HPDF_MemSet($65, 0, 12);
      var $67=$2;
      var $68=_HPDF_List_New($67, 128);
      var $69=$fontdef_attr;
      var $70=(($69)|0);
      HEAP32[(($70)>>2)]=$68;
      var $71=$fontdef_attr;
      var $72=(($71)|0);
      var $73=HEAP32[(($72)>>2)];
      var $74=(($73)|0)!=0;
      if ($74) { __label__ = 10; break; } else { __label__ = 9; break; }
    case 9: 
      var $76=$fontdef;
      var $77=(($76+132)|0);
      var $78=HEAP32[(($77)>>2)];
      var $79=$fontdef;
      var $80=$79;
      _HPDF_FreeMem($78, $80);
      var $81=$fontdef;
      var $82=(($81+132)|0);
      var $83=HEAP32[(($82)>>2)];
      var $84=$fontdef_attr;
      var $85=$84;
      _HPDF_FreeMem($83, $85);
      $1=0;
      __label__ = 11; break;
    case 10: 
      var $87=$fontdef;
      var $88=(($87+188)|0);
      HEAP16[(($88)>>1)]=500;
      var $89=$fontdef_attr;
      var $90=(($89+4)|0);
      HEAP16[(($90)>>1)]=1000;
      var $91=$fontdef_attr;
      var $92=(($91+6)|0);
      var $93=(($92)|0);
      HEAP16[(($93)>>1)]=880;
      var $94=$fontdef_attr;
      var $95=(($94+6)|0);
      var $96=(($95+2)|0);
      HEAP16[(($96)>>1)]=-1000;
      var $97=$fontdef;
      $1=$97;
      __label__ = 11; break;
    case 11: 
      var $99=$1;
      ;
      return $99;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_CIDFontDef_New["X"]=1;

function _HPDF_CIDFontDef_FreeFunc($fontdef) {
  ;
  var __label__;

  var $1;
  var $attr;
  $1=$fontdef;
  var $2=$1;
  var $3=(($2+208)|0);
  var $4=HEAP32[(($3)>>2)];
  var $5=$4;
  $attr=$5;
  var $6=$1;
  _HPDF_CIDFontDef_FreeWidth($6);
  var $7=$1;
  var $8=(($7+132)|0);
  var $9=HEAP32[(($8)>>2)];
  var $10=$attr;
  var $11=$10;
  _HPDF_FreeMem($9, $11);
  ;
  return;
}


function _HPDF_CIDFontDef_GetCIDWidth($fontdef, $cid) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $attr;
      var $i;
      var $w;
      $2=$fontdef;
      $3=$cid;
      var $4=$2;
      var $5=(($4+208)|0);
      var $6=HEAP32[(($5)>>2)];
      var $7=$6;
      $attr=$7;
      $i=0;
      __label__ = 3; break;
    case 3: 
      var $9=$i;
      var $10=$attr;
      var $11=(($10)|0);
      var $12=HEAP32[(($11)>>2)];
      var $13=(($12+16)|0);
      var $14=HEAPU32[(($13)>>2)];
      var $15=(($9)>>>0) < (($14)>>>0);
      if ($15) { __label__ = 4; break; } else { __label__ = 8; break; }
    case 4: 
      var $17=$attr;
      var $18=(($17)|0);
      var $19=HEAP32[(($18)>>2)];
      var $20=$i;
      var $21=_HPDF_List_ItemAt($19, $20);
      var $22=$21;
      $w=$22;
      var $23=$w;
      var $24=(($23)|0);
      var $25=HEAPU16[(($24)>>1)];
      var $26=(($25)&65535);
      var $27=$3;
      var $28=(($27)&65535);
      var $29=(($26)|0)==(($28)|0);
      if ($29) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $31=$w;
      var $32=(($31+2)|0);
      var $33=HEAP16[(($32)>>1)];
      $1=$33;
      __label__ = 9; break;
    case 6: 
      __label__ = 7; break;
    case 7: 
      var $36=$i;
      var $37=((($36)+(1))|0);
      $i=$37;
      __label__ = 3; break;
    case 8: 
      var $39=$attr;
      var $40=(($39+4)|0);
      var $41=HEAP16[(($40)>>1)];
      $1=$41;
      __label__ = 9; break;
    case 9: 
      var $43=$1;
      ;
      return $43;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_CIDFontDef_GetCIDWidth["X"]=1;

function _HPDF_CIDFontDef_AddWidth($fontdef, $widths) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $attr;
      var $w;
      var $ret;
      $2=$fontdef;
      $3=$widths;
      var $4=$2;
      var $5=(($4+208)|0);
      var $6=HEAP32[(($5)>>2)];
      var $7=$6;
      $attr=$7;
      __label__ = 3; break;
    case 3: 
      var $9=$3;
      var $10=(($9)|0);
      var $11=HEAPU16[(($10)>>1)];
      var $12=(($11)&65535);
      var $13=(($12)|0)!=65535;
      if ($13) { __label__ = 4; break; } else { __label__ = 9; break; }
    case 4: 
      var $15=$2;
      var $16=(($15+132)|0);
      var $17=HEAP32[(($16)>>2)];
      var $18=_HPDF_GetMem($17, 4);
      var $19=$18;
      $w=$19;
      var $20=$w;
      var $21=(($20)|0)!=0;
      if ($21) { __label__ = 6; break; } else { __label__ = 5; break; }
    case 5: 
      var $23=$2;
      var $24=(($23+136)|0);
      var $25=HEAP32[(($24)>>2)];
      var $26=(($25)|0);
      var $27=HEAP32[(($26)>>2)];
      $1=$27;
      __label__ = 10; break;
    case 6: 
      var $29=$3;
      var $30=(($29)|0);
      var $31=HEAP16[(($30)>>1)];
      var $32=$w;
      var $33=(($32)|0);
      HEAP16[(($33)>>1)]=$31;
      var $34=$3;
      var $35=(($34+2)|0);
      var $36=HEAP16[(($35)>>1)];
      var $37=$w;
      var $38=(($37+2)|0);
      HEAP16[(($38)>>1)]=$36;
      var $39=$attr;
      var $40=(($39)|0);
      var $41=HEAP32[(($40)>>2)];
      var $42=$w;
      var $43=$42;
      var $44=_HPDF_List_Add($41, $43);
      $ret=$44;
      var $45=(($44)|0)!=0;
      if ($45) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $47=$2;
      var $48=(($47+132)|0);
      var $49=HEAP32[(($48)>>2)];
      var $50=$w;
      var $51=$50;
      _HPDF_FreeMem($49, $51);
      var $52=$ret;
      $1=$52;
      __label__ = 10; break;
    case 8: 
      var $54=$3;
      var $55=(($54+4)|0);
      $3=$55;
      __label__ = 3; break;
    case 9: 
      $1=0;
      __label__ = 10; break;
    case 10: 
      var $58=$1;
      ;
      return $58;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_CIDFontDef_AddWidth["X"]=1;

function _HPDF_CIDFontDef_ChangeStyle($fontdef, $bold, $italic) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      $2=$fontdef;
      $3=$bold;
      $4=$italic;
      var $5=$2;
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $8=$2;
      var $9=(($8+208)|0);
      var $10=HEAP32[(($9)>>2)];
      var $11=(($10)|0)!=0;
      if ($11) { __label__ = 5; break; } else { __label__ = 4; break; }
    case 4: 
      $1=4141;
      __label__ = 10; break;
    case 5: 
      var $14=$3;
      var $15=(($14)|0)!=0;
      if ($15) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      var $17=$2;
      var $18=(($17+182)|0);
      var $19=HEAPU16[(($18)>>1)];
      var $20=(($19)&65535);
      var $21=((($20<<1))|0);
      var $22=(($21) & 65535);
      HEAP16[(($18)>>1)]=$22;
      var $23=$2;
      var $24=(($23+160)|0);
      var $25=HEAP32[(($24)>>2)];
      var $26=$25 | 262144;
      HEAP32[(($24)>>2)]=$26;
      __label__ = 7; break;
    case 7: 
      var $28=$4;
      var $29=(($28)|0)!=0;
      if ($29) { __label__ = 8; break; } else { __label__ = 9; break; }
    case 8: 
      var $31=$2;
      var $32=(($31+180)|0);
      var $33=HEAP16[(($32)>>1)];
      var $34=(($33 << 16) >> 16);
      var $35=((($34)-(11))|0);
      var $36=(($35) & 65535);
      HEAP16[(($32)>>1)]=$36;
      var $37=$2;
      var $38=(($37+160)|0);
      var $39=HEAP32[(($38)>>2)];
      var $40=$39 | 64;
      HEAP32[(($38)>>2)]=$40;
      __label__ = 9; break;
    case 9: 
      $1=0;
      __label__ = 10; break;
    case 10: 
      var $43=$1;
      ;
      return $43;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_CIDFontDef_ChangeStyle["X"]=1;

function _HPDF_UseCNSFonts($pdf) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $fontdef;
      var $ret;
      $2=$pdf;
      var $3=$2;
      var $4=_HPDF_HasDoc($3);
      var $5=(($4)|0)!=0;
      if ($5) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=4133;
      __label__ = 21; break;
    case 4: 
      var $8=$2;
      var $9=(($8+8)|0);
      var $10=HEAP32[(($9)>>2)];
      var $11=_HPDF_CIDFontDef_New($10, ((STRING_TABLE.__str1256)|0), 100);
      $fontdef=$11;
      var $12=$2;
      var $13=$fontdef;
      var $14=_HPDF_Doc_RegisterFontDef($12, $13);
      $ret=$14;
      var $15=(($14)|0)!=0;
      if ($15) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $17=$ret;
      $1=$17;
      __label__ = 21; break;
    case 6: 
      var $19=$2;
      var $20=(($19+8)|0);
      var $21=HEAP32[(($20)>>2)];
      var $22=_HPDF_CIDFontDef_New($21, ((STRING_TABLE.__str11257)|0), 102);
      $fontdef=$22;
      var $23=$2;
      var $24=$fontdef;
      var $25=_HPDF_Doc_RegisterFontDef($23, $24);
      $ret=$25;
      var $26=(($25)|0)!=0;
      if ($26) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $28=$ret;
      $1=$28;
      __label__ = 21; break;
    case 8: 
      var $30=$2;
      var $31=(($30+8)|0);
      var $32=HEAP32[(($31)>>2)];
      var $33=_HPDF_CIDFontDef_New($32, ((STRING_TABLE.__str21258)|0), 104);
      $fontdef=$33;
      var $34=$2;
      var $35=$fontdef;
      var $36=_HPDF_Doc_RegisterFontDef($34, $35);
      $ret=$36;
      var $37=(($36)|0)!=0;
      if ($37) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      var $39=$ret;
      $1=$39;
      __label__ = 21; break;
    case 10: 
      var $41=$2;
      var $42=(($41+8)|0);
      var $43=HEAP32[(($42)>>2)];
      var $44=_HPDF_CIDFontDef_New($43, ((STRING_TABLE.__str31259)|0), 106);
      $fontdef=$44;
      var $45=$2;
      var $46=$fontdef;
      var $47=_HPDF_Doc_RegisterFontDef($45, $46);
      $ret=$47;
      var $48=(($47)|0)!=0;
      if ($48) { __label__ = 11; break; } else { __label__ = 12; break; }
    case 11: 
      var $50=$ret;
      $1=$50;
      __label__ = 21; break;
    case 12: 
      var $52=$2;
      var $53=(($52+8)|0);
      var $54=HEAP32[(($53)>>2)];
      var $55=_HPDF_CIDFontDef_New($54, ((STRING_TABLE.__str41260)|0), 108);
      $fontdef=$55;
      var $56=$2;
      var $57=$fontdef;
      var $58=_HPDF_Doc_RegisterFontDef($56, $57);
      $ret=$58;
      var $59=(($58)|0)!=0;
      if ($59) { __label__ = 13; break; } else { __label__ = 14; break; }
    case 13: 
      var $61=$ret;
      $1=$61;
      __label__ = 21; break;
    case 14: 
      var $63=$2;
      var $64=(($63+8)|0);
      var $65=HEAP32[(($64)>>2)];
      var $66=_HPDF_CIDFontDef_New($65, ((STRING_TABLE.__str51261)|0), 110);
      $fontdef=$66;
      var $67=$2;
      var $68=$fontdef;
      var $69=_HPDF_Doc_RegisterFontDef($67, $68);
      $ret=$69;
      var $70=(($69)|0)!=0;
      if ($70) { __label__ = 15; break; } else { __label__ = 16; break; }
    case 15: 
      var $72=$ret;
      $1=$72;
      __label__ = 21; break;
    case 16: 
      var $74=$2;
      var $75=(($74+8)|0);
      var $76=HEAP32[(($75)>>2)];
      var $77=_HPDF_CIDFontDef_New($76, ((STRING_TABLE.__str61262)|0), 112);
      $fontdef=$77;
      var $78=$2;
      var $79=$fontdef;
      var $80=_HPDF_Doc_RegisterFontDef($78, $79);
      $ret=$80;
      var $81=(($80)|0)!=0;
      if ($81) { __label__ = 17; break; } else { __label__ = 18; break; }
    case 17: 
      var $83=$ret;
      $1=$83;
      __label__ = 21; break;
    case 18: 
      var $85=$2;
      var $86=(($85+8)|0);
      var $87=HEAP32[(($86)>>2)];
      var $88=_HPDF_CIDFontDef_New($87, ((STRING_TABLE.__str71263)|0), 114);
      $fontdef=$88;
      var $89=$2;
      var $90=$fontdef;
      var $91=_HPDF_Doc_RegisterFontDef($89, $90);
      $ret=$91;
      var $92=(($91)|0)!=0;
      if ($92) { __label__ = 19; break; } else { __label__ = 20; break; }
    case 19: 
      var $94=$ret;
      $1=$94;
      __label__ = 21; break;
    case 20: 
      $1=0;
      __label__ = 21; break;
    case 21: 
      var $97=$1;
      ;
      return $97;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_UseCNSFonts["X"]=1;

function _SimSun_Init($fontdef) {
  var __stackBase__  = STACKTOP; STACKTOP += 16; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $ret;
      var $3=__stackBase__;
      $2=$fontdef;
      var $4=$2;
      var $5=(($4+156)|0);
      HEAP16[(($5)>>1)]=859;
      var $6=$2;
      var $7=(($6+158)|0);
      HEAP16[(($7)>>1)]=-140;
      var $8=$2;
      var $9=(($8+194)|0);
      HEAP16[(($9)>>1)]=683;
      var $10=$2;
      var $11=(($10+164)|0);
      _HPDF_ToBox($3, 0, -140, 996, 855);
      var $12=$11;
      var $13=$3;
      assert(16 % 1 === 0, 'memcpy given ' + 16 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP32[(($12)>>2)]=HEAP32[(($13)>>2)];HEAP32[((($12)+(4))>>2)]=HEAP32[((($13)+(4))>>2)];HEAP32[((($12)+(8))>>2)]=HEAP32[((($13)+(8))>>2)];HEAP32[((($12)+(12))>>2)]=HEAP32[((($13)+(12))>>2)];
      var $14=$2;
      var $15=(($14+160)|0);
      HEAP32[(($15)>>2)]=7;
      var $16=$2;
      var $17=(($16+180)|0);
      HEAP16[(($17)>>1)]=0;
      var $18=$2;
      var $19=(($18+182)|0);
      HEAP16[(($19)>>1)]=78;
      var $20=$2;
      var $21=_HPDF_CIDFontDef_AddWidth($20, ((_SIMSUN_W_ARRAY)|0));
      $ret=$21;
      var $22=(($21)|0)!=0;
      if ($22) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $24=$ret;
      $1=$24;
      __label__ = 5; break;
    case 4: 
      var $26=$2;
      var $27=(($26+140)|0);
      HEAP32[(($27)>>2)]=2;
      var $28=$2;
      var $29=(($28+204)|0);
      HEAP32[(($29)>>2)]=1;
      $1=0;
      __label__ = 5; break;
    case 5: 
      var $31=$1;
      STACKTOP = __stackBase__;
      return $31;
    default: assert(0, "bad label: " + __label__);
  }
}


function _SimSun_Bold_Init($fontdef) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $ret;
      $2=$fontdef;
      var $3=$2;
      var $4=_SimSun_Init($3);
      $ret=$4;
      var $5=$ret;
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $8=$ret;
      $1=$8;
      __label__ = 5; break;
    case 4: 
      var $10=$2;
      var $11=_HPDF_CIDFontDef_ChangeStyle($10, 1, 0);
      $1=$11;
      __label__ = 5; break;
    case 5: 
      var $13=$1;
      ;
      return $13;
    default: assert(0, "bad label: " + __label__);
  }
}


function _SimSun_Italic_Init($fontdef) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $ret;
      $2=$fontdef;
      var $3=$2;
      var $4=_SimSun_Init($3);
      $ret=$4;
      var $5=$ret;
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $8=$ret;
      $1=$8;
      __label__ = 5; break;
    case 4: 
      var $10=$2;
      var $11=_HPDF_CIDFontDef_ChangeStyle($10, 0, 1);
      $1=$11;
      __label__ = 5; break;
    case 5: 
      var $13=$1;
      ;
      return $13;
    default: assert(0, "bad label: " + __label__);
  }
}


function _SimSun_BoldItalic_Init($fontdef) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $ret;
      $2=$fontdef;
      var $3=$2;
      var $4=_SimSun_Init($3);
      $ret=$4;
      var $5=$ret;
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $8=$ret;
      $1=$8;
      __label__ = 5; break;
    case 4: 
      var $10=$2;
      var $11=_HPDF_CIDFontDef_ChangeStyle($10, 1, 1);
      $1=$11;
      __label__ = 5; break;
    case 5: 
      var $13=$1;
      ;
      return $13;
    default: assert(0, "bad label: " + __label__);
  }
}


function _SimHei_Init($fontdef) {
  var __stackBase__  = STACKTOP; STACKTOP += 16; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $ret;
      var $3=__stackBase__;
      $2=$fontdef;
      var $4=$2;
      var $5=(($4+156)|0);
      HEAP16[(($5)>>1)]=859;
      var $6=$2;
      var $7=(($6+158)|0);
      HEAP16[(($7)>>1)]=-140;
      var $8=$2;
      var $9=(($8+194)|0);
      HEAP16[(($9)>>1)]=769;
      var $10=$2;
      var $11=(($10+164)|0);
      _HPDF_ToBox($3, 0, -140, 996, 855);
      var $12=$11;
      var $13=$3;
      assert(16 % 1 === 0, 'memcpy given ' + 16 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP32[(($12)>>2)]=HEAP32[(($13)>>2)];HEAP32[((($12)+(4))>>2)]=HEAP32[((($13)+(4))>>2)];HEAP32[((($12)+(8))>>2)]=HEAP32[((($13)+(8))>>2)];HEAP32[((($12)+(12))>>2)]=HEAP32[((($13)+(12))>>2)];
      var $14=$2;
      var $15=(($14+160)|0);
      HEAP32[(($15)>>2)]=5;
      var $16=$2;
      var $17=(($16+180)|0);
      HEAP16[(($17)>>1)]=0;
      var $18=$2;
      var $19=(($18+182)|0);
      HEAP16[(($19)>>1)]=78;
      var $20=$2;
      var $21=_HPDF_CIDFontDef_AddWidth($20, ((_SIMHEI_W_ARRAY)|0));
      $ret=$21;
      var $22=(($21)|0)!=0;
      if ($22) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $24=$ret;
      $1=$24;
      __label__ = 5; break;
    case 4: 
      var $26=$2;
      var $27=(($26+140)|0);
      HEAP32[(($27)>>2)]=2;
      var $28=$2;
      var $29=(($28+204)|0);
      HEAP32[(($29)>>2)]=1;
      $1=0;
      __label__ = 5; break;
    case 5: 
      var $31=$1;
      STACKTOP = __stackBase__;
      return $31;
    default: assert(0, "bad label: " + __label__);
  }
}


function _SimHei_Bold_Init($fontdef) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $ret;
      $2=$fontdef;
      var $3=$2;
      var $4=_SimHei_Init($3);
      $ret=$4;
      var $5=$ret;
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $8=$ret;
      $1=$8;
      __label__ = 5; break;
    case 4: 
      var $10=$2;
      var $11=_HPDF_CIDFontDef_ChangeStyle($10, 1, 0);
      $1=$11;
      __label__ = 5; break;
    case 5: 
      var $13=$1;
      ;
      return $13;
    default: assert(0, "bad label: " + __label__);
  }
}


function _SimHei_Italic_Init($fontdef) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $ret;
      $2=$fontdef;
      var $3=$2;
      var $4=_SimHei_Init($3);
      $ret=$4;
      var $5=$ret;
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $8=$ret;
      $1=$8;
      __label__ = 5; break;
    case 4: 
      var $10=$2;
      var $11=_HPDF_CIDFontDef_ChangeStyle($10, 0, 1);
      $1=$11;
      __label__ = 5; break;
    case 5: 
      var $13=$1;
      ;
      return $13;
    default: assert(0, "bad label: " + __label__);
  }
}


function _SimHei_BoldItalic_Init($fontdef) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $ret;
      $2=$fontdef;
      var $3=$2;
      var $4=_SimHei_Init($3);
      $ret=$4;
      var $5=$ret;
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $8=$ret;
      $1=$8;
      __label__ = 5; break;
    case 4: 
      var $10=$2;
      var $11=_HPDF_CIDFontDef_ChangeStyle($10, 1, 1);
      $1=$11;
      __label__ = 5; break;
    case 5: 
      var $13=$1;
      ;
      return $13;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_UseCNTFonts($pdf) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $fontdef;
      var $ret;
      $2=$pdf;
      var $3=$2;
      var $4=_HPDF_HasDoc($3);
      var $5=(($4)|0)!=0;
      if ($5) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=4133;
      __label__ = 13; break;
    case 4: 
      var $8=$2;
      var $9=(($8+8)|0);
      var $10=HEAP32[(($9)>>2)];
      var $11=_HPDF_CIDFontDef_New($10, ((STRING_TABLE.__str1265)|0), 116);
      $fontdef=$11;
      var $12=$2;
      var $13=$fontdef;
      var $14=_HPDF_Doc_RegisterFontDef($12, $13);
      $ret=$14;
      var $15=(($14)|0)!=0;
      if ($15) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $17=$ret;
      $1=$17;
      __label__ = 13; break;
    case 6: 
      var $19=$2;
      var $20=(($19+8)|0);
      var $21=HEAP32[(($20)>>2)];
      var $22=_HPDF_CIDFontDef_New($21, ((STRING_TABLE.__str11266)|0), 118);
      $fontdef=$22;
      var $23=$2;
      var $24=$fontdef;
      var $25=_HPDF_Doc_RegisterFontDef($23, $24);
      $ret=$25;
      var $26=(($25)|0)!=0;
      if ($26) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $28=$ret;
      $1=$28;
      __label__ = 13; break;
    case 8: 
      var $30=$2;
      var $31=(($30+8)|0);
      var $32=HEAP32[(($31)>>2)];
      var $33=_HPDF_CIDFontDef_New($32, ((STRING_TABLE.__str21267)|0), 120);
      $fontdef=$33;
      var $34=$2;
      var $35=$fontdef;
      var $36=_HPDF_Doc_RegisterFontDef($34, $35);
      $ret=$36;
      var $37=(($36)|0)!=0;
      if ($37) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      var $39=$ret;
      $1=$39;
      __label__ = 13; break;
    case 10: 
      var $41=$2;
      var $42=(($41+8)|0);
      var $43=HEAP32[(($42)>>2)];
      var $44=_HPDF_CIDFontDef_New($43, ((STRING_TABLE.__str31268)|0), 122);
      $fontdef=$44;
      var $45=$2;
      var $46=$fontdef;
      var $47=_HPDF_Doc_RegisterFontDef($45, $46);
      $ret=$47;
      var $48=(($47)|0)!=0;
      if ($48) { __label__ = 11; break; } else { __label__ = 12; break; }
    case 11: 
      var $50=$ret;
      $1=$50;
      __label__ = 13; break;
    case 12: 
      $1=0;
      __label__ = 13; break;
    case 13: 
      var $53=$1;
      ;
      return $53;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_UseCNTFonts["X"]=1;

function _MingLiU_Init($fontdef) {
  var __stackBase__  = STACKTOP; STACKTOP += 16; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $ret;
      var $3=__stackBase__;
      $2=$fontdef;
      var $4=$2;
      var $5=(($4+156)|0);
      HEAP16[(($5)>>1)]=800;
      var $6=$2;
      var $7=(($6+158)|0);
      HEAP16[(($7)>>1)]=-199;
      var $8=$2;
      var $9=(($8+194)|0);
      HEAP16[(($9)>>1)]=769;
      var $10=$2;
      var $11=(($10+164)|0);
      _HPDF_ToBox($3, 0, -199, 1000, 800);
      var $12=$11;
      var $13=$3;
      assert(16 % 1 === 0, 'memcpy given ' + 16 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP32[(($12)>>2)]=HEAP32[(($13)>>2)];HEAP32[((($12)+(4))>>2)]=HEAP32[((($13)+(4))>>2)];HEAP32[((($12)+(8))>>2)]=HEAP32[((($13)+(8))>>2)];HEAP32[((($12)+(12))>>2)]=HEAP32[((($13)+(12))>>2)];
      var $14=$2;
      var $15=(($14+160)|0);
      HEAP32[(($15)>>2)]=7;
      var $16=$2;
      var $17=(($16+180)|0);
      HEAP16[(($17)>>1)]=0;
      var $18=$2;
      var $19=(($18+182)|0);
      HEAP16[(($19)>>1)]=78;
      var $20=$2;
      var $21=_HPDF_CIDFontDef_AddWidth($20, ((_MING_LIU_W_ARRAY)|0));
      $ret=$21;
      var $22=(($21)|0)!=0;
      if ($22) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $24=$ret;
      $1=$24;
      __label__ = 5; break;
    case 4: 
      var $26=$2;
      var $27=(($26+140)|0);
      HEAP32[(($27)>>2)]=2;
      var $28=$2;
      var $29=(($28+204)|0);
      HEAP32[(($29)>>2)]=1;
      $1=0;
      __label__ = 5; break;
    case 5: 
      var $31=$1;
      STACKTOP = __stackBase__;
      return $31;
    default: assert(0, "bad label: " + __label__);
  }
}


function _MingLiU_Bold_Init($fontdef) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $ret;
      $2=$fontdef;
      var $3=$2;
      var $4=_MingLiU_Init($3);
      $ret=$4;
      var $5=$ret;
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $8=$ret;
      $1=$8;
      __label__ = 5; break;
    case 4: 
      var $10=$2;
      var $11=_HPDF_CIDFontDef_ChangeStyle($10, 1, 0);
      $1=$11;
      __label__ = 5; break;
    case 5: 
      var $13=$1;
      ;
      return $13;
    default: assert(0, "bad label: " + __label__);
  }
}


function _MingLiU_Italic_Init($fontdef) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $ret;
      $2=$fontdef;
      var $3=$2;
      var $4=_MingLiU_Init($3);
      $ret=$4;
      var $5=$ret;
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $8=$ret;
      $1=$8;
      __label__ = 5; break;
    case 4: 
      var $10=$2;
      var $11=_HPDF_CIDFontDef_ChangeStyle($10, 0, 1);
      $1=$11;
      __label__ = 5; break;
    case 5: 
      var $13=$1;
      ;
      return $13;
    default: assert(0, "bad label: " + __label__);
  }
}


function _MingLiU_BoldItalic_Init($fontdef) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $ret;
      $2=$fontdef;
      var $3=$2;
      var $4=_MingLiU_Init($3);
      $ret=$4;
      var $5=$ret;
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $8=$ret;
      $1=$8;
      __label__ = 5; break;
    case 4: 
      var $10=$2;
      var $11=_HPDF_CIDFontDef_ChangeStyle($10, 1, 1);
      $1=$11;
      __label__ = 5; break;
    case 5: 
      var $13=$1;
      ;
      return $13;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_UseJPFonts($pdf) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $fontdef;
      var $ret;
      $2=$pdf;
      var $3=$2;
      var $4=_HPDF_Doc_Validate($3);
      var $5=(($4)|0)!=0;
      if ($5) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=4133;
      __label__ = 37; break;
    case 4: 
      var $8=$2;
      var $9=(($8+8)|0);
      var $10=HEAP32[(($9)>>2)];
      var $11=_HPDF_CIDFontDef_New($10, ((STRING_TABLE.__str1270)|0), 124);
      $fontdef=$11;
      var $12=$2;
      var $13=$fontdef;
      var $14=_HPDF_Doc_RegisterFontDef($12, $13);
      $ret=$14;
      var $15=(($14)|0)!=0;
      if ($15) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $17=$ret;
      $1=$17;
      __label__ = 37; break;
    case 6: 
      var $19=$2;
      var $20=(($19+8)|0);
      var $21=HEAP32[(($20)>>2)];
      var $22=_HPDF_CIDFontDef_New($21, ((STRING_TABLE.__str11271)|0), 126);
      $fontdef=$22;
      var $23=$2;
      var $24=$fontdef;
      var $25=_HPDF_Doc_RegisterFontDef($23, $24);
      $ret=$25;
      var $26=(($25)|0)!=0;
      if ($26) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $28=$ret;
      $1=$28;
      __label__ = 37; break;
    case 8: 
      var $30=$2;
      var $31=(($30+8)|0);
      var $32=HEAP32[(($31)>>2)];
      var $33=_HPDF_CIDFontDef_New($32, ((STRING_TABLE.__str21272)|0), 128);
      $fontdef=$33;
      var $34=$2;
      var $35=$fontdef;
      var $36=_HPDF_Doc_RegisterFontDef($34, $35);
      $ret=$36;
      var $37=(($36)|0)!=0;
      if ($37) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      var $39=$ret;
      $1=$39;
      __label__ = 37; break;
    case 10: 
      var $41=$2;
      var $42=(($41+8)|0);
      var $43=HEAP32[(($42)>>2)];
      var $44=_HPDF_CIDFontDef_New($43, ((STRING_TABLE.__str31273)|0), 130);
      $fontdef=$44;
      var $45=$2;
      var $46=$fontdef;
      var $47=_HPDF_Doc_RegisterFontDef($45, $46);
      $ret=$47;
      var $48=(($47)|0)!=0;
      if ($48) { __label__ = 11; break; } else { __label__ = 12; break; }
    case 11: 
      var $50=$ret;
      $1=$50;
      __label__ = 37; break;
    case 12: 
      var $52=$2;
      var $53=(($52+8)|0);
      var $54=HEAP32[(($53)>>2)];
      var $55=_HPDF_CIDFontDef_New($54, ((STRING_TABLE.__str41274)|0), 132);
      $fontdef=$55;
      var $56=$2;
      var $57=$fontdef;
      var $58=_HPDF_Doc_RegisterFontDef($56, $57);
      $ret=$58;
      var $59=(($58)|0)!=0;
      if ($59) { __label__ = 13; break; } else { __label__ = 14; break; }
    case 13: 
      var $61=$ret;
      $1=$61;
      __label__ = 37; break;
    case 14: 
      var $63=$2;
      var $64=(($63+8)|0);
      var $65=HEAP32[(($64)>>2)];
      var $66=_HPDF_CIDFontDef_New($65, ((STRING_TABLE.__str51275)|0), 134);
      $fontdef=$66;
      var $67=$2;
      var $68=$fontdef;
      var $69=_HPDF_Doc_RegisterFontDef($67, $68);
      $ret=$69;
      var $70=(($69)|0)!=0;
      if ($70) { __label__ = 15; break; } else { __label__ = 16; break; }
    case 15: 
      var $72=$ret;
      $1=$72;
      __label__ = 37; break;
    case 16: 
      var $74=$2;
      var $75=(($74+8)|0);
      var $76=HEAP32[(($75)>>2)];
      var $77=_HPDF_CIDFontDef_New($76, ((STRING_TABLE.__str61276)|0), 136);
      $fontdef=$77;
      var $78=$2;
      var $79=$fontdef;
      var $80=_HPDF_Doc_RegisterFontDef($78, $79);
      $ret=$80;
      var $81=(($80)|0)!=0;
      if ($81) { __label__ = 17; break; } else { __label__ = 18; break; }
    case 17: 
      var $83=$ret;
      $1=$83;
      __label__ = 37; break;
    case 18: 
      var $85=$2;
      var $86=(($85+8)|0);
      var $87=HEAP32[(($86)>>2)];
      var $88=_HPDF_CIDFontDef_New($87, ((STRING_TABLE.__str71277)|0), 138);
      $fontdef=$88;
      var $89=$2;
      var $90=$fontdef;
      var $91=_HPDF_Doc_RegisterFontDef($89, $90);
      $ret=$91;
      var $92=(($91)|0)!=0;
      if ($92) { __label__ = 19; break; } else { __label__ = 20; break; }
    case 19: 
      var $94=$ret;
      $1=$94;
      __label__ = 37; break;
    case 20: 
      var $96=$2;
      var $97=(($96+8)|0);
      var $98=HEAP32[(($97)>>2)];
      var $99=_HPDF_CIDFontDef_New($98, ((STRING_TABLE.__str81278)|0), 140);
      $fontdef=$99;
      var $100=$2;
      var $101=$fontdef;
      var $102=_HPDF_Doc_RegisterFontDef($100, $101);
      $ret=$102;
      var $103=(($102)|0)!=0;
      if ($103) { __label__ = 21; break; } else { __label__ = 22; break; }
    case 21: 
      var $105=$ret;
      $1=$105;
      __label__ = 37; break;
    case 22: 
      var $107=$2;
      var $108=(($107+8)|0);
      var $109=HEAP32[(($108)>>2)];
      var $110=_HPDF_CIDFontDef_New($109, ((STRING_TABLE.__str91279)|0), 142);
      $fontdef=$110;
      var $111=$2;
      var $112=$fontdef;
      var $113=_HPDF_Doc_RegisterFontDef($111, $112);
      $ret=$113;
      var $114=(($113)|0)!=0;
      if ($114) { __label__ = 23; break; } else { __label__ = 24; break; }
    case 23: 
      var $116=$ret;
      $1=$116;
      __label__ = 37; break;
    case 24: 
      var $118=$2;
      var $119=(($118+8)|0);
      var $120=HEAP32[(($119)>>2)];
      var $121=_HPDF_CIDFontDef_New($120, ((STRING_TABLE.__str101280)|0), 144);
      $fontdef=$121;
      var $122=$2;
      var $123=$fontdef;
      var $124=_HPDF_Doc_RegisterFontDef($122, $123);
      $ret=$124;
      var $125=(($124)|0)!=0;
      if ($125) { __label__ = 25; break; } else { __label__ = 26; break; }
    case 25: 
      var $127=$ret;
      $1=$127;
      __label__ = 37; break;
    case 26: 
      var $129=$2;
      var $130=(($129+8)|0);
      var $131=HEAP32[(($130)>>2)];
      var $132=_HPDF_CIDFontDef_New($131, ((STRING_TABLE.__str111281)|0), 146);
      $fontdef=$132;
      var $133=$2;
      var $134=$fontdef;
      var $135=_HPDF_Doc_RegisterFontDef($133, $134);
      $ret=$135;
      var $136=(($135)|0)!=0;
      if ($136) { __label__ = 27; break; } else { __label__ = 28; break; }
    case 27: 
      var $138=$ret;
      $1=$138;
      __label__ = 37; break;
    case 28: 
      var $140=$2;
      var $141=(($140+8)|0);
      var $142=HEAP32[(($141)>>2)];
      var $143=_HPDF_CIDFontDef_New($142, ((STRING_TABLE.__str121282)|0), 148);
      $fontdef=$143;
      var $144=$2;
      var $145=$fontdef;
      var $146=_HPDF_Doc_RegisterFontDef($144, $145);
      $ret=$146;
      var $147=(($146)|0)!=0;
      if ($147) { __label__ = 29; break; } else { __label__ = 30; break; }
    case 29: 
      var $149=$ret;
      $1=$149;
      __label__ = 37; break;
    case 30: 
      var $151=$2;
      var $152=(($151+8)|0);
      var $153=HEAP32[(($152)>>2)];
      var $154=_HPDF_CIDFontDef_New($153, ((STRING_TABLE.__str131283)|0), 150);
      $fontdef=$154;
      var $155=$2;
      var $156=$fontdef;
      var $157=_HPDF_Doc_RegisterFontDef($155, $156);
      $ret=$157;
      var $158=(($157)|0)!=0;
      if ($158) { __label__ = 31; break; } else { __label__ = 32; break; }
    case 31: 
      var $160=$ret;
      $1=$160;
      __label__ = 37; break;
    case 32: 
      var $162=$2;
      var $163=(($162+8)|0);
      var $164=HEAP32[(($163)>>2)];
      var $165=_HPDF_CIDFontDef_New($164, ((STRING_TABLE.__str141284)|0), 152);
      $fontdef=$165;
      var $166=$2;
      var $167=$fontdef;
      var $168=_HPDF_Doc_RegisterFontDef($166, $167);
      $ret=$168;
      var $169=(($168)|0)!=0;
      if ($169) { __label__ = 33; break; } else { __label__ = 34; break; }
    case 33: 
      var $171=$ret;
      $1=$171;
      __label__ = 37; break;
    case 34: 
      var $173=$2;
      var $174=(($173+8)|0);
      var $175=HEAP32[(($174)>>2)];
      var $176=_HPDF_CIDFontDef_New($175, ((STRING_TABLE.__str151285)|0), 154);
      $fontdef=$176;
      var $177=$2;
      var $178=$fontdef;
      var $179=_HPDF_Doc_RegisterFontDef($177, $178);
      $ret=$179;
      var $180=(($179)|0)!=0;
      if ($180) { __label__ = 35; break; } else { __label__ = 36; break; }
    case 35: 
      var $182=$ret;
      $1=$182;
      __label__ = 37; break;
    case 36: 
      $1=0;
      __label__ = 37; break;
    case 37: 
      var $185=$1;
      ;
      return $185;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_UseJPFonts["X"]=1;

function _MS_Gothic_Init($fontdef) {
  var __stackBase__  = STACKTOP; STACKTOP += 16; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $ret;
      var $3=__stackBase__;
      $2=$fontdef;
      var $4=$2;
      var $5=(($4+156)|0);
      HEAP16[(($5)>>1)]=859;
      var $6=$2;
      var $7=(($6+158)|0);
      HEAP16[(($7)>>1)]=-140;
      var $8=$2;
      var $9=(($8+194)|0);
      HEAP16[(($9)>>1)]=769;
      var $10=$2;
      var $11=(($10+164)|0);
      _HPDF_ToBox($3, 0, -136, 1000, 859);
      var $12=$11;
      var $13=$3;
      assert(16 % 1 === 0, 'memcpy given ' + 16 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP32[(($12)>>2)]=HEAP32[(($13)>>2)];HEAP32[((($12)+(4))>>2)]=HEAP32[((($13)+(4))>>2)];HEAP32[((($12)+(8))>>2)]=HEAP32[((($13)+(8))>>2)];HEAP32[((($12)+(12))>>2)]=HEAP32[((($13)+(12))>>2)];
      var $14=$2;
      var $15=(($14+160)|0);
      HEAP32[(($15)>>2)]=5;
      var $16=$2;
      var $17=(($16+180)|0);
      HEAP16[(($17)>>1)]=0;
      var $18=$2;
      var $19=(($18+182)|0);
      HEAP16[(($19)>>1)]=78;
      var $20=$2;
      var $21=_HPDF_CIDFontDef_AddWidth($20, ((_MS_Gothic_W_ARRAY)|0));
      $ret=$21;
      var $22=(($21)|0)!=0;
      if ($22) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $24=$ret;
      $1=$24;
      __label__ = 5; break;
    case 4: 
      var $26=$2;
      var $27=(($26+140)|0);
      HEAP32[(($27)>>2)]=2;
      var $28=$2;
      var $29=(($28+204)|0);
      HEAP32[(($29)>>2)]=1;
      $1=0;
      __label__ = 5; break;
    case 5: 
      var $31=$1;
      STACKTOP = __stackBase__;
      return $31;
    default: assert(0, "bad label: " + __label__);
  }
}


function _MS_Gothic_Bold_Init($fontdef) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $ret;
      $2=$fontdef;
      var $3=$2;
      var $4=_MS_Gothic_Init($3);
      $ret=$4;
      var $5=$ret;
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $8=$ret;
      $1=$8;
      __label__ = 5; break;
    case 4: 
      var $10=$2;
      var $11=_HPDF_CIDFontDef_ChangeStyle($10, 1, 0);
      $1=$11;
      __label__ = 5; break;
    case 5: 
      var $13=$1;
      ;
      return $13;
    default: assert(0, "bad label: " + __label__);
  }
}


function _MS_Gothic_Italic_Init($fontdef) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $ret;
      $2=$fontdef;
      var $3=$2;
      var $4=_MS_Gothic_Init($3);
      $ret=$4;
      var $5=$ret;
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $8=$ret;
      $1=$8;
      __label__ = 5; break;
    case 4: 
      var $10=$2;
      var $11=_HPDF_CIDFontDef_ChangeStyle($10, 0, 1);
      $1=$11;
      __label__ = 5; break;
    case 5: 
      var $13=$1;
      ;
      return $13;
    default: assert(0, "bad label: " + __label__);
  }
}


function _MS_Gothic_BoldItalic_Init($fontdef) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $ret;
      $2=$fontdef;
      var $3=$2;
      var $4=_MS_Gothic_Init($3);
      $ret=$4;
      var $5=$ret;
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $8=$ret;
      $1=$8;
      __label__ = 5; break;
    case 4: 
      var $10=$2;
      var $11=_HPDF_CIDFontDef_ChangeStyle($10, 1, 1);
      $1=$11;
      __label__ = 5; break;
    case 5: 
      var $13=$1;
      ;
      return $13;
    default: assert(0, "bad label: " + __label__);
  }
}


function _MS_PGothic_Init($fontdef) {
  var __stackBase__  = STACKTOP; STACKTOP += 16; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $ret;
      var $3=__stackBase__;
      $2=$fontdef;
      var $4=$2;
      var $5=(($4+156)|0);
      HEAP16[(($5)>>1)]=859;
      var $6=$2;
      var $7=(($6+158)|0);
      HEAP16[(($7)>>1)]=-140;
      var $8=$2;
      var $9=(($8+194)|0);
      HEAP16[(($9)>>1)]=679;
      var $10=$2;
      var $11=(($10+164)|0);
      _HPDF_ToBox($3, -121, -136, 996, 859);
      var $12=$11;
      var $13=$3;
      assert(16 % 1 === 0, 'memcpy given ' + 16 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP32[(($12)>>2)]=HEAP32[(($13)>>2)];HEAP32[((($12)+(4))>>2)]=HEAP32[((($13)+(4))>>2)];HEAP32[((($12)+(8))>>2)]=HEAP32[((($13)+(8))>>2)];HEAP32[((($12)+(12))>>2)]=HEAP32[((($13)+(12))>>2)];
      var $14=$2;
      var $15=(($14+160)|0);
      HEAP32[(($15)>>2)]=4;
      var $16=$2;
      var $17=(($16+180)|0);
      HEAP16[(($17)>>1)]=0;
      var $18=$2;
      var $19=(($18+182)|0);
      HEAP16[(($19)>>1)]=78;
      var $20=$2;
      var $21=_HPDF_CIDFontDef_AddWidth($20, ((_MS_PGothic_W_ARRAY)|0));
      $ret=$21;
      var $22=(($21)|0)!=0;
      if ($22) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $24=$ret;
      $1=$24;
      __label__ = 5; break;
    case 4: 
      var $26=$2;
      var $27=(($26+140)|0);
      HEAP32[(($27)>>2)]=2;
      var $28=$2;
      var $29=(($28+204)|0);
      HEAP32[(($29)>>2)]=1;
      $1=0;
      __label__ = 5; break;
    case 5: 
      var $31=$1;
      STACKTOP = __stackBase__;
      return $31;
    default: assert(0, "bad label: " + __label__);
  }
}


function _MS_PGothic_Bold_Init($fontdef) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $ret;
      $2=$fontdef;
      var $3=$2;
      var $4=_MS_PGothic_Init($3);
      $ret=$4;
      var $5=$ret;
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $8=$ret;
      $1=$8;
      __label__ = 5; break;
    case 4: 
      var $10=$2;
      var $11=_HPDF_CIDFontDef_ChangeStyle($10, 1, 0);
      $1=$11;
      __label__ = 5; break;
    case 5: 
      var $13=$1;
      ;
      return $13;
    default: assert(0, "bad label: " + __label__);
  }
}


function _MS_PGothic_Italic_Init($fontdef) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $ret;
      $2=$fontdef;
      var $3=$2;
      var $4=_MS_PGothic_Init($3);
      $ret=$4;
      var $5=$ret;
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $8=$ret;
      $1=$8;
      __label__ = 5; break;
    case 4: 
      var $10=$2;
      var $11=_HPDF_CIDFontDef_ChangeStyle($10, 0, 1);
      $1=$11;
      __label__ = 5; break;
    case 5: 
      var $13=$1;
      ;
      return $13;
    default: assert(0, "bad label: " + __label__);
  }
}


function _MS_PGothic_BoldItalic_Init($fontdef) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $ret;
      $2=$fontdef;
      var $3=$2;
      var $4=_MS_PGothic_Init($3);
      $ret=$4;
      var $5=$ret;
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $8=$ret;
      $1=$8;
      __label__ = 5; break;
    case 4: 
      var $10=$2;
      var $11=_HPDF_CIDFontDef_ChangeStyle($10, 1, 1);
      $1=$11;
      __label__ = 5; break;
    case 5: 
      var $13=$1;
      ;
      return $13;
    default: assert(0, "bad label: " + __label__);
  }
}


function _MS_Mincyo_Init($fontdef) {
  var __stackBase__  = STACKTOP; STACKTOP += 16; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $ret;
      var $3=__stackBase__;
      $2=$fontdef;
      var $4=$2;
      var $5=(($4+156)|0);
      HEAP16[(($5)>>1)]=859;
      var $6=$2;
      var $7=(($6+158)|0);
      HEAP16[(($7)>>1)]=-140;
      var $8=$2;
      var $9=(($8+194)|0);
      HEAP16[(($9)>>1)]=769;
      var $10=$2;
      var $11=(($10+164)|0);
      _HPDF_ToBox($3, 0, -136, 1000, 859);
      var $12=$11;
      var $13=$3;
      assert(16 % 1 === 0, 'memcpy given ' + 16 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP32[(($12)>>2)]=HEAP32[(($13)>>2)];HEAP32[((($12)+(4))>>2)]=HEAP32[((($13)+(4))>>2)];HEAP32[((($12)+(8))>>2)]=HEAP32[((($13)+(8))>>2)];HEAP32[((($12)+(12))>>2)]=HEAP32[((($13)+(12))>>2)];
      var $14=$2;
      var $15=(($14+160)|0);
      HEAP32[(($15)>>2)]=7;
      var $16=$2;
      var $17=(($16+180)|0);
      HEAP16[(($17)>>1)]=0;
      var $18=$2;
      var $19=(($18+182)|0);
      HEAP16[(($19)>>1)]=78;
      var $20=$2;
      var $21=_HPDF_CIDFontDef_AddWidth($20, ((_MS_Gothic_W_ARRAY)|0));
      $ret=$21;
      var $22=(($21)|0)!=0;
      if ($22) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $24=$ret;
      $1=$24;
      __label__ = 5; break;
    case 4: 
      var $26=$2;
      var $27=(($26+140)|0);
      HEAP32[(($27)>>2)]=2;
      var $28=$2;
      var $29=(($28+204)|0);
      HEAP32[(($29)>>2)]=1;
      $1=0;
      __label__ = 5; break;
    case 5: 
      var $31=$1;
      STACKTOP = __stackBase__;
      return $31;
    default: assert(0, "bad label: " + __label__);
  }
}


function _MS_Mincyo_Bold_Init($fontdef) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $ret;
      $2=$fontdef;
      var $3=$2;
      var $4=_MS_Mincyo_Init($3);
      $ret=$4;
      var $5=$ret;
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $8=$ret;
      $1=$8;
      __label__ = 5; break;
    case 4: 
      var $10=$2;
      var $11=_HPDF_CIDFontDef_ChangeStyle($10, 1, 0);
      $1=$11;
      __label__ = 5; break;
    case 5: 
      var $13=$1;
      ;
      return $13;
    default: assert(0, "bad label: " + __label__);
  }
}


function _MS_Mincyo_Italic_Init($fontdef) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $ret;
      $2=$fontdef;
      var $3=$2;
      var $4=_MS_Mincyo_Init($3);
      $ret=$4;
      var $5=$ret;
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $8=$ret;
      $1=$8;
      __label__ = 5; break;
    case 4: 
      var $10=$2;
      var $11=_HPDF_CIDFontDef_ChangeStyle($10, 0, 1);
      $1=$11;
      __label__ = 5; break;
    case 5: 
      var $13=$1;
      ;
      return $13;
    default: assert(0, "bad label: " + __label__);
  }
}


function _MS_Mincyo_BoldItalic_Init($fontdef) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $ret;
      $2=$fontdef;
      var $3=$2;
      var $4=_MS_Mincyo_Init($3);
      $ret=$4;
      var $5=$ret;
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $8=$ret;
      $1=$8;
      __label__ = 5; break;
    case 4: 
      var $10=$2;
      var $11=_HPDF_CIDFontDef_ChangeStyle($10, 1, 1);
      $1=$11;
      __label__ = 5; break;
    case 5: 
      var $13=$1;
      ;
      return $13;
    default: assert(0, "bad label: " + __label__);
  }
}


function _MS_PMincyo_Init($fontdef) {
  var __stackBase__  = STACKTOP; STACKTOP += 16; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $ret;
      var $3=__stackBase__;
      $2=$fontdef;
      var $4=$2;
      var $5=(($4+156)|0);
      HEAP16[(($5)>>1)]=859;
      var $6=$2;
      var $7=(($6+158)|0);
      HEAP16[(($7)>>1)]=-140;
      var $8=$2;
      var $9=(($8+194)|0);
      HEAP16[(($9)>>1)]=679;
      var $10=$2;
      var $11=(($10+164)|0);
      _HPDF_ToBox($3, -82, -136, 996, 859);
      var $12=$11;
      var $13=$3;
      assert(16 % 1 === 0, 'memcpy given ' + 16 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP32[(($12)>>2)]=HEAP32[(($13)>>2)];HEAP32[((($12)+(4))>>2)]=HEAP32[((($13)+(4))>>2)];HEAP32[((($12)+(8))>>2)]=HEAP32[((($13)+(8))>>2)];HEAP32[((($12)+(12))>>2)]=HEAP32[((($13)+(12))>>2)];
      var $14=$2;
      var $15=(($14+160)|0);
      HEAP32[(($15)>>2)]=6;
      var $16=$2;
      var $17=(($16+180)|0);
      HEAP16[(($17)>>1)]=0;
      var $18=$2;
      var $19=(($18+182)|0);
      HEAP16[(($19)>>1)]=78;
      var $20=$2;
      var $21=_HPDF_CIDFontDef_AddWidth($20, ((_MS_PGothic_W_ARRAY)|0));
      $ret=$21;
      var $22=(($21)|0)!=0;
      if ($22) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $24=$ret;
      $1=$24;
      __label__ = 5; break;
    case 4: 
      var $26=$2;
      var $27=(($26+140)|0);
      HEAP32[(($27)>>2)]=2;
      var $28=$2;
      var $29=(($28+204)|0);
      HEAP32[(($29)>>2)]=1;
      $1=0;
      __label__ = 5; break;
    case 5: 
      var $31=$1;
      STACKTOP = __stackBase__;
      return $31;
    default: assert(0, "bad label: " + __label__);
  }
}


function _MS_PMincyo_Bold_Init($fontdef) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $ret;
      $2=$fontdef;
      var $3=$2;
      var $4=_MS_PMincyo_Init($3);
      $ret=$4;
      var $5=$ret;
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $8=$ret;
      $1=$8;
      __label__ = 5; break;
    case 4: 
      var $10=$2;
      var $11=_HPDF_CIDFontDef_ChangeStyle($10, 1, 0);
      $1=$11;
      __label__ = 5; break;
    case 5: 
      var $13=$1;
      ;
      return $13;
    default: assert(0, "bad label: " + __label__);
  }
}


function _MS_PMincyo_Italic_Init($fontdef) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $ret;
      $2=$fontdef;
      var $3=$2;
      var $4=_MS_PMincyo_Init($3);
      $ret=$4;
      var $5=$ret;
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $8=$ret;
      $1=$8;
      __label__ = 5; break;
    case 4: 
      var $10=$2;
      var $11=_HPDF_CIDFontDef_ChangeStyle($10, 0, 1);
      $1=$11;
      __label__ = 5; break;
    case 5: 
      var $13=$1;
      ;
      return $13;
    default: assert(0, "bad label: " + __label__);
  }
}


function _MS_PMincyo_BoldItalic_Init($fontdef) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $ret;
      $2=$fontdef;
      var $3=$2;
      var $4=_MS_PMincyo_Init($3);
      $ret=$4;
      var $5=$ret;
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $8=$ret;
      $1=$8;
      __label__ = 5; break;
    case 4: 
      var $10=$2;
      var $11=_HPDF_CIDFontDef_ChangeStyle($10, 1, 1);
      $1=$11;
      __label__ = 5; break;
    case 5: 
      var $13=$1;
      ;
      return $13;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_UseKRFonts($pdf) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $fontdef;
      var $ret;
      $2=$pdf;
      var $3=$2;
      var $4=_HPDF_HasDoc($3);
      var $5=(($4)|0)!=0;
      if ($5) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=4133;
      __label__ = 37; break;
    case 4: 
      var $8=$2;
      var $9=(($8+8)|0);
      var $10=HEAP32[(($9)>>2)];
      var $11=_HPDF_CIDFontDef_New($10, ((STRING_TABLE.__str1287)|0), 160);
      $fontdef=$11;
      var $12=$2;
      var $13=$fontdef;
      var $14=_HPDF_Doc_RegisterFontDef($12, $13);
      $ret=$14;
      var $15=(($14)|0)!=0;
      if ($15) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $17=$ret;
      $1=$17;
      __label__ = 37; break;
    case 6: 
      var $19=$2;
      var $20=(($19+8)|0);
      var $21=HEAP32[(($20)>>2)];
      var $22=_HPDF_CIDFontDef_New($21, ((STRING_TABLE.__str11288)|0), 162);
      $fontdef=$22;
      var $23=$2;
      var $24=$fontdef;
      var $25=_HPDF_Doc_RegisterFontDef($23, $24);
      $ret=$25;
      var $26=(($25)|0)!=0;
      if ($26) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $28=$ret;
      $1=$28;
      __label__ = 37; break;
    case 8: 
      var $30=$2;
      var $31=(($30+8)|0);
      var $32=HEAP32[(($31)>>2)];
      var $33=_HPDF_CIDFontDef_New($32, ((STRING_TABLE.__str21289)|0), 164);
      $fontdef=$33;
      var $34=$2;
      var $35=$fontdef;
      var $36=_HPDF_Doc_RegisterFontDef($34, $35);
      $ret=$36;
      var $37=(($36)|0)!=0;
      if ($37) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      var $39=$ret;
      $1=$39;
      __label__ = 37; break;
    case 10: 
      var $41=$2;
      var $42=(($41+8)|0);
      var $43=HEAP32[(($42)>>2)];
      var $44=_HPDF_CIDFontDef_New($43, ((STRING_TABLE.__str31290)|0), 166);
      $fontdef=$44;
      var $45=$2;
      var $46=$fontdef;
      var $47=_HPDF_Doc_RegisterFontDef($45, $46);
      $ret=$47;
      var $48=(($47)|0)!=0;
      if ($48) { __label__ = 11; break; } else { __label__ = 12; break; }
    case 11: 
      var $50=$ret;
      $1=$50;
      __label__ = 37; break;
    case 12: 
      var $52=$2;
      var $53=(($52+8)|0);
      var $54=HEAP32[(($53)>>2)];
      var $55=_HPDF_CIDFontDef_New($54, ((STRING_TABLE.__str41291)|0), 168);
      $fontdef=$55;
      var $56=$2;
      var $57=$fontdef;
      var $58=_HPDF_Doc_RegisterFontDef($56, $57);
      $ret=$58;
      var $59=(($58)|0)!=0;
      if ($59) { __label__ = 13; break; } else { __label__ = 14; break; }
    case 13: 
      var $61=$ret;
      $1=$61;
      __label__ = 37; break;
    case 14: 
      var $63=$2;
      var $64=(($63+8)|0);
      var $65=HEAP32[(($64)>>2)];
      var $66=_HPDF_CIDFontDef_New($65, ((STRING_TABLE.__str51292)|0), 170);
      $fontdef=$66;
      var $67=$2;
      var $68=$fontdef;
      var $69=_HPDF_Doc_RegisterFontDef($67, $68);
      $ret=$69;
      var $70=(($69)|0)!=0;
      if ($70) { __label__ = 15; break; } else { __label__ = 16; break; }
    case 15: 
      var $72=$ret;
      $1=$72;
      __label__ = 37; break;
    case 16: 
      var $74=$2;
      var $75=(($74+8)|0);
      var $76=HEAP32[(($75)>>2)];
      var $77=_HPDF_CIDFontDef_New($76, ((STRING_TABLE.__str61293)|0), 172);
      $fontdef=$77;
      var $78=$2;
      var $79=$fontdef;
      var $80=_HPDF_Doc_RegisterFontDef($78, $79);
      $ret=$80;
      var $81=(($80)|0)!=0;
      if ($81) { __label__ = 17; break; } else { __label__ = 18; break; }
    case 17: 
      var $83=$ret;
      $1=$83;
      __label__ = 37; break;
    case 18: 
      var $85=$2;
      var $86=(($85+8)|0);
      var $87=HEAP32[(($86)>>2)];
      var $88=_HPDF_CIDFontDef_New($87, ((STRING_TABLE.__str71294)|0), 174);
      $fontdef=$88;
      var $89=$2;
      var $90=$fontdef;
      var $91=_HPDF_Doc_RegisterFontDef($89, $90);
      $ret=$91;
      var $92=(($91)|0)!=0;
      if ($92) { __label__ = 19; break; } else { __label__ = 20; break; }
    case 19: 
      var $94=$ret;
      $1=$94;
      __label__ = 37; break;
    case 20: 
      var $96=$2;
      var $97=(($96+8)|0);
      var $98=HEAP32[(($97)>>2)];
      var $99=_HPDF_CIDFontDef_New($98, ((STRING_TABLE.__str81295)|0), 176);
      $fontdef=$99;
      var $100=$2;
      var $101=$fontdef;
      var $102=_HPDF_Doc_RegisterFontDef($100, $101);
      $ret=$102;
      var $103=(($102)|0)!=0;
      if ($103) { __label__ = 21; break; } else { __label__ = 22; break; }
    case 21: 
      var $105=$ret;
      $1=$105;
      __label__ = 37; break;
    case 22: 
      var $107=$2;
      var $108=(($107+8)|0);
      var $109=HEAP32[(($108)>>2)];
      var $110=_HPDF_CIDFontDef_New($109, ((STRING_TABLE.__str91296)|0), 178);
      $fontdef=$110;
      var $111=$2;
      var $112=$fontdef;
      var $113=_HPDF_Doc_RegisterFontDef($111, $112);
      $ret=$113;
      var $114=(($113)|0)!=0;
      if ($114) { __label__ = 23; break; } else { __label__ = 24; break; }
    case 23: 
      var $116=$ret;
      $1=$116;
      __label__ = 37; break;
    case 24: 
      var $118=$2;
      var $119=(($118+8)|0);
      var $120=HEAP32[(($119)>>2)];
      var $121=_HPDF_CIDFontDef_New($120, ((STRING_TABLE.__str101297)|0), 180);
      $fontdef=$121;
      var $122=$2;
      var $123=$fontdef;
      var $124=_HPDF_Doc_RegisterFontDef($122, $123);
      $ret=$124;
      var $125=(($124)|0)!=0;
      if ($125) { __label__ = 25; break; } else { __label__ = 26; break; }
    case 25: 
      var $127=$ret;
      $1=$127;
      __label__ = 37; break;
    case 26: 
      var $129=$2;
      var $130=(($129+8)|0);
      var $131=HEAP32[(($130)>>2)];
      var $132=_HPDF_CIDFontDef_New($131, ((STRING_TABLE.__str111298)|0), 182);
      $fontdef=$132;
      var $133=$2;
      var $134=$fontdef;
      var $135=_HPDF_Doc_RegisterFontDef($133, $134);
      $ret=$135;
      var $136=(($135)|0)!=0;
      if ($136) { __label__ = 27; break; } else { __label__ = 28; break; }
    case 27: 
      var $138=$ret;
      $1=$138;
      __label__ = 37; break;
    case 28: 
      var $140=$2;
      var $141=(($140+8)|0);
      var $142=HEAP32[(($141)>>2)];
      var $143=_HPDF_CIDFontDef_New($142, ((STRING_TABLE.__str121299)|0), 184);
      $fontdef=$143;
      var $144=$2;
      var $145=$fontdef;
      var $146=_HPDF_Doc_RegisterFontDef($144, $145);
      $ret=$146;
      var $147=(($146)|0)!=0;
      if ($147) { __label__ = 29; break; } else { __label__ = 30; break; }
    case 29: 
      var $149=$ret;
      $1=$149;
      __label__ = 37; break;
    case 30: 
      var $151=$2;
      var $152=(($151+8)|0);
      var $153=HEAP32[(($152)>>2)];
      var $154=_HPDF_CIDFontDef_New($153, ((STRING_TABLE.__str131300)|0), 186);
      $fontdef=$154;
      var $155=$2;
      var $156=$fontdef;
      var $157=_HPDF_Doc_RegisterFontDef($155, $156);
      $ret=$157;
      var $158=(($157)|0)!=0;
      if ($158) { __label__ = 31; break; } else { __label__ = 32; break; }
    case 31: 
      var $160=$ret;
      $1=$160;
      __label__ = 37; break;
    case 32: 
      var $162=$2;
      var $163=(($162+8)|0);
      var $164=HEAP32[(($163)>>2)];
      var $165=_HPDF_CIDFontDef_New($164, ((STRING_TABLE.__str141301)|0), 188);
      $fontdef=$165;
      var $166=$2;
      var $167=$fontdef;
      var $168=_HPDF_Doc_RegisterFontDef($166, $167);
      $ret=$168;
      var $169=(($168)|0)!=0;
      if ($169) { __label__ = 33; break; } else { __label__ = 34; break; }
    case 33: 
      var $171=$ret;
      $1=$171;
      __label__ = 37; break;
    case 34: 
      var $173=$2;
      var $174=(($173+8)|0);
      var $175=HEAP32[(($174)>>2)];
      var $176=_HPDF_CIDFontDef_New($175, ((STRING_TABLE.__str151302)|0), 190);
      $fontdef=$176;
      var $177=$2;
      var $178=$fontdef;
      var $179=_HPDF_Doc_RegisterFontDef($177, $178);
      $ret=$179;
      var $180=(($179)|0)!=0;
      if ($180) { __label__ = 35; break; } else { __label__ = 36; break; }
    case 35: 
      var $182=$ret;
      $1=$182;
      __label__ = 37; break;
    case 36: 
      $1=0;
      __label__ = 37; break;
    case 37: 
      var $185=$1;
      ;
      return $185;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_UseKRFonts["X"]=1;

function _DotumChe_Init($fontdef) {
  var __stackBase__  = STACKTOP; STACKTOP += 16; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $ret;
      var $3=__stackBase__;
      $2=$fontdef;
      var $4=$2;
      var $5=(($4+156)|0);
      HEAP16[(($5)>>1)]=858;
      var $6=$2;
      var $7=(($6+158)|0);
      HEAP16[(($7)>>1)]=-141;
      var $8=$2;
      var $9=(($8+194)|0);
      HEAP16[(($9)>>1)]=679;
      var $10=$2;
      var $11=(($10+164)|0);
      _HPDF_ToBox($3, 0, -150, 1000, 863);
      var $12=$11;
      var $13=$3;
      assert(16 % 1 === 0, 'memcpy given ' + 16 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP32[(($12)>>2)]=HEAP32[(($13)>>2)];HEAP32[((($12)+(4))>>2)]=HEAP32[((($13)+(4))>>2)];HEAP32[((($12)+(8))>>2)]=HEAP32[((($13)+(8))>>2)];HEAP32[((($12)+(12))>>2)]=HEAP32[((($13)+(12))>>2)];
      var $14=$2;
      var $15=(($14+160)|0);
      HEAP32[(($15)>>2)]=5;
      var $16=$2;
      var $17=(($16+180)|0);
      HEAP16[(($17)>>1)]=0;
      var $18=$2;
      var $19=(($18+182)|0);
      HEAP16[(($19)>>1)]=78;
      var $20=$2;
      var $21=_HPDF_CIDFontDef_AddWidth($20, ((_DotumChe_W_ARRAY)|0));
      $ret=$21;
      var $22=(($21)|0)!=0;
      if ($22) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $24=$ret;
      $1=$24;
      __label__ = 5; break;
    case 4: 
      var $26=$2;
      var $27=(($26+140)|0);
      HEAP32[(($27)>>2)]=2;
      var $28=$2;
      var $29=(($28+204)|0);
      HEAP32[(($29)>>2)]=1;
      $1=0;
      __label__ = 5; break;
    case 5: 
      var $31=$1;
      STACKTOP = __stackBase__;
      return $31;
    default: assert(0, "bad label: " + __label__);
  }
}


function _DotumChe_Bold_Init($fontdef) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $ret;
      $2=$fontdef;
      var $3=$2;
      var $4=_DotumChe_Init($3);
      $ret=$4;
      var $5=$ret;
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $8=$ret;
      $1=$8;
      __label__ = 5; break;
    case 4: 
      var $10=$2;
      var $11=_HPDF_CIDFontDef_ChangeStyle($10, 1, 0);
      $1=$11;
      __label__ = 5; break;
    case 5: 
      var $13=$1;
      ;
      return $13;
    default: assert(0, "bad label: " + __label__);
  }
}


function _DotumChe_Italic_Init($fontdef) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $ret;
      $2=$fontdef;
      var $3=$2;
      var $4=_DotumChe_Init($3);
      $ret=$4;
      var $5=$ret;
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $8=$ret;
      $1=$8;
      __label__ = 5; break;
    case 4: 
      var $10=$2;
      var $11=_HPDF_CIDFontDef_ChangeStyle($10, 0, 1);
      $1=$11;
      __label__ = 5; break;
    case 5: 
      var $13=$1;
      ;
      return $13;
    default: assert(0, "bad label: " + __label__);
  }
}


function _DotumChe_BoldItalic_Init($fontdef) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $ret;
      $2=$fontdef;
      var $3=$2;
      var $4=_DotumChe_Init($3);
      $ret=$4;
      var $5=$ret;
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $8=$ret;
      $1=$8;
      __label__ = 5; break;
    case 4: 
      var $10=$2;
      var $11=_HPDF_CIDFontDef_ChangeStyle($10, 1, 1);
      $1=$11;
      __label__ = 5; break;
    case 5: 
      var $13=$1;
      ;
      return $13;
    default: assert(0, "bad label: " + __label__);
  }
}


function _Dotum_Init($fontdef) {
  var __stackBase__  = STACKTOP; STACKTOP += 16; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $ret;
      var $3=__stackBase__;
      $2=$fontdef;
      var $4=$2;
      var $5=(($4+156)|0);
      HEAP16[(($5)>>1)]=858;
      var $6=$2;
      var $7=(($6+158)|0);
      HEAP16[(($7)>>1)]=-141;
      var $8=$2;
      var $9=(($8+194)|0);
      HEAP16[(($9)>>1)]=679;
      var $10=$2;
      var $11=(($10+164)|0);
      _HPDF_ToBox($3, 0, -150, 1000, 863);
      var $12=$11;
      var $13=$3;
      assert(16 % 1 === 0, 'memcpy given ' + 16 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP32[(($12)>>2)]=HEAP32[(($13)>>2)];HEAP32[((($12)+(4))>>2)]=HEAP32[((($13)+(4))>>2)];HEAP32[((($12)+(8))>>2)]=HEAP32[((($13)+(8))>>2)];HEAP32[((($12)+(12))>>2)]=HEAP32[((($13)+(12))>>2)];
      var $14=$2;
      var $15=(($14+160)|0);
      HEAP32[(($15)>>2)]=4;
      var $16=$2;
      var $17=(($16+180)|0);
      HEAP16[(($17)>>1)]=0;
      var $18=$2;
      var $19=(($18+182)|0);
      HEAP16[(($19)>>1)]=78;
      var $20=$2;
      var $21=_HPDF_CIDFontDef_AddWidth($20, ((_Dotum_W_ARRAY)|0));
      $ret=$21;
      var $22=(($21)|0)!=0;
      if ($22) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $24=$ret;
      $1=$24;
      __label__ = 5; break;
    case 4: 
      var $26=$2;
      var $27=(($26+140)|0);
      HEAP32[(($27)>>2)]=2;
      var $28=$2;
      var $29=(($28+204)|0);
      HEAP32[(($29)>>2)]=1;
      $1=0;
      __label__ = 5; break;
    case 5: 
      var $31=$1;
      STACKTOP = __stackBase__;
      return $31;
    default: assert(0, "bad label: " + __label__);
  }
}


function _Dotum_Bold_Init($fontdef) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $ret;
      $2=$fontdef;
      var $3=$2;
      var $4=_Dotum_Init($3);
      $ret=$4;
      var $5=$ret;
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $8=$ret;
      $1=$8;
      __label__ = 5; break;
    case 4: 
      var $10=$2;
      var $11=_HPDF_CIDFontDef_ChangeStyle($10, 1, 0);
      $1=$11;
      __label__ = 5; break;
    case 5: 
      var $13=$1;
      ;
      return $13;
    default: assert(0, "bad label: " + __label__);
  }
}


function _Dotum_Italic_Init($fontdef) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $ret;
      $2=$fontdef;
      var $3=$2;
      var $4=_Dotum_Init($3);
      $ret=$4;
      var $5=$ret;
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $8=$ret;
      $1=$8;
      __label__ = 5; break;
    case 4: 
      var $10=$2;
      var $11=_HPDF_CIDFontDef_ChangeStyle($10, 0, 1);
      $1=$11;
      __label__ = 5; break;
    case 5: 
      var $13=$1;
      ;
      return $13;
    default: assert(0, "bad label: " + __label__);
  }
}


function _Dotum_BoldItalic_Init($fontdef) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $ret;
      $2=$fontdef;
      var $3=$2;
      var $4=_Dotum_Init($3);
      $ret=$4;
      var $5=$ret;
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $8=$ret;
      $1=$8;
      __label__ = 5; break;
    case 4: 
      var $10=$2;
      var $11=_HPDF_CIDFontDef_ChangeStyle($10, 1, 1);
      $1=$11;
      __label__ = 5; break;
    case 5: 
      var $13=$1;
      ;
      return $13;
    default: assert(0, "bad label: " + __label__);
  }
}


function _BatangChe_Init($fontdef) {
  var __stackBase__  = STACKTOP; STACKTOP += 16; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $ret;
      var $3=__stackBase__;
      $2=$fontdef;
      var $4=$2;
      var $5=(($4+156)|0);
      HEAP16[(($5)>>1)]=858;
      var $6=$2;
      var $7=(($6+158)|0);
      HEAP16[(($7)>>1)]=-141;
      var $8=$2;
      var $9=(($8+194)|0);
      HEAP16[(($9)>>1)]=769;
      var $10=$2;
      var $11=(($10+164)|0);
      _HPDF_ToBox($3, 0, -154, 1000, 861);
      var $12=$11;
      var $13=$3;
      assert(16 % 1 === 0, 'memcpy given ' + 16 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP32[(($12)>>2)]=HEAP32[(($13)>>2)];HEAP32[((($12)+(4))>>2)]=HEAP32[((($13)+(4))>>2)];HEAP32[((($12)+(8))>>2)]=HEAP32[((($13)+(8))>>2)];HEAP32[((($12)+(12))>>2)]=HEAP32[((($13)+(12))>>2)];
      var $14=$2;
      var $15=(($14+160)|0);
      HEAP32[(($15)>>2)]=7;
      var $16=$2;
      var $17=(($16+180)|0);
      HEAP16[(($17)>>1)]=0;
      var $18=$2;
      var $19=(($18+182)|0);
      HEAP16[(($19)>>1)]=78;
      var $20=$2;
      var $21=_HPDF_CIDFontDef_AddWidth($20, ((_DotumChe_W_ARRAY)|0));
      $ret=$21;
      var $22=(($21)|0)!=0;
      if ($22) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $24=$ret;
      $1=$24;
      __label__ = 5; break;
    case 4: 
      var $26=$2;
      var $27=(($26+140)|0);
      HEAP32[(($27)>>2)]=2;
      var $28=$2;
      var $29=(($28+204)|0);
      HEAP32[(($29)>>2)]=1;
      $1=0;
      __label__ = 5; break;
    case 5: 
      var $31=$1;
      STACKTOP = __stackBase__;
      return $31;
    default: assert(0, "bad label: " + __label__);
  }
}


function _BatangChe_Bold_Init($fontdef) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $ret;
      $2=$fontdef;
      var $3=$2;
      var $4=_BatangChe_Init($3);
      $ret=$4;
      var $5=$ret;
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $8=$ret;
      $1=$8;
      __label__ = 5; break;
    case 4: 
      var $10=$2;
      var $11=_HPDF_CIDFontDef_ChangeStyle($10, 1, 0);
      $1=$11;
      __label__ = 5; break;
    case 5: 
      var $13=$1;
      ;
      return $13;
    default: assert(0, "bad label: " + __label__);
  }
}


function _BatangChe_Italic_Init($fontdef) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $ret;
      $2=$fontdef;
      var $3=$2;
      var $4=_BatangChe_Init($3);
      $ret=$4;
      var $5=$ret;
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $8=$ret;
      $1=$8;
      __label__ = 5; break;
    case 4: 
      var $10=$2;
      var $11=_HPDF_CIDFontDef_ChangeStyle($10, 0, 1);
      $1=$11;
      __label__ = 5; break;
    case 5: 
      var $13=$1;
      ;
      return $13;
    default: assert(0, "bad label: " + __label__);
  }
}


function _BatangChe_BoldItalic_Init($fontdef) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $ret;
      $2=$fontdef;
      var $3=$2;
      var $4=_BatangChe_Init($3);
      $ret=$4;
      var $5=$ret;
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $8=$ret;
      $1=$8;
      __label__ = 5; break;
    case 4: 
      var $10=$2;
      var $11=_HPDF_CIDFontDef_ChangeStyle($10, 1, 1);
      $1=$11;
      __label__ = 5; break;
    case 5: 
      var $13=$1;
      ;
      return $13;
    default: assert(0, "bad label: " + __label__);
  }
}


function _Batang_Init($fontdef) {
  var __stackBase__  = STACKTOP; STACKTOP += 16; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $ret;
      var $3=__stackBase__;
      $2=$fontdef;
      var $4=$2;
      var $5=(($4+156)|0);
      HEAP16[(($5)>>1)]=858;
      var $6=$2;
      var $7=(($6+158)|0);
      HEAP16[(($7)>>1)]=-141;
      var $8=$2;
      var $9=(($8+194)|0);
      HEAP16[(($9)>>1)]=679;
      var $10=$2;
      var $11=(($10+164)|0);
      _HPDF_ToBox($3, 0, -154, 1000, 861);
      var $12=$11;
      var $13=$3;
      assert(16 % 1 === 0, 'memcpy given ' + 16 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP32[(($12)>>2)]=HEAP32[(($13)>>2)];HEAP32[((($12)+(4))>>2)]=HEAP32[((($13)+(4))>>2)];HEAP32[((($12)+(8))>>2)]=HEAP32[((($13)+(8))>>2)];HEAP32[((($12)+(12))>>2)]=HEAP32[((($13)+(12))>>2)];
      var $14=$2;
      var $15=(($14+160)|0);
      HEAP32[(($15)>>2)]=6;
      var $16=$2;
      var $17=(($16+180)|0);
      HEAP16[(($17)>>1)]=0;
      var $18=$2;
      var $19=(($18+182)|0);
      HEAP16[(($19)>>1)]=78;
      var $20=$2;
      var $21=_HPDF_CIDFontDef_AddWidth($20, ((_Dotum_W_ARRAY)|0));
      $ret=$21;
      var $22=(($21)|0)!=0;
      if ($22) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $24=$ret;
      $1=$24;
      __label__ = 5; break;
    case 4: 
      var $26=$2;
      var $27=(($26+140)|0);
      HEAP32[(($27)>>2)]=2;
      var $28=$2;
      var $29=(($28+204)|0);
      HEAP32[(($29)>>2)]=1;
      $1=0;
      __label__ = 5; break;
    case 5: 
      var $31=$1;
      STACKTOP = __stackBase__;
      return $31;
    default: assert(0, "bad label: " + __label__);
  }
}


function _Batang_Bold_Init($fontdef) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $ret;
      $2=$fontdef;
      var $3=$2;
      var $4=_Batang_Init($3);
      $ret=$4;
      var $5=$ret;
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $8=$ret;
      $1=$8;
      __label__ = 5; break;
    case 4: 
      var $10=$2;
      var $11=_HPDF_CIDFontDef_ChangeStyle($10, 1, 0);
      $1=$11;
      __label__ = 5; break;
    case 5: 
      var $13=$1;
      ;
      return $13;
    default: assert(0, "bad label: " + __label__);
  }
}


function _Batang_Italic_Init($fontdef) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $ret;
      $2=$fontdef;
      var $3=$2;
      var $4=_Batang_Init($3);
      $ret=$4;
      var $5=$ret;
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $8=$ret;
      $1=$8;
      __label__ = 5; break;
    case 4: 
      var $10=$2;
      var $11=_HPDF_CIDFontDef_ChangeStyle($10, 0, 1);
      $1=$11;
      __label__ = 5; break;
    case 5: 
      var $13=$1;
      ;
      return $13;
    default: assert(0, "bad label: " + __label__);
  }
}


function _Batang_BoldItalic_Init($fontdef) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $ret;
      $2=$fontdef;
      var $3=$2;
      var $4=_Batang_Init($3);
      $ret=$4;
      var $5=$ret;
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $8=$ret;
      $1=$8;
      __label__ = 5; break;
    case 4: 
      var $10=$2;
      var $11=_HPDF_CIDFontDef_ChangeStyle($10, 1, 1);
      $1=$11;
      __label__ = 5; break;
    case 5: 
      var $13=$1;
      ;
      return $13;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_TTFontDef_New($mmgr) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $fontdef;
      var $fontdef_attr;
      $2=$mmgr;
      var $3=$2;
      var $4=(($3)|0)!=0;
      if ($4) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=0;
      __label__ = 9; break;
    case 4: 
      var $7=$2;
      var $8=_HPDF_GetMem($7, 212);
      var $9=$8;
      $fontdef=$9;
      var $10=$fontdef;
      var $11=(($10)|0)!=0;
      if ($11) { __label__ = 6; break; } else { __label__ = 5; break; }
    case 5: 
      $1=0;
      __label__ = 9; break;
    case 6: 
      var $14=$fontdef;
      var $15=$14;
      var $16=_HPDF_MemSet($15, 0, 212);
      var $17=$fontdef;
      var $18=(($17)|0);
      HEAP32[(($18)>>2)]=1179602516;
      var $19=$2;
      var $20=$fontdef;
      var $21=(($20+132)|0);
      HEAP32[(($21)>>2)]=$19;
      var $22=$2;
      var $23=(($22)|0);
      var $24=HEAP32[(($23)>>2)];
      var $25=$fontdef;
      var $26=(($25+136)|0);
      HEAP32[(($26)>>2)]=$24;
      var $27=$fontdef;
      var $28=(($27+140)|0);
      HEAP32[(($28)>>2)]=1;
      var $29=$fontdef;
      var $30=(($29+144)|0);
      HEAP32[(($30)>>2)]=156;
      var $31=$fontdef;
      var $32=(($31+148)|0);
      HEAP32[(($32)>>2)]=158;
      var $33=$2;
      var $34=_HPDF_GetMem($33, 352);
      var $35=$34;
      $fontdef_attr=$35;
      var $36=$fontdef_attr;
      var $37=(($36)|0)!=0;
      if ($37) { __label__ = 8; break; } else { __label__ = 7; break; }
    case 7: 
      var $39=$fontdef;
      var $40=(($39+132)|0);
      var $41=HEAP32[(($40)>>2)];
      var $42=$fontdef;
      var $43=$42;
      _HPDF_FreeMem($41, $43);
      $1=0;
      __label__ = 9; break;
    case 8: 
      var $45=$fontdef_attr;
      var $46=$45;
      var $47=$fontdef;
      var $48=(($47+208)|0);
      HEAP32[(($48)>>2)]=$46;
      var $49=$fontdef_attr;
      var $50=$49;
      var $51=_HPDF_MemSet($50, 0, 352);
      var $52=$fontdef;
      var $53=(($52+160)|0);
      HEAP32[(($53)>>2)]=32;
      var $54=$fontdef;
      $1=$54;
      __label__ = 9; break;
    case 9: 
      var $56=$1;
      ;
      return $56;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_TTFontDef_New["X"]=1;

function _CleanFunc($fontdef) {
  ;
  var __label__;

  var $1;
  var $attr;
  $1=$fontdef;
  var $2=$1;
  var $3=(($2+208)|0);
  var $4=HEAP32[(($3)>>2)];
  var $5=$4;
  $attr=$5;
  var $6=$attr;
  var $7=(($6+216)|0);
  var $8=(($7+8)|0);
  var $9=HEAP32[(($8)>>2)];
  var $10=$attr;
  var $11=(($10+228)|0);
  var $12=HEAPU16[(($11)>>1)];
  var $13=(($12)&65535);
  var $14=(($13)|0);
  var $15=_HPDF_MemSet($9, 0, $14);
  var $16=$attr;
  var $17=(($16+216)|0);
  var $18=(($17+8)|0);
  var $19=HEAP32[(($18)>>2)];
  var $20=(($19)|0);
  HEAP8[($20)]=1;
  ;
  return;
}


function _FreeFunc($fontdef) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $attr;
      $1=$fontdef;
      var $2=$1;
      var $3=(($2+208)|0);
      var $4=HEAP32[(($3)>>2)];
      var $5=$4;
      $attr=$5;
      var $6=$attr;
      var $7=(($6)|0)!=0;
      if ($7) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $9=$1;
      _InitAttr($9);
      var $10=$1;
      var $11=(($10+132)|0);
      var $12=HEAP32[(($11)>>2)];
      var $13=$attr;
      var $14=$13;
      _HPDF_FreeMem($12, $14);
      __label__ = 4; break;
    case 4: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_TTFontDef_Load($mmgr, $stream, $embedding) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $ret;
      var $fontdef;
      $2=$mmgr;
      $3=$stream;
      $4=$embedding;
      var $5=$2;
      var $6=_HPDF_TTFontDef_New($5);
      $fontdef=$6;
      var $7=$fontdef;
      var $8=(($7)|0)!=0;
      if ($8) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      var $10=$3;
      _HPDF_Stream_Free($10);
      $1=0;
      __label__ = 7; break;
    case 4: 
      var $12=$fontdef;
      var $13=$3;
      var $14=$4;
      var $15=_LoadFontData($12, $13, $14, 0);
      $ret=$15;
      var $16=$ret;
      var $17=(($16)|0)!=0;
      if ($17) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $19=$fontdef;
      _HPDF_FontDef_Free($19);
      $1=0;
      __label__ = 7; break;
    case 6: 
      var $21=$fontdef;
      $1=$21;
      __label__ = 7; break;
    case 7: 
      var $23=$1;
      ;
      return $23;
    default: assert(0, "bad label: " + __label__);
  }
}


function _LoadFontData($fontdef, $stream, $embedding, $offset) {
  var __stackBase__  = STACKTOP; STACKTOP += 32; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $5;
      var $attr;
      var $ret;
      var $tbl;
      var $6=__stackBase__;
      var $7=(__stackBase__)+(16);
      $2=$fontdef;
      $3=$stream;
      $4=$embedding;
      $5=$offset;
      var $8=$2;
      var $9=(($8+208)|0);
      var $10=HEAP32[(($9)>>2)];
      var $11=$10;
      $attr=$11;
      var $12=$3;
      var $13=$attr;
      var $14=(($13+348)|0);
      HEAP32[(($14)>>2)]=$12;
      var $15=$4;
      var $16=$attr;
      var $17=(($16+340)|0);
      HEAP32[(($17)>>2)]=$15;
      var $18=$3;
      var $19=$5;
      var $20=_HPDF_Stream_Seek($18, $19, 0);
      $ret=$20;
      var $21=(($20)|0)!=0;
      if ($21) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $23=$ret;
      $1=$23;
      __label__ = 27; break;
    case 4: 
      var $25=$2;
      var $26=_LoadTTFTable($25);
      $ret=$26;
      var $27=(($26)|0)!=0;
      if ($27) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $29=$ret;
      $1=$29;
      __label__ = 27; break;
    case 6: 
      var $31=$2;
      var $32=_ParseHead($31);
      $ret=$32;
      var $33=(($32)|0)!=0;
      if ($33) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $35=$ret;
      $1=$35;
      __label__ = 27; break;
    case 8: 
      var $37=$2;
      var $38=_ParseMaxp($37);
      $ret=$38;
      var $39=(($38)|0)!=0;
      if ($39) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      var $41=$ret;
      $1=$41;
      __label__ = 27; break;
    case 10: 
      var $43=$2;
      var $44=_ParseHhea($43);
      $ret=$44;
      var $45=(($44)|0)!=0;
      if ($45) { __label__ = 11; break; } else { __label__ = 12; break; }
    case 11: 
      var $47=$ret;
      $1=$47;
      __label__ = 27; break;
    case 12: 
      var $49=$2;
      var $50=_ParseCMap($49);
      $ret=$50;
      var $51=(($50)|0)!=0;
      if ($51) { __label__ = 13; break; } else { __label__ = 14; break; }
    case 13: 
      var $53=$ret;
      $1=$53;
      __label__ = 27; break;
    case 14: 
      var $55=$2;
      var $56=_ParseHmtx($55);
      $ret=$56;
      var $57=(($56)|0)!=0;
      if ($57) { __label__ = 15; break; } else { __label__ = 16; break; }
    case 15: 
      var $59=$ret;
      $1=$59;
      __label__ = 27; break;
    case 16: 
      var $61=$2;
      var $62=_ParseLoca($61);
      $ret=$62;
      var $63=(($62)|0)!=0;
      if ($63) { __label__ = 17; break; } else { __label__ = 18; break; }
    case 17: 
      var $65=$ret;
      $1=$65;
      __label__ = 27; break;
    case 18: 
      var $67=$2;
      var $68=_ParseName($67);
      $ret=$68;
      var $69=(($68)|0)!=0;
      if ($69) { __label__ = 19; break; } else { __label__ = 20; break; }
    case 19: 
      var $71=$ret;
      $1=$71;
      __label__ = 27; break;
    case 20: 
      var $73=$2;
      var $74=_ParseOS2($73);
      $ret=$74;
      var $75=(($74)|0)!=0;
      if ($75) { __label__ = 21; break; } else { __label__ = 22; break; }
    case 21: 
      var $77=$ret;
      $1=$77;
      __label__ = 27; break;
    case 22: 
      var $79=$2;
      var $80=_FindTable($79, ((STRING_TABLE.__str11305)|0));
      $tbl=$80;
      var $81=$tbl;
      var $82=(($81)|0)!=0;
      if ($82) { __label__ = 24; break; } else { __label__ = 23; break; }
    case 23: 
      var $84=$2;
      var $85=(($84+136)|0);
      var $86=HEAP32[(($85)>>2)];
      var $87=_HPDF_SetError($86, 4192, 4);
      $1=$87;
      __label__ = 27; break;
    case 24: 
      var $89=$tbl;
      var $90=(($89+8)|0);
      var $91=HEAP32[(($90)>>2)];
      var $92=$attr;
      var $93=(($92+216)|0);
      var $94=(($93)|0);
      HEAP32[(($94)>>2)]=$91;
      var $95=$2;
      _HPDF_TTFontDef_GetCharBBox($6, $95, 72);
      var $96=(($6+12)|0);
      var $97=HEAPF32[(($96)>>2)];
      var $98=($97 >= 0 ? Math.floor($97) : Math.ceil($97));
      var $99=$2;
      var $100=(($99+194)|0);
      HEAP16[(($100)>>1)]=$98;
      var $101=$2;
      _HPDF_TTFontDef_GetCharBBox($7, $101, 120);
      var $102=(($7+12)|0);
      var $103=HEAPF32[(($102)>>2)];
      var $104=($103 >= 0 ? Math.floor($103) : Math.ceil($103));
      var $105=$2;
      var $106=(($105+192)|0);
      HEAP16[(($106)>>1)]=$104;
      var $107=$attr;
      var $108=(($107+244)|0);
      var $109=HEAP32[(($108)>>2)];
      var $110=(($109)|0);
      var $111=(($110)|0);
      var $112=HEAPU16[(($111)>>1)];
      var $113=(($112)&65535);
      var $114=((($113)*(1000))|0);
      var $115=$attr;
      var $116=(($115+160)|0);
      var $117=(($116+18)|0);
      var $118=HEAPU16[(($117)>>1)];
      var $119=(($118)&65535);
      var $120=Math.floor(((($114)>>>0))/((($119)>>>0)));
      var $121=(($120) & 65535);
      var $122=$2;
      var $123=(($122+188)|0);
      HEAP16[(($123)>>1)]=$121;
      var $124=$4;
      var $125=(($124)|0)!=0;
      if ($125) { __label__ = 26; break; } else { __label__ = 25; break; }
    case 25: 
      var $127=$attr;
      var $128=(($127+348)|0);
      var $129=HEAP32[(($128)>>2)];
      _HPDF_Stream_Free($129);
      var $130=$attr;
      var $131=(($130+348)|0);
      HEAP32[(($131)>>2)]=0;
      __label__ = 26; break;
    case 26: 
      $1=0;
      __label__ = 27; break;
    case 27: 
      var $134=$1;
      STACKTOP = __stackBase__;
      return $134;
    default: assert(0, "bad label: " + __label__);
  }
}
_LoadFontData["X"]=1;

function _HPDF_TTFontDef_Load2($mmgr, $stream, $index, $embedding) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $5;
      var $ret;
      var $fontdef;
      $2=$mmgr;
      $3=$stream;
      $4=$index;
      $5=$embedding;
      var $6=$2;
      var $7=_HPDF_TTFontDef_New($6);
      $fontdef=$7;
      var $8=$fontdef;
      var $9=(($8)|0)!=0;
      if ($9) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      var $11=$3;
      _HPDF_Stream_Free($11);
      $1=0;
      __label__ = 7; break;
    case 4: 
      var $13=$fontdef;
      var $14=$3;
      var $15=$4;
      var $16=$5;
      var $17=_LoadFontData2($13, $14, $15, $16);
      $ret=$17;
      var $18=$ret;
      var $19=(($18)|0)!=0;
      if ($19) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $21=$fontdef;
      _HPDF_FontDef_Free($21);
      $1=0;
      __label__ = 7; break;
    case 6: 
      var $23=$fontdef;
      $1=$23;
      __label__ = 7; break;
    case 7: 
      var $25=$1;
      ;
      return $25;
    default: assert(0, "bad label: " + __label__);
  }
}


function _LoadFontData2($fontdef, $stream, $index, $embedding) {
  var __stackBase__  = STACKTOP; STACKTOP += 16; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $5;
      var $attr;
      var $ret;
      var $tag=__stackBase__;
      var $num_fonts=(__stackBase__)+(4);
      var $offset=(__stackBase__)+(8);
      var $size=(__stackBase__)+(12);
      $2=$fontdef;
      $3=$stream;
      $4=$index;
      $5=$embedding;
      var $6=$2;
      var $7=(($6+208)|0);
      var $8=HEAP32[(($7)>>2)];
      var $9=$8;
      $attr=$9;
      var $10=$3;
      var $11=$attr;
      var $12=(($11+348)|0);
      HEAP32[(($12)>>2)]=$10;
      var $13=$5;
      var $14=$attr;
      var $15=(($14+340)|0);
      HEAP32[(($15)>>2)]=$13;
      var $16=$3;
      var $17=_HPDF_Stream_Seek($16, 0, 0);
      $ret=$17;
      var $18=$ret;
      var $19=(($18)|0)!=0;
      if ($19) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $21=$ret;
      $1=$21;
      __label__ = 19; break;
    case 4: 
      HEAP32[(($size)>>2)]=4;
      var $23=$3;
      var $24=(($tag)|0);
      var $25=_HPDF_Stream_Read($23, $24, $size);
      $ret=$25;
      var $26=(($25)|0)!=0;
      if ($26) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $28=$ret;
      $1=$28;
      __label__ = 19; break;
    case 6: 
      var $30=(($tag)|0);
      var $31=_HPDF_MemCmp($30, ((STRING_TABLE.__str131317)|0), 4);
      var $32=(($31)|0)!=0;
      if ($32) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $34=$2;
      var $35=(($34+136)|0);
      var $36=HEAP32[(($35)>>2)];
      var $37=_HPDF_SetError($36, 4159, 0);
      $1=$37;
      __label__ = 19; break;
    case 8: 
      var $39=$3;
      var $40=_HPDF_Stream_Seek($39, 8, 0);
      $ret=$40;
      var $41=(($40)|0)!=0;
      if ($41) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      var $43=$ret;
      $1=$43;
      __label__ = 19; break;
    case 10: 
      var $45=$3;
      var $46=_GetUINT32($45, $num_fonts);
      $ret=$46;
      var $47=(($46)|0)!=0;
      if ($47) { __label__ = 11; break; } else { __label__ = 12; break; }
    case 11: 
      var $49=$ret;
      $1=$49;
      __label__ = 19; break;
    case 12: 
      var $51=$4;
      var $52=HEAPU32[(($num_fonts)>>2)];
      var $53=(($51)>>>0) >= (($52)>>>0);
      if ($53) { __label__ = 13; break; } else { __label__ = 14; break; }
    case 13: 
      var $55=$2;
      var $56=(($55+136)|0);
      var $57=HEAP32[(($56)>>2)];
      var $58=_HPDF_SetError($57, 4160, 0);
      $1=$58;
      __label__ = 19; break;
    case 14: 
      var $60=$3;
      var $61=$4;
      var $62=((($61<<2))|0);
      var $63=((($62)+(12))|0);
      var $64=_HPDF_Stream_Seek($60, $63, 0);
      $ret=$64;
      var $65=(($64)|0)!=0;
      if ($65) { __label__ = 15; break; } else { __label__ = 16; break; }
    case 15: 
      var $67=$ret;
      $1=$67;
      __label__ = 19; break;
    case 16: 
      var $69=$3;
      var $70=_GetUINT32($69, $offset);
      $ret=$70;
      var $71=(($70)|0)!=0;
      if ($71) { __label__ = 17; break; } else { __label__ = 18; break; }
    case 17: 
      var $73=$ret;
      $1=$73;
      __label__ = 19; break;
    case 18: 
      var $75=$2;
      var $76=$3;
      var $77=$5;
      var $78=HEAP32[(($offset)>>2)];
      var $79=_LoadFontData($75, $76, $77, $78);
      $1=$79;
      __label__ = 19; break;
    case 19: 
      var $81=$1;
      STACKTOP = __stackBase__;
      return $81;
    default: assert(0, "bad label: " + __label__);
  }
}
_LoadFontData2["X"]=1;

function _HPDF_TTFontDef_GetCharBBox($agg_result, $fontdef, $unicode) {
  var __stackBase__  = STACKTOP; STACKTOP += 20; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $attr;
      var $gid;
      var $ret;
      var $bbox=__stackBase__;
      var $i=(__stackBase__)+(16);
      var $m;
      $1=$fontdef;
      $2=$unicode;
      var $3=$1;
      var $4=(($3+208)|0);
      var $5=HEAP32[(($4)>>2)];
      var $6=$5;
      $attr=$6;
      var $7=$1;
      var $8=$2;
      var $9=_HPDF_TTFontDef_GetGlyphid($7, $8);
      $gid=$9;
      _HPDF_ToBox($bbox, 0, 0, 0, 0);
      var $10=$gid;
      var $11=(($10)&65535);
      var $12=(($11)|0)==0;
      if ($12) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $14=$agg_result;
      var $15=$bbox;
      assert(16 % 1 === 0, 'memcpy given ' + 16 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP32[(($14)>>2)]=HEAP32[(($15)>>2)];HEAP32[((($14)+(4))>>2)]=HEAP32[((($15)+(4))>>2)];HEAP32[((($14)+(8))>>2)]=HEAP32[((($15)+(8))>>2)];HEAP32[((($14)+(12))>>2)]=HEAP32[((($15)+(12))>>2)];
      __label__ = 12; break;
    case 4: 
      var $17=$attr;
      var $18=(($17+160)|0);
      var $19=(($18+50)|0);
      var $20=HEAP16[(($19)>>1)];
      var $21=(($20 << 16) >> 16);
      var $22=(($21)|0)==0;
      if ($22) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      $m=2;
      __label__ = 7; break;
    case 6: 
      $m=1;
      __label__ = 7; break;
    case 7: 
      var $26=$attr;
      var $27=(($26+348)|0);
      var $28=HEAP32[(($27)>>2)];
      var $29=$attr;
      var $30=(($29+216)|0);
      var $31=(($30)|0);
      var $32=HEAP32[(($31)>>2)];
      var $33=$gid;
      var $34=(($33)&65535);
      var $35=$attr;
      var $36=(($35+216)|0);
      var $37=(($36+4)|0);
      var $38=HEAP32[(($37)>>2)];
      var $39=(($38+($34<<2))|0);
      var $40=HEAP32[(($39)>>2)];
      var $41=$m;
      var $42=((($40)*($41))|0);
      var $43=((($32)+($42))|0);
      var $44=((($43)+(2))|0);
      var $45=_HPDF_Stream_Seek($28, $44, 0);
      $ret=$45;
      var $46=$ret;
      var $47=(($46)|0)!=0;
      if ($47) { __label__ = 8; break; } else { __label__ = 9; break; }
    case 8: 
      var $49=$agg_result;
      var $50=$bbox;
      assert(16 % 1 === 0, 'memcpy given ' + 16 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP32[(($49)>>2)]=HEAP32[(($50)>>2)];HEAP32[((($49)+(4))>>2)]=HEAP32[((($50)+(4))>>2)];HEAP32[((($49)+(8))>>2)]=HEAP32[((($50)+(8))>>2)];HEAP32[((($49)+(12))>>2)]=HEAP32[((($50)+(12))>>2)];
      __label__ = 12; break;
    case 9: 
      var $52=$attr;
      var $53=(($52+348)|0);
      var $54=HEAP32[(($53)>>2)];
      var $55=_GetINT16($54, $i);
      var $56=$ret;
      var $57=((($56)+($55))|0);
      $ret=$57;
      var $58=HEAP16[(($i)>>1)];
      var $59=(($58 << 16) >> 16);
      var $60=((($59)*(1000))|0);
      var $61=$attr;
      var $62=(($61+160)|0);
      var $63=(($62+18)|0);
      var $64=HEAPU16[(($63)>>1)];
      var $65=(($64)&65535);
      var $66=((((($60)|0))/((($65)|0)))&-1);
      var $67=(($66)|0);
      var $68=(($bbox)|0);
      HEAPF32[(($68)>>2)]=$67;
      var $69=$attr;
      var $70=(($69+348)|0);
      var $71=HEAP32[(($70)>>2)];
      var $72=_GetINT16($71, $i);
      var $73=$ret;
      var $74=((($73)+($72))|0);
      $ret=$74;
      var $75=HEAP16[(($i)>>1)];
      var $76=(($75 << 16) >> 16);
      var $77=((($76)*(1000))|0);
      var $78=$attr;
      var $79=(($78+160)|0);
      var $80=(($79+18)|0);
      var $81=HEAPU16[(($80)>>1)];
      var $82=(($81)&65535);
      var $83=((((($77)|0))/((($82)|0)))&-1);
      var $84=(($83)|0);
      var $85=(($bbox+4)|0);
      HEAPF32[(($85)>>2)]=$84;
      var $86=$attr;
      var $87=(($86+348)|0);
      var $88=HEAP32[(($87)>>2)];
      var $89=_GetINT16($88, $i);
      var $90=$ret;
      var $91=((($90)+($89))|0);
      $ret=$91;
      var $92=HEAP16[(($i)>>1)];
      var $93=(($92 << 16) >> 16);
      var $94=((($93)*(1000))|0);
      var $95=$attr;
      var $96=(($95+160)|0);
      var $97=(($96+18)|0);
      var $98=HEAPU16[(($97)>>1)];
      var $99=(($98)&65535);
      var $100=((((($94)|0))/((($99)|0)))&-1);
      var $101=(($100)|0);
      var $102=(($bbox+8)|0);
      HEAPF32[(($102)>>2)]=$101;
      var $103=$attr;
      var $104=(($103+348)|0);
      var $105=HEAP32[(($104)>>2)];
      var $106=_GetINT16($105, $i);
      var $107=$ret;
      var $108=((($107)+($106))|0);
      $ret=$108;
      var $109=HEAP16[(($i)>>1)];
      var $110=(($109 << 16) >> 16);
      var $111=((($110)*(1000))|0);
      var $112=$attr;
      var $113=(($112+160)|0);
      var $114=(($113+18)|0);
      var $115=HEAPU16[(($114)>>1)];
      var $116=(($115)&65535);
      var $117=((((($111)|0))/((($116)|0)))&-1);
      var $118=(($117)|0);
      var $119=(($bbox+12)|0);
      HEAPF32[(($119)>>2)]=$118;
      var $120=$ret;
      var $121=(($120)|0)!=0;
      if ($121) { __label__ = 10; break; } else { __label__ = 11; break; }
    case 10: 
      _HPDF_ToBox($agg_result, 0, 0, 0, 0);
      __label__ = 12; break;
    case 11: 
      var $124=$agg_result;
      var $125=$bbox;
      assert(16 % 1 === 0, 'memcpy given ' + 16 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP32[(($124)>>2)]=HEAP32[(($125)>>2)];HEAP32[((($124)+(4))>>2)]=HEAP32[((($125)+(4))>>2)];HEAP32[((($124)+(8))>>2)]=HEAP32[((($125)+(8))>>2)];HEAP32[((($124)+(12))>>2)]=HEAP32[((($125)+(12))>>2)];
      __label__ = 12; break;
    case 12: 
      STACKTOP = __stackBase__;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_TTFontDef_GetCharBBox["X"]=1;

function _HPDF_TTFontDef_GetGlyphid($fontdef, $unicode) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $attr;
      var $pend_count;
      var $seg_count;
      var $i;
      var $idx;
      var $gid;
      $2=$fontdef;
      $3=$unicode;
      var $4=$2;
      var $5=(($4+208)|0);
      var $6=HEAP32[(($5)>>2)];
      var $7=$6;
      $attr=$7;
      var $8=$attr;
      var $9=(($8+268)|0);
      var $10=(($9+16)|0);
      var $11=HEAP32[(($10)>>2)];
      $pend_count=$11;
      var $12=$attr;
      var $13=(($12+268)|0);
      var $14=(($13+6)|0);
      var $15=HEAPU16[(($14)>>1)];
      var $16=(($15)&65535);
      var $17=((((($16)|0))/(2))&-1);
      $seg_count=$17;
      var $18=$attr;
      var $19=(($18+268)|0);
      var $20=(($19)|0);
      var $21=HEAPU16[(($20)>>1)];
      var $22=(($21)&65535);
      var $23=(($22)|0)==0;
      if ($23) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $25=$3;
      var $26=(($25)&65535);
      var $27=$26 & 255;
      var $28=(($27) & 65535);
      $3=$28;
      var $29=$3;
      var $30=(($29)&65535);
      var $31=$attr;
      var $32=(($31+268)|0);
      var $33=(($32+36)|0);
      var $34=HEAP32[(($33)>>2)];
      var $35=(($34+($30<<1))|0);
      var $36=HEAP16[(($35)>>1)];
      $1=$36;
      __label__ = 19; break;
    case 4: 
      var $38=$attr;
      var $39=(($38+268)|0);
      var $40=(($39+6)|0);
      var $41=HEAPU16[(($40)>>1)];
      var $42=(($41)&65535);
      var $43=(($42)|0)==0;
      if ($43) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $45=$2;
      var $46=(($45+136)|0);
      var $47=HEAP32[(($46)>>2)];
      var $48=_HPDF_SetError($47, 4190, 0);
      $1=0;
      __label__ = 19; break;
    case 6: 
      $i=0;
      __label__ = 7; break;
    case 7: 
      var $51=$i;
      var $52=$seg_count;
      var $53=(($51)>>>0) < (($52)>>>0);
      if ($53) { __label__ = 8; break; } else { __label__ = 12; break; }
    case 8: 
      var $55=$3;
      var $56=(($55)&65535);
      var $57=$pend_count;
      var $58=HEAPU16[(($57)>>1)];
      var $59=(($58)&65535);
      var $60=(($56)|0) <= (($59)|0);
      if ($60) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      __label__ = 12; break;
    case 10: 
      var $63=$pend_count;
      var $64=(($63+2)|0);
      $pend_count=$64;
      __label__ = 11; break;
    case 11: 
      var $66=$i;
      var $67=((($66)+(1))|0);
      $i=$67;
      __label__ = 7; break;
    case 12: 
      var $69=$i;
      var $70=$attr;
      var $71=(($70+268)|0);
      var $72=(($71+24)|0);
      var $73=HEAP32[(($72)>>2)];
      var $74=(($73+($69<<1))|0);
      var $75=HEAPU16[(($74)>>1)];
      var $76=(($75)&65535);
      var $77=$3;
      var $78=(($77)&65535);
      var $79=(($76)|0) > (($78)|0);
      if ($79) { __label__ = 13; break; } else { __label__ = 14; break; }
    case 13: 
      $1=0;
      __label__ = 19; break;
    case 14: 
      var $82=$i;
      var $83=$attr;
      var $84=(($83+268)|0);
      var $85=(($84+32)|0);
      var $86=HEAP32[(($85)>>2)];
      var $87=(($86+($82<<1))|0);
      var $88=HEAPU16[(($87)>>1)];
      var $89=(($88)&65535);
      var $90=(($89)|0)==0;
      if ($90) { __label__ = 15; break; } else { __label__ = 16; break; }
    case 15: 
      var $92=$3;
      var $93=(($92)&65535);
      var $94=$i;
      var $95=$attr;
      var $96=(($95+268)|0);
      var $97=(($96+28)|0);
      var $98=HEAP32[(($97)>>2)];
      var $99=(($98+($94<<1))|0);
      var $100=HEAP16[(($99)>>1)];
      var $101=(($100 << 16) >> 16);
      var $102=((($93)+($101))|0);
      var $103=(($102) & 65535);
      $1=$103;
      __label__ = 19; break;
    case 16: 
      var $105=$i;
      var $106=$attr;
      var $107=(($106+268)|0);
      var $108=(($107+32)|0);
      var $109=HEAP32[(($108)>>2)];
      var $110=(($109+($105<<1))|0);
      var $111=HEAPU16[(($110)>>1)];
      var $112=(($111)&65535);
      var $113=((((($112)|0))/(2))&-1);
      var $114=$3;
      var $115=(($114)&65535);
      var $116=$i;
      var $117=$attr;
      var $118=(($117+268)|0);
      var $119=(($118+24)|0);
      var $120=HEAP32[(($119)>>2)];
      var $121=(($120+($116<<1))|0);
      var $122=HEAPU16[(($121)>>1)];
      var $123=(($122)&65535);
      var $124=((($115)-($123))|0);
      var $125=((($113)+($124))|0);
      var $126=$seg_count;
      var $127=$i;
      var $128=((($126)-($127))|0);
      var $129=((($125)-($128))|0);
      $idx=$129;
      var $130=$idx;
      var $131=$attr;
      var $132=(($131+268)|0);
      var $133=(($132+40)|0);
      var $134=HEAPU32[(($133)>>2)];
      var $135=(($130)>>>0) > (($134)>>>0);
      if ($135) { __label__ = 17; break; } else { __label__ = 18; break; }
    case 17: 
      $1=0;
      __label__ = 19; break;
    case 18: 
      var $138=$idx;
      var $139=$attr;
      var $140=(($139+268)|0);
      var $141=(($140+36)|0);
      var $142=HEAP32[(($141)>>2)];
      var $143=(($142+($138<<1))|0);
      var $144=HEAPU16[(($143)>>1)];
      var $145=(($144)&65535);
      var $146=$i;
      var $147=$attr;
      var $148=(($147+268)|0);
      var $149=(($148+28)|0);
      var $150=HEAP32[(($149)>>2)];
      var $151=(($150+($146<<1))|0);
      var $152=HEAP16[(($151)>>1)];
      var $153=(($152 << 16) >> 16);
      var $154=((($145)+($153))|0);
      var $155=(($154) & 65535);
      $gid=$155;
      var $156=$gid;
      $1=$156;
      __label__ = 19; break;
    case 19: 
      var $158=$1;
      ;
      return $158;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_TTFontDef_GetGlyphid["X"]=1;

function _GetINT16($stream, $value) {
  var __stackBase__  = STACKTOP; STACKTOP += 4; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $ret;
      var $size=__stackBase__;
      $2=$stream;
      $3=$value;
      HEAP32[(($size)>>2)]=2;
      var $4=$2;
      var $5=$3;
      var $6=$5;
      var $7=_HPDF_Stream_Read($4, $6, $size);
      $ret=$7;
      var $8=$ret;
      var $9=(($8)|0)!=0;
      if ($9) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $11=$3;
      HEAP16[(($11)>>1)]=0;
      var $12=$ret;
      $1=$12;
      __label__ = 5; break;
    case 4: 
      var $14=$3;
      _INT16Swap($14);
      $1=0;
      __label__ = 5; break;
    case 5: 
      var $16=$1;
      STACKTOP = __stackBase__;
      return $16;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_TTFontDef_GetCharWidth($fontdef, $unicode) {
  var __stackBase__  = STACKTOP; STACKTOP += 4; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $advance_width;
      var $hmetrics=__stackBase__;
      var $attr;
      var $gid;
      $2=$fontdef;
      $3=$unicode;
      var $4=$2;
      var $5=(($4+208)|0);
      var $6=HEAP32[(($5)>>2)];
      var $7=$6;
      $attr=$7;
      var $8=$2;
      var $9=$3;
      var $10=_HPDF_TTFontDef_GetGlyphid($8, $9);
      $gid=$10;
      var $11=$gid;
      var $12=(($11)&65535);
      var $13=$attr;
      var $14=(($13+228)|0);
      var $15=HEAPU16[(($14)>>1)];
      var $16=(($15)&65535);
      var $17=(($12)|0) >= (($16)|0);
      if ($17) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $19=$2;
      var $20=(($19+188)|0);
      var $21=HEAP16[(($20)>>1)];
      $1=$21;
      __label__ = 9; break;
    case 4: 
      var $23=$gid;
      var $24=(($23)&65535);
      var $25=$attr;
      var $26=(($25+244)|0);
      var $27=HEAP32[(($26)>>2)];
      var $28=(($27+($24<<2))|0);
      var $29=$hmetrics;
      var $30=$28;
      assert(4 % 1 === 0, 'memcpy given ' + 4 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP16[(($29)>>1)]=HEAP16[(($30)>>1)];HEAP16[((($29)+(2))>>1)]=HEAP16[((($30)+(2))>>1)];
      var $31=$gid;
      var $32=(($31)&65535);
      var $33=$attr;
      var $34=(($33+216)|0);
      var $35=(($34+8)|0);
      var $36=HEAP32[(($35)>>2)];
      var $37=(($36+$32)|0);
      var $38=HEAP8[($37)];
      var $39=(($38 << 24) >> 24)!=0;
      if ($39) { __label__ = 8; break; } else { __label__ = 5; break; }
    case 5: 
      var $41=$gid;
      var $42=(($41)&65535);
      var $43=$attr;
      var $44=(($43+216)|0);
      var $45=(($44+8)|0);
      var $46=HEAP32[(($45)>>2)];
      var $47=(($46+$42)|0);
      HEAP8[($47)]=1;
      var $48=$attr;
      var $49=(($48+340)|0);
      var $50=HEAP32[(($49)>>2)];
      var $51=(($50)|0)!=0;
      if ($51) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      var $53=$2;
      var $54=$gid;
      var $55=_CheckCompositGryph($53, $54);
      __label__ = 7; break;
    case 7: 
      __label__ = 8; break;
    case 8: 
      var $58=(($hmetrics)|0);
      var $59=HEAPU16[(($58)>>1)];
      var $60=(($59)&65535);
      var $61=((($60)*(1000))|0);
      var $62=$attr;
      var $63=(($62+160)|0);
      var $64=(($63+18)|0);
      var $65=HEAPU16[(($64)>>1)];
      var $66=(($65)&65535);
      var $67=Math.floor(((($61)>>>0))/((($66)>>>0)));
      var $68=(($67) & 65535);
      $advance_width=$68;
      var $69=$advance_width;
      $1=$69;
      __label__ = 9; break;
    case 9: 
      var $71=$1;
      STACKTOP = __stackBase__;
      return $71;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_TTFontDef_GetCharWidth["X"]=1;

function _CheckCompositGryph($fontdef, $gid) {
  var __stackBase__  = STACKTOP; STACKTOP += 12; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $attr;
      var $offset;
      var $ret;
      var $num_of_contours=__stackBase__;
      var $flags=(__stackBase__)+(4);
      var $glyph_index=(__stackBase__)+(8);
      var $ARG_1_AND_2_ARE_WORDS;
      var $WE_HAVE_A_SCALE;
      var $MORE_COMPONENTS;
      var $WE_HAVE_AN_X_AND_Y_SCALE;
      var $WE_HAVE_A_TWO_BY_TWO;
      $2=$fontdef;
      $3=$gid;
      var $4=$2;
      var $5=(($4+208)|0);
      var $6=HEAP32[(($5)>>2)];
      var $7=$6;
      $attr=$7;
      var $8=$3;
      var $9=(($8)&65535);
      var $10=$attr;
      var $11=(($10+216)|0);
      var $12=(($11+4)|0);
      var $13=HEAP32[(($12)>>2)];
      var $14=(($13+($9<<2))|0);
      var $15=HEAP32[(($14)>>2)];
      $offset=$15;
      var $16=$attr;
      var $17=(($16+160)|0);
      var $18=(($17+50)|0);
      var $19=HEAP16[(($18)>>1)];
      var $20=(($19 << 16) >> 16);
      var $21=(($20)|0)==0;
      if ($21) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $23=$offset;
      var $24=((($23<<1))|0);
      $offset=$24;
      __label__ = 4; break;
    case 4: 
      var $26=$attr;
      var $27=(($26+216)|0);
      var $28=(($27)|0);
      var $29=HEAP32[(($28)>>2)];
      var $30=$offset;
      var $31=((($30)+($29))|0);
      $offset=$31;
      var $32=$attr;
      var $33=(($32+348)|0);
      var $34=HEAP32[(($33)>>2)];
      var $35=$offset;
      var $36=_HPDF_Stream_Seek($34, $35, 0);
      $ret=$36;
      var $37=(($36)|0)!=0;
      if ($37) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $39=$ret;
      $1=$39;
      __label__ = 45; break;
    case 6: 
      $ARG_1_AND_2_ARE_WORDS=1;
      $WE_HAVE_A_SCALE=8;
      $MORE_COMPONENTS=32;
      $WE_HAVE_AN_X_AND_Y_SCALE=64;
      $WE_HAVE_A_TWO_BY_TWO=128;
      var $41=$attr;
      var $42=(($41+348)|0);
      var $43=HEAP32[(($42)>>2)];
      var $44=_GetINT16($43, $num_of_contours);
      $ret=$44;
      var $45=(($44)|0)!=0;
      if ($45) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $47=$ret;
      $1=$47;
      __label__ = 45; break;
    case 8: 
      var $49=HEAP16[(($num_of_contours)>>1)];
      var $50=(($49 << 16) >> 16);
      var $51=(($50)|0)!=-1;
      if ($51) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      $1=0;
      __label__ = 45; break;
    case 10: 
      var $54=$attr;
      var $55=(($54+348)|0);
      var $56=HEAP32[(($55)>>2)];
      var $57=_HPDF_Stream_Seek($56, 8, 1);
      $ret=$57;
      var $58=(($57)|0)!=0;
      if ($58) { __label__ = 11; break; } else { __label__ = 12; break; }
    case 11: 
      var $60=$ret;
      $1=$60;
      __label__ = 45; break;
    case 12: 
      __label__ = 13; break;
    case 13: 
      var $63=$attr;
      var $64=(($63+348)|0);
      var $65=HEAP32[(($64)>>2)];
      var $66=_GetINT16($65, $flags);
      $ret=$66;
      var $67=(($66)|0)!=0;
      if ($67) { __label__ = 14; break; } else { __label__ = 15; break; }
    case 14: 
      var $69=$ret;
      $1=$69;
      __label__ = 45; break;
    case 15: 
      var $71=$attr;
      var $72=(($71+348)|0);
      var $73=HEAP32[(($72)>>2)];
      var $74=_GetINT16($73, $glyph_index);
      $ret=$74;
      var $75=(($74)|0)!=0;
      if ($75) { __label__ = 16; break; } else { __label__ = 17; break; }
    case 16: 
      var $77=$ret;
      $1=$77;
      __label__ = 45; break;
    case 17: 
      var $79=HEAP16[(($flags)>>1)];
      var $80=(($79 << 16) >> 16);
      var $81=$80 & 1;
      var $82=(($81)|0)!=0;
      if ($82) { __label__ = 18; break; } else { __label__ = 21; break; }
    case 18: 
      var $84=$attr;
      var $85=(($84+348)|0);
      var $86=HEAP32[(($85)>>2)];
      var $87=_HPDF_Stream_Seek($86, 4, 1);
      $ret=$87;
      var $88=(($87)|0)!=0;
      if ($88) { __label__ = 19; break; } else { __label__ = 20; break; }
    case 19: 
      var $90=$ret;
      $1=$90;
      __label__ = 45; break;
    case 20: 
      __label__ = 24; break;
    case 21: 
      var $93=$attr;
      var $94=(($93+348)|0);
      var $95=HEAP32[(($94)>>2)];
      var $96=_HPDF_Stream_Seek($95, 2, 1);
      $ret=$96;
      var $97=(($96)|0)!=0;
      if ($97) { __label__ = 22; break; } else { __label__ = 23; break; }
    case 22: 
      var $99=$ret;
      $1=$99;
      __label__ = 45; break;
    case 23: 
      __label__ = 24; break;
    case 24: 
      var $102=HEAP16[(($flags)>>1)];
      var $103=(($102 << 16) >> 16);
      var $104=$103 & 8;
      var $105=(($104)|0)!=0;
      if ($105) { __label__ = 25; break; } else { __label__ = 28; break; }
    case 25: 
      var $107=$attr;
      var $108=(($107+348)|0);
      var $109=HEAP32[(($108)>>2)];
      var $110=_HPDF_Stream_Seek($109, 2, 1);
      $ret=$110;
      var $111=(($110)|0)!=0;
      if ($111) { __label__ = 26; break; } else { __label__ = 27; break; }
    case 26: 
      var $113=$ret;
      $1=$113;
      __label__ = 45; break;
    case 27: 
      __label__ = 38; break;
    case 28: 
      var $116=HEAP16[(($flags)>>1)];
      var $117=(($116 << 16) >> 16);
      var $118=$117 & 64;
      var $119=(($118)|0)!=0;
      if ($119) { __label__ = 29; break; } else { __label__ = 32; break; }
    case 29: 
      var $121=$attr;
      var $122=(($121+348)|0);
      var $123=HEAP32[(($122)>>2)];
      var $124=_HPDF_Stream_Seek($123, 4, 1);
      $ret=$124;
      var $125=(($124)|0)!=0;
      if ($125) { __label__ = 30; break; } else { __label__ = 31; break; }
    case 30: 
      var $127=$ret;
      $1=$127;
      __label__ = 45; break;
    case 31: 
      __label__ = 37; break;
    case 32: 
      var $130=HEAP16[(($flags)>>1)];
      var $131=(($130 << 16) >> 16);
      var $132=$131 & 128;
      var $133=(($132)|0)!=0;
      if ($133) { __label__ = 33; break; } else { __label__ = 36; break; }
    case 33: 
      var $135=$attr;
      var $136=(($135+348)|0);
      var $137=HEAP32[(($136)>>2)];
      var $138=_HPDF_Stream_Seek($137, 8, 1);
      $ret=$138;
      var $139=(($138)|0)!=0;
      if ($139) { __label__ = 34; break; } else { __label__ = 35; break; }
    case 34: 
      var $141=$ret;
      $1=$141;
      __label__ = 45; break;
    case 35: 
      __label__ = 36; break;
    case 36: 
      __label__ = 37; break;
    case 37: 
      __label__ = 38; break;
    case 38: 
      var $146=HEAP16[(($glyph_index)>>1)];
      var $147=(($146 << 16) >> 16);
      var $148=(($147)|0) > 0;
      if ($148) { __label__ = 39; break; } else { __label__ = 41; break; }
    case 39: 
      var $150=HEAP16[(($glyph_index)>>1)];
      var $151=(($150 << 16) >> 16);
      var $152=$attr;
      var $153=(($152+228)|0);
      var $154=HEAPU16[(($153)>>1)];
      var $155=(($154)&65535);
      var $156=(($151)|0) < (($155)|0);
      if ($156) { __label__ = 40; break; } else { __label__ = 41; break; }
    case 40: 
      var $158=HEAP16[(($glyph_index)>>1)];
      var $159=(($158 << 16) >> 16);
      var $160=$attr;
      var $161=(($160+216)|0);
      var $162=(($161+8)|0);
      var $163=HEAP32[(($162)>>2)];
      var $164=(($163+$159)|0);
      HEAP8[($164)]=1;
      __label__ = 41; break;
    case 41: 
      __label__ = 42; break;
    case 42: 
      var $167=HEAP16[(($flags)>>1)];
      var $168=(($167 << 16) >> 16);
      var $169=$168 & 32;
      var $170=(($169)|0)!=0;
      if ($170) { __label__ = 13; break; } else { __label__ = 43; break; }
    case 43: 
      __label__ = 44; break;
    case 44: 
      $1=0;
      __label__ = 45; break;
    case 45: 
      var $174=$1;
      STACKTOP = __stackBase__;
      return $174;
    default: assert(0, "bad label: " + __label__);
  }
}
_CheckCompositGryph["X"]=1;

function _HPDF_TTFontDef_GetGidWidth($fontdef, $gid) {
  var __stackBase__  = STACKTOP; STACKTOP += 4; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $advance_width;
      var $hmetrics=__stackBase__;
      var $attr;
      $2=$fontdef;
      $3=$gid;
      var $4=$2;
      var $5=(($4+208)|0);
      var $6=HEAP32[(($5)>>2)];
      var $7=$6;
      $attr=$7;
      var $8=$3;
      var $9=(($8)&65535);
      var $10=$attr;
      var $11=(($10+228)|0);
      var $12=HEAPU16[(($11)>>1)];
      var $13=(($12)&65535);
      var $14=(($9)|0) >= (($13)|0);
      if ($14) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $16=$2;
      var $17=(($16+188)|0);
      var $18=HEAP16[(($17)>>1)];
      $1=$18;
      __label__ = 5; break;
    case 4: 
      var $20=$3;
      var $21=(($20)&65535);
      var $22=$attr;
      var $23=(($22+244)|0);
      var $24=HEAP32[(($23)>>2)];
      var $25=(($24+($21<<2))|0);
      var $26=$hmetrics;
      var $27=$25;
      assert(4 % 1 === 0, 'memcpy given ' + 4 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP16[(($26)>>1)]=HEAP16[(($27)>>1)];HEAP16[((($26)+(2))>>1)]=HEAP16[((($27)+(2))>>1)];
      var $28=(($hmetrics)|0);
      var $29=HEAPU16[(($28)>>1)];
      var $30=(($29)&65535);
      var $31=((($30)*(1000))|0);
      var $32=$attr;
      var $33=(($32+160)|0);
      var $34=(($33+18)|0);
      var $35=HEAPU16[(($34)>>1)];
      var $36=(($35)&65535);
      var $37=Math.floor(((($31)>>>0))/((($36)>>>0)));
      var $38=(($37) & 65535);
      $advance_width=$38;
      var $39=$advance_width;
      $1=$39;
      __label__ = 5; break;
    case 5: 
      var $41=$1;
      STACKTOP = __stackBase__;
      return $41;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_TTFontDef_GetGidWidth["X"]=1;

function _HPDF_TTFontDef_SaveFontData($fontdef, $stream) {
  var __stackBase__  = STACKTOP; STACKTOP += 256; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $attr;
      var $tmp_tbl=__stackBase__;
      var $tmp_stream;
      var $new_offsets;
      var $i;
      var $check_sum_ptr=(__stackBase__)+(208);
      var $ret;
      var $offset_base;
      var $tmp_check_sum=(__stackBase__)+(212);
      var $tbl;
      var $length;
      var $new_offset;
      var $poffset;
      var $value=(__stackBase__)+(216);
      var $j;
      var $size=(__stackBase__)+(220);
      var $tbl1=(__stackBase__)+(224);
      var $buf=(__stackBase__)+(240);
      var $length2;
      var $rlen=(__stackBase__)+(244);
      var $buf3=(__stackBase__)+(248);
      var $siz=(__stackBase__)+(252);
      $2=$fontdef;
      $3=$stream;
      var $4=$2;
      var $5=(($4+208)|0);
      var $6=HEAP32[(($5)>>2)];
      var $7=$6;
      $attr=$7;
      HEAP32[(($tmp_check_sum)>>2)]=-1313820742;
      var $8=$3;
      var $9=$attr;
      var $10=(($9+252)|0);
      var $11=(($10)|0);
      var $12=HEAP32[(($11)>>2)];
      var $13=_WriteUINT32($8, $12);
      $ret=$13;
      var $14=$3;
      var $15=_WriteUINT16($14, 13);
      var $16=$ret;
      var $17=((($16)+($15))|0);
      $ret=$17;
      var $18=$3;
      var $19=$attr;
      var $20=(($19+252)|0);
      var $21=(($20+6)|0);
      var $22=HEAP16[(($21)>>1)];
      var $23=_WriteUINT16($18, $22);
      var $24=$ret;
      var $25=((($24)+($23))|0);
      $ret=$25;
      var $26=$3;
      var $27=$attr;
      var $28=(($27+252)|0);
      var $29=(($28+8)|0);
      var $30=HEAP16[(($29)>>1)];
      var $31=_WriteUINT16($26, $30);
      var $32=$ret;
      var $33=((($32)+($31))|0);
      $ret=$33;
      var $34=$3;
      var $35=$attr;
      var $36=(($35+252)|0);
      var $37=(($36+10)|0);
      var $38=HEAP16[(($37)>>1)];
      var $39=_WriteUINT16($34, $38);
      var $40=$ret;
      var $41=((($40)+($39))|0);
      $ret=$41;
      var $42=$ret;
      var $43=(($42)|0)!=0;
      if ($43) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $45=$2;
      var $46=(($45+136)|0);
      var $47=HEAP32[(($46)>>2)];
      var $48=_HPDF_Error_GetCode($47);
      $1=$48;
      __label__ = 81; break;
    case 4: 
      var $50=$2;
      var $51=(($50+132)|0);
      var $52=HEAP32[(($51)>>2)];
      var $53=_HPDF_MemStream_New($52, 4096);
      $tmp_stream=$53;
      var $54=$tmp_stream;
      var $55=(($54)|0)!=0;
      if ($55) { __label__ = 6; break; } else { __label__ = 5; break; }
    case 5: 
      var $57=$2;
      var $58=(($57+136)|0);
      var $59=HEAP32[(($58)>>2)];
      var $60=_HPDF_Error_GetCode($59);
      $1=$60;
      __label__ = 81; break;
    case 6: 
      $offset_base=220;
      var $62=$2;
      var $63=(($62+132)|0);
      var $64=HEAP32[(($63)>>2)];
      var $65=$attr;
      var $66=(($65+228)|0);
      var $67=HEAPU16[(($66)>>1)];
      var $68=(($67)&65535);
      var $69=((($68)+(1))|0);
      var $70=((($69<<2))|0);
      var $71=_HPDF_GetMem($64, $70);
      var $72=$71;
      $new_offsets=$72;
      var $73=$new_offsets;
      var $74=(($73)|0)!=0;
      if ($74) { __label__ = 8; break; } else { __label__ = 7; break; }
    case 7: 
      var $76=$tmp_stream;
      _HPDF_Stream_Free($76);
      var $77=$2;
      var $78=(($77+136)|0);
      var $79=HEAP32[(($78)>>2)];
      var $80=_HPDF_Error_GetCode($79);
      $1=$80;
      __label__ = 81; break;
    case 8: 
      $i=0;
      __label__ = 9; break;
    case 9: 
      var $83=$i;
      var $84=(($83)>>>0) < 13;
      if ($84) { __label__ = 10; break; } else { __label__ = 44; break; }
    case 10: 
      var $86=$2;
      var $87=$i;
      var $88=((_REQUIRED_TAGS+($87<<2))|0);
      var $89=HEAP32[(($88)>>2)];
      var $90=_FindTable($86, $89);
      $tbl=$90;
      var $91=$tbl;
      var $92=(($91)|0)!=0;
      if ($92) { __label__ = 12; break; } else { __label__ = 11; break; }
    case 11: 
      var $94=$2;
      var $95=(($94+136)|0);
      var $96=HEAP32[(($95)>>2)];
      var $97=$i;
      var $98=_HPDF_SetError($96, 4192, $97);
      $ret=$98;
      __label__ = 80; break;
    case 12: 
      var $100=$attr;
      var $101=(($100+348)|0);
      var $102=HEAP32[(($101)>>2)];
      var $103=$tbl;
      var $104=(($103+8)|0);
      var $105=HEAP32[(($104)>>2)];
      var $106=_HPDF_Stream_Seek($102, $105, 0);
      $ret=$106;
      var $107=$ret;
      var $108=(($107)|0)!=0;
      if ($108) { __label__ = 13; break; } else { __label__ = 14; break; }
    case 13: 
      __label__ = 80; break;
    case 14: 
      var $111=$tbl;
      var $112=(($111+12)|0);
      var $113=HEAP32[(($112)>>2)];
      $length=$113;
      var $114=$tmp_stream;
      var $115=(($114+16)|0);
      var $116=HEAP32[(($115)>>2)];
      $new_offset=$116;
      var $117=$tbl;
      var $118=(($117)|0);
      var $119=(($118)|0);
      var $120=_HPDF_MemCmp($119, ((STRING_TABLE.__str1304)|0), 4);
      var $121=(($120)|0)==0;
      if ($121) { __label__ = 15; break; } else { __label__ = 16; break; }
    case 15: 
      var $123=$2;
      var $124=$tmp_stream;
      var $125=_WriteHeader1333($123, $124, $check_sum_ptr);
      $ret=$125;
      __label__ = 40; break;
    case 16: 
      var $127=$tbl;
      var $128=(($127)|0);
      var $129=(($128)|0);
      var $130=_HPDF_MemCmp($129, ((STRING_TABLE.__str11305)|0), 4);
      var $131=(($130)|0)==0;
      if ($131) { __label__ = 17; break; } else { __label__ = 18; break; }
    case 17: 
      var $133=$2;
      var $134=$new_offsets;
      var $135=$tmp_stream;
      var $136=_RecreateGLYF($133, $134, $135);
      $ret=$136;
      __label__ = 39; break;
    case 18: 
      var $138=$tbl;
      var $139=(($138)|0);
      var $140=(($139)|0);
      var $141=_HPDF_MemCmp($140, ((STRING_TABLE.__str21306)|0), 4);
      var $142=(($141)|0)==0;
      if ($142) { __label__ = 19; break; } else { __label__ = 31; break; }
    case 19: 
      var $144=$value;
      var $145=_HPDF_MemSet($144, 0, 4);
      var $146=$new_offsets;
      $poffset=$146;
      var $147=$attr;
      var $148=(($147+160)|0);
      var $149=(($148+50)|0);
      var $150=HEAP16[(($149)>>1)];
      var $151=(($150 << 16) >> 16);
      var $152=(($151)|0)==0;
      if ($152) { __label__ = 20; break; } else { __label__ = 25; break; }
    case 20: 
      $j=0;
      __label__ = 21; break;
    case 21: 
      var $155=$j;
      var $156=$attr;
      var $157=(($156+228)|0);
      var $158=HEAPU16[(($157)>>1)];
      var $159=(($158)&65535);
      var $160=(($155)>>>0) <= (($159)>>>0);
      if ($160) { __label__ = 22; break; } else { __label__ = 24; break; }
    case 22: 
      var $162=$tmp_stream;
      var $163=$poffset;
      var $164=HEAP32[(($163)>>2)];
      var $165=(($164) & 65535);
      var $166=_WriteUINT16($162, $165);
      var $167=$ret;
      var $168=((($167)+($166))|0);
      $ret=$168;
      var $169=$poffset;
      var $170=(($169+4)|0);
      $poffset=$170;
      __label__ = 23; break;
    case 23: 
      var $172=$j;
      var $173=((($172)+(1))|0);
      $j=$173;
      __label__ = 21; break;
    case 24: 
      __label__ = 30; break;
    case 25: 
      $j=0;
      __label__ = 26; break;
    case 26: 
      var $177=$j;
      var $178=$attr;
      var $179=(($178+228)|0);
      var $180=HEAPU16[(($179)>>1)];
      var $181=(($180)&65535);
      var $182=(($177)>>>0) <= (($181)>>>0);
      if ($182) { __label__ = 27; break; } else { __label__ = 29; break; }
    case 27: 
      var $184=$tmp_stream;
      var $185=$poffset;
      var $186=HEAP32[(($185)>>2)];
      var $187=_WriteUINT32($184, $186);
      var $188=$ret;
      var $189=((($188)+($187))|0);
      $ret=$189;
      var $190=$poffset;
      var $191=(($190+4)|0);
      $poffset=$191;
      __label__ = 28; break;
    case 28: 
      var $193=$j;
      var $194=((($193)+(1))|0);
      $j=$194;
      __label__ = 26; break;
    case 29: 
      __label__ = 30; break;
    case 30: 
      __label__ = 38; break;
    case 31: 
      var $198=$tbl;
      var $199=(($198)|0);
      var $200=(($199)|0);
      var $201=_HPDF_MemCmp($200, ((STRING_TABLE.__str31307)|0), 4);
      var $202=(($201)|0)==0;
      if ($202) { __label__ = 32; break; } else { __label__ = 33; break; }
    case 32: 
      var $204=$2;
      var $205=$tmp_stream;
      var $206=_RecreateName($204, $205);
      $ret=$206;
      __label__ = 37; break;
    case 33: 
      HEAP32[(($size)>>2)]=4;
      __label__ = 34; break;
    case 34: 
      var $209=$length;
      var $210=(($209)>>>0) > 4;
      if ($210) { __label__ = 35; break; } else { __label__ = 36; break; }
    case 35: 
      HEAP32[(($value)>>2)]=0;
      HEAP32[(($size)>>2)]=4;
      var $212=$attr;
      var $213=(($212+348)|0);
      var $214=HEAP32[(($213)>>2)];
      var $215=$value;
      var $216=_HPDF_Stream_Read($214, $215, $size);
      $ret=$216;
      var $217=$tmp_stream;
      var $218=$value;
      var $219=HEAP32[(($size)>>2)];
      var $220=_HPDF_Stream_Write($217, $218, $219);
      var $221=$ret;
      var $222=((($221)+($220))|0);
      $ret=$222;
      var $223=$length;
      var $224=((($223)-(4))|0);
      $length=$224;
      __label__ = 34; break;
    case 36: 
      HEAP32[(($value)>>2)]=0;
      var $226=$length;
      HEAP32[(($size)>>2)]=$226;
      var $227=$attr;
      var $228=(($227+348)|0);
      var $229=HEAP32[(($228)>>2)];
      var $230=$value;
      var $231=_HPDF_Stream_Read($229, $230, $size);
      var $232=$ret;
      var $233=((($232)+($231))|0);
      $ret=$233;
      var $234=$tmp_stream;
      var $235=$value;
      var $236=HEAP32[(($size)>>2)];
      var $237=_HPDF_Stream_Write($234, $235, $236);
      var $238=$ret;
      var $239=((($238)+($237))|0);
      $ret=$239;
      __label__ = 37; break;
    case 37: 
      __label__ = 38; break;
    case 38: 
      __label__ = 39; break;
    case 39: 
      __label__ = 40; break;
    case 40: 
      var $244=$new_offset;
      var $245=$i;
      var $246=(($tmp_tbl+($245<<4))|0);
      var $247=(($246+8)|0);
      HEAP32[(($247)>>2)]=$244;
      var $248=$tmp_stream;
      var $249=(($248+16)|0);
      var $250=HEAP32[(($249)>>2)];
      var $251=$new_offset;
      var $252=((($250)-($251))|0);
      var $253=$i;
      var $254=(($tmp_tbl+($253<<4))|0);
      var $255=(($254+12)|0);
      HEAP32[(($255)>>2)]=$252;
      var $256=$ret;
      var $257=(($256)|0)!=0;
      if ($257) { __label__ = 41; break; } else { __label__ = 42; break; }
    case 41: 
      __label__ = 80; break;
    case 42: 
      __label__ = 43; break;
    case 43: 
      var $261=$i;
      var $262=((($261)+(1))|0);
      $i=$262;
      __label__ = 9; break;
    case 44: 
      $i=0;
      __label__ = 45; break;
    case 45: 
      var $265=$i;
      var $266=(($265)>>>0) < 13;
      if ($266) { __label__ = 46; break; } else { __label__ = 62; break; }
    case 46: 
      var $268=$i;
      var $269=(($tmp_tbl+($268<<4))|0);
      var $270=$tbl1;
      var $271=$269;
      assert(16 % 1 === 0, 'memcpy given ' + 16 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP32[(($270)>>2)]=HEAP32[(($271)>>2)];HEAP32[((($270)+(4))>>2)]=HEAP32[((($271)+(4))>>2)];HEAP32[((($270)+(8))>>2)]=HEAP32[((($271)+(8))>>2)];HEAP32[((($270)+(12))>>2)]=HEAP32[((($271)+(12))>>2)];
      var $272=(($tbl1+12)|0);
      var $273=HEAP32[(($272)>>2)];
      $length2=$273;
      var $274=$tmp_stream;
      var $275=(($tbl1+8)|0);
      var $276=HEAP32[(($275)>>2)];
      var $277=_HPDF_Stream_Seek($274, $276, 0);
      $ret=$277;
      var $278=(($277)|0)!=0;
      if ($278) { __label__ = 47; break; } else { __label__ = 48; break; }
    case 47: 
      __label__ = 62; break;
    case 48: 
      var $281=(($tbl1+4)|0);
      HEAP32[(($281)>>2)]=0;
      __label__ = 49; break;
    case 49: 
      var $283=$length2;
      var $284=(($283)>>>0) > 0;
      if ($284) { __label__ = 50; break; } else { __label__ = 56; break; }
    case 50: 
      var $286=$length2;
      var $287=(($286)>>>0) > 4;
      if ($287) { __label__ = 51; break; } else { __label__ = 52; break; }
    case 51: 
      var $292 = 4;__label__ = 53; break;
    case 52: 
      var $290=$length2;
      var $292 = $290;__label__ = 53; break;
    case 53: 
      var $292;
      HEAP32[(($rlen)>>2)]=$292;
      HEAP32[(($buf)>>2)]=0;
      var $293=$tmp_stream;
      var $294=$buf;
      var $295=_HPDF_Stream_Read($293, $294, $rlen);
      $ret=$295;
      var $296=(($295)|0)!=0;
      if ($296) { __label__ = 54; break; } else { __label__ = 55; break; }
    case 54: 
      __label__ = 56; break;
    case 55: 
      _UINT32Swap($buf);
      var $299=HEAP32[(($buf)>>2)];
      var $300=(($tbl1+4)|0);
      var $301=HEAP32[(($300)>>2)];
      var $302=((($301)+($299))|0);
      HEAP32[(($300)>>2)]=$302;
      var $303=HEAP32[(($rlen)>>2)];
      var $304=$length2;
      var $305=((($304)-($303))|0);
      $length2=$305;
      __label__ = 49; break;
    case 56: 
      var $307=$ret;
      var $308=(($307)|0)!=0;
      if ($308) { __label__ = 57; break; } else { __label__ = 58; break; }
    case 57: 
      __label__ = 62; break;
    case 58: 
      var $311=$3;
      var $312=$i;
      var $313=((_REQUIRED_TAGS+($312<<2))|0);
      var $314=HEAP32[(($313)>>2)];
      var $315=_HPDF_Stream_Write($311, $314, 4);
      var $316=$ret;
      var $317=((($316)+($315))|0);
      $ret=$317;
      var $318=$3;
      var $319=(($tbl1+4)|0);
      var $320=HEAP32[(($319)>>2)];
      var $321=_WriteUINT32($318, $320);
      var $322=$ret;
      var $323=((($322)+($321))|0);
      $ret=$323;
      var $324=$offset_base;
      var $325=(($tbl1+8)|0);
      var $326=HEAP32[(($325)>>2)];
      var $327=((($326)+($324))|0);
      HEAP32[(($325)>>2)]=$327;
      var $328=$3;
      var $329=(($tbl1+8)|0);
      var $330=HEAP32[(($329)>>2)];
      var $331=_WriteUINT32($328, $330);
      var $332=$ret;
      var $333=((($332)+($331))|0);
      $ret=$333;
      var $334=$3;
      var $335=(($tbl1+12)|0);
      var $336=HEAP32[(($335)>>2)];
      var $337=_WriteUINT32($334, $336);
      var $338=$ret;
      var $339=((($338)+($337))|0);
      $ret=$339;
      var $340=$ret;
      var $341=(($340)|0)!=0;
      if ($341) { __label__ = 59; break; } else { __label__ = 60; break; }
    case 59: 
      __label__ = 62; break;
    case 60: 
      __label__ = 61; break;
    case 61: 
      var $345=$i;
      var $346=((($345)+(1))|0);
      $i=$346;
      __label__ = 45; break;
    case 62: 
      var $348=$ret;
      var $349=(($348)|0)!=0;
      if ($349) { __label__ = 63; break; } else { __label__ = 64; break; }
    case 63: 
      __label__ = 80; break;
    case 64: 
      var $352=$tmp_stream;
      var $353=_HPDF_Stream_Seek($352, 0, 0);
      $ret=$353;
      var $354=$ret;
      var $355=(($354)|0)!=0;
      if ($355) { __label__ = 65; break; } else { __label__ = 66; break; }
    case 65: 
      __label__ = 80; break;
    case 66: 
      __label__ = 67; break;
    case 67: 
      HEAP32[(($siz)>>2)]=4;
      var $359=$tmp_stream;
      var $360=$buf3;
      var $361=_HPDF_Stream_Read($359, $360, $siz);
      $ret=$361;
      var $362=$ret;
      var $363=(($362)|0)!=0;
      if ($363) { __label__ = 69; break; } else { __label__ = 68; break; }
    case 68: 
      var $365=HEAPU32[(($siz)>>2)];
      var $366=(($365)>>>0) <= 0;
      if ($366) { __label__ = 69; break; } else { __label__ = 72; break; }
    case 69: 
      var $368=$ret;
      var $369=(($368)|0)==4184;
      if ($369) { __label__ = 70; break; } else { __label__ = 71; break; }
    case 70: 
      $ret=0;
      __label__ = 71; break;
    case 71: 
      __label__ = 73; break;
    case 72: 
      _UINT32Swap($buf3);
      var $373=HEAP32[(($buf3)>>2)];
      var $374=HEAP32[(($tmp_check_sum)>>2)];
      var $375=((($374)-($373))|0);
      HEAP32[(($tmp_check_sum)>>2)]=$375;
      __label__ = 67; break;
    case 73: 
      var $377=$ret;
      var $378=(($377)|0)!=0;
      if ($378) { __label__ = 74; break; } else { __label__ = 75; break; }
    case 74: 
      __label__ = 80; break;
    case 75: 
      _UINT32Swap($tmp_check_sum);
      var $381=$tmp_stream;
      var $382=HEAP32[(($check_sum_ptr)>>2)];
      var $383=_HPDF_Stream_Seek($381, $382, 0);
      $ret=$383;
      var $384=$ret;
      var $385=(($384)|0)==0;
      if ($385) { __label__ = 76; break; } else { __label__ = 77; break; }
    case 76: 
      var $387=$tmp_stream;
      var $388=$tmp_check_sum;
      var $389=_HPDF_MemStream_Rewrite($387, $388, 4);
      $ret=$389;
      __label__ = 77; break;
    case 77: 
      var $391=$ret;
      var $392=(($391)|0)!=0;
      if ($392) { __label__ = 78; break; } else { __label__ = 79; break; }
    case 78: 
      __label__ = 80; break;
    case 79: 
      var $395=$tmp_stream;
      var $396=(($395+16)|0);
      var $397=HEAP32[(($396)>>2)];
      var $398=$offset_base;
      var $399=((($397)+($398))|0);
      var $400=$attr;
      var $401=(($400+336)|0);
      HEAP32[(($401)>>2)]=$399;
      var $402=$tmp_stream;
      var $403=$3;
      var $404=_HPDF_Stream_WriteToStream($402, $403, 0, 0);
      $ret=$404;
      __label__ = 80; break;
    case 80: 
      var $406=$2;
      var $407=(($406+132)|0);
      var $408=HEAP32[(($407)>>2)];
      var $409=$new_offsets;
      var $410=$409;
      _HPDF_FreeMem($408, $410);
      var $411=$tmp_stream;
      _HPDF_Stream_Free($411);
      var $412=$ret;
      $1=$412;
      __label__ = 81; break;
    case 81: 
      var $414=$1;
      STACKTOP = __stackBase__;
      return $414;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_TTFontDef_SaveFontData["X"]=1;

function _WriteUINT32($stream, $value) {
  var __stackBase__  = STACKTOP; STACKTOP += 4; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $ret;
      var $tmp=__stackBase__;
      $2=$stream;
      $3=$value;
      var $4=$3;
      HEAP32[(($tmp)>>2)]=$4;
      _UINT32Swap($tmp);
      var $5=$2;
      var $6=$tmp;
      var $7=_HPDF_Stream_Write($5, $6, 4);
      $ret=$7;
      var $8=$ret;
      var $9=(($8)|0)!=0;
      if ($9) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $11=$ret;
      $1=$11;
      __label__ = 5; break;
    case 4: 
      $1=0;
      __label__ = 5; break;
    case 5: 
      var $14=$1;
      STACKTOP = __stackBase__;
      return $14;
    default: assert(0, "bad label: " + __label__);
  }
}


function _WriteUINT16($stream, $value) {
  var __stackBase__  = STACKTOP; STACKTOP += 4; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $ret;
      var $tmp=__stackBase__;
      $2=$stream;
      $3=$value;
      var $4=$3;
      HEAP16[(($tmp)>>1)]=$4;
      _UINT16Swap($tmp);
      var $5=$2;
      var $6=$tmp;
      var $7=_HPDF_Stream_Write($5, $6, 2);
      $ret=$7;
      var $8=$ret;
      var $9=(($8)|0)!=0;
      if ($9) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $11=$ret;
      $1=$11;
      __label__ = 5; break;
    case 4: 
      $1=0;
      __label__ = 5; break;
    case 5: 
      var $14=$1;
      STACKTOP = __stackBase__;
      return $14;
    default: assert(0, "bad label: " + __label__);
  }
}


function _FindTable($fontdef, $tag) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $attr;
      var $tbl;
      var $i;
      $2=$fontdef;
      $3=$tag;
      var $4=$2;
      var $5=(($4+208)|0);
      var $6=HEAP32[(($5)>>2)];
      var $7=$6;
      $attr=$7;
      var $8=$attr;
      var $9=(($8+252)|0);
      var $10=(($9+12)|0);
      var $11=HEAP32[(($10)>>2)];
      $tbl=$11;
      $i=0;
      __label__ = 3; break;
    case 3: 
      var $13=$i;
      var $14=$attr;
      var $15=(($14+252)|0);
      var $16=(($15+4)|0);
      var $17=HEAPU16[(($16)>>1)];
      var $18=(($17)&65535);
      var $19=(($13)>>>0) < (($18)>>>0);
      if ($19) { __label__ = 4; break; } else { __label__ = 8; break; }
    case 4: 
      var $21=$tbl;
      var $22=(($21)|0);
      var $23=(($22)|0);
      var $24=$3;
      var $25=_HPDF_MemCmp($23, $24, 4);
      var $26=(($25)|0)==0;
      if ($26) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $28=$tbl;
      $1=$28;
      __label__ = 9; break;
    case 6: 
      __label__ = 7; break;
    case 7: 
      var $31=$i;
      var $32=((($31)+(1))|0);
      $i=$32;
      var $33=$tbl;
      var $34=(($33+16)|0);
      $tbl=$34;
      __label__ = 3; break;
    case 8: 
      $1=0;
      __label__ = 9; break;
    case 9: 
      var $37=$1;
      ;
      return $37;
    default: assert(0, "bad label: " + __label__);
  }
}
_FindTable["X"]=1;

function _WriteHeader1333($fontdef, $stream, $check_sum_ptr) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $attr;
      var $ret;
      $2=$fontdef;
      $3=$stream;
      $4=$check_sum_ptr;
      var $5=$2;
      var $6=(($5+208)|0);
      var $7=HEAP32[(($6)>>2)];
      var $8=$7;
      $attr=$8;
      $ret=0;
      var $9=$3;
      var $10=$attr;
      var $11=(($10+160)|0);
      var $12=(($11)|0);
      var $13=(($12)|0);
      var $14=_HPDF_Stream_Write($9, $13, 4);
      var $15=$ret;
      var $16=((($15)+($14))|0);
      $ret=$16;
      var $17=$3;
      var $18=$attr;
      var $19=(($18+160)|0);
      var $20=(($19+4)|0);
      var $21=HEAP32[(($20)>>2)];
      var $22=_WriteUINT32($17, $21);
      var $23=$ret;
      var $24=((($23)+($22))|0);
      $ret=$24;
      var $25=$3;
      var $26=(($25+16)|0);
      var $27=HEAP32[(($26)>>2)];
      var $28=$4;
      HEAP32[(($28)>>2)]=$27;
      var $29=$3;
      var $30=_WriteUINT32($29, 0);
      var $31=$ret;
      var $32=((($31)+($30))|0);
      $ret=$32;
      var $33=$3;
      var $34=$attr;
      var $35=(($34+160)|0);
      var $36=(($35+12)|0);
      var $37=HEAP32[(($36)>>2)];
      var $38=_WriteUINT32($33, $37);
      var $39=$ret;
      var $40=((($39)+($38))|0);
      $ret=$40;
      var $41=$3;
      var $42=$attr;
      var $43=(($42+160)|0);
      var $44=(($43+16)|0);
      var $45=HEAP16[(($44)>>1)];
      var $46=_WriteUINT16($41, $45);
      var $47=$ret;
      var $48=((($47)+($46))|0);
      $ret=$48;
      var $49=$3;
      var $50=$attr;
      var $51=(($50+160)|0);
      var $52=(($51+18)|0);
      var $53=HEAP16[(($52)>>1)];
      var $54=_WriteUINT16($49, $53);
      var $55=$ret;
      var $56=((($55)+($54))|0);
      $ret=$56;
      var $57=$3;
      var $58=$attr;
      var $59=(($58+160)|0);
      var $60=(($59+20)|0);
      var $61=(($60)|0);
      var $62=_HPDF_Stream_Write($57, $61, 8);
      var $63=$ret;
      var $64=((($63)+($62))|0);
      $ret=$64;
      var $65=$3;
      var $66=$attr;
      var $67=(($66+160)|0);
      var $68=(($67+28)|0);
      var $69=(($68)|0);
      var $70=_HPDF_Stream_Write($65, $69, 8);
      var $71=$ret;
      var $72=((($71)+($70))|0);
      $ret=$72;
      var $73=$3;
      var $74=$attr;
      var $75=(($74+160)|0);
      var $76=(($75+36)|0);
      var $77=HEAP16[(($76)>>1)];
      var $78=_WriteINT16($73, $77);
      var $79=$ret;
      var $80=((($79)+($78))|0);
      $ret=$80;
      var $81=$3;
      var $82=$attr;
      var $83=(($82+160)|0);
      var $84=(($83+38)|0);
      var $85=HEAP16[(($84)>>1)];
      var $86=_WriteINT16($81, $85);
      var $87=$ret;
      var $88=((($87)+($86))|0);
      $ret=$88;
      var $89=$3;
      var $90=$attr;
      var $91=(($90+160)|0);
      var $92=(($91+40)|0);
      var $93=HEAP16[(($92)>>1)];
      var $94=_WriteINT16($89, $93);
      var $95=$ret;
      var $96=((($95)+($94))|0);
      $ret=$96;
      var $97=$3;
      var $98=$attr;
      var $99=(($98+160)|0);
      var $100=(($99+42)|0);
      var $101=HEAP16[(($100)>>1)];
      var $102=_WriteINT16($97, $101);
      var $103=$ret;
      var $104=((($103)+($102))|0);
      $ret=$104;
      var $105=$3;
      var $106=$attr;
      var $107=(($106+160)|0);
      var $108=(($107+44)|0);
      var $109=HEAP16[(($108)>>1)];
      var $110=_WriteUINT16($105, $109);
      var $111=$ret;
      var $112=((($111)+($110))|0);
      $ret=$112;
      var $113=$3;
      var $114=$attr;
      var $115=(($114+160)|0);
      var $116=(($115+46)|0);
      var $117=HEAP16[(($116)>>1)];
      var $118=_WriteUINT16($113, $117);
      var $119=$ret;
      var $120=((($119)+($118))|0);
      $ret=$120;
      var $121=$3;
      var $122=$attr;
      var $123=(($122+160)|0);
      var $124=(($123+48)|0);
      var $125=HEAP16[(($124)>>1)];
      var $126=_WriteINT16($121, $125);
      var $127=$ret;
      var $128=((($127)+($126))|0);
      $ret=$128;
      var $129=$3;
      var $130=$attr;
      var $131=(($130+160)|0);
      var $132=(($131+50)|0);
      var $133=HEAP16[(($132)>>1)];
      var $134=_WriteINT16($129, $133);
      var $135=$ret;
      var $136=((($135)+($134))|0);
      $ret=$136;
      var $137=$3;
      var $138=$attr;
      var $139=(($138+160)|0);
      var $140=(($139+52)|0);
      var $141=HEAP16[(($140)>>1)];
      var $142=_WriteINT16($137, $141);
      var $143=$ret;
      var $144=((($143)+($142))|0);
      $ret=$144;
      var $145=$ret;
      var $146=(($145)|0)!=0;
      if ($146) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $148=$2;
      var $149=(($148+136)|0);
      var $150=HEAP32[(($149)>>2)];
      var $151=_HPDF_Error_GetCode($150);
      $1=$151;
      __label__ = 5; break;
    case 4: 
      $1=0;
      __label__ = 5; break;
    case 5: 
      var $154=$1;
      ;
      return $154;
    default: assert(0, "bad label: " + __label__);
  }
}
_WriteHeader1333["X"]=1;

function _RecreateGLYF($fontdef, $new_offsets, $stream) {
  var __stackBase__  = STACKTOP; STACKTOP += 4100; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $save_offset;
      var $start_offset;
      var $attr;
      var $ret;
      var $i;
      var $buf=__stackBase__;
      var $offset;
      var $len;
      var $tmp_len=(__stackBase__)+(4096);
      $2=$fontdef;
      $3=$new_offsets;
      $4=$stream;
      $save_offset=0;
      var $5=$4;
      var $6=(($5+16)|0);
      var $7=HEAP32[(($6)>>2)];
      $start_offset=$7;
      var $8=$2;
      var $9=(($8+208)|0);
      var $10=HEAP32[(($9)>>2)];
      var $11=$10;
      $attr=$11;
      $i=0;
      __label__ = 3; break;
    case 3: 
      var $13=$i;
      var $14=$attr;
      var $15=(($14+228)|0);
      var $16=HEAPU16[(($15)>>1)];
      var $17=(($16)&65535);
      var $18=(($13)|0) < (($17)|0);
      if ($18) { __label__ = 4; break; } else { __label__ = 27; break; }
    case 4: 
      var $20=$i;
      var $21=$attr;
      var $22=(($21+216)|0);
      var $23=(($22+8)|0);
      var $24=HEAP32[(($23)>>2)];
      var $25=(($24+$20)|0);
      var $26=HEAPU8[($25)];
      var $27=(($26)&255);
      var $28=(($27)|0)==1;
      if ($28) { __label__ = 5; break; } else { __label__ = 24; break; }
    case 5: 
      var $30=$i;
      var $31=$attr;
      var $32=(($31+216)|0);
      var $33=(($32+4)|0);
      var $34=HEAP32[(($33)>>2)];
      var $35=(($34+($30<<2))|0);
      var $36=HEAP32[(($35)>>2)];
      $offset=$36;
      var $37=$i;
      var $38=((($37)+(1))|0);
      var $39=$attr;
      var $40=(($39+216)|0);
      var $41=(($40+4)|0);
      var $42=HEAP32[(($41)>>2)];
      var $43=(($42+($38<<2))|0);
      var $44=HEAP32[(($43)>>2)];
      var $45=$offset;
      var $46=((($44)-($45))|0);
      $len=$46;
      var $47=$4;
      var $48=(($47+16)|0);
      var $49=HEAP32[(($48)>>2)];
      var $50=$start_offset;
      var $51=((($49)-($50))|0);
      var $52=$i;
      var $53=$3;
      var $54=(($53+($52<<2))|0);
      HEAP32[(($54)>>2)]=$51;
      var $55=$attr;
      var $56=(($55+160)|0);
      var $57=(($56+50)|0);
      var $58=HEAP16[(($57)>>1)];
      var $59=(($58 << 16) >> 16);
      var $60=(($59)|0)==0;
      if ($60) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      var $62=$i;
      var $63=$3;
      var $64=(($63+($62<<2))|0);
      var $65=HEAPU32[(($64)>>2)];
      var $66=Math.floor(((($65)>>>0))/(2));
      HEAP32[(($64)>>2)]=$66;
      var $67=$len;
      var $68=((($67<<1))|0);
      $len=$68;
      __label__ = 7; break;
    case 7: 
      var $70=$attr;
      var $71=(($70+160)|0);
      var $72=(($71+50)|0);
      var $73=HEAP16[(($72)>>1)];
      var $74=(($73 << 16) >> 16);
      var $75=(($74)|0)==0;
      if ($75) { __label__ = 8; break; } else { __label__ = 9; break; }
    case 8: 
      var $77=$offset;
      var $78=((($77<<1))|0);
      $offset=$78;
      __label__ = 9; break;
    case 9: 
      var $80=$attr;
      var $81=(($80+216)|0);
      var $82=(($81)|0);
      var $83=HEAP32[(($82)>>2)];
      var $84=$offset;
      var $85=((($84)+($83))|0);
      $offset=$85;
      var $86=$attr;
      var $87=(($86+348)|0);
      var $88=HEAP32[(($87)>>2)];
      var $89=$offset;
      var $90=_HPDF_Stream_Seek($88, $89, 0);
      $ret=$90;
      var $91=(($90)|0)!=0;
      if ($91) { __label__ = 10; break; } else { __label__ = 11; break; }
    case 10: 
      var $93=$ret;
      $1=$93;
      __label__ = 28; break;
    case 11: 
      __label__ = 12; break;
    case 12: 
      var $96=$len;
      var $97=(($96)>>>0) > 0;
      if ($97) { __label__ = 13; break; } else { __label__ = 21; break; }
    case 13: 
      var $99=$len;
      var $100=(($99)>>>0) > 4096;
      if ($100) { __label__ = 14; break; } else { __label__ = 15; break; }
    case 14: 
      var $105 = 4096;__label__ = 16; break;
    case 15: 
      var $103=$len;
      var $105 = $103;__label__ = 16; break;
    case 16: 
      var $105;
      HEAP32[(($tmp_len)>>2)]=$105;
      var $106=(($buf)|0);
      var $107=HEAP32[(($tmp_len)>>2)];
      var $108=_HPDF_MemSet($106, 0, $107);
      var $109=$attr;
      var $110=(($109+348)|0);
      var $111=HEAP32[(($110)>>2)];
      var $112=(($buf)|0);
      var $113=_HPDF_Stream_Read($111, $112, $tmp_len);
      $ret=$113;
      var $114=(($113)|0)!=0;
      if ($114) { __label__ = 17; break; } else { __label__ = 18; break; }
    case 17: 
      var $116=$ret;
      $1=$116;
      __label__ = 28; break;
    case 18: 
      var $118=$4;
      var $119=(($buf)|0);
      var $120=HEAP32[(($tmp_len)>>2)];
      var $121=_HPDF_Stream_Write($118, $119, $120);
      $ret=$121;
      var $122=(($121)|0)!=0;
      if ($122) { __label__ = 19; break; } else { __label__ = 20; break; }
    case 19: 
      var $124=$ret;
      $1=$124;
      __label__ = 28; break;
    case 20: 
      var $126=HEAP32[(($tmp_len)>>2)];
      var $127=$len;
      var $128=((($127)-($126))|0);
      $len=$128;
      __label__ = 12; break;
    case 21: 
      var $130=$4;
      var $131=(($130+16)|0);
      var $132=HEAP32[(($131)>>2)];
      var $133=$start_offset;
      var $134=((($132)-($133))|0);
      $save_offset=$134;
      var $135=$attr;
      var $136=(($135+160)|0);
      var $137=(($136+50)|0);
      var $138=HEAP16[(($137)>>1)];
      var $139=(($138 << 16) >> 16);
      var $140=(($139)|0)==0;
      if ($140) { __label__ = 22; break; } else { __label__ = 23; break; }
    case 22: 
      var $142=$save_offset;
      var $143=Math.floor(((($142)>>>0))/(2));
      $save_offset=$143;
      __label__ = 23; break;
    case 23: 
      __label__ = 25; break;
    case 24: 
      var $146=$save_offset;
      var $147=$i;
      var $148=$3;
      var $149=(($148+($147<<2))|0);
      HEAP32[(($149)>>2)]=$146;
      __label__ = 25; break;
    case 25: 
      __label__ = 26; break;
    case 26: 
      var $152=$i;
      var $153=((($152)+(1))|0);
      $i=$153;
      __label__ = 3; break;
    case 27: 
      var $155=$save_offset;
      var $156=$attr;
      var $157=(($156+228)|0);
      var $158=HEAPU16[(($157)>>1)];
      var $159=(($158)&65535);
      var $160=$3;
      var $161=(($160+($159<<2))|0);
      HEAP32[(($161)>>2)]=$155;
      $1=0;
      __label__ = 28; break;
    case 28: 
      var $163=$1;
      STACKTOP = __stackBase__;
      return $163;
    default: assert(0, "bad label: " + __label__);
  }
}
_RecreateGLYF["X"]=1;

function _RecreateName($fontdef, $stream) {
  var __stackBase__  = STACKTOP; STACKTOP += 4100; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $attr;
      var $tbl;
      var $ret;
      var $i;
      var $name_rec;
      var $tmp_stream;
      var $name_len;
      var $buf=__stackBase__;
      var $tmp_len;
      var $offset;
      var $rec_offset;
      var $len=(__stackBase__)+(4096);
      $2=$fontdef;
      $3=$stream;
      var $4=$2;
      var $5=(($4+208)|0);
      var $6=HEAP32[(($5)>>2)];
      var $7=$6;
      $attr=$7;
      var $8=$2;
      var $9=_FindTable($8, ((STRING_TABLE.__str31307)|0));
      $tbl=$9;
      $ret=0;
      var $10=$2;
      var $11=(($10+132)|0);
      var $12=HEAP32[(($11)>>2)];
      var $13=_HPDF_MemStream_New($12, 4096);
      $tmp_stream=$13;
      var $14=$tmp_stream;
      var $15=(($14)|0)!=0;
      if ($15) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      var $17=$2;
      var $18=(($17+136)|0);
      var $19=HEAP32[(($18)>>2)];
      var $20=_HPDF_Error_GetCode($19);
      $1=$20;
      __label__ = 30; break;
    case 4: 
      var $22=$3;
      var $23=$attr;
      var $24=(($23+232)|0);
      var $25=(($24)|0);
      var $26=HEAP16[(($25)>>1)];
      var $27=_WriteUINT16($22, $26);
      var $28=$ret;
      var $29=((($28)+($27))|0);
      $ret=$29;
      var $30=$3;
      var $31=$attr;
      var $32=(($31+232)|0);
      var $33=(($32+2)|0);
      var $34=HEAP16[(($33)>>1)];
      var $35=_WriteUINT16($30, $34);
      var $36=$ret;
      var $37=((($36)+($35))|0);
      $ret=$37;
      var $38=$3;
      var $39=$attr;
      var $40=(($39+232)|0);
      var $41=(($40+4)|0);
      var $42=HEAP16[(($41)>>1)];
      var $43=_WriteUINT16($38, $42);
      var $44=$ret;
      var $45=((($44)+($43))|0);
      $ret=$45;
      var $46=$ret;
      var $47=(($46)|0)!=0;
      if ($47) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $49=$tmp_stream;
      _HPDF_Stream_Free($49);
      var $50=$2;
      var $51=(($50+136)|0);
      var $52=HEAP32[(($51)>>2)];
      var $53=_HPDF_Error_GetCode($52);
      $1=$53;
      __label__ = 30; break;
    case 6: 
      var $55=$attr;
      var $56=(($55+232)|0);
      var $57=(($56+8)|0);
      var $58=HEAP32[(($57)>>2)];
      $name_rec=$58;
      $i=0;
      __label__ = 7; break;
    case 7: 
      var $60=$i;
      var $61=$attr;
      var $62=(($61+232)|0);
      var $63=(($62+2)|0);
      var $64=HEAPU16[(($63)>>1)];
      var $65=(($64)&65535);
      var $66=(($60)>>>0) < (($65)>>>0);
      if ($66) { __label__ = 8; break; } else { __label__ = 29; break; }
    case 8: 
      var $68=$name_rec;
      var $69=(($68+8)|0);
      var $70=HEAPU16[(($69)>>1)];
      var $71=(($70)&65535);
      $name_len=$71;
      var $72=$name_len;
      $tmp_len=$72;
      var $73=$tbl;
      var $74=(($73+8)|0);
      var $75=HEAP32[(($74)>>2)];
      var $76=$attr;
      var $77=(($76+232)|0);
      var $78=(($77+4)|0);
      var $79=HEAPU16[(($78)>>1)];
      var $80=(($79)&65535);
      var $81=((($75)+($80))|0);
      var $82=$name_rec;
      var $83=(($82+10)|0);
      var $84=HEAPU16[(($83)>>1)];
      var $85=(($84)&65535);
      var $86=((($81)+($85))|0);
      $offset=$86;
      var $87=$tmp_stream;
      var $88=(($87+16)|0);
      var $89=HEAP32[(($88)>>2)];
      $rec_offset=$89;
      var $90=$name_rec;
      var $91=(($90+6)|0);
      var $92=HEAPU16[(($91)>>1)];
      var $93=(($92)&65535);
      var $94=(($93)|0)==1;
      if ($94) { __label__ = 10; break; } else { __label__ = 9; break; }
    case 9: 
      var $96=$name_rec;
      var $97=(($96+6)|0);
      var $98=HEAPU16[(($97)>>1)];
      var $99=(($98)&65535);
      var $100=(($99)|0)==4;
      if ($100) { __label__ = 10; break; } else { __label__ = 15; break; }
    case 10: 
      var $102=$name_rec;
      var $103=(($102)|0);
      var $104=HEAPU16[(($103)>>1)];
      var $105=(($104)&65535);
      var $106=(($105)|0)==0;
      if ($106) { __label__ = 12; break; } else { __label__ = 11; break; }
    case 11: 
      var $108=$name_rec;
      var $109=(($108)|0);
      var $110=HEAPU16[(($109)>>1)];
      var $111=(($110)&65535);
      var $112=(($111)|0)==3;
      if ($112) { __label__ = 12; break; } else { __label__ = 13; break; }
    case 12: 
      var $114=$tmp_stream;
      var $115=$attr;
      var $116=(($115+143)|0);
      var $117=(($116)|0);
      var $118=_HPDF_Stream_Write($114, $117, 14);
      var $119=$ret;
      var $120=((($119)+($118))|0);
      $ret=$120;
      var $121=$name_len;
      var $122=((($121)+(14))|0);
      $name_len=$122;
      __label__ = 14; break;
    case 13: 
      var $124=$tmp_stream;
      var $125=$attr;
      var $126=(($125+136)|0);
      var $127=(($126)|0);
      var $128=_HPDF_Stream_Write($124, $127, 7);
      var $129=$ret;
      var $130=((($129)+($128))|0);
      $ret=$130;
      var $131=$name_len;
      var $132=((($131)+(7))|0);
      $name_len=$132;
      __label__ = 14; break;
    case 14: 
      __label__ = 15; break;
    case 15: 
      var $135=$3;
      var $136=$name_rec;
      var $137=(($136)|0);
      var $138=HEAP16[(($137)>>1)];
      var $139=_WriteUINT16($135, $138);
      var $140=$ret;
      var $141=((($140)+($139))|0);
      $ret=$141;
      var $142=$3;
      var $143=$name_rec;
      var $144=(($143+2)|0);
      var $145=HEAP16[(($144)>>1)];
      var $146=_WriteUINT16($142, $145);
      var $147=$ret;
      var $148=((($147)+($146))|0);
      $ret=$148;
      var $149=$3;
      var $150=$name_rec;
      var $151=(($150+4)|0);
      var $152=HEAP16[(($151)>>1)];
      var $153=_WriteUINT16($149, $152);
      var $154=$ret;
      var $155=((($154)+($153))|0);
      $ret=$155;
      var $156=$3;
      var $157=$name_rec;
      var $158=(($157+6)|0);
      var $159=HEAP16[(($158)>>1)];
      var $160=_WriteUINT16($156, $159);
      var $161=$ret;
      var $162=((($161)+($160))|0);
      $ret=$162;
      var $163=$3;
      var $164=$name_len;
      var $165=(($164) & 65535);
      var $166=_WriteUINT16($163, $165);
      var $167=$ret;
      var $168=((($167)+($166))|0);
      $ret=$168;
      var $169=$3;
      var $170=$rec_offset;
      var $171=(($170) & 65535);
      var $172=_WriteUINT16($169, $171);
      var $173=$ret;
      var $174=((($173)+($172))|0);
      $ret=$174;
      var $175=$attr;
      var $176=(($175+348)|0);
      var $177=HEAP32[(($176)>>2)];
      var $178=$offset;
      var $179=_HPDF_Stream_Seek($177, $178, 0);
      var $180=$ret;
      var $181=((($180)+($179))|0);
      $ret=$181;
      var $182=$ret;
      var $183=(($182)|0)!=0;
      if ($183) { __label__ = 16; break; } else { __label__ = 17; break; }
    case 16: 
      var $185=$tmp_stream;
      _HPDF_Stream_Free($185);
      var $186=$2;
      var $187=(($186+136)|0);
      var $188=HEAP32[(($187)>>2)];
      var $189=_HPDF_Error_GetCode($188);
      $1=$189;
      __label__ = 30; break;
    case 17: 
      __label__ = 18; break;
    case 18: 
      var $192=$tmp_len;
      var $193=(($192)>>>0) > 0;
      if ($193) { __label__ = 19; break; } else { __label__ = 27; break; }
    case 19: 
      var $195=$tmp_len;
      var $196=(($195)>>>0) > 4096;
      if ($196) { __label__ = 20; break; } else { __label__ = 21; break; }
    case 20: 
      var $201 = 4096;__label__ = 22; break;
    case 21: 
      var $199=$tmp_len;
      var $201 = $199;__label__ = 22; break;
    case 22: 
      var $201;
      HEAP32[(($len)>>2)]=$201;
      var $202=$attr;
      var $203=(($202+348)|0);
      var $204=HEAP32[(($203)>>2)];
      var $205=(($buf)|0);
      var $206=_HPDF_Stream_Read($204, $205, $len);
      $ret=$206;
      var $207=(($206)|0)!=0;
      if ($207) { __label__ = 23; break; } else { __label__ = 24; break; }
    case 23: 
      var $209=$tmp_stream;
      _HPDF_Stream_Free($209);
      var $210=$ret;
      $1=$210;
      __label__ = 30; break;
    case 24: 
      var $212=$tmp_stream;
      var $213=(($buf)|0);
      var $214=HEAP32[(($len)>>2)];
      var $215=_HPDF_Stream_Write($212, $213, $214);
      $ret=$215;
      var $216=(($215)|0)!=0;
      if ($216) { __label__ = 25; break; } else { __label__ = 26; break; }
    case 25: 
      var $218=$tmp_stream;
      _HPDF_Stream_Free($218);
      var $219=$ret;
      $1=$219;
      __label__ = 30; break;
    case 26: 
      var $221=HEAP32[(($len)>>2)];
      var $222=$tmp_len;
      var $223=((($222)-($221))|0);
      $tmp_len=$223;
      __label__ = 18; break;
    case 27: 
      var $225=$name_rec;
      var $226=(($225+12)|0);
      $name_rec=$226;
      __label__ = 28; break;
    case 28: 
      var $228=$i;
      var $229=((($228)+(1))|0);
      $i=$229;
      __label__ = 7; break;
    case 29: 
      var $231=$tmp_stream;
      var $232=$3;
      var $233=_HPDF_Stream_WriteToStream($231, $232, 0, 0);
      $ret=$233;
      var $234=$tmp_stream;
      _HPDF_Stream_Free($234);
      var $235=$ret;
      $1=$235;
      __label__ = 30; break;
    case 30: 
      var $237=$1;
      STACKTOP = __stackBase__;
      return $237;
    default: assert(0, "bad label: " + __label__);
  }
}
_RecreateName["X"]=1;

function _UINT32Swap($value) {
  var __stackBase__  = STACKTOP; STACKTOP += 4; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;

  var $1;
  var $b=__stackBase__;
  $1=$value;
  var $2=(($b)|0);
  var $3=$1;
  var $4=$3;
  var $5=_HPDF_MemCpy($2, $4, 4);
  var $6=(($b)|0);
  var $7=HEAPU8[($6)];
  var $8=(($7)&255);
  var $9=$8 << 24;
  var $10=(($b+1)|0);
  var $11=HEAPU8[($10)];
  var $12=(($11)&255);
  var $13=$12 << 16;
  var $14=$9 | $13;
  var $15=(($b+2)|0);
  var $16=HEAPU8[($15)];
  var $17=(($16)&255);
  var $18=$17 << 8;
  var $19=$14 | $18;
  var $20=(($b+3)|0);
  var $21=HEAPU8[($20)];
  var $22=(($21)&255);
  var $23=$19 | $22;
  var $24=$1;
  HEAP32[(($24)>>2)]=$23;
  STACKTOP = __stackBase__;
  return;
}


function _HPDF_TTFontDef_SetTagName($fontdef, $tag) {
  var __stackBase__  = STACKTOP; STACKTOP += 128; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $attr;
      var $buf=__stackBase__;
      var $i;
      $1=$fontdef;
      $2=$tag;
      var $3=$1;
      var $4=(($3+208)|0);
      var $5=HEAP32[(($4)>>2)];
      var $6=$5;
      $attr=$6;
      var $7=$2;
      var $8=_HPDF_StrLen($7, 127);
      var $9=(($8)|0)!=6;
      if ($9) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      __label__ = 9; break;
    case 4: 
      var $12=$attr;
      var $13=(($12+136)|0);
      var $14=(($13)|0);
      var $15=$2;
      var $16=_HPDF_MemCpy($14, $15, 6);
      var $17=$attr;
      var $18=(($17+136)|0);
      var $19=(($18+6)|0);
      HEAP8[($19)]=43;
      $i=0;
      __label__ = 5; break;
    case 5: 
      var $21=$i;
      var $22=(($21)>>>0) < 7;
      if ($22) { __label__ = 6; break; } else { __label__ = 8; break; }
    case 6: 
      var $24=$i;
      var $25=((($24<<1))|0);
      var $26=$attr;
      var $27=(($26+143)|0);
      var $28=(($27+$25)|0);
      HEAP8[($28)]=0;
      var $29=$i;
      var $30=$attr;
      var $31=(($30+136)|0);
      var $32=(($31+$29)|0);
      var $33=HEAP8[($32)];
      var $34=$i;
      var $35=((($34<<1))|0);
      var $36=((($35)+(1))|0);
      var $37=$attr;
      var $38=(($37+143)|0);
      var $39=(($38+$36)|0);
      HEAP8[($39)]=$33;
      __label__ = 7; break;
    case 7: 
      var $41=$i;
      var $42=((($41)+(1))|0);
      $i=$42;
      __label__ = 5; break;
    case 8: 
      var $44=(($buf)|0);
      var $45=_HPDF_MemSet($44, 0, 128);
      var $46=(($buf)|0);
      var $47=$attr;
      var $48=(($47+136)|0);
      var $49=(($48)|0);
      var $50=_HPDF_MemCpy($46, $49, 7);
      var $51=(($buf)|0);
      var $52=(($51+6)|0);
      var $53=(($52+1)|0);
      var $54=$1;
      var $55=(($54+4)|0);
      var $56=(($55)|0);
      var $57=_HPDF_MemCpy($53, $56, 120);
      var $58=$attr;
      var $59=(($58)|0);
      var $60=(($59)|0);
      var $61=(($buf)|0);
      var $62=_HPDF_MemCpy($60, $61, 128);
      __label__ = 9; break;
    case 9: 
      STACKTOP = __stackBase__;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_TTFontDef_SetTagName["X"]=1;

function _WriteINT16($stream, $value) {
  var __stackBase__  = STACKTOP; STACKTOP += 4; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $ret;
      var $tmp=__stackBase__;
      $2=$stream;
      $3=$value;
      var $4=$3;
      HEAP16[(($tmp)>>1)]=$4;
      _INT16Swap($tmp);
      var $5=$2;
      var $6=$tmp;
      var $7=_HPDF_Stream_Write($5, $6, 2);
      $ret=$7;
      var $8=$ret;
      var $9=(($8)|0)!=0;
      if ($9) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $11=$ret;
      $1=$11;
      __label__ = 5; break;
    case 4: 
      $1=0;
      __label__ = 5; break;
    case 5: 
      var $14=$1;
      STACKTOP = __stackBase__;
      return $14;
    default: assert(0, "bad label: " + __label__);
  }
}


function _INT16Swap($value) {
  var __stackBase__  = STACKTOP; STACKTOP += 4; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;

  var $1;
  var $b=__stackBase__;
  $1=$value;
  var $2=(($b)|0);
  var $3=$1;
  var $4=$3;
  var $5=_HPDF_MemCpy($2, $4, 2);
  var $6=(($b)|0);
  var $7=HEAPU8[($6)];
  var $8=(($7)&255);
  var $9=(($8 << 16) >> 16);
  var $10=$9 << 8;
  var $11=(($b+1)|0);
  var $12=HEAPU8[($11)];
  var $13=(($12)&255);
  var $14=(($13 << 16) >> 16);
  var $15=$10 | $14;
  var $16=(($15) & 65535);
  var $17=$1;
  HEAP16[(($17)>>1)]=$16;
  STACKTOP = __stackBase__;
  return;
}


function _UINT16Swap($value) {
  var __stackBase__  = STACKTOP; STACKTOP += 4; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;

  var $1;
  var $b=__stackBase__;
  $1=$value;
  var $2=(($b)|0);
  var $3=$1;
  var $4=$3;
  var $5=_HPDF_MemCpy($2, $4, 2);
  var $6=(($b)|0);
  var $7=HEAPU8[($6)];
  var $8=(($7)&255);
  var $9=(($8)&65535);
  var $10=$9 << 8;
  var $11=(($b+1)|0);
  var $12=HEAPU8[($11)];
  var $13=(($12)&255);
  var $14=(($13)&65535);
  var $15=$10 | $14;
  var $16=(($15) & 65535);
  var $17=$1;
  HEAP16[(($17)>>1)]=$16;
  STACKTOP = __stackBase__;
  return;
}


function _GetUINT32($stream, $value) {
  var __stackBase__  = STACKTOP; STACKTOP += 4; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $ret;
      var $size=__stackBase__;
      $2=$stream;
      $3=$value;
      HEAP32[(($size)>>2)]=4;
      var $4=$2;
      var $5=$3;
      var $6=$5;
      var $7=_HPDF_Stream_Read($4, $6, $size);
      $ret=$7;
      var $8=$ret;
      var $9=(($8)|0)!=0;
      if ($9) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $11=$3;
      HEAP32[(($11)>>2)]=0;
      var $12=$ret;
      $1=$12;
      __label__ = 5; break;
    case 4: 
      var $14=$3;
      _UINT32Swap($14);
      $1=0;
      __label__ = 5; break;
    case 5: 
      var $16=$1;
      STACKTOP = __stackBase__;
      return $16;
    default: assert(0, "bad label: " + __label__);
  }
}


function _LoadTTFTable($fontdef) {
  var __stackBase__  = STACKTOP; STACKTOP += 4; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $attr;
      var $ret;
      var $i;
      var $tbl;
      var $siz=__stackBase__;
      $2=$fontdef;
      var $3=$2;
      var $4=(($3+208)|0);
      var $5=HEAP32[(($4)>>2)];
      var $6=$5;
      $attr=$6;
      $ret=0;
      var $7=$attr;
      var $8=(($7+348)|0);
      var $9=HEAP32[(($8)>>2)];
      var $10=$attr;
      var $11=(($10+252)|0);
      var $12=(($11)|0);
      var $13=_GetUINT32($9, $12);
      var $14=$ret;
      var $15=((($14)+($13))|0);
      $ret=$15;
      var $16=$attr;
      var $17=(($16+348)|0);
      var $18=HEAP32[(($17)>>2)];
      var $19=$attr;
      var $20=(($19+252)|0);
      var $21=(($20+4)|0);
      var $22=_GetUINT16($18, $21);
      var $23=$ret;
      var $24=((($23)+($22))|0);
      $ret=$24;
      var $25=$attr;
      var $26=(($25+348)|0);
      var $27=HEAP32[(($26)>>2)];
      var $28=$attr;
      var $29=(($28+252)|0);
      var $30=(($29+6)|0);
      var $31=_GetUINT16($27, $30);
      var $32=$ret;
      var $33=((($32)+($31))|0);
      $ret=$33;
      var $34=$attr;
      var $35=(($34+348)|0);
      var $36=HEAP32[(($35)>>2)];
      var $37=$attr;
      var $38=(($37+252)|0);
      var $39=(($38+8)|0);
      var $40=_GetUINT16($36, $39);
      var $41=$ret;
      var $42=((($41)+($40))|0);
      $ret=$42;
      var $43=$attr;
      var $44=(($43+348)|0);
      var $45=HEAP32[(($44)>>2)];
      var $46=$attr;
      var $47=(($46+252)|0);
      var $48=(($47+10)|0);
      var $49=_GetUINT16($45, $48);
      var $50=$ret;
      var $51=((($50)+($49))|0);
      $ret=$51;
      var $52=$ret;
      var $53=(($52)|0)!=0;
      if ($53) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $55=$2;
      var $56=(($55+136)|0);
      var $57=HEAP32[(($56)>>2)];
      var $58=_HPDF_Error_GetCode($57);
      $1=$58;
      __label__ = 15; break;
    case 4: 
      var $60=$attr;
      var $61=(($60+252)|0);
      var $62=(($61+4)|0);
      var $63=HEAPU16[(($62)>>1)];
      var $64=(($63)&65535);
      var $65=((($64<<4))|0);
      var $66=(($65)>>>0) > 10000;
      if ($66) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $68=$2;
      var $69=(($68+136)|0);
      var $70=HEAP32[(($69)>>2)];
      var $71=_HPDF_SetError($70, 4191, 0);
      $1=$71;
      __label__ = 15; break;
    case 6: 
      var $73=$2;
      var $74=(($73+132)|0);
      var $75=HEAP32[(($74)>>2)];
      var $76=$attr;
      var $77=(($76+252)|0);
      var $78=(($77+4)|0);
      var $79=HEAPU16[(($78)>>1)];
      var $80=(($79)&65535);
      var $81=((($80<<4))|0);
      var $82=_HPDF_GetMem($75, $81);
      var $83=$82;
      var $84=$attr;
      var $85=(($84+252)|0);
      var $86=(($85+12)|0);
      HEAP32[(($86)>>2)]=$83;
      var $87=$attr;
      var $88=(($87+252)|0);
      var $89=(($88+12)|0);
      var $90=HEAP32[(($89)>>2)];
      var $91=(($90)|0)!=0;
      if ($91) { __label__ = 8; break; } else { __label__ = 7; break; }
    case 7: 
      var $93=$2;
      var $94=(($93+136)|0);
      var $95=HEAP32[(($94)>>2)];
      var $96=_HPDF_Error_GetCode($95);
      $1=$96;
      __label__ = 15; break;
    case 8: 
      var $98=$attr;
      var $99=(($98+252)|0);
      var $100=(($99+12)|0);
      var $101=HEAP32[(($100)>>2)];
      $tbl=$101;
      $i=0;
      __label__ = 9; break;
    case 9: 
      var $103=$i;
      var $104=$attr;
      var $105=(($104+252)|0);
      var $106=(($105+4)|0);
      var $107=HEAPU16[(($106)>>1)];
      var $108=(($107)&65535);
      var $109=(($103)|0) < (($108)|0);
      if ($109) { __label__ = 10; break; } else { __label__ = 14; break; }
    case 10: 
      HEAP32[(($siz)>>2)]=4;
      var $111=$attr;
      var $112=(($111+348)|0);
      var $113=HEAP32[(($112)>>2)];
      var $114=$tbl;
      var $115=(($114)|0);
      var $116=(($115)|0);
      var $117=_HPDF_Stream_Read($113, $116, $siz);
      var $118=$ret;
      var $119=((($118)+($117))|0);
      $ret=$119;
      var $120=$attr;
      var $121=(($120+348)|0);
      var $122=HEAP32[(($121)>>2)];
      var $123=$tbl;
      var $124=(($123+4)|0);
      var $125=_GetUINT32($122, $124);
      var $126=$ret;
      var $127=((($126)+($125))|0);
      $ret=$127;
      var $128=$attr;
      var $129=(($128+348)|0);
      var $130=HEAP32[(($129)>>2)];
      var $131=$tbl;
      var $132=(($131+8)|0);
      var $133=_GetUINT32($130, $132);
      var $134=$ret;
      var $135=((($134)+($133))|0);
      $ret=$135;
      var $136=$attr;
      var $137=(($136+348)|0);
      var $138=HEAP32[(($137)>>2)];
      var $139=$tbl;
      var $140=(($139+12)|0);
      var $141=_GetUINT32($138, $140);
      var $142=$ret;
      var $143=((($142)+($141))|0);
      $ret=$143;
      var $144=$ret;
      var $145=(($144)|0)!=0;
      if ($145) { __label__ = 11; break; } else { __label__ = 12; break; }
    case 11: 
      var $147=$2;
      var $148=(($147+136)|0);
      var $149=HEAP32[(($148)>>2)];
      var $150=_HPDF_Error_GetCode($149);
      $1=$150;
      __label__ = 15; break;
    case 12: 
      var $152=$tbl;
      var $153=(($152+16)|0);
      $tbl=$153;
      __label__ = 13; break;
    case 13: 
      var $155=$i;
      var $156=((($155)+(1))|0);
      $i=$156;
      __label__ = 9; break;
    case 14: 
      $1=0;
      __label__ = 15; break;
    case 15: 
      var $159=$1;
      STACKTOP = __stackBase__;
      return $159;
    default: assert(0, "bad label: " + __label__);
  }
}
_LoadTTFTable["X"]=1;

function _ParseHead($fontdef) {
  var __stackBase__  = STACKTOP; STACKTOP += 4; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $attr;
      var $tbl;
      var $ret;
      var $siz=__stackBase__;
      $2=$fontdef;
      var $3=$2;
      var $4=(($3+208)|0);
      var $5=HEAP32[(($4)>>2)];
      var $6=$5;
      $attr=$6;
      var $7=$2;
      var $8=_FindTable($7, ((STRING_TABLE.__str1304)|0));
      $tbl=$8;
      var $9=$tbl;
      var $10=(($9)|0)!=0;
      if ($10) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      var $12=$2;
      var $13=(($12+136)|0);
      var $14=HEAP32[(($13)>>2)];
      var $15=_HPDF_SetError($14, 4192, 5);
      $1=$15;
      __label__ = 9; break;
    case 4: 
      var $17=$attr;
      var $18=(($17+348)|0);
      var $19=HEAP32[(($18)>>2)];
      var $20=$tbl;
      var $21=(($20+8)|0);
      var $22=HEAP32[(($21)>>2)];
      var $23=_HPDF_Stream_Seek($19, $22, 0);
      $ret=$23;
      var $24=$ret;
      var $25=(($24)|0)!=0;
      if ($25) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $27=$ret;
      $1=$27;
      __label__ = 9; break;
    case 6: 
      HEAP32[(($siz)>>2)]=4;
      var $29=$attr;
      var $30=(($29+348)|0);
      var $31=HEAP32[(($30)>>2)];
      var $32=$attr;
      var $33=(($32+160)|0);
      var $34=(($33)|0);
      var $35=$34;
      var $36=_HPDF_Stream_Read($31, $35, $siz);
      var $37=$ret;
      var $38=((($37)+($36))|0);
      $ret=$38;
      var $39=$attr;
      var $40=(($39+348)|0);
      var $41=HEAP32[(($40)>>2)];
      var $42=$attr;
      var $43=(($42+160)|0);
      var $44=(($43+4)|0);
      var $45=_GetUINT32($41, $44);
      var $46=$ret;
      var $47=((($46)+($45))|0);
      $ret=$47;
      var $48=$attr;
      var $49=(($48+348)|0);
      var $50=HEAP32[(($49)>>2)];
      var $51=$attr;
      var $52=(($51+160)|0);
      var $53=(($52+8)|0);
      var $54=_GetUINT32($50, $53);
      var $55=$ret;
      var $56=((($55)+($54))|0);
      $ret=$56;
      var $57=$attr;
      var $58=(($57+348)|0);
      var $59=HEAP32[(($58)>>2)];
      var $60=$attr;
      var $61=(($60+160)|0);
      var $62=(($61+12)|0);
      var $63=_GetUINT32($59, $62);
      var $64=$ret;
      var $65=((($64)+($63))|0);
      $ret=$65;
      var $66=$attr;
      var $67=(($66+348)|0);
      var $68=HEAP32[(($67)>>2)];
      var $69=$attr;
      var $70=(($69+160)|0);
      var $71=(($70+16)|0);
      var $72=_GetUINT16($68, $71);
      var $73=$ret;
      var $74=((($73)+($72))|0);
      $ret=$74;
      var $75=$attr;
      var $76=(($75+348)|0);
      var $77=HEAP32[(($76)>>2)];
      var $78=$attr;
      var $79=(($78+160)|0);
      var $80=(($79+18)|0);
      var $81=_GetUINT16($77, $80);
      var $82=$ret;
      var $83=((($82)+($81))|0);
      $ret=$83;
      HEAP32[(($siz)>>2)]=8;
      var $84=$attr;
      var $85=(($84+348)|0);
      var $86=HEAP32[(($85)>>2)];
      var $87=$attr;
      var $88=(($87+160)|0);
      var $89=(($88+20)|0);
      var $90=(($89)|0);
      var $91=_HPDF_Stream_Read($86, $90, $siz);
      var $92=$ret;
      var $93=((($92)+($91))|0);
      $ret=$93;
      HEAP32[(($siz)>>2)]=8;
      var $94=$attr;
      var $95=(($94+348)|0);
      var $96=HEAP32[(($95)>>2)];
      var $97=$attr;
      var $98=(($97+160)|0);
      var $99=(($98+28)|0);
      var $100=(($99)|0);
      var $101=_HPDF_Stream_Read($96, $100, $siz);
      var $102=$ret;
      var $103=((($102)+($101))|0);
      $ret=$103;
      var $104=$attr;
      var $105=(($104+348)|0);
      var $106=HEAP32[(($105)>>2)];
      var $107=$attr;
      var $108=(($107+160)|0);
      var $109=(($108+36)|0);
      var $110=_GetINT16($106, $109);
      var $111=$ret;
      var $112=((($111)+($110))|0);
      $ret=$112;
      var $113=$attr;
      var $114=(($113+348)|0);
      var $115=HEAP32[(($114)>>2)];
      var $116=$attr;
      var $117=(($116+160)|0);
      var $118=(($117+38)|0);
      var $119=_GetINT16($115, $118);
      var $120=$ret;
      var $121=((($120)+($119))|0);
      $ret=$121;
      var $122=$attr;
      var $123=(($122+348)|0);
      var $124=HEAP32[(($123)>>2)];
      var $125=$attr;
      var $126=(($125+160)|0);
      var $127=(($126+40)|0);
      var $128=_GetINT16($124, $127);
      var $129=$ret;
      var $130=((($129)+($128))|0);
      $ret=$130;
      var $131=$attr;
      var $132=(($131+348)|0);
      var $133=HEAP32[(($132)>>2)];
      var $134=$attr;
      var $135=(($134+160)|0);
      var $136=(($135+42)|0);
      var $137=_GetINT16($133, $136);
      var $138=$ret;
      var $139=((($138)+($137))|0);
      $ret=$139;
      var $140=$attr;
      var $141=(($140+348)|0);
      var $142=HEAP32[(($141)>>2)];
      var $143=$attr;
      var $144=(($143+160)|0);
      var $145=(($144+44)|0);
      var $146=_GetUINT16($142, $145);
      var $147=$ret;
      var $148=((($147)+($146))|0);
      $ret=$148;
      var $149=$attr;
      var $150=(($149+348)|0);
      var $151=HEAP32[(($150)>>2)];
      var $152=$attr;
      var $153=(($152+160)|0);
      var $154=(($153+46)|0);
      var $155=_GetUINT16($151, $154);
      var $156=$ret;
      var $157=((($156)+($155))|0);
      $ret=$157;
      var $158=$attr;
      var $159=(($158+348)|0);
      var $160=HEAP32[(($159)>>2)];
      var $161=$attr;
      var $162=(($161+160)|0);
      var $163=(($162+48)|0);
      var $164=_GetINT16($160, $163);
      var $165=$ret;
      var $166=((($165)+($164))|0);
      $ret=$166;
      var $167=$attr;
      var $168=(($167+348)|0);
      var $169=HEAP32[(($168)>>2)];
      var $170=$attr;
      var $171=(($170+160)|0);
      var $172=(($171+50)|0);
      var $173=_GetINT16($169, $172);
      var $174=$ret;
      var $175=((($174)+($173))|0);
      $ret=$175;
      var $176=$attr;
      var $177=(($176+348)|0);
      var $178=HEAP32[(($177)>>2)];
      var $179=$attr;
      var $180=(($179+160)|0);
      var $181=(($180+52)|0);
      var $182=_GetINT16($178, $181);
      var $183=$ret;
      var $184=((($183)+($182))|0);
      $ret=$184;
      var $185=$ret;
      var $186=(($185)|0)!=0;
      if ($186) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $188=$2;
      var $189=(($188+136)|0);
      var $190=HEAP32[(($189)>>2)];
      var $191=_HPDF_Error_GetCode($190);
      $1=$191;
      __label__ = 9; break;
    case 8: 
      var $193=$attr;
      var $194=(($193+160)|0);
      var $195=(($194+36)|0);
      var $196=HEAP16[(($195)>>1)];
      var $197=(($196 << 16) >> 16);
      var $198=((($197)*(1000))|0);
      var $199=$attr;
      var $200=(($199+160)|0);
      var $201=(($200+18)|0);
      var $202=HEAPU16[(($201)>>1)];
      var $203=(($202)&65535);
      var $204=((((($198)|0))/((($203)|0)))&-1);
      var $205=(($204)|0);
      var $206=$2;
      var $207=(($206+164)|0);
      var $208=(($207)|0);
      HEAPF32[(($208)>>2)]=$205;
      var $209=$attr;
      var $210=(($209+160)|0);
      var $211=(($210+38)|0);
      var $212=HEAP16[(($211)>>1)];
      var $213=(($212 << 16) >> 16);
      var $214=((($213)*(1000))|0);
      var $215=$attr;
      var $216=(($215+160)|0);
      var $217=(($216+18)|0);
      var $218=HEAPU16[(($217)>>1)];
      var $219=(($218)&65535);
      var $220=((((($214)|0))/((($219)|0)))&-1);
      var $221=(($220)|0);
      var $222=$2;
      var $223=(($222+164)|0);
      var $224=(($223+4)|0);
      HEAPF32[(($224)>>2)]=$221;
      var $225=$attr;
      var $226=(($225+160)|0);
      var $227=(($226+40)|0);
      var $228=HEAP16[(($227)>>1)];
      var $229=(($228 << 16) >> 16);
      var $230=((($229)*(1000))|0);
      var $231=$attr;
      var $232=(($231+160)|0);
      var $233=(($232+18)|0);
      var $234=HEAPU16[(($233)>>1)];
      var $235=(($234)&65535);
      var $236=((((($230)|0))/((($235)|0)))&-1);
      var $237=(($236)|0);
      var $238=$2;
      var $239=(($238+164)|0);
      var $240=(($239+8)|0);
      HEAPF32[(($240)>>2)]=$237;
      var $241=$attr;
      var $242=(($241+160)|0);
      var $243=(($242+42)|0);
      var $244=HEAP16[(($243)>>1)];
      var $245=(($244 << 16) >> 16);
      var $246=((($245)*(1000))|0);
      var $247=$attr;
      var $248=(($247+160)|0);
      var $249=(($248+18)|0);
      var $250=HEAPU16[(($249)>>1)];
      var $251=(($250)&65535);
      var $252=((((($246)|0))/((($251)|0)))&-1);
      var $253=(($252)|0);
      var $254=$2;
      var $255=(($254+164)|0);
      var $256=(($255+12)|0);
      HEAPF32[(($256)>>2)]=$253;
      $1=0;
      __label__ = 9; break;
    case 9: 
      var $258=$1;
      STACKTOP = __stackBase__;
      return $258;
    default: assert(0, "bad label: " + __label__);
  }
}
_ParseHead["X"]=1;

function _ParseMaxp($fontdef) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $attr;
      var $tbl;
      var $ret;
      $2=$fontdef;
      var $3=$2;
      var $4=(($3+208)|0);
      var $5=HEAP32[(($4)>>2)];
      var $6=$5;
      $attr=$6;
      var $7=$2;
      var $8=_FindTable($7, ((STRING_TABLE.__str101314)|0));
      $tbl=$8;
      var $9=$tbl;
      var $10=(($9)|0)!=0;
      if ($10) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      var $12=$2;
      var $13=(($12+136)|0);
      var $14=HEAP32[(($13)>>2)];
      var $15=_HPDF_SetError($14, 4192, 9);
      $1=$15;
      __label__ = 7; break;
    case 4: 
      var $17=$attr;
      var $18=(($17+348)|0);
      var $19=HEAP32[(($18)>>2)];
      var $20=$tbl;
      var $21=(($20+8)|0);
      var $22=HEAP32[(($21)>>2)];
      var $23=((($22)+(4))|0);
      var $24=_HPDF_Stream_Seek($19, $23, 0);
      $ret=$24;
      var $25=$ret;
      var $26=(($25)|0)!=0;
      if ($26) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $28=$ret;
      $1=$28;
      __label__ = 7; break;
    case 6: 
      var $30=$attr;
      var $31=(($30+348)|0);
      var $32=HEAP32[(($31)>>2)];
      var $33=$attr;
      var $34=(($33+228)|0);
      var $35=_GetUINT16($32, $34);
      $ret=$35;
      var $36=$ret;
      $1=$36;
      __label__ = 7; break;
    case 7: 
      var $38=$1;
      ;
      return $38;
    default: assert(0, "bad label: " + __label__);
  }
}
_ParseMaxp["X"]=1;

function _ParseHhea($fontdef) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $attr;
      var $tbl;
      var $ret;
      $2=$fontdef;
      var $3=$2;
      var $4=(($3+208)|0);
      var $5=HEAP32[(($4)>>2)];
      var $6=$5;
      $attr=$6;
      var $7=$2;
      var $8=_FindTable($7, ((STRING_TABLE.__str81312)|0));
      $tbl=$8;
      var $9=$tbl;
      var $10=(($9)|0)!=0;
      if ($10) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      var $12=$2;
      var $13=(($12+136)|0);
      var $14=HEAP32[(($13)>>2)];
      var $15=_HPDF_SetError($14, 4192, 6);
      $1=$15;
      __label__ = 13; break;
    case 4: 
      var $17=$attr;
      var $18=(($17+348)|0);
      var $19=HEAP32[(($18)>>2)];
      var $20=$tbl;
      var $21=(($20+8)|0);
      var $22=HEAP32[(($21)>>2)];
      var $23=((($22)+(4))|0);
      var $24=_HPDF_Stream_Seek($19, $23, 0);
      $ret=$24;
      var $25=$ret;
      var $26=(($25)|0)!=0;
      if ($26) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $28=$ret;
      $1=$28;
      __label__ = 13; break;
    case 6: 
      var $30=$attr;
      var $31=(($30+348)|0);
      var $32=HEAP32[(($31)>>2)];
      var $33=$2;
      var $34=(($33+156)|0);
      var $35=_GetINT16($32, $34);
      var $36=$ret;
      var $37=((($36)+($35))|0);
      $ret=$37;
      var $38=$2;
      var $39=(($38+156)|0);
      var $40=HEAP16[(($39)>>1)];
      var $41=(($40 << 16) >> 16);
      var $42=((($41)*(1000))|0);
      var $43=$attr;
      var $44=(($43+160)|0);
      var $45=(($44+18)|0);
      var $46=HEAPU16[(($45)>>1)];
      var $47=(($46)&65535);
      var $48=((((($42)|0))/((($47)|0)))&-1);
      var $49=(($48) & 65535);
      var $50=$2;
      var $51=(($50+156)|0);
      HEAP16[(($51)>>1)]=$49;
      var $52=$attr;
      var $53=(($52+348)|0);
      var $54=HEAP32[(($53)>>2)];
      var $55=$2;
      var $56=(($55+158)|0);
      var $57=_GetINT16($54, $56);
      var $58=$ret;
      var $59=((($58)+($57))|0);
      $ret=$59;
      var $60=$2;
      var $61=(($60+158)|0);
      var $62=HEAP16[(($61)>>1)];
      var $63=(($62 << 16) >> 16);
      var $64=((($63)*(1000))|0);
      var $65=$attr;
      var $66=(($65+160)|0);
      var $67=(($66+18)|0);
      var $68=HEAPU16[(($67)>>1)];
      var $69=(($68)&65535);
      var $70=((((($64)|0))/((($69)|0)))&-1);
      var $71=(($70) & 65535);
      var $72=$2;
      var $73=(($72+158)|0);
      HEAP16[(($73)>>1)]=$71;
      var $74=$ret;
      var $75=(($74)|0)!=0;
      if ($75) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $77=$2;
      var $78=(($77+136)|0);
      var $79=HEAP32[(($78)>>2)];
      var $80=_HPDF_Error_GetCode($79);
      $1=$80;
      __label__ = 13; break;
    case 8: 
      var $82=$attr;
      var $83=(($82+348)|0);
      var $84=HEAP32[(($83)>>2)];
      var $85=$tbl;
      var $86=(($85+8)|0);
      var $87=HEAP32[(($86)>>2)];
      var $88=((($87)+(34))|0);
      var $89=_HPDF_Stream_Seek($84, $88, 0);
      $ret=$89;
      var $90=$ret;
      var $91=(($90)|0)!=0;
      if ($91) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      var $93=$ret;
      $1=$93;
      __label__ = 13; break;
    case 10: 
      var $95=$attr;
      var $96=(($95+348)|0);
      var $97=HEAP32[(($96)>>2)];
      var $98=$attr;
      var $99=(($98+248)|0);
      var $100=_GetUINT16($97, $99);
      $ret=$100;
      var $101=$ret;
      var $102=(($101)|0)!=0;
      if ($102) { __label__ = 11; break; } else { __label__ = 12; break; }
    case 11: 
      var $104=$2;
      var $105=(($104+136)|0);
      var $106=HEAP32[(($105)>>2)];
      var $107=_HPDF_Error_GetCode($106);
      $1=$107;
      __label__ = 13; break;
    case 12: 
      var $109=$ret;
      $1=$109;
      __label__ = 13; break;
    case 13: 
      var $111=$1;
      ;
      return $111;
    default: assert(0, "bad label: " + __label__);
  }
}
_ParseHhea["X"]=1;

function _ParseCMap($fontdef) {
  var __stackBase__  = STACKTOP; STACKTOP += 24; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $attr;
      var $tbl;
      var $ret;
      var $version=__stackBase__;
      var $num_cmap=(__stackBase__)+(4);
      var $i;
      var $ms_unicode_encoding_offset;
      var $byte_encoding_offset;
      var $platformID=(__stackBase__)+(8);
      var $encodingID=(__stackBase__)+(12);
      var $format=(__stackBase__)+(16);
      var $offset=(__stackBase__)+(20);
      var $save_offset;
      $2=$fontdef;
      var $3=$2;
      var $4=(($3+208)|0);
      var $5=HEAP32[(($4)>>2)];
      var $6=$5;
      $attr=$6;
      var $7=$2;
      var $8=_FindTable($7, ((STRING_TABLE.__str51309)|0));
      $tbl=$8;
      $ms_unicode_encoding_offset=0;
      $byte_encoding_offset=0;
      var $9=$tbl;
      var $10=(($9)|0)!=0;
      if ($10) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      var $12=$2;
      var $13=(($12+136)|0);
      var $14=HEAP32[(($13)>>2)];
      var $15=_HPDF_SetError($14, 4192, 1);
      $1=$15;
      __label__ = 41; break;
    case 4: 
      var $17=$attr;
      var $18=(($17+348)|0);
      var $19=HEAP32[(($18)>>2)];
      var $20=$tbl;
      var $21=(($20+8)|0);
      var $22=HEAP32[(($21)>>2)];
      var $23=_HPDF_Stream_Seek($19, $22, 0);
      $ret=$23;
      var $24=$ret;
      var $25=(($24)|0)!=0;
      if ($25) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $27=$ret;
      $1=$27;
      __label__ = 41; break;
    case 6: 
      var $29=$attr;
      var $30=(($29+348)|0);
      var $31=HEAP32[(($30)>>2)];
      var $32=_GetUINT16($31, $version);
      var $33=$ret;
      var $34=((($33)+($32))|0);
      $ret=$34;
      var $35=$ret;
      var $36=(($35)|0)!=0;
      if ($36) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $38=$2;
      var $39=(($38+136)|0);
      var $40=HEAP32[(($39)>>2)];
      var $41=_HPDF_Error_GetCode($40);
      $1=$41;
      __label__ = 41; break;
    case 8: 
      var $43=HEAPU16[(($version)>>1)];
      var $44=(($43)&65535);
      var $45=(($44)|0)!=0;
      if ($45) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      var $47=$2;
      var $48=(($47+136)|0);
      var $49=HEAP32[(($48)>>2)];
      var $50=_HPDF_SetError($49, 4191, 0);
      $1=$50;
      __label__ = 41; break;
    case 10: 
      var $52=$attr;
      var $53=(($52+348)|0);
      var $54=HEAP32[(($53)>>2)];
      var $55=_GetUINT16($54, $num_cmap);
      var $56=$ret;
      var $57=((($56)+($55))|0);
      $ret=$57;
      var $58=$ret;
      var $59=(($58)|0)!=0;
      if ($59) { __label__ = 11; break; } else { __label__ = 12; break; }
    case 11: 
      var $61=$2;
      var $62=(($61+136)|0);
      var $63=HEAP32[(($62)>>2)];
      var $64=_HPDF_Error_GetCode($63);
      $1=$64;
      __label__ = 41; break;
    case 12: 
      $i=0;
      __label__ = 13; break;
    case 13: 
      var $67=$i;
      var $68=HEAPU16[(($num_cmap)>>1)];
      var $69=(($68)&65535);
      var $70=(($67)>>>0) < (($69)>>>0);
      if ($70) { __label__ = 14; break; } else { __label__ = 34; break; }
    case 14: 
      var $72=$attr;
      var $73=(($72+348)|0);
      var $74=HEAP32[(($73)>>2)];
      var $75=_GetUINT16($74, $platformID);
      var $76=$ret;
      var $77=((($76)+($75))|0);
      $ret=$77;
      var $78=$attr;
      var $79=(($78+348)|0);
      var $80=HEAP32[(($79)>>2)];
      var $81=_GetUINT16($80, $encodingID);
      var $82=$ret;
      var $83=((($82)+($81))|0);
      $ret=$83;
      var $84=$attr;
      var $85=(($84+348)|0);
      var $86=HEAP32[(($85)>>2)];
      var $87=_GetUINT32($86, $offset);
      var $88=$ret;
      var $89=((($88)+($87))|0);
      $ret=$89;
      var $90=$ret;
      var $91=(($90)|0)!=0;
      if ($91) { __label__ = 15; break; } else { __label__ = 16; break; }
    case 15: 
      var $93=$2;
      var $94=(($93+136)|0);
      var $95=HEAP32[(($94)>>2)];
      var $96=_HPDF_Error_GetCode($95);
      $1=$96;
      __label__ = 41; break;
    case 16: 
      var $98=$attr;
      var $99=(($98+348)|0);
      var $100=HEAP32[(($99)>>2)];
      var $101=_HPDF_Stream_Tell($100);
      $save_offset=$101;
      var $102=$save_offset;
      var $103=(($102)|0) < 0;
      if ($103) { __label__ = 17; break; } else { __label__ = 18; break; }
    case 17: 
      var $105=$2;
      var $106=(($105+136)|0);
      var $107=HEAP32[(($106)>>2)];
      var $108=_HPDF_Error_GetCode($107);
      $1=$108;
      __label__ = 41; break;
    case 18: 
      var $110=$attr;
      var $111=(($110+348)|0);
      var $112=HEAP32[(($111)>>2)];
      var $113=$tbl;
      var $114=(($113+8)|0);
      var $115=HEAP32[(($114)>>2)];
      var $116=HEAP32[(($offset)>>2)];
      var $117=((($115)+($116))|0);
      var $118=_HPDF_Stream_Seek($112, $117, 0);
      $ret=$118;
      var $119=$ret;
      var $120=(($119)|0)!=0;
      if ($120) { __label__ = 19; break; } else { __label__ = 20; break; }
    case 19: 
      var $122=$ret;
      $1=$122;
      __label__ = 41; break;
    case 20: 
      var $124=$attr;
      var $125=(($124+348)|0);
      var $126=HEAP32[(($125)>>2)];
      var $127=_GetUINT16($126, $format);
      $ret=$127;
      var $128=$ret;
      var $129=(($128)|0)!=0;
      if ($129) { __label__ = 21; break; } else { __label__ = 22; break; }
    case 21: 
      var $131=$ret;
      $1=$131;
      __label__ = 41; break;
    case 22: 
      var $133=HEAPU16[(($platformID)>>1)];
      var $134=(($133)&65535);
      var $135=(($134)|0)==3;
      if ($135) { __label__ = 23; break; } else { __label__ = 26; break; }
    case 23: 
      var $137=HEAPU16[(($encodingID)>>1)];
      var $138=(($137)&65535);
      var $139=(($138)|0)==1;
      if ($139) { __label__ = 24; break; } else { __label__ = 26; break; }
    case 24: 
      var $141=HEAPU16[(($format)>>1)];
      var $142=(($141)&65535);
      var $143=(($142)|0)==4;
      if ($143) { __label__ = 25; break; } else { __label__ = 26; break; }
    case 25: 
      var $145=HEAP32[(($offset)>>2)];
      $ms_unicode_encoding_offset=$145;
      __label__ = 34; break;
    case 26: 
      var $147=HEAPU16[(($platformID)>>1)];
      var $148=(($147)&65535);
      var $149=(($148)|0)==1;
      if ($149) { __label__ = 27; break; } else { __label__ = 30; break; }
    case 27: 
      var $151=HEAPU16[(($encodingID)>>1)];
      var $152=(($151)&65535);
      var $153=(($152)|0)==0;
      if ($153) { __label__ = 28; break; } else { __label__ = 30; break; }
    case 28: 
      var $155=HEAPU16[(($format)>>1)];
      var $156=(($155)&65535);
      var $157=(($156)|0)==1;
      if ($157) { __label__ = 29; break; } else { __label__ = 30; break; }
    case 29: 
      var $159=HEAP32[(($offset)>>2)];
      $byte_encoding_offset=$159;
      __label__ = 30; break;
    case 30: 
      var $161=$attr;
      var $162=(($161+348)|0);
      var $163=HEAP32[(($162)>>2)];
      var $164=$save_offset;
      var $165=_HPDF_Stream_Seek($163, $164, 0);
      $ret=$165;
      var $166=$ret;
      var $167=(($166)|0)!=0;
      if ($167) { __label__ = 31; break; } else { __label__ = 32; break; }
    case 31: 
      var $169=$ret;
      $1=$169;
      __label__ = 41; break;
    case 32: 
      __label__ = 33; break;
    case 33: 
      var $172=$i;
      var $173=((($172)+(1))|0);
      $i=$173;
      __label__ = 13; break;
    case 34: 
      var $175=$ms_unicode_encoding_offset;
      var $176=(($175)|0)!=0;
      if ($176) { __label__ = 35; break; } else { __label__ = 36; break; }
    case 35: 
      var $178=$2;
      var $179=$ms_unicode_encoding_offset;
      var $180=$tbl;
      var $181=(($180+8)|0);
      var $182=HEAP32[(($181)>>2)];
      var $183=((($179)+($182))|0);
      var $184=_ParseCMAP_format4($178, $183);
      $ret=$184;
      __label__ = 40; break;
    case 36: 
      var $186=$byte_encoding_offset;
      var $187=(($186)|0)!=0;
      if ($187) { __label__ = 37; break; } else { __label__ = 38; break; }
    case 37: 
      var $189=$2;
      var $190=$byte_encoding_offset;
      var $191=$tbl;
      var $192=(($191+8)|0);
      var $193=HEAP32[(($192)>>2)];
      var $194=((($190)+($193))|0);
      var $195=_ParseCMAP_format0($189, $194);
      $ret=$195;
      __label__ = 39; break;
    case 38: 
      var $197=$2;
      var $198=(($197+136)|0);
      var $199=HEAP32[(($198)>>2)];
      var $200=_HPDF_SetError($199, 4191, 0);
      $1=$200;
      __label__ = 41; break;
    case 39: 
      __label__ = 40; break;
    case 40: 
      var $203=$ret;
      $1=$203;
      __label__ = 41; break;
    case 41: 
      var $205=$1;
      STACKTOP = __stackBase__;
      return $205;
    default: assert(0, "bad label: " + __label__);
  }
}
_ParseCMap["X"]=1;

function _ParseHmtx($fontdef) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $attr;
      var $tbl;
      var $ret;
      var $i;
      var $save_aw;
      var $pmetric;
      $2=$fontdef;
      var $3=$2;
      var $4=(($3+208)|0);
      var $5=HEAP32[(($4)>>2)];
      var $6=$5;
      $attr=$6;
      var $7=$2;
      var $8=_FindTable($7, ((STRING_TABLE.__str91313)|0));
      $tbl=$8;
      $save_aw=0;
      var $9=$tbl;
      var $10=(($9)|0)!=0;
      if ($10) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      var $12=$2;
      var $13=(($12+136)|0);
      var $14=HEAP32[(($13)>>2)];
      var $15=_HPDF_SetError($14, 4192, 7);
      $1=$15;
      __label__ = 22; break;
    case 4: 
      var $17=$attr;
      var $18=(($17+348)|0);
      var $19=HEAP32[(($18)>>2)];
      var $20=$tbl;
      var $21=(($20+8)|0);
      var $22=HEAP32[(($21)>>2)];
      var $23=_HPDF_Stream_Seek($19, $22, 0);
      $ret=$23;
      var $24=$ret;
      var $25=(($24)|0)!=0;
      if ($25) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $27=$ret;
      $1=$27;
      __label__ = 22; break;
    case 6: 
      var $29=$2;
      var $30=(($29+132)|0);
      var $31=HEAP32[(($30)>>2)];
      var $32=$attr;
      var $33=(($32+228)|0);
      var $34=HEAPU16[(($33)>>1)];
      var $35=(($34)&65535);
      var $36=((($35<<2))|0);
      var $37=_HPDF_GetMem($31, $36);
      var $38=$37;
      var $39=$attr;
      var $40=(($39+244)|0);
      HEAP32[(($40)>>2)]=$38;
      var $41=$attr;
      var $42=(($41+244)|0);
      var $43=HEAP32[(($42)>>2)];
      var $44=(($43)|0)!=0;
      if ($44) { __label__ = 8; break; } else { __label__ = 7; break; }
    case 7: 
      var $46=$2;
      var $47=(($46+136)|0);
      var $48=HEAP32[(($47)>>2)];
      var $49=_HPDF_Error_GetCode($48);
      $1=$49;
      __label__ = 22; break;
    case 8: 
      var $51=$attr;
      var $52=(($51+244)|0);
      var $53=HEAP32[(($52)>>2)];
      $pmetric=$53;
      $i=0;
      __label__ = 9; break;
    case 9: 
      var $55=$i;
      var $56=$attr;
      var $57=(($56+248)|0);
      var $58=HEAPU16[(($57)>>1)];
      var $59=(($58)&65535);
      var $60=(($55)>>>0) < (($59)>>>0);
      if ($60) { __label__ = 10; break; } else { __label__ = 16; break; }
    case 10: 
      var $62=$attr;
      var $63=(($62+348)|0);
      var $64=HEAP32[(($63)>>2)];
      var $65=$pmetric;
      var $66=(($65)|0);
      var $67=_GetUINT16($64, $66);
      $ret=$67;
      var $68=(($67)|0)!=0;
      if ($68) { __label__ = 11; break; } else { __label__ = 12; break; }
    case 11: 
      var $70=$ret;
      $1=$70;
      __label__ = 22; break;
    case 12: 
      var $72=$attr;
      var $73=(($72+348)|0);
      var $74=HEAP32[(($73)>>2)];
      var $75=$pmetric;
      var $76=(($75+2)|0);
      var $77=_GetINT16($74, $76);
      $ret=$77;
      var $78=(($77)|0)!=0;
      if ($78) { __label__ = 13; break; } else { __label__ = 14; break; }
    case 13: 
      var $80=$ret;
      $1=$80;
      __label__ = 22; break;
    case 14: 
      var $82=$pmetric;
      var $83=(($82)|0);
      var $84=HEAP16[(($83)>>1)];
      $save_aw=$84;
      var $85=$pmetric;
      var $86=(($85+4)|0);
      $pmetric=$86;
      __label__ = 15; break;
    case 15: 
      var $88=$i;
      var $89=((($88)+(1))|0);
      $i=$89;
      __label__ = 9; break;
    case 16: 
      __label__ = 17; break;
    case 17: 
      var $92=$i;
      var $93=$attr;
      var $94=(($93+228)|0);
      var $95=HEAPU16[(($94)>>1)];
      var $96=(($95)&65535);
      var $97=(($92)>>>0) < (($96)>>>0);
      if ($97) { __label__ = 18; break; } else { __label__ = 21; break; }
    case 18: 
      var $99=$save_aw;
      var $100=$pmetric;
      var $101=(($100)|0);
      HEAP16[(($101)>>1)]=$99;
      var $102=$attr;
      var $103=(($102+348)|0);
      var $104=HEAP32[(($103)>>2)];
      var $105=$pmetric;
      var $106=(($105+2)|0);
      var $107=_GetINT16($104, $106);
      $ret=$107;
      var $108=(($107)|0)!=0;
      if ($108) { __label__ = 19; break; } else { __label__ = 20; break; }
    case 19: 
      var $110=$ret;
      $1=$110;
      __label__ = 22; break;
    case 20: 
      var $112=$pmetric;
      var $113=(($112+4)|0);
      $pmetric=$113;
      var $114=$i;
      var $115=((($114)+(1))|0);
      $i=$115;
      __label__ = 17; break;
    case 21: 
      $1=0;
      __label__ = 22; break;
    case 22: 
      var $118=$1;
      ;
      return $118;
    default: assert(0, "bad label: " + __label__);
  }
}
_ParseHmtx["X"]=1;

function _ParseLoca($fontdef) {
  var __stackBase__  = STACKTOP; STACKTOP += 4; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $attr;
      var $tbl;
      var $ret;
      var $i;
      var $poffset;
      var $tmp=__stackBase__;
      $2=$fontdef;
      var $3=$2;
      var $4=(($3+208)|0);
      var $5=HEAP32[(($4)>>2)];
      var $6=$5;
      $attr=$6;
      var $7=$2;
      var $8=_FindTable($7, ((STRING_TABLE.__str21306)|0));
      $tbl=$8;
      var $9=$tbl;
      var $10=(($9)|0)!=0;
      if ($10) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      var $12=$2;
      var $13=(($12+136)|0);
      var $14=HEAP32[(($13)>>2)];
      var $15=_HPDF_SetError($14, 4192, 8);
      $1=$15;
      __label__ = 26; break;
    case 4: 
      var $17=$attr;
      var $18=(($17+348)|0);
      var $19=HEAP32[(($18)>>2)];
      var $20=$tbl;
      var $21=(($20+8)|0);
      var $22=HEAP32[(($21)>>2)];
      var $23=_HPDF_Stream_Seek($19, $22, 0);
      $ret=$23;
      var $24=$ret;
      var $25=(($24)|0)!=0;
      if ($25) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $27=$ret;
      $1=$27;
      __label__ = 26; break;
    case 6: 
      var $29=$2;
      var $30=(($29+132)|0);
      var $31=HEAP32[(($30)>>2)];
      var $32=$attr;
      var $33=(($32+228)|0);
      var $34=HEAPU16[(($33)>>1)];
      var $35=(($34)&65535);
      var $36=((($35)+(1))|0);
      var $37=((($36<<2))|0);
      var $38=_HPDF_GetMem($31, $37);
      var $39=$38;
      var $40=$attr;
      var $41=(($40+216)|0);
      var $42=(($41+4)|0);
      HEAP32[(($42)>>2)]=$39;
      var $43=$attr;
      var $44=(($43+216)|0);
      var $45=(($44+4)|0);
      var $46=HEAP32[(($45)>>2)];
      var $47=(($46)|0)!=0;
      if ($47) { __label__ = 8; break; } else { __label__ = 7; break; }
    case 7: 
      var $49=$2;
      var $50=(($49+136)|0);
      var $51=HEAP32[(($50)>>2)];
      var $52=_HPDF_Error_GetCode($51);
      $1=$52;
      __label__ = 26; break;
    case 8: 
      var $54=$attr;
      var $55=(($54+216)|0);
      var $56=(($55+4)|0);
      var $57=HEAP32[(($56)>>2)];
      var $58=$57;
      var $59=$attr;
      var $60=(($59+228)|0);
      var $61=HEAPU16[(($60)>>1)];
      var $62=(($61)&65535);
      var $63=((($62)+(1))|0);
      var $64=((($63<<2))|0);
      var $65=_HPDF_MemSet($58, 0, $64);
      var $66=$2;
      var $67=(($66+132)|0);
      var $68=HEAP32[(($67)>>2)];
      var $69=$attr;
      var $70=(($69+228)|0);
      var $71=HEAPU16[(($70)>>1)];
      var $72=(($71)&65535);
      var $73=(($72)|0);
      var $74=_HPDF_GetMem($68, $73);
      var $75=$attr;
      var $76=(($75+216)|0);
      var $77=(($76+8)|0);
      HEAP32[(($77)>>2)]=$74;
      var $78=$attr;
      var $79=(($78+216)|0);
      var $80=(($79+8)|0);
      var $81=HEAP32[(($80)>>2)];
      var $82=(($81)|0)!=0;
      if ($82) { __label__ = 10; break; } else { __label__ = 9; break; }
    case 9: 
      var $84=$2;
      var $85=(($84+136)|0);
      var $86=HEAP32[(($85)>>2)];
      var $87=_HPDF_Error_GetCode($86);
      $1=$87;
      __label__ = 26; break;
    case 10: 
      var $89=$attr;
      var $90=(($89+216)|0);
      var $91=(($90+8)|0);
      var $92=HEAP32[(($91)>>2)];
      var $93=$attr;
      var $94=(($93+228)|0);
      var $95=HEAPU16[(($94)>>1)];
      var $96=(($95)&65535);
      var $97=(($96)|0);
      var $98=_HPDF_MemSet($92, 0, $97);
      var $99=$attr;
      var $100=(($99+216)|0);
      var $101=(($100+8)|0);
      var $102=HEAP32[(($101)>>2)];
      var $103=(($102)|0);
      HEAP8[($103)]=1;
      var $104=$attr;
      var $105=(($104+216)|0);
      var $106=(($105+4)|0);
      var $107=HEAP32[(($106)>>2)];
      $poffset=$107;
      var $108=$attr;
      var $109=(($108+160)|0);
      var $110=(($109+50)|0);
      var $111=HEAP16[(($110)>>1)];
      var $112=(($111 << 16) >> 16);
      var $113=(($112)|0)==0;
      if ($113) { __label__ = 11; break; } else { __label__ = 18; break; }
    case 11: 
      $i=0;
      __label__ = 12; break;
    case 12: 
      var $116=$i;
      var $117=$attr;
      var $118=(($117+228)|0);
      var $119=HEAPU16[(($118)>>1)];
      var $120=(($119)&65535);
      var $121=(($116)>>>0) <= (($120)>>>0);
      if ($121) { __label__ = 13; break; } else { __label__ = 17; break; }
    case 13: 
      HEAP16[(($tmp)>>1)]=0;
      var $123=$attr;
      var $124=(($123+348)|0);
      var $125=HEAP32[(($124)>>2)];
      var $126=_GetUINT16($125, $tmp);
      $ret=$126;
      var $127=(($126)|0)!=0;
      if ($127) { __label__ = 14; break; } else { __label__ = 15; break; }
    case 14: 
      var $129=$ret;
      $1=$129;
      __label__ = 26; break;
    case 15: 
      var $131=HEAPU16[(($tmp)>>1)];
      var $132=(($131)&65535);
      var $133=$poffset;
      HEAP32[(($133)>>2)]=$132;
      var $134=$poffset;
      var $135=(($134+4)|0);
      $poffset=$135;
      __label__ = 16; break;
    case 16: 
      var $137=$i;
      var $138=((($137)+(1))|0);
      $i=$138;
      __label__ = 12; break;
    case 17: 
      __label__ = 25; break;
    case 18: 
      $i=0;
      __label__ = 19; break;
    case 19: 
      var $142=$i;
      var $143=$attr;
      var $144=(($143+228)|0);
      var $145=HEAPU16[(($144)>>1)];
      var $146=(($145)&65535);
      var $147=(($142)>>>0) <= (($146)>>>0);
      if ($147) { __label__ = 20; break; } else { __label__ = 24; break; }
    case 20: 
      var $149=$attr;
      var $150=(($149+348)|0);
      var $151=HEAP32[(($150)>>2)];
      var $152=$poffset;
      var $153=_GetUINT32($151, $152);
      $ret=$153;
      var $154=(($153)|0)!=0;
      if ($154) { __label__ = 21; break; } else { __label__ = 22; break; }
    case 21: 
      var $156=$ret;
      $1=$156;
      __label__ = 26; break;
    case 22: 
      var $158=$poffset;
      var $159=(($158+4)|0);
      $poffset=$159;
      __label__ = 23; break;
    case 23: 
      var $161=$i;
      var $162=((($161)+(1))|0);
      $i=$162;
      __label__ = 19; break;
    case 24: 
      __label__ = 25; break;
    case 25: 
      $1=0;
      __label__ = 26; break;
    case 26: 
      var $166=$1;
      STACKTOP = __stackBase__;
      return $166;
    default: assert(0, "bad label: " + __label__);
  }
}
_ParseLoca["X"]=1;

function _ParseName($fontdef) {
  var __stackBase__  = STACKTOP; STACKTOP += 136; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $attr;
      var $tbl;
      var $ret;
      var $i;
      var $name_rec;
      var $offset_id1;
      var $offset_id2;
      var $offset_id1u;
      var $offset_id2u;
      var $len_id1=__stackBase__;
      var $len_id2=(__stackBase__)+(4);
      var $len_id1u;
      var $len_id2u;
      var $tmp=(__stackBase__)+(8);
      var $dst;
      var $src;
      var $j;
      $2=$fontdef;
      var $3=$2;
      var $4=(($3+208)|0);
      var $5=HEAP32[(($4)>>2)];
      var $6=$5;
      $attr=$6;
      var $7=$2;
      var $8=_FindTable($7, ((STRING_TABLE.__str31307)|0));
      $tbl=$8;
      $offset_id1=0;
      $offset_id2=0;
      $offset_id1u=0;
      $offset_id2u=0;
      HEAP32[(($len_id1)>>2)]=0;
      HEAP32[(($len_id2)>>2)]=0;
      $len_id1u=0;
      $len_id2u=0;
      var $9=$tbl;
      var $10=(($9)|0)!=0;
      if ($10) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      var $12=$2;
      var $13=(($12+136)|0);
      var $14=HEAP32[(($13)>>2)];
      var $15=_HPDF_SetError($14, 4192, 10);
      $1=$15;
      __label__ = 80; break;
    case 4: 
      var $17=$attr;
      var $18=(($17+348)|0);
      var $19=HEAP32[(($18)>>2)];
      var $20=$tbl;
      var $21=(($20+8)|0);
      var $22=HEAP32[(($21)>>2)];
      var $23=_HPDF_Stream_Seek($19, $22, 0);
      $ret=$23;
      var $24=$ret;
      var $25=(($24)|0)!=0;
      if ($25) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $27=$ret;
      $1=$27;
      __label__ = 80; break;
    case 6: 
      var $29=$attr;
      var $30=(($29+348)|0);
      var $31=HEAP32[(($30)>>2)];
      var $32=$attr;
      var $33=(($32+232)|0);
      var $34=(($33)|0);
      var $35=_GetUINT16($31, $34);
      var $36=$ret;
      var $37=((($36)+($35))|0);
      $ret=$37;
      var $38=$attr;
      var $39=(($38+348)|0);
      var $40=HEAP32[(($39)>>2)];
      var $41=$attr;
      var $42=(($41+232)|0);
      var $43=(($42+2)|0);
      var $44=_GetUINT16($40, $43);
      var $45=$ret;
      var $46=((($45)+($44))|0);
      $ret=$46;
      var $47=$attr;
      var $48=(($47+348)|0);
      var $49=HEAP32[(($48)>>2)];
      var $50=$attr;
      var $51=(($50+232)|0);
      var $52=(($51+4)|0);
      var $53=_GetUINT16($49, $52);
      var $54=$ret;
      var $55=((($54)+($53))|0);
      $ret=$55;
      var $56=$ret;
      var $57=(($56)|0)!=0;
      if ($57) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $59=$2;
      var $60=(($59+136)|0);
      var $61=HEAP32[(($60)>>2)];
      var $62=_HPDF_Error_GetCode($61);
      $1=$62;
      __label__ = 80; break;
    case 8: 
      var $64=$2;
      var $65=(($64+132)|0);
      var $66=HEAP32[(($65)>>2)];
      var $67=$attr;
      var $68=(($67+232)|0);
      var $69=(($68+2)|0);
      var $70=HEAPU16[(($69)>>1)];
      var $71=(($70)&65535);
      var $72=((($71)*(12))|0);
      var $73=_HPDF_GetMem($66, $72);
      var $74=$73;
      var $75=$attr;
      var $76=(($75+232)|0);
      var $77=(($76+8)|0);
      HEAP32[(($77)>>2)]=$74;
      var $78=$attr;
      var $79=(($78+232)|0);
      var $80=(($79+8)|0);
      var $81=HEAP32[(($80)>>2)];
      var $82=(($81)|0)!=0;
      if ($82) { __label__ = 10; break; } else { __label__ = 9; break; }
    case 9: 
      var $84=$2;
      var $85=(($84+136)|0);
      var $86=HEAP32[(($85)>>2)];
      var $87=_HPDF_Error_GetCode($86);
      $1=$87;
      __label__ = 80; break;
    case 10: 
      var $89=$attr;
      var $90=(($89+232)|0);
      var $91=(($90+8)|0);
      var $92=HEAP32[(($91)>>2)];
      $name_rec=$92;
      $i=0;
      __label__ = 11; break;
    case 11: 
      var $94=$i;
      var $95=$attr;
      var $96=(($95+232)|0);
      var $97=(($96+2)|0);
      var $98=HEAPU16[(($97)>>1)];
      var $99=(($98)&65535);
      var $100=(($94)>>>0) < (($99)>>>0);
      if ($100) { __label__ = 12; break; } else { __label__ = 34; break; }
    case 12: 
      var $102=$attr;
      var $103=(($102+348)|0);
      var $104=HEAP32[(($103)>>2)];
      var $105=$name_rec;
      var $106=(($105)|0);
      var $107=_GetUINT16($104, $106);
      var $108=$ret;
      var $109=((($108)+($107))|0);
      $ret=$109;
      var $110=$attr;
      var $111=(($110+348)|0);
      var $112=HEAP32[(($111)>>2)];
      var $113=$name_rec;
      var $114=(($113+2)|0);
      var $115=_GetUINT16($112, $114);
      var $116=$ret;
      var $117=((($116)+($115))|0);
      $ret=$117;
      var $118=$attr;
      var $119=(($118+348)|0);
      var $120=HEAP32[(($119)>>2)];
      var $121=$name_rec;
      var $122=(($121+4)|0);
      var $123=_GetUINT16($120, $122);
      var $124=$ret;
      var $125=((($124)+($123))|0);
      $ret=$125;
      var $126=$attr;
      var $127=(($126+348)|0);
      var $128=HEAP32[(($127)>>2)];
      var $129=$name_rec;
      var $130=(($129+6)|0);
      var $131=_GetUINT16($128, $130);
      var $132=$ret;
      var $133=((($132)+($131))|0);
      $ret=$133;
      var $134=$attr;
      var $135=(($134+348)|0);
      var $136=HEAP32[(($135)>>2)];
      var $137=$name_rec;
      var $138=(($137+8)|0);
      var $139=_GetUINT16($136, $138);
      var $140=$ret;
      var $141=((($140)+($139))|0);
      $ret=$141;
      var $142=$attr;
      var $143=(($142+348)|0);
      var $144=HEAP32[(($143)>>2)];
      var $145=$name_rec;
      var $146=(($145+10)|0);
      var $147=_GetUINT16($144, $146);
      var $148=$ret;
      var $149=((($148)+($147))|0);
      $ret=$149;
      var $150=$ret;
      var $151=(($150)|0)!=0;
      if ($151) { __label__ = 13; break; } else { __label__ = 14; break; }
    case 13: 
      var $153=$2;
      var $154=(($153+136)|0);
      var $155=HEAP32[(($154)>>2)];
      var $156=_HPDF_Error_GetCode($155);
      $1=$156;
      __label__ = 80; break;
    case 14: 
      var $158=$name_rec;
      var $159=(($158)|0);
      var $160=HEAPU16[(($159)>>1)];
      var $161=(($160)&65535);
      var $162=(($161)|0)==1;
      if ($162) { __label__ = 15; break; } else { __label__ = 18; break; }
    case 15: 
      var $164=$name_rec;
      var $165=(($164+2)|0);
      var $166=HEAPU16[(($165)>>1)];
      var $167=(($166)&65535);
      var $168=(($167)|0)==0;
      if ($168) { __label__ = 16; break; } else { __label__ = 18; break; }
    case 16: 
      var $170=$name_rec;
      var $171=(($170+6)|0);
      var $172=HEAPU16[(($171)>>1)];
      var $173=(($172)&65535);
      var $174=(($173)|0)==6;
      if ($174) { __label__ = 17; break; } else { __label__ = 18; break; }
    case 17: 
      var $176=$tbl;
      var $177=(($176+8)|0);
      var $178=HEAP32[(($177)>>2)];
      var $179=$name_rec;
      var $180=(($179+10)|0);
      var $181=HEAPU16[(($180)>>1)];
      var $182=(($181)&65535);
      var $183=((($178)+($182))|0);
      var $184=$attr;
      var $185=(($184+232)|0);
      var $186=(($185+4)|0);
      var $187=HEAPU16[(($186)>>1)];
      var $188=(($187)&65535);
      var $189=((($183)+($188))|0);
      $offset_id1=$189;
      var $190=$name_rec;
      var $191=(($190+8)|0);
      var $192=HEAPU16[(($191)>>1)];
      var $193=(($192)&65535);
      HEAP32[(($len_id1)>>2)]=$193;
      __label__ = 18; break;
    case 18: 
      var $195=$name_rec;
      var $196=(($195)|0);
      var $197=HEAPU16[(($196)>>1)];
      var $198=(($197)&65535);
      var $199=(($198)|0)==1;
      if ($199) { __label__ = 19; break; } else { __label__ = 22; break; }
    case 19: 
      var $201=$name_rec;
      var $202=(($201+2)|0);
      var $203=HEAPU16[(($202)>>1)];
      var $204=(($203)&65535);
      var $205=(($204)|0)==0;
      if ($205) { __label__ = 20; break; } else { __label__ = 22; break; }
    case 20: 
      var $207=$name_rec;
      var $208=(($207+6)|0);
      var $209=HEAPU16[(($208)>>1)];
      var $210=(($209)&65535);
      var $211=(($210)|0)==2;
      if ($211) { __label__ = 21; break; } else { __label__ = 22; break; }
    case 21: 
      var $213=$tbl;
      var $214=(($213+8)|0);
      var $215=HEAP32[(($214)>>2)];
      var $216=$name_rec;
      var $217=(($216+10)|0);
      var $218=HEAPU16[(($217)>>1)];
      var $219=(($218)&65535);
      var $220=((($215)+($219))|0);
      var $221=$attr;
      var $222=(($221+232)|0);
      var $223=(($222+4)|0);
      var $224=HEAPU16[(($223)>>1)];
      var $225=(($224)&65535);
      var $226=((($220)+($225))|0);
      $offset_id2=$226;
      var $227=$name_rec;
      var $228=(($227+8)|0);
      var $229=HEAPU16[(($228)>>1)];
      var $230=(($229)&65535);
      HEAP32[(($len_id2)>>2)]=$230;
      __label__ = 22; break;
    case 22: 
      var $232=$name_rec;
      var $233=(($232)|0);
      var $234=HEAPU16[(($233)>>1)];
      var $235=(($234)&65535);
      var $236=(($235)|0)==3;
      if ($236) { __label__ = 23; break; } else { __label__ = 27; break; }
    case 23: 
      var $238=$name_rec;
      var $239=(($238+2)|0);
      var $240=HEAPU16[(($239)>>1)];
      var $241=(($240)&65535);
      var $242=(($241)|0)==1;
      if ($242) { __label__ = 24; break; } else { __label__ = 27; break; }
    case 24: 
      var $244=$name_rec;
      var $245=(($244+6)|0);
      var $246=HEAPU16[(($245)>>1)];
      var $247=(($246)&65535);
      var $248=(($247)|0)==6;
      if ($248) { __label__ = 25; break; } else { __label__ = 27; break; }
    case 25: 
      var $250=$name_rec;
      var $251=(($250+4)|0);
      var $252=HEAPU16[(($251)>>1)];
      var $253=(($252)&65535);
      var $254=(($253)|0)==1033;
      if ($254) { __label__ = 26; break; } else { __label__ = 27; break; }
    case 26: 
      var $256=$tbl;
      var $257=(($256+8)|0);
      var $258=HEAP32[(($257)>>2)];
      var $259=$name_rec;
      var $260=(($259+10)|0);
      var $261=HEAPU16[(($260)>>1)];
      var $262=(($261)&65535);
      var $263=((($258)+($262))|0);
      var $264=$attr;
      var $265=(($264+232)|0);
      var $266=(($265+4)|0);
      var $267=HEAPU16[(($266)>>1)];
      var $268=(($267)&65535);
      var $269=((($263)+($268))|0);
      $offset_id1u=$269;
      var $270=$name_rec;
      var $271=(($270+8)|0);
      var $272=HEAPU16[(($271)>>1)];
      var $273=(($272)&65535);
      $len_id1u=$273;
      __label__ = 27; break;
    case 27: 
      var $275=$name_rec;
      var $276=(($275)|0);
      var $277=HEAPU16[(($276)>>1)];
      var $278=(($277)&65535);
      var $279=(($278)|0)==3;
      if ($279) { __label__ = 28; break; } else { __label__ = 32; break; }
    case 28: 
      var $281=$name_rec;
      var $282=(($281+2)|0);
      var $283=HEAPU16[(($282)>>1)];
      var $284=(($283)&65535);
      var $285=(($284)|0)==1;
      if ($285) { __label__ = 29; break; } else { __label__ = 32; break; }
    case 29: 
      var $287=$name_rec;
      var $288=(($287+6)|0);
      var $289=HEAPU16[(($288)>>1)];
      var $290=(($289)&65535);
      var $291=(($290)|0)==2;
      if ($291) { __label__ = 30; break; } else { __label__ = 32; break; }
    case 30: 
      var $293=$name_rec;
      var $294=(($293+4)|0);
      var $295=HEAPU16[(($294)>>1)];
      var $296=(($295)&65535);
      var $297=(($296)|0)==1033;
      if ($297) { __label__ = 31; break; } else { __label__ = 32; break; }
    case 31: 
      var $299=$tbl;
      var $300=(($299+8)|0);
      var $301=HEAP32[(($300)>>2)];
      var $302=$name_rec;
      var $303=(($302+10)|0);
      var $304=HEAPU16[(($303)>>1)];
      var $305=(($304)&65535);
      var $306=((($301)+($305))|0);
      var $307=$attr;
      var $308=(($307+232)|0);
      var $309=(($308+4)|0);
      var $310=HEAPU16[(($309)>>1)];
      var $311=(($310)&65535);
      var $312=((($306)+($311))|0);
      $offset_id2u=$312;
      var $313=$name_rec;
      var $314=(($313+8)|0);
      var $315=HEAPU16[(($314)>>1)];
      var $316=(($315)&65535);
      $len_id2u=$316;
      __label__ = 32; break;
    case 32: 
      var $318=$name_rec;
      var $319=(($318+12)|0);
      $name_rec=$319;
      __label__ = 33; break;
    case 33: 
      var $321=$i;
      var $322=((($321)+(1))|0);
      $i=$322;
      __label__ = 11; break;
    case 34: 
      var $324=$offset_id1;
      var $325=(($324)|0)!=0;
      if ($325) { __label__ = 36; break; } else { __label__ = 35; break; }
    case 35: 
      var $327=$offset_id1u;
      var $328=(($327)|0)!=0;
      if ($328) { __label__ = 36; break; } else { __label__ = 38; break; }
    case 36: 
      var $330=$offset_id2;
      var $331=(($330)|0)!=0;
      if ($331) { __label__ = 39; break; } else { __label__ = 37; break; }
    case 37: 
      var $333=$offset_id2u;
      var $334=(($333)|0)!=0;
      if ($334) { __label__ = 39; break; } else { __label__ = 38; break; }
    case 38: 
      var $336=$2;
      var $337=(($336+136)|0);
      var $338=HEAP32[(($337)>>2)];
      var $339=_HPDF_SetError($338, 4191, 0);
      $1=$339;
      __label__ = 80; break;
    case 39: 
      var $341=HEAP32[(($len_id1)>>2)];
      var $342=(($341)|0)==0;
      if ($342) { __label__ = 40; break; } else { __label__ = 42; break; }
    case 40: 
      var $344=$len_id1u;
      var $345=(($344)>>>0) > 0;
      if ($345) { __label__ = 41; break; } else { __label__ = 42; break; }
    case 41: 
      var $347=$len_id1u;
      var $348=Math.floor(((($347)>>>0))/(2));
      var $349=$len_id1u;
      var $350=((($349)>>>0))%(2);
      var $351=((($348)+($350))|0);
      HEAP32[(($len_id1)>>2)]=$351;
      __label__ = 42; break;
    case 42: 
      var $353=HEAP32[(($len_id2)>>2)];
      var $354=(($353)|0)==0;
      if ($354) { __label__ = 43; break; } else { __label__ = 45; break; }
    case 43: 
      var $356=$len_id2u;
      var $357=(($356)>>>0) > 0;
      if ($357) { __label__ = 44; break; } else { __label__ = 45; break; }
    case 44: 
      var $359=$len_id2u;
      var $360=Math.floor(((($359)>>>0))/(2));
      var $361=$len_id2u;
      var $362=((($361)>>>0))%(2);
      var $363=((($360)+($362))|0);
      HEAP32[(($len_id2)>>2)]=$363;
      __label__ = 45; break;
    case 45: 
      var $365=HEAP32[(($len_id1)>>2)];
      var $366=HEAP32[(($len_id2)>>2)];
      var $367=((($365)+($366))|0);
      var $368=((($367)+(8))|0);
      var $369=(($368)>>>0) > 127;
      if ($369) { __label__ = 46; break; } else { __label__ = 47; break; }
    case 46: 
      var $371=$2;
      var $372=(($371+136)|0);
      var $373=HEAP32[(($372)>>2)];
      var $374=_HPDF_SetError($373, 4191, 0);
      $1=$374;
      __label__ = 80; break;
    case 47: 
      var $376=$attr;
      var $377=(($376)|0);
      var $378=(($377)|0);
      var $379=_HPDF_MemSet($378, 0, 128);
      var $380=$offset_id1;
      var $381=(($380)|0)!=0;
      if ($381) { __label__ = 48; break; } else { __label__ = 53; break; }
    case 48: 
      var $383=$attr;
      var $384=(($383+348)|0);
      var $385=HEAP32[(($384)>>2)];
      var $386=$offset_id1;
      var $387=_HPDF_Stream_Seek($385, $386, 0);
      $ret=$387;
      var $388=(($387)|0)!=0;
      if ($388) { __label__ = 49; break; } else { __label__ = 50; break; }
    case 49: 
      var $390=$ret;
      $1=$390;
      __label__ = 80; break;
    case 50: 
      var $392=$attr;
      var $393=(($392+348)|0);
      var $394=HEAP32[(($393)>>2)];
      var $395=$attr;
      var $396=(($395)|0);
      var $397=(($396)|0);
      var $398=_HPDF_Stream_Read($394, $397, $len_id1);
      $ret=$398;
      var $399=(($398)|0)!=0;
      if ($399) { __label__ = 51; break; } else { __label__ = 52; break; }
    case 51: 
      var $401=$ret;
      $1=$401;
      __label__ = 80; break;
    case 52: 
      __label__ = 56; break;
    case 53: 
      var $404=$attr;
      var $405=(($404+348)|0);
      var $406=HEAP32[(($405)>>2)];
      var $407=$offset_id1u;
      var $408=$len_id1u;
      var $409=$attr;
      var $410=(($409)|0);
      var $411=(($410)|0);
      var $412=_LoadUnicodeName($406, $407, $408, $411);
      $ret=$412;
      var $413=(($412)|0)!=0;
      if ($413) { __label__ = 54; break; } else { __label__ = 55; break; }
    case 54: 
      var $415=$ret;
      $1=$415;
      __label__ = 80; break;
    case 55: 
      __label__ = 56; break;
    case 56: 
      var $418=(($tmp)|0);
      var $419=_HPDF_MemSet($418, 0, 128);
      var $420=$offset_id2;
      var $421=(($420)|0)!=0;
      if ($421) { __label__ = 57; break; } else { __label__ = 62; break; }
    case 57: 
      var $423=$attr;
      var $424=(($423+348)|0);
      var $425=HEAP32[(($424)>>2)];
      var $426=$offset_id2;
      var $427=_HPDF_Stream_Seek($425, $426, 0);
      $ret=$427;
      var $428=(($427)|0)!=0;
      if ($428) { __label__ = 58; break; } else { __label__ = 59; break; }
    case 58: 
      var $430=$ret;
      $1=$430;
      __label__ = 80; break;
    case 59: 
      var $432=$attr;
      var $433=(($432+348)|0);
      var $434=HEAP32[(($433)>>2)];
      var $435=(($tmp)|0);
      var $436=_HPDF_Stream_Read($434, $435, $len_id2);
      $ret=$436;
      var $437=(($436)|0)!=0;
      if ($437) { __label__ = 60; break; } else { __label__ = 61; break; }
    case 60: 
      var $439=$ret;
      $1=$439;
      __label__ = 80; break;
    case 61: 
      __label__ = 65; break;
    case 62: 
      var $442=$attr;
      var $443=(($442+348)|0);
      var $444=HEAP32[(($443)>>2)];
      var $445=$offset_id2u;
      var $446=$len_id2u;
      var $447=(($tmp)|0);
      var $448=_LoadUnicodeName($444, $445, $446, $447);
      $ret=$448;
      var $449=(($448)|0)!=0;
      if ($449) { __label__ = 63; break; } else { __label__ = 64; break; }
    case 63: 
      var $451=$ret;
      $1=$451;
      __label__ = 80; break;
    case 64: 
      __label__ = 65; break;
    case 65: 
      var $454=(($tmp)|0);
      var $455=_HPDF_MemCmp($454, ((STRING_TABLE.__str141318)|0), 7);
      var $456=(($455)|0)!=0;
      if ($456) { __label__ = 66; break; } else { __label__ = 79; break; }
    case 66: 
      var $458=$attr;
      var $459=(($458)|0);
      var $460=(($459)|0);
      var $461=HEAP32[(($len_id1)>>2)];
      var $462=(($460+$461)|0);
      $dst=$462;
      var $463=(($tmp)|0);
      $src=$463;
      var $464=$dst;
      var $465=(($464+1)|0);
      $dst=$465;
      HEAP8[($464)]=44;
      $j=0;
      __label__ = 67; break;
    case 67: 
      var $467=$j;
      var $468=HEAPU32[(($len_id2)>>2)];
      var $469=(($467)>>>0) < (($468)>>>0);
      if ($469) { __label__ = 68; break; } else { __label__ = 74; break; }
    case 68: 
      var $471=$src;
      var $472=HEAP8[($471)];
      var $473=(($472 << 24) >> 24);
      var $474=(($473)|0)!=32;
      if ($474) { __label__ = 69; break; } else { __label__ = 70; break; }
    case 69: 
      var $476=$src;
      var $477=(($476+1)|0);
      $src=$477;
      var $478=HEAP8[($476)];
      var $479=$dst;
      var $480=(($479+1)|0);
      $dst=$480;
      HEAP8[($479)]=$478;
      __label__ = 70; break;
    case 70: 
      var $482=$dst;
      var $483=$attr;
      var $484=(($483)|0);
      var $485=(($484)|0);
      var $486=(($485+127)|0);
      var $487=(($482)>>>0) >= (($486)>>>0);
      if ($487) { __label__ = 71; break; } else { __label__ = 72; break; }
    case 71: 
      __label__ = 74; break;
    case 72: 
      __label__ = 73; break;
    case 73: 
      var $491=$j;
      var $492=((($491)+(1))|0);
      $j=$492;
      __label__ = 67; break;
    case 74: 
      var $494=$dst;
      HEAP8[($494)]=0;
      var $495=(($tmp)|0);
      var $496=HEAP32[(($len_id2)>>2)];
      var $497=_HPDF_StrStr($495, ((STRING_TABLE.__str151319)|0), $496);
      var $498=(($497)|0)!=0;
      if ($498) { __label__ = 75; break; } else { __label__ = 76; break; }
    case 75: 
      var $500=$2;
      var $501=(($500+160)|0);
      var $502=HEAP32[(($501)>>2)];
      var $503=$502 | 262144;
      HEAP32[(($501)>>2)]=$503;
      __label__ = 76; break;
    case 76: 
      var $505=(($tmp)|0);
      var $506=HEAP32[(($len_id2)>>2)];
      var $507=_HPDF_StrStr($505, ((STRING_TABLE.__str161320)|0), $506);
      var $508=(($507)|0)!=0;
      if ($508) { __label__ = 77; break; } else { __label__ = 78; break; }
    case 77: 
      var $510=$2;
      var $511=(($510+160)|0);
      var $512=HEAP32[(($511)>>2)];
      var $513=$512 | 64;
      HEAP32[(($511)>>2)]=$513;
      __label__ = 78; break;
    case 78: 
      __label__ = 79; break;
    case 79: 
      var $516=$2;
      var $517=(($516+4)|0);
      var $518=(($517)|0);
      var $519=$attr;
      var $520=(($519)|0);
      var $521=(($520)|0);
      var $522=_HPDF_MemCpy($518, $521, 128);
      $1=0;
      __label__ = 80; break;
    case 80: 
      var $524=$1;
      STACKTOP = __stackBase__;
      return $524;
    default: assert(0, "bad label: " + __label__);
  }
}
_ParseName["X"]=1;

function _ParseOS2($fontdef) {
  var __stackBase__  = STACKTOP; STACKTOP += 4; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $attr;
      var $tbl;
      var $ret;
      var $len=__stackBase__;
      $2=$fontdef;
      var $3=$2;
      var $4=(($3+208)|0);
      var $5=HEAP32[(($4)>>2)];
      var $6=$5;
      $attr=$6;
      var $7=$2;
      var $8=_FindTable($7, ((STRING_TABLE.__str41308)|0));
      $tbl=$8;
      var $9=$tbl;
      var $10=(($9)|0)!=0;
      if ($10) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      var $12=$2;
      var $13=(($12+136)|0);
      var $14=HEAP32[(($13)>>2)];
      var $15=_HPDF_SetError($14, 4192, 0);
      $1=$15;
      __label__ = 25; break;
    case 4: 
      var $17=$attr;
      var $18=(($17+348)|0);
      var $19=HEAP32[(($18)>>2)];
      var $20=$tbl;
      var $21=(($20+8)|0);
      var $22=HEAP32[(($21)>>2)];
      var $23=((($22)+(8))|0);
      var $24=_HPDF_Stream_Seek($19, $23, 0);
      $ret=$24;
      var $25=$ret;
      var $26=(($25)|0)!=0;
      if ($26) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $28=$ret;
      $1=$28;
      __label__ = 25; break;
    case 6: 
      var $30=$attr;
      var $31=(($30+348)|0);
      var $32=HEAP32[(($31)>>2)];
      var $33=$attr;
      var $34=(($33+312)|0);
      var $35=_GetUINT16($32, $34);
      $ret=$35;
      var $36=(($35)|0)!=0;
      if ($36) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $38=$ret;
      $1=$38;
      __label__ = 25; break;
    case 8: 
      var $40=$attr;
      var $41=(($40+312)|0);
      var $42=HEAPU16[(($41)>>1)];
      var $43=(($42)&65535);
      var $44=$43 & 770;
      var $45=(($44)|0)!=0;
      if ($45) { __label__ = 9; break; } else { __label__ = 11; break; }
    case 9: 
      var $47=$attr;
      var $48=(($47+340)|0);
      var $49=HEAP32[(($48)>>2)];
      var $50=(($49)|0)!=0;
      if ($50) { __label__ = 10; break; } else { __label__ = 11; break; }
    case 10: 
      var $52=$2;
      var $53=(($52+136)|0);
      var $54=HEAP32[(($53)>>2)];
      var $55=_HPDF_SetError($54, 4189, 0);
      $1=$55;
      __label__ = 25; break;
    case 11: 
      var $57=$attr;
      var $58=(($57+348)|0);
      var $59=HEAP32[(($58)>>2)];
      var $60=$tbl;
      var $61=(($60+8)|0);
      var $62=HEAP32[(($61)>>2)];
      var $63=((($62)+(20))|0);
      var $64=_HPDF_Stream_Seek($59, $63, 0);
      $ret=$64;
      var $65=(($64)|0)!=0;
      if ($65) { __label__ = 12; break; } else { __label__ = 13; break; }
    case 12: 
      var $67=$ret;
      $1=$67;
      __label__ = 25; break;
    case 13: 
      HEAP32[(($len)>>2)]=12;
      var $69=$attr;
      var $70=(($69+348)|0);
      var $71=HEAP32[(($70)>>2)];
      var $72=$attr;
      var $73=(($72+314)|0);
      var $74=(($73)|0);
      var $75=_HPDF_Stream_Read($71, $74, $len);
      $ret=$75;
      var $76=(($75)|0)!=0;
      if ($76) { __label__ = 14; break; } else { __label__ = 15; break; }
    case 14: 
      var $78=$ret;
      $1=$78;
      __label__ = 25; break;
    case 15: 
      var $80=$attr;
      var $81=(($80+314)|0);
      var $82=(($81)|0);
      var $83=HEAPU8[($82)];
      var $84=(($83)&255);
      var $85=(($84)|0)==1;
      if ($85) { __label__ = 17; break; } else { __label__ = 16; break; }
    case 16: 
      var $87=$attr;
      var $88=(($87+314)|0);
      var $89=(($88)|0);
      var $90=HEAPU8[($89)];
      var $91=(($90)&255);
      var $92=(($91)|0)==4;
      if ($92) { __label__ = 17; break; } else { __label__ = 18; break; }
    case 17: 
      var $94=$2;
      var $95=(($94+160)|0);
      var $96=HEAP32[(($95)>>2)];
      var $97=$96 | 2;
      var $98=$2;
      var $99=(($98+160)|0);
      HEAP32[(($99)>>2)]=$97;
      __label__ = 18; break;
    case 18: 
      var $101=$attr;
      var $102=(($101+348)|0);
      var $103=HEAP32[(($102)>>2)];
      var $104=_HPDF_Stream_Seek($103, 78, 1);
      $ret=$104;
      var $105=(($104)|0)!=0;
      if ($105) { __label__ = 19; break; } else { __label__ = 20; break; }
    case 19: 
      var $107=$ret;
      $1=$107;
      __label__ = 25; break;
    case 20: 
      var $109=$attr;
      var $110=(($109+348)|0);
      var $111=HEAP32[(($110)>>2)];
      var $112=$attr;
      var $113=(($112+328)|0);
      var $114=_GetUINT32($111, $113);
      $ret=$114;
      var $115=(($114)|0)!=0;
      if ($115) { __label__ = 21; break; } else { __label__ = 22; break; }
    case 21: 
      var $117=$ret;
      $1=$117;
      __label__ = 25; break;
    case 22: 
      var $119=$attr;
      var $120=(($119+348)|0);
      var $121=HEAP32[(($120)>>2)];
      var $122=$attr;
      var $123=(($122+332)|0);
      var $124=_GetUINT32($121, $123);
      $ret=$124;
      var $125=(($124)|0)!=0;
      if ($125) { __label__ = 23; break; } else { __label__ = 24; break; }
    case 23: 
      var $127=$ret;
      $1=$127;
      __label__ = 25; break;
    case 24: 
      $1=0;
      __label__ = 25; break;
    case 25: 
      var $130=$1;
      STACKTOP = __stackBase__;
      return $130;
    default: assert(0, "bad label: " + __label__);
  }
}
_ParseOS2["X"]=1;

function _GetUINT16($stream, $value) {
  var __stackBase__  = STACKTOP; STACKTOP += 4; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $ret;
      var $size=__stackBase__;
      $2=$stream;
      $3=$value;
      HEAP32[(($size)>>2)]=2;
      var $4=$2;
      var $5=$3;
      var $6=$5;
      var $7=_HPDF_Stream_Read($4, $6, $size);
      $ret=$7;
      var $8=$ret;
      var $9=(($8)|0)!=0;
      if ($9) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $11=$3;
      HEAP16[(($11)>>1)]=0;
      var $12=$ret;
      $1=$12;
      __label__ = 5; break;
    case 4: 
      var $14=$3;
      _UINT16Swap($14);
      $1=0;
      __label__ = 5; break;
    case 5: 
      var $16=$1;
      STACKTOP = __stackBase__;
      return $16;
    default: assert(0, "bad label: " + __label__);
  }
}


function _LoadUnicodeName($stream, $offset, $len, $buf) {
  var __stackBase__  = STACKTOP; STACKTOP += 260; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4=__stackBase__;
      var $5;
      var $tmp=(__stackBase__)+(4);
      var $i;
      var $j;
      var $ret;
      $2=$stream;
      $3=$offset;
      HEAP32[(($4)>>2)]=$len;
      $5=$buf;
      $i=0;
      $j=0;
      var $6=$5;
      var $7=_HPDF_MemSet($6, 0, 128);
      var $8=$2;
      var $9=$3;
      var $10=_HPDF_Stream_Seek($8, $9, 0);
      $ret=$10;
      var $11=(($10)|0)!=0;
      if ($11) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $13=$ret;
      $1=$13;
      __label__ = 10; break;
    case 4: 
      var $15=$2;
      var $16=(($tmp)|0);
      var $17=_HPDF_Stream_Read($15, $16, $4);
      $ret=$17;
      var $18=(($17)|0)!=0;
      if ($18) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $20=$ret;
      $1=$20;
      __label__ = 10; break;
    case 6: 
      __label__ = 7; break;
    case 7: 
      var $23=$i;
      var $24=HEAPU32[(($4)>>2)];
      var $25=(($23)>>>0) < (($24)>>>0);
      if ($25) { __label__ = 8; break; } else { __label__ = 9; break; }
    case 8: 
      var $27=$i;
      var $28=((($27)+(1))|0);
      $i=$28;
      var $29=$i;
      var $30=(($tmp+$29)|0);
      var $31=HEAP8[($30)];
      var $32=$j;
      var $33=$5;
      var $34=(($33+$32)|0);
      HEAP8[($34)]=$31;
      var $35=$j;
      var $36=((($35)+(1))|0);
      $j=$36;
      var $37=$i;
      var $38=((($37)+(1))|0);
      $i=$38;
      __label__ = 7; break;
    case 9: 
      $1=0;
      __label__ = 10; break;
    case 10: 
      var $41=$1;
      STACKTOP = __stackBase__;
      return $41;
    default: assert(0, "bad label: " + __label__);
  }
}
_LoadUnicodeName["X"]=1;

function _ParseCMAP_format4($fontdef, $offset) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $attr;
      var $ret;
      var $i;
      var $pend_count;
      var $pstart_count;
      var $pid_delta;
      var $pid_range_offset;
      var $pglyph_id_array;
      var $num_read;
      $2=$fontdef;
      $3=$offset;
      var $4=$2;
      var $5=(($4+208)|0);
      var $6=HEAP32[(($5)>>2)];
      var $7=$6;
      $attr=$7;
      var $8=$attr;
      var $9=(($8+348)|0);
      var $10=HEAP32[(($9)>>2)];
      var $11=$3;
      var $12=_HPDF_Stream_Seek($10, $11, 0);
      $ret=$12;
      var $13=(($12)|0)!=0;
      if ($13) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $15=$ret;
      $1=$15;
      __label__ = 58; break;
    case 4: 
      var $17=$attr;
      var $18=(($17+348)|0);
      var $19=HEAP32[(($18)>>2)];
      var $20=$attr;
      var $21=(($20+268)|0);
      var $22=(($21)|0);
      var $23=_GetUINT16($19, $22);
      var $24=$ret;
      var $25=((($24)+($23))|0);
      $ret=$25;
      var $26=$attr;
      var $27=(($26+348)|0);
      var $28=HEAP32[(($27)>>2)];
      var $29=$attr;
      var $30=(($29+268)|0);
      var $31=(($30+2)|0);
      var $32=_GetUINT16($28, $31);
      var $33=$ret;
      var $34=((($33)+($32))|0);
      $ret=$34;
      var $35=$attr;
      var $36=(($35+348)|0);
      var $37=HEAP32[(($36)>>2)];
      var $38=$attr;
      var $39=(($38+268)|0);
      var $40=(($39+4)|0);
      var $41=_GetUINT16($37, $40);
      var $42=$ret;
      var $43=((($42)+($41))|0);
      $ret=$43;
      var $44=$ret;
      var $45=(($44)|0)!=0;
      if ($45) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $47=$2;
      var $48=(($47+136)|0);
      var $49=HEAP32[(($48)>>2)];
      var $50=_HPDF_Error_GetCode($49);
      $1=$50;
      __label__ = 58; break;
    case 6: 
      var $52=$attr;
      var $53=(($52+268)|0);
      var $54=(($53)|0);
      var $55=HEAPU16[(($54)>>1)];
      var $56=(($55)&65535);
      var $57=(($56)|0)!=4;
      if ($57) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $59=$2;
      var $60=(($59+136)|0);
      var $61=HEAP32[(($60)>>2)];
      var $62=_HPDF_SetError($61, 4191, 0);
      $1=$62;
      __label__ = 58; break;
    case 8: 
      var $64=$attr;
      var $65=(($64+348)|0);
      var $66=HEAP32[(($65)>>2)];
      var $67=$attr;
      var $68=(($67+268)|0);
      var $69=(($68+6)|0);
      var $70=_GetUINT16($66, $69);
      var $71=$ret;
      var $72=((($71)+($70))|0);
      $ret=$72;
      var $73=$attr;
      var $74=(($73+348)|0);
      var $75=HEAP32[(($74)>>2)];
      var $76=$attr;
      var $77=(($76+268)|0);
      var $78=(($77+8)|0);
      var $79=_GetUINT16($75, $78);
      var $80=$ret;
      var $81=((($80)+($79))|0);
      $ret=$81;
      var $82=$attr;
      var $83=(($82+348)|0);
      var $84=HEAP32[(($83)>>2)];
      var $85=$attr;
      var $86=(($85+268)|0);
      var $87=(($86+10)|0);
      var $88=_GetUINT16($84, $87);
      var $89=$ret;
      var $90=((($89)+($88))|0);
      $ret=$90;
      var $91=$attr;
      var $92=(($91+348)|0);
      var $93=HEAP32[(($92)>>2)];
      var $94=$attr;
      var $95=(($94+268)|0);
      var $96=(($95+12)|0);
      var $97=_GetUINT16($93, $96);
      var $98=$ret;
      var $99=((($98)+($97))|0);
      $ret=$99;
      var $100=$ret;
      var $101=(($100)|0)!=0;
      if ($101) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      var $103=$2;
      var $104=(($103+136)|0);
      var $105=HEAP32[(($104)>>2)];
      var $106=_HPDF_Error_GetCode($105);
      $1=$106;
      __label__ = 58; break;
    case 10: 
      var $108=$2;
      var $109=(($108+132)|0);
      var $110=HEAP32[(($109)>>2)];
      var $111=$attr;
      var $112=(($111+268)|0);
      var $113=(($112+6)|0);
      var $114=HEAPU16[(($113)>>1)];
      var $115=(($114)&65535);
      var $116=((($115<<1))|0);
      var $117=Math.floor(((($116)>>>0))/(2));
      var $118=_HPDF_GetMem($110, $117);
      var $119=$118;
      var $120=$attr;
      var $121=(($120+268)|0);
      var $122=(($121+16)|0);
      HEAP32[(($122)>>2)]=$119;
      var $123=$attr;
      var $124=(($123+268)|0);
      var $125=(($124+16)|0);
      var $126=HEAP32[(($125)>>2)];
      var $127=(($126)|0)!=0;
      if ($127) { __label__ = 12; break; } else { __label__ = 11; break; }
    case 11: 
      var $129=$2;
      var $130=(($129+136)|0);
      var $131=HEAP32[(($130)>>2)];
      var $132=_HPDF_Error_GetCode($131);
      $1=$132;
      __label__ = 58; break;
    case 12: 
      var $134=$attr;
      var $135=(($134+268)|0);
      var $136=(($135+16)|0);
      var $137=HEAP32[(($136)>>2)];
      $pend_count=$137;
      $i=0;
      __label__ = 13; break;
    case 13: 
      var $139=$i;
      var $140=$attr;
      var $141=(($140+268)|0);
      var $142=(($141+6)|0);
      var $143=HEAPU16[(($142)>>1)];
      var $144=(($143)&65535);
      var $145=((((($144)|0))/(2))&-1);
      var $146=(($139)>>>0) < (($145)>>>0);
      if ($146) { __label__ = 14; break; } else { __label__ = 18; break; }
    case 14: 
      var $148=$attr;
      var $149=(($148+348)|0);
      var $150=HEAP32[(($149)>>2)];
      var $151=$pend_count;
      var $152=(($151+2)|0);
      $pend_count=$152;
      var $153=_GetUINT16($150, $151);
      $ret=$153;
      var $154=(($153)|0)!=0;
      if ($154) { __label__ = 15; break; } else { __label__ = 16; break; }
    case 15: 
      var $156=$ret;
      $1=$156;
      __label__ = 58; break;
    case 16: 
      __label__ = 17; break;
    case 17: 
      var $159=$i;
      var $160=((($159)+(1))|0);
      $i=$160;
      __label__ = 13; break;
    case 18: 
      var $162=$attr;
      var $163=(($162+348)|0);
      var $164=HEAP32[(($163)>>2)];
      var $165=$attr;
      var $166=(($165+268)|0);
      var $167=(($166+20)|0);
      var $168=_GetUINT16($164, $167);
      $ret=$168;
      var $169=(($168)|0)!=0;
      if ($169) { __label__ = 19; break; } else { __label__ = 20; break; }
    case 19: 
      var $171=$ret;
      $1=$171;
      __label__ = 58; break;
    case 20: 
      var $173=$2;
      var $174=(($173+132)|0);
      var $175=HEAP32[(($174)>>2)];
      var $176=$attr;
      var $177=(($176+268)|0);
      var $178=(($177+6)|0);
      var $179=HEAPU16[(($178)>>1)];
      var $180=(($179)&65535);
      var $181=((($180<<1))|0);
      var $182=Math.floor(((($181)>>>0))/(2));
      var $183=_HPDF_GetMem($175, $182);
      var $184=$183;
      var $185=$attr;
      var $186=(($185+268)|0);
      var $187=(($186+24)|0);
      HEAP32[(($187)>>2)]=$184;
      var $188=$attr;
      var $189=(($188+268)|0);
      var $190=(($189+24)|0);
      var $191=HEAP32[(($190)>>2)];
      var $192=(($191)|0)!=0;
      if ($192) { __label__ = 22; break; } else { __label__ = 21; break; }
    case 21: 
      var $194=$2;
      var $195=(($194+136)|0);
      var $196=HEAP32[(($195)>>2)];
      var $197=_HPDF_Error_GetCode($196);
      $1=$197;
      __label__ = 58; break;
    case 22: 
      var $199=$attr;
      var $200=(($199+268)|0);
      var $201=(($200+24)|0);
      var $202=HEAP32[(($201)>>2)];
      $pstart_count=$202;
      $i=0;
      __label__ = 23; break;
    case 23: 
      var $204=$i;
      var $205=$attr;
      var $206=(($205+268)|0);
      var $207=(($206+6)|0);
      var $208=HEAPU16[(($207)>>1)];
      var $209=(($208)&65535);
      var $210=((((($209)|0))/(2))&-1);
      var $211=(($204)>>>0) < (($210)>>>0);
      if ($211) { __label__ = 24; break; } else { __label__ = 28; break; }
    case 24: 
      var $213=$attr;
      var $214=(($213+348)|0);
      var $215=HEAP32[(($214)>>2)];
      var $216=$pstart_count;
      var $217=(($216+2)|0);
      $pstart_count=$217;
      var $218=_GetUINT16($215, $216);
      $ret=$218;
      var $219=(($218)|0)!=0;
      if ($219) { __label__ = 25; break; } else { __label__ = 26; break; }
    case 25: 
      var $221=$ret;
      $1=$221;
      __label__ = 58; break;
    case 26: 
      __label__ = 27; break;
    case 27: 
      var $224=$i;
      var $225=((($224)+(1))|0);
      $i=$225;
      __label__ = 23; break;
    case 28: 
      var $227=$2;
      var $228=(($227+132)|0);
      var $229=HEAP32[(($228)>>2)];
      var $230=$attr;
      var $231=(($230+268)|0);
      var $232=(($231+6)|0);
      var $233=HEAPU16[(($232)>>1)];
      var $234=(($233)&65535);
      var $235=((($234<<1))|0);
      var $236=Math.floor(((($235)>>>0))/(2));
      var $237=_HPDF_GetMem($229, $236);
      var $238=$237;
      var $239=$attr;
      var $240=(($239+268)|0);
      var $241=(($240+28)|0);
      HEAP32[(($241)>>2)]=$238;
      var $242=$attr;
      var $243=(($242+268)|0);
      var $244=(($243+28)|0);
      var $245=HEAP32[(($244)>>2)];
      var $246=(($245)|0)!=0;
      if ($246) { __label__ = 30; break; } else { __label__ = 29; break; }
    case 29: 
      var $248=$2;
      var $249=(($248+136)|0);
      var $250=HEAP32[(($249)>>2)];
      var $251=_HPDF_Error_GetCode($250);
      $1=$251;
      __label__ = 58; break;
    case 30: 
      var $253=$attr;
      var $254=(($253+268)|0);
      var $255=(($254+28)|0);
      var $256=HEAP32[(($255)>>2)];
      $pid_delta=$256;
      $i=0;
      __label__ = 31; break;
    case 31: 
      var $258=$i;
      var $259=$attr;
      var $260=(($259+268)|0);
      var $261=(($260+6)|0);
      var $262=HEAPU16[(($261)>>1)];
      var $263=(($262)&65535);
      var $264=((((($263)|0))/(2))&-1);
      var $265=(($258)>>>0) < (($264)>>>0);
      if ($265) { __label__ = 32; break; } else { __label__ = 36; break; }
    case 32: 
      var $267=$attr;
      var $268=(($267+348)|0);
      var $269=HEAP32[(($268)>>2)];
      var $270=$pid_delta;
      var $271=(($270+2)|0);
      $pid_delta=$271;
      var $272=_GetINT16($269, $270);
      $ret=$272;
      var $273=(($272)|0)!=0;
      if ($273) { __label__ = 33; break; } else { __label__ = 34; break; }
    case 33: 
      var $275=$ret;
      $1=$275;
      __label__ = 58; break;
    case 34: 
      __label__ = 35; break;
    case 35: 
      var $278=$i;
      var $279=((($278)+(1))|0);
      $i=$279;
      __label__ = 31; break;
    case 36: 
      var $281=$2;
      var $282=(($281+132)|0);
      var $283=HEAP32[(($282)>>2)];
      var $284=$attr;
      var $285=(($284+268)|0);
      var $286=(($285+6)|0);
      var $287=HEAPU16[(($286)>>1)];
      var $288=(($287)&65535);
      var $289=((($288<<1))|0);
      var $290=Math.floor(((($289)>>>0))/(2));
      var $291=_HPDF_GetMem($283, $290);
      var $292=$291;
      var $293=$attr;
      var $294=(($293+268)|0);
      var $295=(($294+32)|0);
      HEAP32[(($295)>>2)]=$292;
      var $296=$attr;
      var $297=(($296+268)|0);
      var $298=(($297+32)|0);
      var $299=HEAP32[(($298)>>2)];
      var $300=(($299)|0)!=0;
      if ($300) { __label__ = 38; break; } else { __label__ = 37; break; }
    case 37: 
      var $302=$2;
      var $303=(($302+136)|0);
      var $304=HEAP32[(($303)>>2)];
      var $305=_HPDF_Error_GetCode($304);
      $1=$305;
      __label__ = 58; break;
    case 38: 
      var $307=$attr;
      var $308=(($307+268)|0);
      var $309=(($308+32)|0);
      var $310=HEAP32[(($309)>>2)];
      $pid_range_offset=$310;
      $i=0;
      __label__ = 39; break;
    case 39: 
      var $312=$i;
      var $313=$attr;
      var $314=(($313+268)|0);
      var $315=(($314+6)|0);
      var $316=HEAPU16[(($315)>>1)];
      var $317=(($316)&65535);
      var $318=((((($317)|0))/(2))&-1);
      var $319=(($312)>>>0) < (($318)>>>0);
      if ($319) { __label__ = 40; break; } else { __label__ = 44; break; }
    case 40: 
      var $321=$attr;
      var $322=(($321+348)|0);
      var $323=HEAP32[(($322)>>2)];
      var $324=$pid_range_offset;
      var $325=(($324+2)|0);
      $pid_range_offset=$325;
      var $326=_GetUINT16($323, $324);
      $ret=$326;
      var $327=(($326)|0)!=0;
      if ($327) { __label__ = 41; break; } else { __label__ = 42; break; }
    case 41: 
      var $329=$ret;
      $1=$329;
      __label__ = 58; break;
    case 42: 
      __label__ = 43; break;
    case 43: 
      var $332=$i;
      var $333=((($332)+(1))|0);
      $i=$333;
      __label__ = 39; break;
    case 44: 
      var $335=$attr;
      var $336=(($335+348)|0);
      var $337=HEAP32[(($336)>>2)];
      var $338=_HPDF_Stream_Tell($337);
      var $339=$3;
      var $340=((($338)-($339))|0);
      $num_read=$340;
      var $341=$num_read;
      var $342=(($341)|0) < 0;
      if ($342) { __label__ = 45; break; } else { __label__ = 46; break; }
    case 45: 
      var $344=$2;
      var $345=(($344+136)|0);
      var $346=HEAP32[(($345)>>2)];
      var $347=_HPDF_Error_GetCode($346);
      $1=$347;
      __label__ = 58; break;
    case 46: 
      var $349=$attr;
      var $350=(($349+268)|0);
      var $351=(($350+2)|0);
      var $352=HEAPU16[(($351)>>1)];
      var $353=(($352)&65535);
      var $354=$num_read;
      var $355=((($353)-($354))|0);
      var $356=((((($355)|0))/(2))&-1);
      var $357=$attr;
      var $358=(($357+268)|0);
      var $359=(($358+40)|0);
      HEAP32[(($359)>>2)]=$356;
      var $360=$attr;
      var $361=(($360+268)|0);
      var $362=(($361+40)|0);
      var $363=HEAPU32[(($362)>>2)];
      var $364=(($363)>>>0) > 0;
      if ($364) { __label__ = 47; break; } else { __label__ = 56; break; }
    case 47: 
      var $366=$2;
      var $367=(($366+132)|0);
      var $368=HEAP32[(($367)>>2)];
      var $369=$attr;
      var $370=(($369+268)|0);
      var $371=(($370+40)|0);
      var $372=HEAP32[(($371)>>2)];
      var $373=((($372<<1))|0);
      var $374=_HPDF_GetMem($368, $373);
      var $375=$374;
      var $376=$attr;
      var $377=(($376+268)|0);
      var $378=(($377+36)|0);
      HEAP32[(($378)>>2)]=$375;
      var $379=$attr;
      var $380=(($379+268)|0);
      var $381=(($380+36)|0);
      var $382=HEAP32[(($381)>>2)];
      var $383=(($382)|0)!=0;
      if ($383) { __label__ = 49; break; } else { __label__ = 48; break; }
    case 48: 
      var $385=$2;
      var $386=(($385+136)|0);
      var $387=HEAP32[(($386)>>2)];
      var $388=_HPDF_Error_GetCode($387);
      $1=$388;
      __label__ = 58; break;
    case 49: 
      var $390=$attr;
      var $391=(($390+268)|0);
      var $392=(($391+36)|0);
      var $393=HEAP32[(($392)>>2)];
      $pglyph_id_array=$393;
      $i=0;
      __label__ = 50; break;
    case 50: 
      var $395=$i;
      var $396=$attr;
      var $397=(($396+268)|0);
      var $398=(($397+40)|0);
      var $399=HEAPU32[(($398)>>2)];
      var $400=(($395)>>>0) < (($399)>>>0);
      if ($400) { __label__ = 51; break; } else { __label__ = 55; break; }
    case 51: 
      var $402=$attr;
      var $403=(($402+348)|0);
      var $404=HEAP32[(($403)>>2)];
      var $405=$pglyph_id_array;
      var $406=(($405+2)|0);
      $pglyph_id_array=$406;
      var $407=_GetUINT16($404, $405);
      $ret=$407;
      var $408=(($407)|0)!=0;
      if ($408) { __label__ = 52; break; } else { __label__ = 53; break; }
    case 52: 
      var $410=$ret;
      $1=$410;
      __label__ = 58; break;
    case 53: 
      __label__ = 54; break;
    case 54: 
      var $413=$i;
      var $414=((($413)+(1))|0);
      $i=$414;
      __label__ = 50; break;
    case 55: 
      __label__ = 57; break;
    case 56: 
      var $417=$attr;
      var $418=(($417+268)|0);
      var $419=(($418+36)|0);
      HEAP32[(($419)>>2)]=0;
      __label__ = 57; break;
    case 57: 
      $1=0;
      __label__ = 58; break;
    case 58: 
      var $422=$1;
      ;
      return $422;
    default: assert(0, "bad label: " + __label__);
  }
}
_ParseCMAP_format4["X"]=1;

function _ParseCMAP_format0($fontdef, $offset) {
  var __stackBase__  = STACKTOP; STACKTOP += 260; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $attr;
      var $ret;
      var $array=__stackBase__;
      var $size=(__stackBase__)+(256);
      var $parray;
      var $i;
      $2=$fontdef;
      $3=$offset;
      var $4=$2;
      var $5=(($4+208)|0);
      var $6=HEAP32[(($5)>>2)];
      var $7=$6;
      $attr=$7;
      var $8=$attr;
      var $9=(($8+348)|0);
      var $10=HEAP32[(($9)>>2)];
      var $11=$3;
      var $12=_HPDF_Stream_Seek($10, $11, 0);
      $ret=$12;
      var $13=$ret;
      var $14=(($13)|0)!=0;
      if ($14) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $16=$ret;
      $1=$16;
      __label__ = 17; break;
    case 4: 
      var $18=$attr;
      var $19=(($18+348)|0);
      var $20=HEAP32[(($19)>>2)];
      var $21=$attr;
      var $22=(($21+268)|0);
      var $23=(($22)|0);
      var $24=_GetUINT16($20, $23);
      var $25=$ret;
      var $26=((($25)+($24))|0);
      $ret=$26;
      var $27=$attr;
      var $28=(($27+348)|0);
      var $29=HEAP32[(($28)>>2)];
      var $30=$attr;
      var $31=(($30+268)|0);
      var $32=(($31+2)|0);
      var $33=_GetUINT16($29, $32);
      var $34=$ret;
      var $35=((($34)+($33))|0);
      $ret=$35;
      var $36=$attr;
      var $37=(($36+348)|0);
      var $38=HEAP32[(($37)>>2)];
      var $39=$attr;
      var $40=(($39+268)|0);
      var $41=(($40+4)|0);
      var $42=_GetUINT16($38, $41);
      var $43=$ret;
      var $44=((($43)+($42))|0);
      $ret=$44;
      var $45=$ret;
      var $46=(($45)|0)!=0;
      if ($46) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $48=$2;
      var $49=(($48+136)|0);
      var $50=HEAP32[(($49)>>2)];
      var $51=_HPDF_Error_GetCode($50);
      $1=$51;
      __label__ = 17; break;
    case 6: 
      var $53=$attr;
      var $54=(($53+268)|0);
      var $55=(($54)|0);
      var $56=HEAPU16[(($55)>>1)];
      var $57=(($56)&65535);
      var $58=(($57)|0)!=0;
      if ($58) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $60=$2;
      var $61=(($60+136)|0);
      var $62=HEAP32[(($61)>>2)];
      var $63=_HPDF_SetError($62, 4191, 0);
      $1=$63;
      __label__ = 17; break;
    case 8: 
      HEAP32[(($size)>>2)]=256;
      var $65=$attr;
      var $66=(($65+348)|0);
      var $67=HEAP32[(($66)>>2)];
      var $68=(($array)|0);
      var $69=_HPDF_Stream_Read($67, $68, $size);
      $ret=$69;
      var $70=$ret;
      var $71=(($70)|0)!=0;
      if ($71) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      var $73=$ret;
      $1=$73;
      __label__ = 17; break;
    case 10: 
      var $75=$attr;
      var $76=(($75+268)|0);
      var $77=(($76+40)|0);
      HEAP32[(($77)>>2)]=256;
      var $78=$2;
      var $79=(($78+132)|0);
      var $80=HEAP32[(($79)>>2)];
      var $81=_HPDF_GetMem($80, 512);
      var $82=$81;
      var $83=$attr;
      var $84=(($83+268)|0);
      var $85=(($84+36)|0);
      HEAP32[(($85)>>2)]=$82;
      var $86=$attr;
      var $87=(($86+268)|0);
      var $88=(($87+36)|0);
      var $89=HEAP32[(($88)>>2)];
      var $90=(($89)|0)!=0;
      if ($90) { __label__ = 12; break; } else { __label__ = 11; break; }
    case 11: 
      var $92=$2;
      var $93=(($92+136)|0);
      var $94=HEAP32[(($93)>>2)];
      var $95=_HPDF_Error_GetCode($94);
      $1=$95;
      __label__ = 17; break;
    case 12: 
      var $97=$attr;
      var $98=(($97+268)|0);
      var $99=(($98+36)|0);
      var $100=HEAP32[(($99)>>2)];
      $parray=$100;
      $i=0;
      __label__ = 13; break;
    case 13: 
      var $102=$i;
      var $103=(($102)>>>0) < 256;
      if ($103) { __label__ = 14; break; } else { __label__ = 16; break; }
    case 14: 
      var $105=$i;
      var $106=$attr;
      var $107=(($106+268)|0);
      var $108=(($107+36)|0);
      var $109=HEAP32[(($108)>>2)];
      var $110=(($109+($105<<1))|0);
      var $111=HEAP16[(($110)>>1)];
      var $112=$parray;
      HEAP16[(($112)>>1)]=$111;
      var $113=$parray;
      var $114=(($113+2)|0);
      $parray=$114;
      __label__ = 15; break;
    case 15: 
      var $116=$i;
      var $117=((($116)+(1))|0);
      $i=$117;
      __label__ = 13; break;
    case 16: 
      $1=0;
      __label__ = 17; break;
    case 17: 
      var $120=$1;
      STACKTOP = __stackBase__;
      return $120;
    default: assert(0, "bad label: " + __label__);
  }
}
_ParseCMAP_format0["X"]=1;

function _InitAttr($fontdef) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $attr;
      $1=$fontdef;
      var $2=$1;
      var $3=(($2+208)|0);
      var $4=HEAP32[(($3)>>2)];
      var $5=$4;
      $attr=$5;
      var $6=$attr;
      var $7=(($6)|0)!=0;
      if ($7) { __label__ = 3; break; } else { __label__ = 28; break; }
    case 3: 
      var $9=$attr;
      var $10=(($9+132)|0);
      var $11=HEAP32[(($10)>>2)];
      var $12=(($11)|0)!=0;
      if ($12) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      var $14=$1;
      var $15=(($14+132)|0);
      var $16=HEAP32[(($15)>>2)];
      var $17=$attr;
      var $18=(($17+132)|0);
      var $19=HEAP32[(($18)>>2)];
      _HPDF_FreeMem($16, $19);
      __label__ = 5; break;
    case 5: 
      var $21=$attr;
      var $22=(($21+244)|0);
      var $23=HEAP32[(($22)>>2)];
      var $24=(($23)|0)!=0;
      if ($24) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      var $26=$1;
      var $27=(($26+132)|0);
      var $28=HEAP32[(($27)>>2)];
      var $29=$attr;
      var $30=(($29+244)|0);
      var $31=HEAP32[(($30)>>2)];
      var $32=$31;
      _HPDF_FreeMem($28, $32);
      __label__ = 7; break;
    case 7: 
      var $34=$attr;
      var $35=(($34+232)|0);
      var $36=(($35+8)|0);
      var $37=HEAP32[(($36)>>2)];
      var $38=(($37)|0)!=0;
      if ($38) { __label__ = 8; break; } else { __label__ = 9; break; }
    case 8: 
      var $40=$1;
      var $41=(($40+132)|0);
      var $42=HEAP32[(($41)>>2)];
      var $43=$attr;
      var $44=(($43+232)|0);
      var $45=(($44+8)|0);
      var $46=HEAP32[(($45)>>2)];
      var $47=$46;
      _HPDF_FreeMem($42, $47);
      __label__ = 9; break;
    case 9: 
      var $49=$attr;
      var $50=(($49+268)|0);
      var $51=(($50+16)|0);
      var $52=HEAP32[(($51)>>2)];
      var $53=(($52)|0)!=0;
      if ($53) { __label__ = 10; break; } else { __label__ = 11; break; }
    case 10: 
      var $55=$1;
      var $56=(($55+132)|0);
      var $57=HEAP32[(($56)>>2)];
      var $58=$attr;
      var $59=(($58+268)|0);
      var $60=(($59+16)|0);
      var $61=HEAP32[(($60)>>2)];
      var $62=$61;
      _HPDF_FreeMem($57, $62);
      __label__ = 11; break;
    case 11: 
      var $64=$attr;
      var $65=(($64+268)|0);
      var $66=(($65+24)|0);
      var $67=HEAP32[(($66)>>2)];
      var $68=(($67)|0)!=0;
      if ($68) { __label__ = 12; break; } else { __label__ = 13; break; }
    case 12: 
      var $70=$1;
      var $71=(($70+132)|0);
      var $72=HEAP32[(($71)>>2)];
      var $73=$attr;
      var $74=(($73+268)|0);
      var $75=(($74+24)|0);
      var $76=HEAP32[(($75)>>2)];
      var $77=$76;
      _HPDF_FreeMem($72, $77);
      __label__ = 13; break;
    case 13: 
      var $79=$attr;
      var $80=(($79+268)|0);
      var $81=(($80+28)|0);
      var $82=HEAP32[(($81)>>2)];
      var $83=(($82)|0)!=0;
      if ($83) { __label__ = 14; break; } else { __label__ = 15; break; }
    case 14: 
      var $85=$1;
      var $86=(($85+132)|0);
      var $87=HEAP32[(($86)>>2)];
      var $88=$attr;
      var $89=(($88+268)|0);
      var $90=(($89+28)|0);
      var $91=HEAP32[(($90)>>2)];
      var $92=$91;
      _HPDF_FreeMem($87, $92);
      __label__ = 15; break;
    case 15: 
      var $94=$attr;
      var $95=(($94+268)|0);
      var $96=(($95+32)|0);
      var $97=HEAP32[(($96)>>2)];
      var $98=(($97)|0)!=0;
      if ($98) { __label__ = 16; break; } else { __label__ = 17; break; }
    case 16: 
      var $100=$1;
      var $101=(($100+132)|0);
      var $102=HEAP32[(($101)>>2)];
      var $103=$attr;
      var $104=(($103+268)|0);
      var $105=(($104+32)|0);
      var $106=HEAP32[(($105)>>2)];
      var $107=$106;
      _HPDF_FreeMem($102, $107);
      __label__ = 17; break;
    case 17: 
      var $109=$attr;
      var $110=(($109+268)|0);
      var $111=(($110+36)|0);
      var $112=HEAP32[(($111)>>2)];
      var $113=(($112)|0)!=0;
      if ($113) { __label__ = 18; break; } else { __label__ = 19; break; }
    case 18: 
      var $115=$1;
      var $116=(($115+132)|0);
      var $117=HEAP32[(($116)>>2)];
      var $118=$attr;
      var $119=(($118+268)|0);
      var $120=(($119+36)|0);
      var $121=HEAP32[(($120)>>2)];
      var $122=$121;
      _HPDF_FreeMem($117, $122);
      __label__ = 19; break;
    case 19: 
      var $124=$attr;
      var $125=(($124+252)|0);
      var $126=(($125+12)|0);
      var $127=HEAP32[(($126)>>2)];
      var $128=(($127)|0)!=0;
      if ($128) { __label__ = 20; break; } else { __label__ = 21; break; }
    case 20: 
      var $130=$1;
      var $131=(($130+132)|0);
      var $132=HEAP32[(($131)>>2)];
      var $133=$attr;
      var $134=(($133+252)|0);
      var $135=(($134+12)|0);
      var $136=HEAP32[(($135)>>2)];
      var $137=$136;
      _HPDF_FreeMem($132, $137);
      __label__ = 21; break;
    case 21: 
      var $139=$attr;
      var $140=(($139+216)|0);
      var $141=(($140+8)|0);
      var $142=HEAP32[(($141)>>2)];
      var $143=(($142)|0)!=0;
      if ($143) { __label__ = 22; break; } else { __label__ = 23; break; }
    case 22: 
      var $145=$1;
      var $146=(($145+132)|0);
      var $147=HEAP32[(($146)>>2)];
      var $148=$attr;
      var $149=(($148+216)|0);
      var $150=(($149+8)|0);
      var $151=HEAP32[(($150)>>2)];
      _HPDF_FreeMem($147, $151);
      __label__ = 23; break;
    case 23: 
      var $153=$attr;
      var $154=(($153+216)|0);
      var $155=(($154+4)|0);
      var $156=HEAP32[(($155)>>2)];
      var $157=(($156)|0)!=0;
      if ($157) { __label__ = 24; break; } else { __label__ = 25; break; }
    case 24: 
      var $159=$1;
      var $160=(($159+132)|0);
      var $161=HEAP32[(($160)>>2)];
      var $162=$attr;
      var $163=(($162+216)|0);
      var $164=(($163+4)|0);
      var $165=HEAP32[(($164)>>2)];
      var $166=$165;
      _HPDF_FreeMem($161, $166);
      __label__ = 25; break;
    case 25: 
      var $168=$attr;
      var $169=(($168+348)|0);
      var $170=HEAP32[(($169)>>2)];
      var $171=(($170)|0)!=0;
      if ($171) { __label__ = 26; break; } else { __label__ = 27; break; }
    case 26: 
      var $173=$attr;
      var $174=(($173+348)|0);
      var $175=HEAP32[(($174)>>2)];
      _HPDF_Stream_Free($175);
      __label__ = 27; break;
    case 27: 
      __label__ = 28; break;
    case 28: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_InitAttr["X"]=1;

function _HPDF_Type1FontDef_New($mmgr) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $fontdef;
      var $fontdef_attr;
      $2=$mmgr;
      var $3=$2;
      var $4=(($3)|0)!=0;
      if ($4) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=0;
      __label__ = 9; break;
    case 4: 
      var $7=$2;
      var $8=_HPDF_GetMem($7, 212);
      var $9=$8;
      $fontdef=$9;
      var $10=$fontdef;
      var $11=(($10)|0)!=0;
      if ($11) { __label__ = 6; break; } else { __label__ = 5; break; }
    case 5: 
      $1=0;
      __label__ = 9; break;
    case 6: 
      var $14=$fontdef;
      var $15=(($14)|0);
      HEAP32[(($15)>>2)]=1179602516;
      var $16=$fontdef;
      var $17=(($16+4)|0);
      var $18=(($17)|0);
      HEAP8[($18)]=0;
      var $19=$2;
      var $20=$fontdef;
      var $21=(($20+132)|0);
      HEAP32[(($21)>>2)]=$19;
      var $22=$2;
      var $23=(($22)|0);
      var $24=HEAP32[(($23)>>2)];
      var $25=$fontdef;
      var $26=(($25+136)|0);
      HEAP32[(($26)>>2)]=$24;
      var $27=$fontdef;
      var $28=(($27+140)|0);
      HEAP32[(($28)>>2)]=0;
      var $29=$fontdef;
      var $30=(($29+144)|0);
      HEAP32[(($30)>>2)]=0;
      var $31=$fontdef;
      var $32=(($31+148)|0);
      HEAP32[(($32)>>2)]=192;
      var $33=$fontdef;
      var $34=(($33+196)|0);
      HEAP32[(($34)>>2)]=0;
      var $35=$fontdef;
      var $36=(($35+204)|0);
      HEAP32[(($36)>>2)]=0;
      var $37=$2;
      var $38=_HPDF_GetMem($37, 172);
      var $39=$38;
      $fontdef_attr=$39;
      var $40=$fontdef_attr;
      var $41=(($40)|0)!=0;
      if ($41) { __label__ = 8; break; } else { __label__ = 7; break; }
    case 7: 
      var $43=$fontdef;
      var $44=(($43+132)|0);
      var $45=HEAP32[(($44)>>2)];
      var $46=$fontdef;
      var $47=$46;
      _HPDF_FreeMem($45, $47);
      $1=0;
      __label__ = 9; break;
    case 8: 
      var $49=$fontdef_attr;
      var $50=$49;
      var $51=$fontdef;
      var $52=(($51+208)|0);
      HEAP32[(($52)>>2)]=$50;
      var $53=$fontdef_attr;
      var $54=$53;
      var $55=_HPDF_MemSet($54, 0, 172);
      var $56=$fontdef;
      var $57=(($56+160)|0);
      HEAP32[(($57)>>2)]=32;
      var $58=$fontdef;
      $1=$58;
      __label__ = 9; break;
    case 9: 
      var $60=$1;
      ;
      return $60;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Type1FontDef_New["X"]=1;

function _FreeFunc1360($fontdef) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $attr;
      $1=$fontdef;
      var $2=$1;
      var $3=(($2+208)|0);
      var $4=HEAP32[(($3)>>2)];
      var $5=$4;
      $attr=$5;
      var $6=$attr;
      var $7=(($6+16)|0);
      var $8=HEAP32[(($7)>>2)];
      var $9=(($8)|0)!=0;
      if ($9) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $11=$1;
      var $12=(($11+132)|0);
      var $13=HEAP32[(($12)>>2)];
      var $14=$attr;
      var $15=(($14+16)|0);
      var $16=HEAP32[(($15)>>2)];
      _HPDF_FreeMem($13, $16);
      __label__ = 4; break;
    case 4: 
      var $18=$attr;
      var $19=(($18+168)|0);
      var $20=HEAP32[(($19)>>2)];
      var $21=(($20)|0)!=0;
      if ($21) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $23=$attr;
      var $24=(($23+168)|0);
      var $25=HEAP32[(($24)>>2)];
      _HPDF_Stream_Free($25);
      __label__ = 6; break;
    case 6: 
      var $27=$1;
      var $28=(($27+132)|0);
      var $29=HEAP32[(($28)>>2)];
      var $30=$attr;
      var $31=(($30+4)|0);
      var $32=HEAP32[(($31)>>2)];
      var $33=$32;
      _HPDF_FreeMem($29, $33);
      var $34=$1;
      var $35=(($34+132)|0);
      var $36=HEAP32[(($35)>>2)];
      var $37=$attr;
      var $38=$37;
      _HPDF_FreeMem($36, $38);
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Type1FontDef_Load($mmgr, $afm, $font_data) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $fontdef;
      var $ret;
      $2=$mmgr;
      $3=$afm;
      $4=$font_data;
      var $5=$3;
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=0;
      __label__ = 13; break;
    case 4: 
      var $9=$2;
      var $10=_HPDF_Type1FontDef_New($9);
      $fontdef=$10;
      var $11=$fontdef;
      var $12=(($11)|0)!=0;
      if ($12) { __label__ = 6; break; } else { __label__ = 5; break; }
    case 5: 
      $1=0;
      __label__ = 13; break;
    case 6: 
      var $15=$fontdef;
      var $16=$3;
      var $17=_LoadAfm($15, $16);
      $ret=$17;
      var $18=$ret;
      var $19=(($18)|0)!=0;
      if ($19) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $21=$fontdef;
      _HPDF_FontDef_Free($21);
      $1=0;
      __label__ = 13; break;
    case 8: 
      var $23=$4;
      var $24=(($23)|0)!=0;
      if ($24) { __label__ = 9; break; } else { __label__ = 12; break; }
    case 9: 
      var $26=$fontdef;
      var $27=$4;
      var $28=_LoadFontData1363($26, $27);
      $ret=$28;
      var $29=$ret;
      var $30=(($29)|0)!=0;
      if ($30) { __label__ = 10; break; } else { __label__ = 11; break; }
    case 10: 
      var $32=$fontdef;
      _HPDF_FontDef_Free($32);
      $1=0;
      __label__ = 13; break;
    case 11: 
      __label__ = 12; break;
    case 12: 
      var $35=$fontdef;
      $1=$35;
      __label__ = 13; break;
    case 13: 
      var $37=$1;
      ;
      return $37;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Type1FontDef_Load["X"]=1;

function _LoadAfm($fontdef, $stream) {
  var __stackBase__  = STACKTOP; STACKTOP += 784; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $attr;
      var $buf=__stackBase__;
      var $cdata;
      var $ret;
      var $len=(__stackBase__)+(512);
      var $keyword=(__stackBase__)+(516);
      var $i;
      var $s;
      var $len1;
      var $buf2=(__stackBase__)+(644);
      var $s3;
      var $buf24=(__stackBase__)+(656);
      $2=$fontdef;
      $3=$stream;
      var $4=$2;
      var $5=(($4+208)|0);
      var $6=HEAP32[(($5)>>2)];
      var $7=$6;
      $attr=$7;
      HEAP32[(($len)>>2)]=512;
      var $8=$3;
      var $9=(($buf)|0);
      var $10=_HPDF_Stream_ReadLn($8, $9, $len);
      $ret=$10;
      var $11=(($10)|0)!=0;
      if ($11) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $13=$ret;
      $1=$13;
      __label__ = 79; break;
    case 4: 
      var $15=(($buf)|0);
      var $16=(($keyword)|0);
      var $17=_GetKeyword($15, $16, 128);
      var $18=(($keyword)|0);
      var $19=_HPDF_StrCmp($18, ((STRING_TABLE.__str21338)|0));
      var $20=(($19)|0)!=0;
      if ($20) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      $1=4123;
      __label__ = 79; break;
    case 6: 
      __label__ = 7; break;
    case 7: 
      HEAP32[(($len)>>2)]=512;
      var $24=$3;
      var $25=(($buf)|0);
      var $26=_HPDF_Stream_ReadLn($24, $25, $len);
      $ret=$26;
      var $27=(($26)|0)!=0;
      if ($27) { __label__ = 8; break; } else { __label__ = 9; break; }
    case 8: 
      var $29=$ret;
      $1=$29;
      __label__ = 79; break;
    case 9: 
      var $31=(($buf)|0);
      var $32=(($keyword)|0);
      var $33=_GetKeyword($31, $32, 128);
      $s=$33;
      var $34=(($keyword)|0);
      var $35=_HPDF_StrCmp($34, ((STRING_TABLE.__str31339)|0));
      var $36=(($35)|0)==0;
      if ($36) { __label__ = 10; break; } else { __label__ = 11; break; }
    case 10: 
      var $38=$2;
      var $39=(($38+4)|0);
      var $40=(($39)|0);
      var $41=$s;
      var $42=$2;
      var $43=(($42+4)|0);
      var $44=(($43)|0);
      var $45=(($44+127)|0);
      var $46=_HPDF_StrCpy($40, $41, $45);
      __label__ = 57; break;
    case 11: 
      var $48=(($keyword)|0);
      var $49=_HPDF_StrCmp($48, ((STRING_TABLE.__str41340)|0));
      var $50=(($49)|0)==0;
      if ($50) { __label__ = 12; break; } else { __label__ = 15; break; }
    case 12: 
      var $52=$s;
      var $53=_HPDF_StrCmp($52, ((STRING_TABLE.__str51341)|0));
      var $54=(($53)|0)==0;
      if ($54) { __label__ = 13; break; } else { __label__ = 14; break; }
    case 13: 
      var $56=$2;
      var $57=(($56+160)|0);
      var $58=HEAP32[(($57)>>2)];
      var $59=$58 | 262144;
      HEAP32[(($57)>>2)]=$59;
      __label__ = 14; break;
    case 14: 
      __label__ = 56; break;
    case 15: 
      var $62=(($keyword)|0);
      var $63=_HPDF_StrCmp($62, ((STRING_TABLE.__str61342)|0));
      var $64=(($63)|0)==0;
      if ($64) { __label__ = 16; break; } else { __label__ = 19; break; }
    case 16: 
      var $66=$s;
      var $67=_HPDF_StrCmp($66, ((STRING_TABLE.__str71343)|0));
      var $68=(($67)|0)==0;
      if ($68) { __label__ = 17; break; } else { __label__ = 18; break; }
    case 17: 
      var $70=$2;
      var $71=(($70+160)|0);
      var $72=HEAP32[(($71)>>2)];
      var $73=$72 | 1;
      HEAP32[(($71)>>2)]=$73;
      __label__ = 18; break;
    case 18: 
      __label__ = 55; break;
    case 19: 
      var $76=(($keyword)|0);
      var $77=_HPDF_StrCmp($76, ((STRING_TABLE.__str81344)|0));
      var $78=(($77)|0)==0;
      if ($78) { __label__ = 20; break; } else { __label__ = 23; break; }
    case 20: 
      var $80=$s;
      var $81=_HPDF_AToI($80);
      var $82=(($81) & 65535);
      var $83=$2;
      var $84=(($83+180)|0);
      HEAP16[(($84)>>1)]=$82;
      var $85=$2;
      var $86=(($85+180)|0);
      var $87=HEAP16[(($86)>>1)];
      var $88=(($87 << 16) >> 16);
      var $89=(($88)|0)!=0;
      if ($89) { __label__ = 21; break; } else { __label__ = 22; break; }
    case 21: 
      var $91=$2;
      var $92=(($91+160)|0);
      var $93=HEAP32[(($92)>>2)];
      var $94=$93 | 64;
      HEAP32[(($92)>>2)]=$94;
      __label__ = 22; break;
    case 22: 
      __label__ = 54; break;
    case 23: 
      var $97=(($keyword)|0);
      var $98=_HPDF_StrCmp($97, ((STRING_TABLE.__str91345)|0));
      var $99=(($98)|0)==0;
      if ($99) { __label__ = 24; break; } else { __label__ = 29; break; }
    case 24: 
      var $101=$s;
      var $102=_HPDF_StrLen($101, 65535);
      $len1=$102;
      var $103=$len1;
      var $104=(($103)>>>0) > 0;
      if ($104) { __label__ = 25; break; } else { __label__ = 28; break; }
    case 25: 
      var $106=$2;
      var $107=(($106+132)|0);
      var $108=HEAP32[(($107)>>2)];
      var $109=$len1;
      var $110=((($109)+(1))|0);
      var $111=_HPDF_GetMem($108, $110);
      var $112=$attr;
      var $113=(($112+16)|0);
      HEAP32[(($113)>>2)]=$111;
      var $114=$attr;
      var $115=(($114+16)|0);
      var $116=HEAP32[(($115)>>2)];
      var $117=(($116)|0)!=0;
      if ($117) { __label__ = 27; break; } else { __label__ = 26; break; }
    case 26: 
      var $119=$2;
      var $120=(($119+136)|0);
      var $121=HEAP32[(($120)>>2)];
      var $122=_HPDF_Error_GetCode($121);
      $1=$122;
      __label__ = 79; break;
    case 27: 
      var $124=$attr;
      var $125=(($124+16)|0);
      var $126=HEAP32[(($125)>>2)];
      var $127=$s;
      var $128=$attr;
      var $129=(($128+16)|0);
      var $130=HEAP32[(($129)>>2)];
      var $131=$len1;
      var $132=(($130+$131)|0);
      var $133=_HPDF_StrCpy($126, $127, $132);
      __label__ = 28; break;
    case 28: 
      __label__ = 53; break;
    case 29: 
      var $136=(($keyword)|0);
      var $137=_HPDF_StrCmp($136, ((STRING_TABLE.__str101346)|0));
      var $138=(($137)|0)==0;
      if ($138) { __label__ = 30; break; } else { __label__ = 31; break; }
    case 30: 
      var $140=$s;
      var $141=(($buf2)|0);
      var $142=_GetKeyword($140, $141, 12);
      $s=$142;
      var $143=(($buf2)|0);
      var $144=_HPDF_AToI($143);
      var $145=(($144)|0);
      var $146=$2;
      var $147=(($146+164)|0);
      var $148=(($147)|0);
      HEAPF32[(($148)>>2)]=$145;
      var $149=$s;
      var $150=(($buf2)|0);
      var $151=_GetKeyword($149, $150, 12);
      $s=$151;
      var $152=(($buf2)|0);
      var $153=_HPDF_AToI($152);
      var $154=(($153)|0);
      var $155=$2;
      var $156=(($155+164)|0);
      var $157=(($156+4)|0);
      HEAPF32[(($157)>>2)]=$154;
      var $158=$s;
      var $159=(($buf2)|0);
      var $160=_GetKeyword($158, $159, 12);
      $s=$160;
      var $161=(($buf2)|0);
      var $162=_HPDF_AToI($161);
      var $163=(($162)|0);
      var $164=$2;
      var $165=(($164+164)|0);
      var $166=(($165+8)|0);
      HEAPF32[(($166)>>2)]=$163;
      var $167=$s;
      var $168=(($buf2)|0);
      var $169=_GetKeyword($167, $168, 12);
      var $170=(($buf2)|0);
      var $171=_HPDF_AToI($170);
      var $172=(($171)|0);
      var $173=$2;
      var $174=(($173+164)|0);
      var $175=(($174+12)|0);
      HEAPF32[(($175)>>2)]=$172;
      __label__ = 52; break;
    case 31: 
      var $177=(($keyword)|0);
      var $178=_HPDF_StrCmp($177, ((STRING_TABLE.__str111347)|0));
      var $179=(($178)|0)==0;
      if ($179) { __label__ = 32; break; } else { __label__ = 33; break; }
    case 32: 
      var $181=$attr;
      var $182=(($181+20)|0);
      var $183=(($182)|0);
      var $184=$s;
      var $185=$attr;
      var $186=(($185+20)|0);
      var $187=(($186)|0);
      var $188=(($187+127)|0);
      var $189=_HPDF_StrCpy($183, $184, $188);
      __label__ = 51; break;
    case 33: 
      var $191=(($keyword)|0);
      var $192=_HPDF_StrCmp($191, ((STRING_TABLE.__str121348)|0));
      var $193=(($192)|0)==0;
      if ($193) { __label__ = 34; break; } else { __label__ = 35; break; }
    case 34: 
      var $195=$s;
      var $196=_HPDF_AToI($195);
      var $197=(($196) & 65535);
      var $198=$2;
      var $199=(($198+194)|0);
      HEAP16[(($199)>>1)]=$197;
      __label__ = 50; break;
    case 35: 
      var $201=(($keyword)|0);
      var $202=_HPDF_StrCmp($201, ((STRING_TABLE.__str131349)|0));
      var $203=(($202)|0)==0;
      if ($203) { __label__ = 36; break; } else { __label__ = 37; break; }
    case 36: 
      var $205=$s;
      var $206=_HPDF_AToI($205);
      var $207=(($206) & 65535);
      var $208=$2;
      var $209=(($208+156)|0);
      HEAP16[(($209)>>1)]=$207;
      __label__ = 49; break;
    case 37: 
      var $211=(($keyword)|0);
      var $212=_HPDF_StrCmp($211, ((STRING_TABLE.__str141350)|0));
      var $213=(($212)|0)==0;
      if ($213) { __label__ = 38; break; } else { __label__ = 39; break; }
    case 38: 
      var $215=$s;
      var $216=_HPDF_AToI($215);
      var $217=(($216) & 65535);
      var $218=$2;
      var $219=(($218+158)|0);
      HEAP16[(($219)>>1)]=$217;
      __label__ = 48; break;
    case 39: 
      var $221=(($keyword)|0);
      var $222=_HPDF_StrCmp($221, ((STRING_TABLE.__str151351)|0));
      var $223=(($222)|0)==0;
      if ($223) { __label__ = 40; break; } else { __label__ = 41; break; }
    case 40: 
      var $225=$s;
      var $226=_HPDF_AToI($225);
      var $227=(($226) & 65535);
      var $228=$2;
      var $229=(($228+190)|0);
      HEAP16[(($229)>>1)]=$227;
      __label__ = 47; break;
    case 41: 
      var $231=(($keyword)|0);
      var $232=_HPDF_StrCmp($231, ((STRING_TABLE.__str161352)|0));
      var $233=(($232)|0)==0;
      if ($233) { __label__ = 42; break; } else { __label__ = 43; break; }
    case 42: 
      var $235=$s;
      var $236=_HPDF_AToI($235);
      var $237=(($236) & 65535);
      var $238=$2;
      var $239=(($238+182)|0);
      HEAP16[(($239)>>1)]=$237;
      __label__ = 46; break;
    case 43: 
      var $241=(($keyword)|0);
      var $242=_HPDF_StrCmp($241, ((STRING_TABLE.__str171353)|0));
      var $243=(($242)|0)==0;
      if ($243) { __label__ = 44; break; } else { __label__ = 45; break; }
    case 44: 
      var $245=$s;
      var $246=_HPDF_AToI($245);
      var $247=$attr;
      var $248=(($247+8)|0);
      HEAP32[(($248)>>2)]=$246;
      __label__ = 58; break;
    case 45: 
      __label__ = 46; break;
    case 46: 
      __label__ = 47; break;
    case 47: 
      __label__ = 48; break;
    case 48: 
      __label__ = 49; break;
    case 49: 
      __label__ = 50; break;
    case 50: 
      __label__ = 51; break;
    case 51: 
      __label__ = 52; break;
    case 52: 
      __label__ = 53; break;
    case 53: 
      __label__ = 54; break;
    case 54: 
      __label__ = 55; break;
    case 55: 
      __label__ = 56; break;
    case 56: 
      __label__ = 57; break;
    case 57: 
      __label__ = 7; break;
    case 58: 
      var $263=$2;
      var $264=(($263+132)|0);
      var $265=HEAP32[(($264)>>2)];
      var $266=$attr;
      var $267=(($266+8)|0);
      var $268=HEAP32[(($267)>>2)];
      var $269=((($268)*(6))|0);
      var $270=_HPDF_GetMem($265, $269);
      var $271=$270;
      $cdata=$271;
      var $272=$cdata;
      var $273=(($272)|0)==0;
      if ($273) { __label__ = 59; break; } else { __label__ = 60; break; }
    case 59: 
      var $275=$2;
      var $276=(($275+136)|0);
      var $277=HEAP32[(($276)>>2)];
      var $278=_HPDF_Error_GetCode($277);
      $1=$278;
      __label__ = 79; break;
    case 60: 
      var $280=$cdata;
      var $281=$280;
      var $282=$attr;
      var $283=(($282+8)|0);
      var $284=HEAP32[(($283)>>2)];
      var $285=((($284)*(6))|0);
      var $286=_HPDF_MemSet($281, 0, $285);
      var $287=$cdata;
      var $288=$attr;
      var $289=(($288+4)|0);
      HEAP32[(($289)>>2)]=$287;
      $i=0;
      __label__ = 61; break;
    case 61: 
      var $291=$i;
      var $292=$attr;
      var $293=(($292+8)|0);
      var $294=HEAPU32[(($293)>>2)];
      var $295=(($291)>>>0) < (($294)>>>0);
      if ($295) { __label__ = 62; break; } else { __label__ = 78; break; }
    case 62: 
      HEAP32[(($len)>>2)]=512;
      var $297=$3;
      var $298=(($buf)|0);
      var $299=_HPDF_Stream_ReadLn($297, $298, $len);
      $ret=$299;
      var $300=(($299)|0)!=0;
      if ($300) { __label__ = 63; break; } else { __label__ = 64; break; }
    case 63: 
      var $302=$ret;
      $1=$302;
      __label__ = 79; break;
    case 64: 
      var $304=(($buf)|0);
      var $305=(($buf24)|0);
      var $306=_GetKeyword($304, $305, 128);
      $s3=$306;
      var $307=(($buf24)|0);
      var $308=_HPDF_StrCmp($307, ((STRING_TABLE.__str181354)|0));
      var $309=(($308)|0)==0;
      if ($309) { __label__ = 65; break; } else { __label__ = 66; break; }
    case 65: 
      var $311=$2;
      var $312=(($311+136)|0);
      var $313=HEAP32[(($312)>>2)];
      var $314=_HPDF_SetError($313, 4127, 0);
      $1=$314;
      __label__ = 79; break;
    case 66: 
      var $316=(($buf24)|0);
      var $317=_HPDF_StrCmp($316, ((STRING_TABLE.__str191355)|0));
      var $318=(($317)|0)==0;
      if ($318) { __label__ = 67; break; } else { __label__ = 68; break; }
    case 67: 
      var $320=$s3;
      var $321=(($320+2)|0);
      $s3=$321;
      var $322=$s3;
      var $323=(($buf24)|0);
      var $324=_GetKeyword($322, $323, 128);
      $s3=$324;
      var $325=(($buf24)|0);
      var $326=_HPDF_AToI($325);
      var $327=(($buf24)|0);
      var $328=_HPDF_AToI($327);
      var $329=(($328) & 65535);
      var $330=$cdata;
      var $331=(($330)|0);
      HEAP16[(($331)>>1)]=$329;
      __label__ = 69; break;
    case 68: 
      var $333=$2;
      var $334=(($333+136)|0);
      var $335=HEAP32[(($334)>>2)];
      var $336=_HPDF_SetError($335, 4127, 0);
      $1=$336;
      __label__ = 79; break;
    case 69: 
      __label__ = 70; break;
    case 70: 
      var $339=$s3;
      var $340=_HPDF_StrStr($339, ((STRING_TABLE.__str201356)|0), 0);
      $s3=$340;
      var $341=$s3;
      var $342=(($341)|0)!=0;
      if ($342) { __label__ = 72; break; } else { __label__ = 71; break; }
    case 71: 
      var $344=$2;
      var $345=(($344+136)|0);
      var $346=HEAP32[(($345)>>2)];
      var $347=_HPDF_SetError($346, 4161, 0);
      $1=$347;
      __label__ = 79; break;
    case 72: 
      var $349=$s3;
      var $350=(($349+3)|0);
      $s3=$350;
      var $351=$s3;
      var $352=(($buf24)|0);
      var $353=_GetKeyword($351, $352, 128);
      $s3=$353;
      var $354=(($buf24)|0);
      var $355=HEAP8[($354)];
      var $356=(($355 << 24) >> 24);
      var $357=(($356)|0)==0;
      if ($357) { __label__ = 73; break; } else { __label__ = 74; break; }
    case 73: 
      var $359=$2;
      var $360=(($359+136)|0);
      var $361=HEAP32[(($360)>>2)];
      var $362=_HPDF_SetError($361, 4161, 0);
      $1=$362;
      __label__ = 79; break;
    case 74: 
      var $364=(($buf24)|0);
      var $365=_HPDF_AToI($364);
      var $366=(($365) & 65535);
      var $367=$cdata;
      var $368=(($367+4)|0);
      HEAP16[(($368)>>1)]=$366;
      var $369=$s3;
      var $370=_HPDF_StrStr($369, ((STRING_TABLE.__str211357)|0), 0);
      $s3=$370;
      var $371=$s3;
      var $372=(($371)|0)!=0;
      if ($372) { __label__ = 76; break; } else { __label__ = 75; break; }
    case 75: 
      var $374=$2;
      var $375=(($374+136)|0);
      var $376=HEAP32[(($375)>>2)];
      var $377=_HPDF_SetError($376, 4146, 0);
      $1=$377;
      __label__ = 79; break;
    case 76: 
      var $379=$s3;
      var $380=(($379+2)|0);
      $s3=$380;
      var $381=$s3;
      var $382=(($buf24)|0);
      var $383=_GetKeyword($381, $382, 128);
      var $384=(($buf24)|0);
      var $385=_HPDF_GryphNameToUnicode($384);
      var $386=$cdata;
      var $387=(($386+2)|0);
      HEAP16[(($387)>>1)]=$385;
      __label__ = 77; break;
    case 77: 
      var $389=$i;
      var $390=((($389)+(1))|0);
      $i=$390;
      var $391=$cdata;
      var $392=(($391+6)|0);
      $cdata=$392;
      __label__ = 61; break;
    case 78: 
      $1=0;
      __label__ = 79; break;
    case 79: 
      var $395=$1;
      STACKTOP = __stackBase__;
      return $395;
    default: assert(0, "bad label: " + __label__);
  }
}
_LoadAfm["X"]=1;

function _LoadFontData1363($fontdef, $stream) {
  var __stackBase__  = STACKTOP; STACKTOP += 4100; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $attr;
      var $buf=__stackBase__;
      var $pbuf;
      var $len=(__stackBase__)+(4096);
      var $ret;
      var $end_flg;
      var $s1;
      var $s2;
      $2=$fontdef;
      $3=$stream;
      var $4=$2;
      var $5=(($4+208)|0);
      var $6=HEAP32[(($5)>>2)];
      var $7=$6;
      $attr=$7;
      var $8=(($buf)|0);
      $pbuf=$8;
      HEAP32[(($len)>>2)]=0;
      $end_flg=0;
      var $9=$2;
      var $10=(($9+132)|0);
      var $11=HEAP32[(($10)>>2)];
      var $12=_HPDF_MemStream_New($11, 4096);
      var $13=$attr;
      var $14=(($13+168)|0);
      HEAP32[(($14)>>2)]=$12;
      var $15=$attr;
      var $16=(($15+168)|0);
      var $17=HEAP32[(($16)>>2)];
      var $18=(($17)|0)!=0;
      if ($18) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      var $20=$2;
      var $21=(($20+136)|0);
      var $22=HEAP32[(($21)>>2)];
      var $23=_HPDF_Error_GetCode($22);
      $1=$23;
      __label__ = 35; break;
    case 4: 
      HEAP32[(($len)>>2)]=11;
      var $25=$3;
      var $26=$pbuf;
      var $27=_HPDF_Stream_Read($25, $26, $len);
      $ret=$27;
      var $28=$ret;
      var $29=(($28)|0)!=0;
      if ($29) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $31=$ret;
      $1=$31;
      __label__ = 35; break;
    case 6: 
      var $33=$pbuf;
      var $34=(($33+11)|0);
      $pbuf=$34;
      __label__ = 7; break;
    case 7: 
      HEAP32[(($len)>>2)]=4085;
      var $36=$3;
      var $37=$pbuf;
      var $38=_HPDF_Stream_Read($36, $37, $len);
      $ret=$38;
      var $39=$ret;
      var $40=(($39)|0)==4184;
      if ($40) { __label__ = 8; break; } else { __label__ = 9; break; }
    case 8: 
      $end_flg=1;
      __label__ = 12; break;
    case 9: 
      var $43=$ret;
      var $44=(($43)|0)!=0;
      if ($44) { __label__ = 10; break; } else { __label__ = 11; break; }
    case 10: 
      var $46=$ret;
      $1=$46;
      __label__ = 35; break;
    case 11: 
      __label__ = 12; break;
    case 12: 
      var $49=HEAPU32[(($len)>>2)];
      var $50=(($49)>>>0) > 0;
      if ($50) { __label__ = 13; break; } else { __label__ = 23; break; }
    case 13: 
      var $52=$attr;
      var $53=(($52+148)|0);
      var $54=HEAP32[(($53)>>2)];
      var $55=(($54)|0)==0;
      if ($55) { __label__ = 14; break; } else { __label__ = 17; break; }
    case 14: 
      var $57=(($buf)|0);
      var $58=HEAP32[(($len)>>2)];
      var $59=((($58)+(11))|0);
      var $60=_HPDF_StrStr($57, ((STRING_TABLE.__str1336)|0), $59);
      $s1=$60;
      var $61=$s1;
      var $62=(($61)|0)!=0;
      if ($62) { __label__ = 15; break; } else { __label__ = 16; break; }
    case 15: 
      var $64=$attr;
      var $65=(($64+168)|0);
      var $66=HEAP32[(($65)>>2)];
      var $67=(($66+16)|0);
      var $68=HEAP32[(($67)>>2)];
      var $69=$s1;
      var $70=(($buf)|0);
      var $71=$69;
      var $72=$70;
      var $73=((($71)-($72))|0);
      var $74=((($68)+($73))|0);
      var $75=((($74)+(6))|0);
      var $76=$attr;
      var $77=(($76+148)|0);
      HEAP32[(($77)>>2)]=$75;
      __label__ = 16; break;
    case 16: 
      __label__ = 17; break;
    case 17: 
      var $80=$attr;
      var $81=(($80+148)|0);
      var $82=HEAPU32[(($81)>>2)];
      var $83=(($82)>>>0) > 0;
      if ($83) { __label__ = 18; break; } else { __label__ = 22; break; }
    case 18: 
      var $85=$attr;
      var $86=(($85+152)|0);
      var $87=HEAP32[(($86)>>2)];
      var $88=(($87)|0)==0;
      if ($88) { __label__ = 19; break; } else { __label__ = 22; break; }
    case 19: 
      var $90=(($buf)|0);
      var $91=HEAP32[(($len)>>2)];
      var $92=((($91)+(11))|0);
      var $93=_HPDF_StrStr($90, ((STRING_TABLE.__str11337)|0), $92);
      $s2=$93;
      var $94=$s2;
      var $95=(($94)|0)!=0;
      if ($95) { __label__ = 20; break; } else { __label__ = 21; break; }
    case 20: 
      var $97=$attr;
      var $98=(($97+168)|0);
      var $99=HEAP32[(($98)>>2)];
      var $100=(($99+16)|0);
      var $101=HEAP32[(($100)>>2)];
      var $102=((($101)-(520))|0);
      var $103=$attr;
      var $104=(($103+148)|0);
      var $105=HEAP32[(($104)>>2)];
      var $106=((($102)-($105))|0);
      var $107=$s2;
      var $108=(($buf)|0);
      var $109=$107;
      var $110=$108;
      var $111=((($109)-($110))|0);
      var $112=((($106)+($111))|0);
      var $113=$attr;
      var $114=(($113+152)|0);
      HEAP32[(($114)>>2)]=$112;
      __label__ = 21; break;
    case 21: 
      __label__ = 22; break;
    case 22: 
      __label__ = 23; break;
    case 23: 
      var $118=$end_flg;
      var $119=(($118)|0)!=0;
      if ($119) { __label__ = 24; break; } else { __label__ = 27; break; }
    case 24: 
      var $121=$attr;
      var $122=(($121+168)|0);
      var $123=HEAP32[(($122)>>2)];
      var $124=(($buf)|0);
      var $125=HEAP32[(($len)>>2)];
      var $126=((($125)+(11))|0);
      var $127=_HPDF_Stream_Write($123, $124, $126);
      $ret=$127;
      var $128=(($127)|0)!=0;
      if ($128) { __label__ = 25; break; } else { __label__ = 26; break; }
    case 25: 
      var $130=$ret;
      $1=$130;
      __label__ = 35; break;
    case 26: 
      __label__ = 31; break;
    case 27: 
      var $133=$attr;
      var $134=(($133+168)|0);
      var $135=HEAP32[(($134)>>2)];
      var $136=(($buf)|0);
      var $137=HEAP32[(($len)>>2)];
      var $138=_HPDF_Stream_Write($135, $136, $137);
      $ret=$138;
      var $139=(($138)|0)!=0;
      if ($139) { __label__ = 28; break; } else { __label__ = 29; break; }
    case 28: 
      var $141=$ret;
      $1=$141;
      __label__ = 35; break;
    case 29: 
      var $143=(($buf)|0);
      var $144=(($buf)|0);
      var $145=HEAP32[(($len)>>2)];
      var $146=(($144+$145)|0);
      var $147=_HPDF_MemCpy($143, $146, 11);
      var $148=(($buf)|0);
      var $149=(($148+11)|0);
      $pbuf=$149;
      __label__ = 30; break;
    case 30: 
      __label__ = 7; break;
    case 31: 
      var $152=$attr;
      var $153=(($152+148)|0);
      var $154=HEAP32[(($153)>>2)];
      var $155=(($154)|0)==0;
      if ($155) { __label__ = 33; break; } else { __label__ = 32; break; }
    case 32: 
      var $157=$attr;
      var $158=(($157+152)|0);
      var $159=HEAP32[(($158)>>2)];
      var $160=(($159)|0)==0;
      if ($160) { __label__ = 33; break; } else { __label__ = 34; break; }
    case 33: 
      var $162=$2;
      var $163=(($162+136)|0);
      var $164=HEAP32[(($163)>>2)];
      var $165=_HPDF_SetError($164, 4196, 0);
      $1=$165;
      __label__ = 35; break;
    case 34: 
      var $167=$attr;
      var $168=(($167+168)|0);
      var $169=HEAP32[(($168)>>2)];
      var $170=(($169+16)|0);
      var $171=HEAP32[(($170)>>2)];
      var $172=$attr;
      var $173=(($172+148)|0);
      var $174=HEAP32[(($173)>>2)];
      var $175=((($171)-($174))|0);
      var $176=$attr;
      var $177=(($176+152)|0);
      var $178=HEAP32[(($177)>>2)];
      var $179=((($175)-($178))|0);
      var $180=$attr;
      var $181=(($180+156)|0);
      HEAP32[(($181)>>2)]=$179;
      $1=0;
      __label__ = 35; break;
    case 35: 
      var $183=$1;
      STACKTOP = __stackBase__;
      return $183;
    default: assert(0, "bad label: " + __label__);
  }
}
_LoadFontData1363["X"]=1;

function _HPDF_Type1FontDef_GetWidth($fontdef, $unicode) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $attr;
      var $cdata;
      var $i;
      $2=$fontdef;
      $3=$unicode;
      var $4=$2;
      var $5=(($4+208)|0);
      var $6=HEAP32[(($5)>>2)];
      var $7=$6;
      $attr=$7;
      var $8=$attr;
      var $9=(($8+4)|0);
      var $10=HEAP32[(($9)>>2)];
      $cdata=$10;
      $i=0;
      __label__ = 3; break;
    case 3: 
      var $12=$i;
      var $13=$attr;
      var $14=(($13+8)|0);
      var $15=HEAPU32[(($14)>>2)];
      var $16=(($12)>>>0) < (($15)>>>0);
      if ($16) { __label__ = 4; break; } else { __label__ = 8; break; }
    case 4: 
      var $18=$cdata;
      var $19=(($18+2)|0);
      var $20=HEAPU16[(($19)>>1)];
      var $21=(($20)&65535);
      var $22=$3;
      var $23=(($22)&65535);
      var $24=(($21)|0)==(($23)|0);
      if ($24) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $26=$cdata;
      var $27=(($26+4)|0);
      var $28=HEAP16[(($27)>>1)];
      $1=$28;
      __label__ = 9; break;
    case 6: 
      var $30=$cdata;
      var $31=(($30+6)|0);
      $cdata=$31;
      __label__ = 7; break;
    case 7: 
      var $33=$i;
      var $34=((($33)+(1))|0);
      $i=$34;
      __label__ = 3; break;
    case 8: 
      var $36=$2;
      var $37=(($36+188)|0);
      var $38=HEAP16[(($37)>>1)];
      $1=$38;
      __label__ = 9; break;
    case 9: 
      var $40=$1;
      ;
      return $40;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Type1FontDef_GetWidth["X"]=1;

function _HPDF_Type1FontDef_SetWidths($fontdef, $widths) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $src;
      var $attr;
      var $dst;
      var $i;
      $2=$fontdef;
      $3=$widths;
      var $4=$3;
      $src=$4;
      var $5=$2;
      var $6=(($5+208)|0);
      var $7=HEAP32[(($6)>>2)];
      var $8=$7;
      $attr=$8;
      $i=0;
      var $9=$2;
      _FreeWidth($9);
      __label__ = 3; break;
    case 3: 
      var $11=$src;
      var $12=(($11+2)|0);
      var $13=HEAPU16[(($12)>>1)];
      var $14=(($13)&65535);
      var $15=(($14)|0)!=65535;
      if ($15) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      var $17=$src;
      var $18=(($17+6)|0);
      $src=$18;
      var $19=$i;
      var $20=((($19)+(1))|0);
      $i=$20;
      __label__ = 3; break;
    case 5: 
      var $22=$i;
      var $23=$attr;
      var $24=(($23+8)|0);
      HEAP32[(($24)>>2)]=$22;
      var $25=$2;
      var $26=(($25+132)|0);
      var $27=HEAP32[(($26)>>2)];
      var $28=$attr;
      var $29=(($28+8)|0);
      var $30=HEAP32[(($29)>>2)];
      var $31=((($30)*(6))|0);
      var $32=_HPDF_GetMem($27, $31);
      var $33=$32;
      $dst=$33;
      var $34=$dst;
      var $35=(($34)|0)==0;
      if ($35) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      var $37=$2;
      var $38=(($37+136)|0);
      var $39=HEAP32[(($38)>>2)];
      var $40=_HPDF_Error_GetCode($39);
      $1=$40;
      __label__ = 14; break;
    case 7: 
      var $42=$dst;
      var $43=$42;
      var $44=$attr;
      var $45=(($44+8)|0);
      var $46=HEAP32[(($45)>>2)];
      var $47=((($46)*(6))|0);
      var $48=_HPDF_MemSet($43, 0, $47);
      var $49=$dst;
      var $50=$attr;
      var $51=(($50+4)|0);
      HEAP32[(($51)>>2)]=$49;
      var $52=$3;
      $src=$52;
      $i=0;
      __label__ = 8; break;
    case 8: 
      var $54=$i;
      var $55=$attr;
      var $56=(($55+8)|0);
      var $57=HEAPU32[(($56)>>2)];
      var $58=(($54)>>>0) < (($57)>>>0);
      if ($58) { __label__ = 9; break; } else { __label__ = 13; break; }
    case 9: 
      var $60=$src;
      var $61=(($60)|0);
      var $62=HEAP16[(($61)>>1)];
      var $63=$dst;
      var $64=(($63)|0);
      HEAP16[(($64)>>1)]=$62;
      var $65=$src;
      var $66=(($65+2)|0);
      var $67=HEAP16[(($66)>>1)];
      var $68=$dst;
      var $69=(($68+2)|0);
      HEAP16[(($69)>>1)]=$67;
      var $70=$src;
      var $71=(($70+4)|0);
      var $72=HEAP16[(($71)>>1)];
      var $73=$dst;
      var $74=(($73+4)|0);
      HEAP16[(($74)>>1)]=$72;
      var $75=$dst;
      var $76=(($75+2)|0);
      var $77=HEAPU16[(($76)>>1)];
      var $78=(($77)&65535);
      var $79=(($78)|0)==32;
      if ($79) { __label__ = 10; break; } else { __label__ = 11; break; }
    case 10: 
      var $81=$src;
      var $82=(($81+4)|0);
      var $83=HEAP16[(($82)>>1)];
      var $84=$2;
      var $85=(($84+188)|0);
      HEAP16[(($85)>>1)]=$83;
      __label__ = 11; break;
    case 11: 
      var $87=$src;
      var $88=(($87+6)|0);
      $src=$88;
      var $89=$dst;
      var $90=(($89+6)|0);
      $dst=$90;
      __label__ = 12; break;
    case 12: 
      var $92=$i;
      var $93=((($92)+(1))|0);
      $i=$93;
      __label__ = 8; break;
    case 13: 
      $1=0;
      __label__ = 14; break;
    case 14: 
      var $96=$1;
      ;
      return $96;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Type1FontDef_SetWidths["X"]=1;

function _FreeWidth($fontdef) {
  ;
  var __label__;

  var $1;
  var $attr;
  $1=$fontdef;
  var $2=$1;
  var $3=(($2+208)|0);
  var $4=HEAP32[(($3)>>2)];
  var $5=$4;
  $attr=$5;
  var $6=$1;
  var $7=(($6+132)|0);
  var $8=HEAP32[(($7)>>2)];
  var $9=$attr;
  var $10=(($9+4)|0);
  var $11=HEAP32[(($10)>>2)];
  var $12=$11;
  _HPDF_FreeMem($8, $12);
  var $13=$attr;
  var $14=(($13+4)|0);
  HEAP32[(($14)>>2)]=0;
  var $15=$1;
  var $16=(($15+204)|0);
  HEAP32[(($16)>>2)]=0;
  ;
  return;
}


function _GetKeyword($src, $keyword, $len) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $src_len;
      $2=$src;
      $3=$keyword;
      $4=$len;
      var $5=$2;
      var $6=_HPDF_StrLen($5, -1);
      $src_len=$6;
      var $7=$3;
      var $8=(($7)|0)!=0;
      if ($8) { __label__ = 3; break; } else { __label__ = 5; break; }
    case 3: 
      var $10=$src_len;
      var $11=(($10)|0)==0;
      if ($11) { __label__ = 5; break; } else { __label__ = 4; break; }
    case 4: 
      var $13=$4;
      var $14=(($13)|0)==0;
      if ($14) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      $1=0;
      __label__ = 26; break;
    case 6: 
      var $17=$3;
      HEAP8[($17)]=0;
      __label__ = 7; break;
    case 7: 
      var $19=$4;
      var $20=(($19)>>>0) > 0;
      if ($20) { __label__ = 8; break; } else { __label__ = 25; break; }
    case 8: 
      var $22=$2;
      var $23=HEAP8[($22)];
      var $24=(($23 << 24) >> 24);
      var $25=(($24)|0)==0;
      if ($25) { __label__ = 14; break; } else { __label__ = 9; break; }
    case 9: 
      var $27=$2;
      var $28=HEAP8[($27)];
      var $29=(($28 << 24) >> 24);
      var $30=(($29)|0)==9;
      if ($30) { __label__ = 14; break; } else { __label__ = 10; break; }
    case 10: 
      var $32=$2;
      var $33=HEAP8[($32)];
      var $34=(($33 << 24) >> 24);
      var $35=(($34)|0)==10;
      if ($35) { __label__ = 14; break; } else { __label__ = 11; break; }
    case 11: 
      var $37=$2;
      var $38=HEAP8[($37)];
      var $39=(($38 << 24) >> 24);
      var $40=(($39)|0)==12;
      if ($40) { __label__ = 14; break; } else { __label__ = 12; break; }
    case 12: 
      var $42=$2;
      var $43=HEAP8[($42)];
      var $44=(($43 << 24) >> 24);
      var $45=(($44)|0)==13;
      if ($45) { __label__ = 14; break; } else { __label__ = 13; break; }
    case 13: 
      var $47=$2;
      var $48=HEAP8[($47)];
      var $49=(($48 << 24) >> 24);
      var $50=(($49)|0)==32;
      if ($50) { __label__ = 14; break; } else { __label__ = 24; break; }
    case 14: 
      var $52=$3;
      HEAP8[($52)]=0;
      __label__ = 15; break;
    case 15: 
      var $54=$2;
      var $55=HEAP8[($54)];
      var $56=(($55 << 24) >> 24);
      var $57=(($56)|0)==0;
      if ($57) { var $84 = 1;__label__ = 21; break; } else { __label__ = 16; break; }
    case 16: 
      var $59=$2;
      var $60=HEAP8[($59)];
      var $61=(($60 << 24) >> 24);
      var $62=(($61)|0)==9;
      if ($62) { var $84 = 1;__label__ = 21; break; } else { __label__ = 17; break; }
    case 17: 
      var $64=$2;
      var $65=HEAP8[($64)];
      var $66=(($65 << 24) >> 24);
      var $67=(($66)|0)==10;
      if ($67) { var $84 = 1;__label__ = 21; break; } else { __label__ = 18; break; }
    case 18: 
      var $69=$2;
      var $70=HEAP8[($69)];
      var $71=(($70 << 24) >> 24);
      var $72=(($71)|0)==12;
      if ($72) { var $84 = 1;__label__ = 21; break; } else { __label__ = 19; break; }
    case 19: 
      var $74=$2;
      var $75=HEAP8[($74)];
      var $76=(($75 << 24) >> 24);
      var $77=(($76)|0)==13;
      if ($77) { var $84 = 1;__label__ = 21; break; } else { __label__ = 20; break; }
    case 20: 
      var $79=$2;
      var $80=HEAP8[($79)];
      var $81=(($80 << 24) >> 24);
      var $82=(($81)|0)==32;
      var $84 = $82;__label__ = 21; break;
    case 21: 
      var $84;
      if ($84) { __label__ = 22; break; } else { __label__ = 23; break; }
    case 22: 
      var $86=$2;
      var $87=(($86+1)|0);
      $2=$87;
      __label__ = 15; break;
    case 23: 
      var $89=$2;
      $1=$89;
      __label__ = 26; break;
    case 24: 
      var $91=$2;
      var $92=(($91+1)|0);
      $2=$92;
      var $93=HEAP8[($91)];
      var $94=$3;
      var $95=(($94+1)|0);
      $3=$95;
      HEAP8[($94)]=$93;
      var $96=$4;
      var $97=((($96)-(1))|0);
      $4=$97;
      __label__ = 7; break;
    case 25: 
      var $99=$3;
      HEAP8[($99)]=0;
      $1=0;
      __label__ = 26; break;
    case 26: 
      var $101=$1;
      ;
      return $101;
    default: assert(0, "bad label: " + __label__);
  }
}
_GetKeyword["X"]=1;

function _HPDF_TTFont_New($mmgr, $fontdef, $encoder, $xref) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $5;
      var $font;
      var $attr;
      var $fontdef_attr;
      var $encoder_attr;
      var $ret;
      $2=$mmgr;
      $3=$fontdef;
      $4=$encoder;
      $5=$xref;
      $ret=0;
      var $6=$2;
      var $7=_HPDF_Dict_New($6);
      $font=$7;
      var $8=$font;
      var $9=(($8)|0)!=0;
      if ($9) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=0;
      __label__ = 21; break;
    case 4: 
      var $12=$font;
      var $13=(($12)|0);
      var $14=(($13+6)|0);
      var $15=HEAPU16[(($14)>>1)];
      var $16=(($15)&65535);
      var $17=$16 | 256;
      var $18=(($17) & 65535);
      HEAP16[(($14)>>1)]=$18;
      var $19=$4;
      var $20=(($19+140)|0);
      var $21=HEAP32[(($20)>>2)];
      var $22=(($21)|0)!=0;
      if ($22) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $24=$font;
      var $25=(($24+12)|0);
      var $26=HEAP32[(($25)>>2)];
      var $27=_HPDF_SetError($26, 4136, 0);
      $1=0;
      __label__ = 21; break;
    case 6: 
      var $29=$3;
      var $30=(($29+140)|0);
      var $31=HEAP32[(($30)>>2)];
      var $32=(($31)|0)!=1;
      if ($32) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $34=$font;
      var $35=(($34+12)|0);
      var $36=HEAP32[(($35)>>2)];
      var $37=_HPDF_SetError($36, 4142, 0);
      $1=0;
      __label__ = 21; break;
    case 8: 
      var $39=$2;
      var $40=_HPDF_GetMem($39, 48);
      var $41=$40;
      $attr=$41;
      var $42=$attr;
      var $43=(($42)|0)!=0;
      if ($43) { __label__ = 10; break; } else { __label__ = 9; break; }
    case 9: 
      var $45=$font;
      _HPDF_Dict_Free($45);
      $1=0;
      __label__ = 21; break;
    case 10: 
      var $47=$attr;
      var $48=$47;
      var $49=_HPDF_MemSet($48, 0, 48);
      var $50=$font;
      var $51=(($50)|0);
      var $52=(($51+6)|0);
      var $53=HEAPU16[(($52)>>1)];
      var $54=(($53)&65535);
      var $55=$54 | 256;
      var $56=(($55) & 65535);
      HEAP16[(($52)>>1)]=$56;
      var $57=$font;
      var $58=(($57+24)|0);
      HEAP32[(($58)>>2)]=194;
      var $59=$font;
      var $60=(($59+20)|0);
      HEAP32[(($60)>>2)]=196;
      var $61=$font;
      var $62=(($61+32)|0);
      HEAP32[(($62)>>2)]=198;
      var $63=$attr;
      var $64=$63;
      var $65=$font;
      var $66=(($65+44)|0);
      HEAP32[(($66)>>2)]=$64;
      var $67=$attr;
      var $68=(($67)|0);
      HEAP32[(($68)>>2)]=1;
      var $69=$attr;
      var $70=(($69+4)|0);
      HEAP32[(($70)>>2)]=0;
      var $71=$attr;
      var $72=(($71+8)|0);
      HEAP32[(($72)>>2)]=200;
      var $73=$attr;
      var $74=(($73+12)|0);
      HEAP32[(($74)>>2)]=202;
      var $75=$3;
      var $76=$attr;
      var $77=(($76+16)|0);
      HEAP32[(($77)>>2)]=$75;
      var $78=$4;
      var $79=$attr;
      var $80=(($79+20)|0);
      HEAP32[(($80)>>2)]=$78;
      var $81=$5;
      var $82=$attr;
      var $83=(($82+32)|0);
      HEAP32[(($83)>>2)]=$81;
      var $84=$2;
      var $85=_HPDF_GetMem($84, 512);
      var $86=$85;
      var $87=$attr;
      var $88=(($87+24)|0);
      HEAP32[(($88)>>2)]=$86;
      var $89=$attr;
      var $90=(($89+24)|0);
      var $91=HEAP32[(($90)>>2)];
      var $92=(($91)|0)!=0;
      if ($92) { __label__ = 12; break; } else { __label__ = 11; break; }
    case 11: 
      var $94=$font;
      _HPDF_Dict_Free($94);
      $1=0;
      __label__ = 21; break;
    case 12: 
      var $96=$attr;
      var $97=(($96+24)|0);
      var $98=HEAP32[(($97)>>2)];
      var $99=$98;
      var $100=_HPDF_MemSet($99, 0, 512);
      var $101=$2;
      var $102=_HPDF_GetMem($101, 256);
      var $103=$attr;
      var $104=(($103+28)|0);
      HEAP32[(($104)>>2)]=$102;
      var $105=$attr;
      var $106=(($105+28)|0);
      var $107=HEAP32[(($106)>>2)];
      var $108=(($107)|0)!=0;
      if ($108) { __label__ = 14; break; } else { __label__ = 13; break; }
    case 13: 
      var $110=$font;
      _HPDF_Dict_Free($110);
      $1=0;
      __label__ = 21; break;
    case 14: 
      var $112=$attr;
      var $113=(($112+28)|0);
      var $114=HEAP32[(($113)>>2)];
      var $115=_HPDF_MemSet($114, 0, 256);
      var $116=$3;
      var $117=(($116+208)|0);
      var $118=HEAP32[(($117)>>2)];
      var $119=$118;
      $fontdef_attr=$119;
      var $120=$font;
      var $121=_HPDF_Dict_AddName($120, ((STRING_TABLE.__str1368)|0), ((STRING_TABLE.__str11369)|0));
      var $122=$ret;
      var $123=((($122)+($121))|0);
      $ret=$123;
      var $124=$font;
      var $125=$fontdef_attr;
      var $126=(($125)|0);
      var $127=(($126)|0);
      var $128=_HPDF_Dict_AddName($124, ((STRING_TABLE.__str21370)|0), $127);
      var $129=$ret;
      var $130=((($129)+($128))|0);
      $ret=$130;
      var $131=$font;
      var $132=_HPDF_Dict_AddName($131, ((STRING_TABLE.__str31371)|0), ((STRING_TABLE.__str41372)|0));
      var $133=$ret;
      var $134=((($133)+($132))|0);
      $ret=$134;
      var $135=$4;
      var $136=(($135+164)|0);
      var $137=HEAP32[(($136)>>2)];
      var $138=$137;
      $encoder_attr=$138;
      var $139=$font;
      var $140=$encoder_attr;
      var $141=(($140+128)|0);
      var $142=HEAPU8[($141)];
      var $143=(($142)&255);
      var $144=_HPDF_Dict_AddNumber($139, ((STRING_TABLE.__str51373)|0), $143);
      var $145=$ret;
      var $146=((($145)+($144))|0);
      $ret=$146;
      var $147=$font;
      var $148=$encoder_attr;
      var $149=(($148+129)|0);
      var $150=HEAPU8[($149)];
      var $151=(($150)&255);
      var $152=_HPDF_Dict_AddNumber($147, ((STRING_TABLE.__str61374)|0), $151);
      var $153=$ret;
      var $154=((($153)+($152))|0);
      $ret=$154;
      var $155=$3;
      var $156=(($155+188)|0);
      var $157=HEAP16[(($156)>>1)];
      var $158=(($157 << 16) >> 16);
      var $159=(($158)|0)!=0;
      if ($159) { __label__ = 15; break; } else { __label__ = 16; break; }
    case 15: 
      var $161=$font;
      var $162=$3;
      var $163=(($162+188)|0);
      var $164=HEAP16[(($163)>>1)];
      var $165=(($164 << 16) >> 16);
      var $166=_HPDF_Dict_AddNumber($161, ((STRING_TABLE.__str71375)|0), $165);
      var $167=$ret;
      var $168=((($167)+($166))|0);
      $ret=$168;
      __label__ = 16; break;
    case 16: 
      var $170=$ret;
      var $171=(($170)|0)!=0;
      if ($171) { __label__ = 17; break; } else { __label__ = 18; break; }
    case 17: 
      var $173=$font;
      _HPDF_Dict_Free($173);
      $1=0;
      __label__ = 21; break;
    case 18: 
      var $175=$5;
      var $176=$font;
      var $177=$176;
      var $178=_HPDF_Xref_Add($175, $177);
      var $179=(($178)|0)!=0;
      if ($179) { __label__ = 19; break; } else { __label__ = 20; break; }
    case 19: 
      $1=0;
      __label__ = 21; break;
    case 20: 
      var $182=$font;
      $1=$182;
      __label__ = 21; break;
    case 21: 
      var $184=$1;
      ;
      return $184;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_TTFont_New["X"]=1;

function _OnWrite($obj, $stream) {
  var __stackBase__  = STACKTOP; STACKTOP += 128; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $attr;
      var $encoder_attr;
      var $i;
      var $ret;
      var $buf=__stackBase__;
      var $pbuf;
      var $eptr;
      $2=$obj;
      $3=$stream;
      var $4=$2;
      var $5=(($4+44)|0);
      var $6=HEAP32[(($5)>>2)];
      var $7=$6;
      $attr=$7;
      var $8=$attr;
      var $9=(($8+20)|0);
      var $10=HEAP32[(($9)>>2)];
      var $11=(($10+164)|0);
      var $12=HEAP32[(($11)>>2)];
      var $13=$12;
      $encoder_attr=$13;
      var $14=(($buf)|0);
      $pbuf=$14;
      var $15=(($buf)|0);
      var $16=(($15+127)|0);
      $eptr=$16;
      var $17=$3;
      var $18=_HPDF_Stream_WriteEscapeName($17, ((STRING_TABLE.__str221390)|0));
      $ret=$18;
      var $19=(($18)|0)!=0;
      if ($19) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $21=$ret;
      $1=$21;
      __label__ = 17; break;
    case 4: 
      var $23=$3;
      var $24=_HPDF_Stream_WriteStr($23, ((STRING_TABLE.__str231391)|0));
      $ret=$24;
      var $25=(($24)|0)!=0;
      if ($25) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $27=$ret;
      $1=$27;
      __label__ = 17; break;
    case 6: 
      var $29=$encoder_attr;
      var $30=(($29+128)|0);
      var $31=HEAPU8[($30)];
      var $32=(($31)&255);
      $i=$32;
      __label__ = 7; break;
    case 7: 
      var $34=$i;
      var $35=$encoder_attr;
      var $36=(($35+129)|0);
      var $37=HEAPU8[($36)];
      var $38=(($37)&255);
      var $39=(($34)>>>0) <= (($38)>>>0);
      if ($39) { __label__ = 8; break; } else { __label__ = 14; break; }
    case 8: 
      var $41=$pbuf;
      var $42=$i;
      var $43=$attr;
      var $44=(($43+24)|0);
      var $45=HEAP32[(($44)>>2)];
      var $46=(($45+($42<<1))|0);
      var $47=HEAP16[(($46)>>1)];
      var $48=(($47 << 16) >> 16);
      var $49=$eptr;
      var $50=_HPDF_IToA($41, $48, $49);
      $pbuf=$50;
      var $51=$pbuf;
      var $52=(($51+1)|0);
      $pbuf=$52;
      HEAP8[($51)]=32;
      var $53=$i;
      var $54=((($53)+(1))|0);
      var $55=((($54)>>>0))%(16);
      var $56=(($55)|0)==0;
      if ($56) { __label__ = 9; break; } else { __label__ = 12; break; }
    case 9: 
      var $58=$pbuf;
      var $59=$eptr;
      var $60=_HPDF_StrCpy($58, ((STRING_TABLE.__str241392)|0), $59);
      var $61=$3;
      var $62=(($buf)|0);
      var $63=_HPDF_Stream_WriteStr($61, $62);
      $ret=$63;
      var $64=(($63)|0)!=0;
      if ($64) { __label__ = 10; break; } else { __label__ = 11; break; }
    case 10: 
      var $66=$ret;
      $1=$66;
      __label__ = 17; break;
    case 11: 
      var $68=(($buf)|0);
      $pbuf=$68;
      __label__ = 12; break;
    case 12: 
      __label__ = 13; break;
    case 13: 
      var $71=$i;
      var $72=((($71)+(1))|0);
      $i=$72;
      __label__ = 7; break;
    case 14: 
      var $74=$pbuf;
      var $75=$eptr;
      var $76=_HPDF_StrCpy($74, ((STRING_TABLE.__str251393)|0), $75);
      var $77=$3;
      var $78=(($buf)|0);
      var $79=_HPDF_Stream_WriteStr($77, $78);
      $ret=$79;
      var $80=(($79)|0)!=0;
      if ($80) { __label__ = 15; break; } else { __label__ = 16; break; }
    case 15: 
      var $82=$ret;
      $1=$82;
      __label__ = 17; break;
    case 16: 
      var $84=$attr;
      var $85=(($84+20)|0);
      var $86=HEAP32[(($85)>>2)];
      var $87=(($86+152)|0);
      var $88=HEAP32[(($87)>>2)];
      var $89=$attr;
      var $90=(($89+20)|0);
      var $91=HEAP32[(($90)>>2)];
      var $92=$3;
      var $93=FUNCTION_TABLE[$88]($91, $92);
      $1=$93;
      __label__ = 17; break;
    case 17: 
      var $95=$1;
      STACKTOP = __stackBase__;
      return $95;
    default: assert(0, "bad label: " + __label__);
  }
}
_OnWrite["X"]=1;

function _BeforeWrite($obj) {
  ;
  var __label__;

  var $1;
  $1=$obj;
  var $2=$1;
  var $3=_CreateDescriptor($2);
  ;
  return $3;
}


function _OnFree($obj) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $attr;
      $1=$obj;
      var $2=$1;
      var $3=(($2+44)|0);
      var $4=HEAP32[(($3)>>2)];
      var $5=$4;
      $attr=$5;
      var $6=$attr;
      var $7=(($6)|0)!=0;
      if ($7) { __label__ = 3; break; } else { __label__ = 8; break; }
    case 3: 
      var $9=$attr;
      var $10=(($9+24)|0);
      var $11=HEAP32[(($10)>>2)];
      var $12=(($11)|0)!=0;
      if ($12) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      var $14=$1;
      var $15=(($14+8)|0);
      var $16=HEAP32[(($15)>>2)];
      var $17=$attr;
      var $18=(($17+24)|0);
      var $19=HEAP32[(($18)>>2)];
      var $20=$19;
      _HPDF_FreeMem($16, $20);
      __label__ = 5; break;
    case 5: 
      var $22=$attr;
      var $23=(($22+28)|0);
      var $24=HEAP32[(($23)>>2)];
      var $25=(($24)|0)!=0;
      if ($25) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      var $27=$1;
      var $28=(($27+8)|0);
      var $29=HEAP32[(($28)>>2)];
      var $30=$attr;
      var $31=(($30+28)|0);
      var $32=HEAP32[(($31)>>2)];
      _HPDF_FreeMem($29, $32);
      __label__ = 7; break;
    case 7: 
      var $34=$1;
      var $35=(($34+8)|0);
      var $36=HEAP32[(($35)>>2)];
      var $37=$attr;
      var $38=$37;
      _HPDF_FreeMem($36, $38);
      __label__ = 8; break;
    case 8: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}


function _TextWidth1396($agg_result, $font, $text, $len) {
  var __stackBase__  = STACKTOP; STACKTOP += 16; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $attr;
      var $ret=__stackBase__;
      var $i;
      var $b;
      $1=$font;
      $2=$text;
      $3=$len;
      var $4=$1;
      var $5=(($4+44)|0);
      var $6=HEAP32[(($5)>>2)];
      var $7=$6;
      $attr=$7;
      var $8=$ret;
      HEAP32[(($8)>>2)]=0; HEAP32[((($8)+(4))>>2)]=0; HEAP32[((($8)+(8))>>2)]=0; HEAP32[((($8)+(12))>>2)]=0;
      $b=0;
      var $9=$attr;
      var $10=(($9+24)|0);
      var $11=HEAP32[(($10)>>2)];
      var $12=(($11)|0)!=0;
      if ($12) { __label__ = 3; break; } else { __label__ = 15; break; }
    case 3: 
      $i=0;
      __label__ = 4; break;
    case 4: 
      var $15=$i;
      var $16=$3;
      var $17=(($15)>>>0) < (($16)>>>0);
      if ($17) { __label__ = 5; break; } else { __label__ = 14; break; }
    case 5: 
      var $19=$i;
      var $20=$2;
      var $21=(($20+$19)|0);
      var $22=HEAP8[($21)];
      $b=$22;
      var $23=(($ret)|0);
      var $24=HEAP32[(($23)>>2)];
      var $25=((($24)+(1))|0);
      HEAP32[(($23)>>2)]=$25;
      var $26=$1;
      var $27=$b;
      var $28=_CharWidth($26, $27);
      var $29=(($ret+8)|0);
      var $30=HEAP32[(($29)>>2)];
      var $31=((($30)+($28))|0);
      HEAP32[(($29)>>2)]=$31;
      var $32=$b;
      var $33=(($32)&255);
      var $34=(($33)|0)==0;
      if ($34) { __label__ = 11; break; } else { __label__ = 6; break; }
    case 6: 
      var $36=$b;
      var $37=(($36)&255);
      var $38=(($37)|0)==9;
      if ($38) { __label__ = 11; break; } else { __label__ = 7; break; }
    case 7: 
      var $40=$b;
      var $41=(($40)&255);
      var $42=(($41)|0)==10;
      if ($42) { __label__ = 11; break; } else { __label__ = 8; break; }
    case 8: 
      var $44=$b;
      var $45=(($44)&255);
      var $46=(($45)|0)==12;
      if ($46) { __label__ = 11; break; } else { __label__ = 9; break; }
    case 9: 
      var $48=$b;
      var $49=(($48)&255);
      var $50=(($49)|0)==13;
      if ($50) { __label__ = 11; break; } else { __label__ = 10; break; }
    case 10: 
      var $52=$b;
      var $53=(($52)&255);
      var $54=(($53)|0)==32;
      if ($54) { __label__ = 11; break; } else { __label__ = 12; break; }
    case 11: 
      var $56=(($ret+12)|0);
      var $57=HEAP32[(($56)>>2)];
      var $58=((($57)+(1))|0);
      HEAP32[(($56)>>2)]=$58;
      var $59=(($ret+4)|0);
      var $60=HEAP32[(($59)>>2)];
      var $61=((($60)+(1))|0);
      HEAP32[(($59)>>2)]=$61;
      __label__ = 12; break;
    case 12: 
      __label__ = 13; break;
    case 13: 
      var $64=$i;
      var $65=((($64)+(1))|0);
      $i=$65;
      __label__ = 4; break;
    case 14: 
      __label__ = 16; break;
    case 15: 
      var $68=$1;
      var $69=(($68+12)|0);
      var $70=HEAP32[(($69)>>2)];
      var $71=_HPDF_SetError($70, 4122, 0);
      __label__ = 16; break;
    case 16: 
      var $73=$b;
      var $74=(($73)&255);
      var $75=(($74)|0)==0;
      if ($75) { __label__ = 22; break; } else { __label__ = 17; break; }
    case 17: 
      var $77=$b;
      var $78=(($77)&255);
      var $79=(($78)|0)==9;
      if ($79) { __label__ = 22; break; } else { __label__ = 18; break; }
    case 18: 
      var $81=$b;
      var $82=(($81)&255);
      var $83=(($82)|0)==10;
      if ($83) { __label__ = 22; break; } else { __label__ = 19; break; }
    case 19: 
      var $85=$b;
      var $86=(($85)&255);
      var $87=(($86)|0)==12;
      if ($87) { __label__ = 22; break; } else { __label__ = 20; break; }
    case 20: 
      var $89=$b;
      var $90=(($89)&255);
      var $91=(($90)|0)==13;
      if ($91) { __label__ = 22; break; } else { __label__ = 21; break; }
    case 21: 
      var $93=$b;
      var $94=(($93)&255);
      var $95=(($94)|0)==32;
      if ($95) { __label__ = 22; break; } else { __label__ = 23; break; }
    case 22: 
      __label__ = 24; break;
    case 23: 
      var $98=(($ret+4)|0);
      var $99=HEAP32[(($98)>>2)];
      var $100=((($99)+(1))|0);
      HEAP32[(($98)>>2)]=$100;
      __label__ = 24; break;
    case 24: 
      var $102=$agg_result;
      var $103=$ret;
      assert(16 % 1 === 0, 'memcpy given ' + 16 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP32[(($102)>>2)]=HEAP32[(($103)>>2)];HEAP32[((($102)+(4))>>2)]=HEAP32[((($103)+(4))>>2)];HEAP32[((($102)+(8))>>2)]=HEAP32[((($103)+(8))>>2)];HEAP32[((($102)+(12))>>2)]=HEAP32[((($103)+(12))>>2)];
      STACKTOP = __stackBase__;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_TextWidth1396["X"]=1;

function _MeasureText1397($font, $text, $len, $width, $font_size, $char_space, $word_space, $wordwrap, $real_width) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $5;
      var $6;
      var $7;
      var $8;
      var $9;
      var $10;
      var $w;
      var $tmp_len;
      var $i;
      var $b;
      $2=$font;
      $3=$text;
      $4=$len;
      $5=$width;
      $6=$font_size;
      $7=$char_space;
      $8=$word_space;
      $9=$wordwrap;
      $10=$real_width;
      $w=0;
      $tmp_len=0;
      $i=0;
      __label__ = 3; break;
    case 3: 
      var $12=$i;
      var $13=$4;
      var $14=(($12)>>>0) < (($13)>>>0);
      if ($14) { __label__ = 4; break; } else { __label__ = 25; break; }
    case 4: 
      var $16=$i;
      var $17=$3;
      var $18=(($17+$16)|0);
      var $19=HEAP8[($18)];
      $b=$19;
      var $20=$b;
      var $21=(($20)&255);
      var $22=(($21)|0)==0;
      if ($22) { __label__ = 10; break; } else { __label__ = 5; break; }
    case 5: 
      var $24=$b;
      var $25=(($24)&255);
      var $26=(($25)|0)==9;
      if ($26) { __label__ = 10; break; } else { __label__ = 6; break; }
    case 6: 
      var $28=$b;
      var $29=(($28)&255);
      var $30=(($29)|0)==10;
      if ($30) { __label__ = 10; break; } else { __label__ = 7; break; }
    case 7: 
      var $32=$b;
      var $33=(($32)&255);
      var $34=(($33)|0)==12;
      if ($34) { __label__ = 10; break; } else { __label__ = 8; break; }
    case 8: 
      var $36=$b;
      var $37=(($36)&255);
      var $38=(($37)|0)==13;
      if ($38) { __label__ = 10; break; } else { __label__ = 9; break; }
    case 9: 
      var $40=$b;
      var $41=(($40)&255);
      var $42=(($41)|0)==32;
      if ($42) { __label__ = 10; break; } else { __label__ = 13; break; }
    case 10: 
      var $44=$i;
      var $45=((($44)+(1))|0);
      $tmp_len=$45;
      var $46=$10;
      var $47=(($46)|0)!=0;
      if ($47) { __label__ = 11; break; } else { __label__ = 12; break; }
    case 11: 
      var $49=$w;
      var $50=$49;
      var $51=$10;
      HEAPF32[(($51)>>2)]=$50;
      __label__ = 12; break;
    case 12: 
      var $53=$8;
      var $54=$53;
      var $55=$w;
      var $56=($55)+($54);
      $w=$56;
      __label__ = 18; break;
    case 13: 
      var $58=$9;
      var $59=(($58)|0)!=0;
      if ($59) { __label__ = 17; break; } else { __label__ = 14; break; }
    case 14: 
      var $61=$i;
      $tmp_len=$61;
      var $62=$10;
      var $63=(($62)|0)!=0;
      if ($63) { __label__ = 15; break; } else { __label__ = 16; break; }
    case 15: 
      var $65=$w;
      var $66=$65;
      var $67=$10;
      HEAPF32[(($67)>>2)]=$66;
      __label__ = 16; break;
    case 16: 
      __label__ = 17; break;
    case 17: 
      __label__ = 18; break;
    case 18: 
      var $71=$2;
      var $72=$b;
      var $73=_CharWidth($71, $72);
      var $74=(($73)|0);
      var $75=$6;
      var $76=$75;
      var $77=($74)*($76);
      var $78=($77)/(1000);
      var $79=$w;
      var $80=($79)+($78);
      $w=$80;
      var $81=$w;
      var $82=$5;
      var $83=$82;
      var $84=$81 > $83;
      if ($84) { __label__ = 20; break; } else { __label__ = 19; break; }
    case 19: 
      var $86=$b;
      var $87=(($86)&255);
      var $88=(($87)|0)==10;
      if ($88) { __label__ = 20; break; } else { __label__ = 21; break; }
    case 20: 
      var $90=$tmp_len;
      $1=$90;
      __label__ = 28; break;
    case 21: 
      var $92=$i;
      var $93=(($92)>>>0) > 0;
      if ($93) { __label__ = 22; break; } else { __label__ = 23; break; }
    case 22: 
      var $95=$7;
      var $96=$95;
      var $97=$w;
      var $98=($97)+($96);
      $w=$98;
      __label__ = 23; break;
    case 23: 
      __label__ = 24; break;
    case 24: 
      var $101=$i;
      var $102=((($101)+(1))|0);
      $i=$102;
      __label__ = 3; break;
    case 25: 
      var $104=$10;
      var $105=(($104)|0)!=0;
      if ($105) { __label__ = 26; break; } else { __label__ = 27; break; }
    case 26: 
      var $107=$w;
      var $108=$107;
      var $109=$10;
      HEAPF32[(($109)>>2)]=$108;
      __label__ = 27; break;
    case 27: 
      var $111=$4;
      $1=$111;
      __label__ = 28; break;
    case 28: 
      var $113=$1;
      ;
      return $113;
    default: assert(0, "bad label: " + __label__);
  }
}
_MeasureText1397["X"]=1;

function _CreateDescriptor($font) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $font_attr;
      var $def;
      var $def_attr;
      var $descriptor;
      var $ret;
      var $array;
      var $font_data;
      $2=$font;
      var $3=$2;
      var $4=(($3+44)|0);
      var $5=HEAP32[(($4)>>2)];
      var $6=$5;
      $font_attr=$6;
      var $7=$font_attr;
      var $8=(($7+16)|0);
      var $9=HEAP32[(($8)>>2)];
      $def=$9;
      var $10=$def;
      var $11=(($10+208)|0);
      var $12=HEAP32[(($11)>>2)];
      var $13=$12;
      $def_attr=$13;
      var $14=$font_attr;
      var $15=(($14+16)|0);
      var $16=HEAP32[(($15)>>2)];
      var $17=(($16+196)|0);
      var $18=HEAP32[(($17)>>2)];
      var $19=(($18)|0)!=0;
      if ($19) { __label__ = 18; break; } else { __label__ = 3; break; }
    case 3: 
      var $21=$2;
      var $22=(($21+8)|0);
      var $23=HEAP32[(($22)>>2)];
      var $24=_HPDF_Dict_New($23);
      $descriptor=$24;
      $ret=0;
      var $25=$descriptor;
      var $26=(($25)|0)!=0;
      if ($26) { __label__ = 5; break; } else { __label__ = 4; break; }
    case 4: 
      var $28=$2;
      var $29=(($28+12)|0);
      var $30=HEAP32[(($29)>>2)];
      var $31=_HPDF_Error_GetCode($30);
      $1=$31;
      __label__ = 19; break;
    case 5: 
      var $33=$font_attr;
      var $34=(($33+32)|0);
      var $35=HEAP32[(($34)>>2)];
      var $36=$descriptor;
      var $37=$36;
      var $38=_HPDF_Xref_Add($35, $37);
      var $39=$ret;
      var $40=((($39)+($38))|0);
      $ret=$40;
      var $41=$descriptor;
      var $42=_HPDF_Dict_AddName($41, ((STRING_TABLE.__str1368)|0), ((STRING_TABLE.__str81376)|0));
      var $43=$ret;
      var $44=((($43)+($42))|0);
      $ret=$44;
      var $45=$descriptor;
      var $46=$def;
      var $47=(($46+156)|0);
      var $48=HEAP16[(($47)>>1)];
      var $49=(($48 << 16) >> 16);
      var $50=_HPDF_Dict_AddNumber($45, ((STRING_TABLE.__str91377)|0), $49);
      var $51=$ret;
      var $52=((($51)+($50))|0);
      $ret=$52;
      var $53=$descriptor;
      var $54=$def;
      var $55=(($54+158)|0);
      var $56=HEAP16[(($55)>>1)];
      var $57=(($56 << 16) >> 16);
      var $58=_HPDF_Dict_AddNumber($53, ((STRING_TABLE.__str101378)|0), $57);
      var $59=$ret;
      var $60=((($59)+($58))|0);
      $ret=$60;
      var $61=$descriptor;
      var $62=$def;
      var $63=(($62+160)|0);
      var $64=HEAP32[(($63)>>2)];
      var $65=_HPDF_Dict_AddNumber($61, ((STRING_TABLE.__str111379)|0), $64);
      var $66=$ret;
      var $67=((($66)+($65))|0);
      $ret=$67;
      var $68=$2;
      var $69=(($68+8)|0);
      var $70=HEAP32[(($69)>>2)];
      var $71=$def;
      var $72=(($71+164)|0);
      var $73=(($72)|0);
      var $74=HEAPF32[(($73)>>2)];
      var $75=(($72+4)|0);
      var $76=HEAPF32[(($75)>>2)];
      var $77=(($72+8)|0);
      var $78=HEAPF32[(($77)>>2)];
      var $79=(($72+12)|0);
      var $80=HEAPF32[(($79)>>2)];
      var $81=_HPDF_Box_Array_New($70, $74, $76, $78, $80);
      $array=$81;
      var $82=$descriptor;
      var $83=$array;
      var $84=$83;
      var $85=_HPDF_Dict_Add($82, ((STRING_TABLE.__str121380)|0), $84);
      var $86=$ret;
      var $87=((($86)+($85))|0);
      $ret=$87;
      var $88=$descriptor;
      var $89=$def_attr;
      var $90=(($89)|0);
      var $91=(($90)|0);
      var $92=_HPDF_Dict_AddName($88, ((STRING_TABLE.__str131381)|0), $91);
      var $93=$ret;
      var $94=((($93)+($92))|0);
      $ret=$94;
      var $95=$descriptor;
      var $96=$def;
      var $97=(($96+180)|0);
      var $98=HEAP16[(($97)>>1)];
      var $99=(($98 << 16) >> 16);
      var $100=_HPDF_Dict_AddNumber($95, ((STRING_TABLE.__str141382)|0), $99);
      var $101=$ret;
      var $102=((($101)+($100))|0);
      $ret=$102;
      var $103=$descriptor;
      var $104=$def;
      var $105=(($104+182)|0);
      var $106=HEAPU16[(($105)>>1)];
      var $107=(($106)&65535);
      var $108=_HPDF_Dict_AddNumber($103, ((STRING_TABLE.__str151383)|0), $107);
      var $109=$ret;
      var $110=((($109)+($108))|0);
      $ret=$110;
      var $111=$descriptor;
      var $112=$def;
      var $113=(($112+192)|0);
      var $114=HEAPU16[(($113)>>1)];
      var $115=(($114)&65535);
      var $116=_HPDF_Dict_AddNumber($111, ((STRING_TABLE.__str161384)|0), $115);
      var $117=$ret;
      var $118=((($117)+($116))|0);
      $ret=$118;
      var $119=$def_attr;
      var $120=(($119+132)|0);
      var $121=HEAP32[(($120)>>2)];
      var $122=(($121)|0)!=0;
      if ($122) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      var $124=$descriptor;
      var $125=$def_attr;
      var $126=(($125+132)|0);
      var $127=HEAP32[(($126)>>2)];
      var $128=_HPDF_Dict_AddName($124, ((STRING_TABLE.__str171385)|0), $127);
      var $129=$ret;
      var $130=((($129)+($128))|0);
      $ret=$130;
      __label__ = 7; break;
    case 7: 
      var $132=$ret;
      var $133=(($132)|0)!=0;
      if ($133) { __label__ = 8; break; } else { __label__ = 9; break; }
    case 8: 
      var $135=$2;
      var $136=(($135+12)|0);
      var $137=HEAP32[(($136)>>2)];
      var $138=_HPDF_Error_GetCode($137);
      $1=$138;
      __label__ = 19; break;
    case 9: 
      var $140=$def_attr;
      var $141=(($140+340)|0);
      var $142=HEAP32[(($141)>>2)];
      var $143=(($142)|0)!=0;
      if ($143) { __label__ = 10; break; } else { __label__ = 15; break; }
    case 10: 
      var $145=$2;
      var $146=(($145+8)|0);
      var $147=HEAP32[(($146)>>2)];
      var $148=$font_attr;
      var $149=(($148+32)|0);
      var $150=HEAP32[(($149)>>2)];
      var $151=_HPDF_DictStream_New($147, $150);
      $font_data=$151;
      var $152=$font_data;
      var $153=(($152)|0)!=0;
      if ($153) { __label__ = 12; break; } else { __label__ = 11; break; }
    case 11: 
      var $155=$2;
      var $156=(($155+12)|0);
      var $157=HEAP32[(($156)>>2)];
      var $158=_HPDF_Error_GetCode($157);
      $1=$158;
      __label__ = 19; break;
    case 12: 
      var $160=$font_attr;
      var $161=(($160+16)|0);
      var $162=HEAP32[(($161)>>2)];
      var $163=$font_data;
      var $164=(($163+36)|0);
      var $165=HEAP32[(($164)>>2)];
      var $166=_HPDF_TTFontDef_SaveFontData($162, $165);
      var $167=(($166)|0)!=0;
      if ($167) { __label__ = 13; break; } else { __label__ = 14; break; }
    case 13: 
      var $169=$2;
      var $170=(($169+12)|0);
      var $171=HEAP32[(($170)>>2)];
      var $172=_HPDF_Error_GetCode($171);
      $1=$172;
      __label__ = 19; break;
    case 14: 
      var $174=$descriptor;
      var $175=$font_data;
      var $176=$175;
      var $177=_HPDF_Dict_Add($174, ((STRING_TABLE.__str181386)|0), $176);
      var $178=$ret;
      var $179=((($178)+($177))|0);
      $ret=$179;
      var $180=$font_data;
      var $181=$def_attr;
      var $182=(($181+336)|0);
      var $183=HEAP32[(($182)>>2)];
      var $184=_HPDF_Dict_AddNumber($180, ((STRING_TABLE.__str191387)|0), $183);
      var $185=$ret;
      var $186=((($185)+($184))|0);
      $ret=$186;
      var $187=$font_data;
      var $188=_HPDF_Dict_AddNumber($187, ((STRING_TABLE.__str201388)|0), 0);
      var $189=$ret;
      var $190=((($189)+($188))|0);
      $ret=$190;
      var $191=$font_data;
      var $192=_HPDF_Dict_AddNumber($191, ((STRING_TABLE.__str211389)|0), 0);
      var $193=$ret;
      var $194=((($193)+($192))|0);
      $ret=$194;
      var $195=$2;
      var $196=(($195+40)|0);
      var $197=HEAP32[(($196)>>2)];
      var $198=$font_data;
      var $199=(($198+40)|0);
      HEAP32[(($199)>>2)]=$197;
      __label__ = 15; break;
    case 15: 
      var $201=$ret;
      var $202=(($201)|0)!=0;
      if ($202) { __label__ = 16; break; } else { __label__ = 17; break; }
    case 16: 
      var $204=$2;
      var $205=(($204+12)|0);
      var $206=HEAP32[(($205)>>2)];
      var $207=_HPDF_Error_GetCode($206);
      $1=$207;
      __label__ = 19; break;
    case 17: 
      var $209=$descriptor;
      var $210=$font_attr;
      var $211=(($210+16)|0);
      var $212=HEAP32[(($211)>>2)];
      var $213=(($212+196)|0);
      HEAP32[(($213)>>2)]=$209;
      __label__ = 18; break;
    case 18: 
      var $215=$2;
      var $216=$font_attr;
      var $217=(($216+16)|0);
      var $218=HEAP32[(($217)>>2)];
      var $219=(($218+196)|0);
      var $220=HEAP32[(($219)>>2)];
      var $221=$220;
      var $222=_HPDF_Dict_Add($215, ((STRING_TABLE.__str81376)|0), $221);
      $1=$222;
      __label__ = 19; break;
    case 19: 
      var $224=$1;
      ;
      return $224;
    default: assert(0, "bad label: " + __label__);
  }
}
_CreateDescriptor["X"]=1;

function _CharWidth($font, $code) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $attr;
      var $unicode;
      $1=$font;
      $2=$code;
      var $3=$1;
      var $4=(($3+44)|0);
      var $5=HEAP32[(($4)>>2)];
      var $6=$5;
      $attr=$6;
      var $7=$2;
      var $8=(($7)&255);
      var $9=$attr;
      var $10=(($9+28)|0);
      var $11=HEAP32[(($10)>>2)];
      var $12=(($11+$8)|0);
      var $13=HEAPU8[($12)];
      var $14=(($13)&255);
      var $15=(($14)|0)==0;
      if ($15) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $17=$attr;
      var $18=(($17+20)|0);
      var $19=HEAP32[(($18)>>2)];
      var $20=$2;
      var $21=(($20)&255);
      var $22=_HPDF_Encoder_ToUnicode($19, $21);
      $unicode=$22;
      var $23=$2;
      var $24=(($23)&255);
      var $25=$attr;
      var $26=(($25+28)|0);
      var $27=HEAP32[(($26)>>2)];
      var $28=(($27+$24)|0);
      HEAP8[($28)]=1;
      var $29=$attr;
      var $30=(($29+16)|0);
      var $31=HEAP32[(($30)>>2)];
      var $32=$unicode;
      var $33=_HPDF_TTFontDef_GetCharWidth($31, $32);
      var $34=$2;
      var $35=(($34)&255);
      var $36=$attr;
      var $37=(($36+24)|0);
      var $38=HEAP32[(($37)>>2)];
      var $39=(($38+($35<<1))|0);
      HEAP16[(($39)>>1)]=$33;
      __label__ = 4; break;
    case 4: 
      var $41=$2;
      var $42=(($41)&255);
      var $43=$attr;
      var $44=(($43+24)|0);
      var $45=HEAP32[(($44)>>2)];
      var $46=(($45+($42<<1))|0);
      var $47=HEAP16[(($46)>>1)];
      var $48=(($47 << 16) >> 16);
      ;
      return $48;
    default: assert(0, "bad label: " + __label__);
  }
}
_CharWidth["X"]=1;

function _Type1Font_MeasureText($font, $text, $len, $width, $font_size, $char_space, $word_space, $wordwrap, $real_width) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $5;
      var $6;
      var $7;
      var $8;
      var $9;
      var $10;
      var $w;
      var $tmp_len;
      var $i;
      var $attr;
      var $b;
      $2=$font;
      $3=$text;
      $4=$len;
      $5=$width;
      $6=$font_size;
      $7=$char_space;
      $8=$word_space;
      $9=$wordwrap;
      $10=$real_width;
      $w=0;
      $tmp_len=0;
      var $11=$2;
      var $12=(($11+44)|0);
      var $13=HEAP32[(($12)>>2)];
      var $14=$13;
      $attr=$14;
      $i=0;
      __label__ = 3; break;
    case 3: 
      var $16=$i;
      var $17=$4;
      var $18=(($16)>>>0) < (($17)>>>0);
      if ($18) { __label__ = 4; break; } else { __label__ = 25; break; }
    case 4: 
      var $20=$i;
      var $21=$3;
      var $22=(($21+$20)|0);
      var $23=HEAP8[($22)];
      $b=$23;
      var $24=$b;
      var $25=(($24)&255);
      var $26=(($25)|0)==0;
      if ($26) { __label__ = 10; break; } else { __label__ = 5; break; }
    case 5: 
      var $28=$b;
      var $29=(($28)&255);
      var $30=(($29)|0)==9;
      if ($30) { __label__ = 10; break; } else { __label__ = 6; break; }
    case 6: 
      var $32=$b;
      var $33=(($32)&255);
      var $34=(($33)|0)==10;
      if ($34) { __label__ = 10; break; } else { __label__ = 7; break; }
    case 7: 
      var $36=$b;
      var $37=(($36)&255);
      var $38=(($37)|0)==12;
      if ($38) { __label__ = 10; break; } else { __label__ = 8; break; }
    case 8: 
      var $40=$b;
      var $41=(($40)&255);
      var $42=(($41)|0)==13;
      if ($42) { __label__ = 10; break; } else { __label__ = 9; break; }
    case 9: 
      var $44=$b;
      var $45=(($44)&255);
      var $46=(($45)|0)==32;
      if ($46) { __label__ = 10; break; } else { __label__ = 13; break; }
    case 10: 
      var $48=$i;
      var $49=((($48)+(1))|0);
      $tmp_len=$49;
      var $50=$10;
      var $51=(($50)|0)!=0;
      if ($51) { __label__ = 11; break; } else { __label__ = 12; break; }
    case 11: 
      var $53=$w;
      var $54=$10;
      HEAPF32[(($54)>>2)]=$53;
      __label__ = 12; break;
    case 12: 
      var $56=$8;
      var $57=$w;
      var $58=($57)+($56);
      $w=$58;
      __label__ = 18; break;
    case 13: 
      var $60=$9;
      var $61=(($60)|0)!=0;
      if ($61) { __label__ = 17; break; } else { __label__ = 14; break; }
    case 14: 
      var $63=$i;
      $tmp_len=$63;
      var $64=$10;
      var $65=(($64)|0)!=0;
      if ($65) { __label__ = 15; break; } else { __label__ = 16; break; }
    case 15: 
      var $67=$w;
      var $68=$10;
      HEAPF32[(($68)>>2)]=$67;
      __label__ = 16; break;
    case 16: 
      __label__ = 17; break;
    case 17: 
      __label__ = 18; break;
    case 18: 
      var $72=$b;
      var $73=(($72)&255);
      var $74=$attr;
      var $75=(($74+24)|0);
      var $76=HEAP32[(($75)>>2)];
      var $77=(($76+($73<<1))|0);
      var $78=HEAP16[(($77)>>1)];
      var $79=(($78 << 16) >> 16);
      var $80=(($79)|0);
      var $81=$6;
      var $82=($80)*($81);
      var $83=($82)/(1000);
      var $84=$w;
      var $85=($84)+($83);
      $w=$85;
      var $86=$w;
      var $87=$5;
      var $88=$86 > $87;
      if ($88) { __label__ = 20; break; } else { __label__ = 19; break; }
    case 19: 
      var $90=$b;
      var $91=(($90)&255);
      var $92=(($91)|0)==10;
      if ($92) { __label__ = 20; break; } else { __label__ = 21; break; }
    case 20: 
      var $94=$tmp_len;
      $1=$94;
      __label__ = 28; break;
    case 21: 
      var $96=$i;
      var $97=(($96)>>>0) > 0;
      if ($97) { __label__ = 22; break; } else { __label__ = 23; break; }
    case 22: 
      var $99=$7;
      var $100=$w;
      var $101=($100)+($99);
      $w=$101;
      __label__ = 23; break;
    case 23: 
      __label__ = 24; break;
    case 24: 
      var $104=$i;
      var $105=((($104)+(1))|0);
      $i=$105;
      __label__ = 3; break;
    case 25: 
      var $107=$10;
      var $108=(($107)|0)!=0;
      if ($108) { __label__ = 26; break; } else { __label__ = 27; break; }
    case 26: 
      var $110=$w;
      var $111=$10;
      HEAPF32[(($111)>>2)]=$110;
      __label__ = 27; break;
    case 27: 
      var $113=$4;
      $1=$113;
      __label__ = 28; break;
    case 28: 
      var $115=$1;
      ;
      return $115;
    default: assert(0, "bad label: " + __label__);
  }
}
_Type1Font_MeasureText["X"]=1;

function _HPDF_Type1Font_New($mmgr, $fontdef, $encoder, $xref) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $5;
      var $font;
      var $attr;
      var $fontdef_attr;
      var $encoder_attr;
      var $ret;
      var $i;
      var $u;
      var $w;
      $2=$mmgr;
      $3=$fontdef;
      $4=$encoder;
      $5=$xref;
      $ret=0;
      var $6=$4;
      var $7=(($6+140)|0);
      var $8=HEAP32[(($7)>>2)];
      var $9=(($8)|0)!=0;
      if ($9) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $11=$2;
      var $12=(($11)|0);
      var $13=HEAP32[(($12)>>2)];
      var $14=_HPDF_SetError($13, 4136, 0);
      $1=0;
      __label__ = 25; break;
    case 4: 
      var $16=$3;
      var $17=(($16+140)|0);
      var $18=HEAP32[(($17)>>2)];
      var $19=(($18)|0)!=0;
      if ($19) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $21=$2;
      var $22=(($21)|0);
      var $23=HEAP32[(($22)>>2)];
      var $24=_HPDF_SetError($23, 4142, 0);
      $1=0;
      __label__ = 25; break;
    case 6: 
      var $26=$2;
      var $27=_HPDF_Dict_New($26);
      $font=$27;
      var $28=$font;
      var $29=(($28)|0)!=0;
      if ($29) { __label__ = 8; break; } else { __label__ = 7; break; }
    case 7: 
      $1=0;
      __label__ = 25; break;
    case 8: 
      var $32=$font;
      var $33=(($32)|0);
      var $34=(($33+6)|0);
      var $35=HEAPU16[(($34)>>1)];
      var $36=(($35)&65535);
      var $37=$36 | 256;
      var $38=(($37) & 65535);
      HEAP16[(($34)>>1)]=$38;
      var $39=$2;
      var $40=_HPDF_GetMem($39, 48);
      var $41=$40;
      $attr=$41;
      var $42=$attr;
      var $43=(($42)|0)!=0;
      if ($43) { __label__ = 10; break; } else { __label__ = 9; break; }
    case 9: 
      var $45=$font;
      _HPDF_Dict_Free($45);
      $1=0;
      __label__ = 25; break;
    case 10: 
      var $47=$font;
      var $48=(($47)|0);
      var $49=(($48+6)|0);
      var $50=HEAPU16[(($49)>>1)];
      var $51=(($50)&65535);
      var $52=$51 | 256;
      var $53=(($52) & 65535);
      HEAP16[(($49)>>1)]=$53;
      var $54=$font;
      var $55=(($54+24)|0);
      HEAP32[(($55)>>2)]=204;
      var $56=$font;
      var $57=(($56+32)|0);
      HEAP32[(($57)>>2)]=206;
      var $58=$attr;
      var $59=$58;
      var $60=_HPDF_MemSet($59, 0, 48);
      var $61=$attr;
      var $62=$61;
      var $63=$font;
      var $64=(($63+44)|0);
      HEAP32[(($64)>>2)]=$62;
      var $65=$attr;
      var $66=(($65)|0);
      HEAP32[(($66)>>2)]=0;
      var $67=$attr;
      var $68=(($67+4)|0);
      HEAP32[(($68)>>2)]=0;
      var $69=$attr;
      var $70=(($69+8)|0);
      HEAP32[(($70)>>2)]=208;
      var $71=$attr;
      var $72=(($71+12)|0);
      HEAP32[(($72)>>2)]=210;
      var $73=$3;
      var $74=$attr;
      var $75=(($74+16)|0);
      HEAP32[(($75)>>2)]=$73;
      var $76=$4;
      var $77=$attr;
      var $78=(($77+20)|0);
      HEAP32[(($78)>>2)]=$76;
      var $79=$5;
      var $80=$attr;
      var $81=(($80+32)|0);
      HEAP32[(($81)>>2)]=$79;
      var $82=$2;
      var $83=_HPDF_GetMem($82, 512);
      var $84=$83;
      var $85=$attr;
      var $86=(($85+24)|0);
      HEAP32[(($86)>>2)]=$84;
      var $87=$attr;
      var $88=(($87+24)|0);
      var $89=HEAP32[(($88)>>2)];
      var $90=(($89)|0)!=0;
      if ($90) { __label__ = 12; break; } else { __label__ = 11; break; }
    case 11: 
      var $92=$font;
      _HPDF_Dict_Free($92);
      $1=0;
      __label__ = 25; break;
    case 12: 
      var $94=$4;
      var $95=(($94+164)|0);
      var $96=HEAP32[(($95)>>2)];
      var $97=$96;
      $encoder_attr=$97;
      var $98=$attr;
      var $99=(($98+24)|0);
      var $100=HEAP32[(($99)>>2)];
      var $101=$100;
      var $102=_HPDF_MemSet($101, 0, 512);
      var $103=$encoder_attr;
      var $104=(($103+128)|0);
      var $105=HEAPU8[($104)];
      var $106=(($105)&255);
      $i=$106;
      __label__ = 13; break;
    case 13: 
      var $108=$i;
      var $109=$encoder_attr;
      var $110=(($109+129)|0);
      var $111=HEAPU8[($110)];
      var $112=(($111)&255);
      var $113=(($108)>>>0) <= (($112)>>>0);
      if ($113) { __label__ = 14; break; } else { __label__ = 16; break; }
    case 14: 
      var $115=$i;
      var $116=$encoder_attr;
      var $117=(($116+130)|0);
      var $118=(($117+($115<<1))|0);
      var $119=HEAP16[(($118)>>1)];
      $u=$119;
      var $120=$3;
      var $121=$u;
      var $122=_HPDF_Type1FontDef_GetWidth($120, $121);
      $w=$122;
      var $123=$w;
      var $124=$i;
      var $125=$attr;
      var $126=(($125+24)|0);
      var $127=HEAP32[(($126)>>2)];
      var $128=(($127+($124<<1))|0);
      HEAP16[(($128)>>1)]=$123;
      __label__ = 15; break;
    case 15: 
      var $130=$i;
      var $131=((($130)+(1))|0);
      $i=$131;
      __label__ = 13; break;
    case 16: 
      var $133=$3;
      var $134=(($133+208)|0);
      var $135=HEAP32[(($134)>>2)];
      var $136=$135;
      $fontdef_attr=$136;
      var $137=$font;
      var $138=_HPDF_Dict_AddName($137, ((STRING_TABLE.__str1398)|0), ((STRING_TABLE.__str11399)|0));
      var $139=$ret;
      var $140=((($139)+($138))|0);
      $ret=$140;
      var $141=$font;
      var $142=$3;
      var $143=(($142+4)|0);
      var $144=(($143)|0);
      var $145=_HPDF_Dict_AddName($141, ((STRING_TABLE.__str21400)|0), $144);
      var $146=$ret;
      var $147=((($146)+($145))|0);
      $ret=$147;
      var $148=$font;
      var $149=_HPDF_Dict_AddName($148, ((STRING_TABLE.__str31401)|0), ((STRING_TABLE.__str41402)|0));
      var $150=$ret;
      var $151=((($150)+($149))|0);
      $ret=$151;
      var $152=$fontdef_attr;
      var $153=(($152+160)|0);
      var $154=HEAP32[(($153)>>2)];
      var $155=(($154)|0)!=0;
      if ($155) { __label__ = 20; break; } else { __label__ = 17; break; }
    case 17: 
      var $157=$3;
      var $158=(($157+188)|0);
      var $159=HEAP16[(($158)>>1)];
      var $160=(($159 << 16) >> 16);
      var $161=(($160)|0)!=0;
      if ($161) { __label__ = 18; break; } else { __label__ = 19; break; }
    case 18: 
      var $163=$font;
      var $164=$3;
      var $165=(($164+188)|0);
      var $166=HEAP16[(($165)>>1)];
      var $167=(($166 << 16) >> 16);
      var $168=_HPDF_Dict_AddNumber($163, ((STRING_TABLE.__str51403)|0), $167);
      var $169=$ret;
      var $170=((($169)+($168))|0);
      $ret=$170;
      __label__ = 19; break;
    case 19: 
      var $172=$2;
      var $173=$font;
      var $174=$5;
      var $175=_Type1Font_CreateDescriptor($172, $173, $174);
      var $176=$ret;
      var $177=((($176)+($175))|0);
      $ret=$177;
      __label__ = 20; break;
    case 20: 
      var $179=$ret;
      var $180=(($179)|0)!=0;
      if ($180) { __label__ = 21; break; } else { __label__ = 22; break; }
    case 21: 
      var $182=$font;
      _HPDF_Dict_Free($182);
      $1=0;
      __label__ = 25; break;
    case 22: 
      var $184=$5;
      var $185=$font;
      var $186=$185;
      var $187=_HPDF_Xref_Add($184, $186);
      var $188=(($187)|0)!=0;
      if ($188) { __label__ = 23; break; } else { __label__ = 24; break; }
    case 23: 
      $1=0;
      __label__ = 25; break;
    case 24: 
      var $191=$font;
      $1=$191;
      __label__ = 25; break;
    case 25: 
      var $193=$1;
      ;
      return $193;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Type1Font_New["X"]=1;

function _Type1Font_OnWrite($obj, $stream) {
  var __stackBase__  = STACKTOP; STACKTOP += 512; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $attr;
      var $fontdef_attr;
      var $encoder_attr;
      var $i;
      var $ret;
      var $buf=__stackBase__;
      var $eptr;
      var $pbuf;
      $2=$obj;
      $3=$stream;
      var $4=$2;
      var $5=(($4+44)|0);
      var $6=HEAP32[(($5)>>2)];
      var $7=$6;
      $attr=$7;
      var $8=$attr;
      var $9=(($8+16)|0);
      var $10=HEAP32[(($9)>>2)];
      var $11=(($10+208)|0);
      var $12=HEAP32[(($11)>>2)];
      var $13=$12;
      $fontdef_attr=$13;
      var $14=$attr;
      var $15=(($14+20)|0);
      var $16=HEAP32[(($15)>>2)];
      var $17=(($16+164)|0);
      var $18=HEAP32[(($17)>>2)];
      var $19=$18;
      $encoder_attr=$19;
      var $20=(($buf)|0);
      var $21=(($20+512)|0);
      var $22=((($21)-(1))|0);
      $eptr=$22;
      var $23=$fontdef_attr;
      var $24=(($23+160)|0);
      var $25=HEAP32[(($24)>>2)];
      var $26=(($25)|0)!=0;
      if ($26) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $28=$encoder_attr;
      var $29=(($28+644)|0);
      var $30=HEAP32[(($29)>>2)];
      var $31=(($30)|0)!=0;
      if ($31) { __label__ = 4; break; } else { __label__ = 23; break; }
    case 4: 
      var $33=(($buf)|0);
      var $34=$eptr;
      var $35=_HPDF_StrCpy($33, ((STRING_TABLE.__str61404)|0), $34);
      $pbuf=$35;
      var $36=$pbuf;
      var $37=$encoder_attr;
      var $38=(($37+128)|0);
      var $39=HEAPU8[($38)];
      var $40=(($39)&255);
      var $41=$eptr;
      var $42=_HPDF_IToA($36, $40, $41);
      $pbuf=$42;
      var $43=$pbuf;
      var $44=$eptr;
      var $45=_HPDF_StrCpy($43, ((STRING_TABLE.__str71405)|0), $44);
      var $46=$3;
      var $47=(($buf)|0);
      var $48=_HPDF_Stream_WriteStr($46, $47);
      $ret=$48;
      var $49=(($48)|0)!=0;
      if ($49) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $51=$ret;
      $1=$51;
      __label__ = 24; break;
    case 6: 
      var $53=(($buf)|0);
      var $54=$eptr;
      var $55=_HPDF_StrCpy($53, ((STRING_TABLE.__str81406)|0), $54);
      $pbuf=$55;
      var $56=$pbuf;
      var $57=$encoder_attr;
      var $58=(($57+129)|0);
      var $59=HEAPU8[($58)];
      var $60=(($59)&255);
      var $61=$eptr;
      var $62=_HPDF_IToA($56, $60, $61);
      $pbuf=$62;
      var $63=$pbuf;
      var $64=$eptr;
      var $65=_HPDF_StrCpy($63, ((STRING_TABLE.__str71405)|0), $64);
      var $66=$3;
      var $67=(($buf)|0);
      var $68=_HPDF_Stream_WriteStr($66, $67);
      $ret=$68;
      var $69=(($68)|0)!=0;
      if ($69) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $71=$ret;
      $1=$71;
      __label__ = 24; break;
    case 8: 
      var $73=$3;
      var $74=_HPDF_Stream_WriteEscapeName($73, ((STRING_TABLE.__str91407)|0));
      $ret=$74;
      var $75=(($74)|0)!=0;
      if ($75) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      var $77=$ret;
      $1=$77;
      __label__ = 24; break;
    case 10: 
      var $79=$3;
      var $80=_HPDF_Stream_WriteStr($79, ((STRING_TABLE.__str101408)|0));
      $ret=$80;
      var $81=(($80)|0)!=0;
      if ($81) { __label__ = 11; break; } else { __label__ = 12; break; }
    case 11: 
      var $83=$ret;
      $1=$83;
      __label__ = 24; break;
    case 12: 
      var $85=(($buf)|0);
      $pbuf=$85;
      var $86=$encoder_attr;
      var $87=(($86+128)|0);
      var $88=HEAPU8[($87)];
      var $89=(($88)&255);
      $i=$89;
      __label__ = 13; break;
    case 13: 
      var $91=$i;
      var $92=$encoder_attr;
      var $93=(($92+129)|0);
      var $94=HEAPU8[($93)];
      var $95=(($94)&255);
      var $96=(($91)>>>0) <= (($95)>>>0);
      if ($96) { __label__ = 14; break; } else { __label__ = 20; break; }
    case 14: 
      var $98=$pbuf;
      var $99=$i;
      var $100=$attr;
      var $101=(($100+24)|0);
      var $102=HEAP32[(($101)>>2)];
      var $103=(($102+($99<<1))|0);
      var $104=HEAP16[(($103)>>1)];
      var $105=(($104 << 16) >> 16);
      var $106=$eptr;
      var $107=_HPDF_IToA($98, $105, $106);
      $pbuf=$107;
      var $108=$pbuf;
      var $109=(($108+1)|0);
      $pbuf=$109;
      HEAP8[($108)]=32;
      var $110=$i;
      var $111=((($110)+(1))|0);
      var $112=((($111)>>>0))%(16);
      var $113=(($112)|0)==0;
      if ($113) { __label__ = 15; break; } else { __label__ = 18; break; }
    case 15: 
      var $115=$pbuf;
      var $116=$eptr;
      var $117=_HPDF_StrCpy($115, ((STRING_TABLE.__str71405)|0), $116);
      var $118=$3;
      var $119=(($buf)|0);
      var $120=_HPDF_Stream_WriteStr($118, $119);
      $ret=$120;
      var $121=(($120)|0)!=0;
      if ($121) { __label__ = 16; break; } else { __label__ = 17; break; }
    case 16: 
      var $123=$ret;
      $1=$123;
      __label__ = 24; break;
    case 17: 
      var $125=(($buf)|0);
      $pbuf=$125;
      __label__ = 18; break;
    case 18: 
      __label__ = 19; break;
    case 19: 
      var $128=$i;
      var $129=((($128)+(1))|0);
      $i=$129;
      __label__ = 13; break;
    case 20: 
      var $131=$pbuf;
      var $132=$eptr;
      var $133=_HPDF_StrCpy($131, ((STRING_TABLE.__str111409)|0), $132);
      var $134=$3;
      var $135=(($buf)|0);
      var $136=_HPDF_Stream_WriteStr($134, $135);
      $ret=$136;
      var $137=(($136)|0)!=0;
      if ($137) { __label__ = 21; break; } else { __label__ = 22; break; }
    case 21: 
      var $139=$ret;
      $1=$139;
      __label__ = 24; break;
    case 22: 
      __label__ = 23; break;
    case 23: 
      var $142=$attr;
      var $143=(($142+20)|0);
      var $144=HEAP32[(($143)>>2)];
      var $145=(($144+152)|0);
      var $146=HEAP32[(($145)>>2)];
      var $147=$attr;
      var $148=(($147+20)|0);
      var $149=HEAP32[(($148)>>2)];
      var $150=$3;
      var $151=FUNCTION_TABLE[$146]($149, $150);
      $1=$151;
      __label__ = 24; break;
    case 24: 
      var $153=$1;
      STACKTOP = __stackBase__;
      return $153;
    default: assert(0, "bad label: " + __label__);
  }
}
_Type1Font_OnWrite["X"]=1;

function _Type1Font_OnFree($obj) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $attr;
      $1=$obj;
      var $2=$1;
      var $3=(($2+44)|0);
      var $4=HEAP32[(($3)>>2)];
      var $5=$4;
      $attr=$5;
      var $6=$attr;
      var $7=(($6)|0)!=0;
      if ($7) { __label__ = 3; break; } else { __label__ = 6; break; }
    case 3: 
      var $9=$attr;
      var $10=(($9+24)|0);
      var $11=HEAP32[(($10)>>2)];
      var $12=(($11)|0)!=0;
      if ($12) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      var $14=$1;
      var $15=(($14+8)|0);
      var $16=HEAP32[(($15)>>2)];
      var $17=$attr;
      var $18=(($17+24)|0);
      var $19=HEAP32[(($18)>>2)];
      var $20=$19;
      _HPDF_FreeMem($16, $20);
      __label__ = 5; break;
    case 5: 
      var $22=$1;
      var $23=(($22+8)|0);
      var $24=HEAP32[(($23)>>2)];
      var $25=$attr;
      var $26=$25;
      _HPDF_FreeMem($24, $26);
      __label__ = 6; break;
    case 6: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}


function _Type1Font_TextWidth($agg_result, $font, $text, $len) {
  var __stackBase__  = STACKTOP; STACKTOP += 16; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $attr;
      var $ret=__stackBase__;
      var $i;
      var $b;
      $1=$font;
      $2=$text;
      $3=$len;
      var $4=$1;
      var $5=(($4+44)|0);
      var $6=HEAP32[(($5)>>2)];
      var $7=$6;
      $attr=$7;
      var $8=$ret;
      HEAP32[(($8)>>2)]=0; HEAP32[((($8)+(4))>>2)]=0; HEAP32[((($8)+(8))>>2)]=0; HEAP32[((($8)+(12))>>2)]=0;
      $b=0;
      var $9=$attr;
      var $10=(($9+24)|0);
      var $11=HEAP32[(($10)>>2)];
      var $12=(($11)|0)!=0;
      if ($12) { __label__ = 3; break; } else { __label__ = 15; break; }
    case 3: 
      $i=0;
      __label__ = 4; break;
    case 4: 
      var $15=$i;
      var $16=$3;
      var $17=(($15)>>>0) < (($16)>>>0);
      if ($17) { __label__ = 5; break; } else { __label__ = 14; break; }
    case 5: 
      var $19=$i;
      var $20=$2;
      var $21=(($20+$19)|0);
      var $22=HEAP8[($21)];
      $b=$22;
      var $23=(($ret)|0);
      var $24=HEAP32[(($23)>>2)];
      var $25=((($24)+(1))|0);
      HEAP32[(($23)>>2)]=$25;
      var $26=$b;
      var $27=(($26)&255);
      var $28=$attr;
      var $29=(($28+24)|0);
      var $30=HEAP32[(($29)>>2)];
      var $31=(($30+($27<<1))|0);
      var $32=HEAP16[(($31)>>1)];
      var $33=(($32 << 16) >> 16);
      var $34=(($ret+8)|0);
      var $35=HEAP32[(($34)>>2)];
      var $36=((($35)+($33))|0);
      HEAP32[(($34)>>2)]=$36;
      var $37=$b;
      var $38=(($37)&255);
      var $39=(($38)|0)==0;
      if ($39) { __label__ = 11; break; } else { __label__ = 6; break; }
    case 6: 
      var $41=$b;
      var $42=(($41)&255);
      var $43=(($42)|0)==9;
      if ($43) { __label__ = 11; break; } else { __label__ = 7; break; }
    case 7: 
      var $45=$b;
      var $46=(($45)&255);
      var $47=(($46)|0)==10;
      if ($47) { __label__ = 11; break; } else { __label__ = 8; break; }
    case 8: 
      var $49=$b;
      var $50=(($49)&255);
      var $51=(($50)|0)==12;
      if ($51) { __label__ = 11; break; } else { __label__ = 9; break; }
    case 9: 
      var $53=$b;
      var $54=(($53)&255);
      var $55=(($54)|0)==13;
      if ($55) { __label__ = 11; break; } else { __label__ = 10; break; }
    case 10: 
      var $57=$b;
      var $58=(($57)&255);
      var $59=(($58)|0)==32;
      if ($59) { __label__ = 11; break; } else { __label__ = 12; break; }
    case 11: 
      var $61=(($ret+12)|0);
      var $62=HEAP32[(($61)>>2)];
      var $63=((($62)+(1))|0);
      HEAP32[(($61)>>2)]=$63;
      var $64=(($ret+4)|0);
      var $65=HEAP32[(($64)>>2)];
      var $66=((($65)+(1))|0);
      HEAP32[(($64)>>2)]=$66;
      __label__ = 12; break;
    case 12: 
      __label__ = 13; break;
    case 13: 
      var $69=$i;
      var $70=((($69)+(1))|0);
      $i=$70;
      __label__ = 4; break;
    case 14: 
      __label__ = 16; break;
    case 15: 
      var $73=$1;
      var $74=(($73+12)|0);
      var $75=HEAP32[(($74)>>2)];
      var $76=_HPDF_SetError($75, 4122, 0);
      __label__ = 16; break;
    case 16: 
      var $78=$b;
      var $79=(($78)&255);
      var $80=(($79)|0)==0;
      if ($80) { __label__ = 22; break; } else { __label__ = 17; break; }
    case 17: 
      var $82=$b;
      var $83=(($82)&255);
      var $84=(($83)|0)==9;
      if ($84) { __label__ = 22; break; } else { __label__ = 18; break; }
    case 18: 
      var $86=$b;
      var $87=(($86)&255);
      var $88=(($87)|0)==10;
      if ($88) { __label__ = 22; break; } else { __label__ = 19; break; }
    case 19: 
      var $90=$b;
      var $91=(($90)&255);
      var $92=(($91)|0)==12;
      if ($92) { __label__ = 22; break; } else { __label__ = 20; break; }
    case 20: 
      var $94=$b;
      var $95=(($94)&255);
      var $96=(($95)|0)==13;
      if ($96) { __label__ = 22; break; } else { __label__ = 21; break; }
    case 21: 
      var $98=$b;
      var $99=(($98)&255);
      var $100=(($99)|0)==32;
      if ($100) { __label__ = 22; break; } else { __label__ = 23; break; }
    case 22: 
      __label__ = 24; break;
    case 23: 
      var $103=(($ret+4)|0);
      var $104=HEAP32[(($103)>>2)];
      var $105=((($104)+(1))|0);
      HEAP32[(($103)>>2)]=$105;
      __label__ = 24; break;
    case 24: 
      var $107=$agg_result;
      var $108=$ret;
      assert(16 % 1 === 0, 'memcpy given ' + 16 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP32[(($107)>>2)]=HEAP32[(($108)>>2)];HEAP32[((($107)+(4))>>2)]=HEAP32[((($108)+(4))>>2)];HEAP32[((($107)+(8))>>2)]=HEAP32[((($108)+(8))>>2)];HEAP32[((($107)+(12))>>2)]=HEAP32[((($108)+(12))>>2)];
      STACKTOP = __stackBase__;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_Type1Font_TextWidth["X"]=1;

function _Type1Font_CreateDescriptor($mmgr, $font, $xref) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $font_attr;
      var $def;
      var $def_attr;
      var $descriptor;
      var $ret;
      var $array;
      var $font_data;
      $2=$mmgr;
      $3=$font;
      $4=$xref;
      var $5=$3;
      var $6=(($5+44)|0);
      var $7=HEAP32[(($6)>>2)];
      var $8=$7;
      $font_attr=$8;
      var $9=$font_attr;
      var $10=(($9+16)|0);
      var $11=HEAP32[(($10)>>2)];
      $def=$11;
      var $12=$def;
      var $13=(($12+208)|0);
      var $14=HEAP32[(($13)>>2)];
      var $15=$14;
      $def_attr=$15;
      var $16=$font_attr;
      var $17=(($16+16)|0);
      var $18=HEAP32[(($17)>>2)];
      var $19=(($18+196)|0);
      var $20=HEAP32[(($19)>>2)];
      var $21=(($20)|0)!=0;
      if ($21) { __label__ = 18; break; } else { __label__ = 3; break; }
    case 3: 
      var $23=$2;
      var $24=_HPDF_Dict_New($23);
      $descriptor=$24;
      $ret=0;
      var $25=$descriptor;
      var $26=(($25)|0)!=0;
      if ($26) { __label__ = 5; break; } else { __label__ = 4; break; }
    case 4: 
      var $28=$3;
      var $29=(($28+12)|0);
      var $30=HEAP32[(($29)>>2)];
      var $31=_HPDF_Error_GetCode($30);
      $1=$31;
      __label__ = 19; break;
    case 5: 
      var $33=$4;
      var $34=$descriptor;
      var $35=$34;
      var $36=_HPDF_Xref_Add($33, $35);
      var $37=$ret;
      var $38=((($37)+($36))|0);
      $ret=$38;
      var $39=$descriptor;
      var $40=_HPDF_Dict_AddName($39, ((STRING_TABLE.__str1398)|0), ((STRING_TABLE.__str121410)|0));
      var $41=$ret;
      var $42=((($41)+($40))|0);
      $ret=$42;
      var $43=$descriptor;
      var $44=$def;
      var $45=(($44+156)|0);
      var $46=HEAP16[(($45)>>1)];
      var $47=(($46 << 16) >> 16);
      var $48=_HPDF_Dict_AddNumber($43, ((STRING_TABLE.__str131411)|0), $47);
      var $49=$ret;
      var $50=((($49)+($48))|0);
      $ret=$50;
      var $51=$descriptor;
      var $52=$def;
      var $53=(($52+158)|0);
      var $54=HEAP16[(($53)>>1)];
      var $55=(($54 << 16) >> 16);
      var $56=_HPDF_Dict_AddNumber($51, ((STRING_TABLE.__str141412)|0), $55);
      var $57=$ret;
      var $58=((($57)+($56))|0);
      $ret=$58;
      var $59=$descriptor;
      var $60=$def;
      var $61=(($60+160)|0);
      var $62=HEAP32[(($61)>>2)];
      var $63=_HPDF_Dict_AddNumber($59, ((STRING_TABLE.__str151413)|0), $62);
      var $64=$ret;
      var $65=((($64)+($63))|0);
      $ret=$65;
      var $66=$2;
      var $67=$def;
      var $68=(($67+164)|0);
      var $69=(($68)|0);
      var $70=HEAPF32[(($69)>>2)];
      var $71=(($68+4)|0);
      var $72=HEAPF32[(($71)>>2)];
      var $73=(($68+8)|0);
      var $74=HEAPF32[(($73)>>2)];
      var $75=(($68+12)|0);
      var $76=HEAPF32[(($75)>>2)];
      var $77=_HPDF_Box_Array_New($66, $70, $72, $74, $76);
      $array=$77;
      var $78=$descriptor;
      var $79=$array;
      var $80=$79;
      var $81=_HPDF_Dict_Add($78, ((STRING_TABLE.__str161414)|0), $80);
      var $82=$ret;
      var $83=((($82)+($81))|0);
      $ret=$83;
      var $84=$descriptor;
      var $85=$font_attr;
      var $86=(($85+16)|0);
      var $87=HEAP32[(($86)>>2)];
      var $88=(($87+4)|0);
      var $89=(($88)|0);
      var $90=_HPDF_Dict_AddName($84, ((STRING_TABLE.__str171415)|0), $89);
      var $91=$ret;
      var $92=((($91)+($90))|0);
      $ret=$92;
      var $93=$descriptor;
      var $94=$def;
      var $95=(($94+180)|0);
      var $96=HEAP16[(($95)>>1)];
      var $97=(($96 << 16) >> 16);
      var $98=_HPDF_Dict_AddNumber($93, ((STRING_TABLE.__str181416)|0), $97);
      var $99=$ret;
      var $100=((($99)+($98))|0);
      $ret=$100;
      var $101=$descriptor;
      var $102=$def;
      var $103=(($102+182)|0);
      var $104=HEAPU16[(($103)>>1)];
      var $105=(($104)&65535);
      var $106=_HPDF_Dict_AddNumber($101, ((STRING_TABLE.__str191417)|0), $105);
      var $107=$ret;
      var $108=((($107)+($106))|0);
      $ret=$108;
      var $109=$descriptor;
      var $110=$def;
      var $111=(($110+192)|0);
      var $112=HEAPU16[(($111)>>1)];
      var $113=(($112)&65535);
      var $114=_HPDF_Dict_AddNumber($109, ((STRING_TABLE.__str201418)|0), $113);
      var $115=$ret;
      var $116=((($115)+($114))|0);
      $ret=$116;
      var $117=$def_attr;
      var $118=(($117+16)|0);
      var $119=HEAP32[(($118)>>2)];
      var $120=(($119)|0)!=0;
      if ($120) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      var $122=$descriptor;
      var $123=$def_attr;
      var $124=(($123+16)|0);
      var $125=HEAP32[(($124)>>2)];
      var $126=_HPDF_Dict_AddName($122, ((STRING_TABLE.__str211419)|0), $125);
      var $127=$ret;
      var $128=((($127)+($126))|0);
      $ret=$128;
      __label__ = 7; break;
    case 7: 
      var $130=$ret;
      var $131=(($130)|0)!=0;
      if ($131) { __label__ = 8; break; } else { __label__ = 9; break; }
    case 8: 
      var $133=$3;
      var $134=(($133+12)|0);
      var $135=HEAP32[(($134)>>2)];
      var $136=_HPDF_Error_GetCode($135);
      $1=$136;
      __label__ = 19; break;
    case 9: 
      var $138=$def_attr;
      var $139=(($138+168)|0);
      var $140=HEAP32[(($139)>>2)];
      var $141=(($140)|0)!=0;
      if ($141) { __label__ = 10; break; } else { __label__ = 15; break; }
    case 10: 
      var $143=$2;
      var $144=$4;
      var $145=_HPDF_DictStream_New($143, $144);
      $font_data=$145;
      var $146=$font_data;
      var $147=(($146)|0)!=0;
      if ($147) { __label__ = 12; break; } else { __label__ = 11; break; }
    case 11: 
      var $149=$3;
      var $150=(($149+12)|0);
      var $151=HEAP32[(($150)>>2)];
      var $152=_HPDF_Error_GetCode($151);
      $1=$152;
      __label__ = 19; break;
    case 12: 
      var $154=$def_attr;
      var $155=(($154+168)|0);
      var $156=HEAP32[(($155)>>2)];
      var $157=$font_data;
      var $158=(($157+36)|0);
      var $159=HEAP32[(($158)>>2)];
      var $160=_HPDF_Stream_WriteToStream($156, $159, 0, 0);
      var $161=(($160)|0)!=0;
      if ($161) { __label__ = 13; break; } else { __label__ = 14; break; }
    case 13: 
      var $163=$3;
      var $164=(($163+12)|0);
      var $165=HEAP32[(($164)>>2)];
      var $166=_HPDF_Error_GetCode($165);
      $1=$166;
      __label__ = 19; break;
    case 14: 
      var $168=$descriptor;
      var $169=$font_data;
      var $170=$169;
      var $171=_HPDF_Dict_Add($168, ((STRING_TABLE.__str221420)|0), $170);
      var $172=$ret;
      var $173=((($172)+($171))|0);
      $ret=$173;
      var $174=$font_data;
      var $175=$def_attr;
      var $176=(($175+148)|0);
      var $177=HEAP32[(($176)>>2)];
      var $178=_HPDF_Dict_AddNumber($174, ((STRING_TABLE.__str231421)|0), $177);
      var $179=$ret;
      var $180=((($179)+($178))|0);
      $ret=$180;
      var $181=$font_data;
      var $182=$def_attr;
      var $183=(($182+152)|0);
      var $184=HEAP32[(($183)>>2)];
      var $185=_HPDF_Dict_AddNumber($181, ((STRING_TABLE.__str241422)|0), $184);
      var $186=$ret;
      var $187=((($186)+($185))|0);
      $ret=$187;
      var $188=$font_data;
      var $189=$def_attr;
      var $190=(($189+156)|0);
      var $191=HEAP32[(($190)>>2)];
      var $192=_HPDF_Dict_AddNumber($188, ((STRING_TABLE.__str251423)|0), $191);
      var $193=$ret;
      var $194=((($193)+($192))|0);
      $ret=$194;
      var $195=$3;
      var $196=(($195+40)|0);
      var $197=HEAP32[(($196)>>2)];
      var $198=$font_data;
      var $199=(($198+40)|0);
      HEAP32[(($199)>>2)]=$197;
      __label__ = 15; break;
    case 15: 
      var $201=$ret;
      var $202=(($201)|0)!=0;
      if ($202) { __label__ = 16; break; } else { __label__ = 17; break; }
    case 16: 
      var $204=$3;
      var $205=(($204+12)|0);
      var $206=HEAP32[(($205)>>2)];
      var $207=_HPDF_Error_GetCode($206);
      $1=$207;
      __label__ = 19; break;
    case 17: 
      var $209=$descriptor;
      var $210=$font_attr;
      var $211=(($210+16)|0);
      var $212=HEAP32[(($211)>>2)];
      var $213=(($212+196)|0);
      HEAP32[(($213)>>2)]=$209;
      __label__ = 18; break;
    case 18: 
      var $215=$3;
      var $216=$font_attr;
      var $217=(($216+16)|0);
      var $218=HEAP32[(($217)>>2)];
      var $219=(($218+196)|0);
      var $220=HEAP32[(($219)>>2)];
      var $221=$220;
      var $222=_HPDF_Dict_Add($215, ((STRING_TABLE.__str121410)|0), $221);
      $1=$222;
      __label__ = 19; break;
    case 19: 
      var $224=$1;
      ;
      return $224;
    default: assert(0, "bad label: " + __label__);
  }
}
_Type1Font_CreateDescriptor["X"]=1;

function _HPDF_GState_New($mmgr, $current) {
  var __stackBase__  = STACKTOP; STACKTOP += 76; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $gstate;
      var $DEF_MATRIX=__stackBase__;
      var $DEF_RGB_COLOR=(__stackBase__)+(24);
      var $DEF_CMYK_COLOR=(__stackBase__)+(36);
      var $DEF_DASH_MODE=(__stackBase__)+(52);
      $2=$mmgr;
      $3=$current;
      var $4=$3;
      var $5=(($4)|0)!=0;
      if ($5) { __label__ = 3; break; } else { __label__ = 5; break; }
    case 3: 
      var $7=$3;
      var $8=(($7+180)|0);
      var $9=HEAPU32[(($8)>>2)];
      var $10=(($9)>>>0) >= 28;
      if ($10) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      var $12=$2;
      var $13=(($12)|0);
      var $14=HEAP32[(($13)>>2)];
      var $15=_HPDF_SetError($14, 4116, 0);
      $1=0;
      __label__ = 11; break;
    case 5: 
      var $17=$2;
      var $18=_HPDF_GetMem($17, 184);
      var $19=$18;
      $gstate=$19;
      var $20=$gstate;
      var $21=(($20)|0)!=0;
      if ($21) { __label__ = 7; break; } else { __label__ = 6; break; }
    case 6: 
      $1=0;
      __label__ = 11; break;
    case 7: 
      var $24=$3;
      var $25=(($24)|0)!=0;
      if ($25) { __label__ = 8; break; } else { __label__ = 9; break; }
    case 8: 
      var $27=$gstate;
      var $28=(($27)|0);
      var $29=$3;
      var $30=(($29)|0);
      var $31=$28;
      var $32=$30;
      assert(24 % 1 === 0, 'memcpy given ' + 24 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP32[(($31)>>2)]=HEAP32[(($32)>>2)];HEAP32[((($31)+(4))>>2)]=HEAP32[((($32)+(4))>>2)];HEAP32[((($31)+(8))>>2)]=HEAP32[((($32)+(8))>>2)];HEAP32[((($31)+(12))>>2)]=HEAP32[((($32)+(12))>>2)];HEAP32[((($31)+(16))>>2)]=HEAP32[((($32)+(16))>>2)];HEAP32[((($31)+(20))>>2)]=HEAP32[((($32)+(20))>>2)];
      var $33=$3;
      var $34=(($33+24)|0);
      var $35=HEAPF32[(($34)>>2)];
      var $36=$gstate;
      var $37=(($36+24)|0);
      HEAPF32[(($37)>>2)]=$35;
      var $38=$3;
      var $39=(($38+28)|0);
      var $40=HEAP32[(($39)>>2)];
      var $41=$gstate;
      var $42=(($41+28)|0);
      HEAP32[(($42)>>2)]=$40;
      var $43=$3;
      var $44=(($43+32)|0);
      var $45=HEAP32[(($44)>>2)];
      var $46=$gstate;
      var $47=(($46+32)|0);
      HEAP32[(($47)>>2)]=$45;
      var $48=$3;
      var $49=(($48+36)|0);
      var $50=HEAPF32[(($49)>>2)];
      var $51=$gstate;
      var $52=(($51+36)|0);
      HEAPF32[(($52)>>2)]=$50;
      var $53=$gstate;
      var $54=(($53+40)|0);
      var $55=$3;
      var $56=(($55+40)|0);
      var $57=$54;
      var $58=$56;
      assert(24 % 1 === 0, 'memcpy given ' + 24 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP32[(($57)>>2)]=HEAP32[(($58)>>2)];HEAP32[((($57)+(4))>>2)]=HEAP32[((($58)+(4))>>2)];HEAP32[((($57)+(8))>>2)]=HEAP32[((($58)+(8))>>2)];HEAP32[((($57)+(12))>>2)]=HEAP32[((($58)+(12))>>2)];HEAP32[((($57)+(16))>>2)]=HEAP32[((($58)+(16))>>2)];HEAP32[((($57)+(20))>>2)]=HEAP32[((($58)+(20))>>2)];
      var $59=$3;
      var $60=(($59+64)|0);
      var $61=HEAPF32[(($60)>>2)];
      var $62=$gstate;
      var $63=(($62+64)|0);
      HEAPF32[(($63)>>2)]=$61;
      var $64=$3;
      var $65=(($64+68)|0);
      var $66=HEAPF32[(($65)>>2)];
      var $67=$gstate;
      var $68=(($67+68)|0);
      HEAPF32[(($68)>>2)]=$66;
      var $69=$3;
      var $70=(($69+72)|0);
      var $71=HEAPF32[(($70)>>2)];
      var $72=$gstate;
      var $73=(($72+72)|0);
      HEAPF32[(($73)>>2)]=$71;
      var $74=$3;
      var $75=(($74+76)|0);
      var $76=HEAPF32[(($75)>>2)];
      var $77=$gstate;
      var $78=(($77+76)|0);
      HEAPF32[(($78)>>2)]=$76;
      var $79=$3;
      var $80=(($79+80)|0);
      var $81=HEAPF32[(($80)>>2)];
      var $82=$gstate;
      var $83=(($82+80)|0);
      HEAPF32[(($83)>>2)]=$81;
      var $84=$3;
      var $85=(($84+84)|0);
      var $86=HEAP32[(($85)>>2)];
      var $87=$gstate;
      var $88=(($87+84)|0);
      HEAP32[(($88)>>2)]=$86;
      var $89=$3;
      var $90=(($89+88)|0);
      var $91=HEAPF32[(($90)>>2)];
      var $92=$gstate;
      var $93=(($92+88)|0);
      HEAPF32[(($93)>>2)]=$91;
      var $94=$3;
      var $95=(($94+96)|0);
      var $96=HEAP32[(($95)>>2)];
      var $97=$gstate;
      var $98=(($97+96)|0);
      HEAP32[(($98)>>2)]=$96;
      var $99=$3;
      var $100=(($99+92)|0);
      var $101=HEAP32[(($100)>>2)];
      var $102=$gstate;
      var $103=(($102+92)|0);
      HEAP32[(($103)>>2)]=$101;
      var $104=$gstate;
      var $105=(($104+100)|0);
      var $106=$3;
      var $107=(($106+100)|0);
      var $108=$105;
      var $109=$107;
      assert(12 % 1 === 0, 'memcpy given ' + 12 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP32[(($108)>>2)]=HEAP32[(($109)>>2)];HEAP32[((($108)+(4))>>2)]=HEAP32[((($109)+(4))>>2)];HEAP32[((($108)+(8))>>2)]=HEAP32[((($109)+(8))>>2)];
      var $110=$gstate;
      var $111=(($110+112)|0);
      var $112=$3;
      var $113=(($112+112)|0);
      var $114=$111;
      var $115=$113;
      assert(12 % 1 === 0, 'memcpy given ' + 12 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP32[(($114)>>2)]=HEAP32[(($115)>>2)];HEAP32[((($114)+(4))>>2)]=HEAP32[((($115)+(4))>>2)];HEAP32[((($114)+(8))>>2)]=HEAP32[((($115)+(8))>>2)];
      var $116=$gstate;
      var $117=(($116+124)|0);
      var $118=$3;
      var $119=(($118+124)|0);
      var $120=$117;
      var $121=$119;
      assert(16 % 1 === 0, 'memcpy given ' + 16 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP32[(($120)>>2)]=HEAP32[(($121)>>2)];HEAP32[((($120)+(4))>>2)]=HEAP32[((($121)+(4))>>2)];HEAP32[((($120)+(8))>>2)]=HEAP32[((($121)+(8))>>2)];HEAP32[((($120)+(12))>>2)]=HEAP32[((($121)+(12))>>2)];
      var $122=$gstate;
      var $123=(($122+140)|0);
      var $124=$3;
      var $125=(($124+140)|0);
      var $126=$123;
      var $127=$125;
      assert(16 % 1 === 0, 'memcpy given ' + 16 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP32[(($126)>>2)]=HEAP32[(($127)>>2)];HEAP32[((($126)+(4))>>2)]=HEAP32[((($127)+(4))>>2)];HEAP32[((($126)+(8))>>2)]=HEAP32[((($127)+(8))>>2)];HEAP32[((($126)+(12))>>2)]=HEAP32[((($127)+(12))>>2)];
      var $128=$3;
      var $129=(($128+156)|0);
      var $130=HEAPF32[(($129)>>2)];
      var $131=$gstate;
      var $132=(($131+156)|0);
      HEAPF32[(($132)>>2)]=$130;
      var $133=$3;
      var $134=(($133+160)|0);
      var $135=HEAPF32[(($134)>>2)];
      var $136=$gstate;
      var $137=(($136+160)|0);
      HEAPF32[(($137)>>2)]=$135;
      var $138=$3;
      var $139=(($138+164)|0);
      var $140=HEAP32[(($139)>>2)];
      var $141=$gstate;
      var $142=(($141+164)|0);
      HEAP32[(($142)>>2)]=$140;
      var $143=$3;
      var $144=(($143+168)|0);
      var $145=HEAPF32[(($144)>>2)];
      var $146=$gstate;
      var $147=(($146+168)|0);
      HEAPF32[(($147)>>2)]=$145;
      var $148=$3;
      var $149=$gstate;
      var $150=(($149+176)|0);
      HEAP32[(($150)>>2)]=$148;
      var $151=$3;
      var $152=(($151+180)|0);
      var $153=HEAP32[(($152)>>2)];
      var $154=((($153)+(1))|0);
      var $155=$gstate;
      var $156=(($155+180)|0);
      HEAP32[(($156)>>2)]=$154;
      __label__ = 10; break;
    case 9: 
      var $158=$DEF_MATRIX;
      assert(24 % 1 === 0, 'memcpy given ' + 24 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP32[(($158)>>2)]=HEAP32[((_HPDF_GState_New_DEF_MATRIX)>>2)];HEAP32[((($158)+(4))>>2)]=HEAP32[(((_HPDF_GState_New_DEF_MATRIX)+(4))>>2)];HEAP32[((($158)+(8))>>2)]=HEAP32[(((_HPDF_GState_New_DEF_MATRIX)+(8))>>2)];HEAP32[((($158)+(12))>>2)]=HEAP32[(((_HPDF_GState_New_DEF_MATRIX)+(12))>>2)];HEAP32[((($158)+(16))>>2)]=HEAP32[(((_HPDF_GState_New_DEF_MATRIX)+(16))>>2)];HEAP32[((($158)+(20))>>2)]=HEAP32[(((_HPDF_GState_New_DEF_MATRIX)+(20))>>2)];
      var $159=$DEF_RGB_COLOR;
      HEAP32[(($159)>>2)]=0; HEAP32[((($159)+(4))>>2)]=0; HEAP32[((($159)+(8))>>2)]=0;
      var $160=$DEF_CMYK_COLOR;
      HEAP32[(($160)>>2)]=0; HEAP32[((($160)+(4))>>2)]=0; HEAP32[((($160)+(8))>>2)]=0; HEAP32[((($160)+(12))>>2)]=0;
      var $161=$DEF_DASH_MODE;
      HEAP32[(($161)>>2)]=0; HEAP32[((($161)+(4))>>2)]=0; HEAP32[((($161)+(8))>>2)]=0; HEAP32[((($161)+(12))>>2)]=0; HEAP32[((($161)+(16))>>2)]=0; HEAP32[((($161)+(20))>>2)]=0;
      var $162=$gstate;
      var $163=(($162)|0);
      var $164=$163;
      var $165=$DEF_MATRIX;
      assert(24 % 1 === 0, 'memcpy given ' + 24 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP32[(($164)>>2)]=HEAP32[(($165)>>2)];HEAP32[((($164)+(4))>>2)]=HEAP32[((($165)+(4))>>2)];HEAP32[((($164)+(8))>>2)]=HEAP32[((($165)+(8))>>2)];HEAP32[((($164)+(12))>>2)]=HEAP32[((($165)+(12))>>2)];HEAP32[((($164)+(16))>>2)]=HEAP32[((($165)+(16))>>2)];HEAP32[((($164)+(20))>>2)]=HEAP32[((($165)+(20))>>2)];
      var $166=$gstate;
      var $167=(($166+24)|0);
      HEAPF32[(($167)>>2)]=1;
      var $168=$gstate;
      var $169=(($168+28)|0);
      HEAP32[(($169)>>2)]=0;
      var $170=$gstate;
      var $171=(($170+32)|0);
      HEAP32[(($171)>>2)]=0;
      var $172=$gstate;
      var $173=(($172+36)|0);
      HEAPF32[(($173)>>2)]=10;
      var $174=$gstate;
      var $175=(($174+40)|0);
      var $176=$175;
      var $177=$DEF_DASH_MODE;
      assert(24 % 1 === 0, 'memcpy given ' + 24 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP32[(($176)>>2)]=HEAP32[(($177)>>2)];HEAP32[((($176)+(4))>>2)]=HEAP32[((($177)+(4))>>2)];HEAP32[((($176)+(8))>>2)]=HEAP32[((($177)+(8))>>2)];HEAP32[((($176)+(12))>>2)]=HEAP32[((($177)+(12))>>2)];HEAP32[((($176)+(16))>>2)]=HEAP32[((($177)+(16))>>2)];HEAP32[((($176)+(20))>>2)]=HEAP32[((($177)+(20))>>2)];
      var $178=$gstate;
      var $179=(($178+64)|0);
      HEAPF32[(($179)>>2)]=1;
      var $180=$gstate;
      var $181=(($180+68)|0);
      HEAPF32[(($181)>>2)]=0;
      var $182=$gstate;
      var $183=(($182+72)|0);
      HEAPF32[(($183)>>2)]=0;
      var $184=$gstate;
      var $185=(($184+76)|0);
      HEAPF32[(($185)>>2)]=100;
      var $186=$gstate;
      var $187=(($186+80)|0);
      HEAPF32[(($187)>>2)]=0;
      var $188=$gstate;
      var $189=(($188+84)|0);
      HEAP32[(($189)>>2)]=0;
      var $190=$gstate;
      var $191=(($190+88)|0);
      HEAPF32[(($191)>>2)]=0;
      var $192=$gstate;
      var $193=(($192+96)|0);
      HEAP32[(($193)>>2)]=0;
      var $194=$gstate;
      var $195=(($194+92)|0);
      HEAP32[(($195)>>2)]=0;
      var $196=$gstate;
      var $197=(($196+100)|0);
      var $198=$197;
      var $199=$DEF_RGB_COLOR;
      assert(12 % 1 === 0, 'memcpy given ' + 12 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP32[(($198)>>2)]=HEAP32[(($199)>>2)];HEAP32[((($198)+(4))>>2)]=HEAP32[((($199)+(4))>>2)];HEAP32[((($198)+(8))>>2)]=HEAP32[((($199)+(8))>>2)];
      var $200=$gstate;
      var $201=(($200+112)|0);
      var $202=$201;
      var $203=$DEF_RGB_COLOR;
      assert(12 % 1 === 0, 'memcpy given ' + 12 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP32[(($202)>>2)]=HEAP32[(($203)>>2)];HEAP32[((($202)+(4))>>2)]=HEAP32[((($203)+(4))>>2)];HEAP32[((($202)+(8))>>2)]=HEAP32[((($203)+(8))>>2)];
      var $204=$gstate;
      var $205=(($204+124)|0);
      var $206=$205;
      var $207=$DEF_CMYK_COLOR;
      assert(16 % 1 === 0, 'memcpy given ' + 16 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP32[(($206)>>2)]=HEAP32[(($207)>>2)];HEAP32[((($206)+(4))>>2)]=HEAP32[((($207)+(4))>>2)];HEAP32[((($206)+(8))>>2)]=HEAP32[((($207)+(8))>>2)];HEAP32[((($206)+(12))>>2)]=HEAP32[((($207)+(12))>>2)];
      var $208=$gstate;
      var $209=(($208+140)|0);
      var $210=$209;
      var $211=$DEF_CMYK_COLOR;
      assert(16 % 1 === 0, 'memcpy given ' + 16 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP32[(($210)>>2)]=HEAP32[(($211)>>2)];HEAP32[((($210)+(4))>>2)]=HEAP32[((($211)+(4))>>2)];HEAP32[((($210)+(8))>>2)]=HEAP32[((($211)+(8))>>2)];HEAP32[((($210)+(12))>>2)]=HEAP32[((($211)+(12))>>2)];
      var $212=$gstate;
      var $213=(($212+156)|0);
      HEAPF32[(($213)>>2)]=0;
      var $214=$gstate;
      var $215=(($214+160)|0);
      HEAPF32[(($215)>>2)]=0;
      var $216=$gstate;
      var $217=(($216+164)|0);
      HEAP32[(($217)>>2)]=0;
      var $218=$gstate;
      var $219=(($218+168)|0);
      HEAPF32[(($219)>>2)]=0;
      var $220=$gstate;
      var $221=(($220+172)|0);
      HEAP32[(($221)>>2)]=0;
      var $222=$gstate;
      var $223=(($222+176)|0);
      HEAP32[(($223)>>2)]=0;
      var $224=$gstate;
      var $225=(($224+180)|0);
      HEAP32[(($225)>>2)]=1;
      __label__ = 10; break;
    case 10: 
      var $227=$gstate;
      $1=$227;
      __label__ = 11; break;
    case 11: 
      var $229=$1;
      STACKTOP = __stackBase__;
      return $229;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_GState_New["X"]=1;

function _HPDF_GState_Free($mmgr, $gstate) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $current;
      $1=$mmgr;
      $2=$gstate;
      $current=0;
      var $3=$2;
      var $4=(($3)|0)!=0;
      if ($4) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $6=$2;
      var $7=(($6+176)|0);
      var $8=HEAP32[(($7)>>2)];
      $current=$8;
      var $9=$1;
      var $10=$2;
      var $11=$10;
      _HPDF_FreeMem($9, $11);
      __label__ = 4; break;
    case 4: 
      var $13=$current;
      ;
      return $13;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Image_LoadJpegImage($mmgr, $jpeg_data, $xref) {
  var __stackBase__  = STACKTOP; STACKTOP += 4100; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $image;
      var $ret;
      var $buf=__stackBase__;
      var $len=(__stackBase__)+(4096);
      var $ret1;
      $2=$mmgr;
      $3=$jpeg_data;
      $4=$xref;
      $ret=0;
      var $5=$2;
      var $6=$4;
      var $7=_HPDF_DictStream_New($5, $6);
      $image=$7;
      var $8=$image;
      var $9=(($8)|0)!=0;
      if ($9) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=0;
      __label__ = 23; break;
    case 4: 
      var $12=$image;
      var $13=(($12)|0);
      var $14=(($13+6)|0);
      var $15=HEAPU16[(($14)>>1)];
      var $16=(($15)&65535);
      var $17=$16 | 1280;
      var $18=(($17) & 65535);
      HEAP16[(($14)>>1)]=$18;
      var $19=$image;
      var $20=(($19+40)|0);
      HEAP32[(($20)>>2)]=2048;
      var $21=$image;
      var $22=_HPDF_Dict_AddName($21, ((STRING_TABLE.__str1426)|0), ((STRING_TABLE.__str11427)|0));
      var $23=$ret;
      var $24=((($23)+($22))|0);
      $ret=$24;
      var $25=$image;
      var $26=_HPDF_Dict_AddName($25, ((STRING_TABLE.__str21428)|0), ((STRING_TABLE.__str31429)|0));
      var $27=$ret;
      var $28=((($27)+($26))|0);
      $ret=$28;
      var $29=$ret;
      var $30=(($29)|0)!=0;
      if ($30) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      $1=0;
      __label__ = 23; break;
    case 6: 
      var $33=$image;
      var $34=$3;
      var $35=_LoadJpegHeader($33, $34);
      var $36=(($35)|0)!=0;
      if ($36) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      $1=0;
      __label__ = 23; break;
    case 8: 
      var $39=$3;
      var $40=_HPDF_Stream_Seek($39, 0, 0);
      var $41=(($40)|0)!=0;
      if ($41) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      $1=0;
      __label__ = 23; break;
    case 10: 
      __label__ = 11; break;
    case 11: 
      HEAP32[(($len)>>2)]=4096;
      var $45=$3;
      var $46=(($buf)|0);
      var $47=_HPDF_Stream_Read($45, $46, $len);
      $ret1=$47;
      var $48=$ret1;
      var $49=(($48)|0)!=0;
      if ($49) { __label__ = 12; break; } else { __label__ = 19; break; }
    case 12: 
      var $51=$ret1;
      var $52=(($51)|0)==4184;
      if ($52) { __label__ = 13; break; } else { __label__ = 18; break; }
    case 13: 
      var $54=HEAPU32[(($len)>>2)];
      var $55=(($54)>>>0) > 0;
      if ($55) { __label__ = 14; break; } else { __label__ = 17; break; }
    case 14: 
      var $57=$image;
      var $58=(($57+36)|0);
      var $59=HEAP32[(($58)>>2)];
      var $60=(($buf)|0);
      var $61=HEAP32[(($len)>>2)];
      var $62=_HPDF_Stream_Write($59, $60, $61);
      $ret1=$62;
      var $63=$ret1;
      var $64=(($63)|0)!=0;
      if ($64) { __label__ = 15; break; } else { __label__ = 16; break; }
    case 15: 
      $1=0;
      __label__ = 23; break;
    case 16: 
      __label__ = 17; break;
    case 17: 
      __label__ = 22; break;
    case 18: 
      $1=0;
      __label__ = 23; break;
    case 19: 
      var $70=$image;
      var $71=(($70+36)|0);
      var $72=HEAP32[(($71)>>2)];
      var $73=(($buf)|0);
      var $74=HEAP32[(($len)>>2)];
      var $75=_HPDF_Stream_Write($72, $73, $74);
      var $76=(($75)|0)!=0;
      if ($76) { __label__ = 20; break; } else { __label__ = 21; break; }
    case 20: 
      $1=0;
      __label__ = 23; break;
    case 21: 
      __label__ = 11; break;
    case 22: 
      var $80=$image;
      $1=$80;
      __label__ = 23; break;
    case 23: 
      var $82=$1;
      STACKTOP = __stackBase__;
      return $82;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Image_LoadJpegImage["X"]=1;

function _LoadJpegHeader($image, $stream) {
  var __stackBase__  = STACKTOP; STACKTOP += 28; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $tag=__stackBase__;
      var $height=(__stackBase__)+(4);
      var $width=(__stackBase__)+(8);
      var $precision=(__stackBase__)+(12);
      var $num_components=(__stackBase__)+(16);
      var $color_space_name;
      var $len=(__stackBase__)+(20);
      var $ret;
      var $array;
      var $size=(__stackBase__)+(24);
      $2=$image;
      $3=$stream;
      HEAP32[(($len)>>2)]=2;
      var $4=$3;
      var $5=$tag;
      var $6=_HPDF_Stream_Read($4, $5, $len);
      var $7=(($6)|0)!=0;
      if ($7) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $9=$3;
      var $10=(($9+12)|0);
      var $11=HEAP32[(($10)>>2)];
      var $12=_HPDF_Error_GetCode($11);
      $1=$12;
      __label__ = 50; break;
    case 4: 
      _HPDF_UInt16Swap($tag);
      var $14=HEAPU16[(($tag)>>1)];
      var $15=(($14)&65535);
      var $16=(($15)|0)!=65496;
      if ($16) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      $1=4145;
      __label__ = 50; break;
    case 6: 
      __label__ = 7; break;
    case 7: 
      HEAP32[(($len)>>2)]=2;
      var $20=$3;
      var $21=$tag;
      var $22=_HPDF_Stream_Read($20, $21, $len);
      var $23=(($22)|0)!=0;
      if ($23) { __label__ = 8; break; } else { __label__ = 9; break; }
    case 8: 
      var $25=$3;
      var $26=(($25+12)|0);
      var $27=HEAP32[(($26)>>2)];
      var $28=_HPDF_Error_GetCode($27);
      $1=$28;
      __label__ = 50; break;
    case 9: 
      _HPDF_UInt16Swap($tag);
      HEAP32[(($len)>>2)]=2;
      var $30=$3;
      var $31=$size;
      var $32=_HPDF_Stream_Read($30, $31, $len);
      var $33=(($32)|0)!=0;
      if ($33) { __label__ = 10; break; } else { __label__ = 11; break; }
    case 10: 
      var $35=$3;
      var $36=(($35+12)|0);
      var $37=HEAP32[(($36)>>2)];
      var $38=_HPDF_Error_GetCode($37);
      $1=$38;
      __label__ = 50; break;
    case 11: 
      _HPDF_UInt16Swap($size);
      var $40=HEAPU16[(($tag)>>1)];
      var $41=(($40)&65535);
      var $42=(($41)|0)==65472;
      if ($42) { __label__ = 15; break; } else { __label__ = 12; break; }
    case 12: 
      var $44=HEAPU16[(($tag)>>1)];
      var $45=(($44)&65535);
      var $46=(($45)|0)==65473;
      if ($46) { __label__ = 15; break; } else { __label__ = 13; break; }
    case 13: 
      var $48=HEAPU16[(($tag)>>1)];
      var $49=(($48)&65535);
      var $50=(($49)|0)==65474;
      if ($50) { __label__ = 15; break; } else { __label__ = 14; break; }
    case 14: 
      var $52=HEAPU16[(($tag)>>1)];
      var $53=(($52)&65535);
      var $54=(($53)|0)==65481;
      if ($54) { __label__ = 15; break; } else { __label__ = 24; break; }
    case 15: 
      HEAP32[(($len)>>2)]=1;
      var $56=$3;
      var $57=_HPDF_Stream_Read($56, $precision, $len);
      var $58=(($57)|0)!=0;
      if ($58) { __label__ = 16; break; } else { __label__ = 17; break; }
    case 16: 
      var $60=$3;
      var $61=(($60+12)|0);
      var $62=HEAP32[(($61)>>2)];
      var $63=_HPDF_Error_GetCode($62);
      $1=$63;
      __label__ = 50; break;
    case 17: 
      HEAP32[(($len)>>2)]=2;
      var $65=$3;
      var $66=$height;
      var $67=_HPDF_Stream_Read($65, $66, $len);
      var $68=(($67)|0)!=0;
      if ($68) { __label__ = 18; break; } else { __label__ = 19; break; }
    case 18: 
      var $70=$3;
      var $71=(($70+12)|0);
      var $72=HEAP32[(($71)>>2)];
      var $73=_HPDF_Error_GetCode($72);
      $1=$73;
      __label__ = 50; break;
    case 19: 
      _HPDF_UInt16Swap($height);
      HEAP32[(($len)>>2)]=2;
      var $75=$3;
      var $76=$width;
      var $77=_HPDF_Stream_Read($75, $76, $len);
      var $78=(($77)|0)!=0;
      if ($78) { __label__ = 20; break; } else { __label__ = 21; break; }
    case 20: 
      var $80=$3;
      var $81=(($80+12)|0);
      var $82=HEAP32[(($81)>>2)];
      var $83=_HPDF_Error_GetCode($82);
      $1=$83;
      __label__ = 50; break;
    case 21: 
      _HPDF_UInt16Swap($width);
      HEAP32[(($len)>>2)]=1;
      var $85=$3;
      var $86=_HPDF_Stream_Read($85, $num_components, $len);
      var $87=(($86)|0)!=0;
      if ($87) { __label__ = 22; break; } else { __label__ = 23; break; }
    case 22: 
      var $89=$3;
      var $90=(($89+12)|0);
      var $91=HEAP32[(($90)>>2)];
      var $92=_HPDF_Error_GetCode($91);
      $1=$92;
      __label__ = 50; break;
    case 23: 
      __label__ = 30; break;
    case 24: 
      var $95=HEAPU16[(($tag)>>1)];
      var $96=(($95)&65535);
      var $97=$96 | 255;
      var $98=(($97)|0)!=65535;
      if ($98) { __label__ = 25; break; } else { __label__ = 26; break; }
    case 25: 
      var $100=$2;
      var $101=(($100+12)|0);
      var $102=HEAP32[(($101)>>2)];
      var $103=_HPDF_SetError($102, 4195, 0);
      $1=$103;
      __label__ = 50; break;
    case 26: 
      __label__ = 27; break;
    case 27: 
      var $106=$3;
      var $107=HEAPU16[(($size)>>1)];
      var $108=(($107)&65535);
      var $109=((($108)-(2))|0);
      var $110=_HPDF_Stream_Seek($106, $109, 1);
      var $111=(($110)|0)!=0;
      if ($111) { __label__ = 28; break; } else { __label__ = 29; break; }
    case 28: 
      var $113=$3;
      var $114=(($113+12)|0);
      var $115=HEAP32[(($114)>>2)];
      var $116=_HPDF_Error_GetCode($115);
      $1=$116;
      __label__ = 50; break;
    case 29: 
      __label__ = 7; break;
    case 30: 
      var $119=$2;
      var $120=HEAPU16[(($height)>>1)];
      var $121=(($120)&65535);
      var $122=_HPDF_Dict_AddNumber($119, ((STRING_TABLE.__str61432)|0), $121);
      var $123=(($122)|0)!=0;
      if ($123) { __label__ = 31; break; } else { __label__ = 32; break; }
    case 31: 
      var $125=$3;
      var $126=(($125+12)|0);
      var $127=HEAP32[(($126)>>2)];
      var $128=_HPDF_Error_GetCode($127);
      $1=$128;
      __label__ = 50; break;
    case 32: 
      var $130=$2;
      var $131=HEAPU16[(($width)>>1)];
      var $132=(($131)&65535);
      var $133=_HPDF_Dict_AddNumber($130, ((STRING_TABLE.__str51431)|0), $132);
      var $134=(($133)|0)!=0;
      if ($134) { __label__ = 33; break; } else { __label__ = 34; break; }
    case 33: 
      var $136=$3;
      var $137=(($136+12)|0);
      var $138=HEAP32[(($137)>>2)];
      var $139=_HPDF_Error_GetCode($138);
      $1=$139;
      __label__ = 50; break;
    case 34: 
      var $141=HEAPU8[($num_components)];
      var $142=(($141)&255);
      if ((($142)|0) == 1) {
        __label__ = 35; break;
      }
      else if ((($142)|0) == 3) {
        __label__ = 36; break;
      }
      else if ((($142)|0) == 4) {
        __label__ = 37; break;
      }
      else {
      __label__ = 44; break;
      }
      
    case 35: 
      var $144=HEAP32[((_COL_GRAY)>>2)];
      $color_space_name=$144;
      __label__ = 45; break;
    case 36: 
      var $146=HEAP32[((_COL_RGB)>>2)];
      $color_space_name=$146;
      __label__ = 45; break;
    case 37: 
      var $148=$2;
      var $149=(($148+8)|0);
      var $150=HEAP32[(($149)>>2)];
      var $151=_HPDF_Array_New($150);
      $array=$151;
      var $152=$array;
      var $153=(($152)|0)!=0;
      if ($153) { __label__ = 39; break; } else { __label__ = 38; break; }
    case 38: 
      var $155=$3;
      var $156=(($155+12)|0);
      var $157=HEAP32[(($156)>>2)];
      var $158=_HPDF_Error_GetCode($157);
      $1=$158;
      __label__ = 50; break;
    case 39: 
      var $160=$2;
      var $161=$array;
      var $162=$161;
      var $163=_HPDF_Dict_Add($160, ((STRING_TABLE.__str141440)|0), $162);
      $ret=$163;
      var $164=$ret;
      var $165=(($164)|0)!=0;
      if ($165) { __label__ = 40; break; } else { __label__ = 41; break; }
    case 40: 
      var $167=$3;
      var $168=(($167+12)|0);
      var $169=HEAP32[(($168)>>2)];
      var $170=_HPDF_Error_GetCode($169);
      $1=$170;
      __label__ = 50; break;
    case 41: 
      var $172=$array;
      var $173=$2;
      var $174=(($173+8)|0);
      var $175=HEAP32[(($174)>>2)];
      var $176=_HPDF_Number_New($175, 1);
      var $177=$176;
      var $178=_HPDF_Array_Add($172, $177);
      var $179=$ret;
      var $180=((($179)+($178))|0);
      $ret=$180;
      var $181=$array;
      var $182=$2;
      var $183=(($182+8)|0);
      var $184=HEAP32[(($183)>>2)];
      var $185=_HPDF_Number_New($184, 0);
      var $186=$185;
      var $187=_HPDF_Array_Add($181, $186);
      var $188=$ret;
      var $189=((($188)+($187))|0);
      $ret=$189;
      var $190=$array;
      var $191=$2;
      var $192=(($191+8)|0);
      var $193=HEAP32[(($192)>>2)];
      var $194=_HPDF_Number_New($193, 1);
      var $195=$194;
      var $196=_HPDF_Array_Add($190, $195);
      var $197=$ret;
      var $198=((($197)+($196))|0);
      $ret=$198;
      var $199=$array;
      var $200=$2;
      var $201=(($200+8)|0);
      var $202=HEAP32[(($201)>>2)];
      var $203=_HPDF_Number_New($202, 0);
      var $204=$203;
      var $205=_HPDF_Array_Add($199, $204);
      var $206=$ret;
      var $207=((($206)+($205))|0);
      $ret=$207;
      var $208=$array;
      var $209=$2;
      var $210=(($209+8)|0);
      var $211=HEAP32[(($210)>>2)];
      var $212=_HPDF_Number_New($211, 1);
      var $213=$212;
      var $214=_HPDF_Array_Add($208, $213);
      var $215=$ret;
      var $216=((($215)+($214))|0);
      $ret=$216;
      var $217=$array;
      var $218=$2;
      var $219=(($218+8)|0);
      var $220=HEAP32[(($219)>>2)];
      var $221=_HPDF_Number_New($220, 0);
      var $222=$221;
      var $223=_HPDF_Array_Add($217, $222);
      var $224=$ret;
      var $225=((($224)+($223))|0);
      $ret=$225;
      var $226=$array;
      var $227=$2;
      var $228=(($227+8)|0);
      var $229=HEAP32[(($228)>>2)];
      var $230=_HPDF_Number_New($229, 1);
      var $231=$230;
      var $232=_HPDF_Array_Add($226, $231);
      var $233=$ret;
      var $234=((($233)+($232))|0);
      $ret=$234;
      var $235=$array;
      var $236=$2;
      var $237=(($236+8)|0);
      var $238=HEAP32[(($237)>>2)];
      var $239=_HPDF_Number_New($238, 0);
      var $240=$239;
      var $241=_HPDF_Array_Add($235, $240);
      var $242=$ret;
      var $243=((($242)+($241))|0);
      $ret=$243;
      var $244=$ret;
      var $245=(($244)|0)!=0;
      if ($245) { __label__ = 42; break; } else { __label__ = 43; break; }
    case 42: 
      var $247=$3;
      var $248=(($247+12)|0);
      var $249=HEAP32[(($248)>>2)];
      var $250=_HPDF_Error_GetCode($249);
      $1=$250;
      __label__ = 50; break;
    case 43: 
      var $252=HEAP32[((_COL_CMYK)>>2)];
      $color_space_name=$252;
      __label__ = 45; break;
    case 44: 
      var $254=$2;
      var $255=(($254+12)|0);
      var $256=HEAP32[(($255)>>2)];
      var $257=_HPDF_SetError($256, 4195, 0);
      $1=$257;
      __label__ = 50; break;
    case 45: 
      var $259=$2;
      var $260=$2;
      var $261=(($260+8)|0);
      var $262=HEAP32[(($261)>>2)];
      var $263=$color_space_name;
      var $264=_HPDF_Name_New($262, $263);
      var $265=$264;
      var $266=_HPDF_Dict_Add($259, ((STRING_TABLE.__str41430)|0), $265);
      var $267=(($266)|0)!=0;
      if ($267) { __label__ = 46; break; } else { __label__ = 47; break; }
    case 46: 
      var $269=$3;
      var $270=(($269+12)|0);
      var $271=HEAP32[(($270)>>2)];
      var $272=_HPDF_Error_GetCode($271);
      $1=$272;
      __label__ = 50; break;
    case 47: 
      var $274=$2;
      var $275=$2;
      var $276=(($275+8)|0);
      var $277=HEAP32[(($276)>>2)];
      var $278=HEAPU8[($precision)];
      var $279=(($278)&255);
      var $280=_HPDF_Number_New($277, $279);
      var $281=$280;
      var $282=_HPDF_Dict_Add($274, ((STRING_TABLE.__str71433)|0), $281);
      var $283=(($282)|0)!=0;
      if ($283) { __label__ = 48; break; } else { __label__ = 49; break; }
    case 48: 
      var $285=$3;
      var $286=(($285+12)|0);
      var $287=HEAP32[(($286)>>2)];
      var $288=_HPDF_Error_GetCode($287);
      $1=$288;
      __label__ = 50; break;
    case 49: 
      $1=0;
      __label__ = 50; break;
    case 50: 
      var $291=$1;
      STACKTOP = __stackBase__;
      return $291;
    default: assert(0, "bad label: " + __label__);
  }
}
_LoadJpegHeader["X"]=1;

function _HPDF_Image_LoadJpegImageFromMem($mmgr, $buf, $size, $xref) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $5;
      var $jpeg_data;
      var $image;
      $2=$mmgr;
      $3=$buf;
      $4=$size;
      $5=$xref;
      var $6=$2;
      var $7=$4;
      var $8=_HPDF_MemStream_New($6, $7);
      $jpeg_data=$8;
      var $9=$jpeg_data;
      var $10=_HPDF_Stream_Validate($9);
      var $11=(($10)|0)!=0;
      if ($11) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      var $13=$2;
      var $14=(($13)|0);
      var $15=HEAP32[(($14)>>2)];
      var $16=_HPDF_RaiseError($15, 4156, 0);
      $1=0;
      __label__ = 7; break;
    case 4: 
      var $18=$jpeg_data;
      var $19=$3;
      var $20=$4;
      var $21=_HPDF_Stream_Write($18, $19, $20);
      var $22=(($21)|0)!=0;
      if ($22) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $24=$jpeg_data;
      _HPDF_Stream_Free($24);
      $1=0;
      __label__ = 7; break;
    case 6: 
      var $26=$2;
      var $27=$jpeg_data;
      var $28=$5;
      var $29=_HPDF_Image_LoadJpegImage($26, $27, $28);
      $image=$29;
      var $30=$jpeg_data;
      _HPDF_Stream_Free($30);
      var $31=$image;
      $1=$31;
      __label__ = 7; break;
    case 7: 
      var $33=$1;
      ;
      return $33;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Image_LoadRawImage($mmgr, $raw_data, $xref, $width, $height, $color_space) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $5;
      var $6;
      var $7;
      var $image;
      var $ret;
      var $size;
      $2=$mmgr;
      $3=$raw_data;
      $4=$xref;
      $5=$width;
      $6=$height;
      $7=$color_space;
      $ret=0;
      var $8=$7;
      var $9=(($8)|0)!=0;
      if ($9) { __label__ = 3; break; } else { __label__ = 6; break; }
    case 3: 
      var $11=$7;
      var $12=(($11)|0)!=1;
      if ($12) { __label__ = 4; break; } else { __label__ = 6; break; }
    case 4: 
      var $14=$7;
      var $15=(($14)|0)!=2;
      if ($15) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $17=$2;
      var $18=(($17)|0);
      var $19=HEAP32[(($18)>>2)];
      var $20=_HPDF_SetError($19, 4128, 0);
      $1=0;
      __label__ = 29; break;
    case 6: 
      var $22=$2;
      var $23=$4;
      var $24=_HPDF_DictStream_New($22, $23);
      $image=$24;
      var $25=$image;
      var $26=(($25)|0)!=0;
      if ($26) { __label__ = 8; break; } else { __label__ = 7; break; }
    case 7: 
      $1=0;
      __label__ = 29; break;
    case 8: 
      var $29=$image;
      var $30=(($29)|0);
      var $31=(($30+6)|0);
      var $32=HEAPU16[(($31)>>1)];
      var $33=(($32)&65535);
      var $34=$33 | 1280;
      var $35=(($34) & 65535);
      HEAP16[(($31)>>1)]=$35;
      var $36=$image;
      var $37=_HPDF_Dict_AddName($36, ((STRING_TABLE.__str1426)|0), ((STRING_TABLE.__str11427)|0));
      var $38=$ret;
      var $39=((($38)+($37))|0);
      $ret=$39;
      var $40=$image;
      var $41=_HPDF_Dict_AddName($40, ((STRING_TABLE.__str21428)|0), ((STRING_TABLE.__str31429)|0));
      var $42=$ret;
      var $43=((($42)+($41))|0);
      $ret=$43;
      var $44=$ret;
      var $45=(($44)|0)!=0;
      if ($45) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      $1=0;
      __label__ = 29; break;
    case 10: 
      var $48=$7;
      var $49=(($48)|0)==0;
      if ($49) { __label__ = 11; break; } else { __label__ = 12; break; }
    case 11: 
      var $51=$5;
      var $52=$6;
      var $53=((($51)*($52))|0);
      $size=$53;
      var $54=$image;
      var $55=HEAP32[((_COL_GRAY)>>2)];
      var $56=_HPDF_Dict_AddName($54, ((STRING_TABLE.__str41430)|0), $55);
      $ret=$56;
      __label__ = 16; break;
    case 12: 
      var $58=$7;
      var $59=(($58)|0)==2;
      if ($59) { __label__ = 13; break; } else { __label__ = 14; break; }
    case 13: 
      var $61=$5;
      var $62=$6;
      var $63=((($61)*($62))|0);
      var $64=((($63<<2))|0);
      $size=$64;
      var $65=$image;
      var $66=HEAP32[((_COL_CMYK)>>2)];
      var $67=_HPDF_Dict_AddName($65, ((STRING_TABLE.__str41430)|0), $66);
      $ret=$67;
      __label__ = 15; break;
    case 14: 
      var $69=$5;
      var $70=$6;
      var $71=((($69)*($70))|0);
      var $72=((($71)*(3))|0);
      $size=$72;
      var $73=$image;
      var $74=HEAP32[((_COL_RGB)>>2)];
      var $75=_HPDF_Dict_AddName($73, ((STRING_TABLE.__str41430)|0), $74);
      $ret=$75;
      __label__ = 15; break;
    case 15: 
      __label__ = 16; break;
    case 16: 
      var $78=$ret;
      var $79=(($78)|0)!=0;
      if ($79) { __label__ = 17; break; } else { __label__ = 18; break; }
    case 17: 
      $1=0;
      __label__ = 29; break;
    case 18: 
      var $82=$image;
      var $83=$5;
      var $84=_HPDF_Dict_AddNumber($82, ((STRING_TABLE.__str51431)|0), $83);
      var $85=(($84)|0)!=0;
      if ($85) { __label__ = 19; break; } else { __label__ = 20; break; }
    case 19: 
      $1=0;
      __label__ = 29; break;
    case 20: 
      var $88=$image;
      var $89=$6;
      var $90=_HPDF_Dict_AddNumber($88, ((STRING_TABLE.__str61432)|0), $89);
      var $91=(($90)|0)!=0;
      if ($91) { __label__ = 21; break; } else { __label__ = 22; break; }
    case 21: 
      $1=0;
      __label__ = 29; break;
    case 22: 
      var $94=$image;
      var $95=_HPDF_Dict_AddNumber($94, ((STRING_TABLE.__str71433)|0), 8);
      var $96=(($95)|0)!=0;
      if ($96) { __label__ = 23; break; } else { __label__ = 24; break; }
    case 23: 
      $1=0;
      __label__ = 29; break;
    case 24: 
      var $99=$3;
      var $100=$image;
      var $101=(($100+36)|0);
      var $102=HEAP32[(($101)>>2)];
      var $103=_HPDF_Stream_WriteToStream($99, $102, 0, 0);
      var $104=(($103)|0)!=0;
      if ($104) { __label__ = 25; break; } else { __label__ = 26; break; }
    case 25: 
      $1=0;
      __label__ = 29; break;
    case 26: 
      var $107=$image;
      var $108=(($107+36)|0);
      var $109=HEAP32[(($108)>>2)];
      var $110=(($109+16)|0);
      var $111=HEAP32[(($110)>>2)];
      var $112=$size;
      var $113=(($111)|0)!=(($112)|0);
      if ($113) { __label__ = 27; break; } else { __label__ = 28; break; }
    case 27: 
      var $115=$image;
      var $116=(($115+12)|0);
      var $117=HEAP32[(($116)>>2)];
      var $118=_HPDF_SetError($117, 4144, 0);
      $1=0;
      __label__ = 29; break;
    case 28: 
      var $120=$image;
      $1=$120;
      __label__ = 29; break;
    case 29: 
      var $122=$1;
      ;
      return $122;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Image_LoadRawImage["X"]=1;

function _HPDF_Image_LoadRawImageFromMem($mmgr, $buf, $xref, $width, $height, $color_space, $bits_per_component) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $5;
      var $6;
      var $7;
      var $8;
      var $image;
      var $ret;
      var $size;
      $2=$mmgr;
      $3=$buf;
      $4=$xref;
      $5=$width;
      $6=$height;
      $7=$color_space;
      $8=$bits_per_component;
      $ret=0;
      var $9=$7;
      var $10=(($9)|0)!=0;
      if ($10) { __label__ = 3; break; } else { __label__ = 5; break; }
    case 3: 
      var $12=$7;
      var $13=(($12)|0)!=1;
      if ($13) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      var $15=$2;
      var $16=(($15)|0);
      var $17=HEAP32[(($16)>>2)];
      var $18=_HPDF_SetError($17, 4128, 0);
      $1=0;
      __label__ = 28; break;
    case 5: 
      var $20=$8;
      var $21=(($20)|0)!=1;
      if ($21) { __label__ = 6; break; } else { __label__ = 10; break; }
    case 6: 
      var $23=$8;
      var $24=(($23)|0)!=2;
      if ($24) { __label__ = 7; break; } else { __label__ = 10; break; }
    case 7: 
      var $26=$8;
      var $27=(($26)|0)!=4;
      if ($27) { __label__ = 8; break; } else { __label__ = 10; break; }
    case 8: 
      var $29=$8;
      var $30=(($29)|0)!=8;
      if ($30) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      var $32=$2;
      var $33=(($32)|0);
      var $34=HEAP32[(($33)>>2)];
      var $35=_HPDF_SetError($34, 4144, 0);
      $1=0;
      __label__ = 28; break;
    case 10: 
      var $37=$2;
      var $38=$4;
      var $39=_HPDF_DictStream_New($37, $38);
      $image=$39;
      var $40=$image;
      var $41=(($40)|0)!=0;
      if ($41) { __label__ = 12; break; } else { __label__ = 11; break; }
    case 11: 
      $1=0;
      __label__ = 28; break;
    case 12: 
      var $44=$image;
      var $45=(($44)|0);
      var $46=(($45+6)|0);
      var $47=HEAPU16[(($46)>>1)];
      var $48=(($47)&65535);
      var $49=$48 | 1280;
      var $50=(($49) & 65535);
      HEAP16[(($46)>>1)]=$50;
      var $51=$image;
      var $52=_HPDF_Dict_AddName($51, ((STRING_TABLE.__str1426)|0), ((STRING_TABLE.__str11427)|0));
      var $53=$ret;
      var $54=((($53)+($52))|0);
      $ret=$54;
      var $55=$image;
      var $56=_HPDF_Dict_AddName($55, ((STRING_TABLE.__str21428)|0), ((STRING_TABLE.__str31429)|0));
      var $57=$ret;
      var $58=((($57)+($56))|0);
      $ret=$58;
      var $59=$ret;
      var $60=(($59)|0)!=0;
      if ($60) { __label__ = 13; break; } else { __label__ = 14; break; }
    case 13: 
      $1=0;
      __label__ = 28; break;
    case 14: 
      var $63=$7;
      var $64=(($63)|0)==0;
      if ($64) { __label__ = 15; break; } else { __label__ = 16; break; }
    case 15: 
      var $66=$5;
      var $67=(($66)>>>0);
      var $68=$6;
      var $69=(($68)>>>0);
      var $70=($67)*($69);
      var $71=$8;
      var $72=Math.floor((8)/((($71)>>>0)));
      var $73=(($72)>>>0);
      var $74=($70)/($73);
      var $75=($74)+(0.876);
      var $76=($75 >= 0 ? Math.floor($75) : Math.ceil($75));
      $size=$76;
      var $77=$image;
      var $78=HEAP32[((_COL_GRAY)>>2)];
      var $79=_HPDF_Dict_AddName($77, ((STRING_TABLE.__str41430)|0), $78);
      $ret=$79;
      __label__ = 17; break;
    case 16: 
      var $81=$5;
      var $82=(($81)>>>0);
      var $83=$6;
      var $84=(($83)>>>0);
      var $85=($82)*($84);
      var $86=$8;
      var $87=Math.floor((8)/((($86)>>>0)));
      var $88=(($87)>>>0);
      var $89=($85)/($88);
      var $90=($89)+(0.876);
      var $91=($90 >= 0 ? Math.floor($90) : Math.ceil($90));
      $size=$91;
      var $92=$size;
      var $93=((($92)*(3))|0);
      $size=$93;
      var $94=$image;
      var $95=HEAP32[((_COL_RGB)>>2)];
      var $96=_HPDF_Dict_AddName($94, ((STRING_TABLE.__str41430)|0), $95);
      $ret=$96;
      __label__ = 17; break;
    case 17: 
      var $98=$ret;
      var $99=(($98)|0)!=0;
      if ($99) { __label__ = 18; break; } else { __label__ = 19; break; }
    case 18: 
      $1=0;
      __label__ = 28; break;
    case 19: 
      var $102=$image;
      var $103=$5;
      var $104=_HPDF_Dict_AddNumber($102, ((STRING_TABLE.__str51431)|0), $103);
      var $105=(($104)|0)!=0;
      if ($105) { __label__ = 20; break; } else { __label__ = 21; break; }
    case 20: 
      $1=0;
      __label__ = 28; break;
    case 21: 
      var $108=$image;
      var $109=$6;
      var $110=_HPDF_Dict_AddNumber($108, ((STRING_TABLE.__str61432)|0), $109);
      var $111=(($110)|0)!=0;
      if ($111) { __label__ = 22; break; } else { __label__ = 23; break; }
    case 22: 
      $1=0;
      __label__ = 28; break;
    case 23: 
      var $114=$image;
      var $115=$8;
      var $116=_HPDF_Dict_AddNumber($114, ((STRING_TABLE.__str71433)|0), $115);
      var $117=(($116)|0)!=0;
      if ($117) { __label__ = 24; break; } else { __label__ = 25; break; }
    case 24: 
      $1=0;
      __label__ = 28; break;
    case 25: 
      var $120=$image;
      var $121=(($120+36)|0);
      var $122=HEAP32[(($121)>>2)];
      var $123=$3;
      var $124=$size;
      var $125=_HPDF_Stream_Write($122, $123, $124);
      var $126=(($125)|0)!=0;
      if ($126) { __label__ = 26; break; } else { __label__ = 27; break; }
    case 26: 
      $1=0;
      __label__ = 28; break;
    case 27: 
      var $129=$image;
      $1=$129;
      __label__ = 28; break;
    case 28: 
      var $131=$1;
      ;
      return $131;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Image_LoadRawImageFromMem["X"]=1;

function _HPDF_Image_Validate($image) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $subtype;
      $2=$image;
      var $3=$2;
      var $4=(($3)|0)!=0;
      if ($4) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=0;
      __label__ = 10; break;
    case 4: 
      var $7=$2;
      var $8=(($7)|0);
      var $9=(($8+6)|0);
      var $10=HEAPU16[(($9)>>1)];
      var $11=(($10)&65535);
      var $12=(($11)|0)!=1297;
      if ($12) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $14=$2;
      var $15=(($14+12)|0);
      var $16=HEAP32[(($15)>>2)];
      var $17=_HPDF_RaiseError($16, 4144, 0);
      $1=0;
      __label__ = 10; break;
    case 6: 
      var $19=$2;
      var $20=_HPDF_Dict_GetItem($19, ((STRING_TABLE.__str21428)|0), 6);
      var $21=$20;
      $subtype=$21;
      var $22=$subtype;
      var $23=(($22)|0)!=0;
      if ($23) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $25=$subtype;
      var $26=(($25+12)|0);
      var $27=(($26)|0);
      var $28=_HPDF_StrCmp($27, ((STRING_TABLE.__str31429)|0));
      var $29=(($28)|0)!=0;
      if ($29) { __label__ = 8; break; } else { __label__ = 9; break; }
    case 8: 
      var $31=$2;
      var $32=(($31+12)|0);
      var $33=HEAP32[(($32)>>2)];
      var $34=_HPDF_RaiseError($33, 4144, 0);
      $1=0;
      __label__ = 10; break;
    case 9: 
      $1=1;
      __label__ = 10; break;
    case 10: 
      var $37=$1;
      ;
      return $37;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Image_GetSize($agg_result, $image) {
  var __stackBase__  = STACKTOP; STACKTOP += 8; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $width;
      var $height;
      var $ret=__stackBase__;
      $1=$image;
      var $2=$ret;
      HEAP32[(($2)>>2)]=0; HEAP32[((($2)+(4))>>2)]=0;
      var $3=$1;
      var $4=_HPDF_Image_Validate($3);
      var $5=(($4)|0)!=0;
      if ($5) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      var $7=$agg_result;
      var $8=$ret;
      assert(8 % 1 === 0, 'memcpy given ' + 8 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP32[(($7)>>2)]=HEAP32[(($8)>>2)];HEAP32[((($7)+(4))>>2)]=HEAP32[((($8)+(4))>>2)];
      __label__ = 8; break;
    case 4: 
      var $10=$1;
      var $11=_HPDF_Dict_GetItem($10, ((STRING_TABLE.__str51431)|0), 4);
      var $12=$11;
      $width=$12;
      var $13=$1;
      var $14=_HPDF_Dict_GetItem($13, ((STRING_TABLE.__str61432)|0), 4);
      var $15=$14;
      $height=$15;
      var $16=$width;
      var $17=(($16)|0)!=0;
      if ($17) { __label__ = 5; break; } else { __label__ = 7; break; }
    case 5: 
      var $19=$height;
      var $20=(($19)|0)!=0;
      if ($20) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      var $22=$width;
      var $23=(($22+8)|0);
      var $24=HEAP32[(($23)>>2)];
      var $25=(($24)|0);
      var $26=(($ret)|0);
      HEAPF32[(($26)>>2)]=$25;
      var $27=$height;
      var $28=(($27+8)|0);
      var $29=HEAP32[(($28)>>2)];
      var $30=(($29)|0);
      var $31=(($ret+4)|0);
      HEAPF32[(($31)>>2)]=$30;
      __label__ = 7; break;
    case 7: 
      var $33=$agg_result;
      var $34=$ret;
      assert(8 % 1 === 0, 'memcpy given ' + 8 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP32[(($33)>>2)]=HEAP32[(($34)>>2)];HEAP32[((($33)+(4))>>2)]=HEAP32[((($34)+(4))>>2)];
      __label__ = 8; break;
    case 8: 
      STACKTOP = __stackBase__;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Image_GetSize2($image, $size) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $width;
      var $height;
      $2=$image;
      $3=$size;
      var $4=$3;
      var $5=(($4)|0);
      HEAPF32[(($5)>>2)]=0;
      var $6=$3;
      var $7=(($6+4)|0);
      HEAPF32[(($7)>>2)]=0;
      var $8=$2;
      var $9=_HPDF_Image_Validate($8);
      var $10=(($9)|0)!=0;
      if ($10) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=4144;
      __label__ = 8; break;
    case 4: 
      var $13=$2;
      var $14=_HPDF_Dict_GetItem($13, ((STRING_TABLE.__str51431)|0), 4);
      var $15=$14;
      $width=$15;
      var $16=$2;
      var $17=_HPDF_Dict_GetItem($16, ((STRING_TABLE.__str61432)|0), 4);
      var $18=$17;
      $height=$18;
      var $19=$width;
      var $20=(($19)|0)!=0;
      if ($20) { __label__ = 5; break; } else { __label__ = 7; break; }
    case 5: 
      var $22=$height;
      var $23=(($22)|0)!=0;
      if ($23) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      var $25=$width;
      var $26=(($25+8)|0);
      var $27=HEAP32[(($26)>>2)];
      var $28=(($27)|0);
      var $29=$3;
      var $30=(($29)|0);
      HEAPF32[(($30)>>2)]=$28;
      var $31=$height;
      var $32=(($31+8)|0);
      var $33=HEAP32[(($32)>>2)];
      var $34=(($33)|0);
      var $35=$3;
      var $36=(($35+4)|0);
      HEAPF32[(($36)>>2)]=$34;
      __label__ = 7; break;
    case 7: 
      $1=0;
      __label__ = 8; break;
    case 8: 
      var $39=$1;
      ;
      return $39;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Image_GetSize2["X"]=1;

function _HPDF_Image_GetBitsPerComponent($image) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $n;
      $2=$image;
      var $3=$2;
      var $4=_HPDF_Image_Validate($3);
      var $5=(($4)|0)!=0;
      if ($5) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=0;
      __label__ = 7; break;
    case 4: 
      var $8=$2;
      var $9=_HPDF_Dict_GetItem($8, ((STRING_TABLE.__str71433)|0), 4);
      var $10=$9;
      $n=$10;
      var $11=$n;
      var $12=(($11)|0)!=0;
      if ($12) { __label__ = 6; break; } else { __label__ = 5; break; }
    case 5: 
      $1=0;
      __label__ = 7; break;
    case 6: 
      var $15=$n;
      var $16=(($15+8)|0);
      var $17=HEAP32[(($16)>>2)];
      $1=$17;
      __label__ = 7; break;
    case 7: 
      var $19=$1;
      ;
      return $19;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Image_GetColorSpace($image) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $n;
      var $a;
      $2=$image;
      var $3=$2;
      var $4=_HPDF_Dict_GetItem($3, ((STRING_TABLE.__str41430)|0), 6);
      var $5=$4;
      $n=$5;
      var $6=$n;
      var $7=(($6)|0)!=0;
      if ($7) { __label__ = 6; break; } else { __label__ = 3; break; }
    case 3: 
      var $9=$2;
      var $10=(($9+12)|0);
      var $11=HEAP32[(($10)>>2)];
      _HPDF_Error_Reset($11);
      var $12=$2;
      var $13=_HPDF_Dict_GetItem($12, ((STRING_TABLE.__str41430)|0), 16);
      var $14=$13;
      $a=$14;
      var $15=$a;
      var $16=(($15)|0)!=0;
      if ($16) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      var $18=$a;
      var $19=_HPDF_Array_GetItem($18, 0, 6);
      var $20=$19;
      $n=$20;
      __label__ = 5; break;
    case 5: 
      __label__ = 6; break;
    case 6: 
      var $23=$n;
      var $24=(($23)|0)!=0;
      if ($24) { __label__ = 8; break; } else { __label__ = 7; break; }
    case 7: 
      var $26=$2;
      var $27=(($26+12)|0);
      var $28=HEAP32[(($27)>>2)];
      var $29=_HPDF_CheckError($28);
      $1=0;
      __label__ = 9; break;
    case 8: 
      var $31=$n;
      var $32=(($31+12)|0);
      var $33=(($32)|0);
      $1=$33;
      __label__ = 9; break;
    case 9: 
      var $35=$1;
      ;
      return $35;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Image_GetWidth($image) {
  var __stackBase__  = STACKTOP; STACKTOP += 8; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;

  var $1;
  var $2=__stackBase__;
  $1=$image;
  var $3=$1;
  _HPDF_Image_GetSize($2, $3);
  var $4=(($2)|0);
  var $5=HEAPF32[(($4)>>2)];
  var $6=($5 >= 0 ? Math.floor($5) : Math.ceil($5));
  STACKTOP = __stackBase__;
  return $6;
}


function _HPDF_Image_GetHeight($image) {
  var __stackBase__  = STACKTOP; STACKTOP += 8; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;

  var $1;
  var $2=__stackBase__;
  $1=$image;
  var $3=$1;
  _HPDF_Image_GetSize($2, $3);
  var $4=(($2+4)|0);
  var $5=HEAPF32[(($4)>>2)];
  var $6=($5 >= 0 ? Math.floor($5) : Math.ceil($5));
  STACKTOP = __stackBase__;
  return $6;
}


function _HPDF_Image_SetMask($image, $mask) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $image_mask;
      var $ret;
      $2=$image;
      $3=$mask;
      var $4=$2;
      var $5=_HPDF_Image_Validate($4);
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=4144;
      __label__ = 12; break;
    case 4: 
      var $9=$3;
      var $10=(($9)|0)!=0;
      if ($10) { __label__ = 5; break; } else { __label__ = 7; break; }
    case 5: 
      var $12=$2;
      var $13=_HPDF_Image_GetBitsPerComponent($12);
      var $14=(($13)|0)!=1;
      if ($14) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      var $16=$2;
      var $17=(($16+12)|0);
      var $18=HEAP32[(($17)>>2)];
      var $19=_HPDF_SetError($18, 4126, 0);
      $1=$19;
      __label__ = 12; break;
    case 7: 
      var $21=$2;
      var $22=_HPDF_Dict_GetItem($21, ((STRING_TABLE.__str81434)|0), 3);
      var $23=$22;
      $image_mask=$23;
      var $24=$image_mask;
      var $25=(($24)|0)!=0;
      if ($25) { __label__ = 11; break; } else { __label__ = 8; break; }
    case 8: 
      var $27=$2;
      var $28=(($27+8)|0);
      var $29=HEAP32[(($28)>>2)];
      var $30=_HPDF_Boolean_New($29, 0);
      $image_mask=$30;
      var $31=$2;
      var $32=$image_mask;
      var $33=$32;
      var $34=_HPDF_Dict_Add($31, ((STRING_TABLE.__str81434)|0), $33);
      $ret=$34;
      var $35=(($34)|0)!=0;
      if ($35) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      var $37=$ret;
      $1=$37;
      __label__ = 12; break;
    case 10: 
      __label__ = 11; break;
    case 11: 
      var $40=$3;
      var $41=$image_mask;
      var $42=(($41+8)|0);
      HEAP32[(($42)>>2)]=$40;
      $1=0;
      __label__ = 12; break;
    case 12: 
      var $44=$1;
      ;
      return $44;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Image_SetMask["X"]=1;

function _HPDF_Image_SetMaskImage($image, $mask_image) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      $2=$image;
      $3=$mask_image;
      var $4=$2;
      var $5=_HPDF_Image_Validate($4);
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=4144;
      __label__ = 9; break;
    case 4: 
      var $9=$3;
      var $10=_HPDF_Image_Validate($9);
      var $11=(($10)|0)!=0;
      if ($11) { __label__ = 6; break; } else { __label__ = 5; break; }
    case 5: 
      $1=4144;
      __label__ = 9; break;
    case 6: 
      var $14=$3;
      var $15=_HPDF_Image_SetMask($14, 1);
      var $16=(($15)|0)!=0;
      if ($16) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $18=$2;
      var $19=(($18+12)|0);
      var $20=HEAP32[(($19)>>2)];
      var $21=_HPDF_CheckError($20);
      $1=$21;
      __label__ = 9; break;
    case 8: 
      var $23=$2;
      var $24=$3;
      var $25=$24;
      var $26=_HPDF_Dict_Add($23, ((STRING_TABLE.__str91435)|0), $25);
      $1=$26;
      __label__ = 9; break;
    case 9: 
      var $28=$1;
      ;
      return $28;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Image_SetColorMask($image, $rmin, $rmax, $gmin, $gmax, $bmin, $bmax) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $5;
      var $6;
      var $7;
      var $8;
      var $array;
      var $name;
      var $ret;
      $2=$image;
      $3=$rmin;
      $4=$rmax;
      $5=$gmin;
      $6=$gmax;
      $7=$bmin;
      $8=$bmax;
      $ret=0;
      var $9=$2;
      var $10=_HPDF_Image_Validate($9);
      var $11=(($10)|0)!=0;
      if ($11) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=4144;
      __label__ = 20; break;
    case 4: 
      var $14=$2;
      var $15=_HPDF_Dict_GetItem($14, ((STRING_TABLE.__str81434)|0), 3);
      var $16=(($15)|0)!=0;
      if ($16) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $18=$2;
      var $19=(($18+12)|0);
      var $20=HEAP32[(($19)>>2)];
      var $21=_HPDF_RaiseError($20, 4149, 0);
      $1=$21;
      __label__ = 20; break;
    case 6: 
      var $23=$2;
      var $24=_HPDF_Image_GetBitsPerComponent($23);
      var $25=(($24)|0)!=8;
      if ($25) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $27=$2;
      var $28=(($27+12)|0);
      var $29=HEAP32[(($28)>>2)];
      var $30=_HPDF_RaiseError($29, 4126, 0);
      $1=$30;
      __label__ = 20; break;
    case 8: 
      var $32=$2;
      var $33=_HPDF_Image_GetColorSpace($32);
      $name=$33;
      var $34=$name;
      var $35=(($34)|0)!=0;
      if ($35) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      var $37=HEAP32[((_COL_RGB)>>2)];
      var $38=$name;
      var $39=_HPDF_StrCmp($37, $38);
      var $40=(($39)|0)!=0;
      if ($40) { __label__ = 10; break; } else { __label__ = 11; break; }
    case 10: 
      var $42=$2;
      var $43=(($42+12)|0);
      var $44=HEAP32[(($43)>>2)];
      var $45=_HPDF_RaiseError($44, 4128, 0);
      $1=$45;
      __label__ = 20; break;
    case 11: 
      var $47=$4;
      var $48=(($47)>>>0) > 255;
      if ($48) { __label__ = 14; break; } else { __label__ = 12; break; }
    case 12: 
      var $50=$6;
      var $51=(($50)>>>0) > 255;
      if ($51) { __label__ = 14; break; } else { __label__ = 13; break; }
    case 13: 
      var $53=$8;
      var $54=(($53)>>>0) > 255;
      if ($54) { __label__ = 14; break; } else { __label__ = 15; break; }
    case 14: 
      var $56=$2;
      var $57=(($56+12)|0);
      var $58=HEAP32[(($57)>>2)];
      var $59=_HPDF_RaiseError($58, 4153, 0);
      $1=$59;
      __label__ = 20; break;
    case 15: 
      var $61=$2;
      var $62=(($61+8)|0);
      var $63=HEAP32[(($62)>>2)];
      var $64=_HPDF_Array_New($63);
      $array=$64;
      var $65=$array;
      var $66=(($65)|0)!=0;
      if ($66) { __label__ = 17; break; } else { __label__ = 16; break; }
    case 16: 
      var $68=$2;
      var $69=(($68+12)|0);
      var $70=HEAP32[(($69)>>2)];
      var $71=_HPDF_CheckError($70);
      $1=$71;
      __label__ = 20; break;
    case 17: 
      var $73=$2;
      var $74=$array;
      var $75=$74;
      var $76=_HPDF_Dict_Add($73, ((STRING_TABLE.__str91435)|0), $75);
      var $77=$ret;
      var $78=((($77)+($76))|0);
      $ret=$78;
      var $79=$array;
      var $80=$3;
      var $81=_HPDF_Array_AddNumber($79, $80);
      var $82=$ret;
      var $83=((($82)+($81))|0);
      $ret=$83;
      var $84=$array;
      var $85=$4;
      var $86=_HPDF_Array_AddNumber($84, $85);
      var $87=$ret;
      var $88=((($87)+($86))|0);
      $ret=$88;
      var $89=$array;
      var $90=$5;
      var $91=_HPDF_Array_AddNumber($89, $90);
      var $92=$ret;
      var $93=((($92)+($91))|0);
      $ret=$93;
      var $94=$array;
      var $95=$6;
      var $96=_HPDF_Array_AddNumber($94, $95);
      var $97=$ret;
      var $98=((($97)+($96))|0);
      $ret=$98;
      var $99=$array;
      var $100=$7;
      var $101=_HPDF_Array_AddNumber($99, $100);
      var $102=$ret;
      var $103=((($102)+($101))|0);
      $ret=$103;
      var $104=$array;
      var $105=$8;
      var $106=_HPDF_Array_AddNumber($104, $105);
      var $107=$ret;
      var $108=((($107)+($106))|0);
      $ret=$108;
      var $109=$ret;
      var $110=(($109)|0)!=0;
      if ($110) { __label__ = 18; break; } else { __label__ = 19; break; }
    case 18: 
      var $112=$2;
      var $113=(($112+12)|0);
      var $114=HEAP32[(($113)>>2)];
      var $115=_HPDF_CheckError($114);
      $1=$115;
      __label__ = 20; break;
    case 19: 
      $1=0;
      __label__ = 20; break;
    case 20: 
      var $118=$1;
      ;
      return $118;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Image_SetColorMask["X"]=1;

function _HPDF_Image_AddSMask($image, $smask) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $name;
      $2=$image;
      $3=$smask;
      var $4=$2;
      var $5=_HPDF_Image_Validate($4);
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=4144;
      __label__ = 12; break;
    case 4: 
      var $9=$3;
      var $10=_HPDF_Image_Validate($9);
      var $11=(($10)|0)!=0;
      if ($11) { __label__ = 6; break; } else { __label__ = 5; break; }
    case 5: 
      $1=4144;
      __label__ = 12; break;
    case 6: 
      var $14=$2;
      var $15=_HPDF_Dict_GetItem($14, ((STRING_TABLE.__str101436)|0), 3);
      var $16=(($15)|0)!=0;
      if ($16) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $18=$2;
      var $19=(($18+12)|0);
      var $20=HEAP32[(($19)>>2)];
      var $21=_HPDF_RaiseError($20, 4149, 0);
      $1=$21;
      __label__ = 12; break;
    case 8: 
      var $23=$3;
      var $24=_HPDF_Image_GetColorSpace($23);
      $name=$24;
      var $25=$name;
      var $26=(($25)|0)!=0;
      if ($26) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      var $28=HEAP32[((_COL_GRAY)>>2)];
      var $29=$name;
      var $30=_HPDF_StrCmp($28, $29);
      var $31=(($30)|0)!=0;
      if ($31) { __label__ = 10; break; } else { __label__ = 11; break; }
    case 10: 
      var $33=$3;
      var $34=(($33+12)|0);
      var $35=HEAP32[(($34)>>2)];
      var $36=_HPDF_RaiseError($35, 4128, 0);
      $1=$36;
      __label__ = 12; break;
    case 11: 
      var $38=$2;
      var $39=$3;
      var $40=$39;
      var $41=_HPDF_Dict_Add($38, ((STRING_TABLE.__str101436)|0), $40);
      $1=$41;
      __label__ = 12; break;
    case 12: 
      var $43=$1;
      ;
      return $43;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Image_AddSMask["X"]=1;

function _HPDF_Image_LoadPngImage($mmgr, $png_data, $xref, $delayed_loading) {
  var __stackBase__  = STACKTOP; STACKTOP += 12; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $5;
      var $ret;
      var $image;
      var $header=__stackBase__;
      var $len=(__stackBase__)+(8);
      $2=$mmgr;
      $3=$png_data;
      $4=$xref;
      $5=$delayed_loading;
      HEAP32[(($len)>>2)]=8;
      var $6=(($header)|0);
      var $7=_HPDF_MemSet($6, 0, 8);
      var $8=$3;
      var $9=(($header)|0);
      var $10=_HPDF_Stream_Read($8, $9, $len);
      $ret=$10;
      var $11=$ret;
      var $12=(($11)|0)!=0;
      if ($12) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      var $14=(($header)|0);
      var $15=_png_sig_cmp($14, 0, 8);
      var $16=(($15)|0)!=0;
      if ($16) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      var $18=$2;
      var $19=(($18)|0);
      var $20=HEAP32[(($19)>>2)];
      var $21=_HPDF_SetError($20, 4155, 0);
      $1=0;
      __label__ = 12; break;
    case 5: 
      var $23=$2;
      var $24=$4;
      var $25=_HPDF_DictStream_New($23, $24);
      $image=$25;
      var $26=$image;
      var $27=(($26)|0)!=0;
      if ($27) { __label__ = 7; break; } else { __label__ = 6; break; }
    case 6: 
      $1=0;
      __label__ = 12; break;
    case 7: 
      var $30=$image;
      var $31=(($30)|0);
      var $32=(($31+6)|0);
      var $33=HEAPU16[(($32)>>1)];
      var $34=(($33)&65535);
      var $35=$34 | 1280;
      var $36=(($35) & 65535);
      HEAP16[(($32)>>1)]=$36;
      var $37=$image;
      var $38=_HPDF_Dict_AddName($37, ((STRING_TABLE.__str1450)|0), ((STRING_TABLE.__str11451)|0));
      var $39=$ret;
      var $40=((($39)+($38))|0);
      $ret=$40;
      var $41=$image;
      var $42=_HPDF_Dict_AddName($41, ((STRING_TABLE.__str21452)|0), ((STRING_TABLE.__str31453)|0));
      var $43=$ret;
      var $44=((($43)+($42))|0);
      $ret=$44;
      var $45=$ret;
      var $46=(($45)|0)!=0;
      if ($46) { __label__ = 8; break; } else { __label__ = 9; break; }
    case 8: 
      $1=0;
      __label__ = 12; break;
    case 9: 
      var $49=$image;
      var $50=$4;
      var $51=$3;
      var $52=$5;
      var $53=_LoadPngData($49, $50, $51, $52);
      var $54=(($53)|0)!=0;
      if ($54) { __label__ = 10; break; } else { __label__ = 11; break; }
    case 10: 
      $1=0;
      __label__ = 12; break;
    case 11: 
      var $57=$image;
      $1=$57;
      __label__ = 12; break;
    case 12: 
      var $59=$1;
      STACKTOP = __stackBase__;
      return $59;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Image_LoadPngImage["X"]=1;

function _LoadPngData($image, $xref, $png_data, $delayed_loading) {
  var __stackBase__  = STACKTOP; STACKTOP += 16; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $5;
      var $ret;
      var $png_ptr=__stackBase__;
      var $info_ptr=(__stackBase__)+(4);
      var $trans=(__stackBase__)+(8);
      var $num_trans=(__stackBase__)+(12);
      var $smask;
      var $smask_data;
      var $smask1;
      var $smask_data2;
      $2=$image;
      $3=$xref;
      $4=$png_data;
      $5=$delayed_loading;
      $ret=0;
      HEAP32[(($png_ptr)>>2)]=0;
      HEAP32[(($info_ptr)>>2)]=0;
      var $6=$2;
      var $7=(($6+12)|0);
      var $8=HEAP32[(($7)>>2)];
      var $9=$8;
      var $10=_png_create_read_struct(((STRING_TABLE.__str41454)|0), $9, 216, 216);
      HEAP32[(($png_ptr)>>2)]=$10;
      var $11=HEAP32[(($png_ptr)>>2)];
      var $12=(($11)|0)==0;
      if ($12) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $14=$2;
      var $15=(($14+12)|0);
      var $16=HEAP32[(($15)>>2)];
      var $17=_HPDF_SetError($16, 4117, 0);
      $1=4117;
      __label__ = 68; break;
    case 4: 
      var $19=HEAP32[(($png_ptr)>>2)];
      var $20=_png_create_info_struct($19);
      HEAP32[(($info_ptr)>>2)]=$20;
      var $21=HEAP32[(($info_ptr)>>2)];
      var $22=(($21)|0)==0;
      if ($22) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $24=$2;
      var $25=(($24+12)|0);
      var $26=HEAP32[(($25)>>2)];
      var $27=_HPDF_SetError($26, 4117, 0);
      __label__ = 65; break;
    case 6: 
      var $29=HEAP32[(($png_ptr)>>2)];
      _png_set_sig_bytes($29, 8);
      var $30=HEAP32[(($png_ptr)>>2)];
      var $31=$4;
      var $32=$31;
      _png_set_read_fn($30, $32, 218);
      var $33=HEAP32[(($png_ptr)>>2)];
      var $34=HEAP32[(($info_ptr)>>2)];
      _png_read_info($33, $34);
      var $35=$2;
      var $36=(($35+12)|0);
      var $37=HEAP32[(($36)>>2)];
      var $38=(($37)|0);
      var $39=HEAP32[(($38)>>2)];
      var $40=(($39)|0)!=0;
      if ($40) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      __label__ = 65; break;
    case 8: 
      var $43=HEAP32[(($info_ptr)>>2)];
      var $44=(($43+24)|0);
      var $45=HEAPU8[($44)];
      var $46=(($45)&255);
      var $47=(($46)|0)==16;
      if ($47) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      var $49=HEAP32[(($png_ptr)>>2)];
      _png_set_strip_16($49);
      __label__ = 10; break;
    case 10: 
      var $51=HEAP32[(($png_ptr)>>2)];
      var $52=HEAP32[(($info_ptr)>>2)];
      _png_read_update_info($51, $52);
      var $53=$2;
      var $54=(($53+12)|0);
      var $55=HEAP32[(($54)>>2)];
      var $56=(($55)|0);
      var $57=HEAP32[(($56)>>2)];
      var $58=(($57)|0)!=0;
      if ($58) { __label__ = 11; break; } else { __label__ = 12; break; }
    case 11: 
      __label__ = 65; break;
    case 12: 
      var $61=$3;
      var $62=(($61)|0)!=0;
      if ($62) { __label__ = 13; break; } else { __label__ = 28; break; }
    case 13: 
      var $64=HEAP32[(($info_ptr)>>2)];
      var $65=(($64+25)|0);
      var $66=HEAPU8[($65)];
      var $67=(($66)&255);
      var $68=3 & $67;
      var $69=(($68)|0)!=0;
      if ($69) { __label__ = 14; break; } else { __label__ = 28; break; }
    case 14: 
      var $71=HEAP32[(($png_ptr)>>2)];
      var $72=HEAP32[(($info_ptr)>>2)];
      var $73=_png_get_valid($71, $72, 16);
      var $74=(($73)|0)!=0;
      if ($74) { __label__ = 15; break; } else { __label__ = 16; break; }
    case 15: 
      var $76=HEAP32[(($png_ptr)>>2)];
      var $77=HEAP32[(($info_ptr)>>2)];
      var $78=_png_get_tRNS($76, $77, $trans, $num_trans, 0);
      var $79=(($78)|0)!=0;
      if ($79) { __label__ = 17; break; } else { __label__ = 16; break; }
    case 16: 
      __label__ = 29; break;
    case 17: 
      var $82=$2;
      var $83=(($82+8)|0);
      var $84=HEAP32[(($83)>>2)];
      var $85=$3;
      var $86=_HPDF_DictStream_New($84, $85);
      $smask=$86;
      var $87=$smask;
      var $88=(($87)|0)!=0;
      if ($88) { __label__ = 19; break; } else { __label__ = 18; break; }
    case 18: 
      $ret=4117;
      __label__ = 65; break;
    case 19: 
      var $91=$smask;
      var $92=(($91)|0);
      var $93=(($92+6)|0);
      var $94=HEAPU16[(($93)>>1)];
      var $95=(($94)&65535);
      var $96=$95 | 1280;
      var $97=(($96) & 65535);
      HEAP16[(($93)>>1)]=$97;
      var $98=$smask;
      var $99=_HPDF_Dict_AddName($98, ((STRING_TABLE.__str1450)|0), ((STRING_TABLE.__str11451)|0));
      $ret=$99;
      var $100=$smask;
      var $101=_HPDF_Dict_AddName($100, ((STRING_TABLE.__str21452)|0), ((STRING_TABLE.__str31453)|0));
      var $102=$ret;
      var $103=((($102)+($101))|0);
      $ret=$103;
      var $104=$smask;
      var $105=HEAP32[(($info_ptr)>>2)];
      var $106=(($105)|0);
      var $107=HEAP32[(($106)>>2)];
      var $108=_HPDF_Dict_AddNumber($104, ((STRING_TABLE.__str51455)|0), $107);
      var $109=$ret;
      var $110=((($109)+($108))|0);
      $ret=$110;
      var $111=$smask;
      var $112=HEAP32[(($info_ptr)>>2)];
      var $113=(($112+4)|0);
      var $114=HEAP32[(($113)>>2)];
      var $115=_HPDF_Dict_AddNumber($111, ((STRING_TABLE.__str61456)|0), $114);
      var $116=$ret;
      var $117=((($116)+($115))|0);
      $ret=$117;
      var $118=$smask;
      var $119=_HPDF_Dict_AddName($118, ((STRING_TABLE.__str71457)|0), ((STRING_TABLE.__str81458)|0));
      var $120=$ret;
      var $121=((($120)+($119))|0);
      $ret=$121;
      var $122=$smask;
      var $123=HEAP32[(($info_ptr)>>2)];
      var $124=(($123+24)|0);
      var $125=HEAPU8[($124)];
      var $126=(($125)&255);
      var $127=_HPDF_Dict_AddNumber($122, ((STRING_TABLE.__str91459)|0), $126);
      var $128=$ret;
      var $129=((($128)+($127))|0);
      $ret=$129;
      var $130=$ret;
      var $131=(($130)|0)!=0;
      if ($131) { __label__ = 20; break; } else { __label__ = 21; break; }
    case 20: 
      var $133=$smask;
      _HPDF_Dict_Free($133);
      $ret=4155;
      __label__ = 65; break;
    case 21: 
      var $135=$2;
      var $136=(($135+8)|0);
      var $137=HEAP32[(($136)>>2)];
      var $138=HEAP32[(($info_ptr)>>2)];
      var $139=(($138)|0);
      var $140=HEAP32[(($139)>>2)];
      var $141=HEAP32[(($info_ptr)>>2)];
      var $142=(($141+4)|0);
      var $143=HEAP32[(($142)>>2)];
      var $144=((($140)*($143))|0);
      var $145=_HPDF_GetMem($137, $144);
      $smask_data=$145;
      var $146=$smask_data;
      var $147=(($146)|0)!=0;
      if ($147) { __label__ = 23; break; } else { __label__ = 22; break; }
    case 22: 
      var $149=$smask;
      _HPDF_Dict_Free($149);
      $ret=4117;
      __label__ = 65; break;
    case 23: 
      var $151=$2;
      var $152=HEAP32[(($png_ptr)>>2)];
      var $153=HEAP32[(($info_ptr)>>2)];
      var $154=$smask_data;
      var $155=HEAP32[(($trans)>>2)];
      var $156=HEAP32[(($num_trans)>>2)];
      var $157=_ReadTransparentPaletteData($151, $152, $153, $154, $155, $156);
      var $158=(($157)|0)!=0;
      if ($158) { __label__ = 24; break; } else { __label__ = 25; break; }
    case 24: 
      var $160=$2;
      var $161=(($160+8)|0);
      var $162=HEAP32[(($161)>>2)];
      var $163=$smask_data;
      _HPDF_FreeMem($162, $163);
      var $164=$smask;
      _HPDF_Dict_Free($164);
      $ret=4155;
      __label__ = 65; break;
    case 25: 
      var $166=$smask;
      var $167=(($166+36)|0);
      var $168=HEAP32[(($167)>>2)];
      var $169=$smask_data;
      var $170=HEAP32[(($info_ptr)>>2)];
      var $171=(($170)|0);
      var $172=HEAP32[(($171)>>2)];
      var $173=HEAP32[(($info_ptr)>>2)];
      var $174=(($173+4)|0);
      var $175=HEAP32[(($174)>>2)];
      var $176=((($172)*($175))|0);
      var $177=_HPDF_Stream_Write($168, $169, $176);
      var $178=(($177)|0)!=0;
      if ($178) { __label__ = 26; break; } else { __label__ = 27; break; }
    case 26: 
      var $180=$2;
      var $181=(($180+8)|0);
      var $182=HEAP32[(($181)>>2)];
      var $183=$smask_data;
      _HPDF_FreeMem($182, $183);
      var $184=$smask;
      _HPDF_Dict_Free($184);
      $ret=4118;
      __label__ = 65; break;
    case 27: 
      var $186=$2;
      var $187=(($186+8)|0);
      var $188=HEAP32[(($187)>>2)];
      var $189=$smask_data;
      _HPDF_FreeMem($188, $189);
      var $190=$2;
      var $191=HEAP32[(($png_ptr)>>2)];
      var $192=HEAP32[(($info_ptr)>>2)];
      var $193=_CreatePallet($190, $191, $192);
      var $194=$ret;
      var $195=((($194)+($193))|0);
      $ret=$195;
      var $196=$2;
      var $197=HEAP32[(($info_ptr)>>2)];
      var $198=(($197)|0);
      var $199=HEAP32[(($198)>>2)];
      var $200=_HPDF_Dict_AddNumber($196, ((STRING_TABLE.__str51455)|0), $199);
      var $201=$ret;
      var $202=((($201)+($200))|0);
      $ret=$202;
      var $203=$2;
      var $204=HEAP32[(($info_ptr)>>2)];
      var $205=(($204+4)|0);
      var $206=HEAP32[(($205)>>2)];
      var $207=_HPDF_Dict_AddNumber($203, ((STRING_TABLE.__str61456)|0), $206);
      var $208=$ret;
      var $209=((($208)+($207))|0);
      $ret=$209;
      var $210=$2;
      var $211=HEAP32[(($info_ptr)>>2)];
      var $212=(($211+24)|0);
      var $213=HEAPU8[($212)];
      var $214=(($213)&255);
      var $215=_HPDF_Dict_AddNumber($210, ((STRING_TABLE.__str91459)|0), $214);
      var $216=$ret;
      var $217=((($216)+($215))|0);
      $ret=$217;
      var $218=$2;
      var $219=$smask;
      var $220=$219;
      var $221=_HPDF_Dict_Add($218, ((STRING_TABLE.__str101460)|0), $220);
      var $222=$ret;
      var $223=((($222)+($221))|0);
      $ret=$223;
      _png_destroy_read_struct($png_ptr, $info_ptr, 0);
      $1=0;
      __label__ = 68; break;
    case 28: 
      __label__ = 29; break;
    case 29: 
      var $226=$3;
      var $227=(($226)|0)!=0;
      if ($227) { __label__ = 30; break; } else { __label__ = 42; break; }
    case 30: 
      var $229=HEAP32[(($info_ptr)>>2)];
      var $230=(($229+25)|0);
      var $231=HEAPU8[($230)];
      var $232=(($231)&255);
      var $233=4 & $232;
      var $234=(($233)|0)!=0;
      if ($234) { __label__ = 31; break; } else { __label__ = 42; break; }
    case 31: 
      var $236=$2;
      var $237=(($236+8)|0);
      var $238=HEAP32[(($237)>>2)];
      var $239=$3;
      var $240=_HPDF_DictStream_New($238, $239);
      $smask1=$240;
      var $241=$smask1;
      var $242=(($241)|0)!=0;
      if ($242) { __label__ = 33; break; } else { __label__ = 32; break; }
    case 32: 
      $ret=4117;
      __label__ = 65; break;
    case 33: 
      var $245=$smask1;
      var $246=(($245)|0);
      var $247=(($246+6)|0);
      var $248=HEAPU16[(($247)>>1)];
      var $249=(($248)&65535);
      var $250=$249 | 1280;
      var $251=(($250) & 65535);
      HEAP16[(($247)>>1)]=$251;
      var $252=$smask1;
      var $253=_HPDF_Dict_AddName($252, ((STRING_TABLE.__str1450)|0), ((STRING_TABLE.__str11451)|0));
      $ret=$253;
      var $254=$smask1;
      var $255=_HPDF_Dict_AddName($254, ((STRING_TABLE.__str21452)|0), ((STRING_TABLE.__str31453)|0));
      var $256=$ret;
      var $257=((($256)+($255))|0);
      $ret=$257;
      var $258=$smask1;
      var $259=HEAP32[(($info_ptr)>>2)];
      var $260=(($259)|0);
      var $261=HEAP32[(($260)>>2)];
      var $262=_HPDF_Dict_AddNumber($258, ((STRING_TABLE.__str51455)|0), $261);
      var $263=$ret;
      var $264=((($263)+($262))|0);
      $ret=$264;
      var $265=$smask1;
      var $266=HEAP32[(($info_ptr)>>2)];
      var $267=(($266+4)|0);
      var $268=HEAP32[(($267)>>2)];
      var $269=_HPDF_Dict_AddNumber($265, ((STRING_TABLE.__str61456)|0), $268);
      var $270=$ret;
      var $271=((($270)+($269))|0);
      $ret=$271;
      var $272=$smask1;
      var $273=_HPDF_Dict_AddName($272, ((STRING_TABLE.__str71457)|0), ((STRING_TABLE.__str81458)|0));
      var $274=$ret;
      var $275=((($274)+($273))|0);
      $ret=$275;
      var $276=$smask1;
      var $277=HEAP32[(($info_ptr)>>2)];
      var $278=(($277+24)|0);
      var $279=HEAPU8[($278)];
      var $280=(($279)&255);
      var $281=_HPDF_Dict_AddNumber($276, ((STRING_TABLE.__str91459)|0), $280);
      var $282=$ret;
      var $283=((($282)+($281))|0);
      $ret=$283;
      var $284=$ret;
      var $285=(($284)|0)!=0;
      if ($285) { __label__ = 34; break; } else { __label__ = 35; break; }
    case 34: 
      var $287=$smask1;
      _HPDF_Dict_Free($287);
      $ret=4155;
      __label__ = 65; break;
    case 35: 
      var $289=$2;
      var $290=(($289+8)|0);
      var $291=HEAP32[(($290)>>2)];
      var $292=HEAP32[(($info_ptr)>>2)];
      var $293=(($292)|0);
      var $294=HEAP32[(($293)>>2)];
      var $295=HEAP32[(($info_ptr)>>2)];
      var $296=(($295+4)|0);
      var $297=HEAP32[(($296)>>2)];
      var $298=((($294)*($297))|0);
      var $299=_HPDF_GetMem($291, $298);
      $smask_data2=$299;
      var $300=$smask_data2;
      var $301=(($300)|0)!=0;
      if ($301) { __label__ = 37; break; } else { __label__ = 36; break; }
    case 36: 
      var $303=$smask1;
      _HPDF_Dict_Free($303);
      $ret=4117;
      __label__ = 65; break;
    case 37: 
      var $305=$2;
      var $306=HEAP32[(($png_ptr)>>2)];
      var $307=HEAP32[(($info_ptr)>>2)];
      var $308=$smask_data2;
      var $309=_ReadTransparentPngData($305, $306, $307, $308);
      var $310=(($309)|0)!=0;
      if ($310) { __label__ = 38; break; } else { __label__ = 39; break; }
    case 38: 
      var $312=$2;
      var $313=(($312+8)|0);
      var $314=HEAP32[(($313)>>2)];
      var $315=$smask_data2;
      _HPDF_FreeMem($314, $315);
      var $316=$smask1;
      _HPDF_Dict_Free($316);
      $ret=4155;
      __label__ = 65; break;
    case 39: 
      var $318=$smask1;
      var $319=(($318+36)|0);
      var $320=HEAP32[(($319)>>2)];
      var $321=$smask_data2;
      var $322=HEAP32[(($info_ptr)>>2)];
      var $323=(($322)|0);
      var $324=HEAP32[(($323)>>2)];
      var $325=HEAP32[(($info_ptr)>>2)];
      var $326=(($325+4)|0);
      var $327=HEAP32[(($326)>>2)];
      var $328=((($324)*($327))|0);
      var $329=_HPDF_Stream_Write($320, $321, $328);
      var $330=(($329)|0)!=0;
      if ($330) { __label__ = 40; break; } else { __label__ = 41; break; }
    case 40: 
      var $332=$2;
      var $333=(($332+8)|0);
      var $334=HEAP32[(($333)>>2)];
      var $335=$smask_data2;
      _HPDF_FreeMem($334, $335);
      var $336=$smask1;
      _HPDF_Dict_Free($336);
      $ret=4118;
      __label__ = 65; break;
    case 41: 
      var $338=$2;
      var $339=(($338+8)|0);
      var $340=HEAP32[(($339)>>2)];
      var $341=$smask_data2;
      _HPDF_FreeMem($340, $341);
      var $342=$2;
      var $343=_HPDF_Dict_AddName($342, ((STRING_TABLE.__str71457)|0), ((STRING_TABLE.__str111461)|0));
      var $344=$ret;
      var $345=((($344)+($343))|0);
      $ret=$345;
      var $346=$2;
      var $347=HEAP32[(($info_ptr)>>2)];
      var $348=(($347)|0);
      var $349=HEAP32[(($348)>>2)];
      var $350=_HPDF_Dict_AddNumber($346, ((STRING_TABLE.__str51455)|0), $349);
      var $351=$ret;
      var $352=((($351)+($350))|0);
      $ret=$352;
      var $353=$2;
      var $354=HEAP32[(($info_ptr)>>2)];
      var $355=(($354+4)|0);
      var $356=HEAP32[(($355)>>2)];
      var $357=_HPDF_Dict_AddNumber($353, ((STRING_TABLE.__str61456)|0), $356);
      var $358=$ret;
      var $359=((($358)+($357))|0);
      $ret=$359;
      var $360=$2;
      var $361=HEAP32[(($info_ptr)>>2)];
      var $362=(($361+24)|0);
      var $363=HEAPU8[($362)];
      var $364=(($363)&255);
      var $365=_HPDF_Dict_AddNumber($360, ((STRING_TABLE.__str91459)|0), $364);
      var $366=$ret;
      var $367=((($366)+($365))|0);
      $ret=$367;
      var $368=$2;
      var $369=$smask1;
      var $370=$369;
      var $371=_HPDF_Dict_Add($368, ((STRING_TABLE.__str101460)|0), $370);
      var $372=$ret;
      var $373=((($372)+($371))|0);
      $ret=$373;
      _png_destroy_read_struct($png_ptr, $info_ptr, 0);
      $1=0;
      __label__ = 68; break;
    case 42: 
      var $375=HEAP32[(($info_ptr)>>2)];
      var $376=(($375+25)|0);
      var $377=HEAPU8[($376)];
      var $378=(($377)&255);
      var $379=(($378)|0)==3;
      if ($379) { __label__ = 43; break; } else { __label__ = 44; break; }
    case 43: 
      var $381=$2;
      var $382=HEAP32[(($png_ptr)>>2)];
      var $383=HEAP32[(($info_ptr)>>2)];
      var $384=_CreatePallet($381, $382, $383);
      $ret=$384;
      __label__ = 48; break;
    case 44: 
      var $386=HEAP32[(($info_ptr)>>2)];
      var $387=(($386+25)|0);
      var $388=HEAPU8[($387)];
      var $389=(($388)&255);
      var $390=(($389)|0)==0;
      if ($390) { __label__ = 45; break; } else { __label__ = 46; break; }
    case 45: 
      var $392=$2;
      var $393=_HPDF_Dict_AddName($392, ((STRING_TABLE.__str71457)|0), ((STRING_TABLE.__str81458)|0));
      $ret=$393;
      __label__ = 47; break;
    case 46: 
      var $395=$2;
      var $396=_HPDF_Dict_AddName($395, ((STRING_TABLE.__str71457)|0), ((STRING_TABLE.__str111461)|0));
      $ret=$396;
      __label__ = 47; break;
    case 47: 
      __label__ = 48; break;
    case 48: 
      var $399=$ret;
      var $400=(($399)|0)!=0;
      if ($400) { __label__ = 49; break; } else { __label__ = 50; break; }
    case 49: 
      __label__ = 65; break;
    case 50: 
      var $403=$5;
      var $404=(($403)|0)!=0;
      if ($404) { __label__ = 51; break; } else { __label__ = 52; break; }
    case 51: 
      var $406=$2;
      var $407=(($406+20)|0);
      HEAP32[(($407)>>2)]=212;
      var $408=$2;
      var $409=(($408+28)|0);
      HEAP32[(($409)>>2)]=214;
      __label__ = 58; break;
    case 52: 
      var $411=HEAP32[(($png_ptr)>>2)];
      var $412=HEAP32[(($info_ptr)>>2)];
      var $413=_png_get_interlace_type($411, $412);
      var $414=(($413)&255);
      var $415=(($414)|0)!=0;
      if ($415) { __label__ = 53; break; } else { __label__ = 54; break; }
    case 53: 
      var $417=$2;
      var $418=HEAP32[(($png_ptr)>>2)];
      var $419=HEAP32[(($info_ptr)>>2)];
      var $420=_ReadPngData_Interlaced($417, $418, $419);
      $ret=$420;
      __label__ = 55; break;
    case 54: 
      var $422=$2;
      var $423=HEAP32[(($png_ptr)>>2)];
      var $424=HEAP32[(($info_ptr)>>2)];
      var $425=_ReadPngData($422, $423, $424);
      $ret=$425;
      __label__ = 55; break;
    case 55: 
      var $427=$ret;
      var $428=(($427)|0)!=0;
      if ($428) { __label__ = 56; break; } else { __label__ = 57; break; }
    case 56: 
      __label__ = 65; break;
    case 57: 
      __label__ = 58; break;
    case 58: 
      var $432=$2;
      var $433=HEAP32[(($info_ptr)>>2)];
      var $434=(($433)|0);
      var $435=HEAP32[(($434)>>2)];
      var $436=_HPDF_Dict_AddNumber($432, ((STRING_TABLE.__str51455)|0), $435);
      var $437=(($436)|0)!=0;
      if ($437) { __label__ = 59; break; } else { __label__ = 60; break; }
    case 59: 
      __label__ = 65; break;
    case 60: 
      var $440=$2;
      var $441=HEAP32[(($info_ptr)>>2)];
      var $442=(($441+4)|0);
      var $443=HEAP32[(($442)>>2)];
      var $444=_HPDF_Dict_AddNumber($440, ((STRING_TABLE.__str61456)|0), $443);
      var $445=(($444)|0)!=0;
      if ($445) { __label__ = 61; break; } else { __label__ = 62; break; }
    case 61: 
      __label__ = 65; break;
    case 62: 
      var $448=$2;
      var $449=HEAP32[(($info_ptr)>>2)];
      var $450=(($449+24)|0);
      var $451=HEAPU8[($450)];
      var $452=(($451)&255);
      var $453=_HPDF_Dict_AddNumber($448, ((STRING_TABLE.__str91459)|0), $452);
      var $454=(($453)|0)!=0;
      if ($454) { __label__ = 63; break; } else { __label__ = 64; break; }
    case 63: 
      __label__ = 65; break;
    case 64: 
      _png_destroy_read_struct($png_ptr, $info_ptr, 0);
      $1=0;
      __label__ = 68; break;
    case 65: 
      _png_destroy_read_struct($png_ptr, $info_ptr, 0);
      var $458=$ret;
      var $459=(($458)|0)!=0;
      if ($459) { __label__ = 66; break; } else { __label__ = 67; break; }
    case 66: 
      var $461=$ret;
      $1=$461;
      __label__ = 68; break;
    case 67: 
      var $463=$2;
      var $464=(($463+12)|0);
      var $465=HEAP32[(($464)>>2)];
      var $466=(($465)|0);
      var $467=HEAP32[(($466)>>2)];
      $1=$467;
      __label__ = 68; break;
    case 68: 
      var $469=$1;
      STACKTOP = __stackBase__;
      return $469;
    default: assert(0, "bad label: " + __label__);
  }
}
_LoadPngData["X"]=1;

function _PngErrorFunc($png_ptr, $msg) {
  var __stackBase__  = STACKTOP; STACKTOP += 16; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $error_number=__stackBase__;
      var $i;
      var $detail_no;
      var $error;
      $1=$png_ptr;
      $2=$msg;
      var $3=(($error_number)|0);
      var $4=_HPDF_MemSet($3, 0, 16);
      $i=0;
      __label__ = 3; break;
    case 3: 
      var $6=$i;
      var $7=(($6)>>>0) < 15;
      if ($7) { __label__ = 4; break; } else { __label__ = 8; break; }
    case 4: 
      var $9=$2;
      var $10=$i;
      var $11=(($9+$10)|0);
      var $12=HEAP8[($11)];
      var $13=$i;
      var $14=(($error_number+$13)|0);
      HEAP8[($14)]=$12;
      var $15=$2;
      var $16=$i;
      var $17=(($15+$16)|0);
      var $18=(($17+1)|0);
      var $19=HEAP8[($18)];
      var $20=(($19 << 24) >> 24);
      var $21=(($20)|0)==32;
      if ($21) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      __label__ = 8; break;
    case 6: 
      __label__ = 7; break;
    case 7: 
      var $25=$i;
      var $26=((($25)+(1))|0);
      $i=$26;
      __label__ = 3; break;
    case 8: 
      var $28=$1;
      var $29=_png_get_error_ptr($28);
      var $30=$29;
      $error=$30;
      var $31=(($error_number)|0);
      var $32=_HPDF_AToI($31);
      $detail_no=$32;
      var $33=$error;
      var $34=$detail_no;
      var $35=_HPDF_SetError($33, 4163, $34);
      STACKTOP = __stackBase__;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}


function _PngReadFunc($png_ptr, $data, $length) {
  var __stackBase__  = STACKTOP; STACKTOP += 4; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;

  var $1;
  var $2;
  var $3;
  var $len=__stackBase__;
  var $stream;
  $1=$png_ptr;
  $2=$data;
  $3=$length;
  var $4=$3;
  HEAP32[(($len)>>2)]=$4;
  var $5=$1;
  var $6=_png_get_io_ptr($5);
  var $7=$6;
  $stream=$7;
  var $8=$stream;
  var $9=$2;
  var $10=_HPDF_Stream_Read($8, $9, $len);
  STACKTOP = __stackBase__;
  return;
}


function _ReadTransparentPaletteData($image, $png_ptr, $info_ptr, $smask_data, $trans, $num_trans) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $5;
      var $6;
      var $7;
      var $ret;
      var $i;
      var $j;
      var $row_ptr;
      var $len;
      $2=$image;
      $3=$png_ptr;
      $4=$info_ptr;
      $5=$smask_data;
      $6=$trans;
      $7=$num_trans;
      $ret=0;
      var $8=$2;
      var $9=(($8+8)|0);
      var $10=HEAP32[(($9)>>2)];
      var $11=$4;
      var $12=(($11+4)|0);
      var $13=HEAP32[(($12)>>2)];
      var $14=((($13<<2))|0);
      var $15=_HPDF_GetMem($10, $14);
      var $16=$15;
      $row_ptr=$16;
      var $17=$row_ptr;
      var $18=(($17)|0)!=0;
      if ($18) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=4117;
      __label__ = 36; break;
    case 4: 
      var $21=$3;
      var $22=$4;
      var $23=_png_get_rowbytes($21, $22);
      $len=$23;
      $i=0;
      __label__ = 5; break;
    case 5: 
      var $25=$i;
      var $26=$4;
      var $27=(($26+4)|0);
      var $28=HEAPU32[(($27)>>2)];
      var $29=(($25)>>>0) < (($28)>>>0);
      if ($29) { __label__ = 6; break; } else { __label__ = 14; break; }
    case 6: 
      var $31=$2;
      var $32=(($31+8)|0);
      var $33=HEAP32[(($32)>>2)];
      var $34=$len;
      var $35=_HPDF_GetMem($33, $34);
      var $36=$i;
      var $37=$row_ptr;
      var $38=(($37+($36<<2))|0);
      HEAP32[(($38)>>2)]=$35;
      var $39=$i;
      var $40=$row_ptr;
      var $41=(($40+($39<<2))|0);
      var $42=HEAP32[(($41)>>2)];
      var $43=(($42)|0)!=0;
      if ($43) { __label__ = 12; break; } else { __label__ = 7; break; }
    case 7: 
      __label__ = 8; break;
    case 8: 
      var $46=$i;
      var $47=(($46)>>>0) >= 0;
      if ($47) { __label__ = 9; break; } else { __label__ = 11; break; }
    case 9: 
      var $49=$2;
      var $50=(($49+8)|0);
      var $51=HEAP32[(($50)>>2)];
      var $52=$i;
      var $53=$row_ptr;
      var $54=(($53+($52<<2))|0);
      var $55=HEAP32[(($54)>>2)];
      _HPDF_FreeMem($51, $55);
      __label__ = 10; break;
    case 10: 
      var $57=$i;
      var $58=((($57)-(1))|0);
      $i=$58;
      __label__ = 8; break;
    case 11: 
      var $60=$2;
      var $61=(($60+8)|0);
      var $62=HEAP32[(($61)>>2)];
      var $63=$row_ptr;
      var $64=$63;
      _HPDF_FreeMem($62, $64);
      $1=4117;
      __label__ = 36; break;
    case 12: 
      __label__ = 13; break;
    case 13: 
      var $67=$i;
      var $68=((($67)+(1))|0);
      $i=$68;
      __label__ = 5; break;
    case 14: 
      __label__ = 15; break;
    case 15: 
      var $71=$3;
      var $72=$row_ptr;
      _png_read_image($71, $72);
      var $73=$2;
      var $74=(($73+12)|0);
      var $75=HEAP32[(($74)>>2)];
      var $76=(($75)|0);
      var $77=HEAP32[(($76)>>2)];
      var $78=(($77)|0)!=0;
      if ($78) { __label__ = 16; break; } else { __label__ = 17; break; }
    case 16: 
      $ret=4155;
      __label__ = 31; break;
    case 17: 
      $j=0;
      __label__ = 18; break;
    case 18: 
      var $82=$j;
      var $83=$4;
      var $84=(($83+4)|0);
      var $85=HEAPU32[(($84)>>2)];
      var $86=(($82)>>>0) < (($85)>>>0);
      if ($86) { __label__ = 19; break; } else { __label__ = 30; break; }
    case 19: 
      $i=0;
      __label__ = 20; break;
    case 20: 
      var $89=$i;
      var $90=$4;
      var $91=(($90)|0);
      var $92=HEAPU32[(($91)>>2)];
      var $93=(($89)>>>0) < (($92)>>>0);
      if ($93) { __label__ = 21; break; } else { __label__ = 26; break; }
    case 21: 
      var $95=$i;
      var $96=$j;
      var $97=$row_ptr;
      var $98=(($97+($96<<2))|0);
      var $99=HEAP32[(($98)>>2)];
      var $100=(($99+$95)|0);
      var $101=HEAPU8[($100)];
      var $102=(($101)&255);
      var $103=$7;
      var $104=(($102)|0) < (($103)|0);
      if ($104) { __label__ = 22; break; } else { __label__ = 23; break; }
    case 22: 
      var $106=$i;
      var $107=$j;
      var $108=$row_ptr;
      var $109=(($108+($107<<2))|0);
      var $110=HEAP32[(($109)>>2)];
      var $111=(($110+$106)|0);
      var $112=HEAPU8[($111)];
      var $113=(($112)&255);
      var $114=$6;
      var $115=(($114+$113)|0);
      var $116=HEAPU8[($115)];
      var $117=(($116)&255);
      var $120 = $117;__label__ = 24; break;
    case 23: 
      var $120 = 255;__label__ = 24; break;
    case 24: 
      var $120;
      var $121=(($120) & 255);
      var $122=$4;
      var $123=(($122)|0);
      var $124=HEAP32[(($123)>>2)];
      var $125=$j;
      var $126=((($124)*($125))|0);
      var $127=$i;
      var $128=((($126)+($127))|0);
      var $129=$5;
      var $130=(($129+$128)|0);
      HEAP8[($130)]=$121;
      __label__ = 25; break;
    case 25: 
      var $132=$i;
      var $133=((($132)+(1))|0);
      $i=$133;
      __label__ = 20; break;
    case 26: 
      var $135=$2;
      var $136=(($135+36)|0);
      var $137=HEAP32[(($136)>>2)];
      var $138=$j;
      var $139=$row_ptr;
      var $140=(($139+($138<<2))|0);
      var $141=HEAP32[(($140)>>2)];
      var $142=$4;
      var $143=(($142)|0);
      var $144=HEAP32[(($143)>>2)];
      var $145=_HPDF_Stream_Write($137, $141, $144);
      var $146=(($145)|0)!=0;
      if ($146) { __label__ = 27; break; } else { __label__ = 28; break; }
    case 27: 
      $ret=4118;
      __label__ = 31; break;
    case 28: 
      __label__ = 29; break;
    case 29: 
      var $150=$j;
      var $151=((($150)+(1))|0);
      $j=$151;
      __label__ = 18; break;
    case 30: 
      __label__ = 31; break;
    case 31: 
      $i=0;
      __label__ = 32; break;
    case 32: 
      var $155=$i;
      var $156=$4;
      var $157=(($156+4)|0);
      var $158=HEAPU32[(($157)>>2)];
      var $159=(($155)>>>0) < (($158)>>>0);
      if ($159) { __label__ = 33; break; } else { __label__ = 35; break; }
    case 33: 
      var $161=$2;
      var $162=(($161+8)|0);
      var $163=HEAP32[(($162)>>2)];
      var $164=$i;
      var $165=$row_ptr;
      var $166=(($165+($164<<2))|0);
      var $167=HEAP32[(($166)>>2)];
      _HPDF_FreeMem($163, $167);
      __label__ = 34; break;
    case 34: 
      var $169=$i;
      var $170=((($169)+(1))|0);
      $i=$170;
      __label__ = 32; break;
    case 35: 
      var $172=$2;
      var $173=(($172+8)|0);
      var $174=HEAP32[(($173)>>2)];
      var $175=$row_ptr;
      var $176=$175;
      _HPDF_FreeMem($174, $176);
      var $177=$ret;
      $1=$177;
      __label__ = 36; break;
    case 36: 
      var $179=$1;
      ;
      return $179;
    default: assert(0, "bad label: " + __label__);
  }
}
_ReadTransparentPaletteData["X"]=1;

function _CreatePallet($image, $png_ptr, $info_ptr) {
  var __stackBase__  = STACKTOP; STACKTOP += 8; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $num_pl=__stackBase__;
      var $src_pl=(__stackBase__)+(4);
      var $ppallet;
      var $p;
      var $i;
      var $array;
      var $b;
      $2=$image;
      $3=$png_ptr;
      $4=$info_ptr;
      HEAP32[(($num_pl)>>2)]=0;
      HEAP32[(($src_pl)>>2)]=0;
      var $5=$3;
      var $6=$4;
      var $7=_png_get_PLTE($5, $6, $src_pl, $num_pl);
      var $8=(($7)|0)!=8;
      if ($8) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $10=$2;
      var $11=(($10+12)|0);
      var $12=HEAP32[(($11)>>2)];
      var $13=_HPDF_SetError($12, 4163, 4101);
      $1=$13;
      __label__ = 15; break;
    case 4: 
      var $15=$2;
      var $16=(($15+8)|0);
      var $17=HEAP32[(($16)>>2)];
      var $18=HEAP32[(($num_pl)>>2)];
      var $19=((($18)*(3))|0);
      var $20=_HPDF_GetMem($17, $19);
      $ppallet=$20;
      var $21=$ppallet;
      var $22=(($21)|0)!=0;
      if ($22) { __label__ = 6; break; } else { __label__ = 5; break; }
    case 5: 
      var $24=$2;
      var $25=(($24+12)|0);
      var $26=HEAP32[(($25)>>2)];
      var $27=(($26)|0);
      var $28=HEAP32[(($27)>>2)];
      $1=$28;
      __label__ = 15; break;
    case 6: 
      var $30=$ppallet;
      $p=$30;
      $i=0;
      __label__ = 7; break;
    case 7: 
      var $32=$i;
      var $33=HEAPU32[(($num_pl)>>2)];
      var $34=(($32)>>>0) < (($33)>>>0);
      if ($34) { __label__ = 8; break; } else { __label__ = 10; break; }
    case 8: 
      var $36=HEAP32[(($src_pl)>>2)];
      var $37=(($36)|0);
      var $38=HEAP8[($37)];
      var $39=$p;
      var $40=(($39+1)|0);
      $p=$40;
      HEAP8[($39)]=$38;
      var $41=HEAP32[(($src_pl)>>2)];
      var $42=(($41+1)|0);
      var $43=HEAP8[($42)];
      var $44=$p;
      var $45=(($44+1)|0);
      $p=$45;
      HEAP8[($44)]=$43;
      var $46=HEAP32[(($src_pl)>>2)];
      var $47=(($46+2)|0);
      var $48=HEAP8[($47)];
      var $49=$p;
      var $50=(($49+1)|0);
      $p=$50;
      HEAP8[($49)]=$48;
      __label__ = 9; break;
    case 9: 
      var $52=$i;
      var $53=((($52)+(1))|0);
      $i=$53;
      var $54=HEAP32[(($src_pl)>>2)];
      var $55=(($54+3)|0);
      HEAP32[(($src_pl)>>2)]=$55;
      __label__ = 7; break;
    case 10: 
      var $57=$2;
      var $58=(($57+8)|0);
      var $59=HEAP32[(($58)>>2)];
      var $60=_HPDF_Array_New($59);
      $array=$60;
      var $61=$array;
      var $62=(($61)|0)!=0;
      if ($62) { __label__ = 11; break; } else { __label__ = 14; break; }
    case 11: 
      var $64=$2;
      var $65=$array;
      var $66=$65;
      var $67=_HPDF_Dict_Add($64, ((STRING_TABLE.__str71457)|0), $66);
      var $68=$array;
      var $69=_HPDF_Array_AddName($68, ((STRING_TABLE.__str131463)|0));
      var $70=$array;
      var $71=_HPDF_Array_AddName($70, ((STRING_TABLE.__str111461)|0));
      var $72=$array;
      var $73=HEAP32[(($num_pl)>>2)];
      var $74=((($73)-(1))|0);
      var $75=_HPDF_Array_AddNumber($72, $74);
      var $76=$2;
      var $77=(($76+8)|0);
      var $78=HEAP32[(($77)>>2)];
      var $79=$ppallet;
      var $80=HEAP32[(($num_pl)>>2)];
      var $81=((($80)*(3))|0);
      var $82=_HPDF_Binary_New($78, $79, $81);
      $b=$82;
      var $83=$b;
      var $84=(($83)|0)!=0;
      if ($84) { __label__ = 12; break; } else { __label__ = 13; break; }
    case 12: 
      var $86=$array;
      var $87=$b;
      var $88=$87;
      var $89=_HPDF_Array_Add($86, $88);
      __label__ = 13; break;
    case 13: 
      __label__ = 14; break;
    case 14: 
      var $92=$2;
      var $93=(($92+8)|0);
      var $94=HEAP32[(($93)>>2)];
      var $95=$ppallet;
      _HPDF_FreeMem($94, $95);
      var $96=$2;
      var $97=(($96+12)|0);
      var $98=HEAP32[(($97)>>2)];
      var $99=(($98)|0);
      var $100=HEAP32[(($99)>>2)];
      $1=$100;
      __label__ = 15; break;
    case 15: 
      var $102=$1;
      STACKTOP = __stackBase__;
      return $102;
    default: assert(0, "bad label: " + __label__);
  }
}
_CreatePallet["X"]=1;

function _ReadTransparentPngData($image, $png_ptr, $info_ptr, $smask_data) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $5;
      var $ret;
      var $row_len;
      var $i;
      var $j;
      var $row_ptr;
      var $row;
      var $color_type;
      var $len;
      $2=$image;
      $3=$png_ptr;
      $4=$info_ptr;
      $5=$smask_data;
      $ret=0;
      var $6=$3;
      var $7=$4;
      var $8=_png_get_color_type($6, $7);
      $color_type=$8;
      var $9=$color_type;
      var $10=(($9)&255);
      var $11=$10 & 4;
      var $12=(($11)|0)!=0;
      if ($12) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=4155;
      __label__ = 49; break;
    case 4: 
      var $15=$2;
      var $16=(($15+8)|0);
      var $17=HEAP32[(($16)>>2)];
      var $18=$4;
      var $19=(($18+4)|0);
      var $20=HEAP32[(($19)>>2)];
      var $21=((($20<<2))|0);
      var $22=_HPDF_GetMem($17, $21);
      var $23=$22;
      $row_ptr=$23;
      var $24=$row_ptr;
      var $25=(($24)|0)!=0;
      if ($25) { __label__ = 6; break; } else { __label__ = 5; break; }
    case 5: 
      $1=4117;
      __label__ = 49; break;
    case 6: 
      var $28=$3;
      var $29=$4;
      var $30=_png_get_rowbytes($28, $29);
      $len=$30;
      $i=0;
      __label__ = 7; break;
    case 7: 
      var $32=$i;
      var $33=$4;
      var $34=(($33+4)|0);
      var $35=HEAPU32[(($34)>>2)];
      var $36=(($32)>>>0) < (($35)>>>0);
      if ($36) { __label__ = 8; break; } else { __label__ = 16; break; }
    case 8: 
      var $38=$2;
      var $39=(($38+8)|0);
      var $40=HEAP32[(($39)>>2)];
      var $41=$len;
      var $42=_HPDF_GetMem($40, $41);
      var $43=$i;
      var $44=$row_ptr;
      var $45=(($44+($43<<2))|0);
      HEAP32[(($45)>>2)]=$42;
      var $46=$i;
      var $47=$row_ptr;
      var $48=(($47+($46<<2))|0);
      var $49=HEAP32[(($48)>>2)];
      var $50=(($49)|0)!=0;
      if ($50) { __label__ = 14; break; } else { __label__ = 9; break; }
    case 9: 
      __label__ = 10; break;
    case 10: 
      var $53=$i;
      var $54=(($53)>>>0) >= 0;
      if ($54) { __label__ = 11; break; } else { __label__ = 13; break; }
    case 11: 
      var $56=$2;
      var $57=(($56+8)|0);
      var $58=HEAP32[(($57)>>2)];
      var $59=$i;
      var $60=$row_ptr;
      var $61=(($60+($59<<2))|0);
      var $62=HEAP32[(($61)>>2)];
      _HPDF_FreeMem($58, $62);
      __label__ = 12; break;
    case 12: 
      var $64=$i;
      var $65=((($64)-(1))|0);
      $i=$65;
      __label__ = 10; break;
    case 13: 
      var $67=$2;
      var $68=(($67+8)|0);
      var $69=HEAP32[(($68)>>2)];
      var $70=$row_ptr;
      var $71=$70;
      _HPDF_FreeMem($69, $71);
      $1=4117;
      __label__ = 49; break;
    case 14: 
      __label__ = 15; break;
    case 15: 
      var $74=$i;
      var $75=((($74)+(1))|0);
      $i=$75;
      __label__ = 7; break;
    case 16: 
      __label__ = 17; break;
    case 17: 
      var $78=$3;
      var $79=$row_ptr;
      _png_read_image($78, $79);
      var $80=$2;
      var $81=(($80+12)|0);
      var $82=HEAP32[(($81)>>2)];
      var $83=(($82)|0);
      var $84=HEAP32[(($83)>>2)];
      var $85=(($84)|0)!=0;
      if ($85) { __label__ = 18; break; } else { __label__ = 19; break; }
    case 18: 
      $ret=4155;
      __label__ = 44; break;
    case 19: 
      var $88=$color_type;
      var $89=(($88)&255);
      if ((($89)|0) == 6) {
        __label__ = 20; break;
      }
      else if ((($89)|0) == 4) {
        __label__ = 31; break;
      }
      else {
      __label__ = 42; break;
      }
      
    case 20: 
      var $91=$4;
      var $92=(($91)|0);
      var $93=HEAP32[(($92)>>2)];
      var $94=((($93)*(3))|0);
      var $95=(($94)|0);
      $row_len=$95;
      $j=0;
      __label__ = 21; break;
    case 21: 
      var $97=$j;
      var $98=$4;
      var $99=(($98+4)|0);
      var $100=HEAPU32[(($99)>>2)];
      var $101=(($97)>>>0) < (($100)>>>0);
      if ($101) { __label__ = 22; break; } else { __label__ = 30; break; }
    case 22: 
      $i=0;
      __label__ = 23; break;
    case 23: 
      var $104=$i;
      var $105=$4;
      var $106=(($105)|0);
      var $107=HEAPU32[(($106)>>2)];
      var $108=(($104)>>>0) < (($107)>>>0);
      if ($108) { __label__ = 24; break; } else { __label__ = 26; break; }
    case 24: 
      var $110=$j;
      var $111=$row_ptr;
      var $112=(($111+($110<<2))|0);
      var $113=HEAP32[(($112)>>2)];
      $row=$113;
      var $114=$row;
      var $115=$i;
      var $116=((($115)*(3))|0);
      var $117=(($114+$116)|0);
      var $118=$row;
      var $119=$i;
      var $120=((($119<<2))|0);
      var $121=(($118+$120)|0);
      _llvm_memmove_p0i8_p0i8_i32($117, $121, 3, 1, 0);
      var $122=$i;
      var $123=((($122<<2))|0);
      var $124=((($123)+(3))|0);
      var $125=$row;
      var $126=(($125+$124)|0);
      var $127=HEAP8[($126)];
      var $128=$4;
      var $129=(($128)|0);
      var $130=HEAP32[(($129)>>2)];
      var $131=$j;
      var $132=((($130)*($131))|0);
      var $133=$i;
      var $134=((($132)+($133))|0);
      var $135=$5;
      var $136=(($135+$134)|0);
      HEAP8[($136)]=$127;
      __label__ = 25; break;
    case 25: 
      var $138=$i;
      var $139=((($138)+(1))|0);
      $i=$139;
      __label__ = 23; break;
    case 26: 
      var $141=$2;
      var $142=(($141+36)|0);
      var $143=HEAP32[(($142)>>2)];
      var $144=$row;
      var $145=$row_len;
      var $146=_HPDF_Stream_Write($143, $144, $145);
      var $147=(($146)|0)!=0;
      if ($147) { __label__ = 27; break; } else { __label__ = 28; break; }
    case 27: 
      $ret=4118;
      __label__ = 44; break;
    case 28: 
      __label__ = 29; break;
    case 29: 
      var $151=$j;
      var $152=((($151)+(1))|0);
      $j=$152;
      __label__ = 21; break;
    case 30: 
      __label__ = 43; break;
    case 31: 
      var $155=$4;
      var $156=(($155)|0);
      var $157=HEAP32[(($156)>>2)];
      var $158=(($157)|0);
      $row_len=$158;
      $j=0;
      __label__ = 32; break;
    case 32: 
      var $160=$j;
      var $161=$4;
      var $162=(($161+4)|0);
      var $163=HEAPU32[(($162)>>2)];
      var $164=(($160)>>>0) < (($163)>>>0);
      if ($164) { __label__ = 33; break; } else { __label__ = 41; break; }
    case 33: 
      $i=0;
      __label__ = 34; break;
    case 34: 
      var $167=$i;
      var $168=$4;
      var $169=(($168)|0);
      var $170=HEAPU32[(($169)>>2)];
      var $171=(($167)>>>0) < (($170)>>>0);
      if ($171) { __label__ = 35; break; } else { __label__ = 37; break; }
    case 35: 
      var $173=$j;
      var $174=$row_ptr;
      var $175=(($174+($173<<2))|0);
      var $176=HEAP32[(($175)>>2)];
      $row=$176;
      var $177=$i;
      var $178=((($177<<1))|0);
      var $179=$row;
      var $180=(($179+$178)|0);
      var $181=HEAP8[($180)];
      var $182=$i;
      var $183=$row;
      var $184=(($183+$182)|0);
      HEAP8[($184)]=$181;
      var $185=$i;
      var $186=((($185<<1))|0);
      var $187=((($186)+(1))|0);
      var $188=$row;
      var $189=(($188+$187)|0);
      var $190=HEAP8[($189)];
      var $191=$4;
      var $192=(($191)|0);
      var $193=HEAP32[(($192)>>2)];
      var $194=$j;
      var $195=((($193)*($194))|0);
      var $196=$i;
      var $197=((($195)+($196))|0);
      var $198=$5;
      var $199=(($198+$197)|0);
      HEAP8[($199)]=$190;
      __label__ = 36; break;
    case 36: 
      var $201=$i;
      var $202=((($201)+(1))|0);
      $i=$202;
      __label__ = 34; break;
    case 37: 
      var $204=$2;
      var $205=(($204+36)|0);
      var $206=HEAP32[(($205)>>2)];
      var $207=$row;
      var $208=$row_len;
      var $209=_HPDF_Stream_Write($206, $207, $208);
      var $210=(($209)|0)!=0;
      if ($210) { __label__ = 38; break; } else { __label__ = 39; break; }
    case 38: 
      $ret=4118;
      __label__ = 44; break;
    case 39: 
      __label__ = 40; break;
    case 40: 
      var $214=$j;
      var $215=((($214)+(1))|0);
      $j=$215;
      __label__ = 32; break;
    case 41: 
      __label__ = 43; break;
    case 42: 
      $ret=4155;
      __label__ = 44; break;
    case 43: 
      __label__ = 44; break;
    case 44: 
      $i=0;
      __label__ = 45; break;
    case 45: 
      var $221=$i;
      var $222=$4;
      var $223=(($222+4)|0);
      var $224=HEAPU32[(($223)>>2)];
      var $225=(($221)>>>0) < (($224)>>>0);
      if ($225) { __label__ = 46; break; } else { __label__ = 48; break; }
    case 46: 
      var $227=$2;
      var $228=(($227+8)|0);
      var $229=HEAP32[(($228)>>2)];
      var $230=$i;
      var $231=$row_ptr;
      var $232=(($231+($230<<2))|0);
      var $233=HEAP32[(($232)>>2)];
      _HPDF_FreeMem($229, $233);
      __label__ = 47; break;
    case 47: 
      var $235=$i;
      var $236=((($235)+(1))|0);
      $i=$236;
      __label__ = 45; break;
    case 48: 
      var $238=$2;
      var $239=(($238+8)|0);
      var $240=HEAP32[(($239)>>2)];
      var $241=$row_ptr;
      var $242=$241;
      _HPDF_FreeMem($240, $242);
      var $243=$ret;
      $1=$243;
      __label__ = 49; break;
    case 49: 
      var $245=$1;
      ;
      return $245;
    default: assert(0, "bad label: " + __label__);
  }
}
_ReadTransparentPngData["X"]=1;

function _PngBeforeWrite($obj) {
  var __stackBase__  = STACKTOP; STACKTOP += 12; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $ret;
      var $header=__stackBase__;
      var $len=(__stackBase__)+(8);
      var $png_data;
      var $s;
      $2=$obj;
      HEAP32[(($len)>>2)]=8;
      var $3=$2;
      var $4=(($3+36)|0);
      var $5=HEAP32[(($4)>>2)];
      _HPDF_MemStream_FreeData($5);
      var $6=$2;
      var $7=_HPDF_Dict_GetItem($6, ((STRING_TABLE.__str121462)|0), 7);
      var $8=$7;
      $s=$8;
      var $9=$s;
      var $10=(($9)|0)!=0;
      if ($10) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      var $12=$2;
      var $13=(($12+12)|0);
      var $14=HEAP32[(($13)>>2)];
      var $15=_HPDF_SetError($14, 4157, 0);
      $1=$15;
      __label__ = 12; break;
    case 4: 
      var $17=$2;
      var $18=(($17+8)|0);
      var $19=HEAP32[(($18)>>2)];
      var $20=$s;
      var $21=(($20+20)|0);
      var $22=HEAP32[(($21)>>2)];
      var $23=_HPDF_FileReader_New($19, $22);
      $png_data=$23;
      var $24=$png_data;
      var $25=_HPDF_Stream_Validate($24);
      var $26=(($25)|0)!=0;
      if ($26) { __label__ = 6; break; } else { __label__ = 5; break; }
    case 5: 
      var $28=$2;
      var $29=(($28+12)|0);
      var $30=HEAP32[(($29)>>2)];
      var $31=(($30)|0);
      var $32=HEAP32[(($31)>>2)];
      $1=$32;
      __label__ = 12; break;
    case 6: 
      var $34=(($header)|0);
      var $35=_HPDF_MemSet($34, 0, 8);
      var $36=$png_data;
      var $37=(($header)|0);
      var $38=_HPDF_Stream_Read($36, $37, $len);
      $ret=$38;
      var $39=$ret;
      var $40=(($39)|0)!=0;
      if ($40) { __label__ = 8; break; } else { __label__ = 7; break; }
    case 7: 
      var $42=(($header)|0);
      var $43=_png_sig_cmp($42, 0, 8);
      var $44=(($43)|0)!=0;
      if ($44) { __label__ = 8; break; } else { __label__ = 9; break; }
    case 8: 
      var $46=$png_data;
      _HPDF_Stream_Free($46);
      var $47=$2;
      var $48=(($47+12)|0);
      var $49=HEAP32[(($48)>>2)];
      var $50=_HPDF_SetError($49, 4155, 0);
      $1=$50;
      __label__ = 12; break;
    case 9: 
      var $52=$2;
      var $53=$png_data;
      var $54=_LoadPngData($52, 0, $53, 0);
      $ret=$54;
      var $55=(($54)|0)!=0;
      if ($55) { __label__ = 10; break; } else { __label__ = 11; break; }
    case 10: 
      var $57=$png_data;
      _HPDF_Stream_Free($57);
      var $58=$ret;
      $1=$58;
      __label__ = 12; break;
    case 11: 
      var $60=$png_data;
      _HPDF_Stream_Free($60);
      $1=0;
      __label__ = 12; break;
    case 12: 
      var $62=$1;
      STACKTOP = __stackBase__;
      return $62;
    default: assert(0, "bad label: " + __label__);
  }
}
_PngBeforeWrite["X"]=1;

function _PngAfterWrite($obj) {
  ;
  var __label__;

  var $1;
  $1=$obj;
  var $2=$1;
  var $3=(($2+36)|0);
  var $4=HEAP32[(($3)>>2)];
  _HPDF_MemStream_FreeData($4);
  ;
  return 0;
}


function _InfoTypeToName($type) {
  ;
  var __label__;

  var $1;
  var $idx;
  $1=$type;
  var $2=$1;
  $idx=$2;
  var $3=$idx;
  var $4=((_HPDF_INFO_ATTR_NAMES+($3<<2))|0);
  var $5=HEAP32[(($4)>>2)];
  ;
  return $5;
}


function _ReadPngData_Interlaced($image, $png_ptr, $info_ptr) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $len;
      var $row_pointers;
      var $i;
      $1=$image;
      $2=$png_ptr;
      $3=$info_ptr;
      var $4=$2;
      var $5=$3;
      var $6=_png_get_rowbytes($4, $5);
      $len=$6;
      var $7=$1;
      var $8=(($7+8)|0);
      var $9=HEAP32[(($8)>>2)];
      var $10=$3;
      var $11=(($10+4)|0);
      var $12=HEAP32[(($11)>>2)];
      var $13=((($12<<2))|0);
      var $14=_HPDF_GetMem($9, $13);
      var $15=$14;
      $row_pointers=$15;
      var $16=$row_pointers;
      var $17=(($16)|0)!=0;
      if ($17) { __label__ = 3; break; } else { __label__ = 24; break; }
    case 3: 
      var $19=$row_pointers;
      var $20=$19;
      var $21=$3;
      var $22=(($21+4)|0);
      var $23=HEAP32[(($22)>>2)];
      var $24=((($23<<2))|0);
      var $25=_HPDF_MemSet($20, 0, $24);
      $i=0;
      __label__ = 4; break;
    case 4: 
      var $27=$i;
      var $28=$3;
      var $29=(($28+4)|0);
      var $30=HEAPU32[(($29)>>2)];
      var $31=(($27)>>>0) < (($30)>>>0);
      if ($31) { __label__ = 5; break; } else { __label__ = 9; break; }
    case 5: 
      var $33=$1;
      var $34=(($33+8)|0);
      var $35=HEAP32[(($34)>>2)];
      var $36=$len;
      var $37=_HPDF_GetMem($35, $36);
      var $38=$i;
      var $39=$row_pointers;
      var $40=(($39+($38<<2))|0);
      HEAP32[(($40)>>2)]=$37;
      var $41=$1;
      var $42=(($41+12)|0);
      var $43=HEAP32[(($42)>>2)];
      var $44=(($43)|0);
      var $45=HEAP32[(($44)>>2)];
      var $46=(($45)|0)!=0;
      if ($46) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      __label__ = 9; break;
    case 7: 
      __label__ = 8; break;
    case 8: 
      var $50=$i;
      var $51=((($50)+(1))|0);
      $i=$51;
      __label__ = 4; break;
    case 9: 
      var $53=$1;
      var $54=(($53+12)|0);
      var $55=HEAP32[(($54)>>2)];
      var $56=(($55)|0);
      var $57=HEAP32[(($56)>>2)];
      var $58=(($57)|0)==0;
      if ($58) { __label__ = 10; break; } else { __label__ = 19; break; }
    case 10: 
      var $60=$2;
      var $61=$row_pointers;
      _png_read_image($60, $61);
      var $62=$1;
      var $63=(($62+12)|0);
      var $64=HEAP32[(($63)>>2)];
      var $65=(($64)|0);
      var $66=HEAP32[(($65)>>2)];
      var $67=(($66)|0)==0;
      if ($67) { __label__ = 11; break; } else { __label__ = 18; break; }
    case 11: 
      $i=0;
      __label__ = 12; break;
    case 12: 
      var $70=$i;
      var $71=$3;
      var $72=(($71+4)|0);
      var $73=HEAPU32[(($72)>>2)];
      var $74=(($70)>>>0) < (($73)>>>0);
      if ($74) { __label__ = 13; break; } else { __label__ = 17; break; }
    case 13: 
      var $76=$1;
      var $77=(($76+36)|0);
      var $78=HEAP32[(($77)>>2)];
      var $79=$i;
      var $80=$row_pointers;
      var $81=(($80+($79<<2))|0);
      var $82=HEAP32[(($81)>>2)];
      var $83=$len;
      var $84=_HPDF_Stream_Write($78, $82, $83);
      var $85=(($84)|0)!=0;
      if ($85) { __label__ = 14; break; } else { __label__ = 15; break; }
    case 14: 
      __label__ = 17; break;
    case 15: 
      __label__ = 16; break;
    case 16: 
      var $89=$i;
      var $90=((($89)+(1))|0);
      $i=$90;
      __label__ = 12; break;
    case 17: 
      __label__ = 18; break;
    case 18: 
      __label__ = 19; break;
    case 19: 
      $i=0;
      __label__ = 20; break;
    case 20: 
      var $95=$i;
      var $96=$3;
      var $97=(($96+4)|0);
      var $98=HEAPU32[(($97)>>2)];
      var $99=(($95)>>>0) < (($98)>>>0);
      if ($99) { __label__ = 21; break; } else { __label__ = 23; break; }
    case 21: 
      var $101=$1;
      var $102=(($101+8)|0);
      var $103=HEAP32[(($102)>>2)];
      var $104=$i;
      var $105=$row_pointers;
      var $106=(($105+($104<<2))|0);
      var $107=HEAP32[(($106)>>2)];
      _HPDF_FreeMem($103, $107);
      __label__ = 22; break;
    case 22: 
      var $109=$i;
      var $110=((($109)+(1))|0);
      $i=$110;
      __label__ = 20; break;
    case 23: 
      var $112=$1;
      var $113=(($112+8)|0);
      var $114=HEAP32[(($113)>>2)];
      var $115=$row_pointers;
      var $116=$115;
      _HPDF_FreeMem($114, $116);
      __label__ = 24; break;
    case 24: 
      var $118=$1;
      var $119=(($118+12)|0);
      var $120=HEAP32[(($119)>>2)];
      var $121=(($120)|0);
      var $122=HEAP32[(($121)>>2)];
      ;
      return $122;
    default: assert(0, "bad label: " + __label__);
  }
}
_ReadPngData_Interlaced["X"]=1;

function _ReadPngData($image, $png_ptr, $info_ptr) {
  var __stackBase__  = STACKTOP; STACKTOP += 4; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $len;
      var $buf_ptr=__stackBase__;
      var $i;
      $1=$image;
      $2=$png_ptr;
      $3=$info_ptr;
      var $4=$2;
      var $5=$3;
      var $6=_png_get_rowbytes($4, $5);
      $len=$6;
      var $7=$1;
      var $8=(($7+8)|0);
      var $9=HEAP32[(($8)>>2)];
      var $10=$len;
      var $11=_HPDF_GetMem($9, $10);
      HEAP32[(($buf_ptr)>>2)]=$11;
      var $12=HEAP32[(($buf_ptr)>>2)];
      var $13=(($12)|0)!=0;
      if ($13) { __label__ = 3; break; } else { __label__ = 12; break; }
    case 3: 
      $i=0;
      __label__ = 4; break;
    case 4: 
      var $16=$i;
      var $17=$3;
      var $18=(($17+4)|0);
      var $19=HEAPU32[(($18)>>2)];
      var $20=(($16)>>>0) < (($19)>>>0);
      if ($20) { __label__ = 5; break; } else { __label__ = 11; break; }
    case 5: 
      var $22=$2;
      _png_read_rows($22, $buf_ptr, 0, 1);
      var $23=$1;
      var $24=(($23+12)|0);
      var $25=HEAP32[(($24)>>2)];
      var $26=(($25)|0);
      var $27=HEAP32[(($26)>>2)];
      var $28=(($27)|0)!=0;
      if ($28) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      __label__ = 11; break;
    case 7: 
      var $31=$1;
      var $32=(($31+36)|0);
      var $33=HEAP32[(($32)>>2)];
      var $34=HEAP32[(($buf_ptr)>>2)];
      var $35=$len;
      var $36=_HPDF_Stream_Write($33, $34, $35);
      var $37=(($36)|0)!=0;
      if ($37) { __label__ = 8; break; } else { __label__ = 9; break; }
    case 8: 
      __label__ = 11; break;
    case 9: 
      __label__ = 10; break;
    case 10: 
      var $41=$i;
      var $42=((($41)+(1))|0);
      $i=$42;
      __label__ = 4; break;
    case 11: 
      var $44=$1;
      var $45=(($44+8)|0);
      var $46=HEAP32[(($45)>>2)];
      var $47=HEAP32[(($buf_ptr)>>2)];
      _HPDF_FreeMem($46, $47);
      __label__ = 12; break;
    case 12: 
      var $49=$1;
      var $50=(($49+12)|0);
      var $51=HEAP32[(($50)>>2)];
      var $52=(($51)|0);
      var $53=HEAP32[(($52)>>2)];
      STACKTOP = __stackBase__;
      return $53;
    default: assert(0, "bad label: " + __label__);
  }
}
_ReadPngData["X"]=1;

function _HPDF_Info_SetInfoAttr($info, $type, $value, $encoder) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $5;
      var $name;
      $2=$info;
      $3=$type;
      $4=$value;
      $5=$encoder;
      var $6=$3;
      var $7=_InfoTypeToName($6);
      $name=$7;
      var $8=$3;
      var $9=(($8)>>>0) <= 1;
      if ($9) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $11=$2;
      var $12=(($11+12)|0);
      var $13=HEAP32[(($12)>>2)];
      var $14=_HPDF_SetError($13, 4153, 0);
      $1=$14;
      __label__ = 5; break;
    case 4: 
      var $16=$2;
      var $17=$name;
      var $18=$2;
      var $19=(($18+8)|0);
      var $20=HEAP32[(($19)>>2)];
      var $21=$4;
      var $22=$5;
      var $23=_HPDF_String_New($20, $21, $22);
      var $24=$23;
      var $25=_HPDF_Dict_Add($16, $17, $24);
      $1=$25;
      __label__ = 5; break;
    case 5: 
      var $27=$1;
      ;
      return $27;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Info_GetInfoAttr($info, $type) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $name;
      var $s;
      $2=$info;
      $3=$type;
      var $4=$3;
      var $5=_InfoTypeToName($4);
      $name=$5;
      var $6=$2;
      var $7=(($6)|0)!=0;
      if ($7) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=0;
      __label__ = 7; break;
    case 4: 
      var $10=$2;
      var $11=$name;
      var $12=_HPDF_Dict_GetItem($10, $11, 7);
      var $13=$12;
      $s=$13;
      var $14=$s;
      var $15=(($14)|0)!=0;
      if ($15) { __label__ = 6; break; } else { __label__ = 5; break; }
    case 5: 
      $1=0;
      __label__ = 7; break;
    case 6: 
      var $18=$s;
      var $19=(($18+20)|0);
      var $20=HEAP32[(($19)>>2)];
      $1=$20;
      __label__ = 7; break;
    case 7: 
      var $22=$1;
      ;
      return $22;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Info_SetInfoDateAttr($info, $type, $value) {
  var __stackBase__  = STACKTOP; STACKTOP += 24; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var tempParam = $value; $value = STACKTOP;STACKTOP += 36;assert(STACKTOP < STACK_ROOT + STACK_MAX, "Ran out of stack");for (var $$src = tempParam>>2, $$dest = $value>>2, $$stop = $$src + 9; $$src < $$stop; $$src++, $$dest++) {
  HEAP32[$$dest] = HEAP32[$$src]
};
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $tmp=__stackBase__;
      var $ptmp;
      var $name;
      $2=$info;
      $3=$type;
      var $4=$3;
      var $5=_InfoTypeToName($4);
      $name=$5;
      var $6=$3;
      var $7=(($6)>>>0) > 1;
      if ($7) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $9=$2;
      var $10=(($9+12)|0);
      var $11=HEAP32[(($10)>>2)];
      var $12=_HPDF_SetError($11, 4153, 0);
      $1=$12;
      __label__ = 35; break;
    case 4: 
      var $14=(($tmp)|0);
      var $15=_HPDF_MemSet($14, 0, 24);
      var $16=(($value+4)|0);
      var $17=HEAP32[(($16)>>2)];
      var $18=(($17)|0) < 1;
      if ($18) { __label__ = 16; break; } else { __label__ = 5; break; }
    case 5: 
      var $20=(($value+4)|0);
      var $21=HEAP32[(($20)>>2)];
      var $22=12 < (($21)|0);
      if ($22) { __label__ = 16; break; } else { __label__ = 6; break; }
    case 6: 
      var $24=(($value+8)|0);
      var $25=HEAP32[(($24)>>2)];
      var $26=(($25)|0) < 1;
      if ($26) { __label__ = 16; break; } else { __label__ = 7; break; }
    case 7: 
      var $28=(($value+12)|0);
      var $29=HEAP32[(($28)>>2)];
      var $30=23 < (($29)|0);
      if ($30) { __label__ = 16; break; } else { __label__ = 8; break; }
    case 8: 
      var $32=(($value+16)|0);
      var $33=HEAP32[(($32)>>2)];
      var $34=59 < (($33)|0);
      if ($34) { __label__ = 16; break; } else { __label__ = 9; break; }
    case 9: 
      var $36=(($value+20)|0);
      var $37=HEAP32[(($36)>>2)];
      var $38=59 < (($37)|0);
      if ($38) { __label__ = 16; break; } else { __label__ = 10; break; }
    case 10: 
      var $40=(($value+24)|0);
      var $41=HEAP8[($40)];
      var $42=(($41 << 24) >> 24);
      var $43=(($42)|0)!=43;
      if ($43) { __label__ = 11; break; } else { __label__ = 14; break; }
    case 11: 
      var $45=(($value+24)|0);
      var $46=HEAP8[($45)];
      var $47=(($46 << 24) >> 24);
      var $48=(($47)|0)!=45;
      if ($48) { __label__ = 12; break; } else { __label__ = 14; break; }
    case 12: 
      var $50=(($value+24)|0);
      var $51=HEAP8[($50)];
      var $52=(($51 << 24) >> 24);
      var $53=(($52)|0)!=90;
      if ($53) { __label__ = 13; break; } else { __label__ = 14; break; }
    case 13: 
      var $55=(($value+24)|0);
      var $56=HEAP8[($55)];
      var $57=(($56 << 24) >> 24);
      var $58=(($57)|0)!=32;
      if ($58) { __label__ = 16; break; } else { __label__ = 14; break; }
    case 14: 
      var $60=(($value+28)|0);
      var $61=HEAP32[(($60)>>2)];
      var $62=23 < (($61)|0);
      if ($62) { __label__ = 16; break; } else { __label__ = 15; break; }
    case 15: 
      var $64=(($value+32)|0);
      var $65=HEAP32[(($64)>>2)];
      var $66=59 < (($65)|0);
      if ($66) { __label__ = 16; break; } else { __label__ = 17; break; }
    case 16: 
      var $68=$2;
      var $69=(($68+12)|0);
      var $70=HEAP32[(($69)>>2)];
      var $71=_HPDF_SetError($70, 4130, 0);
      $1=$71;
      __label__ = 35; break;
    case 17: 
      var $73=(($value+4)|0);
      var $74=HEAP32[(($73)>>2)];
      if ((($74)|0) == 1 || (($74)|0) == 3 || (($74)|0) == 5 || (($74)|0) == 7 || (($74)|0) == 8 || (($74)|0) == 10 || (($74)|0) == 12) {
        __label__ = 18; break;
      }
      else if ((($74)|0) == 4 || (($74)|0) == 6 || (($74)|0) == 9 || (($74)|0) == 11) {
        __label__ = 21; break;
      }
      else if ((($74)|0) == 2) {
        __label__ = 24; break;
      }
      else {
      __label__ = 31; break;
      }
      
    case 18: 
      var $76=(($value+8)|0);
      var $77=HEAP32[(($76)>>2)];
      var $78=(($77)|0) > 31;
      if ($78) { __label__ = 19; break; } else { __label__ = 20; break; }
    case 19: 
      var $80=$2;
      var $81=(($80+12)|0);
      var $82=HEAP32[(($81)>>2)];
      var $83=_HPDF_SetError($82, 4130, 0);
      $1=$83;
      __label__ = 35; break;
    case 20: 
      __label__ = 32; break;
    case 21: 
      var $86=(($value+8)|0);
      var $87=HEAP32[(($86)>>2)];
      var $88=(($87)|0) > 30;
      if ($88) { __label__ = 22; break; } else { __label__ = 23; break; }
    case 22: 
      var $90=$2;
      var $91=(($90+12)|0);
      var $92=HEAP32[(($91)>>2)];
      var $93=_HPDF_SetError($92, 4130, 0);
      $1=$93;
      __label__ = 35; break;
    case 23: 
      __label__ = 32; break;
    case 24: 
      var $96=(($value+8)|0);
      var $97=HEAP32[(($96)>>2)];
      var $98=(($97)|0) > 29;
      if ($98) { __label__ = 29; break; } else { __label__ = 25; break; }
    case 25: 
      var $100=(($value+8)|0);
      var $101=HEAP32[(($100)>>2)];
      var $102=(($101)|0)==29;
      if ($102) { __label__ = 26; break; } else { __label__ = 30; break; }
    case 26: 
      var $104=(($value)|0);
      var $105=HEAP32[(($104)>>2)];
      var $106=((($105)|0))%(4);
      var $107=(($106)|0)!=0;
      if ($107) { __label__ = 29; break; } else { __label__ = 27; break; }
    case 27: 
      var $109=(($value)|0);
      var $110=HEAP32[(($109)>>2)];
      var $111=((($110)|0))%(100);
      var $112=(($111)|0)==0;
      if ($112) { __label__ = 28; break; } else { __label__ = 30; break; }
    case 28: 
      var $114=(($value)|0);
      var $115=HEAP32[(($114)>>2)];
      var $116=((($115)|0))%(400);
      var $117=(($116)|0)!=0;
      if ($117) { __label__ = 29; break; } else { __label__ = 30; break; }
    case 29: 
      var $119=$2;
      var $120=(($119+12)|0);
      var $121=HEAP32[(($120)>>2)];
      var $122=_HPDF_SetError($121, 4130, 0);
      $1=$122;
      __label__ = 35; break;
    case 30: 
      __label__ = 32; break;
    case 31: 
      var $125=$2;
      var $126=(($125+12)|0);
      var $127=HEAP32[(($126)>>2)];
      var $128=_HPDF_SetError($127, 4130, 0);
      $1=$128;
      __label__ = 35; break;
    case 32: 
      var $130=(($tmp)|0);
      var $131=_HPDF_MemCpy($130, ((STRING_TABLE.__str1466)|0), 2);
      $ptmp=$131;
      var $132=$ptmp;
      var $133=(($value)|0);
      var $134=HEAP32[(($133)>>2)];
      var $135=_HPDF_IToA2($132, $134, 5);
      $ptmp=$135;
      var $136=$ptmp;
      var $137=(($value+4)|0);
      var $138=HEAP32[(($137)>>2)];
      var $139=_HPDF_IToA2($136, $138, 3);
      $ptmp=$139;
      var $140=$ptmp;
      var $141=(($value+8)|0);
      var $142=HEAP32[(($141)>>2)];
      var $143=_HPDF_IToA2($140, $142, 3);
      $ptmp=$143;
      var $144=$ptmp;
      var $145=(($value+12)|0);
      var $146=HEAP32[(($145)>>2)];
      var $147=_HPDF_IToA2($144, $146, 3);
      $ptmp=$147;
      var $148=$ptmp;
      var $149=(($value+16)|0);
      var $150=HEAP32[(($149)>>2)];
      var $151=_HPDF_IToA2($148, $150, 3);
      $ptmp=$151;
      var $152=$ptmp;
      var $153=(($value+20)|0);
      var $154=HEAP32[(($153)>>2)];
      var $155=_HPDF_IToA2($152, $154, 3);
      $ptmp=$155;
      var $156=(($value+24)|0);
      var $157=HEAP8[($156)];
      var $158=(($157 << 24) >> 24);
      var $159=(($158)|0)!=32;
      if ($159) { __label__ = 33; break; } else { __label__ = 34; break; }
    case 33: 
      var $161=(($value+24)|0);
      var $162=HEAP8[($161)];
      var $163=$ptmp;
      var $164=(($163+1)|0);
      $ptmp=$164;
      HEAP8[($163)]=$162;
      var $165=$ptmp;
      var $166=(($value+28)|0);
      var $167=HEAP32[(($166)>>2)];
      var $168=_HPDF_IToA2($165, $167, 3);
      $ptmp=$168;
      var $169=$ptmp;
      var $170=(($169+1)|0);
      $ptmp=$170;
      HEAP8[($169)]=39;
      var $171=$ptmp;
      var $172=(($value+32)|0);
      var $173=HEAP32[(($172)>>2)];
      var $174=_HPDF_IToA2($171, $173, 3);
      $ptmp=$174;
      var $175=$ptmp;
      var $176=(($175+1)|0);
      $ptmp=$176;
      HEAP8[($175)]=39;
      __label__ = 34; break;
    case 34: 
      var $178=$ptmp;
      HEAP8[($178)]=0;
      var $179=$2;
      var $180=$name;
      var $181=$2;
      var $182=(($181+8)|0);
      var $183=HEAP32[(($182)>>2)];
      var $184=(($tmp)|0);
      var $185=_HPDF_String_New($183, $184, 0);
      var $186=$185;
      var $187=_HPDF_Dict_Add($179, $180, $186);
      $1=$187;
      __label__ = 35; break;
    case 35: 
      var $189=$1;
      STACKTOP = __stackBase__;
      return $189;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Info_SetInfoDateAttr["X"]=1;

function _HPDF_List_New($mmgr, $items_per_block) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $list;
      $2=$mmgr;
      $3=$items_per_block;
      var $4=$2;
      var $5=(($4)|0)==0;
      if ($5) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      $1=0;
      __label__ = 10; break;
    case 4: 
      var $8=$2;
      var $9=_HPDF_GetMem($8, 24);
      var $10=$9;
      $list=$10;
      var $11=$list;
      var $12=(($11)|0)!=0;
      if ($12) { __label__ = 5; break; } else { __label__ = 9; break; }
    case 5: 
      var $14=$2;
      var $15=$list;
      var $16=(($15)|0);
      HEAP32[(($16)>>2)]=$14;
      var $17=$2;
      var $18=(($17)|0);
      var $19=HEAP32[(($18)>>2)];
      var $20=$list;
      var $21=(($20+4)|0);
      HEAP32[(($21)>>2)]=$19;
      var $22=$list;
      var $23=(($22+8)|0);
      HEAP32[(($23)>>2)]=0;
      var $24=$3;
      var $25=(($24)>>>0) <= 0;
      if ($25) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      var $30 = 20;__label__ = 8; break;
    case 7: 
      var $28=$3;
      var $30 = $28;__label__ = 8; break;
    case 8: 
      var $30;
      var $31=$list;
      var $32=(($31+12)|0);
      HEAP32[(($32)>>2)]=$30;
      var $33=$list;
      var $34=(($33+16)|0);
      HEAP32[(($34)>>2)]=0;
      var $35=$list;
      var $36=(($35+20)|0);
      HEAP32[(($36)>>2)]=0;
      __label__ = 9; break;
    case 9: 
      var $38=$list;
      $1=$38;
      __label__ = 10; break;
    case 10: 
      var $40=$1;
      ;
      return $40;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_List_New["X"]=1;

function _HPDF_List_Add($list, $item) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $ret;
      $2=$list;
      $3=$item;
      var $4=$2;
      var $5=(($4+16)|0);
      var $6=HEAPU32[(($5)>>2)];
      var $7=$2;
      var $8=(($7+8)|0);
      var $9=HEAPU32[(($8)>>2)];
      var $10=(($6)>>>0) >= (($9)>>>0);
      if ($10) { __label__ = 3; break; } else { __label__ = 6; break; }
    case 3: 
      var $12=$2;
      var $13=$2;
      var $14=(($13+8)|0);
      var $15=HEAP32[(($14)>>2)];
      var $16=$2;
      var $17=(($16+12)|0);
      var $18=HEAP32[(($17)>>2)];
      var $19=((($15)+($18))|0);
      var $20=_Resize($12, $19);
      $ret=$20;
      var $21=$ret;
      var $22=(($21)|0)!=0;
      if ($22) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      var $24=$ret;
      $1=$24;
      __label__ = 7; break;
    case 5: 
      __label__ = 6; break;
    case 6: 
      var $27=$3;
      var $28=$2;
      var $29=(($28+16)|0);
      var $30=HEAP32[(($29)>>2)];
      var $31=((($30)+(1))|0);
      HEAP32[(($29)>>2)]=$31;
      var $32=$2;
      var $33=(($32+20)|0);
      var $34=HEAP32[(($33)>>2)];
      var $35=(($34+($30<<2))|0);
      HEAP32[(($35)>>2)]=$27;
      $1=0;
      __label__ = 7; break;
    case 7: 
      var $37=$1;
      ;
      return $37;
    default: assert(0, "bad label: " + __label__);
  }
}


function _Resize($list, $count) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $new_obj;
      $2=$list;
      $3=$count;
      var $4=$2;
      var $5=(($4+16)|0);
      var $6=HEAPU32[(($5)>>2)];
      var $7=$3;
      var $8=(($6)>>>0) >= (($7)>>>0);
      if ($8) { __label__ = 3; break; } else { __label__ = 6; break; }
    case 3: 
      var $10=$2;
      var $11=(($10+16)|0);
      var $12=HEAP32[(($11)>>2)];
      var $13=$3;
      var $14=(($12)|0)==(($13)|0);
      if ($14) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      $1=0;
      __label__ = 13; break;
    case 5: 
      $1=4153;
      __label__ = 13; break;
    case 6: 
      var $18=$2;
      var $19=(($18)|0);
      var $20=HEAP32[(($19)>>2)];
      var $21=$3;
      var $22=((($21<<2))|0);
      var $23=_HPDF_GetMem($20, $22);
      var $24=$23;
      $new_obj=$24;
      var $25=$new_obj;
      var $26=(($25)|0)!=0;
      if ($26) { __label__ = 8; break; } else { __label__ = 7; break; }
    case 7: 
      var $28=$2;
      var $29=(($28+4)|0);
      var $30=HEAP32[(($29)>>2)];
      var $31=_HPDF_Error_GetCode($30);
      $1=$31;
      __label__ = 13; break;
    case 8: 
      var $33=$2;
      var $34=(($33+20)|0);
      var $35=HEAP32[(($34)>>2)];
      var $36=(($35)|0)!=0;
      if ($36) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      var $38=$new_obj;
      var $39=$38;
      var $40=$2;
      var $41=(($40+20)|0);
      var $42=HEAP32[(($41)>>2)];
      var $43=$42;
      var $44=$2;
      var $45=(($44+8)|0);
      var $46=HEAP32[(($45)>>2)];
      var $47=((($46<<2))|0);
      var $48=_HPDF_MemCpy($39, $43, $47);
      __label__ = 10; break;
    case 10: 
      var $50=$3;
      var $51=$2;
      var $52=(($51+8)|0);
      HEAP32[(($52)>>2)]=$50;
      var $53=$2;
      var $54=(($53+20)|0);
      var $55=HEAP32[(($54)>>2)];
      var $56=(($55)|0)!=0;
      if ($56) { __label__ = 11; break; } else { __label__ = 12; break; }
    case 11: 
      var $58=$2;
      var $59=(($58)|0);
      var $60=HEAP32[(($59)>>2)];
      var $61=$2;
      var $62=(($61+20)|0);
      var $63=HEAP32[(($62)>>2)];
      var $64=$63;
      _HPDF_FreeMem($60, $64);
      __label__ = 12; break;
    case 12: 
      var $66=$new_obj;
      var $67=$2;
      var $68=(($67+20)|0);
      HEAP32[(($68)>>2)]=$66;
      $1=0;
      __label__ = 13; break;
    case 13: 
      var $70=$1;
      ;
      return $70;
    default: assert(0, "bad label: " + __label__);
  }
}
_Resize["X"]=1;

function _HPDF_List_Insert($list, $target, $item) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $target_idx;
      var $last_item;
      var $i;
      $2=$list;
      $3=$target;
      $4=$item;
      var $5=$2;
      var $6=$3;
      var $7=_HPDF_List_Find($5, $6);
      $target_idx=$7;
      var $8=$2;
      var $9=(($8+16)|0);
      var $10=HEAP32[(($9)>>2)];
      var $11=((($10)-(1))|0);
      var $12=$2;
      var $13=(($12+20)|0);
      var $14=HEAP32[(($13)>>2)];
      var $15=(($14+($11<<2))|0);
      var $16=HEAP32[(($15)>>2)];
      $last_item=$16;
      var $17=$target_idx;
      var $18=(($17)|0) < 0;
      if ($18) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      $1=4162;
      __label__ = 9; break;
    case 4: 
      var $21=$2;
      var $22=(($21+16)|0);
      var $23=HEAP32[(($22)>>2)];
      var $24=((($23)-(2))|0);
      $i=$24;
      __label__ = 5; break;
    case 5: 
      var $26=$i;
      var $27=$target_idx;
      var $28=(($26)|0) >= (($27)|0);
      if ($28) { __label__ = 6; break; } else { __label__ = 8; break; }
    case 6: 
      var $30=$i;
      var $31=$2;
      var $32=(($31+20)|0);
      var $33=HEAP32[(($32)>>2)];
      var $34=(($33+($30<<2))|0);
      var $35=HEAP32[(($34)>>2)];
      var $36=$i;
      var $37=((($36)+(1))|0);
      var $38=$2;
      var $39=(($38+20)|0);
      var $40=HEAP32[(($39)>>2)];
      var $41=(($40+($37<<2))|0);
      HEAP32[(($41)>>2)]=$35;
      __label__ = 7; break;
    case 7: 
      var $43=$i;
      var $44=((($43)-(1))|0);
      $i=$44;
      __label__ = 5; break;
    case 8: 
      var $46=$4;
      var $47=$target_idx;
      var $48=$2;
      var $49=(($48+20)|0);
      var $50=HEAP32[(($49)>>2)];
      var $51=(($50+($47<<2))|0);
      HEAP32[(($51)>>2)]=$46;
      var $52=$2;
      var $53=$last_item;
      var $54=_HPDF_List_Add($52, $53);
      $1=$54;
      __label__ = 9; break;
    case 9: 
      var $56=$1;
      ;
      return $56;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_List_Insert["X"]=1;

function _HPDF_List_Find($list, $item) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $i;
      $2=$list;
      $3=$item;
      $i=0;
      __label__ = 3; break;
    case 3: 
      var $5=$i;
      var $6=$2;
      var $7=(($6+16)|0);
      var $8=HEAPU32[(($7)>>2)];
      var $9=(($5)>>>0) < (($8)>>>0);
      if ($9) { __label__ = 4; break; } else { __label__ = 8; break; }
    case 4: 
      var $11=$i;
      var $12=$2;
      var $13=(($12+20)|0);
      var $14=HEAP32[(($13)>>2)];
      var $15=(($14+($11<<2))|0);
      var $16=HEAP32[(($15)>>2)];
      var $17=$3;
      var $18=(($16)|0)==(($17)|0);
      if ($18) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $20=$i;
      $1=$20;
      __label__ = 9; break;
    case 6: 
      __label__ = 7; break;
    case 7: 
      var $23=$i;
      var $24=((($23)+(1))|0);
      $i=$24;
      __label__ = 3; break;
    case 8: 
      $1=-1;
      __label__ = 9; break;
    case 9: 
      var $27=$1;
      ;
      return $27;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_List_RemoveByIndex($list, $index) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $tmp;
      $2=$list;
      $3=$index;
      var $4=$2;
      var $5=(($4+16)|0);
      var $6=HEAPU32[(($5)>>2)];
      var $7=$3;
      var $8=(($6)>>>0) <= (($7)>>>0);
      if ($8) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      $1=0;
      __label__ = 8; break;
    case 4: 
      var $11=$3;
      var $12=$2;
      var $13=(($12+20)|0);
      var $14=HEAP32[(($13)>>2)];
      var $15=(($14+($11<<2))|0);
      var $16=HEAP32[(($15)>>2)];
      $tmp=$16;
      __label__ = 5; break;
    case 5: 
      var $18=$3;
      var $19=$2;
      var $20=(($19+16)|0);
      var $21=HEAP32[(($20)>>2)];
      var $22=((($21)-(1))|0);
      var $23=(($18)>>>0) < (($22)>>>0);
      if ($23) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      var $25=$3;
      var $26=((($25)+(1))|0);
      var $27=$2;
      var $28=(($27+20)|0);
      var $29=HEAP32[(($28)>>2)];
      var $30=(($29+($26<<2))|0);
      var $31=HEAP32[(($30)>>2)];
      var $32=$3;
      var $33=$2;
      var $34=(($33+20)|0);
      var $35=HEAP32[(($34)>>2)];
      var $36=(($35+($32<<2))|0);
      HEAP32[(($36)>>2)]=$31;
      var $37=$3;
      var $38=((($37)+(1))|0);
      $3=$38;
      __label__ = 5; break;
    case 7: 
      var $40=$2;
      var $41=(($40+16)|0);
      var $42=HEAP32[(($41)>>2)];
      var $43=((($42)-(1))|0);
      HEAP32[(($41)>>2)]=$43;
      var $44=$tmp;
      $1=$44;
      __label__ = 8; break;
    case 8: 
      var $46=$1;
      ;
      return $46;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_List_RemoveByIndex["X"]=1;

function _HPDF_List_ItemAt($list, $index) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      $1=$list;
      $2=$index;
      var $3=$1;
      var $4=(($3+16)|0);
      var $5=HEAPU32[(($4)>>2)];
      var $6=$2;
      var $7=(($5)>>>0) <= (($6)>>>0);
      if ($7) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $17 = 0;__label__ = 5; break;
    case 4: 
      var $10=$2;
      var $11=$1;
      var $12=(($11+20)|0);
      var $13=HEAP32[(($12)>>2)];
      var $14=(($13+($10<<2))|0);
      var $15=HEAP32[(($14)>>2)];
      var $17 = $15;__label__ = 5; break;
    case 5: 
      var $17;
      ;
      return $17;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Number_SetValue($obj, $value) {
  ;
  var __label__;

  var $1;
  var $2;
  $1=$obj;
  $2=$value;
  var $3=$2;
  var $4=$1;
  var $5=(($4+8)|0);
  HEAP32[(($5)>>2)]=$3;
  ;
  return;
}


function _HPDF_List_Remove($list, $item) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $i;
      var $obj;
      $2=$list;
      $3=$item;
      var $4=$2;
      var $5=(($4+20)|0);
      var $6=HEAP32[(($5)>>2)];
      $obj=$6;
      $i=0;
      __label__ = 3; break;
    case 3: 
      var $8=$i;
      var $9=$2;
      var $10=(($9+16)|0);
      var $11=HEAPU32[(($10)>>2)];
      var $12=(($8)>>>0) < (($11)>>>0);
      if ($12) { __label__ = 4; break; } else { __label__ = 9; break; }
    case 4: 
      var $14=$obj;
      var $15=HEAP32[(($14)>>2)];
      var $16=$3;
      var $17=(($15)|0)==(($16)|0);
      if ($17) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $19=$2;
      var $20=$i;
      var $21=_HPDF_List_RemoveByIndex($19, $20);
      $1=0;
      __label__ = 10; break;
    case 6: 
      var $23=$obj;
      var $24=(($23+4)|0);
      $obj=$24;
      __label__ = 7; break;
    case 7: 
      __label__ = 8; break;
    case 8: 
      var $27=$i;
      var $28=((($27)+(1))|0);
      $i=$28;
      __label__ = 3; break;
    case 9: 
      $1=4162;
      __label__ = 10; break;
    case 10: 
      var $31=$1;
      ;
      return $31;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_List_Free($list) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      $1=$list;
      var $2=$1;
      var $3=(($2)|0)!=0;
      if ($3) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      __label__ = 5; break;
    case 4: 
      var $6=$1;
      _HPDF_List_Clear($6);
      var $7=$1;
      var $8=(($7)|0);
      var $9=HEAP32[(($8)>>2)];
      var $10=$1;
      var $11=$10;
      _HPDF_FreeMem($9, $11);
      __label__ = 5; break;
    case 5: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_List_Clear($list) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      $1=$list;
      var $2=$1;
      var $3=(($2+20)|0);
      var $4=HEAP32[(($3)>>2)];
      var $5=(($4)|0)!=0;
      if ($5) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $7=$1;
      var $8=(($7)|0);
      var $9=HEAP32[(($8)>>2)];
      var $10=$1;
      var $11=(($10+20)|0);
      var $12=HEAP32[(($11)>>2)];
      var $13=$12;
      _HPDF_FreeMem($9, $13);
      __label__ = 4; break;
    case 4: 
      var $15=$1;
      var $16=(($15+8)|0);
      HEAP32[(($16)>>2)]=0;
      var $17=$1;
      var $18=(($17+16)|0);
      HEAP32[(($18)>>2)]=0;
      var $19=$1;
      var $20=(($19+20)|0);
      HEAP32[(($20)>>2)]=0;
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_MMgr_New($error, $buf_size, $alloc_fn, $free_fn) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $mmgr;
      var $node;
      $1=$error;
      $2=$buf_size;
      $3=$alloc_fn;
      $4=$free_fn;
      var $5=$3;
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $8=$3;
      var $9=FUNCTION_TABLE[$8](20);
      var $10=$9;
      $mmgr=$10;
      __label__ = 5; break;
    case 4: 
      var $12=_InternalGetMem(20);
      var $13=$12;
      $mmgr=$13;
      __label__ = 5; break;
    case 5: 
      var $15=$mmgr;
      var $16=(($15)|0)!=0;
      if ($16) { __label__ = 6; break; } else { __label__ = 19; break; }
    case 6: 
      var $18=$1;
      var $19=$mmgr;
      var $20=(($19)|0);
      HEAP32[(($20)>>2)]=$18;
      var $21=$3;
      var $22=(($21)|0)!=0;
      if ($22) { __label__ = 7; break; } else { __label__ = 9; break; }
    case 7: 
      var $24=$4;
      var $25=(($24)|0)!=0;
      if ($25) { __label__ = 8; break; } else { __label__ = 9; break; }
    case 8: 
      var $27=$3;
      var $28=$mmgr;
      var $29=(($28+4)|0);
      HEAP32[(($29)>>2)]=$27;
      var $30=$4;
      var $31=$mmgr;
      var $32=(($31+8)|0);
      HEAP32[(($32)>>2)]=$30;
      __label__ = 10; break;
    case 9: 
      var $34=$mmgr;
      var $35=(($34+4)|0);
      HEAP32[(($35)>>2)]=220;
      var $36=$mmgr;
      var $37=(($36+8)|0);
      HEAP32[(($37)>>2)]=222;
      __label__ = 10; break;
    case 10: 
      var $39=$2;
      var $40=(($39)|0)!=0;
      if ($40) { __label__ = 12; break; } else { __label__ = 11; break; }
    case 11: 
      var $42=$mmgr;
      var $43=(($42+12)|0);
      HEAP32[(($43)>>2)]=0;
      __label__ = 16; break;
    case 12: 
      var $45=$mmgr;
      var $46=(($45+4)|0);
      var $47=HEAP32[(($46)>>2)];
      var $48=$2;
      var $49=((($48)+(16))|0);
      var $50=FUNCTION_TABLE[$47]($49);
      var $51=$50;
      $node=$51;
      var $52=$node;
      var $53=(($52)|0)==0;
      if ($53) { __label__ = 13; break; } else { __label__ = 14; break; }
    case 13: 
      var $55=$1;
      var $56=_HPDF_SetError($55, 4117, 0);
      var $57=$mmgr;
      var $58=(($57+8)|0);
      var $59=HEAP32[(($58)>>2)];
      var $60=$mmgr;
      var $61=$60;
      FUNCTION_TABLE[$59]($61);
      $mmgr=0;
      __label__ = 15; break;
    case 14: 
      var $63=$node;
      var $64=$mmgr;
      var $65=(($64+12)|0);
      HEAP32[(($65)>>2)]=$63;
      var $66=$node;
      var $67=$66;
      var $68=(($67+16)|0);
      var $69=$node;
      var $70=(($69)|0);
      HEAP32[(($70)>>2)]=$68;
      var $71=$2;
      var $72=$node;
      var $73=(($72+4)|0);
      HEAP32[(($73)>>2)]=$71;
      var $74=$node;
      var $75=(($74+8)|0);
      HEAP32[(($75)>>2)]=0;
      var $76=$node;
      var $77=(($76+12)|0);
      HEAP32[(($77)>>2)]=0;
      __label__ = 15; break;
    case 15: 
      __label__ = 16; break;
    case 16: 
      var $80=$mmgr;
      var $81=(($80)|0)!=0;
      if ($81) { __label__ = 17; break; } else { __label__ = 18; break; }
    case 17: 
      var $83=$2;
      var $84=$mmgr;
      var $85=(($84+16)|0);
      HEAP32[(($85)>>2)]=$83;
      __label__ = 18; break;
    case 18: 
      __label__ = 20; break;
    case 19: 
      var $88=$1;
      var $89=_HPDF_SetError($88, 4117, 0);
      __label__ = 20; break;
    case 20: 
      var $91=$mmgr;
      ;
      return $91;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_MMgr_New["X"]=1;

function _InternalGetMem($size) {
  ;
  var __label__;

  var $1;
  $1=$size;
  var $2=$1;
  var $3=_malloc($2);
  ;
  return $3;
}


function _InternalFreeMem($aptr) {
  ;
  var __label__;

  var $1;
  $1=$aptr;
  var $2=$1;
  _free($2);
  ;
  return;
}


function _HPDF_MMgr_Free($mmgr) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $node;
      var $tmp;
      $1=$mmgr;
      var $2=$1;
      var $3=(($2)|0)==0;
      if ($3) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      __label__ = 8; break;
    case 4: 
      var $6=$1;
      var $7=(($6+12)|0);
      var $8=HEAP32[(($7)>>2)];
      $node=$8;
      __label__ = 5; break;
    case 5: 
      var $10=$node;
      var $11=(($10)|0)!=0;
      if ($11) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      var $13=$node;
      $tmp=$13;
      var $14=$tmp;
      var $15=(($14+12)|0);
      var $16=HEAP32[(($15)>>2)];
      $node=$16;
      var $17=$1;
      var $18=(($17+8)|0);
      var $19=HEAP32[(($18)>>2)];
      var $20=$tmp;
      var $21=$20;
      FUNCTION_TABLE[$19]($21);
      __label__ = 5; break;
    case 7: 
      var $23=$1;
      var $24=(($23+8)|0);
      var $25=HEAP32[(($24)>>2)];
      var $26=$1;
      var $27=$26;
      FUNCTION_TABLE[$25]($27);
      __label__ = 8; break;
    case 8: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_GetMem($mmgr, $size) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $ptr;
      var $node;
      var $tmp_buf_siz;
      $2=$mmgr;
      $3=$size;
      var $4=$2;
      var $5=(($4+12)|0);
      var $6=HEAP32[(($5)>>2)];
      var $7=(($6)|0)!=0;
      if ($7) { __label__ = 3; break; } else { __label__ = 12; break; }
    case 3: 
      var $9=$2;
      var $10=(($9+12)|0);
      var $11=HEAP32[(($10)>>2)];
      $node=$11;
      var $12=$node;
      var $13=(($12+4)|0);
      var $14=HEAP32[(($13)>>2)];
      var $15=$node;
      var $16=(($15+8)|0);
      var $17=HEAP32[(($16)>>2)];
      var $18=((($14)-($17))|0);
      var $19=$3;
      var $20=(($18)>>>0) >= (($19)>>>0);
      if ($20) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      var $22=$node;
      var $23=(($22)|0);
      var $24=HEAP32[(($23)>>2)];
      var $25=$node;
      var $26=(($25+8)|0);
      var $27=HEAP32[(($26)>>2)];
      var $28=(($24+$27)|0);
      $ptr=$28;
      var $29=$3;
      var $30=$node;
      var $31=(($30+8)|0);
      var $32=HEAP32[(($31)>>2)];
      var $33=((($32)+($29))|0);
      HEAP32[(($31)>>2)]=$33;
      var $34=$ptr;
      $1=$34;
      __label__ = 16; break;
    case 5: 
      var $36=$2;
      var $37=(($36+16)|0);
      var $38=HEAPU32[(($37)>>2)];
      var $39=$3;
      var $40=(($38)>>>0) < (($39)>>>0);
      if ($40) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      var $42=$3;
      var $48 = $42;__label__ = 8; break;
    case 7: 
      var $44=$2;
      var $45=(($44+16)|0);
      var $46=HEAP32[(($45)>>2)];
      var $48 = $46;__label__ = 8; break;
    case 8: 
      var $48;
      $tmp_buf_siz=$48;
      var $49=$2;
      var $50=(($49+4)|0);
      var $51=HEAP32[(($50)>>2)];
      var $52=$tmp_buf_siz;
      var $53=((($52)+(16))|0);
      var $54=FUNCTION_TABLE[$51]($53);
      var $55=$54;
      $node=$55;
      var $56=$node;
      var $57=(($56)|0)!=0;
      if ($57) { __label__ = 10; break; } else { __label__ = 9; break; }
    case 9: 
      var $59=$2;
      var $60=(($59)|0);
      var $61=HEAP32[(($60)>>2)];
      var $62=_HPDF_SetError($61, 4117, 0);
      $1=0;
      __label__ = 16; break;
    case 10: 
      var $64=$tmp_buf_siz;
      var $65=$node;
      var $66=(($65+4)|0);
      HEAP32[(($66)>>2)]=$64;
      __label__ = 11; break;
    case 11: 
      var $68=$2;
      var $69=(($68+12)|0);
      var $70=HEAP32[(($69)>>2)];
      var $71=$node;
      var $72=(($71+12)|0);
      HEAP32[(($72)>>2)]=$70;
      var $73=$node;
      var $74=$2;
      var $75=(($74+12)|0);
      HEAP32[(($75)>>2)]=$73;
      var $76=$3;
      var $77=$node;
      var $78=(($77+8)|0);
      HEAP32[(($78)>>2)]=$76;
      var $79=$node;
      var $80=$79;
      var $81=(($80+16)|0);
      var $82=$node;
      var $83=(($82)|0);
      HEAP32[(($83)>>2)]=$81;
      var $84=$node;
      var $85=(($84)|0);
      var $86=HEAP32[(($85)>>2)];
      $ptr=$86;
      __label__ = 15; break;
    case 12: 
      var $88=$2;
      var $89=(($88+4)|0);
      var $90=HEAP32[(($89)>>2)];
      var $91=$3;
      var $92=FUNCTION_TABLE[$90]($91);
      $ptr=$92;
      var $93=$ptr;
      var $94=(($93)|0)==0;
      if ($94) { __label__ = 13; break; } else { __label__ = 14; break; }
    case 13: 
      var $96=$2;
      var $97=(($96)|0);
      var $98=HEAP32[(($97)>>2)];
      var $99=_HPDF_SetError($98, 4117, 0);
      __label__ = 14; break;
    case 14: 
      __label__ = 15; break;
    case 15: 
      var $102=$ptr;
      $1=$102;
      __label__ = 16; break;
    case 16: 
      var $104=$1;
      ;
      return $104;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_GetMem["X"]=1;

function _HPDF_FreeMem($mmgr, $aptr) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      $1=$mmgr;
      $2=$aptr;
      var $3=$2;
      var $4=(($3)|0)!=0;
      if ($4) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      __label__ = 7; break;
    case 4: 
      var $7=$1;
      var $8=(($7+12)|0);
      var $9=HEAP32[(($8)>>2)];
      var $10=(($9)|0)!=0;
      if ($10) { __label__ = 6; break; } else { __label__ = 5; break; }
    case 5: 
      var $12=$1;
      var $13=(($12+8)|0);
      var $14=HEAP32[(($13)>>2)];
      var $15=$2;
      FUNCTION_TABLE[$14]($15);
      __label__ = 6; break;
    case 6: 
      __label__ = 7; break;
    case 7: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Name_New($mmgr, $value) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $obj;
      $2=$mmgr;
      $3=$value;
      var $4=$2;
      var $5=_HPDF_GetMem($4, 140);
      var $6=$5;
      $obj=$6;
      var $7=$obj;
      var $8=(($7)|0)!=0;
      if ($8) { __label__ = 3; break; } else { __label__ = 6; break; }
    case 3: 
      var $10=$obj;
      var $11=(($10)|0);
      var $12=$11;
      var $13=_HPDF_MemSet($12, 0, 8);
      var $14=$obj;
      var $15=(($14)|0);
      var $16=(($15+6)|0);
      HEAP16[(($16)>>1)]=6;
      var $17=$2;
      var $18=(($17)|0);
      var $19=HEAP32[(($18)>>2)];
      var $20=$obj;
      var $21=(($20+8)|0);
      HEAP32[(($21)>>2)]=$19;
      var $22=$obj;
      var $23=$3;
      var $24=_HPDF_Name_SetValue($22, $23);
      var $25=(($24)|0)==4164;
      if ($25) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      var $27=$2;
      var $28=$obj;
      var $29=$28;
      _HPDF_FreeMem($27, $29);
      $1=0;
      __label__ = 7; break;
    case 5: 
      __label__ = 6; break;
    case 6: 
      var $32=$obj;
      $1=$32;
      __label__ = 7; break;
    case 7: 
      var $34=$1;
      ;
      return $34;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Name_SetValue($obj, $value) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      $2=$obj;
      $3=$value;
      var $4=$3;
      var $5=(($4)|0)!=0;
      if ($5) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $7=$3;
      var $8=(($7)|0);
      var $9=HEAP8[($8)];
      var $10=(($9 << 24) >> 24);
      var $11=(($10)|0)==0;
      if ($11) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      var $13=$2;
      var $14=(($13+8)|0);
      var $15=HEAP32[(($14)>>2)];
      var $16=_HPDF_SetError($15, 4164, 0);
      $1=$16;
      __label__ = 8; break;
    case 5: 
      var $18=$3;
      var $19=_HPDF_StrLen($18, 128);
      var $20=(($19)>>>0) > 127;
      if ($20) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      var $22=$2;
      var $23=(($22+8)|0);
      var $24=HEAP32[(($23)>>2)];
      var $25=_HPDF_SetError($24, 4165, 0);
      $1=$25;
      __label__ = 8; break;
    case 7: 
      var $27=$2;
      var $28=(($27+12)|0);
      var $29=(($28)|0);
      var $30=$3;
      var $31=$2;
      var $32=(($31+12)|0);
      var $33=(($32)|0);
      var $34=(($33+127)|0);
      var $35=_HPDF_StrCpy($29, $30, $34);
      $1=0;
      __label__ = 8; break;
    case 8: 
      var $37=$1;
      ;
      return $37;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Name_Write($obj, $stream) {
  ;
  var __label__;

  var $1;
  var $2;
  $1=$obj;
  $2=$stream;
  var $3=$2;
  var $4=$1;
  var $5=(($4+12)|0);
  var $6=(($5)|0);
  var $7=_HPDF_Stream_WriteEscapeName($3, $6);
  ;
  return $7;
}


function _HPDF_Number_New($mmgr, $value) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $obj;
      $1=$mmgr;
      $2=$value;
      var $3=$1;
      var $4=_HPDF_GetMem($3, 12);
      var $5=$4;
      $obj=$5;
      var $6=$obj;
      var $7=(($6)|0)!=0;
      if ($7) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $9=$obj;
      var $10=(($9)|0);
      var $11=$10;
      var $12=_HPDF_MemSet($11, 0, 8);
      var $13=$obj;
      var $14=(($13)|0);
      var $15=(($14+6)|0);
      HEAP16[(($15)>>1)]=4;
      var $16=$2;
      var $17=$obj;
      var $18=(($17+8)|0);
      HEAP32[(($18)>>2)]=$16;
      __label__ = 4; break;
    case 4: 
      var $20=$obj;
      ;
      return $20;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Number_Write($obj, $stream) {
  ;
  var __label__;

  var $1;
  var $2;
  $1=$obj;
  $2=$stream;
  var $3=$2;
  var $4=$1;
  var $5=(($4+8)|0);
  var $6=HEAP32[(($5)>>2)];
  var $7=_HPDF_Stream_WriteInt($3, $6);
  ;
  return $7;
}


function _HPDF_Obj_Free($mmgr, $obj) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $header;
      $1=$mmgr;
      $2=$obj;
      var $3=$2;
      var $4=(($3)|0)!=0;
      if ($4) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      __label__ = 6; break;
    case 4: 
      var $7=$2;
      var $8=$7;
      $header=$8;
      var $9=$header;
      var $10=(($9)|0);
      var $11=HEAP32[(($10)>>2)];
      var $12=$11 & 1073741824;
      var $13=(($12)|0)!=0;
      if ($13) { __label__ = 6; break; } else { __label__ = 5; break; }
    case 5: 
      var $15=$1;
      var $16=$2;
      _HPDF_Obj_ForceFree($15, $16);
      __label__ = 6; break;
    case 6: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Obj_ForceFree($mmgr, $obj) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $header;
      $1=$mmgr;
      $2=$obj;
      var $3=$2;
      var $4=(($3)|0)!=0;
      if ($4) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      __label__ = 10; break;
    case 4: 
      var $7=$2;
      var $8=$7;
      $header=$8;
      var $9=$header;
      var $10=(($9+6)|0);
      var $11=HEAPU16[(($10)>>1)];
      var $12=(($11)&65535);
      var $13=$12 & 255;
      if ((($13)|0) == 7) {
        __label__ = 5; break;
      }
      else if ((($13)|0) == 8) {
        __label__ = 6; break;
      }
      else if ((($13)|0) == 16) {
        __label__ = 7; break;
      }
      else if ((($13)|0) == 17) {
        __label__ = 8; break;
      }
      else {
      __label__ = 9; break;
      }
      
    case 5: 
      var $15=$2;
      var $16=$15;
      _HPDF_String_Free($16);
      __label__ = 10; break;
    case 6: 
      var $18=$2;
      var $19=$18;
      _HPDF_Binary_Free($19);
      __label__ = 10; break;
    case 7: 
      var $21=$2;
      var $22=$21;
      _HPDF_Array_Free($22);
      __label__ = 10; break;
    case 8: 
      var $24=$2;
      var $25=$24;
      _HPDF_Dict_Free($25);
      __label__ = 10; break;
    case 9: 
      var $27=$1;
      var $28=$2;
      _HPDF_FreeMem($27, $28);
      __label__ = 10; break;
    case 10: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Outline_Validate($outline) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      $2=$outline;
      var $3=$2;
      var $4=(($3)|0)!=0;
      if ($4) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=0;
      __label__ = 7; break;
    case 4: 
      var $7=$2;
      var $8=(($7)|0);
      var $9=(($8+6)|0);
      var $10=HEAPU16[(($9)>>1)];
      var $11=(($10)&65535);
      var $12=(($11)|0)!=1553;
      if ($12) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      $1=0;
      __label__ = 7; break;
    case 6: 
      $1=1;
      __label__ = 7; break;
    case 7: 
      var $16=$1;
      ;
      return $16;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Obj_Write($obj, $stream, $e) {
  var __stackBase__  = STACKTOP; STACKTOP += 32; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $header;
      var $buf=__stackBase__;
      var $pbuf;
      var $eptr;
      var $p;
      $2=$obj;
      $3=$stream;
      $4=$e;
      var $5=$2;
      var $6=$5;
      $header=$6;
      var $7=$header;
      var $8=(($7)|0);
      var $9=HEAP32[(($8)>>2)];
      var $10=$9 & 268435456;
      var $11=(($10)|0)!=0;
      if ($11) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      $1=0;
      __label__ = 7; break;
    case 4: 
      var $14=$header;
      var $15=(($14+6)|0);
      var $16=HEAPU16[(($15)>>1)];
      var $17=(($16)&65535);
      var $18=(($17)|0)==18;
      if ($18) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $20=(($buf)|0);
      $pbuf=$20;
      var $21=(($buf)|0);
      var $22=(($21+32)|0);
      var $23=((($22)-(1))|0);
      $eptr=$23;
      var $24=$2;
      var $25=$24;
      $p=$25;
      var $26=$p;
      var $27=(($26+8)|0);
      var $28=HEAP32[(($27)>>2)];
      var $29=$28;
      $header=$29;
      var $30=$pbuf;
      var $31=$header;
      var $32=(($31)|0);
      var $33=HEAP32[(($32)>>2)];
      var $34=$33 & 16777215;
      var $35=$eptr;
      var $36=_HPDF_IToA($30, $34, $35);
      $pbuf=$36;
      var $37=$pbuf;
      var $38=(($37+1)|0);
      $pbuf=$38;
      HEAP8[($37)]=32;
      var $39=$pbuf;
      var $40=$header;
      var $41=(($40+4)|0);
      var $42=HEAPU16[(($41)>>1)];
      var $43=(($42)&65535);
      var $44=$eptr;
      var $45=_HPDF_IToA($39, $43, $44);
      $pbuf=$45;
      var $46=$pbuf;
      var $47=$eptr;
      var $48=_HPDF_StrCpy($46, ((STRING_TABLE.__str1512)|0), $47);
      var $49=$3;
      var $50=(($buf)|0);
      var $51=_HPDF_Stream_WriteStr($49, $50);
      $1=$51;
      __label__ = 7; break;
    case 6: 
      var $53=$2;
      var $54=$3;
      var $55=$4;
      var $56=_HPDF_Obj_WriteValue($53, $54, $55);
      $1=$56;
      __label__ = 7; break;
    case 7: 
      var $58=$1;
      STACKTOP = __stackBase__;
      return $58;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Obj_Write["X"]=1;

function _HPDF_Obj_WriteValue($obj, $stream, $e) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $header;
      var $ret;
      $1=$obj;
      $2=$stream;
      $3=$e;
      var $4=$1;
      var $5=$4;
      $header=$5;
      var $6=$header;
      var $7=(($6+6)|0);
      var $8=HEAPU16[(($7)>>1)];
      var $9=(($8)&65535);
      var $10=$9 & 255;
      if ((($10)|0) == 6) {
        __label__ = 3; break;
      }
      else if ((($10)|0) == 4) {
        __label__ = 4; break;
      }
      else if ((($10)|0) == 5) {
        __label__ = 5; break;
      }
      else if ((($10)|0) == 7) {
        __label__ = 6; break;
      }
      else if ((($10)|0) == 8) {
        __label__ = 7; break;
      }
      else if ((($10)|0) == 16) {
        __label__ = 8; break;
      }
      else if ((($10)|0) == 17) {
        __label__ = 9; break;
      }
      else if ((($10)|0) == 3) {
        __label__ = 10; break;
      }
      else if ((($10)|0) == 2) {
        __label__ = 11; break;
      }
      else {
      __label__ = 12; break;
      }
      
    case 3: 
      var $12=$1;
      var $13=$12;
      var $14=$2;
      var $15=_HPDF_Name_Write($13, $14);
      $ret=$15;
      __label__ = 13; break;
    case 4: 
      var $17=$1;
      var $18=$17;
      var $19=$2;
      var $20=_HPDF_Number_Write($18, $19);
      $ret=$20;
      __label__ = 13; break;
    case 5: 
      var $22=$1;
      var $23=$22;
      var $24=$2;
      var $25=_HPDF_Real_Write($23, $24);
      $ret=$25;
      __label__ = 13; break;
    case 6: 
      var $27=$1;
      var $28=$27;
      var $29=$2;
      var $30=$3;
      var $31=_HPDF_String_Write($28, $29, $30);
      $ret=$31;
      __label__ = 13; break;
    case 7: 
      var $33=$1;
      var $34=$33;
      var $35=$2;
      var $36=$3;
      var $37=_HPDF_Binary_Write($34, $35, $36);
      $ret=$37;
      __label__ = 13; break;
    case 8: 
      var $39=$1;
      var $40=$39;
      var $41=$2;
      var $42=$3;
      var $43=_HPDF_Array_Write($40, $41, $42);
      $ret=$43;
      __label__ = 13; break;
    case 9: 
      var $45=$1;
      var $46=$45;
      var $47=$2;
      var $48=$3;
      var $49=_HPDF_Dict_Write($46, $47, $48);
      $ret=$49;
      __label__ = 13; break;
    case 10: 
      var $51=$1;
      var $52=$51;
      var $53=$2;
      var $54=_HPDF_Boolean_Write($52, $53);
      $ret=$54;
      __label__ = 13; break;
    case 11: 
      var $56=$2;
      var $57=_HPDF_Stream_WriteStr($56, ((STRING_TABLE.__str11513)|0));
      $ret=$57;
      __label__ = 13; break;
    case 12: 
      $ret=4115;
      __label__ = 13; break;
    case 13: 
      var $60=$ret;
      ;
      return $60;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Obj_WriteValue["X"]=1;

function _HPDF_Proxy_New($mmgr, $obj) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $p;
      $1=$mmgr;
      $2=$obj;
      var $3=$1;
      var $4=_HPDF_GetMem($3, 12);
      var $5=$4;
      $p=$5;
      var $6=$p;
      var $7=(($6)|0)!=0;
      if ($7) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $9=$p;
      var $10=(($9)|0);
      var $11=$10;
      var $12=_HPDF_MemSet($11, 0, 8);
      var $13=$p;
      var $14=(($13)|0);
      var $15=(($14+6)|0);
      HEAP16[(($15)>>1)]=18;
      var $16=$2;
      var $17=$p;
      var $18=(($17+8)|0);
      HEAP32[(($18)>>2)]=$16;
      __label__ = 4; break;
    case 4: 
      var $20=$p;
      ;
      return $20;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_OutlineRoot_New($mmgr, $xref) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $outline;
      var $ret;
      var $open_flg;
      $2=$mmgr;
      $3=$xref;
      $ret=0;
      var $4=$2;
      var $5=_HPDF_Dict_New($4);
      $outline=$5;
      var $6=$outline;
      var $7=(($6)|0)!=0;
      if ($7) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=0;
      __label__ = 11; break;
    case 4: 
      var $10=$outline;
      var $11=(($10+20)|0);
      HEAP32[(($11)>>2)]=224;
      var $12=$3;
      var $13=$outline;
      var $14=$13;
      var $15=_HPDF_Xref_Add($12, $14);
      var $16=(($15)|0)!=0;
      if ($16) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      $1=0;
      __label__ = 11; break;
    case 6: 
      var $19=$2;
      var $20=_HPDF_Number_New($19, 1);
      $open_flg=$20;
      var $21=$open_flg;
      var $22=(($21)|0)!=0;
      if ($22) { __label__ = 8; break; } else { __label__ = 7; break; }
    case 7: 
      $1=0;
      __label__ = 11; break;
    case 8: 
      var $25=$open_flg;
      var $26=(($25)|0);
      var $27=(($26)|0);
      var $28=HEAP32[(($27)>>2)];
      var $29=$28 | 268435456;
      HEAP32[(($27)>>2)]=$29;
      var $30=$outline;
      var $31=$open_flg;
      var $32=$31;
      var $33=_HPDF_Dict_Add($30, ((STRING_TABLE.__str1520)|0), $32);
      var $34=$ret;
      var $35=((($34)+($33))|0);
      $ret=$35;
      var $36=$outline;
      var $37=_HPDF_Dict_AddName($36, ((STRING_TABLE.__str11522)|0), ((STRING_TABLE.__str21523)|0));
      var $38=$ret;
      var $39=((($38)+($37))|0);
      $ret=$39;
      var $40=$ret;
      var $41=(($40)|0)!=0;
      if ($41) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      $1=0;
      __label__ = 11; break;
    case 10: 
      var $44=$outline;
      var $45=(($44)|0);
      var $46=(($45+6)|0);
      var $47=HEAPU16[(($46)>>1)];
      var $48=(($47)&65535);
      var $49=$48 | 1536;
      var $50=(($49) & 65535);
      HEAP16[(($46)>>1)]=$50;
      var $51=$outline;
      $1=$51;
      __label__ = 11; break;
    case 11: 
      var $53=$1;
      ;
      return $53;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_OutlineRoot_New["X"]=1;

function _BeforeWrite1535($obj) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $n;
      var $count;
      $2=$obj;
      var $3=$2;
      var $4=_HPDF_Dict_GetItem($3, ((STRING_TABLE.__str101531)|0), 4);
      var $5=$4;
      $n=$5;
      var $6=$2;
      var $7=_CountChild($6);
      $count=$7;
      var $8=$count;
      var $9=(($8)|0)==0;
      if ($9) { __label__ = 3; break; } else { __label__ = 5; break; }
    case 3: 
      var $11=$n;
      var $12=(($11)|0)!=0;
      if ($12) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      var $14=$2;
      var $15=_HPDF_Dict_RemoveElement($14, ((STRING_TABLE.__str101531)|0));
      $1=$15;
      __label__ = 13; break;
    case 5: 
      var $17=$2;
      var $18=_HPDF_Outline_GetOpened($17);
      var $19=(($18)|0)!=0;
      if ($19) { __label__ = 7; break; } else { __label__ = 6; break; }
    case 6: 
      var $21=$count;
      var $22=((($21)*(-1))|0);
      $count=$22;
      __label__ = 7; break;
    case 7: 
      var $24=$n;
      var $25=(($24)|0)!=0;
      if ($25) { __label__ = 8; break; } else { __label__ = 9; break; }
    case 8: 
      var $27=$count;
      var $28=$n;
      var $29=(($28+8)|0);
      HEAP32[(($29)>>2)]=$27;
      __label__ = 12; break;
    case 9: 
      var $31=$count;
      var $32=(($31)|0)!=0;
      if ($32) { __label__ = 10; break; } else { __label__ = 11; break; }
    case 10: 
      var $34=$2;
      var $35=$count;
      var $36=_HPDF_Dict_AddNumber($34, ((STRING_TABLE.__str101531)|0), $35);
      $1=$36;
      __label__ = 13; break;
    case 11: 
      __label__ = 12; break;
    case 12: 
      $1=0;
      __label__ = 13; break;
    case 13: 
      var $40=$1;
      ;
      return $40;
    default: assert(0, "bad label: " + __label__);
  }
}
_BeforeWrite1535["X"]=1;

function _HPDF_Outline_New($mmgr, $parent, $title, $encoder, $xref) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $5;
      var $6;
      var $outline;
      var $s;
      var $ret;
      var $open_flg;
      $2=$mmgr;
      $3=$parent;
      $4=$title;
      $5=$encoder;
      $6=$xref;
      $ret=0;
      var $7=$2;
      var $8=(($7)|0)!=0;
      if ($8) { __label__ = 3; break; } else { __label__ = 5; break; }
    case 3: 
      var $10=$3;
      var $11=(($10)|0)!=0;
      if ($11) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      var $13=$6;
      var $14=(($13)|0)!=0;
      if ($14) { __label__ = 6; break; } else { __label__ = 5; break; }
    case 5: 
      $1=0;
      __label__ = 18; break;
    case 6: 
      var $17=$2;
      var $18=_HPDF_Dict_New($17);
      $outline=$18;
      var $19=$outline;
      var $20=(($19)|0)!=0;
      if ($20) { __label__ = 8; break; } else { __label__ = 7; break; }
    case 7: 
      $1=0;
      __label__ = 18; break;
    case 8: 
      var $23=$outline;
      var $24=(($23+20)|0);
      HEAP32[(($24)>>2)]=224;
      var $25=$6;
      var $26=$outline;
      var $27=$26;
      var $28=_HPDF_Xref_Add($25, $27);
      var $29=(($28)|0)!=0;
      if ($29) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      $1=0;
      __label__ = 18; break;
    case 10: 
      var $32=$2;
      var $33=$4;
      var $34=$5;
      var $35=_HPDF_String_New($32, $33, $34);
      $s=$35;
      var $36=$s;
      var $37=(($36)|0)!=0;
      if ($37) { __label__ = 12; break; } else { __label__ = 11; break; }
    case 11: 
      $1=0;
      __label__ = 18; break;
    case 12: 
      var $40=$outline;
      var $41=$s;
      var $42=$41;
      var $43=_HPDF_Dict_Add($40, ((STRING_TABLE.__str31524)|0), $42);
      var $44=$ret;
      var $45=((($44)+($43))|0);
      $ret=$45;
      __label__ = 13; break;
    case 13: 
      var $47=$2;
      var $48=_HPDF_Number_New($47, 1);
      $open_flg=$48;
      var $49=$open_flg;
      var $50=(($49)|0)!=0;
      if ($50) { __label__ = 15; break; } else { __label__ = 14; break; }
    case 14: 
      $1=0;
      __label__ = 18; break;
    case 15: 
      var $53=$open_flg;
      var $54=(($53)|0);
      var $55=(($54)|0);
      var $56=HEAP32[(($55)>>2)];
      var $57=$56 | 268435456;
      HEAP32[(($55)>>2)]=$57;
      var $58=$outline;
      var $59=$open_flg;
      var $60=$59;
      var $61=_HPDF_Dict_Add($58, ((STRING_TABLE.__str1520)|0), $60);
      var $62=$ret;
      var $63=((($62)+($61))|0);
      $ret=$63;
      var $64=$outline;
      var $65=_HPDF_Dict_AddName($64, ((STRING_TABLE.__str11522)|0), ((STRING_TABLE.__str21523)|0));
      var $66=$ret;
      var $67=((($66)+($65))|0);
      $ret=$67;
      var $68=$3;
      var $69=$outline;
      var $70=_AddChild($68, $69);
      var $71=$ret;
      var $72=((($71)+($70))|0);
      $ret=$72;
      var $73=$ret;
      var $74=(($73)|0)!=0;
      if ($74) { __label__ = 16; break; } else { __label__ = 17; break; }
    case 16: 
      $1=0;
      __label__ = 18; break;
    case 17: 
      var $77=$outline;
      var $78=(($77)|0);
      var $79=(($78+6)|0);
      var $80=HEAPU16[(($79)>>1)];
      var $81=(($80)&65535);
      var $82=$81 | 1536;
      var $83=(($82) & 65535);
      HEAP16[(($79)>>1)]=$83;
      var $84=$outline;
      $1=$84;
      __label__ = 18; break;
    case 18: 
      var $86=$1;
      ;
      return $86;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Outline_New["X"]=1;

function _AddChild($parent, $item) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $first;
      var $last;
      var $ret;
      $2=$parent;
      $3=$item;
      var $4=$2;
      var $5=_HPDF_Dict_GetItem($4, ((STRING_TABLE.__str41525)|0), 17);
      var $6=$5;
      $first=$6;
      var $7=$2;
      var $8=_HPDF_Dict_GetItem($7, ((STRING_TABLE.__str51526)|0), 17);
      var $9=$8;
      $last=$9;
      $ret=0;
      var $10=$first;
      var $11=(($10)|0)!=0;
      if ($11) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      var $13=$2;
      var $14=$3;
      var $15=$14;
      var $16=_HPDF_Dict_Add($13, ((STRING_TABLE.__str41525)|0), $15);
      var $17=$ret;
      var $18=((($17)+($16))|0);
      $ret=$18;
      __label__ = 4; break;
    case 4: 
      var $20=$last;
      var $21=(($20)|0)!=0;
      if ($21) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $23=$last;
      var $24=$3;
      var $25=$24;
      var $26=_HPDF_Dict_Add($23, ((STRING_TABLE.__str71528)|0), $25);
      var $27=$ret;
      var $28=((($27)+($26))|0);
      $ret=$28;
      var $29=$3;
      var $30=$last;
      var $31=$30;
      var $32=_HPDF_Dict_Add($29, ((STRING_TABLE.__str61527)|0), $31);
      var $33=$ret;
      var $34=((($33)+($32))|0);
      $ret=$34;
      __label__ = 6; break;
    case 6: 
      var $36=$2;
      var $37=$3;
      var $38=$37;
      var $39=_HPDF_Dict_Add($36, ((STRING_TABLE.__str51526)|0), $38);
      var $40=$ret;
      var $41=((($40)+($39))|0);
      $ret=$41;
      var $42=$3;
      var $43=$2;
      var $44=$43;
      var $45=_HPDF_Dict_Add($42, ((STRING_TABLE.__str81529)|0), $44);
      var $46=$ret;
      var $47=((($46)+($45))|0);
      $ret=$47;
      var $48=$ret;
      var $49=(($48)|0)!=0;
      if ($49) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $51=$3;
      var $52=(($51+12)|0);
      var $53=HEAP32[(($52)>>2)];
      var $54=_HPDF_Error_GetCode($53);
      $1=$54;
      __label__ = 9; break;
    case 8: 
      $1=0;
      __label__ = 9; break;
    case 9: 
      var $57=$1;
      ;
      return $57;
    default: assert(0, "bad label: " + __label__);
  }
}
_AddChild["X"]=1;

function _HPDF_Outline_GetOpened($outline) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $n;
      $2=$outline;
      var $3=$2;
      var $4=_HPDF_Dict_GetItem($3, ((STRING_TABLE.__str1520)|0), 4);
      var $5=$4;
      $n=$5;
      var $6=$n;
      var $7=(($6)|0)!=0;
      if ($7) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=0;
      __label__ = 5; break;
    case 4: 
      var $10=$n;
      var $11=(($10+8)|0);
      var $12=HEAP32[(($11)>>2)];
      $1=$12;
      __label__ = 5; break;
    case 5: 
      var $14=$1;
      ;
      return $14;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Outline_GetFirst($outline) {
  ;
  var __label__;

  var $1;
  $1=$outline;
  var $2=$1;
  var $3=_HPDF_Dict_GetItem($2, ((STRING_TABLE.__str41525)|0), 17);
  var $4=$3;
  ;
  return $4;
}


function _HPDF_Outline_GetNext($outline) {
  ;
  var __label__;

  var $1;
  $1=$outline;
  var $2=$1;
  var $3=_HPDF_Dict_GetItem($2, ((STRING_TABLE.__str71528)|0), 17);
  var $4=$3;
  ;
  return $4;
}


function _HPDF_Outline_SetDestination($outline, $dst) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      $2=$outline;
      $3=$dst;
      var $4=$2;
      var $5=_HPDF_Outline_Validate($4);
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=4150;
      __label__ = 11; break;
    case 4: 
      var $9=$3;
      var $10=_HPDF_Destination_Validate($9);
      var $11=(($10)|0)!=0;
      if ($11) { __label__ = 6; break; } else { __label__ = 5; break; }
    case 5: 
      var $13=$2;
      var $14=(($13+12)|0);
      var $15=HEAP32[(($14)>>2)];
      var $16=_HPDF_RaiseError($15, 4131, 0);
      $1=$16;
      __label__ = 11; break;
    case 6: 
      var $18=$3;
      var $19=(($18)|0)==0;
      if ($19) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $21=$2;
      var $22=_HPDF_Dict_RemoveElement($21, ((STRING_TABLE.__str91530)|0));
      $1=$22;
      __label__ = 11; break;
    case 8: 
      var $24=$2;
      var $25=$3;
      var $26=$25;
      var $27=_HPDF_Dict_Add($24, ((STRING_TABLE.__str91530)|0), $26);
      var $28=(($27)|0)!=0;
      if ($28) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      var $30=$2;
      var $31=(($30+12)|0);
      var $32=HEAP32[(($31)>>2)];
      var $33=_HPDF_CheckError($32);
      $1=$33;
      __label__ = 11; break;
    case 10: 
      $1=0;
      __label__ = 11; break;
    case 11: 
      var $36=$1;
      ;
      return $36;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Outline_SetOpened($outline, $opened) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $n;
      $2=$outline;
      $3=$opened;
      var $4=$2;
      var $5=_HPDF_Outline_Validate($4);
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=4150;
      __label__ = 11; break;
    case 4: 
      var $9=$2;
      var $10=_HPDF_Dict_GetItem($9, ((STRING_TABLE.__str1520)|0), 4);
      var $11=$10;
      $n=$11;
      var $12=$n;
      var $13=(($12)|0)!=0;
      if ($13) { __label__ = 9; break; } else { __label__ = 5; break; }
    case 5: 
      var $15=$2;
      var $16=(($15+8)|0);
      var $17=HEAP32[(($16)>>2)];
      var $18=$3;
      var $19=_HPDF_Number_New($17, $18);
      $n=$19;
      var $20=$n;
      var $21=(($20)|0)!=0;
      if ($21) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      var $23=$2;
      var $24=$n;
      var $25=$24;
      var $26=_HPDF_Dict_Add($23, ((STRING_TABLE.__str1520)|0), $25);
      var $27=(($26)|0)!=0;
      if ($27) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $29=$2;
      var $30=(($29+12)|0);
      var $31=HEAP32[(($30)>>2)];
      var $32=_HPDF_CheckError($31);
      $1=$32;
      __label__ = 11; break;
    case 8: 
      __label__ = 10; break;
    case 9: 
      var $35=$3;
      var $36=$n;
      var $37=(($36+8)|0);
      HEAP32[(($37)>>2)]=$35;
      __label__ = 10; break;
    case 10: 
      $1=0;
      __label__ = 11; break;
    case 11: 
      var $40=$1;
      ;
      return $40;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Outline_SetOpened["X"]=1;

function _CountChild($outline) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $child;
      var $count;
      $1=$outline;
      var $2=$1;
      var $3=_HPDF_Outline_GetFirst($2);
      $child=$3;
      $count=0;
      __label__ = 3; break;
    case 3: 
      var $5=$child;
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 4; break; } else { __label__ = 7; break; }
    case 4: 
      var $8=$count;
      var $9=((($8)+(1))|0);
      $count=$9;
      var $10=$child;
      var $11=_HPDF_Outline_GetOpened($10);
      var $12=(($11)|0)!=0;
      if ($12) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $14=$child;
      var $15=_CountChild($14);
      var $16=$count;
      var $17=((($16)+($15))|0);
      $count=$17;
      __label__ = 6; break;
    case 6: 
      var $19=$child;
      var $20=_HPDF_Outline_GetNext($19);
      $child=$20;
      __label__ = 3; break;
    case 7: 
      var $22=$count;
      ;
      return $22;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_PageLabel_New($pdf, $style, $first_page, $prefix) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $5;
      var $obj;
      $2=$pdf;
      $3=$style;
      $4=$first_page;
      $5=$prefix;
      var $6=$2;
      var $7=(($6+8)|0);
      var $8=HEAP32[(($7)>>2)];
      var $9=_HPDF_Dict_New($8);
      $obj=$9;
      var $10=$obj;
      var $11=(($10)|0)!=0;
      if ($11) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=0;
      __label__ = 32; break;
    case 4: 
      var $14=$3;
      if ((($14)|0) == 0) {
        __label__ = 5; break;
      }
      else if ((($14)|0) == 1) {
        __label__ = 8; break;
      }
      else if ((($14)|0) == 2) {
        __label__ = 11; break;
      }
      else if ((($14)|0) == 3) {
        __label__ = 14; break;
      }
      else if ((($14)|0) == 4) {
        __label__ = 17; break;
      }
      else {
      __label__ = 20; break;
      }
      
    case 5: 
      var $16=$obj;
      var $17=_HPDF_Dict_AddName($16, ((STRING_TABLE.__str1540)|0), ((STRING_TABLE.__str11541)|0));
      var $18=(($17)|0)!=0;
      if ($18) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      __label__ = 31; break;
    case 7: 
      __label__ = 21; break;
    case 8: 
      var $22=$obj;
      var $23=_HPDF_Dict_AddName($22, ((STRING_TABLE.__str1540)|0), ((STRING_TABLE.__str21542)|0));
      var $24=(($23)|0)!=0;
      if ($24) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      __label__ = 31; break;
    case 10: 
      __label__ = 21; break;
    case 11: 
      var $28=$obj;
      var $29=_HPDF_Dict_AddName($28, ((STRING_TABLE.__str1540)|0), ((STRING_TABLE.__str31543)|0));
      var $30=(($29)|0)!=0;
      if ($30) { __label__ = 12; break; } else { __label__ = 13; break; }
    case 12: 
      __label__ = 31; break;
    case 13: 
      __label__ = 21; break;
    case 14: 
      var $34=$obj;
      var $35=_HPDF_Dict_AddName($34, ((STRING_TABLE.__str1540)|0), ((STRING_TABLE.__str41544)|0));
      var $36=(($35)|0)!=0;
      if ($36) { __label__ = 15; break; } else { __label__ = 16; break; }
    case 15: 
      __label__ = 31; break;
    case 16: 
      __label__ = 21; break;
    case 17: 
      var $40=$obj;
      var $41=_HPDF_Dict_AddName($40, ((STRING_TABLE.__str1540)|0), ((STRING_TABLE.__str51545)|0));
      var $42=(($41)|0)!=0;
      if ($42) { __label__ = 18; break; } else { __label__ = 19; break; }
    case 18: 
      __label__ = 31; break;
    case 19: 
      __label__ = 21; break;
    case 20: 
      var $46=$2;
      var $47=(($46+40)|0);
      var $48=$3;
      var $49=_HPDF_SetError($47, 4209, $48);
      __label__ = 31; break;
    case 21: 
      var $51=$5;
      var $52=(($51)|0)!=0;
      if ($52) { __label__ = 22; break; } else { __label__ = 26; break; }
    case 22: 
      var $54=$5;
      var $55=(($54)|0);
      var $56=HEAP8[($55)];
      var $57=(($56 << 24) >> 24);
      var $58=(($57)|0)!=0;
      if ($58) { __label__ = 23; break; } else { __label__ = 26; break; }
    case 23: 
      var $60=$obj;
      var $61=$2;
      var $62=(($61+8)|0);
      var $63=HEAP32[(($62)>>2)];
      var $64=$5;
      var $65=$2;
      var $66=(($65+100)|0);
      var $67=HEAP32[(($66)>>2)];
      var $68=_HPDF_String_New($63, $64, $67);
      var $69=$68;
      var $70=_HPDF_Dict_Add($60, ((STRING_TABLE.__str61546)|0), $69);
      var $71=(($70)|0)!=0;
      if ($71) { __label__ = 24; break; } else { __label__ = 25; break; }
    case 24: 
      __label__ = 31; break;
    case 25: 
      __label__ = 26; break;
    case 26: 
      var $75=$4;
      var $76=(($75)|0)!=0;
      if ($76) { __label__ = 27; break; } else { __label__ = 30; break; }
    case 27: 
      var $78=$obj;
      var $79=$4;
      var $80=_HPDF_Dict_AddNumber($78, ((STRING_TABLE.__str71547)|0), $79);
      var $81=(($80)|0)!=0;
      if ($81) { __label__ = 28; break; } else { __label__ = 29; break; }
    case 28: 
      __label__ = 31; break;
    case 29: 
      __label__ = 30; break;
    case 30: 
      var $85=$obj;
      $1=$85;
      __label__ = 32; break;
    case 31: 
      var $87=$obj;
      _HPDF_Dict_Free($87);
      $1=0;
      __label__ = 32; break;
    case 32: 
      var $89=$1;
      ;
      return $89;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_PageLabel_New["X"]=1;

function _HPDF_Page_SetLineWidth($page, $line_width) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $ret;
      var $attr;
      $2=$page;
      $3=$line_width;
      var $4=$2;
      var $5=_HPDF_Page_CheckState($4, 5);
      $ret=$5;
      var $6=$ret;
      var $7=(($6)|0)!=0;
      if ($7) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $9=$ret;
      $1=$9;
      __label__ = 11; break;
    case 4: 
      var $11=$2;
      var $12=(($11+44)|0);
      var $13=HEAP32[(($12)>>2)];
      var $14=$13;
      $attr=$14;
      var $15=$3;
      var $16=$15 < 0;
      if ($16) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $18=$2;
      var $19=(($18+12)|0);
      var $20=HEAP32[(($19)>>2)];
      var $21=_HPDF_RaiseError($20, 4182, 0);
      $1=$21;
      __label__ = 11; break;
    case 6: 
      var $23=$attr;
      var $24=(($23+76)|0);
      var $25=HEAP32[(($24)>>2)];
      var $26=$3;
      var $27=_HPDF_Stream_WriteReal($25, $26);
      $ret=$27;
      var $28=(($27)|0)!=0;
      if ($28) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $30=$2;
      var $31=(($30+12)|0);
      var $32=HEAP32[(($31)>>2)];
      var $33=_HPDF_CheckError($32);
      $1=$33;
      __label__ = 11; break;
    case 8: 
      var $35=$attr;
      var $36=(($35+76)|0);
      var $37=HEAP32[(($36)>>2)];
      var $38=_HPDF_Stream_WriteStr($37, ((STRING_TABLE.__str1550)|0));
      $ret=$38;
      var $39=(($38)|0)!=0;
      if ($39) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      var $41=$2;
      var $42=(($41+12)|0);
      var $43=HEAP32[(($42)>>2)];
      var $44=_HPDF_CheckError($43);
      $1=$44;
      __label__ = 11; break;
    case 10: 
      var $46=$3;
      var $47=$attr;
      var $48=(($47+16)|0);
      var $49=HEAP32[(($48)>>2)];
      var $50=(($49+24)|0);
      HEAPF32[(($50)>>2)]=$46;
      var $51=$ret;
      $1=$51;
      __label__ = 11; break;
    case 11: 
      var $53=$1;
      ;
      return $53;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Page_SetLineWidth["X"]=1;

function _HPDF_Page_SetLineCap($page, $line_cap) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $ret;
      var $attr;
      $2=$page;
      $3=$line_cap;
      var $4=$2;
      var $5=_HPDF_Page_CheckState($4, 5);
      $ret=$5;
      var $6=$ret;
      var $7=(($6)|0)!=0;
      if ($7) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $9=$ret;
      $1=$9;
      __label__ = 12; break;
    case 4: 
      var $11=$3;
      var $12=(($11)>>>0) < 0;
      if ($12) { __label__ = 6; break; } else { __label__ = 5; break; }
    case 5: 
      var $14=$3;
      var $15=(($14)>>>0) >= 3;
      if ($15) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      var $17=$2;
      var $18=(($17+12)|0);
      var $19=HEAP32[(($18)>>2)];
      var $20=$3;
      var $21=_HPDF_RaiseError($19, 4182, $20);
      $1=$21;
      __label__ = 12; break;
    case 7: 
      var $23=$2;
      var $24=(($23+44)|0);
      var $25=HEAP32[(($24)>>2)];
      var $26=$25;
      $attr=$26;
      var $27=$attr;
      var $28=(($27+76)|0);
      var $29=HEAP32[(($28)>>2)];
      var $30=$3;
      var $31=_HPDF_Stream_WriteInt($29, $30);
      $ret=$31;
      var $32=(($31)|0)!=0;
      if ($32) { __label__ = 8; break; } else { __label__ = 9; break; }
    case 8: 
      var $34=$ret;
      $1=$34;
      __label__ = 12; break;
    case 9: 
      var $36=$attr;
      var $37=(($36+76)|0);
      var $38=HEAP32[(($37)>>2)];
      var $39=_HPDF_Stream_WriteStr($38, ((STRING_TABLE.__str11551)|0));
      $ret=$39;
      var $40=(($39)|0)!=0;
      if ($40) { __label__ = 10; break; } else { __label__ = 11; break; }
    case 10: 
      var $42=$2;
      var $43=(($42+12)|0);
      var $44=HEAP32[(($43)>>2)];
      var $45=_HPDF_CheckError($44);
      $1=$45;
      __label__ = 12; break;
    case 11: 
      var $47=$3;
      var $48=$attr;
      var $49=(($48+16)|0);
      var $50=HEAP32[(($49)>>2)];
      var $51=(($50+28)|0);
      HEAP32[(($51)>>2)]=$47;
      var $52=$ret;
      $1=$52;
      __label__ = 12; break;
    case 12: 
      var $54=$1;
      ;
      return $54;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Page_SetLineCap["X"]=1;

function _HPDF_Page_SetLineJoin($page, $line_join) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $ret;
      var $attr;
      $2=$page;
      $3=$line_join;
      var $4=$2;
      var $5=_HPDF_Page_CheckState($4, 5);
      $ret=$5;
      var $6=$ret;
      var $7=(($6)|0)!=0;
      if ($7) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $9=$ret;
      $1=$9;
      __label__ = 12; break;
    case 4: 
      var $11=$3;
      var $12=(($11)>>>0) < 0;
      if ($12) { __label__ = 6; break; } else { __label__ = 5; break; }
    case 5: 
      var $14=$3;
      var $15=(($14)>>>0) >= 3;
      if ($15) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      var $17=$2;
      var $18=(($17+12)|0);
      var $19=HEAP32[(($18)>>2)];
      var $20=$3;
      var $21=_HPDF_RaiseError($19, 4182, $20);
      $1=$21;
      __label__ = 12; break;
    case 7: 
      var $23=$2;
      var $24=(($23+44)|0);
      var $25=HEAP32[(($24)>>2)];
      var $26=$25;
      $attr=$26;
      var $27=$attr;
      var $28=(($27+76)|0);
      var $29=HEAP32[(($28)>>2)];
      var $30=$3;
      var $31=_HPDF_Stream_WriteInt($29, $30);
      $ret=$31;
      var $32=(($31)|0)!=0;
      if ($32) { __label__ = 8; break; } else { __label__ = 9; break; }
    case 8: 
      var $34=$2;
      var $35=(($34+12)|0);
      var $36=HEAP32[(($35)>>2)];
      var $37=_HPDF_CheckError($36);
      $1=$37;
      __label__ = 12; break;
    case 9: 
      var $39=$attr;
      var $40=(($39+76)|0);
      var $41=HEAP32[(($40)>>2)];
      var $42=_HPDF_Stream_WriteStr($41, ((STRING_TABLE.__str21552)|0));
      $ret=$42;
      var $43=(($42)|0)!=0;
      if ($43) { __label__ = 10; break; } else { __label__ = 11; break; }
    case 10: 
      var $45=$2;
      var $46=(($45+12)|0);
      var $47=HEAP32[(($46)>>2)];
      var $48=_HPDF_CheckError($47);
      $1=$48;
      __label__ = 12; break;
    case 11: 
      var $50=$3;
      var $51=$attr;
      var $52=(($51+16)|0);
      var $53=HEAP32[(($52)>>2)];
      var $54=(($53+32)|0);
      HEAP32[(($54)>>2)]=$50;
      var $55=$ret;
      $1=$55;
      __label__ = 12; break;
    case 12: 
      var $57=$1;
      ;
      return $57;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Page_SetLineJoin["X"]=1;

function _HPDF_Page_SetMiterLimit($page, $miter_limit) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $ret;
      var $attr;
      $2=$page;
      $3=$miter_limit;
      var $4=$2;
      var $5=_HPDF_Page_CheckState($4, 5);
      $ret=$5;
      var $6=$ret;
      var $7=(($6)|0)!=0;
      if ($7) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $9=$ret;
      $1=$9;
      __label__ = 11; break;
    case 4: 
      var $11=$2;
      var $12=(($11+44)|0);
      var $13=HEAP32[(($12)>>2)];
      var $14=$13;
      $attr=$14;
      var $15=$3;
      var $16=$15 < 1;
      if ($16) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $18=$2;
      var $19=(($18+12)|0);
      var $20=HEAP32[(($19)>>2)];
      var $21=_HPDF_RaiseError($20, 4182, 0);
      $1=$21;
      __label__ = 11; break;
    case 6: 
      var $23=$attr;
      var $24=(($23+76)|0);
      var $25=HEAP32[(($24)>>2)];
      var $26=$3;
      var $27=_HPDF_Stream_WriteReal($25, $26);
      $ret=$27;
      var $28=(($27)|0)!=0;
      if ($28) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $30=$2;
      var $31=(($30+12)|0);
      var $32=HEAP32[(($31)>>2)];
      var $33=_HPDF_CheckError($32);
      $1=$33;
      __label__ = 11; break;
    case 8: 
      var $35=$attr;
      var $36=(($35+76)|0);
      var $37=HEAP32[(($36)>>2)];
      var $38=_HPDF_Stream_WriteStr($37, ((STRING_TABLE.__str31553)|0));
      $ret=$38;
      var $39=(($38)|0)!=0;
      if ($39) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      var $41=$2;
      var $42=(($41+12)|0);
      var $43=HEAP32[(($42)>>2)];
      var $44=_HPDF_CheckError($43);
      $1=$44;
      __label__ = 11; break;
    case 10: 
      var $46=$3;
      var $47=$attr;
      var $48=(($47+16)|0);
      var $49=HEAP32[(($48)>>2)];
      var $50=(($49+36)|0);
      HEAPF32[(($50)>>2)]=$46;
      var $51=$ret;
      $1=$51;
      __label__ = 11; break;
    case 11: 
      var $53=$1;
      ;
      return $53;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Page_SetMiterLimit["X"]=1;

function _HPDF_Page_SetDash($page, $dash_ptn, $num_param, $phase) {
  var __stackBase__  = STACKTOP; STACKTOP += 512; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $5;
      var $ret;
      var $buf=__stackBase__;
      var $pbuf;
      var $eptr;
      var $pdash_ptn;
      var $attr;
      var $i;
      $2=$page;
      $3=$dash_ptn;
      $4=$num_param;
      $5=$phase;
      var $6=$2;
      var $7=_HPDF_Page_CheckState($6, 5);
      $ret=$7;
      var $8=(($buf)|0);
      $pbuf=$8;
      var $9=(($buf)|0);
      var $10=(($9+512)|0);
      var $11=((($10)-(1))|0);
      $eptr=$11;
      var $12=$3;
      $pdash_ptn=$12;
      var $13=$ret;
      var $14=(($13)|0)!=0;
      if ($14) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $16=$ret;
      $1=$16;
      __label__ = 27; break;
    case 4: 
      var $18=$4;
      var $19=(($18)|0)!=1;
      if ($19) { __label__ = 5; break; } else { __label__ = 7; break; }
    case 5: 
      var $21=$4;
      var $22=Math.floor(((($21)>>>0))/(2));
      var $23=((($22<<1))|0);
      var $24=$4;
      var $25=(($23)|0)!=(($24)|0);
      if ($25) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      var $27=$2;
      var $28=(($27+12)|0);
      var $29=HEAP32[(($28)>>2)];
      var $30=$4;
      var $31=_HPDF_RaiseError($29, 4168, $30);
      $1=$31;
      __label__ = 27; break;
    case 7: 
      var $33=$4;
      var $34=(($33)|0)==0;
      if ($34) { __label__ = 8; break; } else { __label__ = 10; break; }
    case 8: 
      var $36=$5;
      var $37=(($36)>>>0) > 0;
      if ($37) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      var $39=$2;
      var $40=(($39+12)|0);
      var $41=HEAP32[(($40)>>2)];
      var $42=$5;
      var $43=_HPDF_RaiseError($41, 4182, $42);
      $1=$43;
      __label__ = 27; break;
    case 10: 
      var $45=$3;
      var $46=(($45)|0)!=0;
      if ($46) { __label__ = 13; break; } else { __label__ = 11; break; }
    case 11: 
      var $48=$4;
      var $49=(($48)>>>0) > 0;
      if ($49) { __label__ = 12; break; } else { __label__ = 13; break; }
    case 12: 
      var $51=$2;
      var $52=(($51+12)|0);
      var $53=HEAP32[(($52)>>2)];
      var $54=$5;
      var $55=_HPDF_RaiseError($53, 4153, $54);
      $1=$55;
      __label__ = 27; break;
    case 13: 
      var $57=(($buf)|0);
      var $58=_HPDF_MemSet($57, 0, 512);
      var $59=$pbuf;
      var $60=(($59+1)|0);
      $pbuf=$60;
      HEAP8[($59)]=91;
      $i=0;
      __label__ = 14; break;
    case 14: 
      var $62=$i;
      var $63=$4;
      var $64=(($62)>>>0) < (($63)>>>0);
      if ($64) { __label__ = 15; break; } else { __label__ = 20; break; }
    case 15: 
      var $66=$pdash_ptn;
      var $67=HEAPU16[(($66)>>1)];
      var $68=(($67)&65535);
      var $69=(($68)|0)==0;
      if ($69) { __label__ = 17; break; } else { __label__ = 16; break; }
    case 16: 
      var $71=$pdash_ptn;
      var $72=HEAPU16[(($71)>>1)];
      var $73=(($72)&65535);
      var $74=(($73)|0) > 100;
      if ($74) { __label__ = 17; break; } else { __label__ = 18; break; }
    case 17: 
      var $76=$2;
      var $77=(($76+12)|0);
      var $78=HEAP32[(($77)>>2)];
      var $79=_HPDF_RaiseError($78, 4182, 0);
      $1=$79;
      __label__ = 27; break;
    case 18: 
      var $81=$pbuf;
      var $82=$pdash_ptn;
      var $83=HEAPU16[(($82)>>1)];
      var $84=(($83)&65535);
      var $85=$eptr;
      var $86=_HPDF_IToA($81, $84, $85);
      $pbuf=$86;
      var $87=$pbuf;
      var $88=(($87+1)|0);
      $pbuf=$88;
      HEAP8[($87)]=32;
      var $89=$pdash_ptn;
      var $90=(($89+2)|0);
      $pdash_ptn=$90;
      __label__ = 19; break;
    case 19: 
      var $92=$i;
      var $93=((($92)+(1))|0);
      $i=$93;
      __label__ = 14; break;
    case 20: 
      var $95=$pbuf;
      var $96=(($95+1)|0);
      $pbuf=$96;
      HEAP8[($95)]=93;
      var $97=$pbuf;
      var $98=(($97+1)|0);
      $pbuf=$98;
      HEAP8[($97)]=32;
      var $99=$pbuf;
      var $100=$5;
      var $101=$eptr;
      var $102=_HPDF_IToA($99, $100, $101);
      $pbuf=$102;
      var $103=$pbuf;
      var $104=$eptr;
      var $105=_HPDF_StrCpy($103, ((STRING_TABLE.__str41554)|0), $104);
      var $106=$2;
      var $107=(($106+44)|0);
      var $108=HEAP32[(($107)>>2)];
      var $109=$108;
      $attr=$109;
      var $110=$attr;
      var $111=(($110+76)|0);
      var $112=HEAP32[(($111)>>2)];
      var $113=(($buf)|0);
      var $114=_HPDF_Stream_WriteStr($112, $113);
      $ret=$114;
      var $115=(($114)|0)!=0;
      if ($115) { __label__ = 21; break; } else { __label__ = 22; break; }
    case 21: 
      var $117=$2;
      var $118=(($117+12)|0);
      var $119=HEAP32[(($118)>>2)];
      var $120=_HPDF_CheckError($119);
      $1=$120;
      __label__ = 27; break;
    case 22: 
      var $122=$attr;
      var $123=(($122+16)|0);
      var $124=HEAP32[(($123)>>2)];
      var $125=(($124+40)|0);
      var $126=$125;
      assert(24 % 1 === 0, 'memcpy given ' + 24 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP32[(($126)>>2)]=HEAP32[((_INIT_MODE)>>2)];HEAP32[((($126)+(4))>>2)]=HEAP32[(((_INIT_MODE)+(4))>>2)];HEAP32[((($126)+(8))>>2)]=HEAP32[(((_INIT_MODE)+(8))>>2)];HEAP32[((($126)+(12))>>2)]=HEAP32[(((_INIT_MODE)+(12))>>2)];HEAP32[((($126)+(16))>>2)]=HEAP32[(((_INIT_MODE)+(16))>>2)];HEAP32[((($126)+(20))>>2)]=HEAP32[(((_INIT_MODE)+(20))>>2)];
      var $127=$4;
      var $128=$attr;
      var $129=(($128+16)|0);
      var $130=HEAP32[(($129)>>2)];
      var $131=(($130+40)|0);
      var $132=(($131+16)|0);
      HEAP32[(($132)>>2)]=$127;
      var $133=$5;
      var $134=$attr;
      var $135=(($134+16)|0);
      var $136=HEAP32[(($135)>>2)];
      var $137=(($136+40)|0);
      var $138=(($137+20)|0);
      HEAP32[(($138)>>2)]=$133;
      var $139=$3;
      $pdash_ptn=$139;
      $i=0;
      __label__ = 23; break;
    case 23: 
      var $141=$i;
      var $142=$4;
      var $143=(($141)>>>0) < (($142)>>>0);
      if ($143) { __label__ = 24; break; } else { __label__ = 26; break; }
    case 24: 
      var $145=$pdash_ptn;
      var $146=HEAP16[(($145)>>1)];
      var $147=$i;
      var $148=$attr;
      var $149=(($148+16)|0);
      var $150=HEAP32[(($149)>>2)];
      var $151=(($150+40)|0);
      var $152=(($151)|0);
      var $153=(($152+($147<<1))|0);
      HEAP16[(($153)>>1)]=$146;
      var $154=$pdash_ptn;
      var $155=(($154+2)|0);
      $pdash_ptn=$155;
      __label__ = 25; break;
    case 25: 
      var $157=$i;
      var $158=((($157)+(1))|0);
      $i=$158;
      __label__ = 23; break;
    case 26: 
      var $160=$ret;
      $1=$160;
      __label__ = 27; break;
    case 27: 
      var $162=$1;
      STACKTOP = __stackBase__;
      return $162;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Page_SetDash["X"]=1;

function _HPDF_Page_SetFlat($page, $flatness) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $attr;
      var $ret;
      $2=$page;
      $3=$flatness;
      var $4=$2;
      var $5=_HPDF_Page_CheckState($4, 5);
      $ret=$5;
      var $6=$ret;
      var $7=(($6)|0)!=0;
      if ($7) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $9=$ret;
      $1=$9;
      __label__ = 12; break;
    case 4: 
      var $11=$2;
      var $12=(($11+44)|0);
      var $13=HEAP32[(($12)>>2)];
      var $14=$13;
      $attr=$14;
      var $15=$3;
      var $16=$15 > 100;
      if ($16) { __label__ = 6; break; } else { __label__ = 5; break; }
    case 5: 
      var $18=$3;
      var $19=$18 < 0;
      if ($19) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      var $21=$2;
      var $22=(($21+12)|0);
      var $23=HEAP32[(($22)>>2)];
      var $24=_HPDF_RaiseError($23, 4182, 0);
      $1=$24;
      __label__ = 12; break;
    case 7: 
      var $26=$attr;
      var $27=(($26+76)|0);
      var $28=HEAP32[(($27)>>2)];
      var $29=$3;
      var $30=_HPDF_Stream_WriteReal($28, $29);
      $ret=$30;
      var $31=(($30)|0)!=0;
      if ($31) { __label__ = 8; break; } else { __label__ = 9; break; }
    case 8: 
      var $33=$2;
      var $34=(($33+12)|0);
      var $35=HEAP32[(($34)>>2)];
      var $36=_HPDF_CheckError($35);
      $1=$36;
      __label__ = 12; break;
    case 9: 
      var $38=$attr;
      var $39=(($38+76)|0);
      var $40=HEAP32[(($39)>>2)];
      var $41=_HPDF_Stream_WriteStr($40, ((STRING_TABLE.__str51555)|0));
      $ret=$41;
      var $42=(($41)|0)!=0;
      if ($42) { __label__ = 10; break; } else { __label__ = 11; break; }
    case 10: 
      var $44=$2;
      var $45=(($44+12)|0);
      var $46=HEAP32[(($45)>>2)];
      var $47=_HPDF_CheckError($46);
      $1=$47;
      __label__ = 12; break;
    case 11: 
      var $49=$3;
      var $50=$attr;
      var $51=(($50+16)|0);
      var $52=HEAP32[(($51)>>2)];
      var $53=(($52+64)|0);
      HEAPF32[(($53)>>2)]=$49;
      var $54=$ret;
      $1=$54;
      __label__ = 12; break;
    case 12: 
      var $56=$1;
      ;
      return $56;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Page_SetFlat["X"]=1;

function _HPDF_Page_SetExtGState($page, $ext_gstate) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $ret;
      var $attr;
      var $local_name;
      $2=$page;
      $3=$ext_gstate;
      var $4=$2;
      var $5=_HPDF_Page_CheckState($4, 1);
      $ret=$5;
      var $6=$ret;
      var $7=(($6)|0)!=0;
      if ($7) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $9=$ret;
      $1=$9;
      __label__ = 15; break;
    case 4: 
      var $11=$3;
      var $12=_HPDF_ExtGState_Validate($11);
      var $13=(($12)|0)!=0;
      if ($13) { __label__ = 6; break; } else { __label__ = 5; break; }
    case 5: 
      var $15=$2;
      var $16=(($15+12)|0);
      var $17=HEAP32[(($16)>>2)];
      var $18=_HPDF_RaiseError($17, 4147, 0);
      $1=$18;
      __label__ = 15; break;
    case 6: 
      var $20=$2;
      var $21=(($20+8)|0);
      var $22=HEAP32[(($21)>>2)];
      var $23=$3;
      var $24=(($23+8)|0);
      var $25=HEAP32[(($24)>>2)];
      var $26=(($22)|0)!=(($25)|0);
      if ($26) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $28=$2;
      var $29=(($28+12)|0);
      var $30=HEAP32[(($29)>>2)];
      var $31=_HPDF_RaiseError($30, 4225, 0);
      $1=$31;
      __label__ = 15; break;
    case 8: 
      var $33=$2;
      var $34=(($33+44)|0);
      var $35=HEAP32[(($34)>>2)];
      var $36=$35;
      $attr=$36;
      var $37=$2;
      var $38=$3;
      var $39=_HPDF_Page_GetExtGStateName($37, $38);
      $local_name=$39;
      var $40=$local_name;
      var $41=(($40)|0)!=0;
      if ($41) { __label__ = 10; break; } else { __label__ = 9; break; }
    case 9: 
      var $43=$2;
      var $44=(($43+12)|0);
      var $45=HEAP32[(($44)>>2)];
      var $46=_HPDF_CheckError($45);
      $1=$46;
      __label__ = 15; break;
    case 10: 
      var $48=$attr;
      var $49=(($48+76)|0);
      var $50=HEAP32[(($49)>>2)];
      var $51=$local_name;
      var $52=_HPDF_Stream_WriteEscapeName($50, $51);
      $ret=$52;
      var $53=(($52)|0)!=0;
      if ($53) { __label__ = 11; break; } else { __label__ = 12; break; }
    case 11: 
      var $55=$2;
      var $56=(($55+12)|0);
      var $57=HEAP32[(($56)>>2)];
      var $58=_HPDF_CheckError($57);
      $1=$58;
      __label__ = 15; break;
    case 12: 
      var $60=$attr;
      var $61=(($60+76)|0);
      var $62=HEAP32[(($61)>>2)];
      var $63=_HPDF_Stream_WriteStr($62, ((STRING_TABLE.__str61556)|0));
      $ret=$63;
      var $64=(($63)|0)!=0;
      if ($64) { __label__ = 13; break; } else { __label__ = 14; break; }
    case 13: 
      var $66=$2;
      var $67=(($66+12)|0);
      var $68=HEAP32[(($67)>>2)];
      var $69=_HPDF_CheckError($68);
      $1=$69;
      __label__ = 15; break;
    case 14: 
      var $71=$3;
      var $72=(($71)|0);
      var $73=(($72+6)|0);
      HEAP16[(($73)>>1)]=2833;
      var $74=$ret;
      $1=$74;
      __label__ = 15; break;
    case 15: 
      var $76=$1;
      ;
      return $76;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Page_SetExtGState["X"]=1;

function _HPDF_Page_GSave($page) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $new_gstate;
      var $attr;
      var $ret;
      $2=$page;
      var $3=$2;
      var $4=_HPDF_Page_CheckState($3, 1);
      $ret=$4;
      var $5=$ret;
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $8=$ret;
      $1=$8;
      __label__ = 9; break;
    case 4: 
      var $10=$2;
      var $11=(($10+44)|0);
      var $12=HEAP32[(($11)>>2)];
      var $13=$12;
      $attr=$13;
      var $14=$2;
      var $15=(($14+8)|0);
      var $16=HEAP32[(($15)>>2)];
      var $17=$attr;
      var $18=(($17+16)|0);
      var $19=HEAP32[(($18)>>2)];
      var $20=_HPDF_GState_New($16, $19);
      $new_gstate=$20;
      var $21=$new_gstate;
      var $22=(($21)|0)!=0;
      if ($22) { __label__ = 6; break; } else { __label__ = 5; break; }
    case 5: 
      var $24=$2;
      var $25=(($24+12)|0);
      var $26=HEAP32[(($25)>>2)];
      var $27=_HPDF_CheckError($26);
      $1=$27;
      __label__ = 9; break;
    case 6: 
      var $29=$attr;
      var $30=(($29+76)|0);
      var $31=HEAP32[(($30)>>2)];
      var $32=_HPDF_Stream_WriteStr($31, ((STRING_TABLE.__str71557)|0));
      $ret=$32;
      var $33=(($32)|0)!=0;
      if ($33) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $35=$2;
      var $36=(($35+12)|0);
      var $37=HEAP32[(($36)>>2)];
      var $38=_HPDF_CheckError($37);
      $1=$38;
      __label__ = 9; break;
    case 8: 
      var $40=$new_gstate;
      var $41=$attr;
      var $42=(($41+16)|0);
      HEAP32[(($42)>>2)]=$40;
      var $43=$ret;
      $1=$43;
      __label__ = 9; break;
    case 9: 
      var $45=$1;
      ;
      return $45;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Page_GSave["X"]=1;

function _HPDF_Page_GRestore($page) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $new_gstate;
      var $attr;
      var $ret;
      $2=$page;
      var $3=$2;
      var $4=_HPDF_Page_CheckState($3, 1);
      $ret=$4;
      var $5=$ret;
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $8=$ret;
      $1=$8;
      __label__ = 9; break;
    case 4: 
      var $10=$2;
      var $11=(($10+44)|0);
      var $12=HEAP32[(($11)>>2)];
      var $13=$12;
      $attr=$13;
      var $14=$attr;
      var $15=(($14+16)|0);
      var $16=HEAP32[(($15)>>2)];
      var $17=(($16+176)|0);
      var $18=HEAP32[(($17)>>2)];
      var $19=(($18)|0)!=0;
      if ($19) { __label__ = 6; break; } else { __label__ = 5; break; }
    case 5: 
      var $21=$2;
      var $22=(($21+12)|0);
      var $23=HEAP32[(($22)>>2)];
      var $24=_HPDF_RaiseError($23, 4172, 0);
      $1=$24;
      __label__ = 9; break;
    case 6: 
      var $26=$2;
      var $27=(($26+8)|0);
      var $28=HEAP32[(($27)>>2)];
      var $29=$attr;
      var $30=(($29+16)|0);
      var $31=HEAP32[(($30)>>2)];
      var $32=_HPDF_GState_Free($28, $31);
      $new_gstate=$32;
      var $33=$new_gstate;
      var $34=$attr;
      var $35=(($34+16)|0);
      HEAP32[(($35)>>2)]=$33;
      var $36=$attr;
      var $37=(($36+76)|0);
      var $38=HEAP32[(($37)>>2)];
      var $39=_HPDF_Stream_WriteStr($38, ((STRING_TABLE.__str81558)|0));
      $ret=$39;
      var $40=(($39)|0)!=0;
      if ($40) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $42=$2;
      var $43=(($42+12)|0);
      var $44=HEAP32[(($43)>>2)];
      var $45=_HPDF_CheckError($44);
      $1=$45;
      __label__ = 9; break;
    case 8: 
      var $47=$ret;
      $1=$47;
      __label__ = 9; break;
    case 9: 
      var $49=$1;
      ;
      return $49;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Page_GRestore["X"]=1;

function _HPDF_Page_Concat($page, $a, $b, $c, $d, $x, $y) {
  var __stackBase__  = STACKTOP; STACKTOP += 536; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $5;
      var $6;
      var $7;
      var $8;
      var $ret;
      var $buf=__stackBase__;
      var $pbuf;
      var $eptr;
      var $attr;
      var $tm=(__stackBase__)+(512);
      $2=$page;
      $3=$a;
      $4=$b;
      $5=$c;
      $6=$d;
      $7=$x;
      $8=$y;
      var $9=$2;
      var $10=_HPDF_Page_CheckState($9, 1);
      $ret=$10;
      var $11=(($buf)|0);
      $pbuf=$11;
      var $12=(($buf)|0);
      var $13=(($12+512)|0);
      var $14=((($13)-(1))|0);
      $eptr=$14;
      var $15=$ret;
      var $16=(($15)|0)!=0;
      if ($16) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $18=$ret;
      $1=$18;
      __label__ = 7; break;
    case 4: 
      var $20=$2;
      var $21=(($20+44)|0);
      var $22=HEAP32[(($21)>>2)];
      var $23=$22;
      $attr=$23;
      var $24=(($buf)|0);
      var $25=_HPDF_MemSet($24, 0, 512);
      var $26=$pbuf;
      var $27=$3;
      var $28=$eptr;
      var $29=_HPDF_FToA($26, $27, $28);
      $pbuf=$29;
      var $30=$pbuf;
      var $31=(($30+1)|0);
      $pbuf=$31;
      HEAP8[($30)]=32;
      var $32=$pbuf;
      var $33=$4;
      var $34=$eptr;
      var $35=_HPDF_FToA($32, $33, $34);
      $pbuf=$35;
      var $36=$pbuf;
      var $37=(($36+1)|0);
      $pbuf=$37;
      HEAP8[($36)]=32;
      var $38=$pbuf;
      var $39=$5;
      var $40=$eptr;
      var $41=_HPDF_FToA($38, $39, $40);
      $pbuf=$41;
      var $42=$pbuf;
      var $43=(($42+1)|0);
      $pbuf=$43;
      HEAP8[($42)]=32;
      var $44=$pbuf;
      var $45=$6;
      var $46=$eptr;
      var $47=_HPDF_FToA($44, $45, $46);
      $pbuf=$47;
      var $48=$pbuf;
      var $49=(($48+1)|0);
      $pbuf=$49;
      HEAP8[($48)]=32;
      var $50=$pbuf;
      var $51=$7;
      var $52=$eptr;
      var $53=_HPDF_FToA($50, $51, $52);
      $pbuf=$53;
      var $54=$pbuf;
      var $55=(($54+1)|0);
      $pbuf=$55;
      HEAP8[($54)]=32;
      var $56=$pbuf;
      var $57=$8;
      var $58=$eptr;
      var $59=_HPDF_FToA($56, $57, $58);
      $pbuf=$59;
      var $60=$pbuf;
      var $61=$eptr;
      var $62=_HPDF_StrCpy($60, ((STRING_TABLE.__str91559)|0), $61);
      var $63=$attr;
      var $64=(($63+76)|0);
      var $65=HEAP32[(($64)>>2)];
      var $66=(($buf)|0);
      var $67=_HPDF_Stream_WriteStr($65, $66);
      $ret=$67;
      var $68=(($67)|0)!=0;
      if ($68) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $70=$2;
      var $71=(($70+12)|0);
      var $72=HEAP32[(($71)>>2)];
      var $73=_HPDF_CheckError($72);
      $1=$73;
      __label__ = 7; break;
    case 6: 
      var $75=$attr;
      var $76=(($75+16)|0);
      var $77=HEAP32[(($76)>>2)];
      var $78=(($77)|0);
      var $79=$tm;
      var $80=$78;
      assert(24 % 1 === 0, 'memcpy given ' + 24 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP32[(($79)>>2)]=HEAP32[(($80)>>2)];HEAP32[((($79)+(4))>>2)]=HEAP32[((($80)+(4))>>2)];HEAP32[((($79)+(8))>>2)]=HEAP32[((($80)+(8))>>2)];HEAP32[((($79)+(12))>>2)]=HEAP32[((($80)+(12))>>2)];HEAP32[((($79)+(16))>>2)]=HEAP32[((($80)+(16))>>2)];HEAP32[((($79)+(20))>>2)]=HEAP32[((($80)+(20))>>2)];
      var $81=(($tm)|0);
      var $82=HEAPF32[(($81)>>2)];
      var $83=$3;
      var $84=($82)*($83);
      var $85=(($tm+4)|0);
      var $86=HEAPF32[(($85)>>2)];
      var $87=$5;
      var $88=($86)*($87);
      var $89=($84)+($88);
      var $90=$attr;
      var $91=(($90+16)|0);
      var $92=HEAP32[(($91)>>2)];
      var $93=(($92)|0);
      var $94=(($93)|0);
      HEAPF32[(($94)>>2)]=$89;
      var $95=(($tm)|0);
      var $96=HEAPF32[(($95)>>2)];
      var $97=$4;
      var $98=($96)*($97);
      var $99=(($tm+4)|0);
      var $100=HEAPF32[(($99)>>2)];
      var $101=$6;
      var $102=($100)*($101);
      var $103=($98)+($102);
      var $104=$attr;
      var $105=(($104+16)|0);
      var $106=HEAP32[(($105)>>2)];
      var $107=(($106)|0);
      var $108=(($107+4)|0);
      HEAPF32[(($108)>>2)]=$103;
      var $109=(($tm+8)|0);
      var $110=HEAPF32[(($109)>>2)];
      var $111=$3;
      var $112=($110)*($111);
      var $113=(($tm+12)|0);
      var $114=HEAPF32[(($113)>>2)];
      var $115=$5;
      var $116=($114)*($115);
      var $117=($112)+($116);
      var $118=$attr;
      var $119=(($118+16)|0);
      var $120=HEAP32[(($119)>>2)];
      var $121=(($120)|0);
      var $122=(($121+8)|0);
      HEAPF32[(($122)>>2)]=$117;
      var $123=(($tm+8)|0);
      var $124=HEAPF32[(($123)>>2)];
      var $125=$4;
      var $126=($124)*($125);
      var $127=(($tm+12)|0);
      var $128=HEAPF32[(($127)>>2)];
      var $129=$6;
      var $130=($128)*($129);
      var $131=($126)+($130);
      var $132=$attr;
      var $133=(($132+16)|0);
      var $134=HEAP32[(($133)>>2)];
      var $135=(($134)|0);
      var $136=(($135+12)|0);
      HEAPF32[(($136)>>2)]=$131;
      var $137=(($tm+16)|0);
      var $138=HEAPF32[(($137)>>2)];
      var $139=$7;
      var $140=(($tm)|0);
      var $141=HEAPF32[(($140)>>2)];
      var $142=($139)*($141);
      var $143=($138)+($142);
      var $144=$8;
      var $145=(($tm+8)|0);
      var $146=HEAPF32[(($145)>>2)];
      var $147=($144)*($146);
      var $148=($143)+($147);
      var $149=$attr;
      var $150=(($149+16)|0);
      var $151=HEAP32[(($150)>>2)];
      var $152=(($151)|0);
      var $153=(($152+16)|0);
      HEAPF32[(($153)>>2)]=$148;
      var $154=(($tm+20)|0);
      var $155=HEAPF32[(($154)>>2)];
      var $156=$7;
      var $157=(($tm+4)|0);
      var $158=HEAPF32[(($157)>>2)];
      var $159=($156)*($158);
      var $160=($155)+($159);
      var $161=$8;
      var $162=(($tm+12)|0);
      var $163=HEAPF32[(($162)>>2)];
      var $164=($161)*($163);
      var $165=($160)+($164);
      var $166=$attr;
      var $167=(($166+16)|0);
      var $168=HEAP32[(($167)>>2)];
      var $169=(($168)|0);
      var $170=(($169+20)|0);
      HEAPF32[(($170)>>2)]=$165;
      var $171=$ret;
      $1=$171;
      __label__ = 7; break;
    case 7: 
      var $173=$1;
      STACKTOP = __stackBase__;
      return $173;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Page_Concat["X"]=1;

function _HPDF_Page_MoveTo($page, $x, $y) {
  var __stackBase__  = STACKTOP; STACKTOP += 512; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $ret;
      var $buf=__stackBase__;
      var $pbuf;
      var $eptr;
      var $attr;
      $2=$page;
      $3=$x;
      $4=$y;
      var $5=$2;
      var $6=_HPDF_Page_CheckState($5, 3);
      $ret=$6;
      var $7=(($buf)|0);
      $pbuf=$7;
      var $8=(($buf)|0);
      var $9=(($8+512)|0);
      var $10=((($9)-(1))|0);
      $eptr=$10;
      var $11=$ret;
      var $12=(($11)|0)!=0;
      if ($12) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $14=$ret;
      $1=$14;
      __label__ = 7; break;
    case 4: 
      var $16=$2;
      var $17=(($16+44)|0);
      var $18=HEAP32[(($17)>>2)];
      var $19=$18;
      $attr=$19;
      var $20=(($buf)|0);
      var $21=_HPDF_MemSet($20, 0, 512);
      var $22=$pbuf;
      var $23=$3;
      var $24=$eptr;
      var $25=_HPDF_FToA($22, $23, $24);
      $pbuf=$25;
      var $26=$pbuf;
      var $27=(($26+1)|0);
      $pbuf=$27;
      HEAP8[($26)]=32;
      var $28=$pbuf;
      var $29=$4;
      var $30=$eptr;
      var $31=_HPDF_FToA($28, $29, $30);
      $pbuf=$31;
      var $32=$pbuf;
      var $33=$eptr;
      var $34=_HPDF_StrCpy($32, ((STRING_TABLE.__str101560)|0), $33);
      var $35=$attr;
      var $36=(($35+76)|0);
      var $37=HEAP32[(($36)>>2)];
      var $38=(($buf)|0);
      var $39=_HPDF_Stream_WriteStr($37, $38);
      $ret=$39;
      var $40=(($39)|0)!=0;
      if ($40) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $42=$2;
      var $43=(($42+12)|0);
      var $44=HEAP32[(($43)>>2)];
      var $45=_HPDF_CheckError($44);
      $1=$45;
      __label__ = 7; break;
    case 6: 
      var $47=$3;
      var $48=$attr;
      var $49=(($48+28)|0);
      var $50=(($49)|0);
      HEAPF32[(($50)>>2)]=$47;
      var $51=$4;
      var $52=$attr;
      var $53=(($52+28)|0);
      var $54=(($53+4)|0);
      HEAPF32[(($54)>>2)]=$51;
      var $55=$attr;
      var $56=(($55+20)|0);
      var $57=$attr;
      var $58=(($57+28)|0);
      var $59=$56;
      var $60=$58;
      assert(8 % 1 === 0, 'memcpy given ' + 8 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP32[(($59)>>2)]=HEAP32[(($60)>>2)];HEAP32[((($59)+(4))>>2)]=HEAP32[((($60)+(4))>>2)];
      var $61=$attr;
      var $62=(($61+68)|0);
      HEAP16[(($62)>>1)]=2;
      var $63=$ret;
      $1=$63;
      __label__ = 7; break;
    case 7: 
      var $65=$1;
      STACKTOP = __stackBase__;
      return $65;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Page_MoveTo["X"]=1;

function _HPDF_Page_LineTo($page, $x, $y) {
  var __stackBase__  = STACKTOP; STACKTOP += 512; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $ret;
      var $buf=__stackBase__;
      var $pbuf;
      var $eptr;
      var $attr;
      $2=$page;
      $3=$x;
      $4=$y;
      var $5=$2;
      var $6=_HPDF_Page_CheckState($5, 2);
      $ret=$6;
      var $7=(($buf)|0);
      $pbuf=$7;
      var $8=(($buf)|0);
      var $9=(($8+512)|0);
      var $10=((($9)-(1))|0);
      $eptr=$10;
      var $11=$ret;
      var $12=(($11)|0)!=0;
      if ($12) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $14=$ret;
      $1=$14;
      __label__ = 7; break;
    case 4: 
      var $16=$2;
      var $17=(($16+44)|0);
      var $18=HEAP32[(($17)>>2)];
      var $19=$18;
      $attr=$19;
      var $20=(($buf)|0);
      var $21=_HPDF_MemSet($20, 0, 512);
      var $22=$pbuf;
      var $23=$3;
      var $24=$eptr;
      var $25=_HPDF_FToA($22, $23, $24);
      $pbuf=$25;
      var $26=$pbuf;
      var $27=(($26+1)|0);
      $pbuf=$27;
      HEAP8[($26)]=32;
      var $28=$pbuf;
      var $29=$4;
      var $30=$eptr;
      var $31=_HPDF_FToA($28, $29, $30);
      $pbuf=$31;
      var $32=$pbuf;
      var $33=$eptr;
      var $34=_HPDF_StrCpy($32, ((STRING_TABLE.__str111561)|0), $33);
      var $35=$attr;
      var $36=(($35+76)|0);
      var $37=HEAP32[(($36)>>2)];
      var $38=(($buf)|0);
      var $39=_HPDF_Stream_WriteStr($37, $38);
      $ret=$39;
      var $40=(($39)|0)!=0;
      if ($40) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $42=$2;
      var $43=(($42+12)|0);
      var $44=HEAP32[(($43)>>2)];
      var $45=_HPDF_CheckError($44);
      $1=$45;
      __label__ = 7; break;
    case 6: 
      var $47=$3;
      var $48=$attr;
      var $49=(($48+28)|0);
      var $50=(($49)|0);
      HEAPF32[(($50)>>2)]=$47;
      var $51=$4;
      var $52=$attr;
      var $53=(($52+28)|0);
      var $54=(($53+4)|0);
      HEAPF32[(($54)>>2)]=$51;
      var $55=$ret;
      $1=$55;
      __label__ = 7; break;
    case 7: 
      var $57=$1;
      STACKTOP = __stackBase__;
      return $57;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Page_LineTo["X"]=1;

function _HPDF_Page_CurveTo($page, $x1, $y1, $x2, $y2, $x3, $y3) {
  var __stackBase__  = STACKTOP; STACKTOP += 512; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $5;
      var $6;
      var $7;
      var $8;
      var $ret;
      var $buf=__stackBase__;
      var $pbuf;
      var $eptr;
      var $attr;
      $2=$page;
      $3=$x1;
      $4=$y1;
      $5=$x2;
      $6=$y2;
      $7=$x3;
      $8=$y3;
      var $9=$2;
      var $10=_HPDF_Page_CheckState($9, 2);
      $ret=$10;
      var $11=(($buf)|0);
      $pbuf=$11;
      var $12=(($buf)|0);
      var $13=(($12+512)|0);
      var $14=((($13)-(1))|0);
      $eptr=$14;
      var $15=$ret;
      var $16=(($15)|0)!=0;
      if ($16) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $18=$ret;
      $1=$18;
      __label__ = 7; break;
    case 4: 
      var $20=$2;
      var $21=(($20+44)|0);
      var $22=HEAP32[(($21)>>2)];
      var $23=$22;
      $attr=$23;
      var $24=(($buf)|0);
      var $25=_HPDF_MemSet($24, 0, 512);
      var $26=$pbuf;
      var $27=$3;
      var $28=$eptr;
      var $29=_HPDF_FToA($26, $27, $28);
      $pbuf=$29;
      var $30=$pbuf;
      var $31=(($30+1)|0);
      $pbuf=$31;
      HEAP8[($30)]=32;
      var $32=$pbuf;
      var $33=$4;
      var $34=$eptr;
      var $35=_HPDF_FToA($32, $33, $34);
      $pbuf=$35;
      var $36=$pbuf;
      var $37=(($36+1)|0);
      $pbuf=$37;
      HEAP8[($36)]=32;
      var $38=$pbuf;
      var $39=$5;
      var $40=$eptr;
      var $41=_HPDF_FToA($38, $39, $40);
      $pbuf=$41;
      var $42=$pbuf;
      var $43=(($42+1)|0);
      $pbuf=$43;
      HEAP8[($42)]=32;
      var $44=$pbuf;
      var $45=$6;
      var $46=$eptr;
      var $47=_HPDF_FToA($44, $45, $46);
      $pbuf=$47;
      var $48=$pbuf;
      var $49=(($48+1)|0);
      $pbuf=$49;
      HEAP8[($48)]=32;
      var $50=$pbuf;
      var $51=$7;
      var $52=$eptr;
      var $53=_HPDF_FToA($50, $51, $52);
      $pbuf=$53;
      var $54=$pbuf;
      var $55=(($54+1)|0);
      $pbuf=$55;
      HEAP8[($54)]=32;
      var $56=$pbuf;
      var $57=$8;
      var $58=$eptr;
      var $59=_HPDF_FToA($56, $57, $58);
      $pbuf=$59;
      var $60=$pbuf;
      var $61=$eptr;
      var $62=_HPDF_StrCpy($60, ((STRING_TABLE.__str121562)|0), $61);
      var $63=$attr;
      var $64=(($63+76)|0);
      var $65=HEAP32[(($64)>>2)];
      var $66=(($buf)|0);
      var $67=_HPDF_Stream_WriteStr($65, $66);
      $ret=$67;
      var $68=(($67)|0)!=0;
      if ($68) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $70=$2;
      var $71=(($70+12)|0);
      var $72=HEAP32[(($71)>>2)];
      var $73=_HPDF_CheckError($72);
      $1=$73;
      __label__ = 7; break;
    case 6: 
      var $75=$7;
      var $76=$attr;
      var $77=(($76+28)|0);
      var $78=(($77)|0);
      HEAPF32[(($78)>>2)]=$75;
      var $79=$8;
      var $80=$attr;
      var $81=(($80+28)|0);
      var $82=(($81+4)|0);
      HEAPF32[(($82)>>2)]=$79;
      var $83=$ret;
      $1=$83;
      __label__ = 7; break;
    case 7: 
      var $85=$1;
      STACKTOP = __stackBase__;
      return $85;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Page_CurveTo["X"]=1;

function _HPDF_Page_CurveTo2($page, $x2, $y2, $x3, $y3) {
  var __stackBase__  = STACKTOP; STACKTOP += 512; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $5;
      var $6;
      var $ret;
      var $buf=__stackBase__;
      var $pbuf;
      var $eptr;
      var $attr;
      $2=$page;
      $3=$x2;
      $4=$y2;
      $5=$x3;
      $6=$y3;
      var $7=$2;
      var $8=_HPDF_Page_CheckState($7, 2);
      $ret=$8;
      var $9=(($buf)|0);
      $pbuf=$9;
      var $10=(($buf)|0);
      var $11=(($10+512)|0);
      var $12=((($11)-(1))|0);
      $eptr=$12;
      var $13=$ret;
      var $14=(($13)|0)!=0;
      if ($14) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $16=$ret;
      $1=$16;
      __label__ = 7; break;
    case 4: 
      var $18=$2;
      var $19=(($18+44)|0);
      var $20=HEAP32[(($19)>>2)];
      var $21=$20;
      $attr=$21;
      var $22=(($buf)|0);
      var $23=_HPDF_MemSet($22, 0, 512);
      var $24=$pbuf;
      var $25=$3;
      var $26=$eptr;
      var $27=_HPDF_FToA($24, $25, $26);
      $pbuf=$27;
      var $28=$pbuf;
      var $29=(($28+1)|0);
      $pbuf=$29;
      HEAP8[($28)]=32;
      var $30=$pbuf;
      var $31=$4;
      var $32=$eptr;
      var $33=_HPDF_FToA($30, $31, $32);
      $pbuf=$33;
      var $34=$pbuf;
      var $35=(($34+1)|0);
      $pbuf=$35;
      HEAP8[($34)]=32;
      var $36=$pbuf;
      var $37=$5;
      var $38=$eptr;
      var $39=_HPDF_FToA($36, $37, $38);
      $pbuf=$39;
      var $40=$pbuf;
      var $41=(($40+1)|0);
      $pbuf=$41;
      HEAP8[($40)]=32;
      var $42=$pbuf;
      var $43=$6;
      var $44=$eptr;
      var $45=_HPDF_FToA($42, $43, $44);
      $pbuf=$45;
      var $46=$pbuf;
      var $47=$eptr;
      var $48=_HPDF_StrCpy($46, ((STRING_TABLE.__str131563)|0), $47);
      var $49=$attr;
      var $50=(($49+76)|0);
      var $51=HEAP32[(($50)>>2)];
      var $52=(($buf)|0);
      var $53=_HPDF_Stream_WriteStr($51, $52);
      $ret=$53;
      var $54=(($53)|0)!=0;
      if ($54) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $56=$2;
      var $57=(($56+12)|0);
      var $58=HEAP32[(($57)>>2)];
      var $59=_HPDF_CheckError($58);
      $1=$59;
      __label__ = 7; break;
    case 6: 
      var $61=$5;
      var $62=$attr;
      var $63=(($62+28)|0);
      var $64=(($63)|0);
      HEAPF32[(($64)>>2)]=$61;
      var $65=$6;
      var $66=$attr;
      var $67=(($66+28)|0);
      var $68=(($67+4)|0);
      HEAPF32[(($68)>>2)]=$65;
      var $69=$ret;
      $1=$69;
      __label__ = 7; break;
    case 7: 
      var $71=$1;
      STACKTOP = __stackBase__;
      return $71;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Page_CurveTo2["X"]=1;

function _HPDF_Page_CurveTo3($page, $x1, $y1, $x3, $y3) {
  var __stackBase__  = STACKTOP; STACKTOP += 512; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $5;
      var $6;
      var $ret;
      var $buf=__stackBase__;
      var $pbuf;
      var $eptr;
      var $attr;
      $2=$page;
      $3=$x1;
      $4=$y1;
      $5=$x3;
      $6=$y3;
      var $7=$2;
      var $8=_HPDF_Page_CheckState($7, 2);
      $ret=$8;
      var $9=(($buf)|0);
      $pbuf=$9;
      var $10=(($buf)|0);
      var $11=(($10+512)|0);
      var $12=((($11)-(1))|0);
      $eptr=$12;
      var $13=$ret;
      var $14=(($13)|0)!=0;
      if ($14) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $16=$ret;
      $1=$16;
      __label__ = 7; break;
    case 4: 
      var $18=$2;
      var $19=(($18+44)|0);
      var $20=HEAP32[(($19)>>2)];
      var $21=$20;
      $attr=$21;
      var $22=(($buf)|0);
      var $23=_HPDF_MemSet($22, 0, 512);
      var $24=$pbuf;
      var $25=$3;
      var $26=$eptr;
      var $27=_HPDF_FToA($24, $25, $26);
      $pbuf=$27;
      var $28=$pbuf;
      var $29=(($28+1)|0);
      $pbuf=$29;
      HEAP8[($28)]=32;
      var $30=$pbuf;
      var $31=$4;
      var $32=$eptr;
      var $33=_HPDF_FToA($30, $31, $32);
      $pbuf=$33;
      var $34=$pbuf;
      var $35=(($34+1)|0);
      $pbuf=$35;
      HEAP8[($34)]=32;
      var $36=$pbuf;
      var $37=$5;
      var $38=$eptr;
      var $39=_HPDF_FToA($36, $37, $38);
      $pbuf=$39;
      var $40=$pbuf;
      var $41=(($40+1)|0);
      $pbuf=$41;
      HEAP8[($40)]=32;
      var $42=$pbuf;
      var $43=$6;
      var $44=$eptr;
      var $45=_HPDF_FToA($42, $43, $44);
      $pbuf=$45;
      var $46=$pbuf;
      var $47=$eptr;
      var $48=_HPDF_StrCpy($46, ((STRING_TABLE.__str141564)|0), $47);
      var $49=$attr;
      var $50=(($49+76)|0);
      var $51=HEAP32[(($50)>>2)];
      var $52=(($buf)|0);
      var $53=_HPDF_Stream_WriteStr($51, $52);
      $ret=$53;
      var $54=(($53)|0)!=0;
      if ($54) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $56=$2;
      var $57=(($56+12)|0);
      var $58=HEAP32[(($57)>>2)];
      var $59=_HPDF_CheckError($58);
      $1=$59;
      __label__ = 7; break;
    case 6: 
      var $61=$5;
      var $62=$attr;
      var $63=(($62+28)|0);
      var $64=(($63)|0);
      HEAPF32[(($64)>>2)]=$61;
      var $65=$6;
      var $66=$attr;
      var $67=(($66+28)|0);
      var $68=(($67+4)|0);
      HEAPF32[(($68)>>2)]=$65;
      var $69=$ret;
      $1=$69;
      __label__ = 7; break;
    case 7: 
      var $71=$1;
      STACKTOP = __stackBase__;
      return $71;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Page_CurveTo3["X"]=1;

function _HPDF_Page_ClosePath($page) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $ret;
      var $attr;
      $2=$page;
      var $3=$2;
      var $4=_HPDF_Page_CheckState($3, 2);
      $ret=$4;
      var $5=$ret;
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $8=$ret;
      $1=$8;
      __label__ = 7; break;
    case 4: 
      var $10=$2;
      var $11=(($10+44)|0);
      var $12=HEAP32[(($11)>>2)];
      var $13=$12;
      $attr=$13;
      var $14=$attr;
      var $15=(($14+76)|0);
      var $16=HEAP32[(($15)>>2)];
      var $17=_HPDF_Stream_WriteStr($16, ((STRING_TABLE.__str151565)|0));
      $ret=$17;
      var $18=(($17)|0)!=0;
      if ($18) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $20=$2;
      var $21=(($20+12)|0);
      var $22=HEAP32[(($21)>>2)];
      var $23=_HPDF_CheckError($22);
      $1=$23;
      __label__ = 7; break;
    case 6: 
      var $25=$attr;
      var $26=(($25+28)|0);
      var $27=$attr;
      var $28=(($27+20)|0);
      var $29=$26;
      var $30=$28;
      assert(8 % 1 === 0, 'memcpy given ' + 8 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP32[(($29)>>2)]=HEAP32[(($30)>>2)];HEAP32[((($29)+(4))>>2)]=HEAP32[((($30)+(4))>>2)];
      var $31=$ret;
      $1=$31;
      __label__ = 7; break;
    case 7: 
      var $33=$1;
      ;
      return $33;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Page_Rectangle($page, $x, $y, $width, $height) {
  var __stackBase__  = STACKTOP; STACKTOP += 512; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $5;
      var $6;
      var $ret;
      var $buf=__stackBase__;
      var $pbuf;
      var $eptr;
      var $attr;
      $2=$page;
      $3=$x;
      $4=$y;
      $5=$width;
      $6=$height;
      var $7=$2;
      var $8=_HPDF_Page_CheckState($7, 3);
      $ret=$8;
      var $9=(($buf)|0);
      $pbuf=$9;
      var $10=(($buf)|0);
      var $11=(($10+512)|0);
      var $12=((($11)-(1))|0);
      $eptr=$12;
      var $13=$ret;
      var $14=(($13)|0)!=0;
      if ($14) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $16=$ret;
      $1=$16;
      __label__ = 7; break;
    case 4: 
      var $18=$2;
      var $19=(($18+44)|0);
      var $20=HEAP32[(($19)>>2)];
      var $21=$20;
      $attr=$21;
      var $22=(($buf)|0);
      var $23=_HPDF_MemSet($22, 0, 512);
      var $24=$pbuf;
      var $25=$3;
      var $26=$eptr;
      var $27=_HPDF_FToA($24, $25, $26);
      $pbuf=$27;
      var $28=$pbuf;
      var $29=(($28+1)|0);
      $pbuf=$29;
      HEAP8[($28)]=32;
      var $30=$pbuf;
      var $31=$4;
      var $32=$eptr;
      var $33=_HPDF_FToA($30, $31, $32);
      $pbuf=$33;
      var $34=$pbuf;
      var $35=(($34+1)|0);
      $pbuf=$35;
      HEAP8[($34)]=32;
      var $36=$pbuf;
      var $37=$5;
      var $38=$eptr;
      var $39=_HPDF_FToA($36, $37, $38);
      $pbuf=$39;
      var $40=$pbuf;
      var $41=(($40+1)|0);
      $pbuf=$41;
      HEAP8[($40)]=32;
      var $42=$pbuf;
      var $43=$6;
      var $44=$eptr;
      var $45=_HPDF_FToA($42, $43, $44);
      $pbuf=$45;
      var $46=$pbuf;
      var $47=$eptr;
      var $48=_HPDF_StrCpy($46, ((STRING_TABLE.__str161566)|0), $47);
      var $49=$attr;
      var $50=(($49+76)|0);
      var $51=HEAP32[(($50)>>2)];
      var $52=(($buf)|0);
      var $53=_HPDF_Stream_WriteStr($51, $52);
      $ret=$53;
      var $54=(($53)|0)!=0;
      if ($54) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $56=$2;
      var $57=(($56+12)|0);
      var $58=HEAP32[(($57)>>2)];
      var $59=_HPDF_CheckError($58);
      $1=$59;
      __label__ = 7; break;
    case 6: 
      var $61=$3;
      var $62=$attr;
      var $63=(($62+28)|0);
      var $64=(($63)|0);
      HEAPF32[(($64)>>2)]=$61;
      var $65=$4;
      var $66=$attr;
      var $67=(($66+28)|0);
      var $68=(($67+4)|0);
      HEAPF32[(($68)>>2)]=$65;
      var $69=$attr;
      var $70=(($69+20)|0);
      var $71=$attr;
      var $72=(($71+28)|0);
      var $73=$70;
      var $74=$72;
      assert(8 % 1 === 0, 'memcpy given ' + 8 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP32[(($73)>>2)]=HEAP32[(($74)>>2)];HEAP32[((($73)+(4))>>2)]=HEAP32[((($74)+(4))>>2)];
      var $75=$attr;
      var $76=(($75+68)|0);
      HEAP16[(($76)>>1)]=2;
      var $77=$ret;
      $1=$77;
      __label__ = 7; break;
    case 7: 
      var $79=$1;
      STACKTOP = __stackBase__;
      return $79;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Page_Rectangle["X"]=1;

function _HPDF_Page_Stroke($page) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $ret;
      var $attr;
      $2=$page;
      var $3=$2;
      var $4=_HPDF_Page_CheckState($3, 10);
      $ret=$4;
      var $5=$ret;
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $8=$ret;
      $1=$8;
      __label__ = 7; break;
    case 4: 
      var $10=$2;
      var $11=(($10+44)|0);
      var $12=HEAP32[(($11)>>2)];
      var $13=$12;
      $attr=$13;
      var $14=$attr;
      var $15=(($14+76)|0);
      var $16=HEAP32[(($15)>>2)];
      var $17=_HPDF_Stream_WriteStr($16, ((STRING_TABLE.__str171567)|0));
      $ret=$17;
      var $18=(($17)|0)!=0;
      if ($18) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $20=$2;
      var $21=(($20+12)|0);
      var $22=HEAP32[(($21)>>2)];
      var $23=_HPDF_CheckError($22);
      $1=$23;
      __label__ = 7; break;
    case 6: 
      var $25=$attr;
      var $26=(($25+68)|0);
      HEAP16[(($26)>>1)]=1;
      var $27=$attr;
      var $28=(($27+28)|0);
      var $29=$28;
      assert(8 % 1 === 0, 'memcpy given ' + 8 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP32[(($29)>>2)]=HEAP32[((_INIT_POS)>>2)];HEAP32[((($29)+(4))>>2)]=HEAP32[(((_INIT_POS)+(4))>>2)];
      var $30=$ret;
      $1=$30;
      __label__ = 7; break;
    case 7: 
      var $32=$1;
      ;
      return $32;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Page_ClosePathStroke($page) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $ret;
      var $attr;
      $2=$page;
      var $3=$2;
      var $4=_HPDF_Page_CheckState($3, 10);
      $ret=$4;
      var $5=$ret;
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $8=$ret;
      $1=$8;
      __label__ = 7; break;
    case 4: 
      var $10=$2;
      var $11=(($10+44)|0);
      var $12=HEAP32[(($11)>>2)];
      var $13=$12;
      $attr=$13;
      var $14=$attr;
      var $15=(($14+76)|0);
      var $16=HEAP32[(($15)>>2)];
      var $17=_HPDF_Stream_WriteStr($16, ((STRING_TABLE.__str181568)|0));
      $ret=$17;
      var $18=(($17)|0)!=0;
      if ($18) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $20=$2;
      var $21=(($20+12)|0);
      var $22=HEAP32[(($21)>>2)];
      var $23=_HPDF_CheckError($22);
      $1=$23;
      __label__ = 7; break;
    case 6: 
      var $25=$attr;
      var $26=(($25+68)|0);
      HEAP16[(($26)>>1)]=1;
      var $27=$attr;
      var $28=(($27+28)|0);
      var $29=$28;
      assert(8 % 1 === 0, 'memcpy given ' + 8 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP32[(($29)>>2)]=HEAP32[((_INIT_POS)>>2)];HEAP32[((($29)+(4))>>2)]=HEAP32[(((_INIT_POS)+(4))>>2)];
      var $30=$ret;
      $1=$30;
      __label__ = 7; break;
    case 7: 
      var $32=$1;
      ;
      return $32;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Page_Fill($page) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $ret;
      var $attr;
      $2=$page;
      var $3=$2;
      var $4=_HPDF_Page_CheckState($3, 10);
      $ret=$4;
      var $5=$ret;
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $8=$ret;
      $1=$8;
      __label__ = 7; break;
    case 4: 
      var $10=$2;
      var $11=(($10+44)|0);
      var $12=HEAP32[(($11)>>2)];
      var $13=$12;
      $attr=$13;
      var $14=$attr;
      var $15=(($14+76)|0);
      var $16=HEAP32[(($15)>>2)];
      var $17=_HPDF_Stream_WriteStr($16, ((STRING_TABLE.__str191569)|0));
      $ret=$17;
      var $18=(($17)|0)!=0;
      if ($18) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $20=$2;
      var $21=(($20+12)|0);
      var $22=HEAP32[(($21)>>2)];
      var $23=_HPDF_CheckError($22);
      $1=$23;
      __label__ = 7; break;
    case 6: 
      var $25=$attr;
      var $26=(($25+68)|0);
      HEAP16[(($26)>>1)]=1;
      var $27=$attr;
      var $28=(($27+28)|0);
      var $29=$28;
      assert(8 % 1 === 0, 'memcpy given ' + 8 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP32[(($29)>>2)]=HEAP32[((_INIT_POS)>>2)];HEAP32[((($29)+(4))>>2)]=HEAP32[(((_INIT_POS)+(4))>>2)];
      var $30=$ret;
      $1=$30;
      __label__ = 7; break;
    case 7: 
      var $32=$1;
      ;
      return $32;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Page_Eofill($page) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $ret;
      var $attr;
      $2=$page;
      var $3=$2;
      var $4=_HPDF_Page_CheckState($3, 10);
      $ret=$4;
      var $5=$ret;
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $8=$ret;
      $1=$8;
      __label__ = 7; break;
    case 4: 
      var $10=$2;
      var $11=(($10+44)|0);
      var $12=HEAP32[(($11)>>2)];
      var $13=$12;
      $attr=$13;
      var $14=$attr;
      var $15=(($14+76)|0);
      var $16=HEAP32[(($15)>>2)];
      var $17=_HPDF_Stream_WriteStr($16, ((STRING_TABLE.__str201570)|0));
      $ret=$17;
      var $18=(($17)|0)!=0;
      if ($18) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $20=$2;
      var $21=(($20+12)|0);
      var $22=HEAP32[(($21)>>2)];
      var $23=_HPDF_CheckError($22);
      $1=$23;
      __label__ = 7; break;
    case 6: 
      var $25=$attr;
      var $26=(($25+68)|0);
      HEAP16[(($26)>>1)]=1;
      var $27=$attr;
      var $28=(($27+28)|0);
      var $29=$28;
      assert(8 % 1 === 0, 'memcpy given ' + 8 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP32[(($29)>>2)]=HEAP32[((_INIT_POS)>>2)];HEAP32[((($29)+(4))>>2)]=HEAP32[(((_INIT_POS)+(4))>>2)];
      var $30=$ret;
      $1=$30;
      __label__ = 7; break;
    case 7: 
      var $32=$1;
      ;
      return $32;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Page_FillStroke($page) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $ret;
      var $attr;
      $2=$page;
      var $3=$2;
      var $4=_HPDF_Page_CheckState($3, 10);
      $ret=$4;
      var $5=$ret;
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $8=$ret;
      $1=$8;
      __label__ = 7; break;
    case 4: 
      var $10=$2;
      var $11=(($10+44)|0);
      var $12=HEAP32[(($11)>>2)];
      var $13=$12;
      $attr=$13;
      var $14=$attr;
      var $15=(($14+76)|0);
      var $16=HEAP32[(($15)>>2)];
      var $17=_HPDF_Stream_WriteStr($16, ((STRING_TABLE.__str211571)|0));
      $ret=$17;
      var $18=(($17)|0)!=0;
      if ($18) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $20=$2;
      var $21=(($20+12)|0);
      var $22=HEAP32[(($21)>>2)];
      var $23=_HPDF_CheckError($22);
      $1=$23;
      __label__ = 7; break;
    case 6: 
      var $25=$attr;
      var $26=(($25+68)|0);
      HEAP16[(($26)>>1)]=1;
      var $27=$attr;
      var $28=(($27+28)|0);
      var $29=$28;
      assert(8 % 1 === 0, 'memcpy given ' + 8 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP32[(($29)>>2)]=HEAP32[((_INIT_POS)>>2)];HEAP32[((($29)+(4))>>2)]=HEAP32[(((_INIT_POS)+(4))>>2)];
      var $30=$ret;
      $1=$30;
      __label__ = 7; break;
    case 7: 
      var $32=$1;
      ;
      return $32;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Page_EofillStroke($page) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $ret;
      var $attr;
      $2=$page;
      var $3=$2;
      var $4=_HPDF_Page_CheckState($3, 10);
      $ret=$4;
      var $5=$ret;
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $8=$ret;
      $1=$8;
      __label__ = 7; break;
    case 4: 
      var $10=$2;
      var $11=(($10+44)|0);
      var $12=HEAP32[(($11)>>2)];
      var $13=$12;
      $attr=$13;
      var $14=$attr;
      var $15=(($14+76)|0);
      var $16=HEAP32[(($15)>>2)];
      var $17=_HPDF_Stream_WriteStr($16, ((STRING_TABLE.__str221572)|0));
      $ret=$17;
      var $18=(($17)|0)!=0;
      if ($18) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $20=$2;
      var $21=(($20+12)|0);
      var $22=HEAP32[(($21)>>2)];
      var $23=_HPDF_CheckError($22);
      $1=$23;
      __label__ = 7; break;
    case 6: 
      var $25=$attr;
      var $26=(($25+68)|0);
      HEAP16[(($26)>>1)]=1;
      var $27=$ret;
      $1=$27;
      __label__ = 7; break;
    case 7: 
      var $29=$1;
      ;
      return $29;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Page_ClosePathFillStroke($page) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $ret;
      var $attr;
      $2=$page;
      var $3=$2;
      var $4=_HPDF_Page_CheckState($3, 10);
      $ret=$4;
      var $5=$ret;
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $8=$ret;
      $1=$8;
      __label__ = 7; break;
    case 4: 
      var $10=$2;
      var $11=(($10+44)|0);
      var $12=HEAP32[(($11)>>2)];
      var $13=$12;
      $attr=$13;
      var $14=$attr;
      var $15=(($14+76)|0);
      var $16=HEAP32[(($15)>>2)];
      var $17=_HPDF_Stream_WriteStr($16, ((STRING_TABLE.__str231573)|0));
      $ret=$17;
      var $18=(($17)|0)!=0;
      if ($18) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $20=$2;
      var $21=(($20+12)|0);
      var $22=HEAP32[(($21)>>2)];
      var $23=_HPDF_CheckError($22);
      $1=$23;
      __label__ = 7; break;
    case 6: 
      var $25=$attr;
      var $26=(($25+68)|0);
      HEAP16[(($26)>>1)]=1;
      var $27=$attr;
      var $28=(($27+28)|0);
      var $29=$28;
      assert(8 % 1 === 0, 'memcpy given ' + 8 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP32[(($29)>>2)]=HEAP32[((_INIT_POS)>>2)];HEAP32[((($29)+(4))>>2)]=HEAP32[(((_INIT_POS)+(4))>>2)];
      var $30=$ret;
      $1=$30;
      __label__ = 7; break;
    case 7: 
      var $32=$1;
      ;
      return $32;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Page_ClosePathEofillStroke($page) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $ret;
      var $attr;
      $2=$page;
      var $3=$2;
      var $4=_HPDF_Page_CheckState($3, 10);
      $ret=$4;
      var $5=$ret;
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $8=$ret;
      $1=$8;
      __label__ = 7; break;
    case 4: 
      var $10=$2;
      var $11=(($10+44)|0);
      var $12=HEAP32[(($11)>>2)];
      var $13=$12;
      $attr=$13;
      var $14=$attr;
      var $15=(($14+76)|0);
      var $16=HEAP32[(($15)>>2)];
      var $17=_HPDF_Stream_WriteStr($16, ((STRING_TABLE.__str241574)|0));
      $ret=$17;
      var $18=(($17)|0)!=0;
      if ($18) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $20=$2;
      var $21=(($20+12)|0);
      var $22=HEAP32[(($21)>>2)];
      var $23=_HPDF_CheckError($22);
      $1=$23;
      __label__ = 7; break;
    case 6: 
      var $25=$attr;
      var $26=(($25+68)|0);
      HEAP16[(($26)>>1)]=1;
      var $27=$attr;
      var $28=(($27+28)|0);
      var $29=$28;
      assert(8 % 1 === 0, 'memcpy given ' + 8 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP32[(($29)>>2)]=HEAP32[((_INIT_POS)>>2)];HEAP32[((($29)+(4))>>2)]=HEAP32[(((_INIT_POS)+(4))>>2)];
      var $30=$ret;
      $1=$30;
      __label__ = 7; break;
    case 7: 
      var $32=$1;
      ;
      return $32;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Page_EndPath($page) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $ret;
      var $attr;
      $2=$page;
      var $3=$2;
      var $4=_HPDF_Page_CheckState($3, 10);
      $ret=$4;
      var $5=$ret;
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $8=$ret;
      $1=$8;
      __label__ = 7; break;
    case 4: 
      var $10=$2;
      var $11=(($10+44)|0);
      var $12=HEAP32[(($11)>>2)];
      var $13=$12;
      $attr=$13;
      var $14=$attr;
      var $15=(($14+76)|0);
      var $16=HEAP32[(($15)>>2)];
      var $17=_HPDF_Stream_WriteStr($16, ((STRING_TABLE.__str251575)|0));
      $ret=$17;
      var $18=(($17)|0)!=0;
      if ($18) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $20=$2;
      var $21=(($20+12)|0);
      var $22=HEAP32[(($21)>>2)];
      var $23=_HPDF_CheckError($22);
      $1=$23;
      __label__ = 7; break;
    case 6: 
      var $25=$attr;
      var $26=(($25+68)|0);
      HEAP16[(($26)>>1)]=1;
      var $27=$attr;
      var $28=(($27+28)|0);
      var $29=$28;
      assert(8 % 1 === 0, 'memcpy given ' + 8 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP32[(($29)>>2)]=HEAP32[((_INIT_POS)>>2)];HEAP32[((($29)+(4))>>2)]=HEAP32[(((_INIT_POS)+(4))>>2)];
      var $30=$ret;
      $1=$30;
      __label__ = 7; break;
    case 7: 
      var $32=$1;
      ;
      return $32;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Page_Clip($page) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $ret;
      var $attr;
      $2=$page;
      var $3=$2;
      var $4=_HPDF_Page_CheckState($3, 2);
      $ret=$4;
      var $5=$ret;
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $8=$ret;
      $1=$8;
      __label__ = 7; break;
    case 4: 
      var $10=$2;
      var $11=(($10+44)|0);
      var $12=HEAP32[(($11)>>2)];
      var $13=$12;
      $attr=$13;
      var $14=$attr;
      var $15=(($14+76)|0);
      var $16=HEAP32[(($15)>>2)];
      var $17=_HPDF_Stream_WriteStr($16, ((STRING_TABLE.__str261576)|0));
      $ret=$17;
      var $18=(($17)|0)!=0;
      if ($18) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $20=$2;
      var $21=(($20+12)|0);
      var $22=HEAP32[(($21)>>2)];
      var $23=_HPDF_CheckError($22);
      $1=$23;
      __label__ = 7; break;
    case 6: 
      var $25=$attr;
      var $26=(($25+68)|0);
      HEAP16[(($26)>>1)]=8;
      var $27=$ret;
      $1=$27;
      __label__ = 7; break;
    case 7: 
      var $29=$1;
      ;
      return $29;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Page_Eoclip($page) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $ret;
      var $attr;
      $2=$page;
      var $3=$2;
      var $4=_HPDF_Page_CheckState($3, 2);
      $ret=$4;
      var $5=$ret;
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $8=$ret;
      $1=$8;
      __label__ = 7; break;
    case 4: 
      var $10=$2;
      var $11=(($10+44)|0);
      var $12=HEAP32[(($11)>>2)];
      var $13=$12;
      $attr=$13;
      var $14=$attr;
      var $15=(($14+76)|0);
      var $16=HEAP32[(($15)>>2)];
      var $17=_HPDF_Stream_WriteStr($16, ((STRING_TABLE.__str271577)|0));
      $ret=$17;
      var $18=(($17)|0)!=0;
      if ($18) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $20=$2;
      var $21=(($20+12)|0);
      var $22=HEAP32[(($21)>>2)];
      var $23=_HPDF_CheckError($22);
      $1=$23;
      __label__ = 7; break;
    case 6: 
      var $25=$attr;
      var $26=(($25+68)|0);
      HEAP16[(($26)>>1)]=8;
      var $27=$ret;
      $1=$27;
      __label__ = 7; break;
    case 7: 
      var $29=$1;
      ;
      return $29;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Page_BeginText($page) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $ret;
      var $attr;
      $2=$page;
      var $3=$2;
      var $4=_HPDF_Page_CheckState($3, 1);
      $ret=$4;
      var $5=$ret;
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $8=$ret;
      $1=$8;
      __label__ = 7; break;
    case 4: 
      var $10=$2;
      var $11=(($10+44)|0);
      var $12=HEAP32[(($11)>>2)];
      var $13=$12;
      $attr=$13;
      var $14=$attr;
      var $15=(($14+76)|0);
      var $16=HEAP32[(($15)>>2)];
      var $17=_HPDF_Stream_WriteStr($16, ((STRING_TABLE.__str281578)|0));
      $ret=$17;
      var $18=(($17)|0)!=0;
      if ($18) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $20=$2;
      var $21=(($20+12)|0);
      var $22=HEAP32[(($21)>>2)];
      var $23=_HPDF_CheckError($22);
      $1=$23;
      __label__ = 7; break;
    case 6: 
      var $25=$attr;
      var $26=(($25+68)|0);
      HEAP16[(($26)>>1)]=4;
      var $27=$attr;
      var $28=(($27+36)|0);
      var $29=$28;
      assert(8 % 1 === 0, 'memcpy given ' + 8 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP32[(($29)>>2)]=HEAP32[((_INIT_POS)>>2)];HEAP32[((($29)+(4))>>2)]=HEAP32[(((_INIT_POS)+(4))>>2)];
      var $30=$attr;
      var $31=(($30+44)|0);
      var $32=$31;
      assert(24 % 1 === 0, 'memcpy given ' + 24 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP32[(($32)>>2)]=HEAP32[((_HPDF_Page_BeginText_INIT_MATRIX)>>2)];HEAP32[((($32)+(4))>>2)]=HEAP32[(((_HPDF_Page_BeginText_INIT_MATRIX)+(4))>>2)];HEAP32[((($32)+(8))>>2)]=HEAP32[(((_HPDF_Page_BeginText_INIT_MATRIX)+(8))>>2)];HEAP32[((($32)+(12))>>2)]=HEAP32[(((_HPDF_Page_BeginText_INIT_MATRIX)+(12))>>2)];HEAP32[((($32)+(16))>>2)]=HEAP32[(((_HPDF_Page_BeginText_INIT_MATRIX)+(16))>>2)];HEAP32[((($32)+(20))>>2)]=HEAP32[(((_HPDF_Page_BeginText_INIT_MATRIX)+(20))>>2)];
      var $33=$ret;
      $1=$33;
      __label__ = 7; break;
    case 7: 
      var $35=$1;
      ;
      return $35;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Page_EndText($page) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $ret;
      var $attr;
      $2=$page;
      var $3=$2;
      var $4=_HPDF_Page_CheckState($3, 4);
      $ret=$4;
      var $5=$ret;
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $8=$ret;
      $1=$8;
      __label__ = 7; break;
    case 4: 
      var $10=$2;
      var $11=(($10+44)|0);
      var $12=HEAP32[(($11)>>2)];
      var $13=$12;
      $attr=$13;
      var $14=$attr;
      var $15=(($14+76)|0);
      var $16=HEAP32[(($15)>>2)];
      var $17=_HPDF_Stream_WriteStr($16, ((STRING_TABLE.__str291579)|0));
      $ret=$17;
      var $18=(($17)|0)!=0;
      if ($18) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $20=$2;
      var $21=(($20+12)|0);
      var $22=HEAP32[(($21)>>2)];
      var $23=_HPDF_CheckError($22);
      $1=$23;
      __label__ = 7; break;
    case 6: 
      var $25=$attr;
      var $26=(($25+36)|0);
      var $27=$26;
      assert(8 % 1 === 0, 'memcpy given ' + 8 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP32[(($27)>>2)]=HEAP32[((_INIT_POS)>>2)];HEAP32[((($27)+(4))>>2)]=HEAP32[(((_INIT_POS)+(4))>>2)];
      var $28=$attr;
      var $29=(($28+68)|0);
      HEAP16[(($29)>>1)]=1;
      var $30=$ret;
      $1=$30;
      __label__ = 7; break;
    case 7: 
      var $32=$1;
      ;
      return $32;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Page_SetCharSpace($page, $value) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $ret;
      var $attr;
      $2=$page;
      $3=$value;
      var $4=$2;
      var $5=_HPDF_Page_CheckState($4, 5);
      $ret=$5;
      var $6=$ret;
      var $7=(($6)|0)!=0;
      if ($7) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $9=$ret;
      $1=$9;
      __label__ = 12; break;
    case 4: 
      var $11=$2;
      var $12=(($11+44)|0);
      var $13=HEAP32[(($12)>>2)];
      var $14=$13;
      $attr=$14;
      var $15=$3;
      var $16=$15 < -30;
      if ($16) { __label__ = 6; break; } else { __label__ = 5; break; }
    case 5: 
      var $18=$3;
      var $19=$18 > 300;
      if ($19) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      var $21=$2;
      var $22=(($21+12)|0);
      var $23=HEAP32[(($22)>>2)];
      var $24=_HPDF_RaiseError($23, 4182, 0);
      $1=$24;
      __label__ = 12; break;
    case 7: 
      var $26=$attr;
      var $27=(($26+76)|0);
      var $28=HEAP32[(($27)>>2)];
      var $29=$3;
      var $30=_HPDF_Stream_WriteReal($28, $29);
      $ret=$30;
      var $31=(($30)|0)!=0;
      if ($31) { __label__ = 8; break; } else { __label__ = 9; break; }
    case 8: 
      var $33=$2;
      var $34=(($33+12)|0);
      var $35=HEAP32[(($34)>>2)];
      var $36=_HPDF_CheckError($35);
      $1=$36;
      __label__ = 12; break;
    case 9: 
      var $38=$attr;
      var $39=(($38+76)|0);
      var $40=HEAP32[(($39)>>2)];
      var $41=_HPDF_Stream_WriteStr($40, ((STRING_TABLE.__str301580)|0));
      $ret=$41;
      var $42=(($41)|0)!=0;
      if ($42) { __label__ = 10; break; } else { __label__ = 11; break; }
    case 10: 
      var $44=$2;
      var $45=(($44+12)|0);
      var $46=HEAP32[(($45)>>2)];
      var $47=_HPDF_CheckError($46);
      $1=$47;
      __label__ = 12; break;
    case 11: 
      var $49=$3;
      var $50=$attr;
      var $51=(($50+16)|0);
      var $52=HEAP32[(($51)>>2)];
      var $53=(($52+68)|0);
      HEAPF32[(($53)>>2)]=$49;
      var $54=$ret;
      $1=$54;
      __label__ = 12; break;
    case 12: 
      var $56=$1;
      ;
      return $56;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Page_SetCharSpace["X"]=1;

function _HPDF_Page_SetWordSpace($page, $value) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $ret;
      var $attr;
      $2=$page;
      $3=$value;
      var $4=$2;
      var $5=_HPDF_Page_CheckState($4, 5);
      $ret=$5;
      var $6=$ret;
      var $7=(($6)|0)!=0;
      if ($7) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $9=$ret;
      $1=$9;
      __label__ = 12; break;
    case 4: 
      var $11=$2;
      var $12=(($11+44)|0);
      var $13=HEAP32[(($12)>>2)];
      var $14=$13;
      $attr=$14;
      var $15=$3;
      var $16=$15 < -30;
      if ($16) { __label__ = 6; break; } else { __label__ = 5; break; }
    case 5: 
      var $18=$3;
      var $19=$18 > 300;
      if ($19) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      var $21=$2;
      var $22=(($21+12)|0);
      var $23=HEAP32[(($22)>>2)];
      var $24=_HPDF_RaiseError($23, 4182, 0);
      $1=$24;
      __label__ = 12; break;
    case 7: 
      var $26=$attr;
      var $27=(($26+76)|0);
      var $28=HEAP32[(($27)>>2)];
      var $29=$3;
      var $30=_HPDF_Stream_WriteReal($28, $29);
      $ret=$30;
      var $31=(($30)|0)!=0;
      if ($31) { __label__ = 8; break; } else { __label__ = 9; break; }
    case 8: 
      var $33=$2;
      var $34=(($33+12)|0);
      var $35=HEAP32[(($34)>>2)];
      var $36=_HPDF_CheckError($35);
      $1=$36;
      __label__ = 12; break;
    case 9: 
      var $38=$attr;
      var $39=(($38+76)|0);
      var $40=HEAP32[(($39)>>2)];
      var $41=_HPDF_Stream_WriteStr($40, ((STRING_TABLE.__str311581)|0));
      $ret=$41;
      var $42=(($41)|0)!=0;
      if ($42) { __label__ = 10; break; } else { __label__ = 11; break; }
    case 10: 
      var $44=$2;
      var $45=(($44+12)|0);
      var $46=HEAP32[(($45)>>2)];
      var $47=_HPDF_CheckError($46);
      $1=$47;
      __label__ = 12; break;
    case 11: 
      var $49=$3;
      var $50=$attr;
      var $51=(($50+16)|0);
      var $52=HEAP32[(($51)>>2)];
      var $53=(($52+72)|0);
      HEAPF32[(($53)>>2)]=$49;
      var $54=$ret;
      $1=$54;
      __label__ = 12; break;
    case 12: 
      var $56=$1;
      ;
      return $56;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Page_SetWordSpace["X"]=1;

function _HPDF_Page_SetHorizontalScalling($page, $value) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $ret;
      var $attr;
      $2=$page;
      $3=$value;
      var $4=$2;
      var $5=_HPDF_Page_CheckState($4, 5);
      $ret=$5;
      var $6=$ret;
      var $7=(($6)|0)!=0;
      if ($7) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $9=$ret;
      $1=$9;
      __label__ = 12; break;
    case 4: 
      var $11=$2;
      var $12=(($11+44)|0);
      var $13=HEAP32[(($12)>>2)];
      var $14=$13;
      $attr=$14;
      var $15=$3;
      var $16=$15 < 10;
      if ($16) { __label__ = 6; break; } else { __label__ = 5; break; }
    case 5: 
      var $18=$3;
      var $19=$18 > 300;
      if ($19) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      var $21=$2;
      var $22=(($21+12)|0);
      var $23=HEAP32[(($22)>>2)];
      var $24=_HPDF_RaiseError($23, 4182, 0);
      $1=$24;
      __label__ = 12; break;
    case 7: 
      var $26=$attr;
      var $27=(($26+76)|0);
      var $28=HEAP32[(($27)>>2)];
      var $29=$3;
      var $30=_HPDF_Stream_WriteReal($28, $29);
      $ret=$30;
      var $31=(($30)|0)!=0;
      if ($31) { __label__ = 8; break; } else { __label__ = 9; break; }
    case 8: 
      var $33=$2;
      var $34=(($33+12)|0);
      var $35=HEAP32[(($34)>>2)];
      var $36=_HPDF_CheckError($35);
      $1=$36;
      __label__ = 12; break;
    case 9: 
      var $38=$attr;
      var $39=(($38+76)|0);
      var $40=HEAP32[(($39)>>2)];
      var $41=_HPDF_Stream_WriteStr($40, ((STRING_TABLE.__str321582)|0));
      $ret=$41;
      var $42=(($41)|0)!=0;
      if ($42) { __label__ = 10; break; } else { __label__ = 11; break; }
    case 10: 
      var $44=$2;
      var $45=(($44+12)|0);
      var $46=HEAP32[(($45)>>2)];
      var $47=_HPDF_CheckError($46);
      $1=$47;
      __label__ = 12; break;
    case 11: 
      var $49=$3;
      var $50=$attr;
      var $51=(($50+16)|0);
      var $52=HEAP32[(($51)>>2)];
      var $53=(($52+76)|0);
      HEAPF32[(($53)>>2)]=$49;
      var $54=$ret;
      $1=$54;
      __label__ = 12; break;
    case 12: 
      var $56=$1;
      ;
      return $56;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Page_SetHorizontalScalling["X"]=1;

function _HPDF_Page_SetTextLeading($page, $value) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $ret;
      var $attr;
      $2=$page;
      $3=$value;
      var $4=$2;
      var $5=_HPDF_Page_CheckState($4, 5);
      $ret=$5;
      var $6=$ret;
      var $7=(($6)|0)!=0;
      if ($7) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $9=$ret;
      $1=$9;
      __label__ = 9; break;
    case 4: 
      var $11=$2;
      var $12=(($11+44)|0);
      var $13=HEAP32[(($12)>>2)];
      var $14=$13;
      $attr=$14;
      var $15=$attr;
      var $16=(($15+76)|0);
      var $17=HEAP32[(($16)>>2)];
      var $18=$3;
      var $19=_HPDF_Stream_WriteReal($17, $18);
      $ret=$19;
      var $20=(($19)|0)!=0;
      if ($20) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $22=$2;
      var $23=(($22+12)|0);
      var $24=HEAP32[(($23)>>2)];
      var $25=_HPDF_CheckError($24);
      $1=$25;
      __label__ = 9; break;
    case 6: 
      var $27=$attr;
      var $28=(($27+76)|0);
      var $29=HEAP32[(($28)>>2)];
      var $30=_HPDF_Stream_WriteStr($29, ((STRING_TABLE.__str331583)|0));
      $ret=$30;
      var $31=(($30)|0)!=0;
      if ($31) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $33=$2;
      var $34=(($33+12)|0);
      var $35=HEAP32[(($34)>>2)];
      var $36=_HPDF_CheckError($35);
      $1=$36;
      __label__ = 9; break;
    case 8: 
      var $38=$3;
      var $39=$attr;
      var $40=(($39+16)|0);
      var $41=HEAP32[(($40)>>2)];
      var $42=(($41+80)|0);
      HEAPF32[(($42)>>2)]=$38;
      var $43=$ret;
      $1=$43;
      __label__ = 9; break;
    case 9: 
      var $45=$1;
      ;
      return $45;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Page_SetTextLeading["X"]=1;

function _HPDF_Page_SetFontAndSize($page, $font, $size) {
  var __stackBase__  = STACKTOP; STACKTOP += 512; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $ret;
      var $buf=__stackBase__;
      var $pbuf;
      var $eptr;
      var $local_name;
      var $attr;
      $2=$page;
      $3=$font;
      $4=$size;
      var $5=$2;
      var $6=_HPDF_Page_CheckState($5, 5);
      $ret=$6;
      var $7=(($buf)|0);
      $pbuf=$7;
      var $8=(($buf)|0);
      var $9=(($8+512)|0);
      var $10=((($9)-(1))|0);
      $eptr=$10;
      var $11=$ret;
      var $12=(($11)|0)!=0;
      if ($12) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $14=$ret;
      $1=$14;
      __label__ = 18; break;
    case 4: 
      var $16=$3;
      var $17=_HPDF_Font_Validate($16);
      var $18=(($17)|0)!=0;
      if ($18) { __label__ = 6; break; } else { __label__ = 5; break; }
    case 5: 
      var $20=$2;
      var $21=(($20+12)|0);
      var $22=HEAP32[(($21)>>2)];
      var $23=_HPDF_RaiseError($22, 4175, 0);
      $1=$23;
      __label__ = 18; break;
    case 6: 
      var $25=$4;
      var $26=$25 <= 0;
      if ($26) { __label__ = 8; break; } else { __label__ = 7; break; }
    case 7: 
      var $28=$4;
      var $29=$28 > 300;
      if ($29) { __label__ = 8; break; } else { __label__ = 9; break; }
    case 8: 
      var $31=$2;
      var $32=(($31+12)|0);
      var $33=HEAP32[(($32)>>2)];
      var $34=_HPDF_RaiseError($33, 4176, 0);
      $1=$34;
      __label__ = 18; break;
    case 9: 
      var $36=$2;
      var $37=(($36+8)|0);
      var $38=HEAP32[(($37)>>2)];
      var $39=$3;
      var $40=(($39+8)|0);
      var $41=HEAP32[(($40)>>2)];
      var $42=(($38)|0)!=(($41)|0);
      if ($42) { __label__ = 10; break; } else { __label__ = 11; break; }
    case 10: 
      var $44=$2;
      var $45=(($44+12)|0);
      var $46=HEAP32[(($45)>>2)];
      var $47=_HPDF_RaiseError($46, 4175, 0);
      $1=$47;
      __label__ = 18; break;
    case 11: 
      var $49=$2;
      var $50=(($49+44)|0);
      var $51=HEAP32[(($50)>>2)];
      var $52=$51;
      $attr=$52;
      var $53=$2;
      var $54=$3;
      var $55=_HPDF_Page_GetLocalFontName($53, $54);
      $local_name=$55;
      var $56=$local_name;
      var $57=(($56)|0)!=0;
      if ($57) { __label__ = 13; break; } else { __label__ = 12; break; }
    case 12: 
      var $59=$2;
      var $60=(($59+12)|0);
      var $61=HEAP32[(($60)>>2)];
      var $62=_HPDF_RaiseError($61, 4175, 0);
      $1=$62;
      __label__ = 18; break;
    case 13: 
      var $64=$attr;
      var $65=(($64+76)|0);
      var $66=HEAP32[(($65)>>2)];
      var $67=$local_name;
      var $68=_HPDF_Stream_WriteEscapeName($66, $67);
      $ret=$68;
      var $69=(($68)|0)!=0;
      if ($69) { __label__ = 14; break; } else { __label__ = 15; break; }
    case 14: 
      var $71=$2;
      var $72=(($71+12)|0);
      var $73=HEAP32[(($72)>>2)];
      var $74=_HPDF_CheckError($73);
      $1=$74;
      __label__ = 18; break;
    case 15: 
      var $76=(($buf)|0);
      var $77=_HPDF_MemSet($76, 0, 512);
      var $78=$pbuf;
      var $79=(($78+1)|0);
      $pbuf=$79;
      HEAP8[($78)]=32;
      var $80=$pbuf;
      var $81=$4;
      var $82=$eptr;
      var $83=_HPDF_FToA($80, $81, $82);
      $pbuf=$83;
      var $84=$pbuf;
      var $85=$eptr;
      var $86=_HPDF_StrCpy($84, ((STRING_TABLE.__str341584)|0), $85);
      var $87=$attr;
      var $88=(($87+76)|0);
      var $89=HEAP32[(($88)>>2)];
      var $90=(($buf)|0);
      var $91=_HPDF_Stream_WriteStr($89, $90);
      $ret=$91;
      var $92=(($91)|0)!=0;
      if ($92) { __label__ = 16; break; } else { __label__ = 17; break; }
    case 16: 
      var $94=$2;
      var $95=(($94+12)|0);
      var $96=HEAP32[(($95)>>2)];
      var $97=_HPDF_CheckError($96);
      $1=$97;
      __label__ = 18; break;
    case 17: 
      var $99=$3;
      var $100=$attr;
      var $101=(($100+16)|0);
      var $102=HEAP32[(($101)>>2)];
      var $103=(($102+164)|0);
      HEAP32[(($103)>>2)]=$99;
      var $104=$4;
      var $105=$attr;
      var $106=(($105+16)|0);
      var $107=HEAP32[(($106)>>2)];
      var $108=(($107+168)|0);
      HEAPF32[(($108)>>2)]=$104;
      var $109=$3;
      var $110=(($109+44)|0);
      var $111=HEAP32[(($110)>>2)];
      var $112=$111;
      var $113=(($112+4)|0);
      var $114=HEAP32[(($113)>>2)];
      var $115=$attr;
      var $116=(($115+16)|0);
      var $117=HEAP32[(($116)>>2)];
      var $118=(($117+172)|0);
      HEAP32[(($118)>>2)]=$114;
      var $119=$ret;
      $1=$119;
      __label__ = 18; break;
    case 18: 
      var $121=$1;
      STACKTOP = __stackBase__;
      return $121;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Page_SetFontAndSize["X"]=1;

function _HPDF_Page_SetTextRenderingMode($page, $mode) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $ret;
      var $attr;
      $2=$page;
      $3=$mode;
      var $4=$2;
      var $5=_HPDF_Page_CheckState($4, 5);
      $ret=$5;
      var $6=$ret;
      var $7=(($6)|0)!=0;
      if ($7) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $9=$ret;
      $1=$9;
      __label__ = 12; break;
    case 4: 
      var $11=$3;
      var $12=(($11)>>>0) < 0;
      if ($12) { __label__ = 6; break; } else { __label__ = 5; break; }
    case 5: 
      var $14=$3;
      var $15=(($14)>>>0) >= 8;
      if ($15) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      var $17=$2;
      var $18=(($17+12)|0);
      var $19=HEAP32[(($18)>>2)];
      var $20=$3;
      var $21=_HPDF_RaiseError($19, 4182, $20);
      $1=$21;
      __label__ = 12; break;
    case 7: 
      var $23=$2;
      var $24=(($23+44)|0);
      var $25=HEAP32[(($24)>>2)];
      var $26=$25;
      $attr=$26;
      var $27=$attr;
      var $28=(($27+76)|0);
      var $29=HEAP32[(($28)>>2)];
      var $30=$3;
      var $31=_HPDF_Stream_WriteInt($29, $30);
      $ret=$31;
      var $32=(($31)|0)!=0;
      if ($32) { __label__ = 8; break; } else { __label__ = 9; break; }
    case 8: 
      var $34=$2;
      var $35=(($34+12)|0);
      var $36=HEAP32[(($35)>>2)];
      var $37=_HPDF_CheckError($36);
      $1=$37;
      __label__ = 12; break;
    case 9: 
      var $39=$attr;
      var $40=(($39+76)|0);
      var $41=HEAP32[(($40)>>2)];
      var $42=_HPDF_Stream_WriteStr($41, ((STRING_TABLE.__str351585)|0));
      $ret=$42;
      var $43=(($42)|0)!=0;
      if ($43) { __label__ = 10; break; } else { __label__ = 11; break; }
    case 10: 
      var $45=$2;
      var $46=(($45+12)|0);
      var $47=HEAP32[(($46)>>2)];
      var $48=_HPDF_CheckError($47);
      $1=$48;
      __label__ = 12; break;
    case 11: 
      var $50=$3;
      var $51=$attr;
      var $52=(($51+16)|0);
      var $53=HEAP32[(($52)>>2)];
      var $54=(($53+84)|0);
      HEAP32[(($54)>>2)]=$50;
      var $55=$ret;
      $1=$55;
      __label__ = 12; break;
    case 12: 
      var $57=$1;
      ;
      return $57;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Page_SetTextRenderingMode["X"]=1;

function _HPDF_Page_SetTextRaise($page, $value) {
  ;
  var __label__;

  var $1;
  var $2;
  $1=$page;
  $2=$value;
  var $3=$1;
  var $4=$2;
  var $5=_HPDF_Page_SetTextRise($3, $4);
  ;
  return $5;
}


function _HPDF_Page_SetTextRise($page, $value) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $ret;
      var $attr;
      $2=$page;
      $3=$value;
      var $4=$2;
      var $5=_HPDF_Page_CheckState($4, 5);
      $ret=$5;
      var $6=$ret;
      var $7=(($6)|0)!=0;
      if ($7) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $9=$ret;
      $1=$9;
      __label__ = 9; break;
    case 4: 
      var $11=$2;
      var $12=(($11+44)|0);
      var $13=HEAP32[(($12)>>2)];
      var $14=$13;
      $attr=$14;
      var $15=$attr;
      var $16=(($15+76)|0);
      var $17=HEAP32[(($16)>>2)];
      var $18=$3;
      var $19=_HPDF_Stream_WriteReal($17, $18);
      $ret=$19;
      var $20=(($19)|0)!=0;
      if ($20) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $22=$2;
      var $23=(($22+12)|0);
      var $24=HEAP32[(($23)>>2)];
      var $25=_HPDF_CheckError($24);
      $1=$25;
      __label__ = 9; break;
    case 6: 
      var $27=$attr;
      var $28=(($27+76)|0);
      var $29=HEAP32[(($28)>>2)];
      var $30=_HPDF_Stream_WriteStr($29, ((STRING_TABLE.__str361586)|0));
      $ret=$30;
      var $31=(($30)|0)!=0;
      if ($31) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $33=$2;
      var $34=(($33+12)|0);
      var $35=HEAP32[(($34)>>2)];
      var $36=_HPDF_CheckError($35);
      $1=$36;
      __label__ = 9; break;
    case 8: 
      var $38=$3;
      var $39=$attr;
      var $40=(($39+16)|0);
      var $41=HEAP32[(($40)>>2)];
      var $42=(($41+88)|0);
      HEAPF32[(($42)>>2)]=$38;
      var $43=$ret;
      $1=$43;
      __label__ = 9; break;
    case 9: 
      var $45=$1;
      ;
      return $45;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Page_SetTextRise["X"]=1;

function _HPDF_Page_MoveTextPos($page, $x, $y) {
  var __stackBase__  = STACKTOP; STACKTOP += 512; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $ret;
      var $buf=__stackBase__;
      var $pbuf;
      var $eptr;
      var $attr;
      $2=$page;
      $3=$x;
      $4=$y;
      var $5=$2;
      var $6=_HPDF_Page_CheckState($5, 4);
      $ret=$6;
      var $7=(($buf)|0);
      $pbuf=$7;
      var $8=(($buf)|0);
      var $9=(($8+512)|0);
      var $10=((($9)-(1))|0);
      $eptr=$10;
      var $11=$ret;
      var $12=(($11)|0)!=0;
      if ($12) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $14=$ret;
      $1=$14;
      __label__ = 7; break;
    case 4: 
      var $16=$2;
      var $17=(($16+44)|0);
      var $18=HEAP32[(($17)>>2)];
      var $19=$18;
      $attr=$19;
      var $20=(($buf)|0);
      var $21=_HPDF_MemSet($20, 0, 512);
      var $22=$pbuf;
      var $23=$3;
      var $24=$eptr;
      var $25=_HPDF_FToA($22, $23, $24);
      $pbuf=$25;
      var $26=$pbuf;
      var $27=(($26+1)|0);
      $pbuf=$27;
      HEAP8[($26)]=32;
      var $28=$pbuf;
      var $29=$4;
      var $30=$eptr;
      var $31=_HPDF_FToA($28, $29, $30);
      $pbuf=$31;
      var $32=$pbuf;
      var $33=$eptr;
      var $34=_HPDF_StrCpy($32, ((STRING_TABLE.__str371587)|0), $33);
      var $35=$attr;
      var $36=(($35+76)|0);
      var $37=HEAP32[(($36)>>2)];
      var $38=(($buf)|0);
      var $39=_HPDF_Stream_WriteStr($37, $38);
      $ret=$39;
      var $40=(($39)|0)!=0;
      if ($40) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $42=$2;
      var $43=(($42+12)|0);
      var $44=HEAP32[(($43)>>2)];
      var $45=_HPDF_CheckError($44);
      $1=$45;
      __label__ = 7; break;
    case 6: 
      var $47=$3;
      var $48=$attr;
      var $49=(($48+44)|0);
      var $50=(($49)|0);
      var $51=HEAPF32[(($50)>>2)];
      var $52=($47)*($51);
      var $53=$4;
      var $54=$attr;
      var $55=(($54+44)|0);
      var $56=(($55+8)|0);
      var $57=HEAPF32[(($56)>>2)];
      var $58=($53)*($57);
      var $59=($52)+($58);
      var $60=$attr;
      var $61=(($60+44)|0);
      var $62=(($61+16)|0);
      var $63=HEAPF32[(($62)>>2)];
      var $64=($63)+($59);
      HEAPF32[(($62)>>2)]=$64;
      var $65=$4;
      var $66=$attr;
      var $67=(($66+44)|0);
      var $68=(($67+12)|0);
      var $69=HEAPF32[(($68)>>2)];
      var $70=($65)*($69);
      var $71=$3;
      var $72=$attr;
      var $73=(($72+44)|0);
      var $74=(($73+4)|0);
      var $75=HEAPF32[(($74)>>2)];
      var $76=($71)*($75);
      var $77=($70)+($76);
      var $78=$attr;
      var $79=(($78+44)|0);
      var $80=(($79+20)|0);
      var $81=HEAPF32[(($80)>>2)];
      var $82=($81)+($77);
      HEAPF32[(($80)>>2)]=$82;
      var $83=$attr;
      var $84=(($83+44)|0);
      var $85=(($84+16)|0);
      var $86=HEAPF32[(($85)>>2)];
      var $87=$attr;
      var $88=(($87+36)|0);
      var $89=(($88)|0);
      HEAPF32[(($89)>>2)]=$86;
      var $90=$attr;
      var $91=(($90+44)|0);
      var $92=(($91+20)|0);
      var $93=HEAPF32[(($92)>>2)];
      var $94=$attr;
      var $95=(($94+36)|0);
      var $96=(($95+4)|0);
      HEAPF32[(($96)>>2)]=$93;
      var $97=$ret;
      $1=$97;
      __label__ = 7; break;
    case 7: 
      var $99=$1;
      STACKTOP = __stackBase__;
      return $99;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Page_MoveTextPos["X"]=1;

function _HPDF_Page_MoveTextPos2($page, $x, $y) {
  var __stackBase__  = STACKTOP; STACKTOP += 512; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $ret;
      var $buf=__stackBase__;
      var $pbuf;
      var $eptr;
      var $attr;
      $2=$page;
      $3=$x;
      $4=$y;
      var $5=$2;
      var $6=_HPDF_Page_CheckState($5, 4);
      $ret=$6;
      var $7=(($buf)|0);
      $pbuf=$7;
      var $8=(($buf)|0);
      var $9=(($8+512)|0);
      var $10=((($9)-(1))|0);
      $eptr=$10;
      var $11=$ret;
      var $12=(($11)|0)!=0;
      if ($12) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $14=$ret;
      $1=$14;
      __label__ = 7; break;
    case 4: 
      var $16=$2;
      var $17=(($16+44)|0);
      var $18=HEAP32[(($17)>>2)];
      var $19=$18;
      $attr=$19;
      var $20=(($buf)|0);
      var $21=_HPDF_MemSet($20, 0, 512);
      var $22=$pbuf;
      var $23=$3;
      var $24=$eptr;
      var $25=_HPDF_FToA($22, $23, $24);
      $pbuf=$25;
      var $26=$pbuf;
      var $27=(($26+1)|0);
      $pbuf=$27;
      HEAP8[($26)]=32;
      var $28=$pbuf;
      var $29=$4;
      var $30=$eptr;
      var $31=_HPDF_FToA($28, $29, $30);
      $pbuf=$31;
      var $32=$pbuf;
      var $33=$eptr;
      var $34=_HPDF_StrCpy($32, ((STRING_TABLE.__str381588)|0), $33);
      var $35=$attr;
      var $36=(($35+76)|0);
      var $37=HEAP32[(($36)>>2)];
      var $38=(($buf)|0);
      var $39=_HPDF_Stream_WriteStr($37, $38);
      $ret=$39;
      var $40=(($39)|0)!=0;
      if ($40) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $42=$2;
      var $43=(($42+12)|0);
      var $44=HEAP32[(($43)>>2)];
      var $45=_HPDF_CheckError($44);
      $1=$45;
      __label__ = 7; break;
    case 6: 
      var $47=$3;
      var $48=$attr;
      var $49=(($48+44)|0);
      var $50=(($49)|0);
      var $51=HEAPF32[(($50)>>2)];
      var $52=($47)*($51);
      var $53=$4;
      var $54=$attr;
      var $55=(($54+44)|0);
      var $56=(($55+8)|0);
      var $57=HEAPF32[(($56)>>2)];
      var $58=($53)*($57);
      var $59=($52)+($58);
      var $60=$attr;
      var $61=(($60+44)|0);
      var $62=(($61+16)|0);
      var $63=HEAPF32[(($62)>>2)];
      var $64=($63)+($59);
      HEAPF32[(($62)>>2)]=$64;
      var $65=$4;
      var $66=$attr;
      var $67=(($66+44)|0);
      var $68=(($67+12)|0);
      var $69=HEAPF32[(($68)>>2)];
      var $70=($65)*($69);
      var $71=$3;
      var $72=$attr;
      var $73=(($72+44)|0);
      var $74=(($73+4)|0);
      var $75=HEAPF32[(($74)>>2)];
      var $76=($71)*($75);
      var $77=($70)+($76);
      var $78=$attr;
      var $79=(($78+44)|0);
      var $80=(($79+20)|0);
      var $81=HEAPF32[(($80)>>2)];
      var $82=($81)+($77);
      HEAPF32[(($80)>>2)]=$82;
      var $83=$attr;
      var $84=(($83+44)|0);
      var $85=(($84+16)|0);
      var $86=HEAPF32[(($85)>>2)];
      var $87=$attr;
      var $88=(($87+36)|0);
      var $89=(($88)|0);
      HEAPF32[(($89)>>2)]=$86;
      var $90=$attr;
      var $91=(($90+44)|0);
      var $92=(($91+20)|0);
      var $93=HEAPF32[(($92)>>2)];
      var $94=$attr;
      var $95=(($94+36)|0);
      var $96=(($95+4)|0);
      HEAPF32[(($96)>>2)]=$93;
      var $97=$4;
      var $98=(-$97);
      var $99=$attr;
      var $100=(($99+16)|0);
      var $101=HEAP32[(($100)>>2)];
      var $102=(($101+80)|0);
      HEAPF32[(($102)>>2)]=$98;
      var $103=$ret;
      $1=$103;
      __label__ = 7; break;
    case 7: 
      var $105=$1;
      STACKTOP = __stackBase__;
      return $105;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Page_MoveTextPos2["X"]=1;

function _HPDF_Page_SetTextMatrix($page, $a, $b, $c, $d, $x, $y) {
  var __stackBase__  = STACKTOP; STACKTOP += 512; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $5;
      var $6;
      var $7;
      var $8;
      var $ret;
      var $buf=__stackBase__;
      var $pbuf;
      var $eptr;
      var $attr;
      $2=$page;
      $3=$a;
      $4=$b;
      $5=$c;
      $6=$d;
      $7=$x;
      $8=$y;
      var $9=$2;
      var $10=_HPDF_Page_CheckState($9, 4);
      $ret=$10;
      var $11=(($buf)|0);
      $pbuf=$11;
      var $12=(($buf)|0);
      var $13=(($12+512)|0);
      var $14=((($13)-(1))|0);
      $eptr=$14;
      var $15=$ret;
      var $16=(($15)|0)!=0;
      if ($16) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $18=$ret;
      $1=$18;
      __label__ = 12; break;
    case 4: 
      var $20=$2;
      var $21=(($20+44)|0);
      var $22=HEAP32[(($21)>>2)];
      var $23=$22;
      $attr=$23;
      var $24=$3;
      var $25=$24 == 0;
      if ($25) { __label__ = 6; break; } else { __label__ = 5; break; }
    case 5: 
      var $27=$6;
      var $28=$27 == 0;
      if ($28) { __label__ = 6; break; } else { __label__ = 9; break; }
    case 6: 
      var $30=$4;
      var $31=$30 == 0;
      if ($31) { __label__ = 8; break; } else { __label__ = 7; break; }
    case 7: 
      var $33=$5;
      var $34=$33 == 0;
      if ($34) { __label__ = 8; break; } else { __label__ = 9; break; }
    case 8: 
      var $36=$2;
      var $37=(($36+12)|0);
      var $38=HEAP32[(($37)>>2)];
      var $39=_HPDF_RaiseError($38, 4153, 0);
      $1=$39;
      __label__ = 12; break;
    case 9: 
      var $41=(($buf)|0);
      var $42=_HPDF_MemSet($41, 0, 512);
      var $43=$pbuf;
      var $44=$3;
      var $45=$eptr;
      var $46=_HPDF_FToA($43, $44, $45);
      $pbuf=$46;
      var $47=$pbuf;
      var $48=(($47+1)|0);
      $pbuf=$48;
      HEAP8[($47)]=32;
      var $49=$pbuf;
      var $50=$4;
      var $51=$eptr;
      var $52=_HPDF_FToA($49, $50, $51);
      $pbuf=$52;
      var $53=$pbuf;
      var $54=(($53+1)|0);
      $pbuf=$54;
      HEAP8[($53)]=32;
      var $55=$pbuf;
      var $56=$5;
      var $57=$eptr;
      var $58=_HPDF_FToA($55, $56, $57);
      $pbuf=$58;
      var $59=$pbuf;
      var $60=(($59+1)|0);
      $pbuf=$60;
      HEAP8[($59)]=32;
      var $61=$pbuf;
      var $62=$6;
      var $63=$eptr;
      var $64=_HPDF_FToA($61, $62, $63);
      $pbuf=$64;
      var $65=$pbuf;
      var $66=(($65+1)|0);
      $pbuf=$66;
      HEAP8[($65)]=32;
      var $67=$pbuf;
      var $68=$7;
      var $69=$eptr;
      var $70=_HPDF_FToA($67, $68, $69);
      $pbuf=$70;
      var $71=$pbuf;
      var $72=(($71+1)|0);
      $pbuf=$72;
      HEAP8[($71)]=32;
      var $73=$pbuf;
      var $74=$8;
      var $75=$eptr;
      var $76=_HPDF_FToA($73, $74, $75);
      $pbuf=$76;
      var $77=$pbuf;
      var $78=$eptr;
      var $79=_HPDF_StrCpy($77, ((STRING_TABLE.__str391589)|0), $78);
      var $80=$attr;
      var $81=(($80+76)|0);
      var $82=HEAP32[(($81)>>2)];
      var $83=(($buf)|0);
      var $84=_HPDF_Stream_WriteStr($82, $83);
      $ret=$84;
      var $85=(($84)|0)!=0;
      if ($85) { __label__ = 10; break; } else { __label__ = 11; break; }
    case 10: 
      var $87=$2;
      var $88=(($87+12)|0);
      var $89=HEAP32[(($88)>>2)];
      var $90=_HPDF_CheckError($89);
      $1=$90;
      __label__ = 12; break;
    case 11: 
      var $92=$3;
      var $93=$attr;
      var $94=(($93+44)|0);
      var $95=(($94)|0);
      HEAPF32[(($95)>>2)]=$92;
      var $96=$4;
      var $97=$attr;
      var $98=(($97+44)|0);
      var $99=(($98+4)|0);
      HEAPF32[(($99)>>2)]=$96;
      var $100=$5;
      var $101=$attr;
      var $102=(($101+44)|0);
      var $103=(($102+8)|0);
      HEAPF32[(($103)>>2)]=$100;
      var $104=$6;
      var $105=$attr;
      var $106=(($105+44)|0);
      var $107=(($106+12)|0);
      HEAPF32[(($107)>>2)]=$104;
      var $108=$7;
      var $109=$attr;
      var $110=(($109+44)|0);
      var $111=(($110+16)|0);
      HEAPF32[(($111)>>2)]=$108;
      var $112=$8;
      var $113=$attr;
      var $114=(($113+44)|0);
      var $115=(($114+20)|0);
      HEAPF32[(($115)>>2)]=$112;
      var $116=$attr;
      var $117=(($116+44)|0);
      var $118=(($117+16)|0);
      var $119=HEAPF32[(($118)>>2)];
      var $120=$attr;
      var $121=(($120+36)|0);
      var $122=(($121)|0);
      HEAPF32[(($122)>>2)]=$119;
      var $123=$attr;
      var $124=(($123+44)|0);
      var $125=(($124+20)|0);
      var $126=HEAPF32[(($125)>>2)];
      var $127=$attr;
      var $128=(($127+36)|0);
      var $129=(($128+4)|0);
      HEAPF32[(($129)>>2)]=$126;
      var $130=$ret;
      $1=$130;
      __label__ = 12; break;
    case 12: 
      var $132=$1;
      STACKTOP = __stackBase__;
      return $132;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Page_SetTextMatrix["X"]=1;

function _HPDF_Page_MoveToNextLine($page) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $ret;
      var $attr;
      $2=$page;
      var $3=$2;
      var $4=_HPDF_Page_CheckState($3, 4);
      $ret=$4;
      var $5=$ret;
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $8=$ret;
      $1=$8;
      __label__ = 7; break;
    case 4: 
      var $10=$2;
      var $11=(($10+44)|0);
      var $12=HEAP32[(($11)>>2)];
      var $13=$12;
      $attr=$13;
      var $14=$attr;
      var $15=(($14+76)|0);
      var $16=HEAP32[(($15)>>2)];
      var $17=_HPDF_Stream_WriteStr($16, ((STRING_TABLE.__str401590)|0));
      $ret=$17;
      var $18=(($17)|0)!=0;
      if ($18) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $20=$2;
      var $21=(($20+12)|0);
      var $22=HEAP32[(($21)>>2)];
      var $23=_HPDF_CheckError($22);
      $1=$23;
      __label__ = 7; break;
    case 6: 
      var $25=$attr;
      var $26=(($25+16)|0);
      var $27=HEAP32[(($26)>>2)];
      var $28=(($27+80)|0);
      var $29=HEAPF32[(($28)>>2)];
      var $30=$attr;
      var $31=(($30+44)|0);
      var $32=(($31+8)|0);
      var $33=HEAPF32[(($32)>>2)];
      var $34=($29)*($33);
      var $35=$attr;
      var $36=(($35+44)|0);
      var $37=(($36+16)|0);
      var $38=HEAPF32[(($37)>>2)];
      var $39=($38)-($34);
      HEAPF32[(($37)>>2)]=$39;
      var $40=$attr;
      var $41=(($40+16)|0);
      var $42=HEAP32[(($41)>>2)];
      var $43=(($42+80)|0);
      var $44=HEAPF32[(($43)>>2)];
      var $45=$attr;
      var $46=(($45+44)|0);
      var $47=(($46+12)|0);
      var $48=HEAPF32[(($47)>>2)];
      var $49=($44)*($48);
      var $50=$attr;
      var $51=(($50+44)|0);
      var $52=(($51+20)|0);
      var $53=HEAPF32[(($52)>>2)];
      var $54=($53)-($49);
      HEAPF32[(($52)>>2)]=$54;
      var $55=$attr;
      var $56=(($55+44)|0);
      var $57=(($56+16)|0);
      var $58=HEAPF32[(($57)>>2)];
      var $59=$attr;
      var $60=(($59+36)|0);
      var $61=(($60)|0);
      HEAPF32[(($61)>>2)]=$58;
      var $62=$attr;
      var $63=(($62+44)|0);
      var $64=(($63+20)|0);
      var $65=HEAPF32[(($64)>>2)];
      var $66=$attr;
      var $67=(($66+36)|0);
      var $68=(($67+4)|0);
      HEAPF32[(($68)>>2)]=$65;
      var $69=$ret;
      $1=$69;
      __label__ = 7; break;
    case 7: 
      var $71=$1;
      ;
      return $71;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Page_MoveToNextLine["X"]=1;

function _HPDF_Page_ShowText($page, $text) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $ret;
      var $attr;
      var $tw;
      $2=$page;
      $3=$text;
      var $4=$2;
      var $5=_HPDF_Page_CheckState($4, 4);
      $ret=$5;
      var $6=$ret;
      var $7=(($6)|0)!=0;
      if ($7) { __label__ = 5; break; } else { __label__ = 3; break; }
    case 3: 
      var $9=$3;
      var $10=(($9)|0)==0;
      if ($10) { __label__ = 5; break; } else { __label__ = 4; break; }
    case 4: 
      var $12=$3;
      var $13=(($12)|0);
      var $14=HEAP8[($13)];
      var $15=(($14 << 24) >> 24);
      var $16=(($15)|0)==0;
      if ($16) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $18=$ret;
      $1=$18;
      __label__ = 18; break;
    case 6: 
      var $20=$2;
      var $21=(($20+44)|0);
      var $22=HEAP32[(($21)>>2)];
      var $23=$22;
      $attr=$23;
      var $24=$attr;
      var $25=(($24+16)|0);
      var $26=HEAP32[(($25)>>2)];
      var $27=(($26+164)|0);
      var $28=HEAP32[(($27)>>2)];
      var $29=(($28)|0)!=0;
      if ($29) { __label__ = 8; break; } else { __label__ = 7; break; }
    case 7: 
      var $31=$2;
      var $32=(($31+12)|0);
      var $33=HEAP32[(($32)>>2)];
      var $34=_HPDF_RaiseError($33, 4174, 0);
      $1=$34;
      __label__ = 18; break;
    case 8: 
      var $36=$2;
      var $37=$3;
      var $38=_HPDF_Page_TextWidth($36, $37);
      $tw=$38;
      var $39=$tw;
      var $40=$39 != 0;
      if ($40) { __label__ = 10; break; } else { __label__ = 9; break; }
    case 9: 
      var $42=$ret;
      $1=$42;
      __label__ = 18; break;
    case 10: 
      var $44=$attr;
      var $45=$3;
      var $46=_InternalWriteText($44, $45);
      $ret=$46;
      var $47=(($46)|0)!=0;
      if ($47) { __label__ = 11; break; } else { __label__ = 12; break; }
    case 11: 
      var $49=$2;
      var $50=(($49+12)|0);
      var $51=HEAP32[(($50)>>2)];
      var $52=_HPDF_CheckError($51);
      $1=$52;
      __label__ = 18; break;
    case 12: 
      var $54=$attr;
      var $55=(($54+76)|0);
      var $56=HEAP32[(($55)>>2)];
      var $57=_HPDF_Stream_WriteStr($56, ((STRING_TABLE.__str411591)|0));
      $ret=$57;
      var $58=(($57)|0)!=0;
      if ($58) { __label__ = 13; break; } else { __label__ = 14; break; }
    case 13: 
      var $60=$2;
      var $61=(($60+12)|0);
      var $62=HEAP32[(($61)>>2)];
      var $63=_HPDF_CheckError($62);
      $1=$63;
      __label__ = 18; break;
    case 14: 
      var $65=$attr;
      var $66=(($65+16)|0);
      var $67=HEAP32[(($66)>>2)];
      var $68=(($67+172)|0);
      var $69=HEAP32[(($68)>>2)];
      var $70=(($69)|0)==0;
      if ($70) { __label__ = 15; break; } else { __label__ = 16; break; }
    case 15: 
      var $72=$tw;
      var $73=$attr;
      var $74=(($73+44)|0);
      var $75=(($74)|0);
      var $76=HEAPF32[(($75)>>2)];
      var $77=($72)*($76);
      var $78=$attr;
      var $79=(($78+36)|0);
      var $80=(($79)|0);
      var $81=HEAPF32[(($80)>>2)];
      var $82=($81)+($77);
      HEAPF32[(($80)>>2)]=$82;
      var $83=$tw;
      var $84=$attr;
      var $85=(($84+44)|0);
      var $86=(($85+4)|0);
      var $87=HEAPF32[(($86)>>2)];
      var $88=($83)*($87);
      var $89=$attr;
      var $90=(($89+36)|0);
      var $91=(($90+4)|0);
      var $92=HEAPF32[(($91)>>2)];
      var $93=($92)+($88);
      HEAPF32[(($91)>>2)]=$93;
      __label__ = 17; break;
    case 16: 
      var $95=$tw;
      var $96=$attr;
      var $97=(($96+44)|0);
      var $98=(($97+4)|0);
      var $99=HEAPF32[(($98)>>2)];
      var $100=($95)*($99);
      var $101=$attr;
      var $102=(($101+36)|0);
      var $103=(($102)|0);
      var $104=HEAPF32[(($103)>>2)];
      var $105=($104)-($100);
      HEAPF32[(($103)>>2)]=$105;
      var $106=$tw;
      var $107=$attr;
      var $108=(($107+44)|0);
      var $109=(($108)|0);
      var $110=HEAPF32[(($109)>>2)];
      var $111=($106)*($110);
      var $112=$attr;
      var $113=(($112+36)|0);
      var $114=(($113+4)|0);
      var $115=HEAPF32[(($114)>>2)];
      var $116=($115)-($111);
      HEAPF32[(($114)>>2)]=$116;
      __label__ = 17; break;
    case 17: 
      var $118=$ret;
      $1=$118;
      __label__ = 18; break;
    case 18: 
      var $120=$1;
      ;
      return $120;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Page_ShowText["X"]=1;

function _InternalWriteText($attr, $text) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $font_attr;
      var $ret;
      $2=$attr;
      $3=$text;
      var $4=$2;
      var $5=(($4+16)|0);
      var $6=HEAP32[(($5)>>2)];
      var $7=(($6+164)|0);
      var $8=HEAP32[(($7)>>2)];
      var $9=(($8+44)|0);
      var $10=HEAP32[(($9)>>2)];
      var $11=$10;
      $font_attr=$11;
      var $12=$font_attr;
      var $13=(($12)|0);
      var $14=HEAP32[(($13)>>2)];
      var $15=(($14)|0)==4;
      if ($15) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      var $17=$font_attr;
      var $18=(($17)|0);
      var $19=HEAP32[(($18)>>2)];
      var $20=(($19)|0)==3;
      if ($20) { __label__ = 4; break; } else { __label__ = 9; break; }
    case 4: 
      var $22=$2;
      var $23=(($22+76)|0);
      var $24=HEAP32[(($23)>>2)];
      var $25=_HPDF_Stream_WriteStr($24, ((STRING_TABLE.__str701620)|0));
      $ret=$25;
      var $26=(($25)|0)!=0;
      if ($26) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $28=$ret;
      $1=$28;
      __label__ = 10; break;
    case 6: 
      var $30=$2;
      var $31=(($30+76)|0);
      var $32=HEAP32[(($31)>>2)];
      var $33=$3;
      var $34=$3;
      var $35=_HPDF_StrLen($34, 65535);
      var $36=_HPDF_Stream_WriteBinary($32, $33, $35, 0);
      $ret=$36;
      var $37=(($36)|0)!=0;
      if ($37) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $39=$ret;
      $1=$39;
      __label__ = 10; break;
    case 8: 
      var $41=$2;
      var $42=(($41+76)|0);
      var $43=HEAP32[(($42)>>2)];
      var $44=_HPDF_Stream_WriteStr($43, ((STRING_TABLE.__str711621)|0));
      $1=$44;
      __label__ = 10; break;
    case 9: 
      var $46=$2;
      var $47=(($46+76)|0);
      var $48=HEAP32[(($47)>>2)];
      var $49=$3;
      var $50=_HPDF_Stream_WriteEscapeText($48, $49);
      $1=$50;
      __label__ = 10; break;
    case 10: 
      var $52=$1;
      ;
      return $52;
    default: assert(0, "bad label: " + __label__);
  }
}
_InternalWriteText["X"]=1;

function _HPDF_Page_ShowTextNextLine($page, $text) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $ret;
      var $attr;
      var $tw;
      $2=$page;
      $3=$text;
      var $4=$2;
      var $5=_HPDF_Page_CheckState($4, 4);
      $ret=$5;
      var $6=$ret;
      var $7=(($6)|0)!=0;
      if ($7) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $9=$ret;
      $1=$9;
      __label__ = 17; break;
    case 4: 
      var $11=$2;
      var $12=(($11+44)|0);
      var $13=HEAP32[(($12)>>2)];
      var $14=$13;
      $attr=$14;
      var $15=$attr;
      var $16=(($15+16)|0);
      var $17=HEAP32[(($16)>>2)];
      var $18=(($17+164)|0);
      var $19=HEAP32[(($18)>>2)];
      var $20=(($19)|0)!=0;
      if ($20) { __label__ = 6; break; } else { __label__ = 5; break; }
    case 5: 
      var $22=$2;
      var $23=(($22+12)|0);
      var $24=HEAP32[(($23)>>2)];
      var $25=_HPDF_RaiseError($24, 4174, 0);
      $1=$25;
      __label__ = 17; break;
    case 6: 
      var $27=$3;
      var $28=(($27)|0)==0;
      if ($28) { __label__ = 8; break; } else { __label__ = 7; break; }
    case 7: 
      var $30=$3;
      var $31=(($30)|0);
      var $32=HEAP8[($31)];
      var $33=(($32 << 24) >> 24);
      var $34=(($33)|0)==0;
      if ($34) { __label__ = 8; break; } else { __label__ = 9; break; }
    case 8: 
      var $36=$2;
      var $37=_HPDF_Page_MoveToNextLine($36);
      $1=$37;
      __label__ = 17; break;
    case 9: 
      var $39=$attr;
      var $40=$3;
      var $41=_InternalWriteText($39, $40);
      $ret=$41;
      var $42=(($41)|0)!=0;
      if ($42) { __label__ = 10; break; } else { __label__ = 11; break; }
    case 10: 
      var $44=$2;
      var $45=(($44+12)|0);
      var $46=HEAP32[(($45)>>2)];
      var $47=_HPDF_CheckError($46);
      $1=$47;
      __label__ = 17; break;
    case 11: 
      var $49=$attr;
      var $50=(($49+76)|0);
      var $51=HEAP32[(($50)>>2)];
      var $52=_HPDF_Stream_WriteStr($51, ((STRING_TABLE.__str421592)|0));
      $ret=$52;
      var $53=(($52)|0)!=0;
      if ($53) { __label__ = 12; break; } else { __label__ = 13; break; }
    case 12: 
      var $55=$2;
      var $56=(($55+12)|0);
      var $57=HEAP32[(($56)>>2)];
      var $58=_HPDF_CheckError($57);
      $1=$58;
      __label__ = 17; break;
    case 13: 
      var $60=$2;
      var $61=$3;
      var $62=_HPDF_Page_TextWidth($60, $61);
      $tw=$62;
      var $63=$attr;
      var $64=(($63+16)|0);
      var $65=HEAP32[(($64)>>2)];
      var $66=(($65+80)|0);
      var $67=HEAPF32[(($66)>>2)];
      var $68=$attr;
      var $69=(($68+44)|0);
      var $70=(($69+8)|0);
      var $71=HEAPF32[(($70)>>2)];
      var $72=($67)*($71);
      var $73=$attr;
      var $74=(($73+44)|0);
      var $75=(($74+16)|0);
      var $76=HEAPF32[(($75)>>2)];
      var $77=($76)-($72);
      HEAPF32[(($75)>>2)]=$77;
      var $78=$attr;
      var $79=(($78+16)|0);
      var $80=HEAP32[(($79)>>2)];
      var $81=(($80+80)|0);
      var $82=HEAPF32[(($81)>>2)];
      var $83=$attr;
      var $84=(($83+44)|0);
      var $85=(($84+12)|0);
      var $86=HEAPF32[(($85)>>2)];
      var $87=($82)*($86);
      var $88=$attr;
      var $89=(($88+44)|0);
      var $90=(($89+20)|0);
      var $91=HEAPF32[(($90)>>2)];
      var $92=($91)-($87);
      HEAPF32[(($90)>>2)]=$92;
      var $93=$attr;
      var $94=(($93+44)|0);
      var $95=(($94+16)|0);
      var $96=HEAPF32[(($95)>>2)];
      var $97=$attr;
      var $98=(($97+36)|0);
      var $99=(($98)|0);
      HEAPF32[(($99)>>2)]=$96;
      var $100=$attr;
      var $101=(($100+44)|0);
      var $102=(($101+20)|0);
      var $103=HEAPF32[(($102)>>2)];
      var $104=$attr;
      var $105=(($104+36)|0);
      var $106=(($105+4)|0);
      HEAPF32[(($106)>>2)]=$103;
      var $107=$attr;
      var $108=(($107+16)|0);
      var $109=HEAP32[(($108)>>2)];
      var $110=(($109+172)|0);
      var $111=HEAP32[(($110)>>2)];
      var $112=(($111)|0)==0;
      if ($112) { __label__ = 14; break; } else { __label__ = 15; break; }
    case 14: 
      var $114=$tw;
      var $115=$attr;
      var $116=(($115+44)|0);
      var $117=(($116)|0);
      var $118=HEAPF32[(($117)>>2)];
      var $119=($114)*($118);
      var $120=$attr;
      var $121=(($120+36)|0);
      var $122=(($121)|0);
      var $123=HEAPF32[(($122)>>2)];
      var $124=($123)+($119);
      HEAPF32[(($122)>>2)]=$124;
      var $125=$tw;
      var $126=$attr;
      var $127=(($126+44)|0);
      var $128=(($127+4)|0);
      var $129=HEAPF32[(($128)>>2)];
      var $130=($125)*($129);
      var $131=$attr;
      var $132=(($131+36)|0);
      var $133=(($132+4)|0);
      var $134=HEAPF32[(($133)>>2)];
      var $135=($134)+($130);
      HEAPF32[(($133)>>2)]=$135;
      __label__ = 16; break;
    case 15: 
      var $137=$tw;
      var $138=$attr;
      var $139=(($138+44)|0);
      var $140=(($139+4)|0);
      var $141=HEAPF32[(($140)>>2)];
      var $142=($137)*($141);
      var $143=$attr;
      var $144=(($143+36)|0);
      var $145=(($144)|0);
      var $146=HEAPF32[(($145)>>2)];
      var $147=($146)-($142);
      HEAPF32[(($145)>>2)]=$147;
      var $148=$tw;
      var $149=$attr;
      var $150=(($149+44)|0);
      var $151=(($150)|0);
      var $152=HEAPF32[(($151)>>2)];
      var $153=($148)*($152);
      var $154=$attr;
      var $155=(($154+36)|0);
      var $156=(($155+4)|0);
      var $157=HEAPF32[(($156)>>2)];
      var $158=($157)-($153);
      HEAPF32[(($156)>>2)]=$158;
      __label__ = 16; break;
    case 16: 
      var $160=$ret;
      $1=$160;
      __label__ = 17; break;
    case 17: 
      var $162=$1;
      ;
      return $162;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Page_ShowTextNextLine["X"]=1;

function _HPDF_Page_ShowTextNextLineEx($page, $word_space, $char_space, $text) {
  var __stackBase__  = STACKTOP; STACKTOP += 512; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $5;
      var $ret;
      var $attr;
      var $tw;
      var $buf=__stackBase__;
      var $pbuf;
      var $eptr;
      $2=$page;
      $3=$word_space;
      $4=$char_space;
      $5=$text;
      var $6=$2;
      var $7=_HPDF_Page_CheckState($6, 4);
      $ret=$7;
      var $8=(($buf)|0);
      $pbuf=$8;
      var $9=(($buf)|0);
      var $10=(($9+512)|0);
      var $11=((($10)-(1))|0);
      $eptr=$11;
      var $12=$ret;
      var $13=(($12)|0)!=0;
      if ($13) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $15=$ret;
      $1=$15;
      __label__ = 25; break;
    case 4: 
      var $17=$3;
      var $18=$17 < -30;
      if ($18) { __label__ = 6; break; } else { __label__ = 5; break; }
    case 5: 
      var $20=$3;
      var $21=$20 > 300;
      if ($21) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      var $23=$2;
      var $24=(($23+12)|0);
      var $25=HEAP32[(($24)>>2)];
      var $26=_HPDF_RaiseError($25, 4182, 0);
      $1=$26;
      __label__ = 25; break;
    case 7: 
      var $28=$4;
      var $29=$28 < -30;
      if ($29) { __label__ = 9; break; } else { __label__ = 8; break; }
    case 8: 
      var $31=$4;
      var $32=$31 > 300;
      if ($32) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      var $34=$2;
      var $35=(($34+12)|0);
      var $36=HEAP32[(($35)>>2)];
      var $37=_HPDF_RaiseError($36, 4182, 0);
      $1=$37;
      __label__ = 25; break;
    case 10: 
      var $39=$2;
      var $40=(($39+44)|0);
      var $41=HEAP32[(($40)>>2)];
      var $42=$41;
      $attr=$42;
      var $43=$attr;
      var $44=(($43+16)|0);
      var $45=HEAP32[(($44)>>2)];
      var $46=(($45+164)|0);
      var $47=HEAP32[(($46)>>2)];
      var $48=(($47)|0)!=0;
      if ($48) { __label__ = 12; break; } else { __label__ = 11; break; }
    case 11: 
      var $50=$2;
      var $51=(($50+12)|0);
      var $52=HEAP32[(($51)>>2)];
      var $53=_HPDF_RaiseError($52, 4174, 0);
      $1=$53;
      __label__ = 25; break;
    case 12: 
      var $55=$5;
      var $56=(($55)|0)==0;
      if ($56) { __label__ = 14; break; } else { __label__ = 13; break; }
    case 13: 
      var $58=$5;
      var $59=(($58)|0);
      var $60=HEAP8[($59)];
      var $61=(($60 << 24) >> 24);
      var $62=(($61)|0)==0;
      if ($62) { __label__ = 14; break; } else { __label__ = 15; break; }
    case 14: 
      var $64=$2;
      var $65=_HPDF_Page_MoveToNextLine($64);
      $1=$65;
      __label__ = 25; break;
    case 15: 
      var $67=(($buf)|0);
      var $68=_HPDF_MemSet($67, 0, 512);
      var $69=$pbuf;
      var $70=$3;
      var $71=$eptr;
      var $72=_HPDF_FToA($69, $70, $71);
      $pbuf=$72;
      var $73=$pbuf;
      var $74=(($73+1)|0);
      $pbuf=$74;
      HEAP8[($73)]=32;
      var $75=$pbuf;
      var $76=$4;
      var $77=$eptr;
      var $78=_HPDF_FToA($75, $76, $77);
      $pbuf=$78;
      var $79=$pbuf;
      HEAP8[($79)]=32;
      var $80=$attr;
      var $81=(($buf)|0);
      var $82=_InternalWriteText($80, $81);
      $ret=$82;
      var $83=(($82)|0)!=0;
      if ($83) { __label__ = 16; break; } else { __label__ = 17; break; }
    case 16: 
      var $85=$2;
      var $86=(($85+12)|0);
      var $87=HEAP32[(($86)>>2)];
      var $88=_HPDF_CheckError($87);
      $1=$88;
      __label__ = 25; break;
    case 17: 
      var $90=$attr;
      var $91=$5;
      var $92=_InternalWriteText($90, $91);
      $ret=$92;
      var $93=(($92)|0)!=0;
      if ($93) { __label__ = 18; break; } else { __label__ = 19; break; }
    case 18: 
      var $95=$2;
      var $96=(($95+12)|0);
      var $97=HEAP32[(($96)>>2)];
      var $98=_HPDF_CheckError($97);
      $1=$98;
      __label__ = 25; break;
    case 19: 
      var $100=$attr;
      var $101=(($100+76)|0);
      var $102=HEAP32[(($101)>>2)];
      var $103=_HPDF_Stream_WriteStr($102, ((STRING_TABLE.__str431593)|0));
      $ret=$103;
      var $104=(($103)|0)!=0;
      if ($104) { __label__ = 20; break; } else { __label__ = 21; break; }
    case 20: 
      var $106=$2;
      var $107=(($106+12)|0);
      var $108=HEAP32[(($107)>>2)];
      var $109=_HPDF_CheckError($108);
      $1=$109;
      __label__ = 25; break;
    case 21: 
      var $111=$3;
      var $112=$attr;
      var $113=(($112+16)|0);
      var $114=HEAP32[(($113)>>2)];
      var $115=(($114+72)|0);
      HEAPF32[(($115)>>2)]=$111;
      var $116=$4;
      var $117=$attr;
      var $118=(($117+16)|0);
      var $119=HEAP32[(($118)>>2)];
      var $120=(($119+68)|0);
      HEAPF32[(($120)>>2)]=$116;
      var $121=$2;
      var $122=$5;
      var $123=_HPDF_Page_TextWidth($121, $122);
      $tw=$123;
      var $124=$attr;
      var $125=(($124+16)|0);
      var $126=HEAP32[(($125)>>2)];
      var $127=(($126+80)|0);
      var $128=HEAPF32[(($127)>>2)];
      var $129=$attr;
      var $130=(($129+44)|0);
      var $131=(($130+4)|0);
      var $132=HEAPF32[(($131)>>2)];
      var $133=($128)*($132);
      var $134=$attr;
      var $135=(($134+44)|0);
      var $136=(($135+16)|0);
      var $137=HEAPF32[(($136)>>2)];
      var $138=($137)+($133);
      HEAPF32[(($136)>>2)]=$138;
      var $139=$attr;
      var $140=(($139+16)|0);
      var $141=HEAP32[(($140)>>2)];
      var $142=(($141+80)|0);
      var $143=HEAPF32[(($142)>>2)];
      var $144=$attr;
      var $145=(($144+44)|0);
      var $146=(($145)|0);
      var $147=HEAPF32[(($146)>>2)];
      var $148=($143)*($147);
      var $149=$attr;
      var $150=(($149+44)|0);
      var $151=(($150+20)|0);
      var $152=HEAPF32[(($151)>>2)];
      var $153=($152)-($148);
      HEAPF32[(($151)>>2)]=$153;
      var $154=$attr;
      var $155=(($154+44)|0);
      var $156=(($155+16)|0);
      var $157=HEAPF32[(($156)>>2)];
      var $158=$attr;
      var $159=(($158+36)|0);
      var $160=(($159)|0);
      HEAPF32[(($160)>>2)]=$157;
      var $161=$attr;
      var $162=(($161+44)|0);
      var $163=(($162+20)|0);
      var $164=HEAPF32[(($163)>>2)];
      var $165=$attr;
      var $166=(($165+36)|0);
      var $167=(($166+4)|0);
      HEAPF32[(($167)>>2)]=$164;
      var $168=$attr;
      var $169=(($168+16)|0);
      var $170=HEAP32[(($169)>>2)];
      var $171=(($170+172)|0);
      var $172=HEAP32[(($171)>>2)];
      var $173=(($172)|0)==0;
      if ($173) { __label__ = 22; break; } else { __label__ = 23; break; }
    case 22: 
      var $175=$tw;
      var $176=$attr;
      var $177=(($176+44)|0);
      var $178=(($177)|0);
      var $179=HEAPF32[(($178)>>2)];
      var $180=($175)*($179);
      var $181=$attr;
      var $182=(($181+36)|0);
      var $183=(($182)|0);
      var $184=HEAPF32[(($183)>>2)];
      var $185=($184)+($180);
      HEAPF32[(($183)>>2)]=$185;
      var $186=$tw;
      var $187=$attr;
      var $188=(($187+44)|0);
      var $189=(($188+4)|0);
      var $190=HEAPF32[(($189)>>2)];
      var $191=($186)*($190);
      var $192=$attr;
      var $193=(($192+36)|0);
      var $194=(($193+4)|0);
      var $195=HEAPF32[(($194)>>2)];
      var $196=($195)+($191);
      HEAPF32[(($194)>>2)]=$196;
      __label__ = 24; break;
    case 23: 
      var $198=$tw;
      var $199=$attr;
      var $200=(($199+44)|0);
      var $201=(($200+4)|0);
      var $202=HEAPF32[(($201)>>2)];
      var $203=($198)*($202);
      var $204=$attr;
      var $205=(($204+36)|0);
      var $206=(($205)|0);
      var $207=HEAPF32[(($206)>>2)];
      var $208=($207)-($203);
      HEAPF32[(($206)>>2)]=$208;
      var $209=$tw;
      var $210=$attr;
      var $211=(($210+44)|0);
      var $212=(($211)|0);
      var $213=HEAPF32[(($212)>>2)];
      var $214=($209)*($213);
      var $215=$attr;
      var $216=(($215+36)|0);
      var $217=(($216+4)|0);
      var $218=HEAPF32[(($217)>>2)];
      var $219=($218)-($214);
      HEAPF32[(($217)>>2)]=$219;
      __label__ = 24; break;
    case 24: 
      var $221=$ret;
      $1=$221;
      __label__ = 25; break;
    case 25: 
      var $223=$1;
      STACKTOP = __stackBase__;
      return $223;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Page_ShowTextNextLineEx["X"]=1;

function _HPDF_Page_SetGrayFill($page, $gray) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $ret;
      var $attr;
      $2=$page;
      $3=$gray;
      var $4=$2;
      var $5=_HPDF_Page_CheckState($4, 5);
      $ret=$5;
      var $6=$ret;
      var $7=(($6)|0)!=0;
      if ($7) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $9=$ret;
      $1=$9;
      __label__ = 12; break;
    case 4: 
      var $11=$2;
      var $12=(($11+44)|0);
      var $13=HEAP32[(($12)>>2)];
      var $14=$13;
      $attr=$14;
      var $15=$3;
      var $16=$15 < 0;
      if ($16) { __label__ = 6; break; } else { __label__ = 5; break; }
    case 5: 
      var $18=$3;
      var $19=$18 > 1;
      if ($19) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      var $21=$2;
      var $22=(($21+12)|0);
      var $23=HEAP32[(($22)>>2)];
      var $24=_HPDF_RaiseError($23, 4182, 0);
      $1=$24;
      __label__ = 12; break;
    case 7: 
      var $26=$attr;
      var $27=(($26+76)|0);
      var $28=HEAP32[(($27)>>2)];
      var $29=$3;
      var $30=_HPDF_Stream_WriteReal($28, $29);
      $ret=$30;
      var $31=(($30)|0)!=0;
      if ($31) { __label__ = 8; break; } else { __label__ = 9; break; }
    case 8: 
      var $33=$2;
      var $34=(($33+12)|0);
      var $35=HEAP32[(($34)>>2)];
      var $36=_HPDF_CheckError($35);
      $1=$36;
      __label__ = 12; break;
    case 9: 
      var $38=$attr;
      var $39=(($38+76)|0);
      var $40=HEAP32[(($39)>>2)];
      var $41=_HPDF_Stream_WriteStr($40, ((STRING_TABLE.__str441594)|0));
      $ret=$41;
      var $42=(($41)|0)!=0;
      if ($42) { __label__ = 10; break; } else { __label__ = 11; break; }
    case 10: 
      var $44=$2;
      var $45=(($44+12)|0);
      var $46=HEAP32[(($45)>>2)];
      var $47=_HPDF_CheckError($46);
      $1=$47;
      __label__ = 12; break;
    case 11: 
      var $49=$3;
      var $50=$attr;
      var $51=(($50+16)|0);
      var $52=HEAP32[(($51)>>2)];
      var $53=(($52+156)|0);
      HEAPF32[(($53)>>2)]=$49;
      var $54=$attr;
      var $55=(($54+16)|0);
      var $56=HEAP32[(($55)>>2)];
      var $57=(($56+92)|0);
      HEAP32[(($57)>>2)]=0;
      var $58=$ret;
      $1=$58;
      __label__ = 12; break;
    case 12: 
      var $60=$1;
      ;
      return $60;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Page_SetGrayFill["X"]=1;

function _HPDF_Page_SetGrayStroke($page, $gray) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $ret;
      var $attr;
      $2=$page;
      $3=$gray;
      var $4=$2;
      var $5=_HPDF_Page_CheckState($4, 5);
      $ret=$5;
      var $6=$ret;
      var $7=(($6)|0)!=0;
      if ($7) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $9=$ret;
      $1=$9;
      __label__ = 12; break;
    case 4: 
      var $11=$2;
      var $12=(($11+44)|0);
      var $13=HEAP32[(($12)>>2)];
      var $14=$13;
      $attr=$14;
      var $15=$3;
      var $16=$15 < 0;
      if ($16) { __label__ = 6; break; } else { __label__ = 5; break; }
    case 5: 
      var $18=$3;
      var $19=$18 > 1;
      if ($19) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      var $21=$2;
      var $22=(($21+12)|0);
      var $23=HEAP32[(($22)>>2)];
      var $24=_HPDF_RaiseError($23, 4182, 0);
      $1=$24;
      __label__ = 12; break;
    case 7: 
      var $26=$attr;
      var $27=(($26+76)|0);
      var $28=HEAP32[(($27)>>2)];
      var $29=$3;
      var $30=_HPDF_Stream_WriteReal($28, $29);
      $ret=$30;
      var $31=(($30)|0)!=0;
      if ($31) { __label__ = 8; break; } else { __label__ = 9; break; }
    case 8: 
      var $33=$2;
      var $34=(($33+12)|0);
      var $35=HEAP32[(($34)>>2)];
      var $36=_HPDF_CheckError($35);
      $1=$36;
      __label__ = 12; break;
    case 9: 
      var $38=$attr;
      var $39=(($38+76)|0);
      var $40=HEAP32[(($39)>>2)];
      var $41=_HPDF_Stream_WriteStr($40, ((STRING_TABLE.__str451595)|0));
      $ret=$41;
      var $42=(($41)|0)!=0;
      if ($42) { __label__ = 10; break; } else { __label__ = 11; break; }
    case 10: 
      var $44=$2;
      var $45=(($44+12)|0);
      var $46=HEAP32[(($45)>>2)];
      var $47=_HPDF_CheckError($46);
      $1=$47;
      __label__ = 12; break;
    case 11: 
      var $49=$3;
      var $50=$attr;
      var $51=(($50+16)|0);
      var $52=HEAP32[(($51)>>2)];
      var $53=(($52+160)|0);
      HEAPF32[(($53)>>2)]=$49;
      var $54=$attr;
      var $55=(($54+16)|0);
      var $56=HEAP32[(($55)>>2)];
      var $57=(($56+96)|0);
      HEAP32[(($57)>>2)]=0;
      var $58=$ret;
      $1=$58;
      __label__ = 12; break;
    case 12: 
      var $60=$1;
      ;
      return $60;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Page_SetGrayStroke["X"]=1;

function _HPDF_Page_SetRGBFill($page, $r, $g, $b) {
  var __stackBase__  = STACKTOP; STACKTOP += 512; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $5;
      var $ret;
      var $buf=__stackBase__;
      var $pbuf;
      var $eptr;
      var $attr;
      $2=$page;
      $3=$r;
      $4=$g;
      $5=$b;
      var $6=$2;
      var $7=_HPDF_Page_CheckState($6, 5);
      $ret=$7;
      var $8=(($buf)|0);
      $pbuf=$8;
      var $9=(($buf)|0);
      var $10=(($9+512)|0);
      var $11=((($10)-(1))|0);
      $eptr=$11;
      var $12=$ret;
      var $13=(($12)|0)!=0;
      if ($13) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $15=$ret;
      $1=$15;
      __label__ = 14; break;
    case 4: 
      var $17=$3;
      var $18=$17 < 0;
      if ($18) { __label__ = 10; break; } else { __label__ = 5; break; }
    case 5: 
      var $20=$3;
      var $21=$20 > 1;
      if ($21) { __label__ = 10; break; } else { __label__ = 6; break; }
    case 6: 
      var $23=$4;
      var $24=$23 < 0;
      if ($24) { __label__ = 10; break; } else { __label__ = 7; break; }
    case 7: 
      var $26=$4;
      var $27=$26 > 1;
      if ($27) { __label__ = 10; break; } else { __label__ = 8; break; }
    case 8: 
      var $29=$5;
      var $30=$29 < 0;
      if ($30) { __label__ = 10; break; } else { __label__ = 9; break; }
    case 9: 
      var $32=$5;
      var $33=$32 > 1;
      if ($33) { __label__ = 10; break; } else { __label__ = 11; break; }
    case 10: 
      var $35=$2;
      var $36=(($35+12)|0);
      var $37=HEAP32[(($36)>>2)];
      var $38=_HPDF_RaiseError($37, 4182, 0);
      $1=$38;
      __label__ = 14; break;
    case 11: 
      var $40=$2;
      var $41=(($40+44)|0);
      var $42=HEAP32[(($41)>>2)];
      var $43=$42;
      $attr=$43;
      var $44=(($buf)|0);
      var $45=_HPDF_MemSet($44, 0, 512);
      var $46=$pbuf;
      var $47=$3;
      var $48=$eptr;
      var $49=_HPDF_FToA($46, $47, $48);
      $pbuf=$49;
      var $50=$pbuf;
      var $51=(($50+1)|0);
      $pbuf=$51;
      HEAP8[($50)]=32;
      var $52=$pbuf;
      var $53=$4;
      var $54=$eptr;
      var $55=_HPDF_FToA($52, $53, $54);
      $pbuf=$55;
      var $56=$pbuf;
      var $57=(($56+1)|0);
      $pbuf=$57;
      HEAP8[($56)]=32;
      var $58=$pbuf;
      var $59=$5;
      var $60=$eptr;
      var $61=_HPDF_FToA($58, $59, $60);
      $pbuf=$61;
      var $62=$pbuf;
      var $63=$eptr;
      var $64=_HPDF_StrCpy($62, ((STRING_TABLE.__str461596)|0), $63);
      var $65=$attr;
      var $66=(($65+76)|0);
      var $67=HEAP32[(($66)>>2)];
      var $68=(($buf)|0);
      var $69=_HPDF_Stream_WriteStr($67, $68);
      $ret=$69;
      var $70=(($69)|0)!=0;
      if ($70) { __label__ = 12; break; } else { __label__ = 13; break; }
    case 12: 
      var $72=$2;
      var $73=(($72+12)|0);
      var $74=HEAP32[(($73)>>2)];
      var $75=_HPDF_CheckError($74);
      $1=$75;
      __label__ = 14; break;
    case 13: 
      var $77=$3;
      var $78=$attr;
      var $79=(($78+16)|0);
      var $80=HEAP32[(($79)>>2)];
      var $81=(($80+100)|0);
      var $82=(($81)|0);
      HEAPF32[(($82)>>2)]=$77;
      var $83=$4;
      var $84=$attr;
      var $85=(($84+16)|0);
      var $86=HEAP32[(($85)>>2)];
      var $87=(($86+100)|0);
      var $88=(($87+4)|0);
      HEAPF32[(($88)>>2)]=$83;
      var $89=$5;
      var $90=$attr;
      var $91=(($90+16)|0);
      var $92=HEAP32[(($91)>>2)];
      var $93=(($92+100)|0);
      var $94=(($93+8)|0);
      HEAPF32[(($94)>>2)]=$89;
      var $95=$attr;
      var $96=(($95+16)|0);
      var $97=HEAP32[(($96)>>2)];
      var $98=(($97+92)|0);
      HEAP32[(($98)>>2)]=1;
      var $99=$ret;
      $1=$99;
      __label__ = 14; break;
    case 14: 
      var $101=$1;
      STACKTOP = __stackBase__;
      return $101;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Page_SetRGBFill["X"]=1;

function _HPDF_Page_SetRGBStroke($page, $r, $g, $b) {
  var __stackBase__  = STACKTOP; STACKTOP += 512; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $5;
      var $ret;
      var $buf=__stackBase__;
      var $pbuf;
      var $eptr;
      var $attr;
      $2=$page;
      $3=$r;
      $4=$g;
      $5=$b;
      var $6=$2;
      var $7=_HPDF_Page_CheckState($6, 5);
      $ret=$7;
      var $8=(($buf)|0);
      $pbuf=$8;
      var $9=(($buf)|0);
      var $10=(($9+512)|0);
      var $11=((($10)-(1))|0);
      $eptr=$11;
      var $12=$ret;
      var $13=(($12)|0)!=0;
      if ($13) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $15=$ret;
      $1=$15;
      __label__ = 14; break;
    case 4: 
      var $17=$3;
      var $18=$17 < 0;
      if ($18) { __label__ = 10; break; } else { __label__ = 5; break; }
    case 5: 
      var $20=$3;
      var $21=$20 > 1;
      if ($21) { __label__ = 10; break; } else { __label__ = 6; break; }
    case 6: 
      var $23=$4;
      var $24=$23 < 0;
      if ($24) { __label__ = 10; break; } else { __label__ = 7; break; }
    case 7: 
      var $26=$4;
      var $27=$26 > 1;
      if ($27) { __label__ = 10; break; } else { __label__ = 8; break; }
    case 8: 
      var $29=$5;
      var $30=$29 < 0;
      if ($30) { __label__ = 10; break; } else { __label__ = 9; break; }
    case 9: 
      var $32=$5;
      var $33=$32 > 1;
      if ($33) { __label__ = 10; break; } else { __label__ = 11; break; }
    case 10: 
      var $35=$2;
      var $36=(($35+12)|0);
      var $37=HEAP32[(($36)>>2)];
      var $38=_HPDF_RaiseError($37, 4182, 0);
      $1=$38;
      __label__ = 14; break;
    case 11: 
      var $40=$2;
      var $41=(($40+44)|0);
      var $42=HEAP32[(($41)>>2)];
      var $43=$42;
      $attr=$43;
      var $44=(($buf)|0);
      var $45=_HPDF_MemSet($44, 0, 512);
      var $46=$pbuf;
      var $47=$3;
      var $48=$eptr;
      var $49=_HPDF_FToA($46, $47, $48);
      $pbuf=$49;
      var $50=$pbuf;
      var $51=(($50+1)|0);
      $pbuf=$51;
      HEAP8[($50)]=32;
      var $52=$pbuf;
      var $53=$4;
      var $54=$eptr;
      var $55=_HPDF_FToA($52, $53, $54);
      $pbuf=$55;
      var $56=$pbuf;
      var $57=(($56+1)|0);
      $pbuf=$57;
      HEAP8[($56)]=32;
      var $58=$pbuf;
      var $59=$5;
      var $60=$eptr;
      var $61=_HPDF_FToA($58, $59, $60);
      $pbuf=$61;
      var $62=$pbuf;
      var $63=$eptr;
      var $64=_HPDF_StrCpy($62, ((STRING_TABLE.__str471597)|0), $63);
      var $65=$attr;
      var $66=(($65+76)|0);
      var $67=HEAP32[(($66)>>2)];
      var $68=(($buf)|0);
      var $69=_HPDF_Stream_WriteStr($67, $68);
      $ret=$69;
      var $70=(($69)|0)!=0;
      if ($70) { __label__ = 12; break; } else { __label__ = 13; break; }
    case 12: 
      var $72=$2;
      var $73=(($72+12)|0);
      var $74=HEAP32[(($73)>>2)];
      var $75=_HPDF_CheckError($74);
      $1=$75;
      __label__ = 14; break;
    case 13: 
      var $77=$3;
      var $78=$attr;
      var $79=(($78+16)|0);
      var $80=HEAP32[(($79)>>2)];
      var $81=(($80+112)|0);
      var $82=(($81)|0);
      HEAPF32[(($82)>>2)]=$77;
      var $83=$4;
      var $84=$attr;
      var $85=(($84+16)|0);
      var $86=HEAP32[(($85)>>2)];
      var $87=(($86+112)|0);
      var $88=(($87+4)|0);
      HEAPF32[(($88)>>2)]=$83;
      var $89=$5;
      var $90=$attr;
      var $91=(($90+16)|0);
      var $92=HEAP32[(($91)>>2)];
      var $93=(($92+112)|0);
      var $94=(($93+8)|0);
      HEAPF32[(($94)>>2)]=$89;
      var $95=$attr;
      var $96=(($95+16)|0);
      var $97=HEAP32[(($96)>>2)];
      var $98=(($97+96)|0);
      HEAP32[(($98)>>2)]=1;
      var $99=$ret;
      $1=$99;
      __label__ = 14; break;
    case 14: 
      var $101=$1;
      STACKTOP = __stackBase__;
      return $101;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Page_SetRGBStroke["X"]=1;

function _HPDF_Page_SetCMYKFill($page, $c, $m, $y, $k) {
  var __stackBase__  = STACKTOP; STACKTOP += 512; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $5;
      var $6;
      var $ret;
      var $buf=__stackBase__;
      var $pbuf;
      var $eptr;
      var $attr;
      $2=$page;
      $3=$c;
      $4=$m;
      $5=$y;
      $6=$k;
      var $7=$2;
      var $8=_HPDF_Page_CheckState($7, 5);
      $ret=$8;
      var $9=(($buf)|0);
      $pbuf=$9;
      var $10=(($buf)|0);
      var $11=(($10+512)|0);
      var $12=((($11)-(1))|0);
      $eptr=$12;
      var $13=$ret;
      var $14=(($13)|0)!=0;
      if ($14) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $16=$ret;
      $1=$16;
      __label__ = 16; break;
    case 4: 
      var $18=$3;
      var $19=$18 < 0;
      if ($19) { __label__ = 12; break; } else { __label__ = 5; break; }
    case 5: 
      var $21=$3;
      var $22=$21 > 1;
      if ($22) { __label__ = 12; break; } else { __label__ = 6; break; }
    case 6: 
      var $24=$4;
      var $25=$24 < 0;
      if ($25) { __label__ = 12; break; } else { __label__ = 7; break; }
    case 7: 
      var $27=$4;
      var $28=$27 > 1;
      if ($28) { __label__ = 12; break; } else { __label__ = 8; break; }
    case 8: 
      var $30=$5;
      var $31=$30 < 0;
      if ($31) { __label__ = 12; break; } else { __label__ = 9; break; }
    case 9: 
      var $33=$5;
      var $34=$33 > 1;
      if ($34) { __label__ = 12; break; } else { __label__ = 10; break; }
    case 10: 
      var $36=$6;
      var $37=$36 < 0;
      if ($37) { __label__ = 12; break; } else { __label__ = 11; break; }
    case 11: 
      var $39=$6;
      var $40=$39 > 1;
      if ($40) { __label__ = 12; break; } else { __label__ = 13; break; }
    case 12: 
      var $42=$2;
      var $43=(($42+12)|0);
      var $44=HEAP32[(($43)>>2)];
      var $45=_HPDF_RaiseError($44, 4182, 0);
      $1=$45;
      __label__ = 16; break;
    case 13: 
      var $47=$2;
      var $48=(($47+44)|0);
      var $49=HEAP32[(($48)>>2)];
      var $50=$49;
      $attr=$50;
      var $51=(($buf)|0);
      var $52=_HPDF_MemSet($51, 0, 512);
      var $53=$pbuf;
      var $54=$3;
      var $55=$eptr;
      var $56=_HPDF_FToA($53, $54, $55);
      $pbuf=$56;
      var $57=$pbuf;
      var $58=(($57+1)|0);
      $pbuf=$58;
      HEAP8[($57)]=32;
      var $59=$pbuf;
      var $60=$4;
      var $61=$eptr;
      var $62=_HPDF_FToA($59, $60, $61);
      $pbuf=$62;
      var $63=$pbuf;
      var $64=(($63+1)|0);
      $pbuf=$64;
      HEAP8[($63)]=32;
      var $65=$pbuf;
      var $66=$5;
      var $67=$eptr;
      var $68=_HPDF_FToA($65, $66, $67);
      $pbuf=$68;
      var $69=$pbuf;
      var $70=(($69+1)|0);
      $pbuf=$70;
      HEAP8[($69)]=32;
      var $71=$pbuf;
      var $72=$6;
      var $73=$eptr;
      var $74=_HPDF_FToA($71, $72, $73);
      $pbuf=$74;
      var $75=$pbuf;
      var $76=$eptr;
      var $77=_HPDF_StrCpy($75, ((STRING_TABLE.__str481598)|0), $76);
      var $78=$attr;
      var $79=(($78+76)|0);
      var $80=HEAP32[(($79)>>2)];
      var $81=(($buf)|0);
      var $82=_HPDF_Stream_WriteStr($80, $81);
      $ret=$82;
      var $83=(($82)|0)!=0;
      if ($83) { __label__ = 14; break; } else { __label__ = 15; break; }
    case 14: 
      var $85=$2;
      var $86=(($85+12)|0);
      var $87=HEAP32[(($86)>>2)];
      var $88=_HPDF_CheckError($87);
      $1=$88;
      __label__ = 16; break;
    case 15: 
      var $90=$3;
      var $91=$attr;
      var $92=(($91+16)|0);
      var $93=HEAP32[(($92)>>2)];
      var $94=(($93+124)|0);
      var $95=(($94)|0);
      HEAPF32[(($95)>>2)]=$90;
      var $96=$4;
      var $97=$attr;
      var $98=(($97+16)|0);
      var $99=HEAP32[(($98)>>2)];
      var $100=(($99+124)|0);
      var $101=(($100+4)|0);
      HEAPF32[(($101)>>2)]=$96;
      var $102=$5;
      var $103=$attr;
      var $104=(($103+16)|0);
      var $105=HEAP32[(($104)>>2)];
      var $106=(($105+124)|0);
      var $107=(($106+8)|0);
      HEAPF32[(($107)>>2)]=$102;
      var $108=$6;
      var $109=$attr;
      var $110=(($109+16)|0);
      var $111=HEAP32[(($110)>>2)];
      var $112=(($111+124)|0);
      var $113=(($112+12)|0);
      HEAPF32[(($113)>>2)]=$108;
      var $114=$attr;
      var $115=(($114+16)|0);
      var $116=HEAP32[(($115)>>2)];
      var $117=(($116+92)|0);
      HEAP32[(($117)>>2)]=2;
      var $118=$ret;
      $1=$118;
      __label__ = 16; break;
    case 16: 
      var $120=$1;
      STACKTOP = __stackBase__;
      return $120;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Page_SetCMYKFill["X"]=1;

function _HPDF_Page_SetCMYKStroke($page, $c, $m, $y, $k) {
  var __stackBase__  = STACKTOP; STACKTOP += 512; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $5;
      var $6;
      var $ret;
      var $buf=__stackBase__;
      var $pbuf;
      var $eptr;
      var $attr;
      $2=$page;
      $3=$c;
      $4=$m;
      $5=$y;
      $6=$k;
      var $7=$2;
      var $8=_HPDF_Page_CheckState($7, 5);
      $ret=$8;
      var $9=(($buf)|0);
      $pbuf=$9;
      var $10=(($buf)|0);
      var $11=(($10+512)|0);
      var $12=((($11)-(1))|0);
      $eptr=$12;
      var $13=$ret;
      var $14=(($13)|0)!=0;
      if ($14) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $16=$ret;
      $1=$16;
      __label__ = 16; break;
    case 4: 
      var $18=$3;
      var $19=$18 < 0;
      if ($19) { __label__ = 12; break; } else { __label__ = 5; break; }
    case 5: 
      var $21=$3;
      var $22=$21 > 1;
      if ($22) { __label__ = 12; break; } else { __label__ = 6; break; }
    case 6: 
      var $24=$4;
      var $25=$24 < 0;
      if ($25) { __label__ = 12; break; } else { __label__ = 7; break; }
    case 7: 
      var $27=$4;
      var $28=$27 > 1;
      if ($28) { __label__ = 12; break; } else { __label__ = 8; break; }
    case 8: 
      var $30=$5;
      var $31=$30 < 0;
      if ($31) { __label__ = 12; break; } else { __label__ = 9; break; }
    case 9: 
      var $33=$5;
      var $34=$33 > 1;
      if ($34) { __label__ = 12; break; } else { __label__ = 10; break; }
    case 10: 
      var $36=$6;
      var $37=$36 < 0;
      if ($37) { __label__ = 12; break; } else { __label__ = 11; break; }
    case 11: 
      var $39=$6;
      var $40=$39 > 1;
      if ($40) { __label__ = 12; break; } else { __label__ = 13; break; }
    case 12: 
      var $42=$2;
      var $43=(($42+12)|0);
      var $44=HEAP32[(($43)>>2)];
      var $45=_HPDF_RaiseError($44, 4182, 0);
      $1=$45;
      __label__ = 16; break;
    case 13: 
      var $47=$2;
      var $48=(($47+44)|0);
      var $49=HEAP32[(($48)>>2)];
      var $50=$49;
      $attr=$50;
      var $51=(($buf)|0);
      var $52=_HPDF_MemSet($51, 0, 512);
      var $53=$pbuf;
      var $54=$3;
      var $55=$eptr;
      var $56=_HPDF_FToA($53, $54, $55);
      $pbuf=$56;
      var $57=$pbuf;
      var $58=(($57+1)|0);
      $pbuf=$58;
      HEAP8[($57)]=32;
      var $59=$pbuf;
      var $60=$4;
      var $61=$eptr;
      var $62=_HPDF_FToA($59, $60, $61);
      $pbuf=$62;
      var $63=$pbuf;
      var $64=(($63+1)|0);
      $pbuf=$64;
      HEAP8[($63)]=32;
      var $65=$pbuf;
      var $66=$5;
      var $67=$eptr;
      var $68=_HPDF_FToA($65, $66, $67);
      $pbuf=$68;
      var $69=$pbuf;
      var $70=(($69+1)|0);
      $pbuf=$70;
      HEAP8[($69)]=32;
      var $71=$pbuf;
      var $72=$6;
      var $73=$eptr;
      var $74=_HPDF_FToA($71, $72, $73);
      $pbuf=$74;
      var $75=$pbuf;
      var $76=$eptr;
      var $77=_HPDF_StrCpy($75, ((STRING_TABLE.__str491599)|0), $76);
      var $78=$attr;
      var $79=(($78+76)|0);
      var $80=HEAP32[(($79)>>2)];
      var $81=(($buf)|0);
      var $82=_HPDF_Stream_WriteStr($80, $81);
      $ret=$82;
      var $83=(($82)|0)!=0;
      if ($83) { __label__ = 14; break; } else { __label__ = 15; break; }
    case 14: 
      var $85=$2;
      var $86=(($85+12)|0);
      var $87=HEAP32[(($86)>>2)];
      var $88=_HPDF_CheckError($87);
      $1=$88;
      __label__ = 16; break;
    case 15: 
      var $90=$3;
      var $91=$attr;
      var $92=(($91+16)|0);
      var $93=HEAP32[(($92)>>2)];
      var $94=(($93+140)|0);
      var $95=(($94)|0);
      HEAPF32[(($95)>>2)]=$90;
      var $96=$4;
      var $97=$attr;
      var $98=(($97+16)|0);
      var $99=HEAP32[(($98)>>2)];
      var $100=(($99+140)|0);
      var $101=(($100+4)|0);
      HEAPF32[(($101)>>2)]=$96;
      var $102=$5;
      var $103=$attr;
      var $104=(($103+16)|0);
      var $105=HEAP32[(($104)>>2)];
      var $106=(($105+140)|0);
      var $107=(($106+8)|0);
      HEAPF32[(($107)>>2)]=$102;
      var $108=$6;
      var $109=$attr;
      var $110=(($109+16)|0);
      var $111=HEAP32[(($110)>>2)];
      var $112=(($111+140)|0);
      var $113=(($112+12)|0);
      HEAPF32[(($113)>>2)]=$108;
      var $114=$attr;
      var $115=(($114+16)|0);
      var $116=HEAP32[(($115)>>2)];
      var $117=(($116+96)|0);
      HEAP32[(($117)>>2)]=2;
      var $118=$ret;
      $1=$118;
      __label__ = 16; break;
    case 16: 
      var $120=$1;
      STACKTOP = __stackBase__;
      return $120;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Page_SetCMYKStroke["X"]=1;

function _HPDF_Page_ExecuteXObject($page, $obj) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $ret;
      var $attr;
      var $local_name;
      $2=$page;
      $3=$obj;
      var $4=$2;
      var $5=_HPDF_Page_CheckState($4, 1);
      $ret=$5;
      var $6=$ret;
      var $7=(($6)|0)!=0;
      if ($7) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $9=$ret;
      $1=$9;
      __label__ = 16; break;
    case 4: 
      var $11=$3;
      var $12=(($11)|0)!=0;
      if ($12) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $14=$3;
      var $15=(($14)|0);
      var $16=(($15+6)|0);
      var $17=HEAPU16[(($16)>>1)];
      var $18=(($17)&65535);
      var $19=(($18)|0)!=1297;
      if ($19) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      var $21=$2;
      var $22=(($21+12)|0);
      var $23=HEAP32[(($22)>>2)];
      var $24=_HPDF_RaiseError($23, 4147, 0);
      $1=$24;
      __label__ = 16; break;
    case 7: 
      var $26=$2;
      var $27=(($26+8)|0);
      var $28=HEAP32[(($27)>>2)];
      var $29=$3;
      var $30=(($29+8)|0);
      var $31=HEAP32[(($30)>>2)];
      var $32=(($28)|0)!=(($31)|0);
      if ($32) { __label__ = 8; break; } else { __label__ = 9; break; }
    case 8: 
      var $34=$2;
      var $35=(($34+12)|0);
      var $36=HEAP32[(($35)>>2)];
      var $37=_HPDF_RaiseError($36, 4181, 0);
      $1=$37;
      __label__ = 16; break;
    case 9: 
      var $39=$2;
      var $40=(($39+44)|0);
      var $41=HEAP32[(($40)>>2)];
      var $42=$41;
      $attr=$42;
      var $43=$2;
      var $44=$3;
      var $45=_HPDF_Page_GetXObjectName($43, $44);
      $local_name=$45;
      var $46=$local_name;
      var $47=(($46)|0)!=0;
      if ($47) { __label__ = 11; break; } else { __label__ = 10; break; }
    case 10: 
      var $49=$2;
      var $50=(($49+12)|0);
      var $51=HEAP32[(($50)>>2)];
      var $52=_HPDF_RaiseError($51, 4181, 0);
      $1=$52;
      __label__ = 16; break;
    case 11: 
      var $54=$attr;
      var $55=(($54+76)|0);
      var $56=HEAP32[(($55)>>2)];
      var $57=$local_name;
      var $58=_HPDF_Stream_WriteEscapeName($56, $57);
      $ret=$58;
      var $59=(($58)|0)!=0;
      if ($59) { __label__ = 12; break; } else { __label__ = 13; break; }
    case 12: 
      var $61=$2;
      var $62=(($61+12)|0);
      var $63=HEAP32[(($62)>>2)];
      var $64=_HPDF_CheckError($63);
      $1=$64;
      __label__ = 16; break;
    case 13: 
      var $66=$attr;
      var $67=(($66+76)|0);
      var $68=HEAP32[(($67)>>2)];
      var $69=_HPDF_Stream_WriteStr($68, ((STRING_TABLE.__str501600)|0));
      $ret=$69;
      var $70=(($69)|0)!=0;
      if ($70) { __label__ = 14; break; } else { __label__ = 15; break; }
    case 14: 
      var $72=$2;
      var $73=(($72+12)|0);
      var $74=HEAP32[(($73)>>2)];
      var $75=_HPDF_CheckError($74);
      $1=$75;
      __label__ = 16; break;
    case 15: 
      var $77=$ret;
      $1=$77;
      __label__ = 16; break;
    case 16: 
      var $79=$1;
      ;
      return $79;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Page_ExecuteXObject["X"]=1;

function _HPDF_Page_Circle($page, $x, $y, $ray) {
  var __stackBase__  = STACKTOP; STACKTOP += 1024; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $5;
      var $ret;
      var $buf=__stackBase__;
      var $pbuf;
      var $eptr;
      var $attr;
      $2=$page;
      $3=$x;
      $4=$y;
      $5=$ray;
      var $6=$2;
      var $7=_HPDF_Page_CheckState($6, 3);
      $ret=$7;
      var $8=(($buf)|0);
      $pbuf=$8;
      var $9=(($buf)|0);
      var $10=(($9+512)|0);
      var $11=((($10)-(1))|0);
      $eptr=$11;
      var $12=$ret;
      var $13=(($12)|0)!=0;
      if ($13) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $15=$ret;
      $1=$15;
      __label__ = 7; break;
    case 4: 
      var $17=$2;
      var $18=(($17+44)|0);
      var $19=HEAP32[(($18)>>2)];
      var $20=$19;
      $attr=$20;
      var $21=(($buf)|0);
      var $22=_HPDF_MemSet($21, 0, 512);
      var $23=$pbuf;
      var $24=$3;
      var $25=$5;
      var $26=($24)-($25);
      var $27=$eptr;
      var $28=_HPDF_FToA($23, $26, $27);
      $pbuf=$28;
      var $29=$pbuf;
      var $30=(($29+1)|0);
      $pbuf=$30;
      HEAP8[($29)]=32;
      var $31=$pbuf;
      var $32=$4;
      var $33=$eptr;
      var $34=_HPDF_FToA($31, $32, $33);
      $pbuf=$34;
      var $35=$pbuf;
      var $36=$eptr;
      var $37=_HPDF_StrCpy($35, ((STRING_TABLE.__str101560)|0), $36);
      $pbuf=$37;
      var $38=$pbuf;
      var $39=$eptr;
      var $40=$3;
      var $41=$4;
      var $42=$5;
      var $43=_QuarterCircleA($38, $39, $40, $41, $42);
      $pbuf=$43;
      var $44=$pbuf;
      var $45=$eptr;
      var $46=$3;
      var $47=$4;
      var $48=$5;
      var $49=_QuarterCircleB($44, $45, $46, $47, $48);
      $pbuf=$49;
      var $50=$pbuf;
      var $51=$eptr;
      var $52=$3;
      var $53=$4;
      var $54=$5;
      var $55=_QuarterCircleC($50, $51, $52, $53, $54);
      $pbuf=$55;
      var $56=$pbuf;
      var $57=$eptr;
      var $58=$3;
      var $59=$4;
      var $60=$5;
      var $61=_QuarterCircleD($56, $57, $58, $59, $60);
      var $62=$attr;
      var $63=(($62+76)|0);
      var $64=HEAP32[(($63)>>2)];
      var $65=(($buf)|0);
      var $66=_HPDF_Stream_WriteStr($64, $65);
      $ret=$66;
      var $67=(($66)|0)!=0;
      if ($67) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $69=$2;
      var $70=(($69+12)|0);
      var $71=HEAP32[(($70)>>2)];
      var $72=_HPDF_CheckError($71);
      $1=$72;
      __label__ = 7; break;
    case 6: 
      var $74=$3;
      var $75=$5;
      var $76=($74)-($75);
      var $77=$attr;
      var $78=(($77+28)|0);
      var $79=(($78)|0);
      HEAPF32[(($79)>>2)]=$76;
      var $80=$4;
      var $81=$attr;
      var $82=(($81+28)|0);
      var $83=(($82+4)|0);
      HEAPF32[(($83)>>2)]=$80;
      var $84=$attr;
      var $85=(($84+20)|0);
      var $86=$attr;
      var $87=(($86+28)|0);
      var $88=$85;
      var $89=$87;
      assert(8 % 1 === 0, 'memcpy given ' + 8 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP32[(($88)>>2)]=HEAP32[(($89)>>2)];HEAP32[((($88)+(4))>>2)]=HEAP32[((($89)+(4))>>2)];
      var $90=$attr;
      var $91=(($90+68)|0);
      HEAP16[(($91)>>1)]=2;
      var $92=$ret;
      $1=$92;
      __label__ = 7; break;
    case 7: 
      var $94=$1;
      STACKTOP = __stackBase__;
      return $94;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Page_Circle["X"]=1;

function _QuarterCircleA($pbuf, $eptr, $x, $y, $ray) {
  ;
  var __label__;

  var $1;
  var $2;
  var $3;
  var $4;
  var $5;
  $1=$pbuf;
  $2=$eptr;
  $3=$x;
  $4=$y;
  $5=$ray;
  var $6=$1;
  var $7=$3;
  var $8=$5;
  var $9=($7)-($8);
  var $10=$2;
  var $11=_HPDF_FToA($6, $9, $10);
  $1=$11;
  var $12=$1;
  var $13=(($12+1)|0);
  $1=$13;
  HEAP8[($12)]=32;
  var $14=$1;
  var $15=$4;
  var $16=$5;
  var $17=($16)*(0.5519999861717224);
  var $18=($15)+($17);
  var $19=$2;
  var $20=_HPDF_FToA($14, $18, $19);
  $1=$20;
  var $21=$1;
  var $22=(($21+1)|0);
  $1=$22;
  HEAP8[($21)]=32;
  var $23=$1;
  var $24=$3;
  var $25=$5;
  var $26=($25)*(0.5519999861717224);
  var $27=($24)-($26);
  var $28=$2;
  var $29=_HPDF_FToA($23, $27, $28);
  $1=$29;
  var $30=$1;
  var $31=(($30+1)|0);
  $1=$31;
  HEAP8[($30)]=32;
  var $32=$1;
  var $33=$4;
  var $34=$5;
  var $35=($33)+($34);
  var $36=$2;
  var $37=_HPDF_FToA($32, $35, $36);
  $1=$37;
  var $38=$1;
  var $39=(($38+1)|0);
  $1=$39;
  HEAP8[($38)]=32;
  var $40=$1;
  var $41=$3;
  var $42=$2;
  var $43=_HPDF_FToA($40, $41, $42);
  $1=$43;
  var $44=$1;
  var $45=(($44+1)|0);
  $1=$45;
  HEAP8[($44)]=32;
  var $46=$1;
  var $47=$4;
  var $48=$5;
  var $49=($47)+($48);
  var $50=$2;
  var $51=_HPDF_FToA($46, $49, $50);
  $1=$51;
  var $52=$1;
  var $53=$2;
  var $54=_HPDF_StrCpy($52, ((STRING_TABLE.__str121562)|0), $53);
  ;
  return $54;
}
_QuarterCircleA["X"]=1;

function _QuarterCircleB($pbuf, $eptr, $x, $y, $ray) {
  ;
  var __label__;

  var $1;
  var $2;
  var $3;
  var $4;
  var $5;
  $1=$pbuf;
  $2=$eptr;
  $3=$x;
  $4=$y;
  $5=$ray;
  var $6=$1;
  var $7=$3;
  var $8=$5;
  var $9=($8)*(0.5519999861717224);
  var $10=($7)+($9);
  var $11=$2;
  var $12=_HPDF_FToA($6, $10, $11);
  $1=$12;
  var $13=$1;
  var $14=(($13+1)|0);
  $1=$14;
  HEAP8[($13)]=32;
  var $15=$1;
  var $16=$4;
  var $17=$5;
  var $18=($16)+($17);
  var $19=$2;
  var $20=_HPDF_FToA($15, $18, $19);
  $1=$20;
  var $21=$1;
  var $22=(($21+1)|0);
  $1=$22;
  HEAP8[($21)]=32;
  var $23=$1;
  var $24=$3;
  var $25=$5;
  var $26=($24)+($25);
  var $27=$2;
  var $28=_HPDF_FToA($23, $26, $27);
  $1=$28;
  var $29=$1;
  var $30=(($29+1)|0);
  $1=$30;
  HEAP8[($29)]=32;
  var $31=$1;
  var $32=$4;
  var $33=$5;
  var $34=($33)*(0.5519999861717224);
  var $35=($32)+($34);
  var $36=$2;
  var $37=_HPDF_FToA($31, $35, $36);
  $1=$37;
  var $38=$1;
  var $39=(($38+1)|0);
  $1=$39;
  HEAP8[($38)]=32;
  var $40=$1;
  var $41=$3;
  var $42=$5;
  var $43=($41)+($42);
  var $44=$2;
  var $45=_HPDF_FToA($40, $43, $44);
  $1=$45;
  var $46=$1;
  var $47=(($46+1)|0);
  $1=$47;
  HEAP8[($46)]=32;
  var $48=$1;
  var $49=$4;
  var $50=$2;
  var $51=_HPDF_FToA($48, $49, $50);
  $1=$51;
  var $52=$1;
  var $53=$2;
  var $54=_HPDF_StrCpy($52, ((STRING_TABLE.__str121562)|0), $53);
  ;
  return $54;
}
_QuarterCircleB["X"]=1;

function _QuarterCircleC($pbuf, $eptr, $x, $y, $ray) {
  ;
  var __label__;

  var $1;
  var $2;
  var $3;
  var $4;
  var $5;
  $1=$pbuf;
  $2=$eptr;
  $3=$x;
  $4=$y;
  $5=$ray;
  var $6=$1;
  var $7=$3;
  var $8=$5;
  var $9=($7)+($8);
  var $10=$2;
  var $11=_HPDF_FToA($6, $9, $10);
  $1=$11;
  var $12=$1;
  var $13=(($12+1)|0);
  $1=$13;
  HEAP8[($12)]=32;
  var $14=$1;
  var $15=$4;
  var $16=$5;
  var $17=($16)*(0.5519999861717224);
  var $18=($15)-($17);
  var $19=$2;
  var $20=_HPDF_FToA($14, $18, $19);
  $1=$20;
  var $21=$1;
  var $22=(($21+1)|0);
  $1=$22;
  HEAP8[($21)]=32;
  var $23=$1;
  var $24=$3;
  var $25=$5;
  var $26=($25)*(0.5519999861717224);
  var $27=($24)+($26);
  var $28=$2;
  var $29=_HPDF_FToA($23, $27, $28);
  $1=$29;
  var $30=$1;
  var $31=(($30+1)|0);
  $1=$31;
  HEAP8[($30)]=32;
  var $32=$1;
  var $33=$4;
  var $34=$5;
  var $35=($33)-($34);
  var $36=$2;
  var $37=_HPDF_FToA($32, $35, $36);
  $1=$37;
  var $38=$1;
  var $39=(($38+1)|0);
  $1=$39;
  HEAP8[($38)]=32;
  var $40=$1;
  var $41=$3;
  var $42=$2;
  var $43=_HPDF_FToA($40, $41, $42);
  $1=$43;
  var $44=$1;
  var $45=(($44+1)|0);
  $1=$45;
  HEAP8[($44)]=32;
  var $46=$1;
  var $47=$4;
  var $48=$5;
  var $49=($47)-($48);
  var $50=$2;
  var $51=_HPDF_FToA($46, $49, $50);
  $1=$51;
  var $52=$1;
  var $53=$2;
  var $54=_HPDF_StrCpy($52, ((STRING_TABLE.__str121562)|0), $53);
  ;
  return $54;
}
_QuarterCircleC["X"]=1;

function _QuarterCircleD($pbuf, $eptr, $x, $y, $ray) {
  ;
  var __label__;

  var $1;
  var $2;
  var $3;
  var $4;
  var $5;
  $1=$pbuf;
  $2=$eptr;
  $3=$x;
  $4=$y;
  $5=$ray;
  var $6=$1;
  var $7=$3;
  var $8=$5;
  var $9=($8)*(0.5519999861717224);
  var $10=($7)-($9);
  var $11=$2;
  var $12=_HPDF_FToA($6, $10, $11);
  $1=$12;
  var $13=$1;
  var $14=(($13+1)|0);
  $1=$14;
  HEAP8[($13)]=32;
  var $15=$1;
  var $16=$4;
  var $17=$5;
  var $18=($16)-($17);
  var $19=$2;
  var $20=_HPDF_FToA($15, $18, $19);
  $1=$20;
  var $21=$1;
  var $22=(($21+1)|0);
  $1=$22;
  HEAP8[($21)]=32;
  var $23=$1;
  var $24=$3;
  var $25=$5;
  var $26=($24)-($25);
  var $27=$2;
  var $28=_HPDF_FToA($23, $26, $27);
  $1=$28;
  var $29=$1;
  var $30=(($29+1)|0);
  $1=$30;
  HEAP8[($29)]=32;
  var $31=$1;
  var $32=$4;
  var $33=$5;
  var $34=($33)*(0.5519999861717224);
  var $35=($32)-($34);
  var $36=$2;
  var $37=_HPDF_FToA($31, $35, $36);
  $1=$37;
  var $38=$1;
  var $39=(($38+1)|0);
  $1=$39;
  HEAP8[($38)]=32;
  var $40=$1;
  var $41=$3;
  var $42=$5;
  var $43=($41)-($42);
  var $44=$2;
  var $45=_HPDF_FToA($40, $43, $44);
  $1=$45;
  var $46=$1;
  var $47=(($46+1)|0);
  $1=$47;
  HEAP8[($46)]=32;
  var $48=$1;
  var $49=$4;
  var $50=$2;
  var $51=_HPDF_FToA($48, $49, $50);
  $1=$51;
  var $52=$1;
  var $53=$2;
  var $54=_HPDF_StrCpy($52, ((STRING_TABLE.__str121562)|0), $53);
  ;
  return $54;
}
_QuarterCircleD["X"]=1;

function _HPDF_Page_Ellipse($page, $x, $y, $xray, $yray) {
  var __stackBase__  = STACKTOP; STACKTOP += 512; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $5;
      var $6;
      var $ret;
      var $buf=__stackBase__;
      var $pbuf;
      var $eptr;
      var $attr;
      $2=$page;
      $3=$x;
      $4=$y;
      $5=$xray;
      $6=$yray;
      var $7=$2;
      var $8=_HPDF_Page_CheckState($7, 3);
      $ret=$8;
      var $9=(($buf)|0);
      $pbuf=$9;
      var $10=(($buf)|0);
      var $11=(($10+512)|0);
      var $12=((($11)-(1))|0);
      $eptr=$12;
      var $13=$ret;
      var $14=(($13)|0)!=0;
      if ($14) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $16=$ret;
      $1=$16;
      __label__ = 7; break;
    case 4: 
      var $18=$2;
      var $19=(($18+44)|0);
      var $20=HEAP32[(($19)>>2)];
      var $21=$20;
      $attr=$21;
      var $22=(($buf)|0);
      var $23=_HPDF_MemSet($22, 0, 512);
      var $24=$pbuf;
      var $25=$3;
      var $26=$5;
      var $27=($25)-($26);
      var $28=$eptr;
      var $29=_HPDF_FToA($24, $27, $28);
      $pbuf=$29;
      var $30=$pbuf;
      var $31=(($30+1)|0);
      $pbuf=$31;
      HEAP8[($30)]=32;
      var $32=$pbuf;
      var $33=$4;
      var $34=$eptr;
      var $35=_HPDF_FToA($32, $33, $34);
      $pbuf=$35;
      var $36=$pbuf;
      var $37=$eptr;
      var $38=_HPDF_StrCpy($36, ((STRING_TABLE.__str101560)|0), $37);
      $pbuf=$38;
      var $39=$pbuf;
      var $40=$eptr;
      var $41=$3;
      var $42=$4;
      var $43=$5;
      var $44=$6;
      var $45=_QuarterEllipseA($39, $40, $41, $42, $43, $44);
      $pbuf=$45;
      var $46=$pbuf;
      var $47=$eptr;
      var $48=$3;
      var $49=$4;
      var $50=$5;
      var $51=$6;
      var $52=_QuarterEllipseB($46, $47, $48, $49, $50, $51);
      $pbuf=$52;
      var $53=$pbuf;
      var $54=$eptr;
      var $55=$3;
      var $56=$4;
      var $57=$5;
      var $58=$6;
      var $59=_QuarterEllipseC($53, $54, $55, $56, $57, $58);
      $pbuf=$59;
      var $60=$pbuf;
      var $61=$eptr;
      var $62=$3;
      var $63=$4;
      var $64=$5;
      var $65=$6;
      var $66=_QuarterEllipseD($60, $61, $62, $63, $64, $65);
      var $67=$attr;
      var $68=(($67+76)|0);
      var $69=HEAP32[(($68)>>2)];
      var $70=(($buf)|0);
      var $71=_HPDF_Stream_WriteStr($69, $70);
      $ret=$71;
      var $72=(($71)|0)!=0;
      if ($72) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $74=$2;
      var $75=(($74+12)|0);
      var $76=HEAP32[(($75)>>2)];
      var $77=_HPDF_CheckError($76);
      $1=$77;
      __label__ = 7; break;
    case 6: 
      var $79=$3;
      var $80=$5;
      var $81=($79)-($80);
      var $82=$attr;
      var $83=(($82+28)|0);
      var $84=(($83)|0);
      HEAPF32[(($84)>>2)]=$81;
      var $85=$4;
      var $86=$attr;
      var $87=(($86+28)|0);
      var $88=(($87+4)|0);
      HEAPF32[(($88)>>2)]=$85;
      var $89=$attr;
      var $90=(($89+20)|0);
      var $91=$attr;
      var $92=(($91+28)|0);
      var $93=$90;
      var $94=$92;
      assert(8 % 1 === 0, 'memcpy given ' + 8 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP32[(($93)>>2)]=HEAP32[(($94)>>2)];HEAP32[((($93)+(4))>>2)]=HEAP32[((($94)+(4))>>2)];
      var $95=$attr;
      var $96=(($95+68)|0);
      HEAP16[(($96)>>1)]=2;
      var $97=$ret;
      $1=$97;
      __label__ = 7; break;
    case 7: 
      var $99=$1;
      STACKTOP = __stackBase__;
      return $99;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Page_Ellipse["X"]=1;

function _QuarterEllipseA($pbuf, $eptr, $x, $y, $xray, $yray) {
  ;
  var __label__;

  var $1;
  var $2;
  var $3;
  var $4;
  var $5;
  var $6;
  $1=$pbuf;
  $2=$eptr;
  $3=$x;
  $4=$y;
  $5=$xray;
  $6=$yray;
  var $7=$1;
  var $8=$3;
  var $9=$5;
  var $10=($8)-($9);
  var $11=$2;
  var $12=_HPDF_FToA($7, $10, $11);
  $1=$12;
  var $13=$1;
  var $14=(($13+1)|0);
  $1=$14;
  HEAP8[($13)]=32;
  var $15=$1;
  var $16=$4;
  var $17=$6;
  var $18=($17)*(0.5519999861717224);
  var $19=($16)+($18);
  var $20=$2;
  var $21=_HPDF_FToA($15, $19, $20);
  $1=$21;
  var $22=$1;
  var $23=(($22+1)|0);
  $1=$23;
  HEAP8[($22)]=32;
  var $24=$1;
  var $25=$3;
  var $26=$5;
  var $27=($26)*(0.5519999861717224);
  var $28=($25)-($27);
  var $29=$2;
  var $30=_HPDF_FToA($24, $28, $29);
  $1=$30;
  var $31=$1;
  var $32=(($31+1)|0);
  $1=$32;
  HEAP8[($31)]=32;
  var $33=$1;
  var $34=$4;
  var $35=$6;
  var $36=($34)+($35);
  var $37=$2;
  var $38=_HPDF_FToA($33, $36, $37);
  $1=$38;
  var $39=$1;
  var $40=(($39+1)|0);
  $1=$40;
  HEAP8[($39)]=32;
  var $41=$1;
  var $42=$3;
  var $43=$2;
  var $44=_HPDF_FToA($41, $42, $43);
  $1=$44;
  var $45=$1;
  var $46=(($45+1)|0);
  $1=$46;
  HEAP8[($45)]=32;
  var $47=$1;
  var $48=$4;
  var $49=$6;
  var $50=($48)+($49);
  var $51=$2;
  var $52=_HPDF_FToA($47, $50, $51);
  $1=$52;
  var $53=$1;
  var $54=$2;
  var $55=_HPDF_StrCpy($53, ((STRING_TABLE.__str121562)|0), $54);
  ;
  return $55;
}
_QuarterEllipseA["X"]=1;

function _QuarterEllipseB($pbuf, $eptr, $x, $y, $xray, $yray) {
  ;
  var __label__;

  var $1;
  var $2;
  var $3;
  var $4;
  var $5;
  var $6;
  $1=$pbuf;
  $2=$eptr;
  $3=$x;
  $4=$y;
  $5=$xray;
  $6=$yray;
  var $7=$1;
  var $8=$3;
  var $9=$5;
  var $10=($9)*(0.5519999861717224);
  var $11=($8)+($10);
  var $12=$2;
  var $13=_HPDF_FToA($7, $11, $12);
  $1=$13;
  var $14=$1;
  var $15=(($14+1)|0);
  $1=$15;
  HEAP8[($14)]=32;
  var $16=$1;
  var $17=$4;
  var $18=$6;
  var $19=($17)+($18);
  var $20=$2;
  var $21=_HPDF_FToA($16, $19, $20);
  $1=$21;
  var $22=$1;
  var $23=(($22+1)|0);
  $1=$23;
  HEAP8[($22)]=32;
  var $24=$1;
  var $25=$3;
  var $26=$5;
  var $27=($25)+($26);
  var $28=$2;
  var $29=_HPDF_FToA($24, $27, $28);
  $1=$29;
  var $30=$1;
  var $31=(($30+1)|0);
  $1=$31;
  HEAP8[($30)]=32;
  var $32=$1;
  var $33=$4;
  var $34=$6;
  var $35=($34)*(0.5519999861717224);
  var $36=($33)+($35);
  var $37=$2;
  var $38=_HPDF_FToA($32, $36, $37);
  $1=$38;
  var $39=$1;
  var $40=(($39+1)|0);
  $1=$40;
  HEAP8[($39)]=32;
  var $41=$1;
  var $42=$3;
  var $43=$5;
  var $44=($42)+($43);
  var $45=$2;
  var $46=_HPDF_FToA($41, $44, $45);
  $1=$46;
  var $47=$1;
  var $48=(($47+1)|0);
  $1=$48;
  HEAP8[($47)]=32;
  var $49=$1;
  var $50=$4;
  var $51=$2;
  var $52=_HPDF_FToA($49, $50, $51);
  $1=$52;
  var $53=$1;
  var $54=$2;
  var $55=_HPDF_StrCpy($53, ((STRING_TABLE.__str121562)|0), $54);
  ;
  return $55;
}
_QuarterEllipseB["X"]=1;

function _QuarterEllipseC($pbuf, $eptr, $x, $y, $xray, $yray) {
  ;
  var __label__;

  var $1;
  var $2;
  var $3;
  var $4;
  var $5;
  var $6;
  $1=$pbuf;
  $2=$eptr;
  $3=$x;
  $4=$y;
  $5=$xray;
  $6=$yray;
  var $7=$1;
  var $8=$3;
  var $9=$5;
  var $10=($8)+($9);
  var $11=$2;
  var $12=_HPDF_FToA($7, $10, $11);
  $1=$12;
  var $13=$1;
  var $14=(($13+1)|0);
  $1=$14;
  HEAP8[($13)]=32;
  var $15=$1;
  var $16=$4;
  var $17=$6;
  var $18=($17)*(0.5519999861717224);
  var $19=($16)-($18);
  var $20=$2;
  var $21=_HPDF_FToA($15, $19, $20);
  $1=$21;
  var $22=$1;
  var $23=(($22+1)|0);
  $1=$23;
  HEAP8[($22)]=32;
  var $24=$1;
  var $25=$3;
  var $26=$5;
  var $27=($26)*(0.5519999861717224);
  var $28=($25)+($27);
  var $29=$2;
  var $30=_HPDF_FToA($24, $28, $29);
  $1=$30;
  var $31=$1;
  var $32=(($31+1)|0);
  $1=$32;
  HEAP8[($31)]=32;
  var $33=$1;
  var $34=$4;
  var $35=$6;
  var $36=($34)-($35);
  var $37=$2;
  var $38=_HPDF_FToA($33, $36, $37);
  $1=$38;
  var $39=$1;
  var $40=(($39+1)|0);
  $1=$40;
  HEAP8[($39)]=32;
  var $41=$1;
  var $42=$3;
  var $43=$2;
  var $44=_HPDF_FToA($41, $42, $43);
  $1=$44;
  var $45=$1;
  var $46=(($45+1)|0);
  $1=$46;
  HEAP8[($45)]=32;
  var $47=$1;
  var $48=$4;
  var $49=$6;
  var $50=($48)-($49);
  var $51=$2;
  var $52=_HPDF_FToA($47, $50, $51);
  $1=$52;
  var $53=$1;
  var $54=$2;
  var $55=_HPDF_StrCpy($53, ((STRING_TABLE.__str121562)|0), $54);
  ;
  return $55;
}
_QuarterEllipseC["X"]=1;

function _QuarterEllipseD($pbuf, $eptr, $x, $y, $xray, $yray) {
  ;
  var __label__;

  var $1;
  var $2;
  var $3;
  var $4;
  var $5;
  var $6;
  $1=$pbuf;
  $2=$eptr;
  $3=$x;
  $4=$y;
  $5=$xray;
  $6=$yray;
  var $7=$1;
  var $8=$3;
  var $9=$5;
  var $10=($9)*(0.5519999861717224);
  var $11=($8)-($10);
  var $12=$2;
  var $13=_HPDF_FToA($7, $11, $12);
  $1=$13;
  var $14=$1;
  var $15=(($14+1)|0);
  $1=$15;
  HEAP8[($14)]=32;
  var $16=$1;
  var $17=$4;
  var $18=$6;
  var $19=($17)-($18);
  var $20=$2;
  var $21=_HPDF_FToA($16, $19, $20);
  $1=$21;
  var $22=$1;
  var $23=(($22+1)|0);
  $1=$23;
  HEAP8[($22)]=32;
  var $24=$1;
  var $25=$3;
  var $26=$5;
  var $27=($25)-($26);
  var $28=$2;
  var $29=_HPDF_FToA($24, $27, $28);
  $1=$29;
  var $30=$1;
  var $31=(($30+1)|0);
  $1=$31;
  HEAP8[($30)]=32;
  var $32=$1;
  var $33=$4;
  var $34=$6;
  var $35=($34)*(0.5519999861717224);
  var $36=($33)-($35);
  var $37=$2;
  var $38=_HPDF_FToA($32, $36, $37);
  $1=$38;
  var $39=$1;
  var $40=(($39+1)|0);
  $1=$40;
  HEAP8[($39)]=32;
  var $41=$1;
  var $42=$3;
  var $43=$5;
  var $44=($42)-($43);
  var $45=$2;
  var $46=_HPDF_FToA($41, $44, $45);
  $1=$46;
  var $47=$1;
  var $48=(($47+1)|0);
  $1=$48;
  HEAP8[($47)]=32;
  var $49=$1;
  var $50=$4;
  var $51=$2;
  var $52=_HPDF_FToA($49, $50, $51);
  $1=$52;
  var $53=$1;
  var $54=$2;
  var $55=_HPDF_StrCpy($53, ((STRING_TABLE.__str121562)|0), $54);
  ;
  return $55;
}
_QuarterEllipseD["X"]=1;

function _HPDF_Page_Arc($page, $x, $y, $ray, $ang1, $ang2) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $5;
      var $6;
      var $7;
      var $cont_flg;
      var $ret;
      var $tmp_ang;
      $2=$page;
      $3=$x;
      $4=$y;
      $5=$ray;
      $6=$ang1;
      $7=$ang2;
      $cont_flg=0;
      var $8=$2;
      var $9=_HPDF_Page_CheckState($8, 3);
      $ret=$9;
      var $10=$6;
      var $11=$7;
      var $12=$10 >= $11;
      if ($12) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      var $14=$7;
      var $15=$6;
      var $16=($14)-($15);
      var $17=$16 >= 360;
      if ($17) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      var $19=$2;
      var $20=(($19+12)|0);
      var $21=HEAP32[(($20)>>2)];
      var $22=_HPDF_RaiseError($21, 4182, 0);
      __label__ = 5; break;
    case 5: 
      var $24=$ret;
      var $25=(($24)|0)!=0;
      if ($25) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      var $27=$ret;
      $1=$27;
      __label__ = 22; break;
    case 7: 
      __label__ = 8; break;
    case 8: 
      var $30=$6;
      var $31=$30 < 0;
      if ($31) { var $36 = 1;__label__ = 10; break; } else { __label__ = 9; break; }
    case 9: 
      var $33=$7;
      var $34=$33 < 0;
      var $36 = $34;__label__ = 10; break;
    case 10: 
      var $36;
      if ($36) { __label__ = 11; break; } else { __label__ = 12; break; }
    case 11: 
      var $38=$6;
      var $39=($38)+(360);
      $6=$39;
      var $40=$7;
      var $41=($40)+(360);
      $7=$41;
      __label__ = 8; break;
    case 12: 
      __label__ = 13; break;
    case 13: 
      var $44=$7;
      var $45=$6;
      var $46=($44)-($45);
      var $47=$46 <= 90;
      if ($47) { __label__ = 14; break; } else { __label__ = 15; break; }
    case 14: 
      var $49=$2;
      var $50=$3;
      var $51=$4;
      var $52=$5;
      var $53=$6;
      var $54=$7;
      var $55=$cont_flg;
      var $56=_InternalArc($49, $50, $51, $52, $53, $54, $55);
      $1=$56;
      __label__ = 22; break;
    case 15: 
      var $58=$6;
      var $59=($58)+(90);
      $tmp_ang=$59;
      var $60=$2;
      var $61=$3;
      var $62=$4;
      var $63=$5;
      var $64=$6;
      var $65=$tmp_ang;
      var $66=$cont_flg;
      var $67=_InternalArc($60, $61, $62, $63, $64, $65, $66);
      $ret=$67;
      var $68=(($67)|0)!=0;
      if ($68) { __label__ = 16; break; } else { __label__ = 17; break; }
    case 16: 
      var $70=$ret;
      $1=$70;
      __label__ = 22; break;
    case 17: 
      var $72=$tmp_ang;
      $6=$72;
      __label__ = 18; break;
    case 18: 
      var $74=$6;
      var $75=$7;
      var $76=$74 >= $75;
      if ($76) { __label__ = 19; break; } else { __label__ = 20; break; }
    case 19: 
      __label__ = 21; break;
    case 20: 
      $cont_flg=1;
      __label__ = 13; break;
    case 21: 
      $1=0;
      __label__ = 22; break;
    case 22: 
      var $81=$1;
      ;
      return $81;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Page_Arc["X"]=1;

function _InternalArc($page, $x, $y, $ray, $ang1, $ang2, $cont_flg) {
  var __stackBase__  = STACKTOP; STACKTOP += 512; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $5;
      var $6;
      var $7;
      var $8;
      var $PIE;
      var $buf=__stackBase__;
      var $pbuf;
      var $eptr;
      var $attr;
      var $ret;
      var $rx0;
      var $ry0;
      var $rx1;
      var $ry1;
      var $rx2;
      var $ry2;
      var $rx3;
      var $ry3;
      var $x0;
      var $y0;
      var $x1;
      var $y1;
      var $x2;
      var $y2;
      var $x3;
      var $y3;
      var $delta_angle;
      var $new_angle;
      $2=$page;
      $3=$x;
      $4=$y;
      $5=$ray;
      $6=$ang1;
      $7=$ang2;
      $8=$cont_flg;
      $PIE=3.141590118408203;
      var $9=(($buf)|0);
      $pbuf=$9;
      var $10=(($buf)|0);
      var $11=(($10+512)|0);
      var $12=((($11)-(1))|0);
      $eptr=$12;
      var $13=$2;
      var $14=(($13+44)|0);
      var $15=HEAP32[(($14)>>2)];
      var $16=$15;
      $attr=$16;
      var $17=(($buf)|0);
      var $18=_HPDF_MemSet($17, 0, 512);
      var $19=$6;
      var $20=$7;
      var $21=($19)+($20);
      var $22=$21;
      var $23=($22)/(2);
      var $24=(90)-($23);
      var $25=($24)/(180);
      var $26=($25)*(3.141590118408203);
      $delta_angle=$26;
      var $27=$7;
      var $28=$6;
      var $29=($27)-($28);
      var $30=$29;
      var $31=($30)/(2);
      var $32=($31)/(180);
      var $33=($32)*(3.141590118408203);
      $new_angle=$33;
      var $34=$5;
      var $35=$34;
      var $36=$new_angle;
      var $37=_cos($36);
      var $38=($35)*($37);
      $rx0=$38;
      var $39=$5;
      var $40=$39;
      var $41=$new_angle;
      var $42=_sin($41);
      var $43=($40)*($42);
      $ry0=$43;
      var $44=$5;
      var $45=$44;
      var $46=($45)*(4);
      var $47=$rx0;
      var $48=($46)-($47);
      var $49=($48)/(3);
      $rx2=$49;
      var $50=$5;
      var $51=$50;
      var $52=$51;
      var $53=$rx0;
      var $54=($52)-($53);
      var $55=$rx0;
      var $56=$5;
      var $57=$56;
      var $58=($57)*(3);
      var $59=($55)-($58);
      var $60=($54)*($59);
      var $61=$ry0;
      var $62=($61)*(3);
      var $63=($60)/($62);
      $ry2=$63;
      var $64=$rx2;
      $rx1=$64;
      var $65=$ry2;
      var $66=(-$65);
      $ry1=$66;
      var $67=$rx0;
      $rx3=$67;
      var $68=$ry0;
      var $69=(-$68);
      $ry3=$69;
      var $70=$rx0;
      var $71=$delta_angle;
      var $72=_cos($71);
      var $73=($70)*($72);
      var $74=$ry0;
      var $75=$delta_angle;
      var $76=_sin($75);
      var $77=($74)*($76);
      var $78=($73)-($77);
      var $79=$3;
      var $80=$79;
      var $81=($78)+($80);
      $x0=$81;
      var $82=$rx0;
      var $83=$delta_angle;
      var $84=_sin($83);
      var $85=($82)*($84);
      var $86=$ry0;
      var $87=$delta_angle;
      var $88=_cos($87);
      var $89=($86)*($88);
      var $90=($85)+($89);
      var $91=$4;
      var $92=$91;
      var $93=($90)+($92);
      $y0=$93;
      var $94=$rx1;
      var $95=$delta_angle;
      var $96=_cos($95);
      var $97=($94)*($96);
      var $98=$ry1;
      var $99=$delta_angle;
      var $100=_sin($99);
      var $101=($98)*($100);
      var $102=($97)-($101);
      var $103=$3;
      var $104=$103;
      var $105=($102)+($104);
      $x1=$105;
      var $106=$rx1;
      var $107=$delta_angle;
      var $108=_sin($107);
      var $109=($106)*($108);
      var $110=$ry1;
      var $111=$delta_angle;
      var $112=_cos($111);
      var $113=($110)*($112);
      var $114=($109)+($113);
      var $115=$4;
      var $116=$115;
      var $117=($114)+($116);
      $y1=$117;
      var $118=$rx2;
      var $119=$delta_angle;
      var $120=_cos($119);
      var $121=($118)*($120);
      var $122=$ry2;
      var $123=$delta_angle;
      var $124=_sin($123);
      var $125=($122)*($124);
      var $126=($121)-($125);
      var $127=$3;
      var $128=$127;
      var $129=($126)+($128);
      $x2=$129;
      var $130=$rx2;
      var $131=$delta_angle;
      var $132=_sin($131);
      var $133=($130)*($132);
      var $134=$ry2;
      var $135=$delta_angle;
      var $136=_cos($135);
      var $137=($134)*($136);
      var $138=($133)+($137);
      var $139=$4;
      var $140=$139;
      var $141=($138)+($140);
      $y2=$141;
      var $142=$rx3;
      var $143=$delta_angle;
      var $144=_cos($143);
      var $145=($142)*($144);
      var $146=$ry3;
      var $147=$delta_angle;
      var $148=_sin($147);
      var $149=($146)*($148);
      var $150=($145)-($149);
      var $151=$3;
      var $152=$151;
      var $153=($150)+($152);
      $x3=$153;
      var $154=$rx3;
      var $155=$delta_angle;
      var $156=_sin($155);
      var $157=($154)*($156);
      var $158=$ry3;
      var $159=$delta_angle;
      var $160=_cos($159);
      var $161=($158)*($160);
      var $162=($157)+($161);
      var $163=$4;
      var $164=$163;
      var $165=($162)+($164);
      $y3=$165;
      var $166=$8;
      var $167=(($166)|0)!=0;
      if ($167) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      var $169=$pbuf;
      var $170=$x0;
      var $171=$170;
      var $172=$eptr;
      var $173=_HPDF_FToA($169, $171, $172);
      $pbuf=$173;
      var $174=$pbuf;
      var $175=(($174+1)|0);
      $pbuf=$175;
      HEAP8[($174)]=32;
      var $176=$pbuf;
      var $177=$y0;
      var $178=$177;
      var $179=$eptr;
      var $180=_HPDF_FToA($176, $178, $179);
      $pbuf=$180;
      var $181=$pbuf;
      var $182=$eptr;
      var $183=_HPDF_StrCpy($181, ((STRING_TABLE.__str101560)|0), $182);
      $pbuf=$183;
      __label__ = 4; break;
    case 4: 
      var $185=$pbuf;
      var $186=$x1;
      var $187=$186;
      var $188=$eptr;
      var $189=_HPDF_FToA($185, $187, $188);
      $pbuf=$189;
      var $190=$pbuf;
      var $191=(($190+1)|0);
      $pbuf=$191;
      HEAP8[($190)]=32;
      var $192=$pbuf;
      var $193=$y1;
      var $194=$193;
      var $195=$eptr;
      var $196=_HPDF_FToA($192, $194, $195);
      $pbuf=$196;
      var $197=$pbuf;
      var $198=(($197+1)|0);
      $pbuf=$198;
      HEAP8[($197)]=32;
      var $199=$pbuf;
      var $200=$x2;
      var $201=$200;
      var $202=$eptr;
      var $203=_HPDF_FToA($199, $201, $202);
      $pbuf=$203;
      var $204=$pbuf;
      var $205=(($204+1)|0);
      $pbuf=$205;
      HEAP8[($204)]=32;
      var $206=$pbuf;
      var $207=$y2;
      var $208=$207;
      var $209=$eptr;
      var $210=_HPDF_FToA($206, $208, $209);
      $pbuf=$210;
      var $211=$pbuf;
      var $212=(($211+1)|0);
      $pbuf=$212;
      HEAP8[($211)]=32;
      var $213=$pbuf;
      var $214=$x3;
      var $215=$214;
      var $216=$eptr;
      var $217=_HPDF_FToA($213, $215, $216);
      $pbuf=$217;
      var $218=$pbuf;
      var $219=(($218+1)|0);
      $pbuf=$219;
      HEAP8[($218)]=32;
      var $220=$pbuf;
      var $221=$y3;
      var $222=$221;
      var $223=$eptr;
      var $224=_HPDF_FToA($220, $222, $223);
      $pbuf=$224;
      var $225=$pbuf;
      var $226=$eptr;
      var $227=_HPDF_StrCpy($225, ((STRING_TABLE.__str121562)|0), $226);
      var $228=$attr;
      var $229=(($228+76)|0);
      var $230=HEAP32[(($229)>>2)];
      var $231=(($buf)|0);
      var $232=_HPDF_Stream_WriteStr($230, $231);
      $ret=$232;
      var $233=(($232)|0)!=0;
      if ($233) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $235=$2;
      var $236=(($235+12)|0);
      var $237=HEAP32[(($236)>>2)];
      var $238=_HPDF_CheckError($237);
      $1=$238;
      __label__ = 7; break;
    case 6: 
      var $240=$x3;
      var $241=$240;
      var $242=$attr;
      var $243=(($242+28)|0);
      var $244=(($243)|0);
      HEAPF32[(($244)>>2)]=$241;
      var $245=$y3;
      var $246=$245;
      var $247=$attr;
      var $248=(($247+28)|0);
      var $249=(($248+4)|0);
      HEAPF32[(($249)>>2)]=$246;
      var $250=$attr;
      var $251=(($250+20)|0);
      var $252=$attr;
      var $253=(($252+28)|0);
      var $254=$251;
      var $255=$253;
      assert(8 % 1 === 0, 'memcpy given ' + 8 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP32[(($254)>>2)]=HEAP32[(($255)>>2)];HEAP32[((($254)+(4))>>2)]=HEAP32[((($255)+(4))>>2)];
      var $256=$attr;
      var $257=(($256+68)|0);
      HEAP16[(($257)>>1)]=2;
      var $258=$ret;
      $1=$258;
      __label__ = 7; break;
    case 7: 
      var $260=$1;
      STACKTOP = __stackBase__;
      return $260;
    default: assert(0, "bad label: " + __label__);
  }
}
_InternalArc["X"]=1;

function _HPDF_Page_DrawImage($page, $image, $x, $y, $width, $height) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $5;
      var $6;
      var $7;
      var $ret;
      $2=$page;
      $3=$image;
      $4=$x;
      $5=$y;
      $6=$width;
      $7=$height;
      var $8=$2;
      var $9=_HPDF_Page_GSave($8);
      $ret=$9;
      var $10=(($9)|0)!=0;
      if ($10) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $12=$ret;
      $1=$12;
      __label__ = 9; break;
    case 4: 
      var $14=$2;
      var $15=$6;
      var $16=$7;
      var $17=$4;
      var $18=$5;
      var $19=_HPDF_Page_Concat($14, $15, 0, 0, $16, $17, $18);
      $ret=$19;
      var $20=(($19)|0)!=0;
      if ($20) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $22=$ret;
      $1=$22;
      __label__ = 9; break;
    case 6: 
      var $24=$2;
      var $25=$3;
      var $26=_HPDF_Page_ExecuteXObject($24, $25);
      $ret=$26;
      var $27=(($26)|0)!=0;
      if ($27) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $29=$ret;
      $1=$29;
      __label__ = 9; break;
    case 8: 
      var $31=$2;
      var $32=_HPDF_Page_GRestore($31);
      $1=$32;
      __label__ = 9; break;
    case 9: 
      var $34=$1;
      ;
      return $34;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Page_TextOut($page, $xpos, $ypos, $text) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $5;
      var $ret;
      var $x;
      var $y;
      var $attr;
      $2=$page;
      $3=$xpos;
      $4=$ypos;
      $5=$text;
      var $6=$2;
      var $7=_HPDF_Page_CheckState($6, 4);
      $ret=$7;
      var $8=$ret;
      var $9=(($8)|0)!=0;
      if ($9) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $11=$ret;
      $1=$11;
      __label__ = 10; break;
    case 4: 
      var $13=$2;
      var $14=(($13+44)|0);
      var $15=HEAP32[(($14)>>2)];
      var $16=$15;
      $attr=$16;
      var $17=$attr;
      var $18=(($17+44)|0);
      var $19=(($18)|0);
      var $20=HEAPF32[(($19)>>2)];
      var $21=$20 == 0;
      if ($21) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $23=$3;
      var $24=$attr;
      var $25=(($24+44)|0);
      var $26=(($25+16)|0);
      var $27=HEAPF32[(($26)>>2)];
      var $28=($23)-($27);
      var $29=$attr;
      var $30=(($29+44)|0);
      var $31=(($30+8)|0);
      var $32=HEAPF32[(($31)>>2)];
      var $33=($28)/($32);
      $y=$33;
      var $34=$4;
      var $35=$attr;
      var $36=(($35+44)|0);
      var $37=(($36+20)|0);
      var $38=HEAPF32[(($37)>>2)];
      var $39=($34)-($38);
      var $40=$3;
      var $41=$attr;
      var $42=(($41+44)|0);
      var $43=(($42+16)|0);
      var $44=HEAPF32[(($43)>>2)];
      var $45=($40)-($44);
      var $46=$attr;
      var $47=(($46+44)|0);
      var $48=(($47+12)|0);
      var $49=HEAPF32[(($48)>>2)];
      var $50=($45)*($49);
      var $51=$attr;
      var $52=(($51+44)|0);
      var $53=(($52+8)|0);
      var $54=HEAPF32[(($53)>>2)];
      var $55=($50)/($54);
      var $56=($39)-($55);
      var $57=$attr;
      var $58=(($57+44)|0);
      var $59=(($58+4)|0);
      var $60=HEAPF32[(($59)>>2)];
      var $61=($56)/($60);
      $x=$61;
      __label__ = 7; break;
    case 6: 
      var $63=$4;
      var $64=$attr;
      var $65=(($64+44)|0);
      var $66=(($65+20)|0);
      var $67=HEAPF32[(($66)>>2)];
      var $68=($63)-($67);
      var $69=$3;
      var $70=$attr;
      var $71=(($70+44)|0);
      var $72=(($71+16)|0);
      var $73=HEAPF32[(($72)>>2)];
      var $74=($69)-($73);
      var $75=$attr;
      var $76=(($75+44)|0);
      var $77=(($76+4)|0);
      var $78=HEAPF32[(($77)>>2)];
      var $79=($74)*($78);
      var $80=$attr;
      var $81=(($80+44)|0);
      var $82=(($81)|0);
      var $83=HEAPF32[(($82)>>2)];
      var $84=($79)/($83);
      var $85=($68)-($84);
      var $86=$attr;
      var $87=(($86+44)|0);
      var $88=(($87+12)|0);
      var $89=HEAPF32[(($88)>>2)];
      var $90=$attr;
      var $91=(($90+44)|0);
      var $92=(($91+8)|0);
      var $93=HEAPF32[(($92)>>2)];
      var $94=$attr;
      var $95=(($94+44)|0);
      var $96=(($95+4)|0);
      var $97=HEAPF32[(($96)>>2)];
      var $98=($93)*($97);
      var $99=$attr;
      var $100=(($99+44)|0);
      var $101=(($100)|0);
      var $102=HEAPF32[(($101)>>2)];
      var $103=($98)/($102);
      var $104=($89)-($103);
      var $105=($85)/($104);
      $y=$105;
      var $106=$3;
      var $107=$attr;
      var $108=(($107+44)|0);
      var $109=(($108+16)|0);
      var $110=HEAPF32[(($109)>>2)];
      var $111=($106)-($110);
      var $112=$y;
      var $113=$attr;
      var $114=(($113+44)|0);
      var $115=(($114+8)|0);
      var $116=HEAPF32[(($115)>>2)];
      var $117=($112)*($116);
      var $118=($111)-($117);
      var $119=$attr;
      var $120=(($119+44)|0);
      var $121=(($120)|0);
      var $122=HEAPF32[(($121)>>2)];
      var $123=($118)/($122);
      $x=$123;
      __label__ = 7; break;
    case 7: 
      var $125=$2;
      var $126=$x;
      var $127=$y;
      var $128=_HPDF_Page_MoveTextPos($125, $126, $127);
      $ret=$128;
      var $129=(($128)|0)!=0;
      if ($129) { __label__ = 8; break; } else { __label__ = 9; break; }
    case 8: 
      var $131=$ret;
      $1=$131;
      __label__ = 10; break;
    case 9: 
      var $133=$2;
      var $134=$5;
      var $135=_HPDF_Page_ShowText($133, $134);
      $1=$135;
      __label__ = 10; break;
    case 10: 
      var $137=$1;
      ;
      return $137;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Page_TextOut["X"]=1;

function _HPDF_Page_TextRect($page, $left, $top, $right, $bottom, $text, $align, $len) {
  var __stackBase__  = STACKTOP; STACKTOP += 52; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $5;
      var $6;
      var $7;
      var $8;
      var $9;
      var $ret;
      var $x;
      var $y;
      var $attr;
      var $ptr;
      var $save_char_space;
      var $is_insufficient_space;
      var $num_rest;
      var $bbox=__stackBase__;
      var $char_space_changed;
      var $10=(__stackBase__)+(16);
      var $tmp_len;
      var $rw=(__stackBase__)+(32);
      var $x_adjust;
      var $tmp_ptr;
      var $num_char;
      var $state=(__stackBase__)+(36);
      var $encoder;
      var $i;
      var $btype;
      $2=$page;
      $3=$left;
      $4=$top;
      $5=$right;
      $6=$bottom;
      $7=$text;
      $8=$align;
      $9=$len;
      var $11=$2;
      var $12=_HPDF_Page_CheckState($11, 4);
      $ret=$12;
      var $13=$7;
      $ptr=$13;
      $save_char_space=0;
      $is_insufficient_space=0;
      $char_space_changed=0;
      var $14=$ret;
      var $15=(($14)|0)!=0;
      if ($15) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $17=$ret;
      $1=$17;
      __label__ = 84; break;
    case 4: 
      var $19=$2;
      var $20=(($19+44)|0);
      var $21=HEAP32[(($20)>>2)];
      var $22=$21;
      $attr=$22;
      var $23=$attr;
      var $24=(($23+16)|0);
      var $25=HEAP32[(($24)>>2)];
      var $26=(($25+164)|0);
      var $27=HEAP32[(($26)>>2)];
      var $28=(($27)|0)!=0;
      if ($28) { __label__ = 6; break; } else { __label__ = 5; break; }
    case 5: 
      var $30=$2;
      var $31=(($30+12)|0);
      var $32=HEAP32[(($31)>>2)];
      var $33=_HPDF_RaiseError($32, 4174, 0);
      $1=$33;
      __label__ = 84; break;
    case 6: 
      var $35=$attr;
      var $36=(($35+16)|0);
      var $37=HEAP32[(($36)>>2)];
      var $38=(($37+164)|0);
      var $39=HEAP32[(($38)>>2)];
      _HPDF_Font_GetBBox($10, $39);
      var $40=$bbox;
      var $41=$10;
      assert(16 % 1 === 0, 'memcpy given ' + 16 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP32[(($40)>>2)]=HEAP32[(($41)>>2)];HEAP32[((($40)+(4))>>2)]=HEAP32[((($41)+(4))>>2)];HEAP32[((($40)+(8))>>2)]=HEAP32[((($41)+(8))>>2)];HEAP32[((($40)+(12))>>2)]=HEAP32[((($41)+(12))>>2)];
      var $42=$9;
      var $43=(($42)|0)!=0;
      if ($43) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $45=$9;
      HEAP32[(($45)>>2)]=0;
      __label__ = 8; break;
    case 8: 
      var $47=$7;
      var $48=_HPDF_StrLen($47, 65536);
      $num_rest=$48;
      var $49=$num_rest;
      var $50=(($49)>>>0) > 65535;
      if ($50) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      var $52=$2;
      var $53=(($52+12)|0);
      var $54=HEAP32[(($53)>>2)];
      var $55=_HPDF_RaiseError($54, 4187, 0);
      $1=$55;
      __label__ = 84; break;
    case 10: 
      var $57=$num_rest;
      var $58=(($57)|0)!=0;
      if ($58) { __label__ = 12; break; } else { __label__ = 11; break; }
    case 11: 
      $1=0;
      __label__ = 84; break;
    case 12: 
      __label__ = 13; break;
    case 13: 
      var $62=$attr;
      var $63=(($62+16)|0);
      var $64=HEAP32[(($63)>>2)];
      var $65=(($64+80)|0);
      var $66=HEAPF32[(($65)>>2)];
      var $67=$66 == 0;
      if ($67) { __label__ = 14; break; } else { __label__ = 15; break; }
    case 14: 
      var $69=$2;
      var $70=(($bbox+12)|0);
      var $71=HEAPF32[(($70)>>2)];
      var $72=(($bbox+4)|0);
      var $73=HEAPF32[(($72)>>2)];
      var $74=($71)-($73);
      var $75=($74)/(1000);
      var $76=$attr;
      var $77=(($76+16)|0);
      var $78=HEAP32[(($77)>>2)];
      var $79=(($78+168)|0);
      var $80=HEAPF32[(($79)>>2)];
      var $81=($75)*($80);
      var $82=_HPDF_Page_SetTextLeading($69, $81);
      __label__ = 15; break;
    case 15: 
      var $84=$4;
      var $85=(($bbox+12)|0);
      var $86=HEAPF32[(($85)>>2)];
      var $87=($86)/(1000);
      var $88=$attr;
      var $89=(($88+16)|0);
      var $90=HEAP32[(($89)>>2)];
      var $91=(($90+168)|0);
      var $92=HEAPF32[(($91)>>2)];
      var $93=($87)*($92);
      var $94=($84)-($93);
      var $95=$attr;
      var $96=(($95+16)|0);
      var $97=HEAP32[(($96)>>2)];
      var $98=(($97+80)|0);
      var $99=HEAPF32[(($98)>>2)];
      var $100=($94)+($99);
      $4=$100;
      var $101=$6;
      var $102=(($bbox+4)|0);
      var $103=HEAPF32[(($102)>>2)];
      var $104=($103)/(1000);
      var $105=$attr;
      var $106=(($105+16)|0);
      var $107=HEAP32[(($106)>>2)];
      var $108=(($107+168)|0);
      var $109=HEAPF32[(($108)>>2)];
      var $110=($104)*($109);
      var $111=($101)-($110);
      $6=$111;
      var $112=$attr;
      var $113=(($112+44)|0);
      var $114=(($113)|0);
      var $115=HEAPF32[(($114)>>2)];
      var $116=$115 == 0;
      if ($116) { __label__ = 16; break; } else { __label__ = 17; break; }
    case 16: 
      var $118=$3;
      var $119=$attr;
      var $120=(($119+44)|0);
      var $121=(($120+16)|0);
      var $122=HEAPF32[(($121)>>2)];
      var $123=($118)-($122);
      var $124=$attr;
      var $125=(($124+44)|0);
      var $126=(($125+8)|0);
      var $127=HEAPF32[(($126)>>2)];
      var $128=($123)/($127);
      $y=$128;
      var $129=$4;
      var $130=$attr;
      var $131=(($130+44)|0);
      var $132=(($131+20)|0);
      var $133=HEAPF32[(($132)>>2)];
      var $134=($129)-($133);
      var $135=$3;
      var $136=$attr;
      var $137=(($136+44)|0);
      var $138=(($137+16)|0);
      var $139=HEAPF32[(($138)>>2)];
      var $140=($135)-($139);
      var $141=$attr;
      var $142=(($141+44)|0);
      var $143=(($142+12)|0);
      var $144=HEAPF32[(($143)>>2)];
      var $145=($140)*($144);
      var $146=$attr;
      var $147=(($146+44)|0);
      var $148=(($147+8)|0);
      var $149=HEAPF32[(($148)>>2)];
      var $150=($145)/($149);
      var $151=($134)-($150);
      var $152=$attr;
      var $153=(($152+44)|0);
      var $154=(($153+4)|0);
      var $155=HEAPF32[(($154)>>2)];
      var $156=($151)/($155);
      $x=$156;
      __label__ = 18; break;
    case 17: 
      var $158=$4;
      var $159=$attr;
      var $160=(($159+44)|0);
      var $161=(($160+20)|0);
      var $162=HEAPF32[(($161)>>2)];
      var $163=($158)-($162);
      var $164=$3;
      var $165=$attr;
      var $166=(($165+44)|0);
      var $167=(($166+16)|0);
      var $168=HEAPF32[(($167)>>2)];
      var $169=($164)-($168);
      var $170=$attr;
      var $171=(($170+44)|0);
      var $172=(($171+4)|0);
      var $173=HEAPF32[(($172)>>2)];
      var $174=($169)*($173);
      var $175=$attr;
      var $176=(($175+44)|0);
      var $177=(($176)|0);
      var $178=HEAPF32[(($177)>>2)];
      var $179=($174)/($178);
      var $180=($163)-($179);
      var $181=$attr;
      var $182=(($181+44)|0);
      var $183=(($182+12)|0);
      var $184=HEAPF32[(($183)>>2)];
      var $185=$attr;
      var $186=(($185+44)|0);
      var $187=(($186+8)|0);
      var $188=HEAPF32[(($187)>>2)];
      var $189=$attr;
      var $190=(($189+44)|0);
      var $191=(($190+4)|0);
      var $192=HEAPF32[(($191)>>2)];
      var $193=($188)*($192);
      var $194=$attr;
      var $195=(($194+44)|0);
      var $196=(($195)|0);
      var $197=HEAPF32[(($196)>>2)];
      var $198=($193)/($197);
      var $199=($184)-($198);
      var $200=($180)/($199);
      $y=$200;
      var $201=$3;
      var $202=$attr;
      var $203=(($202+44)|0);
      var $204=(($203+16)|0);
      var $205=HEAPF32[(($204)>>2)];
      var $206=($201)-($205);
      var $207=$y;
      var $208=$attr;
      var $209=(($208+44)|0);
      var $210=(($209+8)|0);
      var $211=HEAPF32[(($210)>>2)];
      var $212=($207)*($211);
      var $213=($206)-($212);
      var $214=$attr;
      var $215=(($214+44)|0);
      var $216=(($215)|0);
      var $217=HEAPF32[(($216)>>2)];
      var $218=($213)/($217);
      $x=$218;
      __label__ = 18; break;
    case 18: 
      var $220=$2;
      var $221=$x;
      var $222=$y;
      var $223=_HPDF_Page_MoveTextPos($220, $221, $222);
      $ret=$223;
      var $224=(($223)|0)!=0;
      if ($224) { __label__ = 19; break; } else { __label__ = 20; break; }
    case 19: 
      var $226=$ret;
      $1=$226;
      __label__ = 84; break;
    case 20: 
      var $228=$8;
      var $229=(($228)|0)==3;
      if ($229) { __label__ = 21; break; } else { __label__ = 22; break; }
    case 21: 
      var $231=$attr;
      var $232=(($231+16)|0);
      var $233=HEAP32[(($232)>>2)];
      var $234=(($233+68)|0);
      var $235=HEAPF32[(($234)>>2)];
      $save_char_space=$235;
      var $236=$attr;
      var $237=(($236+16)|0);
      var $238=HEAP32[(($237)>>2)];
      var $239=(($238+68)|0);
      HEAPF32[(($239)>>2)]=0;
      __label__ = 22; break;
    case 22: 
      __label__ = 23; break;
    case 23: 
      var $242=$2;
      var $243=$ptr;
      var $244=$5;
      var $245=$3;
      var $246=($244)-($245);
      var $247=_HPDF_Page_MeasureText($242, $243, $246, 1, $rw);
      $tmp_len=$247;
      var $248=$tmp_len;
      var $249=(($248)|0)==0;
      if ($249) { __label__ = 24; break; } else { __label__ = 25; break; }
    case 24: 
      $is_insufficient_space=1;
      __label__ = 77; break;
    case 25: 
      var $252=$9;
      var $253=(($252)|0)!=0;
      if ($253) { __label__ = 26; break; } else { __label__ = 27; break; }
    case 26: 
      var $255=$tmp_len;
      var $256=$9;
      var $257=HEAP32[(($256)>>2)];
      var $258=((($257)+($255))|0);
      HEAP32[(($256)>>2)]=$258;
      __label__ = 27; break;
    case 27: 
      var $260=$8;
      if ((($260)|0) == 1) {
        __label__ = 28; break;
      }
      else if ((($260)|0) == 2) {
        __label__ = 35; break;
      }
      else if ((($260)|0) == 3) {
        __label__ = 42; break;
      }
      else {
      __label__ = 69; break;
      }
      
    case 28: 
      var $262=$5;
      var $263=$3;
      var $264=($262)-($263);
      var $265=HEAPF32[(($rw)>>2)];
      var $266=($264)-($265);
      $x_adjust=$266;
      var $267=$2;
      var $268=$x_adjust;
      var $269=_HPDF_Page_MoveTextPos($267, $268, 0);
      $ret=$269;
      var $270=(($269)|0)!=0;
      if ($270) { __label__ = 29; break; } else { __label__ = 30; break; }
    case 29: 
      var $272=$ret;
      $1=$272;
      __label__ = 84; break;
    case 30: 
      var $274=$2;
      var $275=$ptr;
      var $276=$tmp_len;
      var $277=_InternalShowTextNextLine($274, $275, $276);
      $ret=$277;
      var $278=(($277)|0)!=0;
      if ($278) { __label__ = 31; break; } else { __label__ = 32; break; }
    case 31: 
      var $280=$2;
      var $281=(($280+12)|0);
      var $282=HEAP32[(($281)>>2)];
      var $283=_HPDF_CheckError($282);
      $1=$283;
      __label__ = 84; break;
    case 32: 
      var $285=$2;
      var $286=$x_adjust;
      var $287=(-$286);
      var $288=_HPDF_Page_MoveTextPos($285, $287, 0);
      $ret=$288;
      var $289=(($288)|0)!=0;
      if ($289) { __label__ = 33; break; } else { __label__ = 34; break; }
    case 33: 
      var $291=$ret;
      $1=$291;
      __label__ = 84; break;
    case 34: 
      __label__ = 72; break;
    case 35: 
      var $294=$5;
      var $295=$3;
      var $296=($294)-($295);
      var $297=HEAPF32[(($rw)>>2)];
      var $298=($296)-($297);
      var $299=($298)/(2);
      $x_adjust=$299;
      var $300=$2;
      var $301=$x_adjust;
      var $302=_HPDF_Page_MoveTextPos($300, $301, 0);
      $ret=$302;
      var $303=(($302)|0)!=0;
      if ($303) { __label__ = 36; break; } else { __label__ = 37; break; }
    case 36: 
      var $305=$ret;
      $1=$305;
      __label__ = 84; break;
    case 37: 
      var $307=$2;
      var $308=$ptr;
      var $309=$tmp_len;
      var $310=_InternalShowTextNextLine($307, $308, $309);
      $ret=$310;
      var $311=(($310)|0)!=0;
      if ($311) { __label__ = 38; break; } else { __label__ = 39; break; }
    case 38: 
      var $313=$2;
      var $314=(($313+12)|0);
      var $315=HEAP32[(($314)>>2)];
      var $316=_HPDF_CheckError($315);
      $1=$316;
      __label__ = 84; break;
    case 39: 
      var $318=$2;
      var $319=$x_adjust;
      var $320=(-$319);
      var $321=_HPDF_Page_MoveTextPos($318, $320, 0);
      $ret=$321;
      var $322=(($321)|0)!=0;
      if ($322) { __label__ = 40; break; } else { __label__ = 41; break; }
    case 40: 
      var $324=$ret;
      $1=$324;
      __label__ = 84; break;
    case 41: 
      __label__ = 72; break;
    case 42: 
      $num_char=0;
      var $327=$attr;
      var $328=(($327+16)|0);
      var $329=HEAP32[(($328)>>2)];
      var $330=(($329+164)|0);
      var $331=HEAP32[(($330)>>2)];
      var $332=(($331+44)|0);
      var $333=HEAP32[(($332)>>2)];
      var $334=$333;
      var $335=(($334+20)|0);
      var $336=HEAP32[(($335)>>2)];
      $encoder=$336;
      var $337=$ptr;
      $tmp_ptr=$337;
      var $338=$encoder;
      var $339=$tmp_ptr;
      var $340=$tmp_len;
      _HPDF_Encoder_SetParseText($338, $state, $339, $340);
      $i=0;
      __label__ = 43; break;
    case 43: 
      var $342=$tmp_ptr;
      var $343=HEAP8[($342)];
      var $344=(($343 << 24) >> 24)!=0;
      if ($344) { __label__ = 44; break; } else { __label__ = 49; break; }
    case 44: 
      var $346=$encoder;
      var $347=_HPDF_Encoder_ByteType($346, $state);
      $btype=$347;
      var $348=$btype;
      var $349=(($348)|0)!=2;
      if ($349) { __label__ = 45; break; } else { __label__ = 46; break; }
    case 45: 
      var $351=$num_char;
      var $352=((($351)+(1))|0);
      $num_char=$352;
      __label__ = 46; break;
    case 46: 
      var $354=$i;
      var $355=((($354)+(1))|0);
      $i=$355;
      var $356=$i;
      var $357=$tmp_len;
      var $358=(($356)>>>0) >= (($357)>>>0);
      if ($358) { __label__ = 47; break; } else { __label__ = 48; break; }
    case 47: 
      __label__ = 49; break;
    case 48: 
      var $361=$tmp_ptr;
      var $362=(($361+1)|0);
      $tmp_ptr=$362;
      __label__ = 43; break;
    case 49: 
      var $364=$tmp_ptr;
      var $365=HEAP8[($364)];
      var $366=(($365 << 24) >> 24);
      var $367=(($366)|0)==0;
      if ($367) { __label__ = 55; break; } else { __label__ = 50; break; }
    case 50: 
      var $369=$tmp_ptr;
      var $370=HEAP8[($369)];
      var $371=(($370 << 24) >> 24);
      var $372=(($371)|0)==9;
      if ($372) { __label__ = 55; break; } else { __label__ = 51; break; }
    case 51: 
      var $374=$tmp_ptr;
      var $375=HEAP8[($374)];
      var $376=(($375 << 24) >> 24);
      var $377=(($376)|0)==10;
      if ($377) { __label__ = 55; break; } else { __label__ = 52; break; }
    case 52: 
      var $379=$tmp_ptr;
      var $380=HEAP8[($379)];
      var $381=(($380 << 24) >> 24);
      var $382=(($381)|0)==12;
      if ($382) { __label__ = 55; break; } else { __label__ = 53; break; }
    case 53: 
      var $384=$tmp_ptr;
      var $385=HEAP8[($384)];
      var $386=(($385 << 24) >> 24);
      var $387=(($386)|0)==13;
      if ($387) { __label__ = 55; break; } else { __label__ = 54; break; }
    case 54: 
      var $389=$tmp_ptr;
      var $390=HEAP8[($389)];
      var $391=(($390 << 24) >> 24);
      var $392=(($391)|0)==32;
      if ($392) { __label__ = 55; break; } else { __label__ = 56; break; }
    case 55: 
      var $394=$num_char;
      var $395=((($394)-(1))|0);
      $num_char=$395;
      __label__ = 56; break;
    case 56: 
      var $397=$num_char;
      var $398=(($397)>>>0) > 1;
      if ($398) { __label__ = 57; break; } else { __label__ = 58; break; }
    case 57: 
      var $400=$5;
      var $401=$3;
      var $402=($400)-($401);
      var $403=HEAPF32[(($rw)>>2)];
      var $404=($402)-($403);
      var $405=$num_char;
      var $406=((($405)-(1))|0);
      var $407=(($406)>>>0);
      var $408=($404)/($407);
      $x_adjust=$408;
      __label__ = 59; break;
    case 58: 
      $x_adjust=0;
      __label__ = 59; break;
    case 59: 
      var $411=$num_rest;
      var $412=$tmp_len;
      var $413=(($411)|0)==(($412)|0);
      if ($413) { __label__ = 60; break; } else { __label__ = 63; break; }
    case 60: 
      var $415=$2;
      var $416=$save_char_space;
      var $417=_HPDF_Page_SetCharSpace($415, $416);
      $ret=$417;
      var $418=(($417)|0)!=0;
      if ($418) { __label__ = 61; break; } else { __label__ = 62; break; }
    case 61: 
      var $420=$ret;
      $1=$420;
      __label__ = 84; break;
    case 62: 
      $char_space_changed=0;
      __label__ = 66; break;
    case 63: 
      var $423=$2;
      var $424=$x_adjust;
      var $425=_HPDF_Page_SetCharSpace($423, $424);
      $ret=$425;
      var $426=(($425)|0)!=0;
      if ($426) { __label__ = 64; break; } else { __label__ = 65; break; }
    case 64: 
      var $428=$ret;
      $1=$428;
      __label__ = 84; break;
    case 65: 
      $char_space_changed=1;
      __label__ = 66; break;
    case 66: 
      var $431=$2;
      var $432=$ptr;
      var $433=$tmp_len;
      var $434=_InternalShowTextNextLine($431, $432, $433);
      $ret=$434;
      var $435=(($434)|0)!=0;
      if ($435) { __label__ = 67; break; } else { __label__ = 68; break; }
    case 67: 
      var $437=$2;
      var $438=(($437+12)|0);
      var $439=HEAP32[(($438)>>2)];
      var $440=_HPDF_CheckError($439);
      $1=$440;
      __label__ = 84; break;
    case 68: 
      var $442=$attr;
      var $443=(($442+16)|0);
      var $444=HEAP32[(($443)>>2)];
      var $445=(($444+68)|0);
      HEAPF32[(($445)>>2)]=0;
      __label__ = 72; break;
    case 69: 
      var $447=$2;
      var $448=$ptr;
      var $449=$tmp_len;
      var $450=_InternalShowTextNextLine($447, $448, $449);
      $ret=$450;
      var $451=(($450)|0)!=0;
      if ($451) { __label__ = 70; break; } else { __label__ = 71; break; }
    case 70: 
      var $453=$2;
      var $454=(($453+12)|0);
      var $455=HEAP32[(($454)>>2)];
      var $456=_HPDF_CheckError($455);
      $1=$456;
      __label__ = 84; break;
    case 71: 
      __label__ = 72; break;
    case 72: 
      var $459=$tmp_len;
      var $460=$num_rest;
      var $461=((($460)-($459))|0);
      $num_rest=$461;
      var $462=$num_rest;
      var $463=(($462)>>>0) <= 0;
      if ($463) { __label__ = 73; break; } else { __label__ = 74; break; }
    case 73: 
      __label__ = 77; break;
    case 74: 
      var $466=$attr;
      var $467=(($466+36)|0);
      var $468=(($467+4)|0);
      var $469=HEAPF32[(($468)>>2)];
      var $470=$attr;
      var $471=(($470+16)|0);
      var $472=HEAP32[(($471)>>2)];
      var $473=(($472+80)|0);
      var $474=HEAPF32[(($473)>>2)];
      var $475=($469)-($474);
      var $476=$6;
      var $477=$475 < $476;
      if ($477) { __label__ = 75; break; } else { __label__ = 76; break; }
    case 75: 
      $is_insufficient_space=1;
      __label__ = 77; break;
    case 76: 
      var $480=$tmp_len;
      var $481=$ptr;
      var $482=(($481+$480)|0);
      $ptr=$482;
      __label__ = 23; break;
    case 77: 
      var $484=$char_space_changed;
      var $485=(($484)|0)!=0;
      if ($485) { __label__ = 78; break; } else { __label__ = 81; break; }
    case 78: 
      var $487=$2;
      var $488=$save_char_space;
      var $489=_HPDF_Page_SetCharSpace($487, $488);
      $ret=$489;
      var $490=(($489)|0)!=0;
      if ($490) { __label__ = 79; break; } else { __label__ = 80; break; }
    case 79: 
      var $492=$ret;
      $1=$492;
      __label__ = 84; break;
    case 80: 
      __label__ = 81; break;
    case 81: 
      var $495=$is_insufficient_space;
      var $496=(($495)|0)!=0;
      if ($496) { __label__ = 82; break; } else { __label__ = 83; break; }
    case 82: 
      $1=4214;
      __label__ = 84; break;
    case 83: 
      $1=0;
      __label__ = 84; break;
    case 84: 
      var $500=$1;
      STACKTOP = __stackBase__;
      return $500;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Page_TextRect["X"]=1;

function _InternalShowTextNextLine($page, $text, $len) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $ret;
      var $attr;
      var $tw;
      var $font_attr;
      $2=$page;
      $3=$text;
      $4=$len;
      var $5=$2;
      var $6=(($5+44)|0);
      var $7=HEAP32[(($6)>>2)];
      var $8=$7;
      $attr=$8;
      var $9=$attr;
      var $10=(($9+16)|0);
      var $11=HEAP32[(($10)>>2)];
      var $12=(($11+164)|0);
      var $13=HEAP32[(($12)>>2)];
      var $14=(($13+44)|0);
      var $15=HEAP32[(($14)>>2)];
      var $16=$15;
      $font_attr=$16;
      var $17=$font_attr;
      var $18=(($17)|0);
      var $19=HEAP32[(($18)>>2)];
      var $20=(($19)|0)==4;
      if ($20) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      var $22=$font_attr;
      var $23=(($22)|0);
      var $24=HEAP32[(($23)>>2)];
      var $25=(($24)|0)==3;
      if ($25) { __label__ = 4; break; } else { __label__ = 11; break; }
    case 4: 
      var $27=$attr;
      var $28=(($27+76)|0);
      var $29=HEAP32[(($28)>>2)];
      var $30=_HPDF_Stream_WriteStr($29, ((STRING_TABLE.__str701620)|0));
      $ret=$30;
      var $31=(($30)|0)!=0;
      if ($31) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $33=$ret;
      $1=$33;
      __label__ = 20; break;
    case 6: 
      var $35=$attr;
      var $36=(($35+76)|0);
      var $37=HEAP32[(($36)>>2)];
      var $38=$3;
      var $39=$4;
      var $40=_HPDF_Stream_WriteBinary($37, $38, $39, 0);
      $ret=$40;
      var $41=(($40)|0)!=0;
      if ($41) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $43=$ret;
      $1=$43;
      __label__ = 20; break;
    case 8: 
      var $45=$attr;
      var $46=(($45+76)|0);
      var $47=HEAP32[(($46)>>2)];
      var $48=_HPDF_Stream_WriteStr($47, ((STRING_TABLE.__str711621)|0));
      $ret=$48;
      var $49=(($48)|0)!=0;
      if ($49) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      var $51=$ret;
      $1=$51;
      __label__ = 20; break;
    case 10: 
      __label__ = 14; break;
    case 11: 
      var $54=$attr;
      var $55=(($54+76)|0);
      var $56=HEAP32[(($55)>>2)];
      var $57=$3;
      var $58=$4;
      var $59=_HPDF_Stream_WriteEscapeText2($56, $57, $58);
      $ret=$59;
      var $60=(($59)|0)!=0;
      if ($60) { __label__ = 12; break; } else { __label__ = 13; break; }
    case 12: 
      var $62=$ret;
      $1=$62;
      __label__ = 20; break;
    case 13: 
      __label__ = 14; break;
    case 14: 
      var $65=$attr;
      var $66=(($65+76)|0);
      var $67=HEAP32[(($66)>>2)];
      var $68=_HPDF_Stream_WriteStr($67, ((STRING_TABLE.__str421592)|0));
      $ret=$68;
      var $69=(($68)|0)!=0;
      if ($69) { __label__ = 15; break; } else { __label__ = 16; break; }
    case 15: 
      var $71=$ret;
      $1=$71;
      __label__ = 20; break;
    case 16: 
      var $73=$2;
      var $74=$3;
      var $75=_HPDF_Page_TextWidth($73, $74);
      $tw=$75;
      var $76=$attr;
      var $77=(($76+16)|0);
      var $78=HEAP32[(($77)>>2)];
      var $79=(($78+80)|0);
      var $80=HEAPF32[(($79)>>2)];
      var $81=$attr;
      var $82=(($81+44)|0);
      var $83=(($82+8)|0);
      var $84=HEAPF32[(($83)>>2)];
      var $85=($80)*($84);
      var $86=$attr;
      var $87=(($86+44)|0);
      var $88=(($87+16)|0);
      var $89=HEAPF32[(($88)>>2)];
      var $90=($89)-($85);
      HEAPF32[(($88)>>2)]=$90;
      var $91=$attr;
      var $92=(($91+16)|0);
      var $93=HEAP32[(($92)>>2)];
      var $94=(($93+80)|0);
      var $95=HEAPF32[(($94)>>2)];
      var $96=$attr;
      var $97=(($96+44)|0);
      var $98=(($97+12)|0);
      var $99=HEAPF32[(($98)>>2)];
      var $100=($95)*($99);
      var $101=$attr;
      var $102=(($101+44)|0);
      var $103=(($102+20)|0);
      var $104=HEAPF32[(($103)>>2)];
      var $105=($104)-($100);
      HEAPF32[(($103)>>2)]=$105;
      var $106=$attr;
      var $107=(($106+44)|0);
      var $108=(($107+16)|0);
      var $109=HEAPF32[(($108)>>2)];
      var $110=$attr;
      var $111=(($110+36)|0);
      var $112=(($111)|0);
      HEAPF32[(($112)>>2)]=$109;
      var $113=$attr;
      var $114=(($113+44)|0);
      var $115=(($114+20)|0);
      var $116=HEAPF32[(($115)>>2)];
      var $117=$attr;
      var $118=(($117+36)|0);
      var $119=(($118+4)|0);
      HEAPF32[(($119)>>2)]=$116;
      var $120=$attr;
      var $121=(($120+16)|0);
      var $122=HEAP32[(($121)>>2)];
      var $123=(($122+172)|0);
      var $124=HEAP32[(($123)>>2)];
      var $125=(($124)|0)==0;
      if ($125) { __label__ = 17; break; } else { __label__ = 18; break; }
    case 17: 
      var $127=$tw;
      var $128=$attr;
      var $129=(($128+44)|0);
      var $130=(($129)|0);
      var $131=HEAPF32[(($130)>>2)];
      var $132=($127)*($131);
      var $133=$attr;
      var $134=(($133+36)|0);
      var $135=(($134)|0);
      var $136=HEAPF32[(($135)>>2)];
      var $137=($136)+($132);
      HEAPF32[(($135)>>2)]=$137;
      var $138=$tw;
      var $139=$attr;
      var $140=(($139+44)|0);
      var $141=(($140+4)|0);
      var $142=HEAPF32[(($141)>>2)];
      var $143=($138)*($142);
      var $144=$attr;
      var $145=(($144+36)|0);
      var $146=(($145+4)|0);
      var $147=HEAPF32[(($146)>>2)];
      var $148=($147)+($143);
      HEAPF32[(($146)>>2)]=$148;
      __label__ = 19; break;
    case 18: 
      var $150=$tw;
      var $151=$attr;
      var $152=(($151+44)|0);
      var $153=(($152+4)|0);
      var $154=HEAPF32[(($153)>>2)];
      var $155=($150)*($154);
      var $156=$attr;
      var $157=(($156+36)|0);
      var $158=(($157)|0);
      var $159=HEAPF32[(($158)>>2)];
      var $160=($159)-($155);
      HEAPF32[(($158)>>2)]=$160;
      var $161=$tw;
      var $162=$attr;
      var $163=(($162+44)|0);
      var $164=(($163)|0);
      var $165=HEAPF32[(($164)>>2)];
      var $166=($161)*($165);
      var $167=$attr;
      var $168=(($167+36)|0);
      var $169=(($168+4)|0);
      var $170=HEAPF32[(($169)>>2)];
      var $171=($170)-($166);
      HEAPF32[(($169)>>2)]=$171;
      __label__ = 19; break;
    case 19: 
      var $173=$ret;
      $1=$173;
      __label__ = 20; break;
    case 20: 
      var $175=$1;
      ;
      return $175;
    default: assert(0, "bad label: " + __label__);
  }
}
_InternalShowTextNextLine["X"]=1;

function _HPDF_Page_SetSlideShow($page, $type, $disp_time, $trans_time) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $5;
      var $ret;
      var $dict;
      $2=$page;
      $3=$type;
      $4=$disp_time;
      $5=$trans_time;
      $ret=0;
      var $6=$2;
      var $7=_HPDF_Page_Validate($6);
      var $8=(($7)|0)!=0;
      if ($8) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=4151;
      __label__ = 41; break;
    case 4: 
      var $11=$4;
      var $12=$11 < 0;
      if ($12) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $14=$2;
      var $15=(($14+12)|0);
      var $16=HEAP32[(($15)>>2)];
      var $17=$4;
      var $18=($17 >= 0 ? Math.floor($17) : Math.ceil($17));
      var $19=_HPDF_RaiseError($16, 4215, $18);
      $1=$19;
      __label__ = 41; break;
    case 6: 
      var $21=$5;
      var $22=$21 < 0;
      if ($22) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $24=$2;
      var $25=(($24+12)|0);
      var $26=HEAP32[(($25)>>2)];
      var $27=$5;
      var $28=($27 >= 0 ? Math.floor($27) : Math.ceil($27));
      var $29=_HPDF_RaiseError($26, 4216, $28);
      $1=$29;
      __label__ = 41; break;
    case 8: 
      var $31=$2;
      var $32=(($31+8)|0);
      var $33=HEAP32[(($32)>>2)];
      var $34=_HPDF_Dict_New($33);
      $dict=$34;
      var $35=$dict;
      var $36=(($35)|0)!=0;
      if ($36) { __label__ = 10; break; } else { __label__ = 9; break; }
    case 9: 
      var $38=$2;
      var $39=(($38+12)|0);
      var $40=HEAP32[(($39)>>2)];
      var $41=_HPDF_Error_GetCode($40);
      $1=$41;
      __label__ = 41; break;
    case 10: 
      var $43=$dict;
      var $44=_HPDF_Dict_AddName($43, ((STRING_TABLE.__str511601)|0), ((STRING_TABLE.__str521602)|0));
      $ret=$44;
      var $45=(($44)|0)!=0;
      if ($45) { __label__ = 11; break; } else { __label__ = 12; break; }
    case 11: 
      __label__ = 40; break;
    case 12: 
      var $48=$dict;
      var $49=$5;
      var $50=_HPDF_Dict_AddReal($48, ((STRING_TABLE.__str531603)|0), $49);
      $ret=$50;
      var $51=(($50)|0)!=0;
      if ($51) { __label__ = 13; break; } else { __label__ = 14; break; }
    case 13: 
      __label__ = 40; break;
    case 14: 
      var $54=$3;
      if ((($54)|0) == 0) {
        __label__ = 15; break;
      }
      else if ((($54)|0) == 1) {
        __label__ = 16; break;
      }
      else if ((($54)|0) == 2) {
        __label__ = 17; break;
      }
      else if ((($54)|0) == 3) {
        __label__ = 18; break;
      }
      else if ((($54)|0) == 4) {
        __label__ = 19; break;
      }
      else if ((($54)|0) == 5) {
        __label__ = 20; break;
      }
      else if ((($54)|0) == 6) {
        __label__ = 21; break;
      }
      else if ((($54)|0) == 7) {
        __label__ = 22; break;
      }
      else if ((($54)|0) == 8) {
        __label__ = 23; break;
      }
      else if ((($54)|0) == 9) {
        __label__ = 24; break;
      }
      else if ((($54)|0) == 10) {
        __label__ = 25; break;
      }
      else if ((($54)|0) == 11) {
        __label__ = 26; break;
      }
      else if ((($54)|0) == 12) {
        __label__ = 27; break;
      }
      else if ((($54)|0) == 13) {
        __label__ = 28; break;
      }
      else if ((($54)|0) == 14) {
        __label__ = 29; break;
      }
      else if ((($54)|0) == 15) {
        __label__ = 30; break;
      }
      else if ((($54)|0) == 16) {
        __label__ = 31; break;
      }
      else {
      __label__ = 32; break;
      }
      
    case 15: 
      var $56=$dict;
      var $57=_HPDF_Dict_AddName($56, ((STRING_TABLE.__str541604)|0), ((STRING_TABLE.__str551605)|0));
      var $58=$ret;
      var $59=((($58)+($57))|0);
      $ret=$59;
      var $60=$dict;
      var $61=_HPDF_Dict_AddNumber($60, ((STRING_TABLE.__str561606)|0), 0);
      var $62=$ret;
      var $63=((($62)+($61))|0);
      $ret=$63;
      __label__ = 33; break;
    case 16: 
      var $65=$dict;
      var $66=_HPDF_Dict_AddName($65, ((STRING_TABLE.__str541604)|0), ((STRING_TABLE.__str551605)|0));
      var $67=$ret;
      var $68=((($67)+($66))|0);
      $ret=$68;
      var $69=$dict;
      var $70=_HPDF_Dict_AddNumber($69, ((STRING_TABLE.__str561606)|0), 90);
      var $71=$ret;
      var $72=((($71)+($70))|0);
      $ret=$72;
      __label__ = 33; break;
    case 17: 
      var $74=$dict;
      var $75=_HPDF_Dict_AddName($74, ((STRING_TABLE.__str541604)|0), ((STRING_TABLE.__str551605)|0));
      var $76=$ret;
      var $77=((($76)+($75))|0);
      $ret=$77;
      var $78=$dict;
      var $79=_HPDF_Dict_AddNumber($78, ((STRING_TABLE.__str561606)|0), 180);
      var $80=$ret;
      var $81=((($80)+($79))|0);
      $ret=$81;
      __label__ = 33; break;
    case 18: 
      var $83=$dict;
      var $84=_HPDF_Dict_AddName($83, ((STRING_TABLE.__str541604)|0), ((STRING_TABLE.__str551605)|0));
      var $85=$ret;
      var $86=((($85)+($84))|0);
      $ret=$86;
      var $87=$dict;
      var $88=_HPDF_Dict_AddNumber($87, ((STRING_TABLE.__str561606)|0), 270);
      var $89=$ret;
      var $90=((($89)+($88))|0);
      $ret=$90;
      __label__ = 33; break;
    case 19: 
      var $92=$dict;
      var $93=_HPDF_Dict_AddName($92, ((STRING_TABLE.__str541604)|0), ((STRING_TABLE.__str571607)|0));
      var $94=$ret;
      var $95=((($94)+($93))|0);
      $ret=$95;
      var $96=$dict;
      var $97=_HPDF_Dict_AddName($96, ((STRING_TABLE.__str581608)|0), ((STRING_TABLE.__str591609)|0));
      var $98=$ret;
      var $99=((($98)+($97))|0);
      $ret=$99;
      var $100=$dict;
      var $101=_HPDF_Dict_AddName($100, ((STRING_TABLE.__str601610)|0), ((STRING_TABLE.__str611611)|0));
      var $102=$ret;
      var $103=((($102)+($101))|0);
      $ret=$103;
      __label__ = 33; break;
    case 20: 
      var $105=$dict;
      var $106=_HPDF_Dict_AddName($105, ((STRING_TABLE.__str541604)|0), ((STRING_TABLE.__str571607)|0));
      var $107=$ret;
      var $108=((($107)+($106))|0);
      $ret=$108;
      var $109=$dict;
      var $110=_HPDF_Dict_AddName($109, ((STRING_TABLE.__str581608)|0), ((STRING_TABLE.__str591609)|0));
      var $111=$ret;
      var $112=((($111)+($110))|0);
      $ret=$112;
      var $113=$dict;
      var $114=_HPDF_Dict_AddName($113, ((STRING_TABLE.__str601610)|0), ((STRING_TABLE.__str621612)|0));
      var $115=$ret;
      var $116=((($115)+($114))|0);
      $ret=$116;
      __label__ = 33; break;
    case 21: 
      var $118=$dict;
      var $119=_HPDF_Dict_AddName($118, ((STRING_TABLE.__str541604)|0), ((STRING_TABLE.__str571607)|0));
      var $120=$ret;
      var $121=((($120)+($119))|0);
      $ret=$121;
      var $122=$dict;
      var $123=_HPDF_Dict_AddName($122, ((STRING_TABLE.__str581608)|0), ((STRING_TABLE.__str631613)|0));
      var $124=$ret;
      var $125=((($124)+($123))|0);
      $ret=$125;
      var $126=$dict;
      var $127=_HPDF_Dict_AddName($126, ((STRING_TABLE.__str601610)|0), ((STRING_TABLE.__str611611)|0));
      var $128=$ret;
      var $129=((($128)+($127))|0);
      $ret=$129;
      __label__ = 33; break;
    case 22: 
      var $131=$dict;
      var $132=_HPDF_Dict_AddName($131, ((STRING_TABLE.__str541604)|0), ((STRING_TABLE.__str571607)|0));
      var $133=$ret;
      var $134=((($133)+($132))|0);
      $ret=$134;
      var $135=$dict;
      var $136=_HPDF_Dict_AddName($135, ((STRING_TABLE.__str581608)|0), ((STRING_TABLE.__str631613)|0));
      var $137=$ret;
      var $138=((($137)+($136))|0);
      $ret=$138;
      var $139=$dict;
      var $140=_HPDF_Dict_AddName($139, ((STRING_TABLE.__str601610)|0), ((STRING_TABLE.__str621612)|0));
      var $141=$ret;
      var $142=((($141)+($140))|0);
      $ret=$142;
      __label__ = 33; break;
    case 23: 
      var $144=$dict;
      var $145=_HPDF_Dict_AddName($144, ((STRING_TABLE.__str541604)|0), ((STRING_TABLE.__str641614)|0));
      var $146=$ret;
      var $147=((($146)+($145))|0);
      $ret=$147;
      var $148=$dict;
      var $149=_HPDF_Dict_AddName($148, ((STRING_TABLE.__str601610)|0), ((STRING_TABLE.__str611611)|0));
      var $150=$ret;
      var $151=((($150)+($149))|0);
      $ret=$151;
      __label__ = 33; break;
    case 24: 
      var $153=$dict;
      var $154=_HPDF_Dict_AddName($153, ((STRING_TABLE.__str541604)|0), ((STRING_TABLE.__str641614)|0));
      var $155=$ret;
      var $156=((($155)+($154))|0);
      $ret=$156;
      var $157=$dict;
      var $158=_HPDF_Dict_AddName($157, ((STRING_TABLE.__str601610)|0), ((STRING_TABLE.__str621612)|0));
      var $159=$ret;
      var $160=((($159)+($158))|0);
      $ret=$160;
      __label__ = 33; break;
    case 25: 
      var $162=$dict;
      var $163=_HPDF_Dict_AddName($162, ((STRING_TABLE.__str541604)|0), ((STRING_TABLE.__str651615)|0));
      var $164=$ret;
      var $165=((($164)+($163))|0);
      $ret=$165;
      var $166=$dict;
      var $167=_HPDF_Dict_AddName($166, ((STRING_TABLE.__str581608)|0), ((STRING_TABLE.__str591609)|0));
      var $168=$ret;
      var $169=((($168)+($167))|0);
      $ret=$169;
      __label__ = 33; break;
    case 26: 
      var $171=$dict;
      var $172=_HPDF_Dict_AddName($171, ((STRING_TABLE.__str541604)|0), ((STRING_TABLE.__str651615)|0));
      var $173=$ret;
      var $174=((($173)+($172))|0);
      $ret=$174;
      var $175=$dict;
      var $176=_HPDF_Dict_AddName($175, ((STRING_TABLE.__str581608)|0), ((STRING_TABLE.__str631613)|0));
      var $177=$ret;
      var $178=((($177)+($176))|0);
      $ret=$178;
      __label__ = 33; break;
    case 27: 
      var $180=$dict;
      var $181=_HPDF_Dict_AddName($180, ((STRING_TABLE.__str541604)|0), ((STRING_TABLE.__str661616)|0));
      var $182=$ret;
      var $183=((($182)+($181))|0);
      $ret=$183;
      __label__ = 33; break;
    case 28: 
      var $185=$dict;
      var $186=_HPDF_Dict_AddName($185, ((STRING_TABLE.__str541604)|0), ((STRING_TABLE.__str671617)|0));
      var $187=$ret;
      var $188=((($187)+($186))|0);
      $ret=$188;
      var $189=$dict;
      var $190=_HPDF_Dict_AddNumber($189, ((STRING_TABLE.__str561606)|0), 0);
      var $191=$ret;
      var $192=((($191)+($190))|0);
      $ret=$192;
      __label__ = 33; break;
    case 29: 
      var $194=$dict;
      var $195=_HPDF_Dict_AddName($194, ((STRING_TABLE.__str541604)|0), ((STRING_TABLE.__str671617)|0));
      var $196=$ret;
      var $197=((($196)+($195))|0);
      $ret=$197;
      var $198=$dict;
      var $199=_HPDF_Dict_AddNumber($198, ((STRING_TABLE.__str561606)|0), 270);
      var $200=$ret;
      var $201=((($200)+($199))|0);
      $ret=$201;
      __label__ = 33; break;
    case 30: 
      var $203=$dict;
      var $204=_HPDF_Dict_AddName($203, ((STRING_TABLE.__str541604)|0), ((STRING_TABLE.__str671617)|0));
      var $205=$ret;
      var $206=((($205)+($204))|0);
      $ret=$206;
      var $207=$dict;
      var $208=_HPDF_Dict_AddNumber($207, ((STRING_TABLE.__str561606)|0), 315);
      var $209=$ret;
      var $210=((($209)+($208))|0);
      $ret=$210;
      __label__ = 33; break;
    case 31: 
      var $212=$dict;
      var $213=_HPDF_Dict_AddName($212, ((STRING_TABLE.__str541604)|0), ((STRING_TABLE.__str681618)|0));
      var $214=$ret;
      var $215=((($214)+($213))|0);
      $ret=$215;
      __label__ = 33; break;
    case 32: 
      $ret=4217;
      __label__ = 33; break;
    case 33: 
      var $218=$ret;
      var $219=(($218)|0)!=0;
      if ($219) { __label__ = 34; break; } else { __label__ = 35; break; }
    case 34: 
      __label__ = 40; break;
    case 35: 
      var $222=$2;
      var $223=$4;
      var $224=_HPDF_Dict_AddReal($222, ((STRING_TABLE.__str691619)|0), $223);
      $ret=$224;
      var $225=(($224)|0)!=0;
      if ($225) { __label__ = 36; break; } else { __label__ = 37; break; }
    case 36: 
      __label__ = 40; break;
    case 37: 
      var $228=$2;
      var $229=$dict;
      var $230=$229;
      var $231=_HPDF_Dict_Add($228, ((STRING_TABLE.__str521602)|0), $230);
      $ret=$231;
      var $232=(($231)|0)!=0;
      if ($232) { __label__ = 38; break; } else { __label__ = 39; break; }
    case 38: 
      var $234=$ret;
      $1=$234;
      __label__ = 41; break;
    case 39: 
      $1=0;
      __label__ = 41; break;
    case 40: 
      var $237=$dict;
      _HPDF_Dict_Free($237);
      var $238=$2;
      var $239=(($238+12)|0);
      var $240=HEAP32[(($239)>>2)];
      var $241=_HPDF_Error_GetCode($240);
      $1=$241;
      __label__ = 41; break;
    case 41: 
      var $243=$1;
      ;
      return $243;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Page_SetSlideShow["X"]=1;

function _HPDF_Pages_New($mmgr, $parent, $xref) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $ret;
      var $pages;
      $2=$mmgr;
      $3=$parent;
      $4=$xref;
      $ret=0;
      var $5=$2;
      var $6=_HPDF_Dict_New($5);
      $pages=$6;
      var $7=$pages;
      var $8=(($7)|0)!=0;
      if ($8) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=0;
      __label__ = 12; break;
    case 4: 
      var $11=$pages;
      var $12=(($11)|0);
      var $13=(($12+6)|0);
      var $14=HEAPU16[(($13)>>1)];
      var $15=(($14)&65535);
      var $16=$15 | 768;
      var $17=(($16) & 65535);
      HEAP16[(($13)>>1)]=$17;
      var $18=$pages;
      var $19=(($18+20)|0);
      HEAP32[(($19)>>2)]=226;
      var $20=$4;
      var $21=$pages;
      var $22=$21;
      var $23=_HPDF_Xref_Add($20, $22);
      var $24=(($23)|0)!=0;
      if ($24) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      $1=0;
      __label__ = 12; break;
    case 6: 
      var $27=$pages;
      var $28=_HPDF_Dict_AddName($27, ((STRING_TABLE.__str1623)|0), ((STRING_TABLE.__str11624)|0));
      var $29=$ret;
      var $30=((($29)+($28))|0);
      $ret=$30;
      var $31=$pages;
      var $32=$pages;
      var $33=(($32+8)|0);
      var $34=HEAP32[(($33)>>2)];
      var $35=_HPDF_Array_New($34);
      var $36=$35;
      var $37=_HPDF_Dict_Add($31, ((STRING_TABLE.__str21625)|0), $36);
      var $38=$ret;
      var $39=((($38)+($37))|0);
      $ret=$39;
      var $40=$pages;
      var $41=$pages;
      var $42=(($41+8)|0);
      var $43=HEAP32[(($42)>>2)];
      var $44=_HPDF_Number_New($43, 0);
      var $45=$44;
      var $46=_HPDF_Dict_Add($40, ((STRING_TABLE.__str31626)|0), $45);
      var $47=$ret;
      var $48=((($47)+($46))|0);
      $ret=$48;
      var $49=$ret;
      var $50=(($49)|0)==0;
      if ($50) { __label__ = 7; break; } else { __label__ = 9; break; }
    case 7: 
      var $52=$3;
      var $53=(($52)|0)!=0;
      if ($53) { __label__ = 8; break; } else { __label__ = 9; break; }
    case 8: 
      var $55=$3;
      var $56=$pages;
      var $57=_HPDF_Pages_AddKids($55, $56);
      var $58=$ret;
      var $59=((($58)+($57))|0);
      $ret=$59;
      __label__ = 9; break;
    case 9: 
      var $61=$ret;
      var $62=(($61)|0)!=0;
      if ($62) { __label__ = 10; break; } else { __label__ = 11; break; }
    case 10: 
      $1=0;
      __label__ = 12; break;
    case 11: 
      var $65=$pages;
      $1=$65;
      __label__ = 12; break;
    case 12: 
      var $67=$1;
      ;
      return $67;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Pages_New["X"]=1;

function _Pages_BeforeWrite($obj) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $kids;
      var $count;
      var $ret;
      $2=$obj;
      var $3=$2;
      var $4=_HPDF_Dict_GetItem($3, ((STRING_TABLE.__str21625)|0), 16);
      var $5=$4;
      $kids=$5;
      var $6=$2;
      var $7=_HPDF_Dict_GetItem($6, ((STRING_TABLE.__str31626)|0), 4);
      var $8=$7;
      $count=$8;
      var $9=$kids;
      var $10=(($9)|0)!=0;
      if ($10) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      var $12=$2;
      var $13=(($12+12)|0);
      var $14=HEAP32[(($13)>>2)];
      var $15=_HPDF_SetError($14, 4169, 0);
      $1=$15;
      __label__ = 12; break;
    case 4: 
      var $17=$count;
      var $18=(($17)|0)!=0;
      if ($18) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $20=$2;
      var $21=_GetPageCount($20);
      var $22=$count;
      var $23=(($22+8)|0);
      HEAP32[(($23)>>2)]=$21;
      __label__ = 11; break;
    case 6: 
      var $25=$2;
      var $26=(($25+8)|0);
      var $27=HEAP32[(($26)>>2)];
      var $28=$2;
      var $29=_GetPageCount($28);
      var $30=_HPDF_Number_New($27, $29);
      $count=$30;
      var $31=$count;
      var $32=(($31)|0)!=0;
      if ($32) { __label__ = 8; break; } else { __label__ = 7; break; }
    case 7: 
      var $34=$2;
      var $35=(($34+12)|0);
      var $36=HEAP32[(($35)>>2)];
      var $37=_HPDF_Error_GetCode($36);
      $1=$37;
      __label__ = 12; break;
    case 8: 
      var $39=$2;
      var $40=$count;
      var $41=$40;
      var $42=_HPDF_Dict_Add($39, ((STRING_TABLE.__str31626)|0), $41);
      $ret=$42;
      var $43=(($42)|0)!=0;
      if ($43) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      var $45=$ret;
      $1=$45;
      __label__ = 12; break;
    case 10: 
      __label__ = 11; break;
    case 11: 
      $1=0;
      __label__ = 12; break;
    case 12: 
      var $49=$1;
      ;
      return $49;
    default: assert(0, "bad label: " + __label__);
  }
}
_Pages_BeforeWrite["X"]=1;

function _HPDF_Pages_AddKids($parent, $kid) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $kids;
      var $ret;
      var $attr;
      $2=$parent;
      $3=$kid;
      var $4=$3;
      var $5=_HPDF_Dict_GetItem($4, ((STRING_TABLE.__str41627)|0), 17);
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $8=$2;
      var $9=(($8+12)|0);
      var $10=HEAP32[(($9)>>2)];
      var $11=_HPDF_SetError($10, 4173, 0);
      $1=$11;
      __label__ = 11; break;
    case 4: 
      var $13=$3;
      var $14=$2;
      var $15=$14;
      var $16=_HPDF_Dict_Add($13, ((STRING_TABLE.__str41627)|0), $15);
      $ret=$16;
      var $17=(($16)|0)!=0;
      if ($17) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $19=$ret;
      $1=$19;
      __label__ = 11; break;
    case 6: 
      var $21=$2;
      var $22=_HPDF_Dict_GetItem($21, ((STRING_TABLE.__str21625)|0), 16);
      var $23=$22;
      $kids=$23;
      var $24=$kids;
      var $25=(($24)|0)!=0;
      if ($25) { __label__ = 8; break; } else { __label__ = 7; break; }
    case 7: 
      var $27=$2;
      var $28=(($27+12)|0);
      var $29=HEAP32[(($28)>>2)];
      var $30=_HPDF_SetError($29, 4169, 0);
      $1=$30;
      __label__ = 11; break;
    case 8: 
      var $32=$3;
      var $33=(($32)|0);
      var $34=(($33+6)|0);
      var $35=HEAPU16[(($34)>>1)];
      var $36=(($35)&65535);
      var $37=(($36)|0)==1041;
      if ($37) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      var $39=$3;
      var $40=(($39+44)|0);
      var $41=HEAP32[(($40)>>2)];
      var $42=$41;
      $attr=$42;
      var $43=$2;
      var $44=$attr;
      var $45=(($44)|0);
      HEAP32[(($45)>>2)]=$43;
      __label__ = 10; break;
    case 10: 
      var $47=$kids;
      var $48=$3;
      var $49=$48;
      var $50=_HPDF_Array_Add($47, $49);
      $1=$50;
      __label__ = 11; break;
    case 11: 
      var $52=$1;
      ;
      return $52;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Pages_AddKids["X"]=1;

function _HPDF_Pages_Validate($pages) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $header;
      $2=$pages;
      var $3=$2;
      var $4=$3;
      $header=$4;
      var $5=$2;
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $8=$header;
      var $9=(($8+6)|0);
      var $10=HEAPU16[(($9)>>1)];
      var $11=(($10)&65535);
      var $12=(($11)|0)!=785;
      if ($12) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      $1=0;
      __label__ = 6; break;
    case 5: 
      $1=1;
      __label__ = 6; break;
    case 6: 
      var $16=$1;
      ;
      return $16;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Page_InsertBefore($page, $target) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $parent;
      var $kids;
      var $ret;
      var $attr;
      $2=$page;
      $3=$target;
      var $4=$3;
      var $5=(($4+44)|0);
      var $6=HEAP32[(($5)>>2)];
      var $7=$6;
      $attr=$7;
      var $8=$attr;
      var $9=(($8)|0);
      var $10=HEAP32[(($9)>>2)];
      $parent=$10;
      var $11=$parent;
      var $12=(($11)|0)!=0;
      if ($12) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      var $14=$parent;
      var $15=(($14+12)|0);
      var $16=HEAP32[(($15)>>2)];
      var $17=_HPDF_SetError($16, 4173, 0);
      $1=$17;
      __label__ = 11; break;
    case 4: 
      var $19=$2;
      var $20=_HPDF_Dict_GetItem($19, ((STRING_TABLE.__str41627)|0), 17);
      var $21=(($20)|0)!=0;
      if ($21) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $23=$parent;
      var $24=(($23+12)|0);
      var $25=HEAP32[(($24)>>2)];
      var $26=_HPDF_SetError($25, 4173, 0);
      $1=$26;
      __label__ = 11; break;
    case 6: 
      var $28=$2;
      var $29=$parent;
      var $30=$29;
      var $31=_HPDF_Dict_Add($28, ((STRING_TABLE.__str41627)|0), $30);
      $ret=$31;
      var $32=(($31)|0)!=0;
      if ($32) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $34=$ret;
      $1=$34;
      __label__ = 11; break;
    case 8: 
      var $36=$parent;
      var $37=_HPDF_Dict_GetItem($36, ((STRING_TABLE.__str21625)|0), 16);
      var $38=$37;
      $kids=$38;
      var $39=$kids;
      var $40=(($39)|0)!=0;
      if ($40) { __label__ = 10; break; } else { __label__ = 9; break; }
    case 9: 
      var $42=$parent;
      var $43=(($42+12)|0);
      var $44=HEAP32[(($43)>>2)];
      var $45=_HPDF_SetError($44, 4169, 0);
      $1=$45;
      __label__ = 11; break;
    case 10: 
      var $47=$2;
      var $48=(($47+44)|0);
      var $49=HEAP32[(($48)>>2)];
      var $50=$49;
      $attr=$50;
      var $51=$parent;
      var $52=$attr;
      var $53=(($52)|0);
      HEAP32[(($53)>>2)]=$51;
      var $54=$kids;
      var $55=$3;
      var $56=$55;
      var $57=$2;
      var $58=$57;
      var $59=_HPDF_Array_Insert($54, $56, $58);
      $1=$59;
      __label__ = 11; break;
    case 11: 
      var $61=$1;
      ;
      return $61;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Page_InsertBefore["X"]=1;

function _HPDF_Page_New($mmgr, $xref) {
  var __stackBase__  = STACKTOP; STACKTOP += 32; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $ret;
      var $attr;
      var $page;
      var $4=__stackBase__;
      var $5=(__stackBase__)+(8);
      var $6=(__stackBase__)+(16);
      $2=$mmgr;
      $3=$xref;
      var $7=$2;
      var $8=_HPDF_Dict_New($7);
      $page=$8;
      var $9=$page;
      var $10=(($9)|0)!=0;
      if ($10) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=0;
      __label__ = 14; break;
    case 4: 
      var $13=$page;
      var $14=(($13)|0);
      var $15=(($14+6)|0);
      var $16=HEAPU16[(($15)>>1)];
      var $17=(($16)&65535);
      var $18=$17 | 1024;
      var $19=(($18) & 65535);
      HEAP16[(($15)>>1)]=$19;
      var $20=$page;
      var $21=(($20+32)|0);
      HEAP32[(($21)>>2)]=228;
      var $22=$page;
      var $23=(($22+20)|0);
      HEAP32[(($23)>>2)]=230;
      var $24=$page;
      var $25=(($24+8)|0);
      var $26=HEAP32[(($25)>>2)];
      var $27=_HPDF_GetMem($26, 92);
      var $28=$27;
      $attr=$28;
      var $29=$attr;
      var $30=(($29)|0)!=0;
      if ($30) { __label__ = 6; break; } else { __label__ = 5; break; }
    case 5: 
      var $32=$page;
      _HPDF_Dict_Free($32);
      $1=0;
      __label__ = 14; break;
    case 6: 
      var $34=$attr;
      var $35=$34;
      var $36=$page;
      var $37=(($36+44)|0);
      HEAP32[(($37)>>2)]=$35;
      var $38=$attr;
      var $39=$38;
      var $40=_HPDF_MemSet($39, 0, 92);
      var $41=$attr;
      var $42=(($41+68)|0);
      HEAP16[(($42)>>1)]=1;
      var $43=$attr;
      var $44=(($43+28)|0);
      _HPDF_ToPoint($4, 0, 0);
      var $45=$44;
      var $46=$4;
      assert(8 % 1 === 0, 'memcpy given ' + 8 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP32[(($45)>>2)]=HEAP32[(($46)>>2)];HEAP32[((($45)+(4))>>2)]=HEAP32[((($46)+(4))>>2)];
      var $47=$attr;
      var $48=(($47+36)|0);
      _HPDF_ToPoint($5, 0, 0);
      var $49=$48;
      var $50=$5;
      assert(8 % 1 === 0, 'memcpy given ' + 8 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP32[(($49)>>2)]=HEAP32[(($50)>>2)];HEAP32[((($49)+(4))>>2)]=HEAP32[((($50)+(4))>>2)];
      var $51=$3;
      var $52=$page;
      var $53=$52;
      var $54=_HPDF_Xref_Add($51, $53);
      $ret=$54;
      var $55=$ret;
      var $56=(($55)|0)!=0;
      if ($56) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      $1=0;
      __label__ = 14; break;
    case 8: 
      var $59=$page;
      var $60=(($59+8)|0);
      var $61=HEAP32[(($60)>>2)];
      var $62=_HPDF_GState_New($61, 0);
      var $63=$attr;
      var $64=(($63+16)|0);
      HEAP32[(($64)>>2)]=$62;
      var $65=$page;
      var $66=(($65+8)|0);
      var $67=HEAP32[(($66)>>2)];
      var $68=$3;
      var $69=_HPDF_DictStream_New($67, $68);
      var $70=$attr;
      var $71=(($70+72)|0);
      HEAP32[(($71)>>2)]=$69;
      var $72=$attr;
      var $73=(($72+16)|0);
      var $74=HEAP32[(($73)>>2)];
      var $75=(($74)|0)!=0;
      if ($75) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      var $77=$attr;
      var $78=(($77+72)|0);
      var $79=HEAP32[(($78)>>2)];
      var $80=(($79)|0)!=0;
      if ($80) { __label__ = 11; break; } else { __label__ = 10; break; }
    case 10: 
      $1=0;
      __label__ = 14; break;
    case 11: 
      var $83=$attr;
      var $84=(($83+72)|0);
      var $85=HEAP32[(($84)>>2)];
      var $86=(($85+36)|0);
      var $87=HEAP32[(($86)>>2)];
      var $88=$attr;
      var $89=(($88+76)|0);
      HEAP32[(($89)>>2)]=$87;
      var $90=$3;
      var $91=$attr;
      var $92=(($91+80)|0);
      HEAP32[(($92)>>2)]=$90;
      var $93=$page;
      var $94=_HPDF_Dict_AddName($93, ((STRING_TABLE.__str1623)|0), ((STRING_TABLE.__str51628)|0));
      var $95=$ret;
      var $96=((($95)+($94))|0);
      $ret=$96;
      var $97=$page;
      var $98=$page;
      var $99=(($98+8)|0);
      var $100=HEAP32[(($99)>>2)];
      _HPDF_ToBox($6, 0, 0, 595, 841);
      var $101=(($6)|0);
      var $102=HEAPF32[(($101)>>2)];
      var $103=(($6+4)|0);
      var $104=HEAPF32[(($103)>>2)];
      var $105=(($6+8)|0);
      var $106=HEAPF32[(($105)>>2)];
      var $107=(($6+12)|0);
      var $108=HEAPF32[(($107)>>2)];
      var $109=_HPDF_Box_Array_New($100, $102, $104, $106, $108);
      var $110=$109;
      var $111=_HPDF_Dict_Add($97, ((STRING_TABLE.__str61629)|0), $110);
      var $112=$ret;
      var $113=((($112)+($111))|0);
      $ret=$113;
      var $114=$page;
      var $115=$attr;
      var $116=(($115+72)|0);
      var $117=HEAP32[(($116)>>2)];
      var $118=$117;
      var $119=_HPDF_Dict_Add($114, ((STRING_TABLE.__str71630)|0), $118);
      var $120=$ret;
      var $121=((($120)+($119))|0);
      $ret=$121;
      var $122=$page;
      var $123=_AddResource($122);
      var $124=$ret;
      var $125=((($124)+($123))|0);
      $ret=$125;
      var $126=$ret;
      var $127=(($126)|0)!=0;
      if ($127) { __label__ = 12; break; } else { __label__ = 13; break; }
    case 12: 
      $1=0;
      __label__ = 14; break;
    case 13: 
      var $130=$page;
      $1=$130;
      __label__ = 14; break;
    case 14: 
      var $132=$1;
      STACKTOP = __stackBase__;
      return $132;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Page_New["X"]=1;

function _Page_OnFree($obj) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $attr;
      $1=$obj;
      var $2=$1;
      var $3=(($2+44)|0);
      var $4=HEAP32[(($3)>>2)];
      var $5=$4;
      $attr=$5;
      var $6=$attr;
      var $7=(($6)|0)!=0;
      if ($7) { __label__ = 3; break; } else { __label__ = 6; break; }
    case 3: 
      var $9=$attr;
      var $10=(($9+16)|0);
      var $11=HEAP32[(($10)>>2)];
      var $12=(($11)|0)!=0;
      if ($12) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      var $14=$1;
      var $15=(($14+8)|0);
      var $16=HEAP32[(($15)>>2)];
      var $17=$attr;
      var $18=(($17+16)|0);
      var $19=HEAP32[(($18)>>2)];
      var $20=_HPDF_GState_Free($16, $19);
      __label__ = 5; break;
    case 5: 
      var $22=$1;
      var $23=(($22+8)|0);
      var $24=HEAP32[(($23)>>2)];
      var $25=$attr;
      var $26=$25;
      _HPDF_FreeMem($24, $26);
      __label__ = 6; break;
    case 6: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}


function _Page_BeforeWrite($obj) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $ret;
      var $page;
      var $attr;
      $2=$obj;
      var $3=$2;
      $page=$3;
      var $4=$2;
      var $5=(($4+44)|0);
      var $6=HEAP32[(($5)>>2)];
      var $7=$6;
      $attr=$7;
      var $8=$attr;
      var $9=(($8+68)|0);
      var $10=HEAPU16[(($9)>>1)];
      var $11=(($10)&65535);
      var $12=(($11)|0)==2;
      if ($12) { __label__ = 3; break; } else { __label__ = 6; break; }
    case 3: 
      var $14=$page;
      var $15=_HPDF_Page_EndPath($14);
      $ret=$15;
      var $16=(($15)|0)!=0;
      if ($16) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      var $18=$ret;
      $1=$18;
      __label__ = 18; break;
    case 5: 
      __label__ = 6; break;
    case 6: 
      var $21=$attr;
      var $22=(($21+68)|0);
      var $23=HEAPU16[(($22)>>1)];
      var $24=(($23)&65535);
      var $25=(($24)|0)==4;
      if ($25) { __label__ = 7; break; } else { __label__ = 10; break; }
    case 7: 
      var $27=$page;
      var $28=_HPDF_Page_EndText($27);
      $ret=$28;
      var $29=(($28)|0)!=0;
      if ($29) { __label__ = 8; break; } else { __label__ = 9; break; }
    case 8: 
      var $31=$ret;
      $1=$31;
      __label__ = 18; break;
    case 9: 
      __label__ = 10; break;
    case 10: 
      var $34=$attr;
      var $35=(($34+16)|0);
      var $36=HEAP32[(($35)>>2)];
      var $37=(($36)|0)!=0;
      if ($37) { __label__ = 11; break; } else { __label__ = 17; break; }
    case 11: 
      __label__ = 12; break;
    case 12: 
      var $40=$attr;
      var $41=(($40+16)|0);
      var $42=HEAP32[(($41)>>2)];
      var $43=(($42+176)|0);
      var $44=HEAP32[(($43)>>2)];
      var $45=(($44)|0)!=0;
      if ($45) { __label__ = 13; break; } else { __label__ = 16; break; }
    case 13: 
      var $47=$page;
      var $48=_HPDF_Page_GRestore($47);
      $ret=$48;
      var $49=(($48)|0)!=0;
      if ($49) { __label__ = 14; break; } else { __label__ = 15; break; }
    case 14: 
      var $51=$ret;
      $1=$51;
      __label__ = 18; break;
    case 15: 
      __label__ = 12; break;
    case 16: 
      __label__ = 17; break;
    case 17: 
      $1=0;
      __label__ = 18; break;
    case 18: 
      var $56=$1;
      ;
      return $56;
    default: assert(0, "bad label: " + __label__);
  }
}
_Page_BeforeWrite["X"]=1;

function _AddResource($page) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $ret;
      var $resource;
      var $procset;
      $2=$page;
      $ret=0;
      var $3=$2;
      var $4=(($3+8)|0);
      var $5=HEAP32[(($4)>>2)];
      var $6=_HPDF_Dict_New($5);
      $resource=$6;
      var $7=$resource;
      var $8=(($7)|0)!=0;
      if ($8) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      var $10=$2;
      var $11=(($10+12)|0);
      var $12=HEAP32[(($11)>>2)];
      var $13=_HPDF_Error_GetCode($12);
      $1=$13;
      __label__ = 7; break;
    case 4: 
      var $15=$2;
      var $16=$resource;
      var $17=$16;
      var $18=_HPDF_Dict_Add($15, ((STRING_TABLE.__str81631)|0), $17);
      var $19=$ret;
      var $20=((($19)+($18))|0);
      $ret=$20;
      var $21=$2;
      var $22=(($21+8)|0);
      var $23=HEAP32[(($22)>>2)];
      var $24=_HPDF_Array_New($23);
      $procset=$24;
      var $25=$procset;
      var $26=(($25)|0)!=0;
      if ($26) { __label__ = 6; break; } else { __label__ = 5; break; }
    case 5: 
      var $28=$2;
      var $29=(($28+12)|0);
      var $30=HEAP32[(($29)>>2)];
      var $31=_HPDF_Error_GetCode($30);
      $1=$31;
      __label__ = 7; break;
    case 6: 
      var $33=$resource;
      var $34=$procset;
      var $35=$34;
      var $36=_HPDF_Dict_Add($33, ((STRING_TABLE.__str181641)|0), $35);
      var $37=$ret;
      var $38=((($37)+($36))|0);
      $ret=$38;
      var $39=$procset;
      var $40=$2;
      var $41=(($40+8)|0);
      var $42=HEAP32[(($41)>>2)];
      var $43=_HPDF_Name_New($42, ((STRING_TABLE.__str191642)|0));
      var $44=$43;
      var $45=_HPDF_Array_Add($39, $44);
      var $46=$ret;
      var $47=((($46)+($45))|0);
      $ret=$47;
      var $48=$procset;
      var $49=$2;
      var $50=(($49+8)|0);
      var $51=HEAP32[(($50)>>2)];
      var $52=_HPDF_Name_New($51, ((STRING_TABLE.__str201643)|0));
      var $53=$52;
      var $54=_HPDF_Array_Add($48, $53);
      var $55=$ret;
      var $56=((($55)+($54))|0);
      $ret=$56;
      var $57=$procset;
      var $58=$2;
      var $59=(($58+8)|0);
      var $60=HEAP32[(($59)>>2)];
      var $61=_HPDF_Name_New($60, ((STRING_TABLE.__str211644)|0));
      var $62=$61;
      var $63=_HPDF_Array_Add($57, $62);
      var $64=$ret;
      var $65=((($64)+($63))|0);
      $ret=$65;
      var $66=$procset;
      var $67=$2;
      var $68=(($67+8)|0);
      var $69=HEAP32[(($68)>>2)];
      var $70=_HPDF_Name_New($69, ((STRING_TABLE.__str221645)|0));
      var $71=$70;
      var $72=_HPDF_Array_Add($66, $71);
      var $73=$ret;
      var $74=((($73)+($72))|0);
      $ret=$74;
      var $75=$procset;
      var $76=$2;
      var $77=(($76+8)|0);
      var $78=HEAP32[(($77)>>2)];
      var $79=_HPDF_Name_New($78, ((STRING_TABLE.__str231646)|0));
      var $80=$79;
      var $81=_HPDF_Array_Add($75, $80);
      var $82=$ret;
      var $83=((($82)+($81))|0);
      $ret=$83;
      var $84=$ret;
      $1=$84;
      __label__ = 7; break;
    case 7: 
      var $86=$1;
      ;
      return $86;
    default: assert(0, "bad label: " + __label__);
  }
}
_AddResource["X"]=1;

function _HPDF_Page_CheckState($page, $mode) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      $2=$page;
      $3=$mode;
      var $4=$2;
      var $5=(($4)|0)!=0;
      if ($5) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=4147;
      __label__ = 9; break;
    case 4: 
      var $8=$2;
      var $9=(($8)|0);
      var $10=(($9+6)|0);
      var $11=HEAPU16[(($10)>>1)];
      var $12=(($11)&65535);
      var $13=(($12)|0)!=1041;
      if ($13) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      $1=4151;
      __label__ = 9; break;
    case 6: 
      var $16=$2;
      var $17=(($16+44)|0);
      var $18=HEAP32[(($17)>>2)];
      var $19=$18;
      var $20=(($19+68)|0);
      var $21=HEAPU16[(($20)>>1)];
      var $22=(($21)&65535);
      var $23=$3;
      var $24=$22 & $23;
      var $25=(($24)|0)!=0;
      if ($25) { __label__ = 8; break; } else { __label__ = 7; break; }
    case 7: 
      var $27=$2;
      var $28=(($27+12)|0);
      var $29=HEAP32[(($28)>>2)];
      var $30=_HPDF_RaiseError($29, 4177, 0);
      $1=$30;
      __label__ = 9; break;
    case 8: 
      $1=0;
      __label__ = 9; break;
    case 9: 
      var $33=$1;
      ;
      return $33;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Page_GetInheritableItem($page, $key, $obj_class) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $chk;
      var $i;
      var $obj;
      var $pages;
      $2=$page;
      $3=$key;
      $4=$obj_class;
      $chk=0;
      $i=0;
      __label__ = 3; break;
    case 3: 
      var $6=$i;
      var $7=((_HPDF_INHERITABLE_ENTRIES+($6<<2))|0);
      var $8=HEAP32[(($7)>>2)];
      var $9=(($8)|0)!=0;
      if ($9) { __label__ = 4; break; } else { __label__ = 7; break; }
    case 4: 
      var $11=$3;
      var $12=$i;
      var $13=((_HPDF_INHERITABLE_ENTRIES+($12<<2))|0);
      var $14=HEAP32[(($13)>>2)];
      var $15=_HPDF_StrCmp($11, $14);
      var $16=(($15)|0)==0;
      if ($16) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      $chk=1;
      __label__ = 7; break;
    case 6: 
      var $19=$i;
      var $20=((($19)+(1))|0);
      $i=$20;
      __label__ = 3; break;
    case 7: 
      var $22=$chk;
      var $23=(($22)|0)!=1;
      if ($23) { __label__ = 8; break; } else { __label__ = 9; break; }
    case 8: 
      var $25=$2;
      var $26=(($25+12)|0);
      var $27=HEAP32[(($26)>>2)];
      var $28=_HPDF_SetError($27, 4153, 0);
      $1=0;
      __label__ = 17; break;
    case 9: 
      var $30=$2;
      var $31=$3;
      var $32=$4;
      var $33=_HPDF_Dict_GetItem($30, $31, $32);
      $obj=$33;
      var $34=$obj;
      var $35=(($34)|0)!=0;
      if ($35) { __label__ = 16; break; } else { __label__ = 10; break; }
    case 10: 
      var $37=$2;
      var $38=_HPDF_Dict_GetItem($37, ((STRING_TABLE.__str41627)|0), 17);
      var $39=$38;
      $pages=$39;
      __label__ = 11; break;
    case 11: 
      var $41=$pages;
      var $42=(($41)|0)!=0;
      if ($42) { __label__ = 12; break; } else { __label__ = 15; break; }
    case 12: 
      var $44=$2;
      var $45=$3;
      var $46=$4;
      var $47=_HPDF_Dict_GetItem($44, $45, $46);
      $obj=$47;
      var $48=$obj;
      var $49=(($48)|0)!=0;
      if ($49) { __label__ = 13; break; } else { __label__ = 14; break; }
    case 13: 
      __label__ = 15; break;
    case 14: 
      var $52=$pages;
      var $53=_HPDF_Dict_GetItem($52, ((STRING_TABLE.__str41627)|0), 17);
      var $54=$53;
      $pages=$54;
      __label__ = 11; break;
    case 15: 
      __label__ = 16; break;
    case 16: 
      var $57=$obj;
      $1=$57;
      __label__ = 17; break;
    case 17: 
      var $59=$1;
      ;
      return $59;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Page_GetInheritableItem["X"]=1;

function _HPDF_Page_GetLocalFontName($page, $font) {
  var __stackBase__  = STACKTOP; STACKTOP += 128; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $attr;
      var $key;
      var $resources;
      var $fonts;
      var $fontName=__stackBase__;
      var $ptr;
      var $end_ptr;
      $2=$page;
      $3=$font;
      var $4=$2;
      var $5=(($4+44)|0);
      var $6=HEAP32[(($5)>>2)];
      var $7=$6;
      $attr=$7;
      var $8=$attr;
      var $9=(($8+4)|0);
      var $10=HEAP32[(($9)>>2)];
      var $11=(($10)|0)!=0;
      if ($11) { __label__ = 10; break; } else { __label__ = 3; break; }
    case 3: 
      var $13=$2;
      var $14=_HPDF_Page_GetInheritableItem($13, ((STRING_TABLE.__str81631)|0), 17);
      var $15=$14;
      $resources=$15;
      var $16=$resources;
      var $17=(($16)|0)!=0;
      if ($17) { __label__ = 5; break; } else { __label__ = 4; break; }
    case 4: 
      $1=0;
      __label__ = 15; break;
    case 5: 
      var $20=$2;
      var $21=(($20+8)|0);
      var $22=HEAP32[(($21)>>2)];
      var $23=_HPDF_Dict_New($22);
      $fonts=$23;
      var $24=$fonts;
      var $25=(($24)|0)!=0;
      if ($25) { __label__ = 7; break; } else { __label__ = 6; break; }
    case 6: 
      $1=0;
      __label__ = 15; break;
    case 7: 
      var $28=$resources;
      var $29=$fonts;
      var $30=$29;
      var $31=_HPDF_Dict_Add($28, ((STRING_TABLE.__str91632)|0), $30);
      var $32=(($31)|0)!=0;
      if ($32) { __label__ = 8; break; } else { __label__ = 9; break; }
    case 8: 
      $1=0;
      __label__ = 15; break;
    case 9: 
      var $35=$fonts;
      var $36=$attr;
      var $37=(($36+4)|0);
      HEAP32[(($37)>>2)]=$35;
      __label__ = 10; break;
    case 10: 
      var $39=$attr;
      var $40=(($39+4)|0);
      var $41=HEAP32[(($40)>>2)];
      var $42=$3;
      var $43=$42;
      var $44=_HPDF_Dict_GetKeyByObj($41, $43);
      $key=$44;
      var $45=$key;
      var $46=(($45)|0)!=0;
      if ($46) { __label__ = 14; break; } else { __label__ = 11; break; }
    case 11: 
      var $48=(($fontName)|0);
      var $49=(($48+127)|0);
      $end_ptr=$49;
      var $50=(($fontName)|0);
      var $51=$end_ptr;
      var $52=_HPDF_StrCpy($50, ((STRING_TABLE.__str101633)|0), $51);
      $ptr=$52;
      var $53=$ptr;
      var $54=$attr;
      var $55=(($54+4)|0);
      var $56=HEAP32[(($55)>>2)];
      var $57=(($56+16)|0);
      var $58=HEAP32[(($57)>>2)];
      var $59=(($58+16)|0);
      var $60=HEAP32[(($59)>>2)];
      var $61=((($60)+(1))|0);
      var $62=$end_ptr;
      var $63=_HPDF_IToA($53, $61, $62);
      var $64=$attr;
      var $65=(($64+4)|0);
      var $66=HEAP32[(($65)>>2)];
      var $67=(($fontName)|0);
      var $68=$3;
      var $69=$68;
      var $70=_HPDF_Dict_Add($66, $67, $69);
      var $71=(($70)|0)!=0;
      if ($71) { __label__ = 12; break; } else { __label__ = 13; break; }
    case 12: 
      $1=0;
      __label__ = 15; break;
    case 13: 
      var $74=$attr;
      var $75=(($74+4)|0);
      var $76=HEAP32[(($75)>>2)];
      var $77=$3;
      var $78=$77;
      var $79=_HPDF_Dict_GetKeyByObj($76, $78);
      $key=$79;
      __label__ = 14; break;
    case 14: 
      var $81=$key;
      $1=$81;
      __label__ = 15; break;
    case 15: 
      var $83=$1;
      STACKTOP = __stackBase__;
      return $83;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Page_GetLocalFontName["X"]=1;

function _HPDF_Page_GetMediaBox($agg_result, $page) {
  var __stackBase__  = STACKTOP; STACKTOP += 16; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $media_box=__stackBase__;
      var $array;
      var $r;
      $1=$page;
      var $2=$media_box;
      HEAP32[(($2)>>2)]=0; HEAP32[((($2)+(4))>>2)]=0; HEAP32[((($2)+(8))>>2)]=0; HEAP32[((($2)+(12))>>2)]=0;
      var $3=$1;
      var $4=_HPDF_Page_Validate($3);
      var $5=(($4)|0)!=0;
      if ($5) { __label__ = 3; break; } else { __label__ = 15; break; }
    case 3: 
      var $7=$1;
      var $8=_HPDF_Page_GetInheritableItem($7, ((STRING_TABLE.__str61629)|0), 16);
      var $9=$8;
      $array=$9;
      var $10=$array;
      var $11=(($10)|0)!=0;
      if ($11) { __label__ = 4; break; } else { __label__ = 13; break; }
    case 4: 
      var $13=$array;
      var $14=_HPDF_Array_GetItem($13, 0, 5);
      var $15=$14;
      $r=$15;
      var $16=$r;
      var $17=(($16)|0)!=0;
      if ($17) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $19=$r;
      var $20=(($19+12)|0);
      var $21=HEAPF32[(($20)>>2)];
      var $22=(($media_box)|0);
      HEAPF32[(($22)>>2)]=$21;
      __label__ = 6; break;
    case 6: 
      var $24=$array;
      var $25=_HPDF_Array_GetItem($24, 1, 5);
      var $26=$25;
      $r=$26;
      var $27=$r;
      var $28=(($27)|0)!=0;
      if ($28) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $30=$r;
      var $31=(($30+12)|0);
      var $32=HEAPF32[(($31)>>2)];
      var $33=(($media_box+4)|0);
      HEAPF32[(($33)>>2)]=$32;
      __label__ = 8; break;
    case 8: 
      var $35=$array;
      var $36=_HPDF_Array_GetItem($35, 2, 5);
      var $37=$36;
      $r=$37;
      var $38=$r;
      var $39=(($38)|0)!=0;
      if ($39) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      var $41=$r;
      var $42=(($41+12)|0);
      var $43=HEAPF32[(($42)>>2)];
      var $44=(($media_box+8)|0);
      HEAPF32[(($44)>>2)]=$43;
      __label__ = 10; break;
    case 10: 
      var $46=$array;
      var $47=_HPDF_Array_GetItem($46, 3, 5);
      var $48=$47;
      $r=$48;
      var $49=$r;
      var $50=(($49)|0)!=0;
      if ($50) { __label__ = 11; break; } else { __label__ = 12; break; }
    case 11: 
      var $52=$r;
      var $53=(($52+12)|0);
      var $54=HEAPF32[(($53)>>2)];
      var $55=(($media_box+12)|0);
      HEAPF32[(($55)>>2)]=$54;
      __label__ = 12; break;
    case 12: 
      var $57=$1;
      var $58=(($57+12)|0);
      var $59=HEAP32[(($58)>>2)];
      var $60=_HPDF_CheckError($59);
      __label__ = 14; break;
    case 13: 
      var $62=$1;
      var $63=(($62+12)|0);
      var $64=HEAP32[(($63)>>2)];
      var $65=_HPDF_RaiseError($64, 4170, 0);
      __label__ = 14; break;
    case 14: 
      __label__ = 15; break;
    case 15: 
      var $68=$agg_result;
      var $69=$media_box;
      assert(16 % 1 === 0, 'memcpy given ' + 16 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP32[(($68)>>2)]=HEAP32[(($69)>>2)];HEAP32[((($68)+(4))>>2)]=HEAP32[((($69)+(4))>>2)];HEAP32[((($68)+(8))>>2)]=HEAP32[((($69)+(8))>>2)];HEAP32[((($68)+(12))>>2)]=HEAP32[((($69)+(12))>>2)];
      STACKTOP = __stackBase__;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Page_GetMediaBox["X"]=1;

function _HPDF_Page_Validate($page) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $header;
      $2=$page;
      var $3=$2;
      var $4=$3;
      $header=$4;
      var $5=$2;
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $8=$2;
      var $9=(($8+44)|0);
      var $10=HEAP32[(($9)>>2)];
      var $11=(($10)|0)!=0;
      if ($11) { __label__ = 5; break; } else { __label__ = 4; break; }
    case 4: 
      $1=0;
      __label__ = 8; break;
    case 5: 
      var $14=$header;
      var $15=(($14+6)|0);
      var $16=HEAPU16[(($15)>>1)];
      var $17=(($16)&65535);
      var $18=(($17)|0)!=1041;
      if ($18) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      $1=0;
      __label__ = 8; break;
    case 7: 
      $1=1;
      __label__ = 8; break;
    case 8: 
      var $22=$1;
      ;
      return $22;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Page_GetXObjectName($page, $xobj) {
  var __stackBase__  = STACKTOP; STACKTOP += 128; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $attr;
      var $key;
      var $resources;
      var $xobjects;
      var $xobj_name=__stackBase__;
      var $ptr;
      var $end_ptr;
      $2=$page;
      $3=$xobj;
      var $4=$2;
      var $5=(($4+44)|0);
      var $6=HEAP32[(($5)>>2)];
      var $7=$6;
      $attr=$7;
      var $8=$attr;
      var $9=(($8+8)|0);
      var $10=HEAP32[(($9)>>2)];
      var $11=(($10)|0)!=0;
      if ($11) { __label__ = 10; break; } else { __label__ = 3; break; }
    case 3: 
      var $13=$2;
      var $14=_HPDF_Page_GetInheritableItem($13, ((STRING_TABLE.__str81631)|0), 17);
      var $15=$14;
      $resources=$15;
      var $16=$resources;
      var $17=(($16)|0)!=0;
      if ($17) { __label__ = 5; break; } else { __label__ = 4; break; }
    case 4: 
      $1=0;
      __label__ = 15; break;
    case 5: 
      var $20=$2;
      var $21=(($20+8)|0);
      var $22=HEAP32[(($21)>>2)];
      var $23=_HPDF_Dict_New($22);
      $xobjects=$23;
      var $24=$xobjects;
      var $25=(($24)|0)!=0;
      if ($25) { __label__ = 7; break; } else { __label__ = 6; break; }
    case 6: 
      $1=0;
      __label__ = 15; break;
    case 7: 
      var $28=$resources;
      var $29=$xobjects;
      var $30=$29;
      var $31=_HPDF_Dict_Add($28, ((STRING_TABLE.__str111634)|0), $30);
      var $32=(($31)|0)!=0;
      if ($32) { __label__ = 8; break; } else { __label__ = 9; break; }
    case 8: 
      $1=0;
      __label__ = 15; break;
    case 9: 
      var $35=$xobjects;
      var $36=$attr;
      var $37=(($36+8)|0);
      HEAP32[(($37)>>2)]=$35;
      __label__ = 10; break;
    case 10: 
      var $39=$attr;
      var $40=(($39+8)|0);
      var $41=HEAP32[(($40)>>2)];
      var $42=$3;
      var $43=$42;
      var $44=_HPDF_Dict_GetKeyByObj($41, $43);
      $key=$44;
      var $45=$key;
      var $46=(($45)|0)!=0;
      if ($46) { __label__ = 14; break; } else { __label__ = 11; break; }
    case 11: 
      var $48=(($xobj_name)|0);
      var $49=(($48+127)|0);
      $end_ptr=$49;
      var $50=(($xobj_name)|0);
      var $51=$end_ptr;
      var $52=_HPDF_StrCpy($50, ((STRING_TABLE.__str121635)|0), $51);
      $ptr=$52;
      var $53=$ptr;
      var $54=$attr;
      var $55=(($54+8)|0);
      var $56=HEAP32[(($55)>>2)];
      var $57=(($56+16)|0);
      var $58=HEAP32[(($57)>>2)];
      var $59=(($58+16)|0);
      var $60=HEAP32[(($59)>>2)];
      var $61=((($60)+(1))|0);
      var $62=$end_ptr;
      var $63=_HPDF_IToA($53, $61, $62);
      var $64=$attr;
      var $65=(($64+8)|0);
      var $66=HEAP32[(($65)>>2)];
      var $67=(($xobj_name)|0);
      var $68=$3;
      var $69=$68;
      var $70=_HPDF_Dict_Add($66, $67, $69);
      var $71=(($70)|0)!=0;
      if ($71) { __label__ = 12; break; } else { __label__ = 13; break; }
    case 12: 
      $1=0;
      __label__ = 15; break;
    case 13: 
      var $74=$attr;
      var $75=(($74+8)|0);
      var $76=HEAP32[(($75)>>2)];
      var $77=$3;
      var $78=$77;
      var $79=_HPDF_Dict_GetKeyByObj($76, $78);
      $key=$79;
      __label__ = 14; break;
    case 14: 
      var $81=$key;
      $1=$81;
      __label__ = 15; break;
    case 15: 
      var $83=$1;
      STACKTOP = __stackBase__;
      return $83;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Page_GetXObjectName["X"]=1;

function _HPDF_Page_GetExtGStateName($page, $state) {
  var __stackBase__  = STACKTOP; STACKTOP += 128; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $attr;
      var $key;
      var $resources;
      var $ext_gstates;
      var $ext_gstate_name=__stackBase__;
      var $ptr;
      var $end_ptr;
      $2=$page;
      $3=$state;
      var $4=$2;
      var $5=(($4+44)|0);
      var $6=HEAP32[(($5)>>2)];
      var $7=$6;
      $attr=$7;
      var $8=$attr;
      var $9=(($8+12)|0);
      var $10=HEAP32[(($9)>>2)];
      var $11=(($10)|0)!=0;
      if ($11) { __label__ = 10; break; } else { __label__ = 3; break; }
    case 3: 
      var $13=$2;
      var $14=_HPDF_Page_GetInheritableItem($13, ((STRING_TABLE.__str81631)|0), 17);
      var $15=$14;
      $resources=$15;
      var $16=$resources;
      var $17=(($16)|0)!=0;
      if ($17) { __label__ = 5; break; } else { __label__ = 4; break; }
    case 4: 
      $1=0;
      __label__ = 15; break;
    case 5: 
      var $20=$2;
      var $21=(($20+8)|0);
      var $22=HEAP32[(($21)>>2)];
      var $23=_HPDF_Dict_New($22);
      $ext_gstates=$23;
      var $24=$ext_gstates;
      var $25=(($24)|0)!=0;
      if ($25) { __label__ = 7; break; } else { __label__ = 6; break; }
    case 6: 
      $1=0;
      __label__ = 15; break;
    case 7: 
      var $28=$resources;
      var $29=$ext_gstates;
      var $30=$29;
      var $31=_HPDF_Dict_Add($28, ((STRING_TABLE.__str131636)|0), $30);
      var $32=(($31)|0)!=0;
      if ($32) { __label__ = 8; break; } else { __label__ = 9; break; }
    case 8: 
      $1=0;
      __label__ = 15; break;
    case 9: 
      var $35=$ext_gstates;
      var $36=$attr;
      var $37=(($36+12)|0);
      HEAP32[(($37)>>2)]=$35;
      __label__ = 10; break;
    case 10: 
      var $39=$attr;
      var $40=(($39+12)|0);
      var $41=HEAP32[(($40)>>2)];
      var $42=$3;
      var $43=$42;
      var $44=_HPDF_Dict_GetKeyByObj($41, $43);
      $key=$44;
      var $45=$key;
      var $46=(($45)|0)!=0;
      if ($46) { __label__ = 14; break; } else { __label__ = 11; break; }
    case 11: 
      var $48=(($ext_gstate_name)|0);
      var $49=(($48+127)|0);
      $end_ptr=$49;
      var $50=(($ext_gstate_name)|0);
      var $51=$end_ptr;
      var $52=_HPDF_StrCpy($50, ((STRING_TABLE.__str141637)|0), $51);
      $ptr=$52;
      var $53=$ptr;
      var $54=$attr;
      var $55=(($54+12)|0);
      var $56=HEAP32[(($55)>>2)];
      var $57=(($56+16)|0);
      var $58=HEAP32[(($57)>>2)];
      var $59=(($58+16)|0);
      var $60=HEAP32[(($59)>>2)];
      var $61=((($60)+(1))|0);
      var $62=$end_ptr;
      var $63=_HPDF_IToA($53, $61, $62);
      var $64=$attr;
      var $65=(($64+12)|0);
      var $66=HEAP32[(($65)>>2)];
      var $67=(($ext_gstate_name)|0);
      var $68=$3;
      var $69=$68;
      var $70=_HPDF_Dict_Add($66, $67, $69);
      var $71=(($70)|0)!=0;
      if ($71) { __label__ = 12; break; } else { __label__ = 13; break; }
    case 12: 
      $1=0;
      __label__ = 15; break;
    case 13: 
      var $74=$attr;
      var $75=(($74+12)|0);
      var $76=HEAP32[(($75)>>2)];
      var $77=$3;
      var $78=$77;
      var $79=_HPDF_Dict_GetKeyByObj($76, $78);
      $key=$79;
      __label__ = 14; break;
    case 14: 
      var $81=$key;
      $1=$81;
      __label__ = 15; break;
    case 15: 
      var $83=$1;
      STACKTOP = __stackBase__;
      return $83;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Page_GetExtGStateName["X"]=1;

function _HPDF_Page_TextWidth($page, $text) {
  var __stackBase__  = STACKTOP; STACKTOP += 32; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $attr;
      var $tw=__stackBase__;
      var $ret;
      var $len;
      var $4=(__stackBase__)+(16);
      $2=$page;
      $3=$text;
      $ret=0;
      var $5=$3;
      var $6=_HPDF_StrLen($5, 65536);
      $len=$6;
      var $7=$2;
      var $8=_HPDF_Page_Validate($7);
      var $9=(($8)|0)!=0;
      if ($9) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $11=$len;
      var $12=(($11)|0)==0;
      if ($12) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      $1=0;
      __label__ = 8; break;
    case 5: 
      var $15=$2;
      var $16=(($15+44)|0);
      var $17=HEAP32[(($16)>>2)];
      var $18=$17;
      $attr=$18;
      var $19=$attr;
      var $20=(($19+16)|0);
      var $21=HEAP32[(($20)>>2)];
      var $22=(($21+164)|0);
      var $23=HEAP32[(($22)>>2)];
      var $24=(($23)|0)!=0;
      if ($24) { __label__ = 7; break; } else { __label__ = 6; break; }
    case 6: 
      var $26=$2;
      var $27=(($26+12)|0);
      var $28=HEAP32[(($27)>>2)];
      var $29=_HPDF_RaiseError($28, 4174, 0);
      $1=0;
      __label__ = 8; break;
    case 7: 
      var $31=$attr;
      var $32=(($31+16)|0);
      var $33=HEAP32[(($32)>>2)];
      var $34=(($33+164)|0);
      var $35=HEAP32[(($34)>>2)];
      var $36=$3;
      var $37=$len;
      _HPDF_Font_TextWidth($4, $35, $36, $37);
      var $38=$tw;
      var $39=$4;
      assert(16 % 1 === 0, 'memcpy given ' + 16 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP32[(($38)>>2)]=HEAP32[(($39)>>2)];HEAP32[((($38)+(4))>>2)]=HEAP32[((($39)+(4))>>2)];HEAP32[((($38)+(8))>>2)]=HEAP32[((($39)+(8))>>2)];HEAP32[((($38)+(12))>>2)]=HEAP32[((($39)+(12))>>2)];
      var $40=$attr;
      var $41=(($40+16)|0);
      var $42=HEAP32[(($41)>>2)];
      var $43=(($42+72)|0);
      var $44=HEAPF32[(($43)>>2)];
      var $45=(($tw+12)|0);
      var $46=HEAPU32[(($45)>>2)];
      var $47=(($46)>>>0);
      var $48=($44)*($47);
      var $49=$ret;
      var $50=($49)+($48);
      $ret=$50;
      var $51=(($tw+8)|0);
      var $52=HEAPU32[(($51)>>2)];
      var $53=(($52)>>>0);
      var $54=$attr;
      var $55=(($54+16)|0);
      var $56=HEAP32[(($55)>>2)];
      var $57=(($56+168)|0);
      var $58=HEAPF32[(($57)>>2)];
      var $59=($53)*($58);
      var $60=($59)/(1000);
      var $61=$ret;
      var $62=($61)+($60);
      $ret=$62;
      var $63=$attr;
      var $64=(($63+16)|0);
      var $65=HEAP32[(($64)>>2)];
      var $66=(($65+68)|0);
      var $67=HEAPF32[(($66)>>2)];
      var $68=(($tw)|0);
      var $69=HEAPU32[(($68)>>2)];
      var $70=(($69)>>>0);
      var $71=($67)*($70);
      var $72=$ret;
      var $73=($72)+($71);
      $ret=$73;
      var $74=$2;
      var $75=(($74+12)|0);
      var $76=HEAP32[(($75)>>2)];
      var $77=_HPDF_CheckError($76);
      var $78=$ret;
      $1=$78;
      __label__ = 8; break;
    case 8: 
      var $80=$1;
      STACKTOP = __stackBase__;
      return $80;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Page_TextWidth["X"]=1;

function _HPDF_Page_MeasureText($page, $text, $width, $wordwrap, $real_width) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $5;
      var $6;
      var $attr;
      var $len;
      var $ret;
      $2=$page;
      $3=$text;
      $4=$width;
      $5=$wordwrap;
      $6=$real_width;
      var $7=$3;
      var $8=_HPDF_StrLen($7, 65536);
      $len=$8;
      var $9=$2;
      var $10=_HPDF_Page_Validate($9);
      var $11=(($10)|0)!=0;
      if ($11) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $13=$len;
      var $14=(($13)|0)==0;
      if ($14) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      $1=0;
      __label__ = 8; break;
    case 5: 
      var $17=$2;
      var $18=(($17+44)|0);
      var $19=HEAP32[(($18)>>2)];
      var $20=$19;
      $attr=$20;
      var $21=$attr;
      var $22=(($21+16)|0);
      var $23=HEAP32[(($22)>>2)];
      var $24=(($23+164)|0);
      var $25=HEAP32[(($24)>>2)];
      var $26=(($25)|0)!=0;
      if ($26) { __label__ = 7; break; } else { __label__ = 6; break; }
    case 6: 
      var $28=$2;
      var $29=(($28+12)|0);
      var $30=HEAP32[(($29)>>2)];
      var $31=_HPDF_RaiseError($30, 4174, 0);
      $1=0;
      __label__ = 8; break;
    case 7: 
      var $33=$attr;
      var $34=(($33+16)|0);
      var $35=HEAP32[(($34)>>2)];
      var $36=(($35+164)|0);
      var $37=HEAP32[(($36)>>2)];
      var $38=$3;
      var $39=$len;
      var $40=$4;
      var $41=$attr;
      var $42=(($41+16)|0);
      var $43=HEAP32[(($42)>>2)];
      var $44=(($43+168)|0);
      var $45=HEAPF32[(($44)>>2)];
      var $46=$attr;
      var $47=(($46+16)|0);
      var $48=HEAP32[(($47)>>2)];
      var $49=(($48+68)|0);
      var $50=HEAPF32[(($49)>>2)];
      var $51=$attr;
      var $52=(($51+16)|0);
      var $53=HEAP32[(($52)>>2)];
      var $54=(($53+72)|0);
      var $55=HEAPF32[(($54)>>2)];
      var $56=$5;
      var $57=$6;
      var $58=_HPDF_Font_MeasureText($37, $38, $39, $40, $45, $50, $55, $56, $57);
      $ret=$58;
      var $59=$2;
      var $60=(($59+12)|0);
      var $61=HEAP32[(($60)>>2)];
      var $62=_HPDF_CheckError($61);
      var $63=$ret;
      $1=$63;
      __label__ = 8; break;
    case 8: 
      var $65=$1;
      ;
      return $65;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Page_MeasureText["X"]=1;

function _HPDF_Page_GetWidth($page) {
  var __stackBase__  = STACKTOP; STACKTOP += 16; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;

  var $1;
  var $2=__stackBase__;
  $1=$page;
  var $3=$1;
  _HPDF_Page_GetMediaBox($2, $3);
  var $4=(($2+8)|0);
  var $5=HEAPF32[(($4)>>2)];
  STACKTOP = __stackBase__;
  return $5;
}


function _HPDF_Page_GetHeight($page) {
  var __stackBase__  = STACKTOP; STACKTOP += 16; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;

  var $1;
  var $2=__stackBase__;
  $1=$page;
  var $3=$1;
  _HPDF_Page_GetMediaBox($2, $3);
  var $4=(($2+12)|0);
  var $5=HEAPF32[(($4)>>2)];
  STACKTOP = __stackBase__;
  return $5;
}


function _HPDF_Page_GetCurrentFont($page) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $attr;
      $2=$page;
      var $3=$2;
      var $4=_HPDF_Page_Validate($3);
      var $5=(($4)|0)!=0;
      if ($5) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $7=$2;
      var $8=(($7+44)|0);
      var $9=HEAP32[(($8)>>2)];
      var $10=$9;
      $attr=$10;
      var $11=$attr;
      var $12=(($11+16)|0);
      var $13=HEAP32[(($12)>>2)];
      var $14=(($13+164)|0);
      var $15=HEAP32[(($14)>>2)];
      $1=$15;
      __label__ = 5; break;
    case 4: 
      $1=0;
      __label__ = 5; break;
    case 5: 
      var $18=$1;
      ;
      return $18;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Page_GetCurrentFontSize($page) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $attr;
      $2=$page;
      var $3=$2;
      var $4=_HPDF_Page_Validate($3);
      var $5=(($4)|0)!=0;
      if ($5) { __label__ = 3; break; } else { __label__ = 7; break; }
    case 3: 
      var $7=$2;
      var $8=(($7+44)|0);
      var $9=HEAP32[(($8)>>2)];
      var $10=$9;
      $attr=$10;
      var $11=$attr;
      var $12=(($11+16)|0);
      var $13=HEAP32[(($12)>>2)];
      var $14=(($13+164)|0);
      var $15=HEAP32[(($14)>>2)];
      var $16=(($15)|0)!=0;
      if ($16) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      var $18=$attr;
      var $19=(($18+16)|0);
      var $20=HEAP32[(($19)>>2)];
      var $21=(($20+168)|0);
      var $22=HEAPF32[(($21)>>2)];
      var $25 = $22;__label__ = 6; break;
    case 5: 
      var $25 = 0;__label__ = 6; break;
    case 6: 
      var $25;
      $1=$25;
      __label__ = 8; break;
    case 7: 
      $1=0;
      __label__ = 8; break;
    case 8: 
      var $28=$1;
      ;
      return $28;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Page_GetTransMatrix($agg_result, $page) {
  var __stackBase__  = STACKTOP; STACKTOP += 24; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $DEF_MATRIX=__stackBase__;
      var $attr;
      $1=$page;
      var $2=$DEF_MATRIX;
      assert(24 % 1 === 0, 'memcpy given ' + 24 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP32[(($2)>>2)]=HEAP32[((_HPDF_Page_GetTransMatrix_DEF_MATRIX)>>2)];HEAP32[((($2)+(4))>>2)]=HEAP32[(((_HPDF_Page_GetTransMatrix_DEF_MATRIX)+(4))>>2)];HEAP32[((($2)+(8))>>2)]=HEAP32[(((_HPDF_Page_GetTransMatrix_DEF_MATRIX)+(8))>>2)];HEAP32[((($2)+(12))>>2)]=HEAP32[(((_HPDF_Page_GetTransMatrix_DEF_MATRIX)+(12))>>2)];HEAP32[((($2)+(16))>>2)]=HEAP32[(((_HPDF_Page_GetTransMatrix_DEF_MATRIX)+(16))>>2)];HEAP32[((($2)+(20))>>2)]=HEAP32[(((_HPDF_Page_GetTransMatrix_DEF_MATRIX)+(20))>>2)];
      var $3=$1;
      var $4=_HPDF_Page_Validate($3);
      var $5=(($4)|0)!=0;
      if ($5) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $7=$1;
      var $8=(($7+44)|0);
      var $9=HEAP32[(($8)>>2)];
      var $10=$9;
      $attr=$10;
      var $11=$attr;
      var $12=(($11+16)|0);
      var $13=HEAP32[(($12)>>2)];
      var $14=(($13)|0);
      var $15=$agg_result;
      var $16=$14;
      assert(24 % 1 === 0, 'memcpy given ' + 24 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP32[(($15)>>2)]=HEAP32[(($16)>>2)];HEAP32[((($15)+(4))>>2)]=HEAP32[((($16)+(4))>>2)];HEAP32[((($15)+(8))>>2)]=HEAP32[((($16)+(8))>>2)];HEAP32[((($15)+(12))>>2)]=HEAP32[((($16)+(12))>>2)];HEAP32[((($15)+(16))>>2)]=HEAP32[((($16)+(16))>>2)];HEAP32[((($15)+(20))>>2)]=HEAP32[((($16)+(20))>>2)];
      __label__ = 5; break;
    case 4: 
      var $18=$agg_result;
      var $19=$DEF_MATRIX;
      assert(24 % 1 === 0, 'memcpy given ' + 24 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP32[(($18)>>2)]=HEAP32[(($19)>>2)];HEAP32[((($18)+(4))>>2)]=HEAP32[((($19)+(4))>>2)];HEAP32[((($18)+(8))>>2)]=HEAP32[((($19)+(8))>>2)];HEAP32[((($18)+(12))>>2)]=HEAP32[((($19)+(12))>>2)];HEAP32[((($18)+(16))>>2)]=HEAP32[((($19)+(16))>>2)];HEAP32[((($18)+(20))>>2)]=HEAP32[((($19)+(20))>>2)];
      __label__ = 5; break;
    case 5: 
      STACKTOP = __stackBase__;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Page_GetLineWidth($page) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $attr;
      $2=$page;
      var $3=$2;
      var $4=_HPDF_Page_Validate($3);
      var $5=(($4)|0)!=0;
      if ($5) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $7=$2;
      var $8=(($7+44)|0);
      var $9=HEAP32[(($8)>>2)];
      var $10=$9;
      $attr=$10;
      var $11=$attr;
      var $12=(($11+16)|0);
      var $13=HEAP32[(($12)>>2)];
      var $14=(($13+24)|0);
      var $15=HEAPF32[(($14)>>2)];
      $1=$15;
      __label__ = 5; break;
    case 4: 
      $1=1;
      __label__ = 5; break;
    case 5: 
      var $18=$1;
      ;
      return $18;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Page_GetLineCap($page) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $attr;
      $2=$page;
      var $3=$2;
      var $4=_HPDF_Page_Validate($3);
      var $5=(($4)|0)!=0;
      if ($5) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $7=$2;
      var $8=(($7+44)|0);
      var $9=HEAP32[(($8)>>2)];
      var $10=$9;
      $attr=$10;
      var $11=$attr;
      var $12=(($11+16)|0);
      var $13=HEAP32[(($12)>>2)];
      var $14=(($13+28)|0);
      var $15=HEAP32[(($14)>>2)];
      $1=$15;
      __label__ = 5; break;
    case 4: 
      $1=0;
      __label__ = 5; break;
    case 5: 
      var $18=$1;
      ;
      return $18;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Page_GetLineJoin($page) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $attr;
      $2=$page;
      var $3=$2;
      var $4=_HPDF_Page_Validate($3);
      var $5=(($4)|0)!=0;
      if ($5) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $7=$2;
      var $8=(($7+44)|0);
      var $9=HEAP32[(($8)>>2)];
      var $10=$9;
      $attr=$10;
      var $11=$attr;
      var $12=(($11+16)|0);
      var $13=HEAP32[(($12)>>2)];
      var $14=(($13+32)|0);
      var $15=HEAP32[(($14)>>2)];
      $1=$15;
      __label__ = 5; break;
    case 4: 
      $1=0;
      __label__ = 5; break;
    case 5: 
      var $18=$1;
      ;
      return $18;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Page_GetMiterLimit($page) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $attr;
      $2=$page;
      var $3=$2;
      var $4=_HPDF_Page_Validate($3);
      var $5=(($4)|0)!=0;
      if ($5) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $7=$2;
      var $8=(($7+44)|0);
      var $9=HEAP32[(($8)>>2)];
      var $10=$9;
      $attr=$10;
      var $11=$attr;
      var $12=(($11+16)|0);
      var $13=HEAP32[(($12)>>2)];
      var $14=(($13+36)|0);
      var $15=HEAPF32[(($14)>>2)];
      $1=$15;
      __label__ = 5; break;
    case 4: 
      $1=10;
      __label__ = 5; break;
    case 5: 
      var $18=$1;
      ;
      return $18;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Page_GetDash($agg_result, $page) {
  var __stackBase__  = STACKTOP; STACKTOP += 24; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $mode=__stackBase__;
      var $attr;
      $1=$page;
      var $2=$mode;
      HEAP32[(($2)>>2)]=0; HEAP32[((($2)+(4))>>2)]=0; HEAP32[((($2)+(8))>>2)]=0; HEAP32[((($2)+(12))>>2)]=0; HEAP32[((($2)+(16))>>2)]=0; HEAP32[((($2)+(20))>>2)]=0;
      var $3=$1;
      var $4=_HPDF_Page_Validate($3);
      var $5=(($4)|0)!=0;
      if ($5) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $7=$1;
      var $8=(($7+44)|0);
      var $9=HEAP32[(($8)>>2)];
      var $10=$9;
      $attr=$10;
      var $11=$attr;
      var $12=(($11+16)|0);
      var $13=HEAP32[(($12)>>2)];
      var $14=(($13+40)|0);
      var $15=$mode;
      var $16=$14;
      assert(24 % 1 === 0, 'memcpy given ' + 24 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP32[(($15)>>2)]=HEAP32[(($16)>>2)];HEAP32[((($15)+(4))>>2)]=HEAP32[((($16)+(4))>>2)];HEAP32[((($15)+(8))>>2)]=HEAP32[((($16)+(8))>>2)];HEAP32[((($15)+(12))>>2)]=HEAP32[((($16)+(12))>>2)];HEAP32[((($15)+(16))>>2)]=HEAP32[((($16)+(16))>>2)];HEAP32[((($15)+(20))>>2)]=HEAP32[((($16)+(20))>>2)];
      __label__ = 4; break;
    case 4: 
      var $18=$agg_result;
      var $19=$mode;
      assert(24 % 1 === 0, 'memcpy given ' + 24 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP32[(($18)>>2)]=HEAP32[(($19)>>2)];HEAP32[((($18)+(4))>>2)]=HEAP32[((($19)+(4))>>2)];HEAP32[((($18)+(8))>>2)]=HEAP32[((($19)+(8))>>2)];HEAP32[((($18)+(12))>>2)]=HEAP32[((($19)+(12))>>2)];HEAP32[((($18)+(16))>>2)]=HEAP32[((($19)+(16))>>2)];HEAP32[((($18)+(20))>>2)]=HEAP32[((($19)+(20))>>2)];
      STACKTOP = __stackBase__;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Page_GetFlat($page) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $attr;
      $2=$page;
      var $3=$2;
      var $4=_HPDF_Page_Validate($3);
      var $5=(($4)|0)!=0;
      if ($5) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $7=$2;
      var $8=(($7+44)|0);
      var $9=HEAP32[(($8)>>2)];
      var $10=$9;
      $attr=$10;
      var $11=$attr;
      var $12=(($11+16)|0);
      var $13=HEAP32[(($12)>>2)];
      var $14=(($13+64)|0);
      var $15=HEAPF32[(($14)>>2)];
      $1=$15;
      __label__ = 5; break;
    case 4: 
      $1=1;
      __label__ = 5; break;
    case 5: 
      var $18=$1;
      ;
      return $18;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Page_GetWordSpace($page) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $attr;
      $2=$page;
      var $3=$2;
      var $4=_HPDF_Page_Validate($3);
      var $5=(($4)|0)!=0;
      if ($5) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $7=$2;
      var $8=(($7+44)|0);
      var $9=HEAP32[(($8)>>2)];
      var $10=$9;
      $attr=$10;
      var $11=$attr;
      var $12=(($11+16)|0);
      var $13=HEAP32[(($12)>>2)];
      var $14=(($13+72)|0);
      var $15=HEAPF32[(($14)>>2)];
      $1=$15;
      __label__ = 5; break;
    case 4: 
      $1=0;
      __label__ = 5; break;
    case 5: 
      var $18=$1;
      ;
      return $18;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Page_GetCharSpace($page) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $attr;
      $2=$page;
      var $3=$2;
      var $4=_HPDF_Page_Validate($3);
      var $5=(($4)|0)!=0;
      if ($5) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $7=$2;
      var $8=(($7+44)|0);
      var $9=HEAP32[(($8)>>2)];
      var $10=$9;
      $attr=$10;
      var $11=$attr;
      var $12=(($11+16)|0);
      var $13=HEAP32[(($12)>>2)];
      var $14=(($13+68)|0);
      var $15=HEAPF32[(($14)>>2)];
      $1=$15;
      __label__ = 5; break;
    case 4: 
      $1=0;
      __label__ = 5; break;
    case 5: 
      var $18=$1;
      ;
      return $18;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Page_GetHorizontalScalling($page) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $attr;
      $2=$page;
      var $3=$2;
      var $4=_HPDF_Page_Validate($3);
      var $5=(($4)|0)!=0;
      if ($5) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $7=$2;
      var $8=(($7+44)|0);
      var $9=HEAP32[(($8)>>2)];
      var $10=$9;
      $attr=$10;
      var $11=$attr;
      var $12=(($11+16)|0);
      var $13=HEAP32[(($12)>>2)];
      var $14=(($13+76)|0);
      var $15=HEAPF32[(($14)>>2)];
      $1=$15;
      __label__ = 5; break;
    case 4: 
      $1=100;
      __label__ = 5; break;
    case 5: 
      var $18=$1;
      ;
      return $18;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Page_GetTextLeading($page) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $attr;
      $2=$page;
      var $3=$2;
      var $4=_HPDF_Page_Validate($3);
      var $5=(($4)|0)!=0;
      if ($5) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $7=$2;
      var $8=(($7+44)|0);
      var $9=HEAP32[(($8)>>2)];
      var $10=$9;
      $attr=$10;
      var $11=$attr;
      var $12=(($11+16)|0);
      var $13=HEAP32[(($12)>>2)];
      var $14=(($13+80)|0);
      var $15=HEAPF32[(($14)>>2)];
      $1=$15;
      __label__ = 5; break;
    case 4: 
      $1=0;
      __label__ = 5; break;
    case 5: 
      var $18=$1;
      ;
      return $18;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Page_GetTextRenderingMode($page) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $attr;
      $2=$page;
      var $3=$2;
      var $4=_HPDF_Page_Validate($3);
      var $5=(($4)|0)!=0;
      if ($5) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $7=$2;
      var $8=(($7+44)|0);
      var $9=HEAP32[(($8)>>2)];
      var $10=$9;
      $attr=$10;
      var $11=$attr;
      var $12=(($11+16)|0);
      var $13=HEAP32[(($12)>>2)];
      var $14=(($13+84)|0);
      var $15=HEAP32[(($14)>>2)];
      $1=$15;
      __label__ = 5; break;
    case 4: 
      $1=0;
      __label__ = 5; break;
    case 5: 
      var $18=$1;
      ;
      return $18;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Page_GetTextRaise($page) {
  ;
  var __label__;

  var $1;
  $1=$page;
  var $2=$1;
  var $3=_HPDF_Page_GetTextRise($2);
  ;
  return $3;
}


function _HPDF_Page_GetTextRise($page) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $attr;
      $2=$page;
      var $3=$2;
      var $4=_HPDF_Page_Validate($3);
      var $5=(($4)|0)!=0;
      if ($5) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $7=$2;
      var $8=(($7+44)|0);
      var $9=HEAP32[(($8)>>2)];
      var $10=$9;
      $attr=$10;
      var $11=$attr;
      var $12=(($11+16)|0);
      var $13=HEAP32[(($12)>>2)];
      var $14=(($13+88)|0);
      var $15=HEAPF32[(($14)>>2)];
      $1=$15;
      __label__ = 5; break;
    case 4: 
      $1=0;
      __label__ = 5; break;
    case 5: 
      var $18=$1;
      ;
      return $18;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Page_GetRGBFill($agg_result, $page) {
  var __stackBase__  = STACKTOP; STACKTOP += 12; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $DEF_RGB_COLOR=__stackBase__;
      var $attr;
      $1=$page;
      var $2=$DEF_RGB_COLOR;
      HEAP32[(($2)>>2)]=0; HEAP32[((($2)+(4))>>2)]=0; HEAP32[((($2)+(8))>>2)]=0;
      var $3=$1;
      var $4=_HPDF_Page_Validate($3);
      var $5=(($4)|0)!=0;
      if ($5) { __label__ = 3; break; } else { __label__ = 6; break; }
    case 3: 
      var $7=$1;
      var $8=(($7+44)|0);
      var $9=HEAP32[(($8)>>2)];
      var $10=$9;
      $attr=$10;
      var $11=$attr;
      var $12=(($11+16)|0);
      var $13=HEAP32[(($12)>>2)];
      var $14=(($13+92)|0);
      var $15=HEAP32[(($14)>>2)];
      var $16=(($15)|0)==1;
      if ($16) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      var $18=$attr;
      var $19=(($18+16)|0);
      var $20=HEAP32[(($19)>>2)];
      var $21=(($20+100)|0);
      var $22=$agg_result;
      var $23=$21;
      assert(12 % 1 === 0, 'memcpy given ' + 12 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP32[(($22)>>2)]=HEAP32[(($23)>>2)];HEAP32[((($22)+(4))>>2)]=HEAP32[((($23)+(4))>>2)];HEAP32[((($22)+(8))>>2)]=HEAP32[((($23)+(8))>>2)];
      __label__ = 7; break;
    case 5: 
      __label__ = 6; break;
    case 6: 
      var $26=$agg_result;
      var $27=$DEF_RGB_COLOR;
      assert(12 % 1 === 0, 'memcpy given ' + 12 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP32[(($26)>>2)]=HEAP32[(($27)>>2)];HEAP32[((($26)+(4))>>2)]=HEAP32[((($27)+(4))>>2)];HEAP32[((($26)+(8))>>2)]=HEAP32[((($27)+(8))>>2)];
      __label__ = 7; break;
    case 7: 
      STACKTOP = __stackBase__;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Page_GetRGBStroke($agg_result, $page) {
  var __stackBase__  = STACKTOP; STACKTOP += 12; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $DEF_RGB_COLOR=__stackBase__;
      var $attr;
      $1=$page;
      var $2=$DEF_RGB_COLOR;
      HEAP32[(($2)>>2)]=0; HEAP32[((($2)+(4))>>2)]=0; HEAP32[((($2)+(8))>>2)]=0;
      var $3=$1;
      var $4=_HPDF_Page_Validate($3);
      var $5=(($4)|0)!=0;
      if ($5) { __label__ = 3; break; } else { __label__ = 6; break; }
    case 3: 
      var $7=$1;
      var $8=(($7+44)|0);
      var $9=HEAP32[(($8)>>2)];
      var $10=$9;
      $attr=$10;
      var $11=$attr;
      var $12=(($11+16)|0);
      var $13=HEAP32[(($12)>>2)];
      var $14=(($13+96)|0);
      var $15=HEAP32[(($14)>>2)];
      var $16=(($15)|0)==1;
      if ($16) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      var $18=$attr;
      var $19=(($18+16)|0);
      var $20=HEAP32[(($19)>>2)];
      var $21=(($20+112)|0);
      var $22=$agg_result;
      var $23=$21;
      assert(12 % 1 === 0, 'memcpy given ' + 12 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP32[(($22)>>2)]=HEAP32[(($23)>>2)];HEAP32[((($22)+(4))>>2)]=HEAP32[((($23)+(4))>>2)];HEAP32[((($22)+(8))>>2)]=HEAP32[((($23)+(8))>>2)];
      __label__ = 7; break;
    case 5: 
      __label__ = 6; break;
    case 6: 
      var $26=$agg_result;
      var $27=$DEF_RGB_COLOR;
      assert(12 % 1 === 0, 'memcpy given ' + 12 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP32[(($26)>>2)]=HEAP32[(($27)>>2)];HEAP32[((($26)+(4))>>2)]=HEAP32[((($27)+(4))>>2)];HEAP32[((($26)+(8))>>2)]=HEAP32[((($27)+(8))>>2)];
      __label__ = 7; break;
    case 7: 
      STACKTOP = __stackBase__;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Page_GetCMYKFill($agg_result, $page) {
  var __stackBase__  = STACKTOP; STACKTOP += 16; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $DEF_CMYK_COLOR=__stackBase__;
      var $attr;
      $1=$page;
      var $2=$DEF_CMYK_COLOR;
      HEAP32[(($2)>>2)]=0; HEAP32[((($2)+(4))>>2)]=0; HEAP32[((($2)+(8))>>2)]=0; HEAP32[((($2)+(12))>>2)]=0;
      var $3=$1;
      var $4=_HPDF_Page_Validate($3);
      var $5=(($4)|0)!=0;
      if ($5) { __label__ = 3; break; } else { __label__ = 6; break; }
    case 3: 
      var $7=$1;
      var $8=(($7+44)|0);
      var $9=HEAP32[(($8)>>2)];
      var $10=$9;
      $attr=$10;
      var $11=$attr;
      var $12=(($11+16)|0);
      var $13=HEAP32[(($12)>>2)];
      var $14=(($13+92)|0);
      var $15=HEAP32[(($14)>>2)];
      var $16=(($15)|0)==2;
      if ($16) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      var $18=$attr;
      var $19=(($18+16)|0);
      var $20=HEAP32[(($19)>>2)];
      var $21=(($20+124)|0);
      var $22=$agg_result;
      var $23=$21;
      assert(16 % 1 === 0, 'memcpy given ' + 16 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP32[(($22)>>2)]=HEAP32[(($23)>>2)];HEAP32[((($22)+(4))>>2)]=HEAP32[((($23)+(4))>>2)];HEAP32[((($22)+(8))>>2)]=HEAP32[((($23)+(8))>>2)];HEAP32[((($22)+(12))>>2)]=HEAP32[((($23)+(12))>>2)];
      __label__ = 7; break;
    case 5: 
      __label__ = 6; break;
    case 6: 
      var $26=$agg_result;
      var $27=$DEF_CMYK_COLOR;
      assert(16 % 1 === 0, 'memcpy given ' + 16 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP32[(($26)>>2)]=HEAP32[(($27)>>2)];HEAP32[((($26)+(4))>>2)]=HEAP32[((($27)+(4))>>2)];HEAP32[((($26)+(8))>>2)]=HEAP32[((($27)+(8))>>2)];HEAP32[((($26)+(12))>>2)]=HEAP32[((($27)+(12))>>2)];
      __label__ = 7; break;
    case 7: 
      STACKTOP = __stackBase__;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Page_GetCMYKStroke($agg_result, $page) {
  var __stackBase__  = STACKTOP; STACKTOP += 16; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $DEF_CMYK_COLOR=__stackBase__;
      var $attr;
      $1=$page;
      var $2=$DEF_CMYK_COLOR;
      HEAP32[(($2)>>2)]=0; HEAP32[((($2)+(4))>>2)]=0; HEAP32[((($2)+(8))>>2)]=0; HEAP32[((($2)+(12))>>2)]=0;
      var $3=$1;
      var $4=_HPDF_Page_Validate($3);
      var $5=(($4)|0)!=0;
      if ($5) { __label__ = 3; break; } else { __label__ = 6; break; }
    case 3: 
      var $7=$1;
      var $8=(($7+44)|0);
      var $9=HEAP32[(($8)>>2)];
      var $10=$9;
      $attr=$10;
      var $11=$attr;
      var $12=(($11+16)|0);
      var $13=HEAP32[(($12)>>2)];
      var $14=(($13+96)|0);
      var $15=HEAP32[(($14)>>2)];
      var $16=(($15)|0)==2;
      if ($16) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      var $18=$attr;
      var $19=(($18+16)|0);
      var $20=HEAP32[(($19)>>2)];
      var $21=(($20+140)|0);
      var $22=$agg_result;
      var $23=$21;
      assert(16 % 1 === 0, 'memcpy given ' + 16 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP32[(($22)>>2)]=HEAP32[(($23)>>2)];HEAP32[((($22)+(4))>>2)]=HEAP32[((($23)+(4))>>2)];HEAP32[((($22)+(8))>>2)]=HEAP32[((($23)+(8))>>2)];HEAP32[((($22)+(12))>>2)]=HEAP32[((($23)+(12))>>2)];
      __label__ = 7; break;
    case 5: 
      __label__ = 6; break;
    case 6: 
      var $26=$agg_result;
      var $27=$DEF_CMYK_COLOR;
      assert(16 % 1 === 0, 'memcpy given ' + 16 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP32[(($26)>>2)]=HEAP32[(($27)>>2)];HEAP32[((($26)+(4))>>2)]=HEAP32[((($27)+(4))>>2)];HEAP32[((($26)+(8))>>2)]=HEAP32[((($27)+(8))>>2)];HEAP32[((($26)+(12))>>2)]=HEAP32[((($27)+(12))>>2)];
      __label__ = 7; break;
    case 7: 
      STACKTOP = __stackBase__;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Page_GetGrayFill($page) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $attr;
      $2=$page;
      var $3=$2;
      var $4=_HPDF_Page_Validate($3);
      var $5=(($4)|0)!=0;
      if ($5) { __label__ = 3; break; } else { __label__ = 6; break; }
    case 3: 
      var $7=$2;
      var $8=(($7+44)|0);
      var $9=HEAP32[(($8)>>2)];
      var $10=$9;
      $attr=$10;
      var $11=$attr;
      var $12=(($11+16)|0);
      var $13=HEAP32[(($12)>>2)];
      var $14=(($13+92)|0);
      var $15=HEAP32[(($14)>>2)];
      var $16=(($15)|0)==0;
      if ($16) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      var $18=$attr;
      var $19=(($18+16)|0);
      var $20=HEAP32[(($19)>>2)];
      var $21=(($20+156)|0);
      var $22=HEAPF32[(($21)>>2)];
      $1=$22;
      __label__ = 7; break;
    case 5: 
      __label__ = 6; break;
    case 6: 
      $1=0;
      __label__ = 7; break;
    case 7: 
      var $26=$1;
      ;
      return $26;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Page_GetGrayStroke($page) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $attr;
      $2=$page;
      var $3=$2;
      var $4=_HPDF_Page_Validate($3);
      var $5=(($4)|0)!=0;
      if ($5) { __label__ = 3; break; } else { __label__ = 6; break; }
    case 3: 
      var $7=$2;
      var $8=(($7+44)|0);
      var $9=HEAP32[(($8)>>2)];
      var $10=$9;
      $attr=$10;
      var $11=$attr;
      var $12=(($11+16)|0);
      var $13=HEAP32[(($12)>>2)];
      var $14=(($13+96)|0);
      var $15=HEAP32[(($14)>>2)];
      var $16=(($15)|0)==0;
      if ($16) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      var $18=$attr;
      var $19=(($18+16)|0);
      var $20=HEAP32[(($19)>>2)];
      var $21=(($20+160)|0);
      var $22=HEAPF32[(($21)>>2)];
      $1=$22;
      __label__ = 7; break;
    case 5: 
      __label__ = 6; break;
    case 6: 
      $1=0;
      __label__ = 7; break;
    case 7: 
      var $26=$1;
      ;
      return $26;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Page_GetStrokingColorSpace($page) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      $2=$page;
      var $3=$2;
      var $4=_HPDF_Page_Validate($3);
      var $5=(($4)|0)!=0;
      if ($5) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $7=$2;
      var $8=(($7+44)|0);
      var $9=HEAP32[(($8)>>2)];
      var $10=$9;
      var $11=(($10+16)|0);
      var $12=HEAP32[(($11)>>2)];
      var $13=(($12+96)|0);
      var $14=HEAP32[(($13)>>2)];
      $1=$14;
      __label__ = 5; break;
    case 4: 
      $1=11;
      __label__ = 5; break;
    case 5: 
      var $17=$1;
      ;
      return $17;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Page_GetFillingColorSpace($page) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      $2=$page;
      var $3=$2;
      var $4=_HPDF_Page_Validate($3);
      var $5=(($4)|0)!=0;
      if ($5) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $7=$2;
      var $8=(($7+44)|0);
      var $9=HEAP32[(($8)>>2)];
      var $10=$9;
      var $11=(($10+16)|0);
      var $12=HEAP32[(($11)>>2)];
      var $13=(($12+92)|0);
      var $14=HEAP32[(($13)>>2)];
      $1=$14;
      __label__ = 5; break;
    case 4: 
      $1=11;
      __label__ = 5; break;
    case 5: 
      var $17=$1;
      ;
      return $17;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Page_GetTextMatrix($agg_result, $page) {
  var __stackBase__  = STACKTOP; STACKTOP += 24; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $DEF_MATRIX=__stackBase__;
      var $attr;
      $1=$page;
      var $2=$DEF_MATRIX;
      assert(24 % 1 === 0, 'memcpy given ' + 24 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP32[(($2)>>2)]=HEAP32[((_HPDF_Page_GetTextMatrix_DEF_MATRIX)>>2)];HEAP32[((($2)+(4))>>2)]=HEAP32[(((_HPDF_Page_GetTextMatrix_DEF_MATRIX)+(4))>>2)];HEAP32[((($2)+(8))>>2)]=HEAP32[(((_HPDF_Page_GetTextMatrix_DEF_MATRIX)+(8))>>2)];HEAP32[((($2)+(12))>>2)]=HEAP32[(((_HPDF_Page_GetTextMatrix_DEF_MATRIX)+(12))>>2)];HEAP32[((($2)+(16))>>2)]=HEAP32[(((_HPDF_Page_GetTextMatrix_DEF_MATRIX)+(16))>>2)];HEAP32[((($2)+(20))>>2)]=HEAP32[(((_HPDF_Page_GetTextMatrix_DEF_MATRIX)+(20))>>2)];
      var $3=$1;
      var $4=_HPDF_Page_Validate($3);
      var $5=(($4)|0)!=0;
      if ($5) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $7=$1;
      var $8=(($7+44)|0);
      var $9=HEAP32[(($8)>>2)];
      var $10=$9;
      $attr=$10;
      var $11=$attr;
      var $12=(($11+44)|0);
      var $13=$agg_result;
      var $14=$12;
      assert(24 % 1 === 0, 'memcpy given ' + 24 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP32[(($13)>>2)]=HEAP32[(($14)>>2)];HEAP32[((($13)+(4))>>2)]=HEAP32[((($14)+(4))>>2)];HEAP32[((($13)+(8))>>2)]=HEAP32[((($14)+(8))>>2)];HEAP32[((($13)+(12))>>2)]=HEAP32[((($14)+(12))>>2)];HEAP32[((($13)+(16))>>2)]=HEAP32[((($14)+(16))>>2)];HEAP32[((($13)+(20))>>2)]=HEAP32[((($14)+(20))>>2)];
      __label__ = 5; break;
    case 4: 
      var $16=$agg_result;
      var $17=$DEF_MATRIX;
      assert(24 % 1 === 0, 'memcpy given ' + 24 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP32[(($16)>>2)]=HEAP32[(($17)>>2)];HEAP32[((($16)+(4))>>2)]=HEAP32[((($17)+(4))>>2)];HEAP32[((($16)+(8))>>2)]=HEAP32[((($17)+(8))>>2)];HEAP32[((($16)+(12))>>2)]=HEAP32[((($17)+(12))>>2)];HEAP32[((($16)+(16))>>2)]=HEAP32[((($17)+(16))>>2)];HEAP32[((($16)+(20))>>2)]=HEAP32[((($17)+(20))>>2)];
      __label__ = 5; break;
    case 5: 
      STACKTOP = __stackBase__;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Page_GetGStateDepth($page) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $attr;
      $2=$page;
      var $3=$2;
      var $4=_HPDF_Page_Validate($3);
      var $5=(($4)|0)!=0;
      if ($5) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $7=$2;
      var $8=(($7+44)|0);
      var $9=HEAP32[(($8)>>2)];
      var $10=$9;
      $attr=$10;
      var $11=$attr;
      var $12=(($11+16)|0);
      var $13=HEAP32[(($12)>>2)];
      var $14=(($13+180)|0);
      var $15=HEAP32[(($14)>>2)];
      $1=$15;
      __label__ = 5; break;
    case 4: 
      $1=0;
      __label__ = 5; break;
    case 5: 
      var $18=$1;
      ;
      return $18;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Page_GetGMode($page) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      $2=$page;
      var $3=$2;
      var $4=_HPDF_Page_Validate($3);
      var $5=(($4)|0)!=0;
      if ($5) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $7=$2;
      var $8=(($7+44)|0);
      var $9=HEAP32[(($8)>>2)];
      var $10=$9;
      var $11=(($10+68)|0);
      var $12=HEAP16[(($11)>>1)];
      $1=$12;
      __label__ = 5; break;
    case 4: 
      $1=0;
      __label__ = 5; break;
    case 5: 
      var $15=$1;
      ;
      return $15;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Page_GetCurrentPos($agg_result, $page) {
  var __stackBase__  = STACKTOP; STACKTOP += 8; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $pos=__stackBase__;
      var $attr;
      $1=$page;
      var $2=$pos;
      HEAP32[(($2)>>2)]=0; HEAP32[((($2)+(4))>>2)]=0;
      var $3=$1;
      var $4=_HPDF_Page_Validate($3);
      var $5=(($4)|0)!=0;
      if ($5) { __label__ = 3; break; } else { __label__ = 6; break; }
    case 3: 
      var $7=$1;
      var $8=(($7+44)|0);
      var $9=HEAP32[(($8)>>2)];
      var $10=$9;
      $attr=$10;
      var $11=$attr;
      var $12=(($11+68)|0);
      var $13=HEAPU16[(($12)>>1)];
      var $14=(($13)&65535);
      var $15=$14 & 2;
      var $16=(($15)|0)!=0;
      if ($16) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      var $18=$attr;
      var $19=(($18+28)|0);
      var $20=$pos;
      var $21=$19;
      assert(8 % 1 === 0, 'memcpy given ' + 8 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP32[(($20)>>2)]=HEAP32[(($21)>>2)];HEAP32[((($20)+(4))>>2)]=HEAP32[((($21)+(4))>>2)];
      __label__ = 5; break;
    case 5: 
      __label__ = 6; break;
    case 6: 
      var $24=$agg_result;
      var $25=$pos;
      assert(8 % 1 === 0, 'memcpy given ' + 8 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP32[(($24)>>2)]=HEAP32[(($25)>>2)];HEAP32[((($24)+(4))>>2)]=HEAP32[((($25)+(4))>>2)];
      STACKTOP = __stackBase__;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Page_GetCurrentPos2($page, $pos) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $attr;
      $2=$page;
      $3=$pos;
      var $4=$3;
      var $5=(($4)|0);
      HEAPF32[(($5)>>2)]=0;
      var $6=$3;
      var $7=(($6+4)|0);
      HEAPF32[(($7)>>2)]=0;
      var $8=$2;
      var $9=_HPDF_Page_Validate($8);
      var $10=(($9)|0)!=0;
      if ($10) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=4151;
      __label__ = 7; break;
    case 4: 
      var $13=$2;
      var $14=(($13+44)|0);
      var $15=HEAP32[(($14)>>2)];
      var $16=$15;
      $attr=$16;
      var $17=$attr;
      var $18=(($17+68)|0);
      var $19=HEAPU16[(($18)>>1)];
      var $20=(($19)&65535);
      var $21=$20 & 2;
      var $22=(($21)|0)!=0;
      if ($22) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $24=$3;
      var $25=$attr;
      var $26=(($25+28)|0);
      var $27=$24;
      var $28=$26;
      assert(8 % 1 === 0, 'memcpy given ' + 8 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP32[(($27)>>2)]=HEAP32[(($28)>>2)];HEAP32[((($27)+(4))>>2)]=HEAP32[((($28)+(4))>>2)];
      __label__ = 6; break;
    case 6: 
      $1=0;
      __label__ = 7; break;
    case 7: 
      var $31=$1;
      ;
      return $31;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Page_GetCurrentTextPos($agg_result, $page) {
  var __stackBase__  = STACKTOP; STACKTOP += 8; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $pos=__stackBase__;
      var $attr;
      $1=$page;
      var $2=$pos;
      HEAP32[(($2)>>2)]=0; HEAP32[((($2)+(4))>>2)]=0;
      var $3=$1;
      var $4=_HPDF_Page_Validate($3);
      var $5=(($4)|0)!=0;
      if ($5) { __label__ = 3; break; } else { __label__ = 6; break; }
    case 3: 
      var $7=$1;
      var $8=(($7+44)|0);
      var $9=HEAP32[(($8)>>2)];
      var $10=$9;
      $attr=$10;
      var $11=$attr;
      var $12=(($11+68)|0);
      var $13=HEAPU16[(($12)>>1)];
      var $14=(($13)&65535);
      var $15=$14 & 4;
      var $16=(($15)|0)!=0;
      if ($16) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      var $18=$attr;
      var $19=(($18+36)|0);
      var $20=$pos;
      var $21=$19;
      assert(8 % 1 === 0, 'memcpy given ' + 8 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP32[(($20)>>2)]=HEAP32[(($21)>>2)];HEAP32[((($20)+(4))>>2)]=HEAP32[((($21)+(4))>>2)];
      __label__ = 5; break;
    case 5: 
      __label__ = 6; break;
    case 6: 
      var $24=$agg_result;
      var $25=$pos;
      assert(8 % 1 === 0, 'memcpy given ' + 8 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP32[(($24)>>2)]=HEAP32[(($25)>>2)];HEAP32[((($24)+(4))>>2)]=HEAP32[((($25)+(4))>>2)];
      STACKTOP = __stackBase__;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Page_GetCurrentTextPos2($page, $pos) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $attr;
      $2=$page;
      $3=$pos;
      var $4=$3;
      var $5=(($4)|0);
      HEAPF32[(($5)>>2)]=0;
      var $6=$3;
      var $7=(($6+4)|0);
      HEAPF32[(($7)>>2)]=0;
      var $8=$2;
      var $9=_HPDF_Page_Validate($8);
      var $10=(($9)|0)!=0;
      if ($10) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=4151;
      __label__ = 7; break;
    case 4: 
      var $13=$2;
      var $14=(($13+44)|0);
      var $15=HEAP32[(($14)>>2)];
      var $16=$15;
      $attr=$16;
      var $17=$attr;
      var $18=(($17+68)|0);
      var $19=HEAPU16[(($18)>>1)];
      var $20=(($19)&65535);
      var $21=$20 & 4;
      var $22=(($21)|0)!=0;
      if ($22) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $24=$3;
      var $25=$attr;
      var $26=(($25+36)|0);
      var $27=$24;
      var $28=$26;
      assert(8 % 1 === 0, 'memcpy given ' + 8 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP32[(($27)>>2)]=HEAP32[(($28)>>2)];HEAP32[((($27)+(4))>>2)]=HEAP32[((($28)+(4))>>2)];
      __label__ = 6; break;
    case 6: 
      $1=0;
      __label__ = 7; break;
    case 7: 
      var $31=$1;
      ;
      return $31;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Page_SetBoxValue($page, $name, $index, $value) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $5;
      var $r;
      var $array;
      $2=$page;
      $3=$name;
      $4=$index;
      $5=$value;
      var $6=$2;
      var $7=_HPDF_Page_Validate($6);
      var $8=(($7)|0)!=0;
      if ($8) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=4151;
      __label__ = 9; break;
    case 4: 
      var $11=$2;
      var $12=$3;
      var $13=_HPDF_Page_GetInheritableItem($11, $12, 16);
      var $14=$13;
      $array=$14;
      var $15=$array;
      var $16=(($15)|0)!=0;
      if ($16) { __label__ = 6; break; } else { __label__ = 5; break; }
    case 5: 
      var $18=$2;
      var $19=(($18+12)|0);
      var $20=HEAP32[(($19)>>2)];
      var $21=_HPDF_SetError($20, 4170, 0);
      $1=$21;
      __label__ = 9; break;
    case 6: 
      var $23=$array;
      var $24=$4;
      var $25=_HPDF_Array_GetItem($23, $24, 5);
      var $26=$25;
      $r=$26;
      var $27=$r;
      var $28=(($27)|0)!=0;
      if ($28) { __label__ = 8; break; } else { __label__ = 7; break; }
    case 7: 
      var $30=$2;
      var $31=(($30+12)|0);
      var $32=HEAP32[(($31)>>2)];
      var $33=_HPDF_SetError($32, 4178, 0);
      $1=$33;
      __label__ = 9; break;
    case 8: 
      var $35=$5;
      var $36=$r;
      var $37=(($36+12)|0);
      HEAPF32[(($37)>>2)]=$35;
      $1=0;
      __label__ = 9; break;
    case 9: 
      var $39=$1;
      ;
      return $39;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Page_SetBoxValue["X"]=1;

function _HPDF_Page_SetRotate($page, $angle) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $n;
      var $ret;
      $2=$page;
      $3=$angle;
      $ret=0;
      var $4=$2;
      var $5=_HPDF_Page_Validate($4);
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=4151;
      __label__ = 10; break;
    case 4: 
      var $9=$3;
      var $10=(($9)&65535);
      var $11=((($10)|0))%(90);
      var $12=(($11)|0)!=0;
      if ($12) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $14=$2;
      var $15=(($14+12)|0);
      var $16=HEAP32[(($15)>>2)];
      var $17=$3;
      var $18=(($17)&65535);
      var $19=_HPDF_RaiseError($16, 4179, $18);
      $1=$19;
      __label__ = 10; break;
    case 6: 
      var $21=$2;
      var $22=_HPDF_Page_GetInheritableItem($21, ((STRING_TABLE.__str151638)|0), 4);
      var $23=$22;
      $n=$23;
      var $24=$n;
      var $25=(($24)|0)!=0;
      if ($25) { __label__ = 8; break; } else { __label__ = 7; break; }
    case 7: 
      var $27=$2;
      var $28=$3;
      var $29=(($28)&65535);
      var $30=_HPDF_Dict_AddNumber($27, ((STRING_TABLE.__str151638)|0), $29);
      $ret=$30;
      __label__ = 9; break;
    case 8: 
      var $32=$3;
      var $33=(($32)&65535);
      var $34=$n;
      var $35=(($34+8)|0);
      HEAP32[(($35)>>2)]=$33;
      __label__ = 9; break;
    case 9: 
      var $37=$ret;
      $1=$37;
      __label__ = 10; break;
    case 10: 
      var $39=$1;
      ;
      return $39;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Page_SetRotate["X"]=1;

function _HPDF_Page_SetZoom($page, $zoom) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $ret;
      $2=$page;
      $3=$zoom;
      $ret=0;
      var $4=$2;
      var $5=_HPDF_Page_Validate($4);
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=4151;
      __label__ = 8; break;
    case 4: 
      var $9=$3;
      var $10=$9;
      var $11=$10 < 0.08;
      if ($11) { __label__ = 6; break; } else { __label__ = 5; break; }
    case 5: 
      var $13=$3;
      var $14=$13 > 32;
      if ($14) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      var $16=$2;
      var $17=(($16+12)|0);
      var $18=HEAP32[(($17)>>2)];
      var $19=_HPDF_RaiseError($18, 4153, 0);
      $1=$19;
      __label__ = 8; break;
    case 7: 
      var $21=$2;
      var $22=$3;
      var $23=_HPDF_Dict_AddReal($21, ((STRING_TABLE.__str161639)|0), $22);
      $ret=$23;
      var $24=$ret;
      $1=$24;
      __label__ = 8; break;
    case 8: 
      var $26=$1;
      ;
      return $26;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Page_SetWidth($page, $value) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      $2=$page;
      $3=$value;
      var $4=$3;
      var $5=$4 < 3;
      if ($5) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      var $7=$3;
      var $8=$7 > 14400;
      if ($8) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      var $10=$2;
      var $11=(($10+12)|0);
      var $12=HEAP32[(($11)>>2)];
      var $13=_HPDF_RaiseError($12, 4180, 0);
      $1=$13;
      __label__ = 8; break;
    case 5: 
      var $15=$2;
      var $16=$3;
      var $17=_HPDF_Page_SetBoxValue($15, ((STRING_TABLE.__str61629)|0), 2, $16);
      var $18=(($17)|0)!=0;
      if ($18) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      var $20=$2;
      var $21=(($20+12)|0);
      var $22=HEAP32[(($21)>>2)];
      var $23=_HPDF_CheckError($22);
      $1=$23;
      __label__ = 8; break;
    case 7: 
      $1=0;
      __label__ = 8; break;
    case 8: 
      var $26=$1;
      ;
      return $26;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Page_SetHeight($page, $value) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      $2=$page;
      $3=$value;
      var $4=$3;
      var $5=$4 < 3;
      if ($5) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      var $7=$3;
      var $8=$7 > 14400;
      if ($8) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      var $10=$2;
      var $11=(($10+12)|0);
      var $12=HEAP32[(($11)>>2)];
      var $13=_HPDF_RaiseError($12, 4180, 0);
      $1=$13;
      __label__ = 8; break;
    case 5: 
      var $15=$2;
      var $16=$3;
      var $17=_HPDF_Page_SetBoxValue($15, ((STRING_TABLE.__str61629)|0), 3, $16);
      var $18=(($17)|0)!=0;
      if ($18) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      var $20=$2;
      var $21=(($20+12)|0);
      var $22=HEAP32[(($21)>>2)];
      var $23=_HPDF_CheckError($22);
      $1=$23;
      __label__ = 8; break;
    case 7: 
      $1=0;
      __label__ = 8; break;
    case 8: 
      var $26=$1;
      ;
      return $26;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Page_SetFilter($page, $filter) {
  ;
  var __label__;

  var $1;
  var $2;
  var $attr;
  $1=$page;
  $2=$filter;
  var $3=$1;
  var $4=(($3+44)|0);
  var $5=HEAP32[(($4)>>2)];
  var $6=$5;
  $attr=$6;
  var $7=$2;
  var $8=$attr;
  var $9=(($8+72)|0);
  var $10=HEAP32[(($9)>>2)];
  var $11=(($10+40)|0);
  HEAP32[(($11)>>2)]=$7;
  ;
  return;
}


function _HPDF_Page_SetSize($page, $size, $direction) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $ret;
      $2=$page;
      $3=$size;
      $4=$direction;
      $ret=0;
      var $5=$2;
      var $6=_HPDF_Page_Validate($5);
      var $7=(($6)|0)!=0;
      if ($7) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=4151;
      __label__ = 16; break;
    case 4: 
      var $10=$3;
      var $11=(($10)>>>0) < 0;
      if ($11) { __label__ = 6; break; } else { __label__ = 5; break; }
    case 5: 
      var $13=$3;
      var $14=(($13)>>>0) > 12;
      if ($14) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      var $16=$2;
      var $17=(($16+12)|0);
      var $18=HEAP32[(($17)>>2)];
      var $19=$4;
      var $20=_HPDF_RaiseError($18, 4180, $19);
      $1=$20;
      __label__ = 16; break;
    case 7: 
      var $22=$4;
      var $23=(($22)|0)==1;
      if ($23) { __label__ = 8; break; } else { __label__ = 9; break; }
    case 8: 
      var $25=$2;
      var $26=$3;
      var $27=((_HPDF_PREDEFINED_PAGE_SIZES+($26<<3))|0);
      var $28=(($27)|0);
      var $29=HEAPF32[(($28)>>2)];
      var $30=_HPDF_Page_SetHeight($25, $29);
      var $31=$ret;
      var $32=((($31)+($30))|0);
      $ret=$32;
      var $33=$2;
      var $34=$3;
      var $35=((_HPDF_PREDEFINED_PAGE_SIZES+($34<<3))|0);
      var $36=(($35+4)|0);
      var $37=HEAPF32[(($36)>>2)];
      var $38=_HPDF_Page_SetWidth($33, $37);
      var $39=$ret;
      var $40=((($39)+($38))|0);
      $ret=$40;
      __label__ = 13; break;
    case 9: 
      var $42=$4;
      var $43=(($42)|0)==0;
      if ($43) { __label__ = 10; break; } else { __label__ = 11; break; }
    case 10: 
      var $45=$2;
      var $46=$3;
      var $47=((_HPDF_PREDEFINED_PAGE_SIZES+($46<<3))|0);
      var $48=(($47+4)|0);
      var $49=HEAPF32[(($48)>>2)];
      var $50=_HPDF_Page_SetHeight($45, $49);
      var $51=$ret;
      var $52=((($51)+($50))|0);
      $ret=$52;
      var $53=$2;
      var $54=$3;
      var $55=((_HPDF_PREDEFINED_PAGE_SIZES+($54<<3))|0);
      var $56=(($55)|0);
      var $57=HEAPF32[(($56)>>2)];
      var $58=_HPDF_Page_SetWidth($53, $57);
      var $59=$ret;
      var $60=((($59)+($58))|0);
      $ret=$60;
      __label__ = 12; break;
    case 11: 
      var $62=$2;
      var $63=(($62+12)|0);
      var $64=HEAP32[(($63)>>2)];
      var $65=$4;
      var $66=_HPDF_SetError($64, 4212, $65);
      $ret=$66;
      __label__ = 12; break;
    case 12: 
      __label__ = 13; break;
    case 13: 
      var $69=$ret;
      var $70=(($69)|0)!=0;
      if ($70) { __label__ = 14; break; } else { __label__ = 15; break; }
    case 14: 
      var $72=$2;
      var $73=(($72+12)|0);
      var $74=HEAP32[(($73)>>2)];
      var $75=_HPDF_CheckError($74);
      $1=$75;
      __label__ = 16; break;
    case 15: 
      $1=0;
      __label__ = 16; break;
    case 16: 
      var $78=$1;
      ;
      return $78;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Page_SetSize["X"]=1;

function _HPDF_Page_CreateDestination($page) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $attr;
      var $dst;
      $2=$page;
      var $3=$2;
      var $4=_HPDF_Page_Validate($3);
      var $5=(($4)|0)!=0;
      if ($5) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=0;
      __label__ = 7; break;
    case 4: 
      var $8=$2;
      var $9=(($8+44)|0);
      var $10=HEAP32[(($9)>>2)];
      var $11=$10;
      $attr=$11;
      var $12=$2;
      var $13=(($12+8)|0);
      var $14=HEAP32[(($13)>>2)];
      var $15=$2;
      var $16=$attr;
      var $17=(($16+80)|0);
      var $18=HEAP32[(($17)>>2)];
      var $19=_HPDF_Destination_New($14, $15, $18);
      $dst=$19;
      var $20=$dst;
      var $21=(($20)|0)!=0;
      if ($21) { __label__ = 6; break; } else { __label__ = 5; break; }
    case 5: 
      var $23=$2;
      var $24=(($23+12)|0);
      var $25=HEAP32[(($24)>>2)];
      var $26=_HPDF_CheckError($25);
      __label__ = 6; break;
    case 6: 
      var $28=$dst;
      $1=$28;
      __label__ = 7; break;
    case 7: 
      var $30=$1;
      ;
      return $30;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Page_Create3DAnnot($page, $rect_0, $rect_1, $rect_2, $rect_3, $u3d) {
  var __stackBase__  = STACKTOP; STACKTOP += 16; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $rect=__stackBase__;
      var $3;
      var $attr;
      var $annot;
      $2=$page;
      var $4=(($rect)|0);
      HEAPF32[(($4)>>2)]=$rect_0;
      var $5=(($rect+4)|0);
      HEAPF32[(($5)>>2)]=$rect_1;
      var $6=(($rect+8)|0);
      HEAPF32[(($6)>>2)]=$rect_2;
      var $7=(($rect+12)|0);
      HEAPF32[(($7)>>2)]=$rect_3;
      $3=$u3d;
      var $8=$2;
      var $9=_HPDF_Page_Validate($8);
      var $10=(($9)|0)!=0;
      if ($10) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=0;
      __label__ = 10; break;
    case 4: 
      var $13=$2;
      var $14=(($13+44)|0);
      var $15=HEAP32[(($14)>>2)];
      var $16=$15;
      $attr=$16;
      var $17=$2;
      var $18=(($17+8)|0);
      var $19=HEAP32[(($18)>>2)];
      var $20=$attr;
      var $21=(($20+80)|0);
      var $22=HEAP32[(($21)>>2)];
      var $23=$3;
      var $24=(($rect)|0);
      var $25=HEAPF32[(($24)>>2)];
      var $26=(($rect+4)|0);
      var $27=HEAPF32[(($26)>>2)];
      var $28=(($rect+8)|0);
      var $29=HEAPF32[(($28)>>2)];
      var $30=(($rect+12)|0);
      var $31=HEAPF32[(($30)>>2)];
      var $32=_HPDF_3DAnnot_New($19, $22, $25, $27, $29, $31, $23);
      $annot=$32;
      var $33=$annot;
      var $34=(($33)|0)!=0;
      if ($34) { __label__ = 5; break; } else { __label__ = 8; break; }
    case 5: 
      var $36=$2;
      var $37=$annot;
      var $38=_AddAnnotation($36, $37);
      var $39=(($38)|0)!=0;
      if ($39) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      var $41=$2;
      var $42=(($41+12)|0);
      var $43=HEAP32[(($42)>>2)];
      var $44=_HPDF_CheckError($43);
      $annot=0;
      __label__ = 7; break;
    case 7: 
      __label__ = 9; break;
    case 8: 
      var $47=$2;
      var $48=(($47+12)|0);
      var $49=HEAP32[(($48)>>2)];
      var $50=_HPDF_CheckError($49);
      __label__ = 9; break;
    case 9: 
      var $52=$annot;
      $1=$52;
      __label__ = 10; break;
    case 10: 
      var $54=$1;
      STACKTOP = __stackBase__;
      return $54;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Page_Create3DAnnot["X"]=1;

function _AddAnnotation($page, $annot) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $array;
      var $ret;
      $2=$page;
      $3=$annot;
      var $4=$2;
      var $5=_HPDF_Dict_GetItem($4, ((STRING_TABLE.__str171640)|0), 16);
      var $6=$5;
      $array=$6;
      var $7=$array;
      var $8=(($7)|0)!=0;
      if ($8) { __label__ = 8; break; } else { __label__ = 3; break; }
    case 3: 
      var $10=$2;
      var $11=(($10+8)|0);
      var $12=HEAP32[(($11)>>2)];
      var $13=_HPDF_Array_New($12);
      $array=$13;
      var $14=$array;
      var $15=(($14)|0)!=0;
      if ($15) { __label__ = 5; break; } else { __label__ = 4; break; }
    case 4: 
      var $17=$2;
      var $18=(($17+12)|0);
      var $19=HEAP32[(($18)>>2)];
      var $20=_HPDF_Error_GetCode($19);
      $1=$20;
      __label__ = 9; break;
    case 5: 
      var $22=$2;
      var $23=$array;
      var $24=$23;
      var $25=_HPDF_Dict_Add($22, ((STRING_TABLE.__str171640)|0), $24);
      $ret=$25;
      var $26=$ret;
      var $27=(($26)|0)!=0;
      if ($27) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      var $29=$ret;
      $1=$29;
      __label__ = 9; break;
    case 7: 
      __label__ = 8; break;
    case 8: 
      var $32=$array;
      var $33=$3;
      var $34=$33;
      var $35=_HPDF_Array_Add($32, $34);
      $1=$35;
      __label__ = 9; break;
    case 9: 
      var $37=$1;
      ;
      return $37;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Page_CreateTextAnnot($page, $rect_0, $rect_1, $rect_2, $rect_3, $text, $encoder) {
  var __stackBase__  = STACKTOP; STACKTOP += 16; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $rect=__stackBase__;
      var $3;
      var $4;
      var $attr;
      var $annot;
      $2=$page;
      var $5=(($rect)|0);
      HEAPF32[(($5)>>2)]=$rect_0;
      var $6=(($rect+4)|0);
      HEAPF32[(($6)>>2)]=$rect_1;
      var $7=(($rect+8)|0);
      HEAPF32[(($7)>>2)]=$rect_2;
      var $8=(($rect+12)|0);
      HEAPF32[(($8)>>2)]=$rect_3;
      $3=$text;
      $4=$encoder;
      var $9=$2;
      var $10=_HPDF_Page_Validate($9);
      var $11=(($10)|0)!=0;
      if ($11) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=0;
      __label__ = 13; break;
    case 4: 
      var $14=$2;
      var $15=(($14+44)|0);
      var $16=HEAP32[(($15)>>2)];
      var $17=$16;
      $attr=$17;
      var $18=$4;
      var $19=(($18)|0)!=0;
      if ($19) { __label__ = 5; break; } else { __label__ = 7; break; }
    case 5: 
      var $21=$4;
      var $22=_HPDF_Encoder_Validate($21);
      var $23=(($22)|0)!=0;
      if ($23) { __label__ = 7; break; } else { __label__ = 6; break; }
    case 6: 
      var $25=$2;
      var $26=(($25+12)|0);
      var $27=HEAP32[(($26)>>2)];
      var $28=_HPDF_RaiseError($27, 4135, 0);
      $1=0;
      __label__ = 13; break;
    case 7: 
      var $30=$2;
      var $31=(($30+8)|0);
      var $32=HEAP32[(($31)>>2)];
      var $33=$attr;
      var $34=(($33+80)|0);
      var $35=HEAP32[(($34)>>2)];
      var $36=$3;
      var $37=$4;
      var $38=(($rect)|0);
      var $39=HEAPF32[(($38)>>2)];
      var $40=(($rect+4)|0);
      var $41=HEAPF32[(($40)>>2)];
      var $42=(($rect+8)|0);
      var $43=HEAPF32[(($42)>>2)];
      var $44=(($rect+12)|0);
      var $45=HEAPF32[(($44)>>2)];
      var $46=_HPDF_TextAnnot_New($32, $35, $39, $41, $43, $45, $36, $37);
      $annot=$46;
      var $47=$annot;
      var $48=(($47)|0)!=0;
      if ($48) { __label__ = 8; break; } else { __label__ = 11; break; }
    case 8: 
      var $50=$2;
      var $51=$annot;
      var $52=_AddAnnotation($50, $51);
      var $53=(($52)|0)!=0;
      if ($53) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      var $55=$2;
      var $56=(($55+12)|0);
      var $57=HEAP32[(($56)>>2)];
      var $58=_HPDF_CheckError($57);
      $annot=0;
      __label__ = 10; break;
    case 10: 
      __label__ = 12; break;
    case 11: 
      var $61=$2;
      var $62=(($61+12)|0);
      var $63=HEAP32[(($62)>>2)];
      var $64=_HPDF_CheckError($63);
      __label__ = 12; break;
    case 12: 
      var $66=$annot;
      $1=$66;
      __label__ = 13; break;
    case 13: 
      var $68=$1;
      STACKTOP = __stackBase__;
      return $68;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Page_CreateTextAnnot["X"]=1;

function _HPDF_Page_CreateLinkAnnot($page, $rect_0, $rect_1, $rect_2, $rect_3, $dst) {
  var __stackBase__  = STACKTOP; STACKTOP += 16; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $rect=__stackBase__;
      var $3;
      var $attr;
      var $annot;
      $2=$page;
      var $4=(($rect)|0);
      HEAPF32[(($4)>>2)]=$rect_0;
      var $5=(($rect+4)|0);
      HEAPF32[(($5)>>2)]=$rect_1;
      var $6=(($rect+8)|0);
      HEAPF32[(($6)>>2)]=$rect_2;
      var $7=(($rect+12)|0);
      HEAPF32[(($7)>>2)]=$rect_3;
      $3=$dst;
      var $8=$2;
      var $9=_HPDF_Page_Validate($8);
      var $10=(($9)|0)!=0;
      if ($10) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=0;
      __label__ = 12; break;
    case 4: 
      var $13=$2;
      var $14=(($13+44)|0);
      var $15=HEAP32[(($14)>>2)];
      var $16=$15;
      $attr=$16;
      var $17=$3;
      var $18=_HPDF_Destination_Validate($17);
      var $19=(($18)|0)!=0;
      if ($19) { __label__ = 6; break; } else { __label__ = 5; break; }
    case 5: 
      var $21=$2;
      var $22=(($21+12)|0);
      var $23=HEAP32[(($22)>>2)];
      var $24=_HPDF_RaiseError($23, 4131, 0);
      $1=0;
      __label__ = 12; break;
    case 6: 
      var $26=$2;
      var $27=(($26+8)|0);
      var $28=HEAP32[(($27)>>2)];
      var $29=$attr;
      var $30=(($29+80)|0);
      var $31=HEAP32[(($30)>>2)];
      var $32=$3;
      var $33=(($rect)|0);
      var $34=HEAPF32[(($33)>>2)];
      var $35=(($rect+4)|0);
      var $36=HEAPF32[(($35)>>2)];
      var $37=(($rect+8)|0);
      var $38=HEAPF32[(($37)>>2)];
      var $39=(($rect+12)|0);
      var $40=HEAPF32[(($39)>>2)];
      var $41=_HPDF_LinkAnnot_New($28, $31, $34, $36, $38, $40, $32);
      $annot=$41;
      var $42=$annot;
      var $43=(($42)|0)!=0;
      if ($43) { __label__ = 7; break; } else { __label__ = 10; break; }
    case 7: 
      var $45=$2;
      var $46=$annot;
      var $47=_AddAnnotation($45, $46);
      var $48=(($47)|0)!=0;
      if ($48) { __label__ = 8; break; } else { __label__ = 9; break; }
    case 8: 
      var $50=$2;
      var $51=(($50+12)|0);
      var $52=HEAP32[(($51)>>2)];
      var $53=_HPDF_CheckError($52);
      $annot=0;
      __label__ = 9; break;
    case 9: 
      __label__ = 11; break;
    case 10: 
      var $56=$2;
      var $57=(($56+12)|0);
      var $58=HEAP32[(($57)>>2)];
      var $59=_HPDF_CheckError($58);
      __label__ = 11; break;
    case 11: 
      var $61=$annot;
      $1=$61;
      __label__ = 12; break;
    case 12: 
      var $63=$1;
      STACKTOP = __stackBase__;
      return $63;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Page_CreateLinkAnnot["X"]=1;

function _HPDF_Page_CreateURILinkAnnot($page, $rect_0, $rect_1, $rect_2, $rect_3, $uri) {
  var __stackBase__  = STACKTOP; STACKTOP += 16; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $rect=__stackBase__;
      var $3;
      var $attr;
      var $annot;
      $2=$page;
      var $4=(($rect)|0);
      HEAPF32[(($4)>>2)]=$rect_0;
      var $5=(($rect+4)|0);
      HEAPF32[(($5)>>2)]=$rect_1;
      var $6=(($rect+8)|0);
      HEAPF32[(($6)>>2)]=$rect_2;
      var $7=(($rect+12)|0);
      HEAPF32[(($7)>>2)]=$rect_3;
      $3=$uri;
      var $8=$2;
      var $9=_HPDF_Page_Validate($8);
      var $10=(($9)|0)!=0;
      if ($10) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=0;
      __label__ = 12; break;
    case 4: 
      var $13=$2;
      var $14=(($13+44)|0);
      var $15=HEAP32[(($14)>>2)];
      var $16=$15;
      $attr=$16;
      var $17=$3;
      var $18=_HPDF_StrLen($17, 65535);
      var $19=(($18)>>>0) <= 0;
      if ($19) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $21=$2;
      var $22=(($21+12)|0);
      var $23=HEAP32[(($22)>>2)];
      var $24=_HPDF_RaiseError($23, 4200, 0);
      $1=0;
      __label__ = 12; break;
    case 6: 
      var $26=$2;
      var $27=(($26+8)|0);
      var $28=HEAP32[(($27)>>2)];
      var $29=$attr;
      var $30=(($29+80)|0);
      var $31=HEAP32[(($30)>>2)];
      var $32=$3;
      var $33=(($rect)|0);
      var $34=HEAPF32[(($33)>>2)];
      var $35=(($rect+4)|0);
      var $36=HEAPF32[(($35)>>2)];
      var $37=(($rect+8)|0);
      var $38=HEAPF32[(($37)>>2)];
      var $39=(($rect+12)|0);
      var $40=HEAPF32[(($39)>>2)];
      var $41=_HPDF_URILinkAnnot_New($28, $31, $34, $36, $38, $40, $32);
      $annot=$41;
      var $42=$annot;
      var $43=(($42)|0)!=0;
      if ($43) { __label__ = 7; break; } else { __label__ = 10; break; }
    case 7: 
      var $45=$2;
      var $46=$annot;
      var $47=_AddAnnotation($45, $46);
      var $48=(($47)|0)!=0;
      if ($48) { __label__ = 8; break; } else { __label__ = 9; break; }
    case 8: 
      var $50=$2;
      var $51=(($50+12)|0);
      var $52=HEAP32[(($51)>>2)];
      var $53=_HPDF_CheckError($52);
      $annot=0;
      __label__ = 9; break;
    case 9: 
      __label__ = 11; break;
    case 10: 
      var $56=$2;
      var $57=(($56+12)|0);
      var $58=HEAP32[(($57)>>2)];
      var $59=_HPDF_CheckError($58);
      __label__ = 11; break;
    case 11: 
      var $61=$annot;
      $1=$61;
      __label__ = 12; break;
    case 12: 
      var $63=$1;
      STACKTOP = __stackBase__;
      return $63;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Page_CreateURILinkAnnot["X"]=1;

function _GetPageCount($pages) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $i;
      var $count;
      var $kids;
      var $obj;
      var $header;
      $2=$pages;
      $count=0;
      var $3=$2;
      var $4=_HPDF_Dict_GetItem($3, ((STRING_TABLE.__str21625)|0), 16);
      var $5=$4;
      $kids=$5;
      var $6=$kids;
      var $7=(($6)|0)!=0;
      if ($7) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=0;
      __label__ = 14; break;
    case 4: 
      $i=0;
      __label__ = 5; break;
    case 5: 
      var $11=$i;
      var $12=$kids;
      var $13=(($12+16)|0);
      var $14=HEAP32[(($13)>>2)];
      var $15=(($14+16)|0);
      var $16=HEAPU32[(($15)>>2)];
      var $17=(($11)>>>0) < (($16)>>>0);
      if ($17) { __label__ = 6; break; } else { __label__ = 13; break; }
    case 6: 
      var $19=$kids;
      var $20=$i;
      var $21=_HPDF_Array_GetItem($19, $20, 17);
      $obj=$21;
      var $22=$obj;
      var $23=$22;
      $header=$23;
      var $24=$header;
      var $25=(($24+6)|0);
      var $26=HEAPU16[(($25)>>1)];
      var $27=(($26)&65535);
      var $28=(($27)|0)==785;
      if ($28) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $30=$obj;
      var $31=$30;
      var $32=_GetPageCount($31);
      var $33=$count;
      var $34=((($33)+($32))|0);
      $count=$34;
      __label__ = 11; break;
    case 8: 
      var $36=$header;
      var $37=(($36+6)|0);
      var $38=HEAPU16[(($37)>>1)];
      var $39=(($38)&65535);
      var $40=(($39)|0)==1041;
      if ($40) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      var $42=$count;
      var $43=((($42)+(1))|0);
      $count=$43;
      __label__ = 10; break;
    case 10: 
      __label__ = 11; break;
    case 11: 
      __label__ = 12; break;
    case 12: 
      var $47=$i;
      var $48=((($47)+(1))|0);
      $i=$48;
      __label__ = 5; break;
    case 13: 
      var $50=$count;
      $1=$50;
      __label__ = 14; break;
    case 14: 
      var $52=$1;
      ;
      return $52;
    default: assert(0, "bad label: " + __label__);
  }
}
_GetPageCount["X"]=1;

function _HPDF_Real_New($mmgr, $value) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $obj;
      $1=$mmgr;
      $2=$value;
      var $3=$1;
      var $4=_HPDF_GetMem($3, 16);
      var $5=$4;
      $obj=$5;
      var $6=$obj;
      var $7=(($6)|0)!=0;
      if ($7) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $9=$obj;
      var $10=(($9)|0);
      var $11=$10;
      var $12=_HPDF_MemSet($11, 0, 8);
      var $13=$obj;
      var $14=(($13)|0);
      var $15=(($14+6)|0);
      HEAP16[(($15)>>1)]=5;
      var $16=$1;
      var $17=(($16)|0);
      var $18=HEAP32[(($17)>>2)];
      var $19=$obj;
      var $20=(($19+8)|0);
      HEAP32[(($20)>>2)]=$18;
      var $21=$obj;
      var $22=$2;
      var $23=_HPDF_Real_SetValue($21, $22);
      __label__ = 4; break;
    case 4: 
      var $25=$obj;
      ;
      return $25;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Real_SetValue($obj, $value) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $ret;
      $2=$obj;
      $3=$value;
      $ret=0;
      var $4=$3;
      var $5=$4 > 32767;
      if ($5) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $7=$2;
      var $8=(($7+8)|0);
      var $9=HEAP32[(($8)>>2)];
      var $10=_HPDF_SetError($9, 4183, 0);
      $1=$10;
      __label__ = 7; break;
    case 4: 
      var $12=$3;
      var $13=$12 < -32767;
      if ($13) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $15=$2;
      var $16=(($15+8)|0);
      var $17=HEAP32[(($16)>>2)];
      var $18=_HPDF_SetError($17, 4183, 0);
      $1=$18;
      __label__ = 7; break;
    case 6: 
      var $20=$3;
      var $21=$2;
      var $22=(($21+12)|0);
      HEAPF32[(($22)>>2)]=$20;
      var $23=$ret;
      $1=$23;
      __label__ = 7; break;
    case 7: 
      var $25=$1;
      ;
      return $25;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Real_Write($obj, $stream) {
  ;
  var __label__;

  var $1;
  var $2;
  $1=$obj;
  $2=$stream;
  var $3=$2;
  var $4=$1;
  var $5=(($4+12)|0);
  var $6=HEAPF32[(($5)>>2)];
  var $7=_HPDF_Stream_WriteReal($3, $6);
  ;
  return $7;
}


function _HPDF_Stream_Read($stream, $ptr, $size) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      $2=$stream;
      $3=$ptr;
      $4=$size;
      var $5=$2;
      var $6=(($5+24)|0);
      var $7=$6;
      var $8=HEAP32[(($7)>>2)];
      var $9=(($8)|0)!=0;
      if ($9) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      var $11=$2;
      var $12=(($11+12)|0);
      var $13=HEAP32[(($12)>>2)];
      var $14=_HPDF_SetError($13, 4149, 0);
      $1=$14;
      __label__ = 5; break;
    case 4: 
      var $16=$2;
      var $17=(($16+24)|0);
      var $18=$17;
      var $19=HEAP32[(($18)>>2)];
      var $20=$2;
      var $21=$3;
      var $22=$4;
      var $23=FUNCTION_TABLE[$19]($20, $21, $22);
      $1=$23;
      __label__ = 5; break;
    case 5: 
      var $25=$1;
      ;
      return $25;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Stream_ReadLn($stream, $s, $size) {
  var __stackBase__  = STACKTOP; STACKTOP += 4100; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $buf=__stackBase__;
      var $r_size;
      var $read_size=(__stackBase__)+(4096);
      var $pbuf;
      var $ret;
      $2=$stream;
      $3=$s;
      $4=$size;
      var $5=$4;
      var $6=HEAP32[(($5)>>2)];
      $r_size=$6;
      HEAP32[(($read_size)>>2)]=4096;
      var $7=$2;
      var $8=(($7)|0)!=0;
      if ($8) { __label__ = 3; break; } else { __label__ = 5; break; }
    case 3: 
      var $10=$3;
      var $11=(($10)|0)!=0;
      if ($11) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      var $13=$4;
      var $14=HEAP32[(($13)>>2)];
      var $15=(($14)|0)==0;
      if ($15) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $17=$2;
      var $18=(($17+12)|0);
      var $19=HEAP32[(($18)>>2)];
      var $20=_HPDF_SetError($19, 4153, 0);
      $1=$20;
      __label__ = 36; break;
    case 6: 
      var $22=$2;
      var $23=(($22+28)|0);
      var $24=HEAP32[(($23)>>2)];
      var $25=(($24)|0)!=0;
      if ($25) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $27=$2;
      var $28=(($27+24)|0);
      var $29=$28;
      var $30=HEAP32[(($29)>>2)];
      var $31=(($30)|0)!=0;
      if ($31) { __label__ = 9; break; } else { __label__ = 8; break; }
    case 8: 
      var $33=$2;
      var $34=(($33+12)|0);
      var $35=HEAP32[(($34)>>2)];
      var $36=_HPDF_SetError($35, 4149, 0);
      $1=$36;
      __label__ = 36; break;
    case 9: 
      var $38=$r_size;
      var $39=(($38)>>>0) < 4096;
      if ($39) { __label__ = 10; break; } else { __label__ = 11; break; }
    case 10: 
      var $41=$r_size;
      HEAP32[(($read_size)>>2)]=$41;
      __label__ = 11; break;
    case 11: 
      var $43=$4;
      HEAP32[(($43)>>2)]=0;
      __label__ = 12; break;
    case 12: 
      var $45=$r_size;
      var $46=(($45)>>>0) > 1;
      if ($46) { __label__ = 13; break; } else { __label__ = 35; break; }
    case 13: 
      var $48=(($buf)|0);
      $pbuf=$48;
      var $49=$2;
      var $50=(($buf)|0);
      var $51=_HPDF_Stream_Read($49, $50, $read_size);
      $ret=$51;
      var $52=$ret;
      var $53=(($52)|0)!=0;
      if ($53) { __label__ = 14; break; } else { __label__ = 16; break; }
    case 14: 
      var $55=HEAP32[(($read_size)>>2)];
      var $56=(($55)|0)==0;
      if ($56) { __label__ = 15; break; } else { __label__ = 16; break; }
    case 15: 
      var $58=$ret;
      $1=$58;
      __label__ = 36; break;
    case 16: 
      var $60=HEAP32[(($read_size)>>2)];
      var $61=$r_size;
      var $62=((($61)-($60))|0);
      $r_size=$62;
      __label__ = 17; break;
    case 17: 
      var $64=HEAPU32[(($read_size)>>2)];
      var $65=(($64)>>>0) > 0;
      if ($65) { __label__ = 18; break; } else { __label__ = 29; break; }
    case 18: 
      var $67=$pbuf;
      var $68=HEAP8[($67)];
      var $69=(($68 << 24) >> 24);
      var $70=(($69)|0)==10;
      if ($70) { __label__ = 20; break; } else { __label__ = 19; break; }
    case 19: 
      var $72=$pbuf;
      var $73=HEAP8[($72)];
      var $74=(($73 << 24) >> 24);
      var $75=(($74)|0)==13;
      if ($75) { __label__ = 20; break; } else { __label__ = 28; break; }
    case 20: 
      var $77=$3;
      HEAP8[($77)]=0;
      var $78=HEAP32[(($read_size)>>2)];
      var $79=((($78)-(1))|0);
      HEAP32[(($read_size)>>2)]=$79;
      var $80=$pbuf;
      var $81=HEAP8[($80)];
      var $82=(($81 << 24) >> 24);
      var $83=(($82)|0)==13;
      if ($83) { __label__ = 22; break; } else { __label__ = 21; break; }
    case 21: 
      var $85=HEAPU32[(($read_size)>>2)];
      var $86=(($85)>>>0) > 1;
      if ($86) { __label__ = 22; break; } else { __label__ = 25; break; }
    case 22: 
      var $88=$pbuf;
      var $89=(($88+1)|0);
      $pbuf=$89;
      var $90=$pbuf;
      var $91=HEAP8[($90)];
      var $92=(($91 << 24) >> 24);
      var $93=(($92)|0)==10;
      if ($93) { __label__ = 23; break; } else { __label__ = 24; break; }
    case 23: 
      var $95=HEAP32[(($read_size)>>2)];
      var $96=((($95)-(1))|0);
      HEAP32[(($read_size)>>2)]=$96;
      __label__ = 24; break;
    case 24: 
      __label__ = 25; break;
    case 25: 
      var $99=HEAPU32[(($read_size)>>2)];
      var $100=(($99)>>>0) > 0;
      if ($100) { __label__ = 26; break; } else { __label__ = 27; break; }
    case 26: 
      var $102=$2;
      var $103=HEAP32[(($read_size)>>2)];
      var $104=(((-$103))|0);
      var $105=_HPDF_Stream_Seek($102, $104, 1);
      $1=$105;
      __label__ = 36; break;
    case 27: 
      $1=0;
      __label__ = 36; break;
    case 28: 
      var $108=$pbuf;
      var $109=(($108+1)|0);
      $pbuf=$109;
      var $110=HEAP8[($108)];
      var $111=$3;
      var $112=(($111+1)|0);
      $3=$112;
      HEAP8[($111)]=$110;
      var $113=HEAP32[(($read_size)>>2)];
      var $114=((($113)-(1))|0);
      HEAP32[(($read_size)>>2)]=$114;
      var $115=$4;
      var $116=HEAP32[(($115)>>2)];
      var $117=((($116)+(1))|0);
      HEAP32[(($115)>>2)]=$117;
      __label__ = 17; break;
    case 29: 
      var $119=$r_size;
      var $120=(($119)>>>0) < 4096;
      if ($120) { __label__ = 30; break; } else { __label__ = 31; break; }
    case 30: 
      var $122=$r_size;
      HEAP32[(($read_size)>>2)]=$122;
      __label__ = 32; break;
    case 31: 
      HEAP32[(($read_size)>>2)]=4096;
      __label__ = 32; break;
    case 32: 
      var $125=$ret;
      var $126=(($125)|0)==4184;
      if ($126) { __label__ = 33; break; } else { __label__ = 34; break; }
    case 33: 
      $1=4184;
      __label__ = 36; break;
    case 34: 
      __label__ = 12; break;
    case 35: 
      var $130=$3;
      HEAP8[($130)]=0;
      $1=4185;
      __label__ = 36; break;
    case 36: 
      var $132=$1;
      STACKTOP = __stackBase__;
      return $132;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Stream_ReadLn["X"]=1;

function _HPDF_Stream_Seek($stream, $pos, $mode) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      $2=$stream;
      $3=$pos;
      $4=$mode;
      var $5=$2;
      var $6=(($5+28)|0);
      var $7=HEAP32[(($6)>>2)];
      var $8=(($7)|0)!=0;
      if ($8) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      var $10=$2;
      var $11=(($10+12)|0);
      var $12=HEAP32[(($11)>>2)];
      var $13=_HPDF_SetError($12, 4149, 0);
      $1=$13;
      __label__ = 7; break;
    case 4: 
      var $15=$2;
      var $16=(($15+12)|0);
      var $17=HEAP32[(($16)>>2)];
      var $18=_HPDF_Error_GetCode($17);
      var $19=(($18)|0)!=0;
      if ($19) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      $1=4188;
      __label__ = 7; break;
    case 6: 
      var $22=$2;
      var $23=(($22+28)|0);
      var $24=HEAP32[(($23)>>2)];
      var $25=$2;
      var $26=$3;
      var $27=$4;
      var $28=FUNCTION_TABLE[$24]($25, $26, $27);
      $1=$28;
      __label__ = 7; break;
    case 7: 
      var $30=$1;
      ;
      return $30;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Stream_Write($stream, $ptr, $size) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $ret;
      $2=$stream;
      $3=$ptr;
      $4=$size;
      var $5=$2;
      var $6=(($5+20)|0);
      var $7=HEAP32[(($6)>>2)];
      var $8=(($7)|0)!=0;
      if ($8) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      var $10=$2;
      var $11=(($10+12)|0);
      var $12=HEAP32[(($11)>>2)];
      var $13=_HPDF_SetError($12, 4149, 0);
      $1=$13;
      __label__ = 7; break;
    case 4: 
      var $15=$2;
      var $16=(($15+20)|0);
      var $17=HEAP32[(($16)>>2)];
      var $18=$2;
      var $19=$3;
      var $20=$4;
      var $21=FUNCTION_TABLE[$17]($18, $19, $20);
      $ret=$21;
      var $22=$ret;
      var $23=(($22)|0)!=0;
      if ($23) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $25=$ret;
      $1=$25;
      __label__ = 7; break;
    case 6: 
      var $27=$4;
      var $28=$2;
      var $29=(($28+16)|0);
      var $30=HEAP32[(($29)>>2)];
      var $31=((($30)+($27))|0);
      HEAP32[(($29)>>2)]=$31;
      $1=0;
      __label__ = 7; break;
    case 7: 
      var $33=$1;
      ;
      return $33;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Stream_WriteChar($stream, $value) {
  var __stackBase__  = STACKTOP; STACKTOP += 4; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;

  var $1;
  var $2=__stackBase__;
  $1=$stream;
  HEAP8[($2)]=$value;
  var $3=$1;
  var $4=_HPDF_Stream_Write($3, $2, 1);
  STACKTOP = __stackBase__;
  return $4;
}


function _HPDF_Stream_WriteStr($stream, $value) {
  ;
  var __label__;

  var $1;
  var $2;
  var $len;
  $1=$stream;
  $2=$value;
  var $3=$2;
  var $4=_HPDF_StrLen($3, -1);
  $len=$4;
  var $5=$1;
  var $6=$2;
  var $7=$len;
  var $8=_HPDF_Stream_Write($5, $6, $7);
  ;
  return $8;
}


function _HPDF_Stream_WriteInt($stream, $value) {
  var __stackBase__  = STACKTOP; STACKTOP += 12; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;

  var $1;
  var $2;
  var $buf=__stackBase__;
  var $p;
  $1=$stream;
  $2=$value;
  var $3=(($buf)|0);
  var $4=$2;
  var $5=(($buf)|0);
  var $6=(($5+11)|0);
  var $7=_HPDF_IToA($3, $4, $6);
  $p=$7;
  var $8=$1;
  var $9=(($buf)|0);
  var $10=$p;
  var $11=(($buf)|0);
  var $12=$10;
  var $13=$11;
  var $14=((($12)-($13))|0);
  var $15=_HPDF_Stream_Write($8, $9, $14);
  STACKTOP = __stackBase__;
  return $15;
}


function _HPDF_Stream_WriteUInt($stream, $value) {
  ;
  var __label__;

  var $1;
  var $2;
  $1=$stream;
  $2=$value;
  var $3=$1;
  var $4=$2;
  var $5=_HPDF_Stream_WriteInt($3, $4);
  ;
  return $5;
}


function _HPDF_Stream_WriteReal($stream, $value) {
  var __stackBase__  = STACKTOP; STACKTOP += 12; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;

  var $1;
  var $2;
  var $buf=__stackBase__;
  var $p;
  $1=$stream;
  $2=$value;
  var $3=(($buf)|0);
  var $4=$2;
  var $5=(($buf)|0);
  var $6=(($5+11)|0);
  var $7=_HPDF_FToA($3, $4, $6);
  $p=$7;
  var $8=$1;
  var $9=(($buf)|0);
  var $10=$p;
  var $11=(($buf)|0);
  var $12=$10;
  var $13=$11;
  var $14=((($12)-($13))|0);
  var $15=_HPDF_Stream_Write($8, $9, $14);
  STACKTOP = __stackBase__;
  return $15;
}


function _HPDF_Stream_Free($stream) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      $1=$stream;
      var $2=$1;
      var $3=(($2)|0)!=0;
      if ($3) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      __label__ = 7; break;
    case 4: 
      var $6=$1;
      var $7=(($6+32)|0);
      var $8=HEAP32[(($7)>>2)];
      var $9=(($8)|0)!=0;
      if ($9) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $11=$1;
      var $12=(($11+32)|0);
      var $13=HEAP32[(($12)>>2)];
      var $14=$1;
      FUNCTION_TABLE[$13]($14);
      __label__ = 6; break;
    case 6: 
      var $16=$1;
      var $17=(($16)|0);
      HEAP32[(($17)>>2)]=0;
      var $18=$1;
      var $19=(($18+8)|0);
      var $20=HEAP32[(($19)>>2)];
      var $21=$1;
      var $22=$21;
      _HPDF_FreeMem($20, $22);
      __label__ = 7; break;
    case 7: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Stream_Tell($stream) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      $2=$stream;
      var $3=$2;
      var $4=(($3+36)|0);
      var $5=HEAP32[(($4)>>2)];
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      var $8=$2;
      var $9=(($8+12)|0);
      var $10=HEAP32[(($9)>>2)];
      var $11=_HPDF_SetError($10, 4149, 0);
      $1=$11;
      __label__ = 7; break;
    case 4: 
      var $13=$2;
      var $14=(($13+12)|0);
      var $15=HEAP32[(($14)>>2)];
      var $16=_HPDF_Error_GetCode($15);
      var $17=(($16)|0)!=0;
      if ($17) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      $1=4188;
      __label__ = 7; break;
    case 6: 
      var $20=$2;
      var $21=(($20+36)|0);
      var $22=HEAP32[(($21)>>2)];
      var $23=$2;
      var $24=FUNCTION_TABLE[$22]($23);
      $1=$24;
      __label__ = 7; break;
    case 7: 
      var $26=$1;
      ;
      return $26;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Stream_Size($stream) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      $2=$stream;
      var $3=$2;
      var $4=(($3+20)|0);
      var $5=HEAP32[(($4)>>2)];
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $8=$2;
      var $9=(($8+16)|0);
      var $10=HEAP32[(($9)>>2)];
      $1=$10;
      __label__ = 9; break;
    case 4: 
      var $12=$2;
      var $13=(($12+40)|0);
      var $14=HEAP32[(($13)>>2)];
      var $15=(($14)|0)!=0;
      if ($15) { __label__ = 6; break; } else { __label__ = 5; break; }
    case 5: 
      var $17=$2;
      var $18=(($17+12)|0);
      var $19=HEAP32[(($18)>>2)];
      var $20=_HPDF_SetError($19, 4149, 0);
      $1=0;
      __label__ = 9; break;
    case 6: 
      var $22=$2;
      var $23=(($22+12)|0);
      var $24=HEAP32[(($23)>>2)];
      var $25=_HPDF_Error_GetCode($24);
      var $26=(($25)|0)!=0;
      if ($26) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      $1=0;
      __label__ = 9; break;
    case 8: 
      var $29=$2;
      var $30=(($29+40)|0);
      var $31=HEAP32[(($30)>>2)];
      var $32=$2;
      var $33=FUNCTION_TABLE[$31]($32);
      $1=$33;
      __label__ = 9; break;
    case 9: 
      var $35=$1;
      ;
      return $35;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Stream_WriteEscapeName($stream, $value) {
  var __stackBase__  = STACKTOP; STACKTOP += 384; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $tmp_char=__stackBase__;
      var $len;
      var $i;
      var $pos1;
      var $pos2;
      var $c;
      $1=$stream;
      $2=$value;
      var $3=$2;
      var $4=_HPDF_StrLen($3, 127);
      $len=$4;
      var $5=$2;
      $pos1=$5;
      var $6=(($tmp_char)|0);
      $pos2=$6;
      var $7=$pos2;
      var $8=(($7+1)|0);
      $pos2=$8;
      HEAP8[($7)]=47;
      $i=0;
      __label__ = 3; break;
    case 3: 
      var $10=$i;
      var $11=$len;
      var $12=(($10)|0) < (($11)|0);
      if ($12) { __label__ = 4; break; } else { __label__ = 28; break; }
    case 4: 
      var $14=$pos1;
      var $15=(($14+1)|0);
      $pos1=$15;
      var $16=HEAP8[($14)];
      $c=$16;
      var $17=$c;
      var $18=(($17)&255);
      var $19=(($18)|0) < 32;
      if ($19) { __label__ = 18; break; } else { __label__ = 5; break; }
    case 5: 
      var $21=$c;
      var $22=(($21)&255);
      var $23=(($22)|0) > 126;
      if ($23) { __label__ = 18; break; } else { __label__ = 6; break; }
    case 6: 
      var $25=$c;
      var $26=(($25)&255);
      var $27=(($26)|0)==92;
      if ($27) { __label__ = 18; break; } else { __label__ = 7; break; }
    case 7: 
      var $29=$c;
      var $30=(($29)&255);
      var $31=(($30)|0)==37;
      if ($31) { __label__ = 18; break; } else { __label__ = 8; break; }
    case 8: 
      var $33=$c;
      var $34=(($33)&255);
      var $35=(($34)|0)==35;
      if ($35) { __label__ = 18; break; } else { __label__ = 9; break; }
    case 9: 
      var $37=$c;
      var $38=(($37)&255);
      var $39=(($38)|0)==47;
      if ($39) { __label__ = 18; break; } else { __label__ = 10; break; }
    case 10: 
      var $41=$c;
      var $42=(($41)&255);
      var $43=(($42)|0)==40;
      if ($43) { __label__ = 18; break; } else { __label__ = 11; break; }
    case 11: 
      var $45=$c;
      var $46=(($45)&255);
      var $47=(($46)|0)==41;
      if ($47) { __label__ = 18; break; } else { __label__ = 12; break; }
    case 12: 
      var $49=$c;
      var $50=(($49)&255);
      var $51=(($50)|0)==60;
      if ($51) { __label__ = 18; break; } else { __label__ = 13; break; }
    case 13: 
      var $53=$c;
      var $54=(($53)&255);
      var $55=(($54)|0)==62;
      if ($55) { __label__ = 18; break; } else { __label__ = 14; break; }
    case 14: 
      var $57=$c;
      var $58=(($57)&255);
      var $59=(($58)|0)==91;
      if ($59) { __label__ = 18; break; } else { __label__ = 15; break; }
    case 15: 
      var $61=$c;
      var $62=(($61)&255);
      var $63=(($62)|0)==93;
      if ($63) { __label__ = 18; break; } else { __label__ = 16; break; }
    case 16: 
      var $65=$c;
      var $66=(($65)&255);
      var $67=(($66)|0)==123;
      if ($67) { __label__ = 18; break; } else { __label__ = 17; break; }
    case 17: 
      var $69=$c;
      var $70=(($69)&255);
      var $71=(($70)|0)==125;
      if ($71) { __label__ = 18; break; } else { __label__ = 25; break; }
    case 18: 
      var $73=$pos2;
      var $74=(($73+1)|0);
      $pos2=$74;
      HEAP8[($73)]=35;
      var $75=$c;
      var $76=(($75)&255);
      var $77=$76 >> 4;
      var $78=(($77) & 255);
      var $79=$pos2;
      HEAP8[($79)]=$78;
      var $80=$pos2;
      var $81=HEAP8[($80)];
      var $82=(($81 << 24) >> 24);
      var $83=(($82)|0) <= 9;
      if ($83) { __label__ = 19; break; } else { __label__ = 20; break; }
    case 19: 
      var $85=$pos2;
      var $86=HEAP8[($85)];
      var $87=(($86 << 24) >> 24);
      var $88=((($87)+(48))|0);
      var $89=(($88) & 255);
      HEAP8[($85)]=$89;
      __label__ = 21; break;
    case 20: 
      var $91=$pos2;
      var $92=HEAP8[($91)];
      var $93=(($92 << 24) >> 24);
      var $94=((($93)+(55))|0);
      var $95=(($94) & 255);
      HEAP8[($91)]=$95;
      __label__ = 21; break;
    case 21: 
      var $97=$pos2;
      var $98=(($97+1)|0);
      $pos2=$98;
      var $99=$c;
      var $100=(($99)&255);
      var $101=$100 & 15;
      var $102=(($101) & 255);
      var $103=$pos2;
      HEAP8[($103)]=$102;
      var $104=$pos2;
      var $105=HEAP8[($104)];
      var $106=(($105 << 24) >> 24);
      var $107=(($106)|0) <= 9;
      if ($107) { __label__ = 22; break; } else { __label__ = 23; break; }
    case 22: 
      var $109=$pos2;
      var $110=HEAP8[($109)];
      var $111=(($110 << 24) >> 24);
      var $112=((($111)+(48))|0);
      var $113=(($112) & 255);
      HEAP8[($109)]=$113;
      __label__ = 24; break;
    case 23: 
      var $115=$pos2;
      var $116=HEAP8[($115)];
      var $117=(($116 << 24) >> 24);
      var $118=((($117)+(55))|0);
      var $119=(($118) & 255);
      HEAP8[($115)]=$119;
      __label__ = 24; break;
    case 24: 
      var $121=$pos2;
      var $122=(($121+1)|0);
      $pos2=$122;
      __label__ = 26; break;
    case 25: 
      var $124=$c;
      var $125=$pos2;
      var $126=(($125+1)|0);
      $pos2=$126;
      HEAP8[($125)]=$124;
      __label__ = 26; break;
    case 26: 
      __label__ = 27; break;
    case 27: 
      var $129=$i;
      var $130=((($129)+(1))|0);
      $i=$130;
      __label__ = 3; break;
    case 28: 
      var $132=$pos2;
      HEAP8[($132)]=0;
      var $133=$1;
      var $134=(($tmp_char)|0);
      var $135=(($tmp_char)|0);
      var $136=_HPDF_StrLen($135, -1);
      var $137=_HPDF_Stream_Write($133, $134, $136);
      STACKTOP = __stackBase__;
      return $137;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Stream_WriteEscapeName["X"]=1;

function _HPDF_Stream_WriteEscapeText2($stream, $text, $len) {
  var __stackBase__  = STACKTOP; STACKTOP += 256; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $buf=__stackBase__;
      var $idx;
      var $i;
      var $p;
      var $ret;
      var $c;
      $2=$stream;
      $3=$text;
      $4=$len;
      $idx=0;
      var $5=$3;
      $p=$5;
      var $6=$4;
      var $7=(($6)|0)!=0;
      if ($7) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=0;
      __label__ = 29; break;
    case 4: 
      var $10=$idx;
      var $11=((($10)+(1))|0);
      $idx=$11;
      var $12=(($buf+$10)|0);
      HEAP8[($12)]=40;
      $i=0;
      __label__ = 5; break;
    case 5: 
      var $14=$i;
      var $15=$4;
      var $16=(($14)>>>0) < (($15)>>>0);
      if ($16) { __label__ = 6; break; } else { __label__ = 28; break; }
    case 6: 
      var $18=$p;
      var $19=(($18+1)|0);
      $p=$19;
      var $20=HEAP8[($18)];
      $c=$20;
      var $21=$c;
      var $22=(($21)&255);
      var $23=(($22)|0) < 32;
      if ($23) { __label__ = 20; break; } else { __label__ = 7; break; }
    case 7: 
      var $25=$c;
      var $26=(($25)&255);
      var $27=(($26)|0) > 126;
      if ($27) { __label__ = 20; break; } else { __label__ = 8; break; }
    case 8: 
      var $29=$c;
      var $30=(($29)&255);
      var $31=(($30)|0)==92;
      if ($31) { __label__ = 20; break; } else { __label__ = 9; break; }
    case 9: 
      var $33=$c;
      var $34=(($33)&255);
      var $35=(($34)|0)==37;
      if ($35) { __label__ = 20; break; } else { __label__ = 10; break; }
    case 10: 
      var $37=$c;
      var $38=(($37)&255);
      var $39=(($38)|0)==35;
      if ($39) { __label__ = 20; break; } else { __label__ = 11; break; }
    case 11: 
      var $41=$c;
      var $42=(($41)&255);
      var $43=(($42)|0)==47;
      if ($43) { __label__ = 20; break; } else { __label__ = 12; break; }
    case 12: 
      var $45=$c;
      var $46=(($45)&255);
      var $47=(($46)|0)==40;
      if ($47) { __label__ = 20; break; } else { __label__ = 13; break; }
    case 13: 
      var $49=$c;
      var $50=(($49)&255);
      var $51=(($50)|0)==41;
      if ($51) { __label__ = 20; break; } else { __label__ = 14; break; }
    case 14: 
      var $53=$c;
      var $54=(($53)&255);
      var $55=(($54)|0)==60;
      if ($55) { __label__ = 20; break; } else { __label__ = 15; break; }
    case 15: 
      var $57=$c;
      var $58=(($57)&255);
      var $59=(($58)|0)==62;
      if ($59) { __label__ = 20; break; } else { __label__ = 16; break; }
    case 16: 
      var $61=$c;
      var $62=(($61)&255);
      var $63=(($62)|0)==91;
      if ($63) { __label__ = 20; break; } else { __label__ = 17; break; }
    case 17: 
      var $65=$c;
      var $66=(($65)&255);
      var $67=(($66)|0)==93;
      if ($67) { __label__ = 20; break; } else { __label__ = 18; break; }
    case 18: 
      var $69=$c;
      var $70=(($69)&255);
      var $71=(($70)|0)==123;
      if ($71) { __label__ = 20; break; } else { __label__ = 19; break; }
    case 19: 
      var $73=$c;
      var $74=(($73)&255);
      var $75=(($74)|0)==125;
      if ($75) { __label__ = 20; break; } else { __label__ = 21; break; }
    case 20: 
      var $77=$idx;
      var $78=((($77)+(1))|0);
      $idx=$78;
      var $79=(($buf+$77)|0);
      HEAP8[($79)]=92;
      var $80=$c;
      var $81=(($80)&255);
      var $82=$81 >> 6;
      var $83=(($82) & 255);
      var $84=$idx;
      var $85=(($buf+$84)|0);
      HEAP8[($85)]=$83;
      var $86=$idx;
      var $87=(($buf+$86)|0);
      var $88=HEAP8[($87)];
      var $89=(($88 << 24) >> 24);
      var $90=((($89)+(48))|0);
      var $91=(($90) & 255);
      HEAP8[($87)]=$91;
      var $92=$idx;
      var $93=((($92)+(1))|0);
      $idx=$93;
      var $94=$c;
      var $95=(($94)&255);
      var $96=$95 & 56;
      var $97=$96 >> 3;
      var $98=(($97) & 255);
      var $99=$idx;
      var $100=(($buf+$99)|0);
      HEAP8[($100)]=$98;
      var $101=$idx;
      var $102=(($buf+$101)|0);
      var $103=HEAP8[($102)];
      var $104=(($103 << 24) >> 24);
      var $105=((($104)+(48))|0);
      var $106=(($105) & 255);
      HEAP8[($102)]=$106;
      var $107=$idx;
      var $108=((($107)+(1))|0);
      $idx=$108;
      var $109=$c;
      var $110=(($109)&255);
      var $111=$110 & 7;
      var $112=(($111) & 255);
      var $113=$idx;
      var $114=(($buf+$113)|0);
      HEAP8[($114)]=$112;
      var $115=$idx;
      var $116=(($buf+$115)|0);
      var $117=HEAP8[($116)];
      var $118=(($117 << 24) >> 24);
      var $119=((($118)+(48))|0);
      var $120=(($119) & 255);
      HEAP8[($116)]=$120;
      var $121=$idx;
      var $122=((($121)+(1))|0);
      $idx=$122;
      __label__ = 22; break;
    case 21: 
      var $124=$c;
      var $125=$idx;
      var $126=((($125)+(1))|0);
      $idx=$126;
      var $127=(($buf+$125)|0);
      HEAP8[($127)]=$124;
      __label__ = 22; break;
    case 22: 
      var $129=$idx;
      var $130=(($129)>>>0) > 252;
      if ($130) { __label__ = 23; break; } else { __label__ = 26; break; }
    case 23: 
      var $132=$2;
      var $133=(($buf)|0);
      var $134=$idx;
      var $135=_HPDF_Stream_Write($132, $133, $134);
      $ret=$135;
      var $136=$ret;
      var $137=(($136)|0)!=0;
      if ($137) { __label__ = 24; break; } else { __label__ = 25; break; }
    case 24: 
      var $139=$ret;
      $1=$139;
      __label__ = 29; break;
    case 25: 
      $idx=0;
      __label__ = 26; break;
    case 26: 
      __label__ = 27; break;
    case 27: 
      var $143=$i;
      var $144=((($143)+(1))|0);
      $i=$144;
      __label__ = 5; break;
    case 28: 
      var $146=$idx;
      var $147=((($146)+(1))|0);
      $idx=$147;
      var $148=(($buf+$146)|0);
      HEAP8[($148)]=41;
      var $149=$2;
      var $150=(($buf)|0);
      var $151=$idx;
      var $152=_HPDF_Stream_Write($149, $150, $151);
      $ret=$152;
      var $153=$ret;
      $1=$153;
      __label__ = 29; break;
    case 29: 
      var $155=$1;
      STACKTOP = __stackBase__;
      return $155;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Stream_WriteEscapeText2["X"]=1;

function _HPDF_Stream_WriteEscapeText($stream, $text) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $len;
      $1=$stream;
      $2=$text;
      var $3=$2;
      var $4=(($3)|0)==0;
      if ($4) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $10 = 0;__label__ = 5; break;
    case 4: 
      var $7=$2;
      var $8=_HPDF_StrLen($7, 65535);
      var $10 = $8;__label__ = 5; break;
    case 5: 
      var $10;
      $len=$10;
      var $11=$1;
      var $12=$2;
      var $13=$len;
      var $14=_HPDF_Stream_WriteEscapeText2($11, $12, $13);
      ;
      return $14;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Stream_WriteBinary($stream, $data, $len, $e) {
  var __stackBase__  = STACKTOP; STACKTOP += 512; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $5;
      var $buf=__stackBase__;
      var $ebuf=(__stackBase__)+(256);
      var $pbuf;
      var $flg;
      var $idx;
      var $i;
      var $p;
      var $ret;
      var $c;
      $2=$stream;
      $3=$data;
      $4=$len;
      $5=$e;
      $pbuf=0;
      $flg=0;
      $idx=0;
      $ret=0;
      var $6=$5;
      var $7=(($6)|0)!=0;
      if ($7) { __label__ = 3; break; } else { __label__ = 7; break; }
    case 3: 
      var $9=$4;
      var $10=(($9)>>>0) <= 256;
      if ($10) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      var $12=(($ebuf)|0);
      $pbuf=$12;
      __label__ = 6; break;
    case 5: 
      var $14=$2;
      var $15=(($14+8)|0);
      var $16=HEAP32[(($15)>>2)];
      var $17=$4;
      var $18=_HPDF_GetMem($16, $17);
      $pbuf=$18;
      $flg=1;
      __label__ = 6; break;
    case 6: 
      var $20=$5;
      var $21=$3;
      var $22=$pbuf;
      var $23=$4;
      _HPDF_Encrypt_CryptBuf($20, $21, $22, $23);
      var $24=$pbuf;
      $p=$24;
      __label__ = 8; break;
    case 7: 
      var $26=$3;
      $p=$26;
      __label__ = 8; break;
    case 8: 
      $i=0;
      __label__ = 9; break;
    case 9: 
      var $29=$i;
      var $30=$4;
      var $31=(($29)>>>0) < (($30)>>>0);
      if ($31) { __label__ = 10; break; } else { __label__ = 24; break; }
    case 10: 
      var $33=$p;
      var $34=HEAPU8[($33)];
      var $35=(($34)&255);
      var $36=$35 >> 4;
      var $37=(($36) & 255);
      $c=$37;
      var $38=$c;
      var $39=(($38 << 24) >> 24);
      var $40=(($39)|0) <= 9;
      if ($40) { __label__ = 11; break; } else { __label__ = 12; break; }
    case 11: 
      var $42=$c;
      var $43=(($42 << 24) >> 24);
      var $44=((($43)+(48))|0);
      var $45=(($44) & 255);
      $c=$45;
      __label__ = 13; break;
    case 12: 
      var $47=$c;
      var $48=(($47 << 24) >> 24);
      var $49=((($48)+(55))|0);
      var $50=(($49) & 255);
      $c=$50;
      __label__ = 13; break;
    case 13: 
      var $52=$c;
      var $53=$idx;
      var $54=((($53)+(1))|0);
      $idx=$54;
      var $55=(($buf+$53)|0);
      HEAP8[($55)]=$52;
      var $56=$p;
      var $57=HEAPU8[($56)];
      var $58=(($57)&255);
      var $59=$58 & 15;
      var $60=(($59) & 255);
      $c=$60;
      var $61=$c;
      var $62=(($61 << 24) >> 24);
      var $63=(($62)|0) <= 9;
      if ($63) { __label__ = 14; break; } else { __label__ = 15; break; }
    case 14: 
      var $65=$c;
      var $66=(($65 << 24) >> 24);
      var $67=((($66)+(48))|0);
      var $68=(($67) & 255);
      $c=$68;
      __label__ = 16; break;
    case 15: 
      var $70=$c;
      var $71=(($70 << 24) >> 24);
      var $72=((($71)+(55))|0);
      var $73=(($72) & 255);
      $c=$73;
      __label__ = 16; break;
    case 16: 
      var $75=$c;
      var $76=$idx;
      var $77=((($76)+(1))|0);
      $idx=$77;
      var $78=(($buf+$76)|0);
      HEAP8[($78)]=$75;
      var $79=$idx;
      var $80=(($79)>>>0) > 254;
      if ($80) { __label__ = 17; break; } else { __label__ = 22; break; }
    case 17: 
      var $82=$2;
      var $83=(($buf)|0);
      var $84=$idx;
      var $85=_HPDF_Stream_Write($82, $83, $84);
      $ret=$85;
      var $86=$ret;
      var $87=(($86)|0)!=0;
      if ($87) { __label__ = 18; break; } else { __label__ = 21; break; }
    case 18: 
      var $89=$flg;
      var $90=(($89)|0)!=0;
      if ($90) { __label__ = 19; break; } else { __label__ = 20; break; }
    case 19: 
      var $92=$2;
      var $93=(($92+8)|0);
      var $94=HEAP32[(($93)>>2)];
      var $95=$pbuf;
      _HPDF_FreeMem($94, $95);
      __label__ = 20; break;
    case 20: 
      var $97=$ret;
      $1=$97;
      __label__ = 29; break;
    case 21: 
      $idx=0;
      __label__ = 22; break;
    case 22: 
      __label__ = 23; break;
    case 23: 
      var $101=$i;
      var $102=((($101)+(1))|0);
      $i=$102;
      var $103=$p;
      var $104=(($103+1)|0);
      $p=$104;
      __label__ = 9; break;
    case 24: 
      var $106=$idx;
      var $107=(($106)>>>0) > 0;
      if ($107) { __label__ = 25; break; } else { __label__ = 26; break; }
    case 25: 
      var $109=$2;
      var $110=(($buf)|0);
      var $111=$idx;
      var $112=_HPDF_Stream_Write($109, $110, $111);
      $ret=$112;
      __label__ = 26; break;
    case 26: 
      var $114=$flg;
      var $115=(($114)|0)!=0;
      if ($115) { __label__ = 27; break; } else { __label__ = 28; break; }
    case 27: 
      var $117=$2;
      var $118=(($117+8)|0);
      var $119=HEAP32[(($118)>>2)];
      var $120=$pbuf;
      _HPDF_FreeMem($119, $120);
      __label__ = 28; break;
    case 28: 
      var $122=$ret;
      $1=$122;
      __label__ = 29; break;
    case 29: 
      var $124=$1;
      STACKTOP = __stackBase__;
      return $124;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Stream_WriteBinary["X"]=1;

function _HPDF_Stream_WriteToStreamWithDeflate($src, $dst, $e) {
  var __stackBase__  = STACKTOP; STACKTOP += 13196; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $ret;
      var $flg;
      var $strm=__stackBase__;
      var $inbuf=(__stackBase__)+(56);
      var $otbuf=(__stackBase__)+(4152);
      var $ebuf=(__stackBase__)+(8672);
      var $size=(__stackBase__)+(13192);
      var $osize;
      $2=$src;
      $3=$dst;
      $4=$e;
      var $5=$2;
      var $6=_HPDF_Stream_Seek($5, 0, 0);
      $ret=$6;
      var $7=$ret;
      var $8=(($7)|0)!=0;
      if ($8) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $10=$ret;
      $1=$10;
      __label__ = 47; break;
    case 4: 
      var $12=$strm;
      var $13=_HPDF_MemSet($12, 0, 56);
      var $14=(($otbuf)|0);
      var $15=(($strm+12)|0);
      HEAP32[(($15)>>2)]=$14;
      var $16=(($strm+16)|0);
      HEAP32[(($16)>>2)]=4518;
      var $17=_deflateInit_($strm, -1, ((STRING_TABLE.__str1679)|0), 56);
      $ret=$17;
      var $18=$ret;
      var $19=(($18)|0)!=0;
      if ($19) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $21=$2;
      var $22=(($21+12)|0);
      var $23=HEAP32[(($22)>>2)];
      var $24=$ret;
      var $25=_HPDF_SetError($23, 4198, $24);
      $1=$25;
      __label__ = 47; break;
    case 6: 
      var $27=(($inbuf)|0);
      var $28=(($strm)|0);
      HEAP32[(($28)>>2)]=$27;
      var $29=(($strm+4)|0);
      HEAP32[(($29)>>2)]=0;
      $flg=0;
      __label__ = 7; break;
    case 7: 
      HEAP32[(($size)>>2)]=4096;
      var $31=$2;
      var $32=(($inbuf)|0);
      var $33=_HPDF_Stream_Read($31, $32, $size);
      $ret=$33;
      var $34=(($inbuf)|0);
      var $35=(($strm)|0);
      HEAP32[(($35)>>2)]=$34;
      var $36=HEAP32[(($size)>>2)];
      var $37=(($strm+4)|0);
      HEAP32[(($37)>>2)]=$36;
      var $38=$ret;
      var $39=(($38)|0)!=0;
      if ($39) { __label__ = 8; break; } else { __label__ = 14; break; }
    case 8: 
      var $41=$ret;
      var $42=(($41)|0)==4184;
      if ($42) { __label__ = 9; break; } else { __label__ = 12; break; }
    case 9: 
      $flg=1;
      var $44=HEAP32[(($size)>>2)];
      var $45=(($44)|0)==0;
      if ($45) { __label__ = 10; break; } else { __label__ = 11; break; }
    case 10: 
      __label__ = 30; break;
    case 11: 
      __label__ = 13; break;
    case 12: 
      var $49=_deflateEnd($strm);
      var $50=$ret;
      $1=$50;
      __label__ = 47; break;
    case 13: 
      __label__ = 14; break;
    case 14: 
      __label__ = 15; break;
    case 15: 
      var $54=(($strm+4)|0);
      var $55=HEAPU32[(($54)>>2)];
      var $56=(($55)>>>0) > 0;
      if ($56) { __label__ = 16; break; } else { __label__ = 27; break; }
    case 16: 
      var $58=_deflate($strm, 0);
      $ret=$58;
      var $59=$ret;
      var $60=(($59)|0)!=0;
      if ($60) { __label__ = 17; break; } else { __label__ = 19; break; }
    case 17: 
      var $62=$ret;
      var $63=(($62)|0)!=1;
      if ($63) { __label__ = 18; break; } else { __label__ = 19; break; }
    case 18: 
      var $65=_deflateEnd($strm);
      var $66=$2;
      var $67=(($66+12)|0);
      var $68=HEAP32[(($67)>>2)];
      var $69=$ret;
      var $70=_HPDF_SetError($68, 4198, $69);
      $1=$70;
      __label__ = 47; break;
    case 19: 
      var $72=(($strm+16)|0);
      var $73=HEAP32[(($72)>>2)];
      var $74=(($73)|0)==0;
      if ($74) { __label__ = 20; break; } else { __label__ = 26; break; }
    case 20: 
      var $76=$4;
      var $77=(($76)|0)!=0;
      if ($77) { __label__ = 21; break; } else { __label__ = 22; break; }
    case 21: 
      var $79=$4;
      var $80=(($otbuf)|0);
      var $81=(($ebuf)|0);
      _HPDF_Encrypt_CryptBuf($79, $80, $81, 4518);
      var $82=$3;
      var $83=(($ebuf)|0);
      var $84=_HPDF_Stream_Write($82, $83, 4518);
      $ret=$84;
      __label__ = 23; break;
    case 22: 
      var $86=$3;
      var $87=(($otbuf)|0);
      var $88=_HPDF_Stream_Write($86, $87, 4518);
      $ret=$88;
      __label__ = 23; break;
    case 23: 
      var $90=$ret;
      var $91=(($90)|0)!=0;
      if ($91) { __label__ = 24; break; } else { __label__ = 25; break; }
    case 24: 
      var $93=_deflateEnd($strm);
      var $94=$2;
      var $95=(($94+12)|0);
      var $96=HEAP32[(($95)>>2)];
      var $97=$ret;
      var $98=_HPDF_SetError($96, 4198, $97);
      $1=$98;
      __label__ = 47; break;
    case 25: 
      var $100=(($otbuf)|0);
      var $101=(($strm+12)|0);
      HEAP32[(($101)>>2)]=$100;
      var $102=(($strm+16)|0);
      HEAP32[(($102)>>2)]=4518;
      __label__ = 26; break;
    case 26: 
      __label__ = 15; break;
    case 27: 
      var $105=$flg;
      var $106=(($105)|0)!=0;
      if ($106) { __label__ = 28; break; } else { __label__ = 29; break; }
    case 28: 
      __label__ = 30; break;
    case 29: 
      __label__ = 7; break;
    case 30: 
      $flg=0;
      __label__ = 31; break;
    case 31: 
      var $111=_deflate($strm, 4);
      $ret=$111;
      var $112=$ret;
      var $113=(($112)|0)!=0;
      if ($113) { __label__ = 32; break; } else { __label__ = 34; break; }
    case 32: 
      var $115=$ret;
      var $116=(($115)|0)!=1;
      if ($116) { __label__ = 33; break; } else { __label__ = 34; break; }
    case 33: 
      var $118=_deflateEnd($strm);
      var $119=$2;
      var $120=(($119+12)|0);
      var $121=HEAP32[(($120)>>2)];
      var $122=$ret;
      var $123=_HPDF_SetError($121, 4198, $122);
      $1=$123;
      __label__ = 47; break;
    case 34: 
      var $125=$ret;
      var $126=(($125)|0)==1;
      if ($126) { __label__ = 35; break; } else { __label__ = 36; break; }
    case 35: 
      $flg=1;
      __label__ = 36; break;
    case 36: 
      var $129=(($strm+16)|0);
      var $130=HEAPU32[(($129)>>2)];
      var $131=(($130)>>>0) < 4518;
      if ($131) { __label__ = 37; break; } else { __label__ = 43; break; }
    case 37: 
      var $133=(($strm+16)|0);
      var $134=HEAP32[(($133)>>2)];
      var $135=(((4518)-($134))|0);
      $osize=$135;
      var $136=$4;
      var $137=(($136)|0)!=0;
      if ($137) { __label__ = 38; break; } else { __label__ = 39; break; }
    case 38: 
      var $139=$4;
      var $140=(($otbuf)|0);
      var $141=(($ebuf)|0);
      var $142=$osize;
      _HPDF_Encrypt_CryptBuf($139, $140, $141, $142);
      var $143=$3;
      var $144=(($ebuf)|0);
      var $145=$osize;
      var $146=_HPDF_Stream_Write($143, $144, $145);
      $ret=$146;
      __label__ = 40; break;
    case 39: 
      var $148=$3;
      var $149=(($otbuf)|0);
      var $150=$osize;
      var $151=_HPDF_Stream_Write($148, $149, $150);
      $ret=$151;
      __label__ = 40; break;
    case 40: 
      var $153=$ret;
      var $154=(($153)|0)!=0;
      if ($154) { __label__ = 41; break; } else { __label__ = 42; break; }
    case 41: 
      var $156=_deflateEnd($strm);
      var $157=$2;
      var $158=(($157+12)|0);
      var $159=HEAP32[(($158)>>2)];
      var $160=$ret;
      var $161=_HPDF_SetError($159, 4198, $160);
      $1=$161;
      __label__ = 47; break;
    case 42: 
      var $163=(($otbuf)|0);
      var $164=(($strm+12)|0);
      HEAP32[(($164)>>2)]=$163;
      var $165=(($strm+16)|0);
      HEAP32[(($165)>>2)]=4518;
      __label__ = 43; break;
    case 43: 
      var $167=$flg;
      var $168=(($167)|0)!=0;
      if ($168) { __label__ = 44; break; } else { __label__ = 45; break; }
    case 44: 
      __label__ = 46; break;
    case 45: 
      __label__ = 31; break;
    case 46: 
      var $172=_deflateEnd($strm);
      $1=0;
      __label__ = 47; break;
    case 47: 
      var $174=$1;
      STACKTOP = __stackBase__;
      return $174;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Stream_WriteToStreamWithDeflate["X"]=1;

function _HPDF_Stream_WriteToStream($src, $dst, $filter, $e) {
  var __stackBase__  = STACKTOP; STACKTOP += 8196; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $5;
      var $ret;
      var $buf=__stackBase__;
      var $ebuf=(__stackBase__)+(4096);
      var $flg;
      var $size=(__stackBase__)+(8192);
      $2=$src;
      $3=$dst;
      $4=$filter;
      $5=$e;
      var $6=$3;
      var $7=(($6)|0)!=0;
      if ($7) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $9=$3;
      var $10=(($9+20)|0);
      var $11=HEAP32[(($10)>>2)];
      var $12=(($11)|0)!=0;
      if ($12) { __label__ = 5; break; } else { __label__ = 4; break; }
    case 4: 
      var $14=$2;
      var $15=(($14+12)|0);
      var $16=HEAP32[(($15)>>2)];
      var $17=_HPDF_SetError($16, 4147, 0);
      $1=4147;
      __label__ = 31; break;
    case 5: 
      var $19=$2;
      var $20=(($19+12)|0);
      var $21=HEAP32[(($20)>>2)];
      var $22=_HPDF_Error_GetCode($21);
      var $23=(($22)|0)!=0;
      if ($23) { __label__ = 7; break; } else { __label__ = 6; break; }
    case 6: 
      var $25=$3;
      var $26=(($25+12)|0);
      var $27=HEAP32[(($26)>>2)];
      var $28=_HPDF_Error_GetCode($27);
      var $29=(($28)|0)!=0;
      if ($29) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      $1=4188;
      __label__ = 31; break;
    case 8: 
      var $32=$2;
      var $33=_HPDF_Stream_Size($32);
      var $34=(($33)|0)==0;
      if ($34) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      $1=0;
      __label__ = 31; break;
    case 10: 
      var $37=$4;
      var $38=$37 & 1024;
      var $39=(($38)|0)!=0;
      if ($39) { __label__ = 11; break; } else { __label__ = 12; break; }
    case 11: 
      var $41=$2;
      var $42=$3;
      var $43=$5;
      var $44=_HPDF_Stream_WriteToStreamWithDeflate($41, $42, $43);
      $1=$44;
      __label__ = 31; break;
    case 12: 
      var $46=$2;
      var $47=_HPDF_Stream_Seek($46, 0, 0);
      $ret=$47;
      var $48=$ret;
      var $49=(($48)|0)!=0;
      if ($49) { __label__ = 13; break; } else { __label__ = 14; break; }
    case 13: 
      var $51=$ret;
      $1=$51;
      __label__ = 31; break;
    case 14: 
      $flg=0;
      __label__ = 15; break;
    case 15: 
      HEAP32[(($size)>>2)]=4096;
      var $54=$2;
      var $55=(($buf)|0);
      var $56=_HPDF_Stream_Read($54, $55, $size);
      $ret=$56;
      var $57=$ret;
      var $58=(($57)|0)!=0;
      if ($58) { __label__ = 16; break; } else { __label__ = 22; break; }
    case 16: 
      var $60=$ret;
      var $61=(($60)|0)==4184;
      if ($61) { __label__ = 17; break; } else { __label__ = 20; break; }
    case 17: 
      $flg=1;
      var $63=HEAP32[(($size)>>2)];
      var $64=(($63)|0)==0;
      if ($64) { __label__ = 18; break; } else { __label__ = 19; break; }
    case 18: 
      __label__ = 30; break;
    case 19: 
      __label__ = 21; break;
    case 20: 
      var $68=$ret;
      $1=$68;
      __label__ = 31; break;
    case 21: 
      __label__ = 22; break;
    case 22: 
      var $71=$5;
      var $72=(($71)|0)!=0;
      if ($72) { __label__ = 23; break; } else { __label__ = 24; break; }
    case 23: 
      var $74=$5;
      var $75=(($buf)|0);
      var $76=(($ebuf)|0);
      var $77=HEAP32[(($size)>>2)];
      _HPDF_Encrypt_CryptBuf($74, $75, $76, $77);
      var $78=$3;
      var $79=(($ebuf)|0);
      var $80=HEAP32[(($size)>>2)];
      var $81=_HPDF_Stream_Write($78, $79, $80);
      $ret=$81;
      __label__ = 25; break;
    case 24: 
      var $83=$3;
      var $84=(($buf)|0);
      var $85=HEAP32[(($size)>>2)];
      var $86=_HPDF_Stream_Write($83, $84, $85);
      $ret=$86;
      __label__ = 25; break;
    case 25: 
      var $88=$ret;
      var $89=(($88)|0)!=0;
      if ($89) { __label__ = 26; break; } else { __label__ = 27; break; }
    case 26: 
      var $91=$ret;
      $1=$91;
      __label__ = 31; break;
    case 27: 
      var $93=$flg;
      var $94=(($93)|0)!=0;
      if ($94) { __label__ = 28; break; } else { __label__ = 29; break; }
    case 28: 
      __label__ = 30; break;
    case 29: 
      __label__ = 15; break;
    case 30: 
      $1=0;
      __label__ = 31; break;
    case 31: 
      var $99=$1;
      STACKTOP = __stackBase__;
      return $99;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Stream_WriteToStream["X"]=1;

function _HPDF_MemStream_TellFunc($stream) {
  ;
  var __label__;

  var $1;
  var $ret;
  var $attr;
  $1=$stream;
  var $2=$1;
  var $3=(($2+44)|0);
  var $4=HEAP32[(($3)>>2)];
  var $5=$4;
  $attr=$5;
  var $6=$attr;
  var $7=(($6+16)|0);
  var $8=HEAP32[(($7)>>2)];
  var $9=$attr;
  var $10=(($9+4)|0);
  var $11=HEAP32[(($10)>>2)];
  var $12=((($8)*($11))|0);
  $ret=$12;
  var $13=$attr;
  var $14=(($13+20)|0);
  var $15=HEAP32[(($14)>>2)];
  var $16=$ret;
  var $17=((($16)+($15))|0);
  $ret=$17;
  var $18=$ret;
  ;
  return $18;
}


function _HPDF_MemStream_SizeFunc($stream) {
  ;
  var __label__;

  var $1;
  $1=$stream;
  var $2=$1;
  var $3=(($2+16)|0);
  var $4=HEAP32[(($3)>>2)];
  ;
  return $4;
}


function _HPDF_FileReader_New($mmgr, $fname) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $stream;
      var $fp;
      $2=$mmgr;
      $3=$fname;
      var $4=$3;
      var $5=_fopen($4, ((STRING_TABLE.__str11680)|0));
      $fp=$5;
      var $6=$fp;
      var $7=(($6)|0)!=0;
      if ($7) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      var $9=$2;
      var $10=(($9)|0);
      var $11=HEAP32[(($10)>>2)];
      var $12=___errno();
      var $13=HEAP32[(($12)>>2)];
      var $14=_HPDF_SetError($11, 4119, $13);
      $1=0;
      __label__ = 7; break;
    case 4: 
      var $16=$2;
      var $17=_HPDF_GetMem($16, 48);
      var $18=$17;
      $stream=$18;
      var $19=$stream;
      var $20=(($19)|0)!=0;
      if ($20) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $22=$stream;
      var $23=$22;
      var $24=_HPDF_MemSet($23, 0, 48);
      var $25=$stream;
      var $26=(($25)|0);
      HEAP32[(($26)>>2)]=1398035021;
      var $27=$stream;
      var $28=(($27+4)|0);
      HEAP32[(($28)>>2)]=2;
      var $29=$2;
      var $30=(($29)|0);
      var $31=HEAP32[(($30)>>2)];
      var $32=$stream;
      var $33=(($32+12)|0);
      HEAP32[(($33)>>2)]=$31;
      var $34=$2;
      var $35=$stream;
      var $36=(($35+8)|0);
      HEAP32[(($36)>>2)]=$34;
      var $37=$stream;
      var $38=(($37+24)|0);
      var $39=$38;
      HEAP32[(($39)>>2)]=232;
      var $40=$stream;
      var $41=(($40+28)|0);
      HEAP32[(($41)>>2)]=234;
      var $42=$stream;
      var $43=(($42+36)|0);
      HEAP32[(($43)>>2)]=236;
      var $44=$stream;
      var $45=(($44+40)|0);
      HEAP32[(($45)>>2)]=238;
      var $46=$stream;
      var $47=(($46+32)|0);
      HEAP32[(($47)>>2)]=240;
      var $48=$fp;
      var $49=$48;
      var $50=$stream;
      var $51=(($50+44)|0);
      HEAP32[(($51)>>2)]=$49;
      __label__ = 6; break;
    case 6: 
      var $53=$stream;
      $1=$53;
      __label__ = 7; break;
    case 7: 
      var $55=$1;
      ;
      return $55;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_FileReader_New["X"]=1;

function _HPDF_FileReader_ReadFunc($stream, $ptr, $siz) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $fp;
      var $rsiz;
      $2=$stream;
      $3=$ptr;
      $4=$siz;
      var $5=$2;
      var $6=(($5+44)|0);
      var $7=HEAP32[(($6)>>2)];
      var $8=$7;
      $fp=$8;
      var $9=$3;
      var $10=$4;
      var $11=HEAP32[(($10)>>2)];
      var $12=_HPDF_MemSet($9, 0, $11);
      var $13=$3;
      var $14=$4;
      var $15=HEAP32[(($14)>>2)];
      var $16=$fp;
      var $17=_fread($13, 1, $15, $16);
      $rsiz=$17;
      var $18=$rsiz;
      var $19=$4;
      var $20=HEAP32[(($19)>>2)];
      var $21=(($18)|0)!=(($20)|0);
      if ($21) { __label__ = 3; break; } else { __label__ = 6; break; }
    case 3: 
      var $23=$fp;
      var $24=_feof($23);
      var $25=(($24)|0)!=0;
      if ($25) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      var $27=$rsiz;
      var $28=$4;
      HEAP32[(($28)>>2)]=$27;
      $1=4184;
      __label__ = 7; break;
    case 5: 
      var $30=$2;
      var $31=(($30+12)|0);
      var $32=HEAP32[(($31)>>2)];
      var $33=$fp;
      var $34=_ferror($33);
      var $35=_HPDF_SetError($32, 4118, $34);
      $1=$35;
      __label__ = 7; break;
    case 6: 
      $1=0;
      __label__ = 7; break;
    case 7: 
      var $38=$1;
      ;
      return $38;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_FileReader_ReadFunc["X"]=1;

function _HPDF_FileReader_SeekFunc($stream, $pos, $mode) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $fp;
      var $whence;
      $2=$stream;
      $3=$pos;
      $4=$mode;
      var $5=$2;
      var $6=(($5+44)|0);
      var $7=HEAP32[(($6)>>2)];
      var $8=$7;
      $fp=$8;
      var $9=$4;
      if ((($9)|0) == 1) {
        __label__ = 3; break;
      }
      else if ((($9)|0) == 2) {
        __label__ = 4; break;
      }
      else {
      __label__ = 5; break;
      }
      
    case 3: 
      $whence=1;
      __label__ = 6; break;
    case 4: 
      $whence=2;
      __label__ = 6; break;
    case 5: 
      $whence=0;
      __label__ = 6; break;
    case 6: 
      var $14=$fp;
      var $15=$3;
      var $16=$whence;
      var $17=_fseek($14, $15, $16);
      var $18=(($17)|0)!=0;
      if ($18) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $20=$2;
      var $21=(($20+12)|0);
      var $22=HEAP32[(($21)>>2)];
      var $23=$fp;
      var $24=_ferror($23);
      var $25=_HPDF_SetError($22, 4118, $24);
      $1=$25;
      __label__ = 9; break;
    case 8: 
      $1=0;
      __label__ = 9; break;
    case 9: 
      var $28=$1;
      ;
      return $28;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_FileStream_TellFunc($stream) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $ret;
      var $fp;
      $2=$stream;
      var $3=$2;
      var $4=(($3+44)|0);
      var $5=HEAP32[(($4)>>2)];
      var $6=$5;
      $fp=$6;
      var $7=$fp;
      var $8=_ftell($7);
      $ret=$8;
      var $9=(($8)|0) < 0;
      if ($9) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $11=$2;
      var $12=(($11+12)|0);
      var $13=HEAP32[(($12)>>2)];
      var $14=$fp;
      var $15=_ferror($14);
      var $16=_HPDF_SetError($13, 4118, $15);
      $1=$16;
      __label__ = 5; break;
    case 4: 
      var $18=$ret;
      $1=$18;
      __label__ = 5; break;
    case 5: 
      var $20=$1;
      ;
      return $20;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_FileStream_SizeFunc($stream) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $size;
      var $ptr;
      var $fp;
      $2=$stream;
      var $3=$2;
      var $4=(($3+44)|0);
      var $5=HEAP32[(($4)>>2)];
      var $6=$5;
      $fp=$6;
      var $7=$fp;
      var $8=_ftell($7);
      $ptr=$8;
      var $9=(($8)|0) < 0;
      if ($9) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $11=$2;
      var $12=(($11+12)|0);
      var $13=HEAP32[(($12)>>2)];
      var $14=$fp;
      var $15=_ferror($14);
      var $16=_HPDF_SetError($13, 4118, $15);
      $1=0;
      __label__ = 11; break;
    case 4: 
      var $18=$fp;
      var $19=_fseek($18, 0, 2);
      var $20=(($19)|0) < 0;
      if ($20) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $22=$2;
      var $23=(($22+12)|0);
      var $24=HEAP32[(($23)>>2)];
      var $25=$fp;
      var $26=_ferror($25);
      var $27=_HPDF_SetError($24, 4118, $26);
      $1=0;
      __label__ = 11; break;
    case 6: 
      var $29=$fp;
      var $30=_ftell($29);
      $size=$30;
      var $31=(($30)|0) < 0;
      if ($31) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $33=$2;
      var $34=(($33+12)|0);
      var $35=HEAP32[(($34)>>2)];
      var $36=$fp;
      var $37=_ferror($36);
      var $38=_HPDF_SetError($35, 4118, $37);
      $1=0;
      __label__ = 11; break;
    case 8: 
      var $40=$fp;
      var $41=$ptr;
      var $42=_fseek($40, $41, 0);
      var $43=(($42)|0) < 0;
      if ($43) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      var $45=$2;
      var $46=(($45+12)|0);
      var $47=HEAP32[(($46)>>2)];
      var $48=$fp;
      var $49=_ferror($48);
      var $50=_HPDF_SetError($47, 4118, $49);
      $1=0;
      __label__ = 11; break;
    case 10: 
      var $52=$size;
      $1=$52;
      __label__ = 11; break;
    case 11: 
      var $54=$1;
      ;
      return $54;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_FileStream_SizeFunc["X"]=1;

function _HPDF_FileStream_FreeFunc($stream) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $fp;
      $1=$stream;
      var $2=$1;
      var $3=(($2+44)|0);
      var $4=HEAP32[(($3)>>2)];
      var $5=$4;
      $fp=$5;
      var $6=$fp;
      var $7=(($6)|0)!=0;
      if ($7) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $9=$fp;
      var $10=_fclose($9);
      __label__ = 4; break;
    case 4: 
      var $12=$1;
      var $13=(($12+44)|0);
      HEAP32[(($13)>>2)]=0;
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_FileWriter_New($mmgr, $fname) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $stream;
      var $fp;
      $2=$mmgr;
      $3=$fname;
      var $4=$3;
      var $5=_fopen($4, ((STRING_TABLE.__str21681)|0));
      $fp=$5;
      var $6=$fp;
      var $7=(($6)|0)!=0;
      if ($7) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      var $9=$2;
      var $10=(($9)|0);
      var $11=HEAP32[(($10)>>2)];
      var $12=___errno();
      var $13=HEAP32[(($12)>>2)];
      var $14=_HPDF_SetError($11, 4119, $13);
      $1=0;
      __label__ = 7; break;
    case 4: 
      var $16=$2;
      var $17=_HPDF_GetMem($16, 48);
      var $18=$17;
      $stream=$18;
      var $19=$stream;
      var $20=(($19)|0)!=0;
      if ($20) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $22=$stream;
      var $23=$22;
      var $24=_HPDF_MemSet($23, 0, 48);
      var $25=$stream;
      var $26=(($25)|0);
      HEAP32[(($26)>>2)]=1398035021;
      var $27=$2;
      var $28=(($27)|0);
      var $29=HEAP32[(($28)>>2)];
      var $30=$stream;
      var $31=(($30+12)|0);
      HEAP32[(($31)>>2)]=$29;
      var $32=$2;
      var $33=$stream;
      var $34=(($33+8)|0);
      HEAP32[(($34)>>2)]=$32;
      var $35=$stream;
      var $36=(($35+20)|0);
      HEAP32[(($36)>>2)]=242;
      var $37=$stream;
      var $38=(($37+32)|0);
      HEAP32[(($38)>>2)]=240;
      var $39=$stream;
      var $40=(($39+36)|0);
      HEAP32[(($40)>>2)]=236;
      var $41=$fp;
      var $42=$41;
      var $43=$stream;
      var $44=(($43+44)|0);
      HEAP32[(($44)>>2)]=$42;
      var $45=$stream;
      var $46=(($45+4)|0);
      HEAP32[(($46)>>2)]=2;
      __label__ = 6; break;
    case 6: 
      var $48=$stream;
      $1=$48;
      __label__ = 7; break;
    case 7: 
      var $50=$1;
      ;
      return $50;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_FileWriter_New["X"]=1;

function _HPDF_FileWriter_WriteFunc($stream, $ptr, $siz) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $fp;
      var $ret;
      $2=$stream;
      $3=$ptr;
      $4=$siz;
      var $5=$2;
      var $6=(($5+44)|0);
      var $7=HEAP32[(($6)>>2)];
      var $8=$7;
      $fp=$8;
      var $9=$3;
      var $10=$4;
      var $11=$fp;
      var $12=_fwrite($9, 1, $10, $11);
      $ret=$12;
      var $13=$ret;
      var $14=$4;
      var $15=(($13)|0)!=(($14)|0);
      if ($15) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $17=$2;
      var $18=(($17+12)|0);
      var $19=HEAP32[(($18)>>2)];
      var $20=$fp;
      var $21=_ferror($20);
      var $22=_HPDF_SetError($19, 4118, $21);
      $1=$22;
      __label__ = 5; break;
    case 4: 
      $1=0;
      __label__ = 5; break;
    case 5: 
      var $25=$1;
      ;
      return $25;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_MemStream_InWrite($stream, $ptr, $count) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $attr;
      var $rsize;
      $2=$stream;
      $3=$ptr;
      $4=$count;
      var $5=$2;
      var $6=(($5+44)|0);
      var $7=HEAP32[(($6)>>2)];
      var $8=$7;
      $attr=$8;
      var $9=$attr;
      var $10=(($9+4)|0);
      var $11=HEAP32[(($10)>>2)];
      var $12=$attr;
      var $13=(($12+8)|0);
      var $14=HEAP32[(($13)>>2)];
      var $15=((($11)-($14))|0);
      $rsize=$15;
      var $16=$4;
      var $17=HEAPU32[(($16)>>2)];
      var $18=(($17)>>>0) <= 0;
      if ($18) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      $1=0;
      __label__ = 14; break;
    case 4: 
      var $21=$rsize;
      var $22=$4;
      var $23=HEAPU32[(($22)>>2)];
      var $24=(($21)>>>0) >= (($23)>>>0);
      if ($24) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $26=$attr;
      var $27=(($26+12)|0);
      var $28=HEAP32[(($27)>>2)];
      var $29=$3;
      var $30=HEAP32[(($29)>>2)];
      var $31=$4;
      var $32=HEAP32[(($31)>>2)];
      var $33=_HPDF_MemCpy($28, $30, $32);
      var $34=$4;
      var $35=HEAP32[(($34)>>2)];
      var $36=$attr;
      var $37=(($36+12)|0);
      var $38=HEAP32[(($37)>>2)];
      var $39=(($38+$35)|0);
      HEAP32[(($37)>>2)]=$39;
      var $40=$4;
      var $41=HEAP32[(($40)>>2)];
      var $42=$attr;
      var $43=(($42+8)|0);
      var $44=HEAP32[(($43)>>2)];
      var $45=((($44)+($41))|0);
      HEAP32[(($43)>>2)]=$45;
      var $46=$4;
      HEAP32[(($46)>>2)]=0;
      __label__ = 13; break;
    case 6: 
      var $48=$rsize;
      var $49=(($48)>>>0) > 0;
      if ($49) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $51=$attr;
      var $52=(($51+12)|0);
      var $53=HEAP32[(($52)>>2)];
      var $54=$3;
      var $55=HEAP32[(($54)>>2)];
      var $56=$rsize;
      var $57=_HPDF_MemCpy($53, $55, $56);
      var $58=$rsize;
      var $59=$3;
      var $60=HEAP32[(($59)>>2)];
      var $61=(($60+$58)|0);
      HEAP32[(($59)>>2)]=$61;
      var $62=$rsize;
      var $63=$4;
      var $64=HEAP32[(($63)>>2)];
      var $65=((($64)-($62))|0);
      HEAP32[(($63)>>2)]=$65;
      __label__ = 8; break;
    case 8: 
      var $67=$2;
      var $68=(($67+8)|0);
      var $69=HEAP32[(($68)>>2)];
      var $70=$attr;
      var $71=(($70+4)|0);
      var $72=HEAP32[(($71)>>2)];
      var $73=_HPDF_GetMem($69, $72);
      var $74=$attr;
      var $75=(($74+12)|0);
      HEAP32[(($75)>>2)]=$73;
      var $76=$attr;
      var $77=(($76+12)|0);
      var $78=HEAP32[(($77)>>2)];
      var $79=(($78)|0)==0;
      if ($79) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      var $81=$2;
      var $82=(($81+12)|0);
      var $83=HEAP32[(($82)>>2)];
      var $84=_HPDF_Error_GetCode($83);
      $1=$84;
      __label__ = 14; break;
    case 10: 
      var $86=$attr;
      var $87=(($86)|0);
      var $88=HEAP32[(($87)>>2)];
      var $89=$attr;
      var $90=(($89+12)|0);
      var $91=HEAP32[(($90)>>2)];
      var $92=_HPDF_List_Add($88, $91);
      var $93=(($92)|0)!=0;
      if ($93) { __label__ = 11; break; } else { __label__ = 12; break; }
    case 11: 
      var $95=$2;
      var $96=(($95+8)|0);
      var $97=HEAP32[(($96)>>2)];
      var $98=$attr;
      var $99=(($98+12)|0);
      var $100=HEAP32[(($99)>>2)];
      _HPDF_FreeMem($97, $100);
      var $101=$attr;
      var $102=(($101+12)|0);
      HEAP32[(($102)>>2)]=0;
      var $103=$2;
      var $104=(($103+12)|0);
      var $105=HEAP32[(($104)>>2)];
      var $106=_HPDF_Error_GetCode($105);
      $1=$106;
      __label__ = 14; break;
    case 12: 
      var $108=$attr;
      var $109=(($108+8)|0);
      HEAP32[(($109)>>2)]=0;
      __label__ = 13; break;
    case 13: 
      $1=0;
      __label__ = 14; break;
    case 14: 
      var $112=$1;
      ;
      return $112;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_MemStream_InWrite["X"]=1;

function _HPDF_MemStream_WriteFunc($stream, $ptr, $siz) {
  var __stackBase__  = STACKTOP; STACKTOP += 8; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3=__stackBase__;
      var $4;
      var $wsiz=(__stackBase__)+(4);
      var $ret;
      $2=$stream;
      HEAP32[(($3)>>2)]=$ptr;
      $4=$siz;
      var $5=$4;
      HEAP32[(($wsiz)>>2)]=$5;
      var $6=$2;
      var $7=(($6+12)|0);
      var $8=HEAP32[(($7)>>2)];
      var $9=_HPDF_Error_GetCode($8);
      var $10=(($9)|0)!=0;
      if ($10) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      $1=4188;
      __label__ = 10; break;
    case 4: 
      __label__ = 5; break;
    case 5: 
      var $14=HEAPU32[(($wsiz)>>2)];
      var $15=(($14)>>>0) > 0;
      if ($15) { __label__ = 6; break; } else { __label__ = 9; break; }
    case 6: 
      var $17=$2;
      var $18=_HPDF_MemStream_InWrite($17, $3, $wsiz);
      $ret=$18;
      var $19=$ret;
      var $20=(($19)|0)!=0;
      if ($20) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $22=$ret;
      $1=$22;
      __label__ = 10; break;
    case 8: 
      __label__ = 5; break;
    case 9: 
      $1=0;
      __label__ = 10; break;
    case 10: 
      var $26=$1;
      STACKTOP = __stackBase__;
      return $26;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_MemStream_SeekFunc($stream, $pos, $mode) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $attr;
      $2=$stream;
      $3=$pos;
      $4=$mode;
      var $5=$2;
      var $6=(($5+44)|0);
      var $7=HEAP32[(($6)>>2)];
      var $8=$7;
      $attr=$8;
      var $9=$4;
      var $10=(($9)|0)==1;
      if ($10) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $12=$attr;
      var $13=(($12+16)|0);
      var $14=HEAP32[(($13)>>2)];
      var $15=$attr;
      var $16=(($15+4)|0);
      var $17=HEAP32[(($16)>>2)];
      var $18=((($14)*($17))|0);
      var $19=$3;
      var $20=((($19)+($18))|0);
      $3=$20;
      var $21=$attr;
      var $22=(($21+20)|0);
      var $23=HEAP32[(($22)>>2)];
      var $24=$3;
      var $25=((($24)+($23))|0);
      $3=$25;
      __label__ = 7; break;
    case 4: 
      var $27=$4;
      var $28=(($27)|0)==2;
      if ($28) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $30=$2;
      var $31=(($30+16)|0);
      var $32=HEAP32[(($31)>>2)];
      var $33=$3;
      var $34=((($32)-($33))|0);
      $3=$34;
      __label__ = 6; break;
    case 6: 
      __label__ = 7; break;
    case 7: 
      var $37=$3;
      var $38=$2;
      var $39=(($38+16)|0);
      var $40=HEAPU32[(($39)>>2)];
      var $41=(($37)>>>0) > (($40)>>>0);
      if ($41) { __label__ = 8; break; } else { __label__ = 9; break; }
    case 8: 
      var $43=$2;
      var $44=(($43+12)|0);
      var $45=HEAP32[(($44)>>2)];
      var $46=_HPDF_SetError($45, 4184, 0);
      $1=$46;
      __label__ = 15; break;
    case 9: 
      var $48=$2;
      var $49=(($48+16)|0);
      var $50=HEAP32[(($49)>>2)];
      var $51=(($50)|0)==0;
      if ($51) { __label__ = 10; break; } else { __label__ = 11; break; }
    case 10: 
      $1=0;
      __label__ = 15; break;
    case 11: 
      var $54=$3;
      var $55=$attr;
      var $56=(($55+4)|0);
      var $57=HEAPU32[(($56)>>2)];
      var $58=Math.floor(((($54)>>>0))/((($57)>>>0)));
      var $59=$attr;
      var $60=(($59+16)|0);
      HEAP32[(($60)>>2)]=$58;
      var $61=$3;
      var $62=$attr;
      var $63=(($62+4)|0);
      var $64=HEAPU32[(($63)>>2)];
      var $65=((($61)>>>0))%((($64)>>>0));
      var $66=$attr;
      var $67=(($66+20)|0);
      HEAP32[(($67)>>2)]=$65;
      var $68=$attr;
      var $69=(($68)|0);
      var $70=HEAP32[(($69)>>2)];
      var $71=$attr;
      var $72=(($71+16)|0);
      var $73=HEAP32[(($72)>>2)];
      var $74=_HPDF_List_ItemAt($70, $73);
      var $75=$attr;
      var $76=(($75+24)|0);
      HEAP32[(($76)>>2)]=$74;
      var $77=$attr;
      var $78=(($77+24)|0);
      var $79=HEAP32[(($78)>>2)];
      var $80=(($79)|0)==0;
      if ($80) { __label__ = 12; break; } else { __label__ = 13; break; }
    case 12: 
      var $82=$2;
      var $83=(($82+12)|0);
      var $84=HEAP32[(($83)>>2)];
      var $85=_HPDF_SetError($84, 4147, 0);
      $1=4147;
      __label__ = 15; break;
    case 13: 
      var $87=$attr;
      var $88=(($87+20)|0);
      var $89=HEAP32[(($88)>>2)];
      var $90=$attr;
      var $91=(($90+24)|0);
      var $92=HEAP32[(($91)>>2)];
      var $93=(($92+$89)|0);
      HEAP32[(($91)>>2)]=$93;
      __label__ = 14; break;
    case 14: 
      $1=0;
      __label__ = 15; break;
    case 15: 
      var $96=$1;
      ;
      return $96;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_MemStream_SeekFunc["X"]=1;

function _HPDF_MemStream_GetBufPtr($stream, $index, $length) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $ret;
      var $attr;
      $2=$stream;
      $3=$index;
      $4=$length;
      var $5=$2;
      var $6=(($5+4)|0);
      var $7=HEAP32[(($6)>>2)];
      var $8=(($7)|0)!=3;
      if ($8) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $10=$2;
      var $11=(($10+12)|0);
      var $12=HEAP32[(($11)>>2)];
      var $13=_HPDF_SetError($12, 4147, 0);
      $1=0;
      __label__ = 10; break;
    case 4: 
      var $15=$2;
      var $16=(($15+44)|0);
      var $17=HEAP32[(($16)>>2)];
      var $18=$17;
      $attr=$18;
      var $19=$attr;
      var $20=(($19)|0);
      var $21=HEAP32[(($20)>>2)];
      var $22=$3;
      var $23=_HPDF_List_ItemAt($21, $22);
      $ret=$23;
      var $24=$ret;
      var $25=(($24)|0)==0;
      if ($25) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $27=$2;
      var $28=(($27+12)|0);
      var $29=HEAP32[(($28)>>2)];
      var $30=_HPDF_SetError($29, 4153, 0);
      var $31=$4;
      HEAP32[(($31)>>2)]=0;
      $1=0;
      __label__ = 10; break;
    case 6: 
      var $33=$attr;
      var $34=(($33)|0);
      var $35=HEAP32[(($34)>>2)];
      var $36=(($35+16)|0);
      var $37=HEAP32[(($36)>>2)];
      var $38=((($37)-(1))|0);
      var $39=$3;
      var $40=(($38)|0)==(($39)|0);
      if ($40) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $42=$attr;
      var $43=(($42+8)|0);
      var $44=HEAP32[(($43)>>2)];
      var $50 = $44;__label__ = 9; break;
    case 8: 
      var $46=$attr;
      var $47=(($46+4)|0);
      var $48=HEAP32[(($47)>>2)];
      var $50 = $48;__label__ = 9; break;
    case 9: 
      var $50;
      var $51=$4;
      HEAP32[(($51)>>2)]=$50;
      var $52=$ret;
      $1=$52;
      __label__ = 10; break;
    case 10: 
      var $54=$1;
      ;
      return $54;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_MemStream_GetBufPtr["X"]=1;

function _HPDF_Stream_Validate($stream) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      $2=$stream;
      var $3=$2;
      var $4=(($3)|0)!=0;
      if ($4) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $6=$2;
      var $7=(($6)|0);
      var $8=HEAP32[(($7)>>2)];
      var $9=(($8)|0)!=1398035021;
      if ($9) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      $1=0;
      __label__ = 6; break;
    case 5: 
      $1=1;
      __label__ = 6; break;
    case 6: 
      var $13=$1;
      ;
      return $13;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_MemStream_FreeData($stream) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $attr;
      var $i;
      $1=$stream;
      var $2=$1;
      var $3=(($2)|0)!=0;
      if ($3) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $5=$1;
      var $6=(($5+4)|0);
      var $7=HEAP32[(($6)>>2)];
      var $8=(($7)|0)!=3;
      if ($8) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      __label__ = 10; break;
    case 5: 
      var $11=$1;
      var $12=(($11+44)|0);
      var $13=HEAP32[(($12)>>2)];
      var $14=$13;
      $attr=$14;
      $i=0;
      __label__ = 6; break;
    case 6: 
      var $16=$i;
      var $17=$attr;
      var $18=(($17)|0);
      var $19=HEAP32[(($18)>>2)];
      var $20=(($19+16)|0);
      var $21=HEAPU32[(($20)>>2)];
      var $22=(($16)>>>0) < (($21)>>>0);
      if ($22) { __label__ = 7; break; } else { __label__ = 9; break; }
    case 7: 
      var $24=$1;
      var $25=(($24+8)|0);
      var $26=HEAP32[(($25)>>2)];
      var $27=$attr;
      var $28=(($27)|0);
      var $29=HEAP32[(($28)>>2)];
      var $30=$i;
      var $31=_HPDF_List_ItemAt($29, $30);
      _HPDF_FreeMem($26, $31);
      __label__ = 8; break;
    case 8: 
      var $33=$i;
      var $34=((($33)+(1))|0);
      $i=$34;
      __label__ = 6; break;
    case 9: 
      var $36=$attr;
      var $37=(($36)|0);
      var $38=HEAP32[(($37)>>2)];
      _HPDF_List_Clear($38);
      var $39=$1;
      var $40=(($39+16)|0);
      HEAP32[(($40)>>2)]=0;
      var $41=$attr;
      var $42=(($41+4)|0);
      var $43=HEAP32[(($42)>>2)];
      var $44=$attr;
      var $45=(($44+8)|0);
      HEAP32[(($45)>>2)]=$43;
      var $46=$attr;
      var $47=(($46+12)|0);
      HEAP32[(($47)>>2)]=0;
      var $48=$attr;
      var $49=(($48+16)|0);
      HEAP32[(($49)>>2)]=0;
      var $50=$attr;
      var $51=(($50+20)|0);
      HEAP32[(($51)>>2)]=0;
      __label__ = 10; break;
    case 10: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_MemStream_FreeData["X"]=1;

function _HPDF_MemStream_FreeFunc($stream) {
  ;
  var __label__;

  var $1;
  var $attr;
  $1=$stream;
  var $2=$1;
  var $3=(($2+44)|0);
  var $4=HEAP32[(($3)>>2)];
  var $5=$4;
  $attr=$5;
  var $6=$1;
  _HPDF_MemStream_FreeData($6);
  var $7=$attr;
  var $8=(($7)|0);
  var $9=HEAP32[(($8)>>2)];
  _HPDF_List_Free($9);
  var $10=$1;
  var $11=(($10+8)|0);
  var $12=HEAP32[(($11)>>2)];
  var $13=$attr;
  var $14=$13;
  _HPDF_FreeMem($12, $14);
  var $15=$1;
  var $16=(($15+44)|0);
  HEAP32[(($16)>>2)]=0;
  ;
  return;
}


function _HPDF_MemStream_New($mmgr, $buf_siz) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $stream;
      var $attr;
      $2=$mmgr;
      $3=$buf_siz;
      var $4=$2;
      var $5=_HPDF_GetMem($4, 48);
      var $6=$5;
      $stream=$6;
      var $7=$stream;
      var $8=(($7)|0)!=0;
      if ($8) { __label__ = 3; break; } else { __label__ = 11; break; }
    case 3: 
      var $10=$2;
      var $11=_HPDF_GetMem($10, 28);
      var $12=$11;
      $attr=$12;
      var $13=$attr;
      var $14=(($13)|0)!=0;
      if ($14) { __label__ = 5; break; } else { __label__ = 4; break; }
    case 4: 
      var $16=$2;
      var $17=$stream;
      var $18=$17;
      _HPDF_FreeMem($16, $18);
      $1=0;
      __label__ = 12; break;
    case 5: 
      var $20=$stream;
      var $21=$20;
      var $22=_HPDF_MemSet($21, 0, 48);
      var $23=$attr;
      var $24=$23;
      var $25=_HPDF_MemSet($24, 0, 28);
      var $26=$2;
      var $27=_HPDF_List_New($26, 20);
      var $28=$attr;
      var $29=(($28)|0);
      HEAP32[(($29)>>2)]=$27;
      var $30=$attr;
      var $31=(($30)|0);
      var $32=HEAP32[(($31)>>2)];
      var $33=(($32)|0)!=0;
      if ($33) { __label__ = 7; break; } else { __label__ = 6; break; }
    case 6: 
      var $35=$2;
      var $36=$stream;
      var $37=$36;
      _HPDF_FreeMem($35, $37);
      var $38=$2;
      var $39=$attr;
      var $40=$39;
      _HPDF_FreeMem($38, $40);
      $1=0;
      __label__ = 12; break;
    case 7: 
      var $42=$stream;
      var $43=(($42)|0);
      HEAP32[(($43)>>2)]=1398035021;
      var $44=$stream;
      var $45=(($44+4)|0);
      HEAP32[(($45)>>2)]=3;
      var $46=$2;
      var $47=(($46)|0);
      var $48=HEAP32[(($47)>>2)];
      var $49=$stream;
      var $50=(($49+12)|0);
      HEAP32[(($50)>>2)]=$48;
      var $51=$2;
      var $52=$stream;
      var $53=(($52+8)|0);
      HEAP32[(($53)>>2)]=$51;
      var $54=$attr;
      var $55=$54;
      var $56=$stream;
      var $57=(($56+44)|0);
      HEAP32[(($57)>>2)]=$55;
      var $58=$3;
      var $59=(($58)>>>0) > 0;
      if ($59) { __label__ = 8; break; } else { __label__ = 9; break; }
    case 8: 
      var $61=$3;
      var $64 = $61;__label__ = 10; break;
    case 9: 
      var $64 = 4096;__label__ = 10; break;
    case 10: 
      var $64;
      var $65=$attr;
      var $66=(($65+4)|0);
      HEAP32[(($66)>>2)]=$64;
      var $67=$attr;
      var $68=(($67+4)|0);
      var $69=HEAP32[(($68)>>2)];
      var $70=$attr;
      var $71=(($70+8)|0);
      HEAP32[(($71)>>2)]=$69;
      var $72=$stream;
      var $73=(($72+20)|0);
      HEAP32[(($73)>>2)]=244;
      var $74=$stream;
      var $75=(($74+24)|0);
      var $76=$75;
      HEAP32[(($76)>>2)]=246;
      var $77=$stream;
      var $78=(($77+28)|0);
      HEAP32[(($78)>>2)]=248;
      var $79=$stream;
      var $80=(($79+36)|0);
      HEAP32[(($80)>>2)]=250;
      var $81=$stream;
      var $82=(($81+40)|0);
      HEAP32[(($82)>>2)]=252;
      var $83=$stream;
      var $84=(($83+32)|0);
      HEAP32[(($84)>>2)]=254;
      __label__ = 11; break;
    case 11: 
      var $86=$stream;
      $1=$86;
      __label__ = 12; break;
    case 12: 
      var $88=$1;
      ;
      return $88;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_MemStream_New["X"]=1;

function _HPDF_MemStream_ReadFunc($stream, $buf, $size) {
  var __stackBase__  = STACKTOP; STACKTOP += 4; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $attr;
      var $buf_size=__stackBase__;
      var $rlen;
      var $tmp_len;
      $2=$stream;
      $3=$buf;
      $4=$size;
      var $5=$2;
      var $6=(($5+44)|0);
      var $7=HEAP32[(($6)>>2)];
      var $8=$7;
      $attr=$8;
      var $9=$4;
      var $10=HEAP32[(($9)>>2)];
      $rlen=$10;
      var $11=$4;
      HEAP32[(($11)>>2)]=0;
      __label__ = 3; break;
    case 3: 
      var $13=$rlen;
      var $14=(($13)>>>0) > 0;
      if ($14) { __label__ = 4; break; } else { __label__ = 20; break; }
    case 4: 
      var $16=$attr;
      var $17=(($16)|0);
      var $18=HEAP32[(($17)>>2)];
      var $19=(($18+16)|0);
      var $20=HEAP32[(($19)>>2)];
      var $21=(($20)|0)==0;
      if ($21) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      $1=4184;
      __label__ = 21; break;
    case 6: 
      var $24=$attr;
      var $25=(($24)|0);
      var $26=HEAP32[(($25)>>2)];
      var $27=(($26+16)|0);
      var $28=HEAP32[(($27)>>2)];
      var $29=((($28)-(1))|0);
      var $30=$attr;
      var $31=(($30+16)|0);
      var $32=HEAPU32[(($31)>>2)];
      var $33=(($29)>>>0) > (($32)>>>0);
      if ($33) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $35=$attr;
      var $36=(($35+4)|0);
      var $37=HEAP32[(($36)>>2)];
      var $38=$attr;
      var $39=(($38+20)|0);
      var $40=HEAP32[(($39)>>2)];
      var $41=((($37)-($40))|0);
      $tmp_len=$41;
      __label__ = 12; break;
    case 8: 
      var $43=$attr;
      var $44=(($43)|0);
      var $45=HEAP32[(($44)>>2)];
      var $46=(($45+16)|0);
      var $47=HEAP32[(($46)>>2)];
      var $48=((($47)-(1))|0);
      var $49=$attr;
      var $50=(($49+16)|0);
      var $51=HEAP32[(($50)>>2)];
      var $52=(($48)|0)==(($51)|0);
      if ($52) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      var $54=$attr;
      var $55=(($54+8)|0);
      var $56=HEAP32[(($55)>>2)];
      var $57=$attr;
      var $58=(($57+20)|0);
      var $59=HEAP32[(($58)>>2)];
      var $60=((($56)-($59))|0);
      $tmp_len=$60;
      __label__ = 11; break;
    case 10: 
      $1=4184;
      __label__ = 21; break;
    case 11: 
      __label__ = 12; break;
    case 12: 
      var $64=$attr;
      var $65=(($64+24)|0);
      var $66=HEAP32[(($65)>>2)];
      var $67=(($66)|0)!=0;
      if ($67) { __label__ = 14; break; } else { __label__ = 13; break; }
    case 13: 
      var $69=$attr;
      var $70=(($69)|0);
      var $71=HEAP32[(($70)>>2)];
      var $72=$attr;
      var $73=(($72+16)|0);
      var $74=HEAP32[(($73)>>2)];
      var $75=_HPDF_List_ItemAt($71, $74);
      var $76=$attr;
      var $77=(($76+24)|0);
      HEAP32[(($77)>>2)]=$75;
      __label__ = 14; break;
    case 14: 
      var $79=$tmp_len;
      var $80=$rlen;
      var $81=(($79)>>>0) >= (($80)>>>0);
      if ($81) { __label__ = 15; break; } else { __label__ = 16; break; }
    case 15: 
      var $83=$3;
      var $84=$attr;
      var $85=(($84+24)|0);
      var $86=HEAP32[(($85)>>2)];
      var $87=$rlen;
      var $88=_HPDF_MemCpy($83, $86, $87);
      var $89=$rlen;
      var $90=$attr;
      var $91=(($90+20)|0);
      var $92=HEAP32[(($91)>>2)];
      var $93=((($92)+($89))|0);
      HEAP32[(($91)>>2)]=$93;
      var $94=$rlen;
      var $95=$4;
      var $96=HEAP32[(($95)>>2)];
      var $97=((($96)+($94))|0);
      HEAP32[(($95)>>2)]=$97;
      var $98=$rlen;
      var $99=$attr;
      var $100=(($99+24)|0);
      var $101=HEAP32[(($100)>>2)];
      var $102=(($101+$98)|0);
      HEAP32[(($100)>>2)]=$102;
      $1=0;
      __label__ = 21; break;
    case 16: 
      var $104=$3;
      var $105=$attr;
      var $106=(($105+24)|0);
      var $107=HEAP32[(($106)>>2)];
      var $108=$tmp_len;
      var $109=_HPDF_MemCpy($104, $107, $108);
      $3=$109;
      var $110=$tmp_len;
      var $111=$rlen;
      var $112=((($111)-($110))|0);
      $rlen=$112;
      var $113=$tmp_len;
      var $114=$4;
      var $115=HEAP32[(($114)>>2)];
      var $116=((($115)+($113))|0);
      HEAP32[(($114)>>2)]=$116;
      var $117=$attr;
      var $118=(($117+16)|0);
      var $119=HEAP32[(($118)>>2)];
      var $120=$attr;
      var $121=(($120)|0);
      var $122=HEAP32[(($121)>>2)];
      var $123=(($122+16)|0);
      var $124=HEAP32[(($123)>>2)];
      var $125=((($124)-(1))|0);
      var $126=(($119)|0)==(($125)|0);
      if ($126) { __label__ = 17; break; } else { __label__ = 18; break; }
    case 17: 
      var $128=$tmp_len;
      var $129=$attr;
      var $130=(($129+24)|0);
      var $131=HEAP32[(($130)>>2)];
      var $132=(($131+$128)|0);
      HEAP32[(($130)>>2)]=$132;
      var $133=$tmp_len;
      var $134=$attr;
      var $135=(($134+20)|0);
      var $136=HEAP32[(($135)>>2)];
      var $137=((($136)+($133))|0);
      HEAP32[(($135)>>2)]=$137;
      $1=4184;
      __label__ = 21; break;
    case 18: 
      var $139=$attr;
      var $140=(($139+16)|0);
      var $141=HEAP32[(($140)>>2)];
      var $142=((($141)+(1))|0);
      HEAP32[(($140)>>2)]=$142;
      var $143=$attr;
      var $144=(($143+20)|0);
      HEAP32[(($144)>>2)]=0;
      var $145=$2;
      var $146=$attr;
      var $147=(($146+16)|0);
      var $148=HEAP32[(($147)>>2)];
      var $149=_HPDF_MemStream_GetBufPtr($145, $148, $buf_size);
      var $150=$attr;
      var $151=(($150+24)|0);
      HEAP32[(($151)>>2)]=$149;
      __label__ = 19; break;
    case 19: 
      __label__ = 3; break;
    case 20: 
      $1=0;
      __label__ = 21; break;
    case 21: 
      var $155=$1;
      STACKTOP = __stackBase__;
      return $155;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_MemStream_ReadFunc["X"]=1;

function _HPDF_MemStream_Rewrite($stream, $buf, $size) {
  var __stackBase__  = STACKTOP; STACKTOP += 4; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $attr;
      var $buf_size=__stackBase__;
      var $rlen;
      var $tmp_len;
      var $ret;
      $2=$stream;
      $3=$buf;
      $4=$size;
      var $5=$2;
      var $6=(($5+44)|0);
      var $7=HEAP32[(($6)>>2)];
      var $8=$7;
      $attr=$8;
      var $9=$4;
      $rlen=$9;
      __label__ = 3; break;
    case 3: 
      var $11=$rlen;
      var $12=(($11)>>>0) > 0;
      if ($12) { __label__ = 4; break; } else { __label__ = 16; break; }
    case 4: 
      var $14=$attr;
      var $15=(($14)|0);
      var $16=HEAP32[(($15)>>2)];
      var $17=(($16+16)|0);
      var $18=HEAPU32[(($17)>>2)];
      var $19=$attr;
      var $20=(($19+16)|0);
      var $21=HEAPU32[(($20)>>2)];
      var $22=(($18)>>>0) <= (($21)>>>0);
      if ($22) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $24=$2;
      var $25=$3;
      var $26=$rlen;
      var $27=_HPDF_MemStream_WriteFunc($24, $25, $26);
      $ret=$27;
      var $28=$attr;
      var $29=(($28)|0);
      var $30=HEAP32[(($29)>>2)];
      var $31=(($30+16)|0);
      var $32=HEAP32[(($31)>>2)];
      var $33=$attr;
      var $34=(($33+16)|0);
      HEAP32[(($34)>>2)]=$32;
      var $35=$attr;
      var $36=(($35+8)|0);
      var $37=HEAP32[(($36)>>2)];
      var $38=$attr;
      var $39=(($38+20)|0);
      HEAP32[(($39)>>2)]=$37;
      var $40=$attr;
      var $41=(($40+12)|0);
      var $42=HEAP32[(($41)>>2)];
      var $43=$attr;
      var $44=(($43+24)|0);
      HEAP32[(($44)>>2)]=$42;
      var $45=$ret;
      $1=$45;
      __label__ = 17; break;
    case 6: 
      var $47=$attr;
      var $48=(($47)|0);
      var $49=HEAP32[(($48)>>2)];
      var $50=(($49+16)|0);
      var $51=HEAP32[(($50)>>2)];
      var $52=$attr;
      var $53=(($52+16)|0);
      var $54=HEAP32[(($53)>>2)];
      var $55=(($51)|0)==(($54)|0);
      if ($55) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $57=$attr;
      var $58=(($57+8)|0);
      var $59=HEAP32[(($58)>>2)];
      var $60=$attr;
      var $61=(($60+20)|0);
      var $62=HEAP32[(($61)>>2)];
      var $63=((($59)-($62))|0);
      $tmp_len=$63;
      __label__ = 9; break;
    case 8: 
      var $65=$attr;
      var $66=(($65+4)|0);
      var $67=HEAP32[(($66)>>2)];
      var $68=$attr;
      var $69=(($68+20)|0);
      var $70=HEAP32[(($69)>>2)];
      var $71=((($67)-($70))|0);
      $tmp_len=$71;
      __label__ = 9; break;
    case 9: 
      __label__ = 10; break;
    case 10: 
      var $74=$tmp_len;
      var $75=$rlen;
      var $76=(($74)>>>0) >= (($75)>>>0);
      if ($76) { __label__ = 11; break; } else { __label__ = 12; break; }
    case 11: 
      var $78=$attr;
      var $79=(($78+24)|0);
      var $80=HEAP32[(($79)>>2)];
      var $81=$3;
      var $82=$rlen;
      var $83=_HPDF_MemCpy($80, $81, $82);
      var $84=$rlen;
      var $85=$attr;
      var $86=(($85+20)|0);
      var $87=HEAP32[(($86)>>2)];
      var $88=((($87)+($84))|0);
      HEAP32[(($86)>>2)]=$88;
      var $89=$rlen;
      var $90=$attr;
      var $91=(($90+24)|0);
      var $92=HEAP32[(($91)>>2)];
      var $93=(($92+$89)|0);
      HEAP32[(($91)>>2)]=$93;
      $1=0;
      __label__ = 17; break;
    case 12: 
      var $95=$attr;
      var $96=(($95+24)|0);
      var $97=HEAP32[(($96)>>2)];
      var $98=$3;
      var $99=$tmp_len;
      var $100=_HPDF_MemCpy($97, $98, $99);
      var $101=$tmp_len;
      var $102=$3;
      var $103=(($102+$101)|0);
      $3=$103;
      var $104=$tmp_len;
      var $105=$rlen;
      var $106=((($105)-($104))|0);
      $rlen=$106;
      var $107=$attr;
      var $108=(($107+16)|0);
      var $109=HEAP32[(($108)>>2)];
      var $110=((($109)+(1))|0);
      HEAP32[(($108)>>2)]=$110;
      var $111=$attr;
      var $112=(($111)|0);
      var $113=HEAP32[(($112)>>2)];
      var $114=(($113+16)|0);
      var $115=HEAPU32[(($114)>>2)];
      var $116=$attr;
      var $117=(($116+16)|0);
      var $118=HEAPU32[(($117)>>2)];
      var $119=(($115)>>>0) > (($118)>>>0);
      if ($119) { __label__ = 13; break; } else { __label__ = 14; break; }
    case 13: 
      var $121=$attr;
      var $122=(($121+20)|0);
      HEAP32[(($122)>>2)]=0;
      var $123=$2;
      var $124=$attr;
      var $125=(($124+16)|0);
      var $126=HEAP32[(($125)>>2)];
      var $127=_HPDF_MemStream_GetBufPtr($123, $126, $buf_size);
      var $128=$attr;
      var $129=(($128+24)|0);
      HEAP32[(($129)>>2)]=$127;
      __label__ = 14; break;
    case 14: 
      __label__ = 15; break;
    case 15: 
      __label__ = 3; break;
    case 16: 
      $1=0;
      __label__ = 17; break;
    case 17: 
      var $134=$1;
      STACKTOP = __stackBase__;
      return $134;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_MemStream_Rewrite["X"]=1;

function _HPDF_String_New($mmgr, $value, $encoder) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $obj;
      $2=$mmgr;
      $3=$value;
      $4=$encoder;
      var $5=$2;
      var $6=_HPDF_GetMem($5, 28);
      var $7=$6;
      $obj=$7;
      var $8=$obj;
      var $9=(($8)|0)!=0;
      if ($9) { __label__ = 3; break; } else { __label__ = 6; break; }
    case 3: 
      var $11=$obj;
      var $12=(($11)|0);
      var $13=$12;
      var $14=_HPDF_MemSet($13, 0, 8);
      var $15=$obj;
      var $16=(($15)|0);
      var $17=(($16+6)|0);
      HEAP16[(($17)>>1)]=7;
      var $18=$2;
      var $19=$obj;
      var $20=(($19+8)|0);
      HEAP32[(($20)>>2)]=$18;
      var $21=$2;
      var $22=(($21)|0);
      var $23=HEAP32[(($22)>>2)];
      var $24=$obj;
      var $25=(($24+12)|0);
      HEAP32[(($25)>>2)]=$23;
      var $26=$4;
      var $27=$obj;
      var $28=(($27+16)|0);
      HEAP32[(($28)>>2)]=$26;
      var $29=$obj;
      var $30=(($29+20)|0);
      HEAP32[(($30)>>2)]=0;
      var $31=$obj;
      var $32=(($31+24)|0);
      HEAP32[(($32)>>2)]=0;
      var $33=$obj;
      var $34=$3;
      var $35=_HPDF_String_SetValue($33, $34);
      var $36=(($35)|0)!=0;
      if ($36) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      var $38=$obj;
      var $39=(($38+8)|0);
      var $40=HEAP32[(($39)>>2)];
      var $41=$obj;
      var $42=$41;
      _HPDF_FreeMem($40, $42);
      $1=0;
      __label__ = 7; break;
    case 5: 
      __label__ = 6; break;
    case 6: 
      var $45=$obj;
      $1=$45;
      __label__ = 7; break;
    case 7: 
      var $47=$1;
      ;
      return $47;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_String_New["X"]=1;

function _HPDF_String_SetValue($obj, $value) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $len;
      var $ret;
      $2=$obj;
      $3=$value;
      $ret=0;
      var $4=$2;
      var $5=(($4+20)|0);
      var $6=HEAP32[(($5)>>2)];
      var $7=(($6)|0)!=0;
      if ($7) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $9=$2;
      var $10=(($9+8)|0);
      var $11=HEAP32[(($10)>>2)];
      var $12=$2;
      var $13=(($12+20)|0);
      var $14=HEAP32[(($13)>>2)];
      _HPDF_FreeMem($11, $14);
      var $15=$2;
      var $16=(($15+24)|0);
      HEAP32[(($16)>>2)]=0;
      __label__ = 4; break;
    case 4: 
      var $18=$3;
      var $19=_HPDF_StrLen($18, 65536);
      $len=$19;
      var $20=$len;
      var $21=(($20)>>>0) > 65535;
      if ($21) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $23=$2;
      var $24=(($23+12)|0);
      var $25=HEAP32[(($24)>>2)];
      var $26=_HPDF_SetError($25, 4187, 0);
      $1=$26;
      __label__ = 9; break;
    case 6: 
      var $28=$2;
      var $29=(($28+8)|0);
      var $30=HEAP32[(($29)>>2)];
      var $31=$len;
      var $32=((($31)+(1))|0);
      var $33=_HPDF_GetMem($30, $32);
      var $34=$2;
      var $35=(($34+20)|0);
      HEAP32[(($35)>>2)]=$33;
      var $36=$2;
      var $37=(($36+20)|0);
      var $38=HEAP32[(($37)>>2)];
      var $39=(($38)|0)!=0;
      if ($39) { __label__ = 8; break; } else { __label__ = 7; break; }
    case 7: 
      var $41=$2;
      var $42=(($41+12)|0);
      var $43=HEAP32[(($42)>>2)];
      var $44=_HPDF_Error_GetCode($43);
      $1=$44;
      __label__ = 9; break;
    case 8: 
      var $46=$2;
      var $47=(($46+20)|0);
      var $48=HEAP32[(($47)>>2)];
      var $49=$3;
      var $50=$2;
      var $51=(($50+20)|0);
      var $52=HEAP32[(($51)>>2)];
      var $53=$len;
      var $54=(($52+$53)|0);
      var $55=_HPDF_StrCpy($48, $49, $54);
      var $56=$len;
      var $57=$2;
      var $58=(($57+24)|0);
      HEAP32[(($58)>>2)]=$56;
      var $59=$ret;
      $1=$59;
      __label__ = 9; break;
    case 9: 
      var $61=$1;
      ;
      return $61;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_String_SetValue["X"]=1;

function _HPDF_String_Free($obj) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      $1=$obj;
      var $2=$1;
      var $3=(($2)|0)!=0;
      if ($3) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      __label__ = 5; break;
    case 4: 
      var $6=$1;
      var $7=(($6+8)|0);
      var $8=HEAP32[(($7)>>2)];
      var $9=$1;
      var $10=(($9+20)|0);
      var $11=HEAP32[(($10)>>2)];
      _HPDF_FreeMem($8, $11);
      var $12=$1;
      var $13=(($12+8)|0);
      var $14=HEAP32[(($13)>>2)];
      var $15=$1;
      var $16=$15;
      _HPDF_FreeMem($14, $16);
      __label__ = 5; break;
    case 5: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_String_Write($obj, $stream, $e) {
  var __stackBase__  = STACKTOP; STACKTOP += 532; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $ret;
      var $src;
      var $buf=__stackBase__;
      var $tmp_len;
      var $pbuf;
      var $len;
      var $parse_state=(__stackBase__)+(512);
      var $i;
      var $b;
      var $tmp_unicode=(__stackBase__)+(528);
      var $btype;
      var $b2;
      var $char_code;
      $2=$obj;
      $3=$stream;
      $4=$e;
      var $5=$4;
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $8=$4;
      _HPDF_Encrypt_Reset($8);
      __label__ = 4; break;
    case 4: 
      var $10=$2;
      var $11=(($10+16)|0);
      var $12=HEAP32[(($11)>>2)];
      var $13=(($12)|0)==0;
      if ($13) { __label__ = 5; break; } else { __label__ = 12; break; }
    case 5: 
      var $15=$4;
      var $16=(($15)|0)!=0;
      if ($16) { __label__ = 6; break; } else { __label__ = 11; break; }
    case 6: 
      var $18=$3;
      var $19=_HPDF_Stream_WriteChar($18, 60);
      $ret=$19;
      var $20=(($19)|0)!=0;
      if ($20) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $22=$ret;
      $1=$22;
      __label__ = 37; break;
    case 8: 
      var $24=$3;
      var $25=$2;
      var $26=(($25+20)|0);
      var $27=HEAP32[(($26)>>2)];
      var $28=$2;
      var $29=(($28+20)|0);
      var $30=HEAP32[(($29)>>2)];
      var $31=_HPDF_StrLen($30, -1);
      var $32=$4;
      var $33=_HPDF_Stream_WriteBinary($24, $27, $31, $32);
      $ret=$33;
      var $34=(($33)|0)!=0;
      if ($34) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      var $36=$ret;
      $1=$36;
      __label__ = 37; break;
    case 10: 
      var $38=$3;
      var $39=_HPDF_Stream_WriteChar($38, 62);
      $1=$39;
      __label__ = 37; break;
    case 11: 
      var $41=$3;
      var $42=$2;
      var $43=(($42+20)|0);
      var $44=HEAP32[(($43)>>2)];
      var $45=_HPDF_Stream_WriteEscapeText($41, $44);
      $1=$45;
      __label__ = 37; break;
    case 12: 
      var $47=$2;
      var $48=(($47+20)|0);
      var $49=HEAP32[(($48)>>2)];
      $src=$49;
      $tmp_len=0;
      var $50=(($buf)|0);
      $pbuf=$50;
      var $51=$2;
      var $52=(($51+24)|0);
      var $53=HEAP32[(($52)>>2)];
      $len=$53;
      var $54=$3;
      var $55=_HPDF_Stream_WriteChar($54, 60);
      $ret=$55;
      var $56=(($55)|0)!=0;
      if ($56) { __label__ = 13; break; } else { __label__ = 14; break; }
    case 13: 
      var $58=$ret;
      $1=$58;
      __label__ = 37; break;
    case 14: 
      var $60=$3;
      var $61=$4;
      var $62=_HPDF_Stream_WriteBinary($60, ((STRING_TABLE._UNICODE_HEADER)|0), 2, $61);
      $ret=$62;
      var $63=(($62)|0)!=0;
      if ($63) { __label__ = 15; break; } else { __label__ = 16; break; }
    case 15: 
      var $65=$ret;
      $1=$65;
      __label__ = 37; break;
    case 16: 
      var $67=$2;
      var $68=(($67+16)|0);
      var $69=HEAP32[(($68)>>2)];
      var $70=$src;
      var $71=$len;
      _HPDF_Encoder_SetParseText($69, $parse_state, $70, $71);
      $i=0;
      __label__ = 17; break;
    case 17: 
      var $73=$i;
      var $74=$len;
      var $75=(($73)>>>0) < (($74)>>>0);
      if ($75) { __label__ = 18; break; } else { __label__ = 29; break; }
    case 18: 
      var $77=$i;
      var $78=$src;
      var $79=(($78+$77)|0);
      var $80=HEAP8[($79)];
      $b=$80;
      var $81=$2;
      var $82=(($81+16)|0);
      var $83=HEAP32[(($82)>>2)];
      var $84=_HPDF_Encoder_ByteType($83, $parse_state);
      $btype=$84;
      var $85=$tmp_len;
      var $86=(($85)>>>0) >= 255;
      if ($86) { __label__ = 19; break; } else { __label__ = 22; break; }
    case 19: 
      var $88=$3;
      var $89=(($buf)|0);
      var $90=$tmp_len;
      var $91=((($90<<1))|0);
      var $92=$4;
      var $93=_HPDF_Stream_WriteBinary($88, $89, $91, $92);
      $ret=$93;
      var $94=(($93)|0)!=0;
      if ($94) { __label__ = 20; break; } else { __label__ = 21; break; }
    case 20: 
      var $96=$ret;
      $1=$96;
      __label__ = 37; break;
    case 21: 
      $tmp_len=0;
      var $98=(($buf)|0);
      $pbuf=$98;
      __label__ = 22; break;
    case 22: 
      var $100=$btype;
      var $101=(($100)|0)!=2;
      if ($101) { __label__ = 23; break; } else { __label__ = 27; break; }
    case 23: 
      var $103=$btype;
      var $104=(($103)|0)==1;
      if ($104) { __label__ = 24; break; } else { __label__ = 25; break; }
    case 24: 
      var $106=$i;
      var $107=((($106)+(1))|0);
      var $108=$src;
      var $109=(($108+$107)|0);
      var $110=HEAP8[($109)];
      $b2=$110;
      var $111=$b;
      var $112=(($111)&255);
      var $113=((($112<<8))|0);
      var $114=$b2;
      var $115=(($114)&255);
      var $116=((($113)+($115))|0);
      var $117=(($116) & 65535);
      $char_code=$117;
      var $118=$2;
      var $119=(($118+16)|0);
      var $120=HEAP32[(($119)>>2)];
      var $121=$char_code;
      var $122=_HPDF_Encoder_ToUnicode($120, $121);
      HEAP16[(($tmp_unicode)>>1)]=$122;
      __label__ = 26; break;
    case 25: 
      var $124=$2;
      var $125=(($124+16)|0);
      var $126=HEAP32[(($125)>>2)];
      var $127=$b;
      var $128=(($127)&255);
      var $129=_HPDF_Encoder_ToUnicode($126, $128);
      HEAP16[(($tmp_unicode)>>1)]=$129;
      __label__ = 26; break;
    case 26: 
      _HPDF_UInt16Swap($tmp_unicode);
      var $131=$pbuf;
      var $132=$tmp_unicode;
      var $133=_HPDF_MemCpy($131, $132, 2);
      var $134=$pbuf;
      var $135=(($134+2)|0);
      $pbuf=$135;
      var $136=$tmp_len;
      var $137=((($136)+(1))|0);
      $tmp_len=$137;
      __label__ = 27; break;
    case 27: 
      __label__ = 28; break;
    case 28: 
      var $140=$i;
      var $141=((($140)+(1))|0);
      $i=$141;
      __label__ = 17; break;
    case 29: 
      var $143=$tmp_len;
      var $144=(($143)>>>0) > 0;
      if ($144) { __label__ = 30; break; } else { __label__ = 33; break; }
    case 30: 
      var $146=$3;
      var $147=(($buf)|0);
      var $148=$tmp_len;
      var $149=((($148<<1))|0);
      var $150=$4;
      var $151=_HPDF_Stream_WriteBinary($146, $147, $149, $150);
      $ret=$151;
      var $152=(($151)|0)!=0;
      if ($152) { __label__ = 31; break; } else { __label__ = 32; break; }
    case 31: 
      var $154=$ret;
      $1=$154;
      __label__ = 37; break;
    case 32: 
      __label__ = 33; break;
    case 33: 
      var $157=$3;
      var $158=_HPDF_Stream_WriteChar($157, 62);
      $ret=$158;
      var $159=(($158)|0)!=0;
      if ($159) { __label__ = 34; break; } else { __label__ = 35; break; }
    case 34: 
      var $161=$ret;
      $1=$161;
      __label__ = 37; break;
    case 35: 
      __label__ = 36; break;
    case 36: 
      $1=0;
      __label__ = 37; break;
    case 37: 
      var $165=$1;
      STACKTOP = __stackBase__;
      return $165;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_String_Write["X"]=1;

function _HPDF_LoadU3DFromFile($pdf, $filename) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $imagedata;
      var $image;
      $2=$pdf;
      $3=$filename;
      var $4=$2;
      var $5=_HPDF_HasDoc($4);
      var $6=(($5)|0)!=0;
      if ($6) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=0;
      __label__ = 10; break;
    case 4: 
      var $9=$2;
      var $10=(($9+8)|0);
      var $11=HEAP32[(($10)>>2)];
      var $12=$3;
      var $13=_HPDF_FileReader_New($11, $12);
      $imagedata=$13;
      var $14=$imagedata;
      var $15=_HPDF_Stream_Validate($14);
      var $16=(($15)|0)!=0;
      if ($16) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $18=$2;
      var $19=(($18+8)|0);
      var $20=HEAP32[(($19)>>2)];
      var $21=$imagedata;
      var $22=$2;
      var $23=(($22+20)|0);
      var $24=HEAP32[(($23)>>2)];
      var $25=_HPDF_U3D_LoadU3D($20, $21, $24);
      $image=$25;
      __label__ = 7; break;
    case 6: 
      $image=0;
      __label__ = 7; break;
    case 7: 
      var $28=$imagedata;
      _HPDF_Stream_Free($28);
      var $29=$image;
      var $30=(($29)|0)!=0;
      if ($30) { __label__ = 9; break; } else { __label__ = 8; break; }
    case 8: 
      var $32=$2;
      var $33=(($32+40)|0);
      var $34=_HPDF_CheckError($33);
      __label__ = 9; break;
    case 9: 
      var $36=$image;
      $1=$36;
      __label__ = 10; break;
    case 10: 
      var $38=$1;
      ;
      return $38;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_U3D_LoadU3D($mmgr, $u3d_data, $xref) {
  var __stackBase__  = STACKTOP; STACKTOP += 4104; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $u3d;
      var $type=__stackBase__;
      var $buf=(__stackBase__)+(4);
      var $len=(__stackBase__)+(4100);
      var $ret;
      $2=$mmgr;
      $3=$u3d_data;
      $4=$xref;
      var $5=$2;
      var $6=$4;
      var $7=_HPDF_DictStream_New($5, $6);
      $u3d=$7;
      var $8=$u3d;
      var $9=(($8)|0)!=0;
      if ($9) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=0;
      __label__ = 23; break;
    case 4: 
      var $12=$u3d;
      var $13=(($12)|0);
      var $14=(($13+6)|0);
      var $15=HEAPU16[(($14)>>1)];
      var $16=(($15)&65535);
      var $17=$16 | 1280;
      var $18=(($17) & 65535);
      HEAP16[(($14)>>1)]=$18;
      var $19=$u3d;
      var $20=(($19+40)|0);
      HEAP32[(($20)>>2)]=0;
      var $21=$u3d;
      var $22=_HPDF_Dict_AddName($21, ((STRING_TABLE.__str1732)|0), ((STRING_TABLE.__str41736)|0));
      var $23=(($22)|0)!=0;
      if ($23) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $25=$u3d;
      _HPDF_Dict_Free($25);
      $1=0;
      __label__ = 23; break;
    case 6: 
      var $27=$3;
      var $28=_Get3DStreamType($27, $type);
      var $29=(($28)|0)!=0;
      if ($29) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $31=$u3d;
      _HPDF_Dict_Free($31);
      $1=0;
      __label__ = 23; break;
    case 8: 
      var $33=$u3d;
      var $34=HEAP32[(($type)>>2)];
      var $35=_HPDF_Dict_AddName($33, ((STRING_TABLE.__str21734)|0), $34);
      var $36=(($35)|0)!=0;
      if ($36) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      var $38=$u3d;
      _HPDF_Dict_Free($38);
      $1=0;
      __label__ = 23; break;
    case 10: 
      __label__ = 11; break;
    case 11: 
      HEAP32[(($len)>>2)]=4096;
      var $41=$3;
      var $42=(($buf)|0);
      var $43=_HPDF_Stream_Read($41, $42, $len);
      $ret=$43;
      var $44=$ret;
      var $45=(($44)|0)!=0;
      if ($45) { __label__ = 12; break; } else { __label__ = 19; break; }
    case 12: 
      var $47=$ret;
      var $48=(($47)|0)==4184;
      if ($48) { __label__ = 13; break; } else { __label__ = 18; break; }
    case 13: 
      var $50=HEAPU32[(($len)>>2)];
      var $51=(($50)>>>0) > 0;
      if ($51) { __label__ = 14; break; } else { __label__ = 17; break; }
    case 14: 
      var $53=$u3d;
      var $54=(($53+36)|0);
      var $55=HEAP32[(($54)>>2)];
      var $56=(($buf)|0);
      var $57=HEAP32[(($len)>>2)];
      var $58=_HPDF_Stream_Write($55, $56, $57);
      $ret=$58;
      var $59=$ret;
      var $60=(($59)|0)!=0;
      if ($60) { __label__ = 15; break; } else { __label__ = 16; break; }
    case 15: 
      var $62=$u3d;
      _HPDF_Dict_Free($62);
      $1=0;
      __label__ = 23; break;
    case 16: 
      __label__ = 17; break;
    case 17: 
      __label__ = 22; break;
    case 18: 
      var $66=$u3d;
      _HPDF_Dict_Free($66);
      $1=0;
      __label__ = 23; break;
    case 19: 
      var $68=$u3d;
      var $69=(($68+36)|0);
      var $70=HEAP32[(($69)>>2)];
      var $71=(($buf)|0);
      var $72=HEAP32[(($len)>>2)];
      var $73=_HPDF_Stream_Write($70, $71, $72);
      var $74=(($73)|0)!=0;
      if ($74) { __label__ = 20; break; } else { __label__ = 21; break; }
    case 20: 
      var $76=$u3d;
      _HPDF_Dict_Free($76);
      $1=0;
      __label__ = 23; break;
    case 21: 
      __label__ = 11; break;
    case 22: 
      var $79=$u3d;
      $1=$79;
      __label__ = 23; break;
    case 23: 
      var $81=$1;
      STACKTOP = __stackBase__;
      return $81;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_U3D_LoadU3D["X"]=1;

function _Get3DStreamType($stream, $type) {
  var __stackBase__  = STACKTOP; STACKTOP += 8; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $tag=__stackBase__;
      var $len=(__stackBase__)+(4);
      $2=$stream;
      $3=$type;
      HEAP32[(($len)>>2)]=4;
      var $4=$2;
      var $5=(($tag)|0);
      var $6=_HPDF_Stream_Read($4, $5, $len);
      var $7=(($6)|0)!=0;
      if ($7) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $9=$2;
      var $10=(($9+12)|0);
      var $11=HEAP32[(($10)>>2)];
      var $12=_HPDF_Error_GetCode($11);
      $1=$12;
      __label__ = 11; break;
    case 4: 
      var $14=$2;
      var $15=_HPDF_Stream_Seek($14, 0, 0);
      var $16=(($15)|0)!=0;
      if ($16) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $18=$2;
      var $19=(($18+12)|0);
      var $20=HEAP32[(($19)>>2)];
      var $21=_HPDF_Error_GetCode($20);
      $1=$21;
      __label__ = 11; break;
    case 6: 
      var $23=(($tag)|0);
      var $24=_HPDF_MemCmp($23, ((STRING_TABLE._u3d)|0), 4);
      var $25=(($24)|0)==0;
      if ($25) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $27=$3;
      HEAP32[(($27)>>2)]=((STRING_TABLE._u3d)|0);
      $1=0;
      __label__ = 11; break;
    case 8: 
      var $29=(($tag)|0);
      var $30=_HPDF_MemCmp($29, ((STRING_TABLE._prc)|0), 3);
      var $31=(($30)|0)==0;
      if ($31) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      var $33=$3;
      HEAP32[(($33)>>2)]=((STRING_TABLE._prc)|0);
      $1=0;
      __label__ = 11; break;
    case 10: 
      $1=4227;
      __label__ = 11; break;
    case 11: 
      var $36=$1;
      STACKTOP = __stackBase__;
      return $36;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_Create3DView($mmgr, $name) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $ret;
      var $view;
      $2=$mmgr;
      $3=$name;
      $ret=0;
      var $4=$3;
      var $5=(($4)|0)==0;
      if ($5) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      var $7=$3;
      var $8=(($7)|0);
      var $9=HEAP8[($8)];
      var $10=(($9 << 24) >> 24);
      var $11=(($10)|0)==0;
      if ($11) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      $1=0;
      __label__ = 14; break;
    case 5: 
      var $14=$2;
      var $15=_HPDF_Dict_New($14);
      $view=$15;
      var $16=$view;
      var $17=(($16)|0)!=0;
      if ($17) { __label__ = 7; break; } else { __label__ = 6; break; }
    case 6: 
      $1=0;
      __label__ = 14; break;
    case 7: 
      var $20=$view;
      var $21=_HPDF_Dict_AddName($20, ((STRING_TABLE.__str51737)|0), ((STRING_TABLE.__str61738)|0));
      $ret=$21;
      var $22=$ret;
      var $23=(($22)|0)!=0;
      if ($23) { __label__ = 8; break; } else { __label__ = 9; break; }
    case 8: 
      var $25=$view;
      _HPDF_Dict_Free($25);
      $1=0;
      __label__ = 14; break;
    case 9: 
      var $27=$view;
      var $28=$2;
      var $29=$3;
      var $30=_HPDF_String_New($28, $29, 0);
      var $31=$30;
      var $32=_HPDF_Dict_Add($27, ((STRING_TABLE.__str71739)|0), $31);
      $ret=$32;
      var $33=$ret;
      var $34=(($33)|0)!=0;
      if ($34) { __label__ = 10; break; } else { __label__ = 11; break; }
    case 10: 
      var $36=$view;
      _HPDF_Dict_Free($36);
      $1=0;
      __label__ = 14; break;
    case 11: 
      var $38=$view;
      var $39=$2;
      var $40=$3;
      var $41=_HPDF_String_New($39, $40, 0);
      var $42=$41;
      var $43=_HPDF_Dict_Add($38, ((STRING_TABLE.__str81740)|0), $42);
      $ret=$43;
      var $44=$ret;
      var $45=(($44)|0)!=0;
      if ($45) { __label__ = 12; break; } else { __label__ = 13; break; }
    case 12: 
      var $47=$view;
      _HPDF_Dict_Free($47);
      $1=0;
      __label__ = 14; break;
    case 13: 
      var $49=$view;
      $1=$49;
      __label__ = 14; break;
    case 14: 
      var $51=$1;
      ;
      return $51;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Create3DView["X"]=1;

function _HPDF_U3D_Add3DView($u3d, $view) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $views;
      var $ret;
      $2=$u3d;
      $3=$view;
      $views=0;
      $ret=0;
      var $4=$2;
      var $5=(($4)|0)==0;
      if ($5) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      var $7=$3;
      var $8=(($7)|0)==0;
      if ($8) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      $1=4227;
      __label__ = 15; break;
    case 5: 
      var $11=$2;
      var $12=_HPDF_Dict_GetItem($11, ((STRING_TABLE.__str91741)|0), 16);
      var $13=$12;
      $views=$13;
      var $14=$views;
      var $15=(($14)|0)==0;
      if ($15) { __label__ = 6; break; } else { __label__ = 12; break; }
    case 6: 
      var $17=$2;
      var $18=(($17+8)|0);
      var $19=HEAP32[(($18)>>2)];
      var $20=_HPDF_Array_New($19);
      $views=$20;
      var $21=$views;
      var $22=(($21)|0)!=0;
      if ($22) { __label__ = 8; break; } else { __label__ = 7; break; }
    case 7: 
      var $24=$2;
      var $25=(($24+12)|0);
      var $26=HEAP32[(($25)>>2)];
      var $27=_HPDF_Error_GetCode($26);
      $1=$27;
      __label__ = 15; break;
    case 8: 
      var $29=$2;
      var $30=$views;
      var $31=$30;
      var $32=_HPDF_Dict_Add($29, ((STRING_TABLE.__str91741)|0), $31);
      $ret=$32;
      var $33=$ret;
      var $34=(($33)|0)==0;
      if ($34) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      var $36=$2;
      var $37=_HPDF_Dict_AddNumber($36, ((STRING_TABLE.__str101742)|0), 0);
      $ret=$37;
      __label__ = 11; break;
    case 10: 
      var $39=$views;
      _HPDF_Array_Free($39);
      var $40=$ret;
      $1=$40;
      __label__ = 15; break;
    case 11: 
      __label__ = 12; break;
    case 12: 
      var $43=$ret;
      var $44=(($43)|0)==0;
      if ($44) { __label__ = 13; break; } else { __label__ = 14; break; }
    case 13: 
      var $46=$views;
      var $47=$3;
      var $48=$47;
      var $49=_HPDF_Array_Add($46, $48);
      $ret=$49;
      __label__ = 14; break;
    case 14: 
      var $51=$ret;
      $1=$51;
      __label__ = 15; break;
    case 15: 
      var $53=$1;
      ;
      return $53;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_U3D_Add3DView["X"]=1;

function _HPDF_U3D_SetDefault3DView($u3d, $name) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $ret;
      $2=$u3d;
      $3=$name;
      $ret=0;
      var $4=$2;
      var $5=(($4)|0)==0;
      if ($5) { __label__ = 5; break; } else { __label__ = 3; break; }
    case 3: 
      var $7=$3;
      var $8=(($7)|0)==0;
      if ($8) { __label__ = 5; break; } else { __label__ = 4; break; }
    case 4: 
      var $10=$3;
      var $11=(($10)|0);
      var $12=HEAP8[($11)];
      var $13=(($12 << 24) >> 24);
      var $14=(($13)|0)==0;
      if ($14) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      $1=4227;
      __label__ = 7; break;
    case 6: 
      var $17=$2;
      var $18=$2;
      var $19=(($18+8)|0);
      var $20=HEAP32[(($19)>>2)];
      var $21=$3;
      var $22=_HPDF_String_New($20, $21, 0);
      var $23=$22;
      var $24=_HPDF_Dict_Add($17, ((STRING_TABLE.__str101742)|0), $23);
      $ret=$24;
      var $25=$ret;
      $1=$25;
      __label__ = 7; break;
    case 7: 
      var $27=$1;
      ;
      return $27;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_3DView_AddNode($view, $name, $opacity, $visible) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $5;
      var $nodes;
      var $node;
      var $ret;
      $2=$view;
      $3=$name;
      $4=$opacity;
      $5=$visible;
      $nodes=0;
      $ret=0;
      var $6=$2;
      var $7=(($6)|0)==0;
      if ($7) { __label__ = 7; break; } else { __label__ = 3; break; }
    case 3: 
      var $9=$4;
      var $10=$9 < 0;
      if ($10) { __label__ = 7; break; } else { __label__ = 4; break; }
    case 4: 
      var $12=$4;
      var $13=$12 > 1;
      if ($13) { __label__ = 7; break; } else { __label__ = 5; break; }
    case 5: 
      var $15=$3;
      var $16=(($15)|0)==0;
      if ($16) { __label__ = 7; break; } else { __label__ = 6; break; }
    case 6: 
      var $18=$3;
      var $19=(($18)|0);
      var $20=HEAP8[($19)];
      var $21=(($20 << 24) >> 24);
      var $22=(($21)|0)==0;
      if ($22) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      $1=4227;
      __label__ = 27; break;
    case 8: 
      var $25=$2;
      var $26=_HPDF_Dict_GetItem($25, ((STRING_TABLE.__str111743)|0), 16);
      var $27=$26;
      $nodes=$27;
      var $28=$nodes;
      var $29=(($28)|0)==0;
      if ($29) { __label__ = 9; break; } else { __label__ = 14; break; }
    case 9: 
      var $31=$2;
      var $32=(($31+8)|0);
      var $33=HEAP32[(($32)>>2)];
      var $34=_HPDF_Array_New($33);
      $nodes=$34;
      var $35=$nodes;
      var $36=(($35)|0)!=0;
      if ($36) { __label__ = 11; break; } else { __label__ = 10; break; }
    case 10: 
      var $38=$2;
      var $39=(($38+12)|0);
      var $40=HEAP32[(($39)>>2)];
      var $41=_HPDF_Error_GetCode($40);
      $1=$41;
      __label__ = 27; break;
    case 11: 
      var $43=$2;
      var $44=$nodes;
      var $45=$44;
      var $46=_HPDF_Dict_Add($43, ((STRING_TABLE.__str111743)|0), $45);
      $ret=$46;
      var $47=$ret;
      var $48=(($47)|0)!=0;
      if ($48) { __label__ = 12; break; } else { __label__ = 13; break; }
    case 12: 
      var $50=$nodes;
      _HPDF_Array_Free($50);
      var $51=$ret;
      $1=$51;
      __label__ = 27; break;
    case 13: 
      __label__ = 14; break;
    case 14: 
      var $54=$2;
      var $55=(($54+8)|0);
      var $56=HEAP32[(($55)>>2)];
      var $57=_HPDF_Dict_New($56);
      $node=$57;
      var $58=$node;
      var $59=(($58)|0)!=0;
      if ($59) { __label__ = 16; break; } else { __label__ = 15; break; }
    case 15: 
      var $61=$nodes;
      _HPDF_Array_Free($61);
      var $62=$2;
      var $63=(($62+12)|0);
      var $64=HEAP32[(($63)>>2)];
      var $65=_HPDF_Error_GetCode($64);
      $1=$65;
      __label__ = 27; break;
    case 16: 
      var $67=$node;
      var $68=_HPDF_Dict_AddName($67, ((STRING_TABLE.__str1732)|0), ((STRING_TABLE.__str121744)|0));
      $ret=$68;
      var $69=$ret;
      var $70=(($69)|0)!=0;
      if ($70) { __label__ = 17; break; } else { __label__ = 18; break; }
    case 17: 
      var $72=$nodes;
      _HPDF_Array_Free($72);
      var $73=$node;
      _HPDF_Dict_Free($73);
      var $74=$ret;
      $1=$74;
      __label__ = 27; break;
    case 18: 
      var $76=$node;
      var $77=$2;
      var $78=(($77+8)|0);
      var $79=HEAP32[(($78)>>2)];
      var $80=$3;
      var $81=_HPDF_String_New($79, $80, 0);
      var $82=$81;
      var $83=_HPDF_Dict_Add($76, ((STRING_TABLE.__str131745)|0), $82);
      $ret=$83;
      var $84=$ret;
      var $85=(($84)|0)!=0;
      if ($85) { __label__ = 19; break; } else { __label__ = 20; break; }
    case 19: 
      var $87=$nodes;
      _HPDF_Array_Free($87);
      var $88=$node;
      _HPDF_Dict_Free($88);
      var $89=$ret;
      $1=$89;
      __label__ = 27; break;
    case 20: 
      var $91=$node;
      var $92=$4;
      var $93=_HPDF_Dict_AddReal($91, ((STRING_TABLE.__str141746)|0), $92);
      $ret=$93;
      var $94=$ret;
      var $95=(($94)|0)!=0;
      if ($95) { __label__ = 21; break; } else { __label__ = 22; break; }
    case 21: 
      var $97=$nodes;
      _HPDF_Array_Free($97);
      var $98=$node;
      _HPDF_Dict_Free($98);
      var $99=$ret;
      $1=$99;
      __label__ = 27; break;
    case 22: 
      var $101=$node;
      var $102=$5;
      var $103=_HPDF_Dict_AddBoolean($101, ((STRING_TABLE.__str151747)|0), $102);
      $ret=$103;
      var $104=$ret;
      var $105=(($104)|0)!=0;
      if ($105) { __label__ = 23; break; } else { __label__ = 24; break; }
    case 23: 
      var $107=$node;
      _HPDF_Dict_Free($107);
      var $108=$nodes;
      _HPDF_Array_Free($108);
      var $109=$ret;
      $1=$109;
      __label__ = 27; break;
    case 24: 
      var $111=$nodes;
      var $112=$node;
      var $113=$112;
      var $114=_HPDF_Array_Add($111, $113);
      $ret=$114;
      var $115=$ret;
      var $116=(($115)|0)!=0;
      if ($116) { __label__ = 25; break; } else { __label__ = 26; break; }
    case 25: 
      var $118=$node;
      _HPDF_Dict_Free($118);
      var $119=$nodes;
      _HPDF_Array_Free($119);
      var $120=$ret;
      $1=$120;
      __label__ = 27; break;
    case 26: 
      var $122=$ret;
      $1=$122;
      __label__ = 27; break;
    case 27: 
      var $124=$1;
      ;
      return $124;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_3DView_AddNode["X"]=1;

function _HPDF_3DView_SetLighting($view, $scheme) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $ret;
      var $lighting;
      var $i;
      $2=$view;
      $3=$scheme;
      $ret=0;
      var $4=$2;
      var $5=(($4)|0)==0;
      if ($5) { __label__ = 5; break; } else { __label__ = 3; break; }
    case 3: 
      var $7=$3;
      var $8=(($7)|0)==0;
      if ($8) { __label__ = 5; break; } else { __label__ = 4; break; }
    case 4: 
      var $10=$3;
      var $11=(($10)|0);
      var $12=HEAP8[($11)];
      var $13=(($12 << 24) >> 24);
      var $14=(($13)|0)==0;
      if ($14) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      $1=4227;
      __label__ = 23; break;
    case 6: 
      $i=0;
      __label__ = 7; break;
    case 7: 
      var $18=$i;
      var $19=(($18)|0) < 12;
      if ($19) { __label__ = 8; break; } else { __label__ = 12; break; }
    case 8: 
      var $21=$3;
      var $22=$i;
      var $23=((_HPDF_3DView_SetLighting_schemes+($22<<2))|0);
      var $24=HEAP32[(($23)>>2)];
      var $25=_strcmp($21, $24);
      var $26=(($25)|0)!=0;
      if ($26) { __label__ = 10; break; } else { __label__ = 9; break; }
    case 9: 
      __label__ = 12; break;
    case 10: 
      __label__ = 11; break;
    case 11: 
      var $30=$i;
      var $31=((($30)+(1))|0);
      $i=$31;
      __label__ = 7; break;
    case 12: 
      var $33=$i;
      var $34=(($33)|0)==12;
      if ($34) { __label__ = 13; break; } else { __label__ = 14; break; }
    case 13: 
      $1=4227;
      __label__ = 23; break;
    case 14: 
      var $37=$2;
      var $38=(($37+8)|0);
      var $39=HEAP32[(($38)>>2)];
      var $40=_HPDF_Dict_New($39);
      $lighting=$40;
      var $41=$lighting;
      var $42=(($41)|0)!=0;
      if ($42) { __label__ = 16; break; } else { __label__ = 15; break; }
    case 15: 
      var $44=$2;
      var $45=(($44+12)|0);
      var $46=HEAP32[(($45)>>2)];
      var $47=_HPDF_Error_GetCode($46);
      $1=$47;
      __label__ = 23; break;
    case 16: 
      var $49=$lighting;
      var $50=_HPDF_Dict_AddName($49, ((STRING_TABLE.__str1732)|0), ((STRING_TABLE.__str281760)|0));
      $ret=$50;
      var $51=$ret;
      var $52=(($51)|0)!=0;
      if ($52) { __label__ = 17; break; } else { __label__ = 18; break; }
    case 17: 
      var $54=$lighting;
      _HPDF_Dict_Free($54);
      var $55=$ret;
      $1=$55;
      __label__ = 23; break;
    case 18: 
      var $57=$lighting;
      var $58=$3;
      var $59=_HPDF_Dict_AddName($57, ((STRING_TABLE.__str21734)|0), $58);
      $ret=$59;
      var $60=$ret;
      var $61=(($60)|0)!=0;
      if ($61) { __label__ = 19; break; } else { __label__ = 20; break; }
    case 19: 
      var $63=$lighting;
      _HPDF_Dict_Free($63);
      var $64=$ret;
      $1=$64;
      __label__ = 23; break;
    case 20: 
      var $66=$2;
      var $67=$lighting;
      var $68=$67;
      var $69=_HPDF_Dict_Add($66, ((STRING_TABLE.__str291761)|0), $68);
      $ret=$69;
      var $70=$ret;
      var $71=(($70)|0)!=0;
      if ($71) { __label__ = 21; break; } else { __label__ = 22; break; }
    case 21: 
      var $73=$lighting;
      _HPDF_Dict_Free($73);
      var $74=$ret;
      $1=$74;
      __label__ = 23; break;
    case 22: 
      var $76=$ret;
      $1=$76;
      __label__ = 23; break;
    case 23: 
      var $78=$1;
      ;
      return $78;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_3DView_SetLighting["X"]=1;

function _HPDF_3DView_SetBackgroundColor($view, $r, $g, $b) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $5;
      var $color;
      var $ret;
      var $background;
      $2=$view;
      $3=$r;
      $4=$g;
      $5=$b;
      $ret=0;
      var $6=$2;
      var $7=(($6)|0)==0;
      if ($7) { __label__ = 9; break; } else { __label__ = 3; break; }
    case 3: 
      var $9=$3;
      var $10=$9 < 0;
      if ($10) { __label__ = 9; break; } else { __label__ = 4; break; }
    case 4: 
      var $12=$3;
      var $13=$12 > 1;
      if ($13) { __label__ = 9; break; } else { __label__ = 5; break; }
    case 5: 
      var $15=$4;
      var $16=$15 < 0;
      if ($16) { __label__ = 9; break; } else { __label__ = 6; break; }
    case 6: 
      var $18=$4;
      var $19=$18 > 1;
      if ($19) { __label__ = 9; break; } else { __label__ = 7; break; }
    case 7: 
      var $21=$5;
      var $22=$21 < 0;
      if ($22) { __label__ = 9; break; } else { __label__ = 8; break; }
    case 8: 
      var $24=$5;
      var $25=$24 > 1;
      if ($25) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      $1=4227;
      __label__ = 27; break;
    case 10: 
      var $28=$2;
      var $29=(($28+8)|0);
      var $30=HEAP32[(($29)>>2)];
      var $31=_HPDF_Dict_New($30);
      $background=$31;
      var $32=$background;
      var $33=(($32)|0)!=0;
      if ($33) { __label__ = 12; break; } else { __label__ = 11; break; }
    case 11: 
      var $35=$2;
      var $36=(($35+12)|0);
      var $37=HEAP32[(($36)>>2)];
      var $38=_HPDF_Error_GetCode($37);
      $1=$38;
      __label__ = 27; break;
    case 12: 
      var $40=$2;
      var $41=(($40+8)|0);
      var $42=HEAP32[(($41)>>2)];
      var $43=_HPDF_Array_New($42);
      $color=$43;
      var $44=$color;
      var $45=(($44)|0)!=0;
      if ($45) { __label__ = 14; break; } else { __label__ = 13; break; }
    case 13: 
      var $47=$background;
      _HPDF_Dict_Free($47);
      var $48=$2;
      var $49=(($48+12)|0);
      var $50=HEAP32[(($49)>>2)];
      var $51=_HPDF_Error_GetCode($50);
      $1=$51;
      __label__ = 27; break;
    case 14: 
      var $53=$color;
      var $54=$3;
      var $55=_HPDF_Array_AddReal($53, $54);
      $ret=$55;
      var $56=$ret;
      var $57=(($56)|0)!=0;
      if ($57) { __label__ = 15; break; } else { __label__ = 16; break; }
    case 15: 
      var $59=$color;
      _HPDF_Array_Free($59);
      var $60=$background;
      _HPDF_Dict_Free($60);
      var $61=$ret;
      $1=$61;
      __label__ = 27; break;
    case 16: 
      var $63=$color;
      var $64=$4;
      var $65=_HPDF_Array_AddReal($63, $64);
      $ret=$65;
      var $66=$ret;
      var $67=(($66)|0)!=0;
      if ($67) { __label__ = 17; break; } else { __label__ = 18; break; }
    case 17: 
      var $69=$color;
      _HPDF_Array_Free($69);
      var $70=$background;
      _HPDF_Dict_Free($70);
      var $71=$ret;
      $1=$71;
      __label__ = 27; break;
    case 18: 
      var $73=$color;
      var $74=$5;
      var $75=_HPDF_Array_AddReal($73, $74);
      $ret=$75;
      var $76=$ret;
      var $77=(($76)|0)!=0;
      if ($77) { __label__ = 19; break; } else { __label__ = 20; break; }
    case 19: 
      var $79=$color;
      _HPDF_Array_Free($79);
      var $80=$background;
      _HPDF_Dict_Free($80);
      var $81=$ret;
      $1=$81;
      __label__ = 27; break;
    case 20: 
      var $83=$background;
      var $84=_HPDF_Dict_AddName($83, ((STRING_TABLE.__str1732)|0), ((STRING_TABLE.__str301762)|0));
      $ret=$84;
      var $85=$ret;
      var $86=(($85)|0)!=0;
      if ($86) { __label__ = 21; break; } else { __label__ = 22; break; }
    case 21: 
      var $88=$color;
      _HPDF_Array_Free($88);
      var $89=$background;
      _HPDF_Dict_Free($89);
      var $90=$ret;
      $1=$90;
      __label__ = 27; break;
    case 22: 
      var $92=$background;
      var $93=$color;
      var $94=$93;
      var $95=_HPDF_Dict_Add($92, ((STRING_TABLE.__str311763)|0), $94);
      $ret=$95;
      var $96=$ret;
      var $97=(($96)|0)!=0;
      if ($97) { __label__ = 23; break; } else { __label__ = 24; break; }
    case 23: 
      var $99=$color;
      _HPDF_Array_Free($99);
      var $100=$background;
      _HPDF_Dict_Free($100);
      var $101=$ret;
      $1=$101;
      __label__ = 27; break;
    case 24: 
      var $103=$2;
      var $104=$background;
      var $105=$104;
      var $106=_HPDF_Dict_Add($103, ((STRING_TABLE.__str321764)|0), $105);
      $ret=$106;
      var $107=$ret;
      var $108=(($107)|0)!=0;
      if ($108) { __label__ = 25; break; } else { __label__ = 26; break; }
    case 25: 
      var $110=$color;
      _HPDF_Array_Free($110);
      var $111=$background;
      _HPDF_Dict_Free($111);
      var $112=$ret;
      $1=$112;
      __label__ = 27; break;
    case 26: 
      var $114=$ret;
      $1=$114;
      __label__ = 27; break;
    case 27: 
      var $116=$1;
      ;
      return $116;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_3DView_SetBackgroundColor["X"]=1;

function _HPDF_3DView_SetPerspectiveProjection($view, $fov) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $ret;
      var $projection;
      $2=$view;
      $3=$fov;
      $ret=0;
      var $4=$2;
      var $5=(($4)|0)==0;
      if ($5) { __label__ = 5; break; } else { __label__ = 3; break; }
    case 3: 
      var $7=$3;
      var $8=$7 < 0;
      if ($8) { __label__ = 5; break; } else { __label__ = 4; break; }
    case 4: 
      var $10=$3;
      var $11=$10 > 180;
      if ($11) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      $1=4227;
      __label__ = 17; break;
    case 6: 
      var $14=$2;
      var $15=(($14+8)|0);
      var $16=HEAP32[(($15)>>2)];
      var $17=_HPDF_Dict_New($16);
      $projection=$17;
      var $18=$projection;
      var $19=(($18)|0)!=0;
      if ($19) { __label__ = 8; break; } else { __label__ = 7; break; }
    case 7: 
      var $21=$2;
      var $22=(($21+12)|0);
      var $23=HEAP32[(($22)>>2)];
      var $24=_HPDF_Error_GetCode($23);
      $1=$24;
      __label__ = 17; break;
    case 8: 
      var $26=$projection;
      var $27=_HPDF_Dict_AddName($26, ((STRING_TABLE.__str21734)|0), ((STRING_TABLE.__str331765)|0));
      $ret=$27;
      var $28=$ret;
      var $29=(($28)|0)!=0;
      if ($29) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      var $31=$projection;
      _HPDF_Dict_Free($31);
      var $32=$ret;
      $1=$32;
      __label__ = 17; break;
    case 10: 
      var $34=$projection;
      var $35=_HPDF_Dict_AddName($34, ((STRING_TABLE.__str341766)|0), ((STRING_TABLE.__str351767)|0));
      $ret=$35;
      var $36=$ret;
      var $37=(($36)|0)!=0;
      if ($37) { __label__ = 11; break; } else { __label__ = 12; break; }
    case 11: 
      var $39=$projection;
      _HPDF_Dict_Free($39);
      var $40=$ret;
      $1=$40;
      __label__ = 17; break;
    case 12: 
      var $42=$projection;
      var $43=$3;
      var $44=_HPDF_Dict_AddReal($42, ((STRING_TABLE.__str361768)|0), $43);
      $ret=$44;
      var $45=$ret;
      var $46=(($45)|0)!=0;
      if ($46) { __label__ = 13; break; } else { __label__ = 14; break; }
    case 13: 
      var $48=$projection;
      _HPDF_Dict_Free($48);
      var $49=$ret;
      $1=$49;
      __label__ = 17; break;
    case 14: 
      var $51=$2;
      var $52=$projection;
      var $53=$52;
      var $54=_HPDF_Dict_Add($51, ((STRING_TABLE.__str331765)|0), $53);
      $ret=$54;
      var $55=$ret;
      var $56=(($55)|0)!=0;
      if ($56) { __label__ = 15; break; } else { __label__ = 16; break; }
    case 15: 
      var $58=$projection;
      _HPDF_Dict_Free($58);
      var $59=$ret;
      $1=$59;
      __label__ = 17; break;
    case 16: 
      var $61=$ret;
      $1=$61;
      __label__ = 17; break;
    case 17: 
      var $63=$1;
      ;
      return $63;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_3DView_SetPerspectiveProjection["X"]=1;

function _HPDF_3DView_SetOrthogonalProjection($view, $mag) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $ret;
      var $projection;
      $2=$view;
      $3=$mag;
      $ret=0;
      var $4=$2;
      var $5=(($4)|0)==0;
      if ($5) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      var $7=$3;
      var $8=$7 <= 0;
      if ($8) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      $1=4227;
      __label__ = 14; break;
    case 5: 
      var $11=$2;
      var $12=(($11+8)|0);
      var $13=HEAP32[(($12)>>2)];
      var $14=_HPDF_Dict_New($13);
      $projection=$14;
      var $15=$projection;
      var $16=(($15)|0)!=0;
      if ($16) { __label__ = 7; break; } else { __label__ = 6; break; }
    case 6: 
      var $18=$2;
      var $19=(($18+12)|0);
      var $20=HEAP32[(($19)>>2)];
      var $21=_HPDF_Error_GetCode($20);
      $1=$21;
      __label__ = 14; break;
    case 7: 
      var $23=$projection;
      var $24=_HPDF_Dict_AddName($23, ((STRING_TABLE.__str21734)|0), ((STRING_TABLE.__str141746)|0));
      $ret=$24;
      var $25=$ret;
      var $26=(($25)|0)!=0;
      if ($26) { __label__ = 8; break; } else { __label__ = 9; break; }
    case 8: 
      var $28=$projection;
      _HPDF_Dict_Free($28);
      var $29=$ret;
      $1=$29;
      __label__ = 14; break;
    case 9: 
      var $31=$projection;
      var $32=$3;
      var $33=_HPDF_Dict_AddReal($31, ((STRING_TABLE.__str371769)|0), $32);
      $ret=$33;
      var $34=$ret;
      var $35=(($34)|0)!=0;
      if ($35) { __label__ = 10; break; } else { __label__ = 11; break; }
    case 10: 
      var $37=$projection;
      _HPDF_Dict_Free($37);
      var $38=$ret;
      $1=$38;
      __label__ = 14; break;
    case 11: 
      var $40=$2;
      var $41=$projection;
      var $42=$41;
      var $43=_HPDF_Dict_Add($40, ((STRING_TABLE.__str331765)|0), $42);
      $ret=$43;
      var $44=$ret;
      var $45=(($44)|0)!=0;
      if ($45) { __label__ = 12; break; } else { __label__ = 13; break; }
    case 12: 
      var $47=$projection;
      _HPDF_Dict_Free($47);
      var $48=$ret;
      $1=$48;
      __label__ = 14; break;
    case 13: 
      var $50=$ret;
      $1=$50;
      __label__ = 14; break;
    case 14: 
      var $52=$1;
      ;
      return $52;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_3DView_SetOrthogonalProjection["X"]=1;

function _HPDF_AToI($s) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $flg;
      var $v;
      $2=$s;
      $flg=0;
      $v=0;
      var $3=$2;
      var $4=(($3)|0)!=0;
      if ($4) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=0;
      __label__ = 25; break;
    case 4: 
      __label__ = 5; break;
    case 5: 
      var $8=$2;
      var $9=HEAP8[($8)];
      var $10=(($9 << 24) >> 24)!=0;
      if ($10) { __label__ = 6; break; } else { __label__ = 17; break; }
    case 6: 
      var $12=$2;
      var $13=HEAP8[($12)];
      var $14=(($13 << 24) >> 24);
      var $15=(($14)|0)==0;
      if ($15) { __label__ = 12; break; } else { __label__ = 7; break; }
    case 7: 
      var $17=$2;
      var $18=HEAP8[($17)];
      var $19=(($18 << 24) >> 24);
      var $20=(($19)|0)==9;
      if ($20) { __label__ = 12; break; } else { __label__ = 8; break; }
    case 8: 
      var $22=$2;
      var $23=HEAP8[($22)];
      var $24=(($23 << 24) >> 24);
      var $25=(($24)|0)==10;
      if ($25) { __label__ = 12; break; } else { __label__ = 9; break; }
    case 9: 
      var $27=$2;
      var $28=HEAP8[($27)];
      var $29=(($28 << 24) >> 24);
      var $30=(($29)|0)==12;
      if ($30) { __label__ = 12; break; } else { __label__ = 10; break; }
    case 10: 
      var $32=$2;
      var $33=HEAP8[($32)];
      var $34=(($33 << 24) >> 24);
      var $35=(($34)|0)==13;
      if ($35) { __label__ = 12; break; } else { __label__ = 11; break; }
    case 11: 
      var $37=$2;
      var $38=HEAP8[($37)];
      var $39=(($38 << 24) >> 24);
      var $40=(($39)|0)==32;
      if ($40) { __label__ = 12; break; } else { __label__ = 13; break; }
    case 12: 
      var $42=$2;
      var $43=(($42+1)|0);
      $2=$43;
      __label__ = 16; break;
    case 13: 
      var $45=$2;
      var $46=HEAP8[($45)];
      var $47=(($46 << 24) >> 24);
      var $48=(($47)|0)==45;
      if ($48) { __label__ = 14; break; } else { __label__ = 15; break; }
    case 14: 
      $flg=1;
      var $50=$2;
      var $51=(($50+1)|0);
      $2=$51;
      __label__ = 15; break;
    case 15: 
      __label__ = 17; break;
    case 16: 
      __label__ = 5; break;
    case 17: 
      __label__ = 18; break;
    case 18: 
      var $56=$2;
      var $57=HEAP8[($56)];
      var $58=(($57 << 24) >> 24);
      var $59=(($58)|0) >= 48;
      if ($59) { __label__ = 19; break; } else { var $66 = 0;__label__ = 20; break; }
    case 19: 
      var $61=$2;
      var $62=HEAP8[($61)];
      var $63=(($62 << 24) >> 24);
      var $64=(($63)|0) <= 57;
      var $66 = $64;__label__ = 20; break;
    case 20: 
      var $66;
      if ($66) { __label__ = 21; break; } else { __label__ = 22; break; }
    case 21: 
      var $68=$v;
      var $69=((($68)*(10))|0);
      $v=$69;
      var $70=$2;
      var $71=HEAP8[($70)];
      var $72=(($71 << 24) >> 24);
      var $73=((($72)-(48))|0);
      var $74=$v;
      var $75=((($74)+($73))|0);
      $v=$75;
      var $76=$2;
      var $77=(($76+1)|0);
      $2=$77;
      __label__ = 18; break;
    case 22: 
      var $79=$flg;
      var $80=(($79)|0)!=0;
      if ($80) { __label__ = 23; break; } else { __label__ = 24; break; }
    case 23: 
      var $82=$v;
      var $83=((($82)*(-1))|0);
      $v=$83;
      __label__ = 24; break;
    case 24: 
      var $85=$v;
      $1=$85;
      __label__ = 25; break;
    case 25: 
      var $87=$1;
      ;
      return $87;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_AToI["X"]=1;

function _HPDF_IToA($s, $val, $eptr) {
  var __stackBase__  = STACKTOP; STACKTOP += 12; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $t;
      var $buf=__stackBase__;
      $1=$s;
      $2=$val;
      $3=$eptr;
      var $4=$2;
      var $5=(($4)|0) < 0;
      if ($5) { __label__ = 3; break; } else { __label__ = 6; break; }
    case 3: 
      var $7=$2;
      var $8=(($7)|0) < -2147483647;
      if ($8) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      $2=-2147483647;
      __label__ = 5; break;
    case 5: 
      var $11=$1;
      var $12=(($11+1)|0);
      $1=$12;
      HEAP8[($11)]=45;
      var $13=$2;
      var $14=(((-$13))|0);
      $2=$14;
      __label__ = 12; break;
    case 6: 
      var $16=$2;
      var $17=(($16)|0) > 2147483647;
      if ($17) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      $2=2147483647;
      __label__ = 11; break;
    case 8: 
      var $20=$2;
      var $21=(($20)|0)==0;
      if ($21) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      var $23=$1;
      var $24=(($23+1)|0);
      $1=$24;
      HEAP8[($23)]=48;
      __label__ = 10; break;
    case 10: 
      __label__ = 11; break;
    case 11: 
      __label__ = 12; break;
    case 12: 
      var $28=(($buf)|0);
      var $29=(($28+11)|0);
      $t=$29;
      var $30=$t;
      var $31=((($30)-(1))|0);
      $t=$31;
      HEAP8[($30)]=0;
      __label__ = 13; break;
    case 13: 
      var $33=$2;
      var $34=(($33)|0) > 0;
      if ($34) { __label__ = 14; break; } else { __label__ = 15; break; }
    case 14: 
      var $36=$2;
      var $37=((($36)|0))%(10);
      var $38=(($37) & 255);
      var $39=(($38 << 24) >> 24);
      var $40=((($39)+(48))|0);
      var $41=(($40) & 255);
      var $42=$t;
      HEAP8[($42)]=$41;
      var $43=$2;
      var $44=((((($43)|0))/(10))&-1);
      $2=$44;
      var $45=$t;
      var $46=((($45)-(1))|0);
      $t=$46;
      __label__ = 13; break;
    case 15: 
      var $48=$t;
      var $49=(($48+1)|0);
      $t=$49;
      __label__ = 16; break;
    case 16: 
      var $51=$1;
      var $52=$3;
      var $53=(($51)>>>0) < (($52)>>>0);
      if ($53) { __label__ = 17; break; } else { var $60 = 0;__label__ = 18; break; }
    case 17: 
      var $55=$t;
      var $56=HEAP8[($55)];
      var $57=(($56 << 24) >> 24);
      var $58=(($57)|0)!=0;
      var $60 = $58;__label__ = 18; break;
    case 18: 
      var $60;
      if ($60) { __label__ = 19; break; } else { __label__ = 20; break; }
    case 19: 
      var $62=$t;
      var $63=(($62+1)|0);
      $t=$63;
      var $64=HEAP8[($62)];
      var $65=$1;
      var $66=(($65+1)|0);
      $1=$66;
      HEAP8[($65)]=$64;
      __label__ = 16; break;
    case 20: 
      var $68=$1;
      HEAP8[($68)]=0;
      var $69=$1;
      STACKTOP = __stackBase__;
      return $69;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_IToA["X"]=1;

function _HPDF_IToA2($s, $val, $len) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $t;
      var $u;
      $1=$s;
      $2=$val;
      $3=$len;
      var $4=$2;
      var $5=(($4)>>>0) > 2147483647;
      if ($5) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      $2=2147483647;
      __label__ = 4; break;
    case 4: 
      var $8=$1;
      var $9=$3;
      var $10=(($8+$9)|0);
      var $11=((($10)-(1))|0);
      $u=$11;
      var $12=$u;
      HEAP8[($12)]=0;
      var $13=$u;
      var $14=((($13)-(1))|0);
      $t=$14;
      __label__ = 5; break;
    case 5: 
      var $16=$2;
      var $17=(($16)>>>0) > 0;
      if ($17) { __label__ = 6; break; } else { var $23 = 0;__label__ = 7; break; }
    case 6: 
      var $19=$t;
      var $20=$1;
      var $21=(($19)>>>0) >= (($20)>>>0);
      var $23 = $21;__label__ = 7; break;
    case 7: 
      var $23;
      if ($23) { __label__ = 8; break; } else { __label__ = 9; break; }
    case 8: 
      var $25=$2;
      var $26=((($25)>>>0))%(10);
      var $27=(($26) & 255);
      var $28=(($27 << 24) >> 24);
      var $29=((($28)+(48))|0);
      var $30=(($29) & 255);
      var $31=$t;
      HEAP8[($31)]=$30;
      var $32=$2;
      var $33=Math.floor(((($32)>>>0))/(10));
      $2=$33;
      var $34=$t;
      var $35=((($34)-(1))|0);
      $t=$35;
      __label__ = 5; break;
    case 9: 
      __label__ = 10; break;
    case 10: 
      var $38=$1;
      var $39=$t;
      var $40=(($38)>>>0) <= (($39)>>>0);
      if ($40) { __label__ = 11; break; } else { __label__ = 12; break; }
    case 11: 
      var $42=$t;
      var $43=((($42)-(1))|0);
      $t=$43;
      HEAP8[($42)]=48;
      __label__ = 10; break;
    case 12: 
      var $45=$1;
      var $46=$3;
      var $47=(($45+$46)|0);
      var $48=((($47)-(1))|0);
      ;
      return $48;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_IToA2["X"]=1;

function _HPDF_3DView_SetCamera($view, $coox, $cooy, $cooz, $c2cx, $c2cy, $c2cz, $roo, $roll) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $5;
      var $6;
      var $7;
      var $8;
      var $9;
      var $10;
      var $viewx;
      var $viewy;
      var $viewz;
      var $leftx;
      var $lefty;
      var $leftz;
      var $upx;
      var $upy;
      var $upz;
      var $transx;
      var $transy;
      var $transz;
      var $matrix;
      var $ret;
      var $modulo;
      var $modulo1;
      var $modulo2;
      var $leftxprime;
      var $leftyprime;
      var $leftzprime;
      var $upxprime;
      var $upyprime;
      var $upzprime;
      var $sinroll;
      var $cosroll;
      $2=$view;
      $3=$coox;
      $4=$cooy;
      $5=$cooz;
      $6=$c2cx;
      $7=$c2cy;
      $8=$c2cz;
      $9=$roo;
      $10=$roll;
      $ret=0;
      var $11=$2;
      var $12=(($11)|0)==0;
      if ($12) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      $1=4227;
      __label__ = 55; break;
    case 4: 
      var $15=$6;
      var $16=(-$15);
      $viewx=$16;
      var $17=$7;
      var $18=(-$17);
      $viewy=$18;
      var $19=$8;
      var $20=(-$19);
      $viewz=$20;
      var $21=$viewx;
      var $22=$21;
      var $23=$22 == 0;
      if ($23) { __label__ = 5; break; } else { __label__ = 8; break; }
    case 5: 
      var $25=$viewy;
      var $26=$25;
      var $27=$26 == 0;
      if ($27) { __label__ = 6; break; } else { __label__ = 8; break; }
    case 6: 
      var $29=$viewz;
      var $30=$29;
      var $31=$30 == 0;
      if ($31) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      $viewy=1;
      __label__ = 8; break;
    case 8: 
      var $34=$viewx;
      var $35=$viewx;
      var $36=($34)*($35);
      var $37=$viewy;
      var $38=$viewy;
      var $39=($37)*($38);
      var $40=($36)+($39);
      var $41=$viewz;
      var $42=$viewz;
      var $43=($41)*($42);
      var $44=($40)+($43);
      var $45=$44;
      var $46=_sqrt($45);
      var $47=$46;
      $modulo=$47;
      var $48=$modulo;
      var $49=$48;
      var $50=$49 != 0;
      if ($50) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      var $52=$viewx;
      var $53=$modulo;
      var $54=($52)/($53);
      $viewx=$54;
      var $55=$viewy;
      var $56=$modulo;
      var $57=($55)/($56);
      $viewy=$57;
      var $58=$viewz;
      var $59=$modulo;
      var $60=($58)/($59);
      $viewz=$60;
      __label__ = 10; break;
    case 10: 
      $leftx=-1;
      $lefty=0;
      $leftz=0;
      var $62=$viewz;
      var $63=$62;
      var $64=$63 < 0;
      if ($64) { __label__ = 11; break; } else { __label__ = 12; break; }
    case 11: 
      $upx=0;
      $upy=1;
      $upz=0;
      __label__ = 13; break;
    case 12: 
      $upx=0;
      $upy=-1;
      $upz=0;
      __label__ = 13; break;
    case 13: 
      var $68=$viewx;
      var $69=$68;
      var $70=_fabs($69);
      var $71=$viewy;
      var $72=$71;
      var $73=_fabs($72);
      var $74=($70)+($73);
      var $75=$74 != 0;
      if ($75) { __label__ = 14; break; } else { __label__ = 19; break; }
    case 14: 
      var $77=$viewz;
      var $78=(-$77);
      var $79=$viewx;
      var $80=($78)*($79);
      $upx=$80;
      var $81=$viewz;
      var $82=(-$81);
      var $83=$viewy;
      var $84=($82)*($83);
      $upy=$84;
      var $85=$viewz;
      var $86=(-$85);
      var $87=$viewz;
      var $88=($86)*($87);
      var $89=($88)+(1);
      $upz=$89;
      var $90=$upx;
      var $91=$upx;
      var $92=($90)*($91);
      var $93=$upy;
      var $94=$upy;
      var $95=($93)*($94);
      var $96=($92)+($95);
      var $97=$upz;
      var $98=$upz;
      var $99=($97)*($98);
      var $100=($96)+($99);
      var $101=$100;
      var $102=_sqrt($101);
      var $103=$102;
      $modulo1=$103;
      var $104=$modulo1;
      var $105=$104;
      var $106=$105 != 0;
      if ($106) { __label__ = 15; break; } else { __label__ = 16; break; }
    case 15: 
      var $108=$upx;
      var $109=$modulo1;
      var $110=($108)/($109);
      $upx=$110;
      var $111=$upy;
      var $112=$modulo1;
      var $113=($111)/($112);
      $upy=$113;
      var $114=$upz;
      var $115=$modulo1;
      var $116=($114)/($115);
      $upz=$116;
      __label__ = 16; break;
    case 16: 
      var $118=$viewz;
      var $119=$upy;
      var $120=($118)*($119);
      var $121=$viewy;
      var $122=$upz;
      var $123=($121)*($122);
      var $124=($120)-($123);
      $leftx=$124;
      var $125=$viewx;
      var $126=$upz;
      var $127=($125)*($126);
      var $128=$viewz;
      var $129=$upx;
      var $130=($128)*($129);
      var $131=($127)-($130);
      $lefty=$131;
      var $132=$viewy;
      var $133=$upx;
      var $134=($132)*($133);
      var $135=$viewx;
      var $136=$upy;
      var $137=($135)*($136);
      var $138=($134)-($137);
      $leftz=$138;
      var $139=$leftx;
      var $140=$leftx;
      var $141=($139)*($140);
      var $142=$lefty;
      var $143=$lefty;
      var $144=($142)*($143);
      var $145=($141)+($144);
      var $146=$leftz;
      var $147=$leftz;
      var $148=($146)*($147);
      var $149=($145)+($148);
      var $150=$149;
      var $151=_sqrt($150);
      var $152=$151;
      $modulo2=$152;
      var $153=$modulo2;
      var $154=$153;
      var $155=$154 != 0;
      if ($155) { __label__ = 17; break; } else { __label__ = 18; break; }
    case 17: 
      var $157=$leftx;
      var $158=$modulo2;
      var $159=($157)/($158);
      $leftx=$159;
      var $160=$lefty;
      var $161=$modulo2;
      var $162=($160)/($161);
      $lefty=$162;
      var $163=$leftz;
      var $164=$modulo2;
      var $165=($163)/($164);
      $leftz=$165;
      __label__ = 18; break;
    case 18: 
      __label__ = 19; break;
    case 19: 
      var $168=$10;
      var $169=($168)/(180);
      var $170=$169;
      var $171=($170)*(3.141592653589793);
      var $172=_sin($171);
      var $173=$172;
      $sinroll=$173;
      var $174=$10;
      var $175=($174)/(180);
      var $176=$175;
      var $177=($176)*(3.141592653589793);
      var $178=_cos($177);
      var $179=$178;
      $cosroll=$179;
      var $180=$leftx;
      var $181=$cosroll;
      var $182=($180)*($181);
      var $183=$upx;
      var $184=$sinroll;
      var $185=($183)*($184);
      var $186=($182)+($185);
      $leftxprime=$186;
      var $187=$lefty;
      var $188=$cosroll;
      var $189=($187)*($188);
      var $190=$upy;
      var $191=$sinroll;
      var $192=($190)*($191);
      var $193=($189)+($192);
      $leftyprime=$193;
      var $194=$leftz;
      var $195=$cosroll;
      var $196=($194)*($195);
      var $197=$upz;
      var $198=$sinroll;
      var $199=($197)*($198);
      var $200=($196)+($199);
      $leftzprime=$200;
      var $201=$upx;
      var $202=$cosroll;
      var $203=($201)*($202);
      var $204=$leftx;
      var $205=$sinroll;
      var $206=($204)*($205);
      var $207=($203)+($206);
      $upxprime=$207;
      var $208=$upy;
      var $209=$cosroll;
      var $210=($208)*($209);
      var $211=$lefty;
      var $212=$sinroll;
      var $213=($211)*($212);
      var $214=($210)+($213);
      $upyprime=$214;
      var $215=$upz;
      var $216=$cosroll;
      var $217=($215)*($216);
      var $218=$leftz;
      var $219=$sinroll;
      var $220=($218)*($219);
      var $221=($217)+($220);
      $upzprime=$221;
      var $222=$leftxprime;
      $leftx=$222;
      var $223=$leftyprime;
      $lefty=$223;
      var $224=$leftzprime;
      $leftz=$224;
      var $225=$upxprime;
      $upx=$225;
      var $226=$upyprime;
      $upy=$226;
      var $227=$upzprime;
      $upz=$227;
      var $228=$9;
      var $229=$228;
      var $230=_fabs($229);
      var $231=$230;
      $9=$231;
      var $232=$9;
      var $233=$232;
      var $234=$233 == 0;
      if ($234) { __label__ = 20; break; } else { __label__ = 21; break; }
    case 20: 
      $9=1.000000045813705e-18;
      __label__ = 21; break;
    case 21: 
      var $237=$3;
      var $238=$9;
      var $239=$viewx;
      var $240=($238)*($239);
      var $241=($237)-($240);
      $transx=$241;
      var $242=$4;
      var $243=$9;
      var $244=$viewy;
      var $245=($243)*($244);
      var $246=($242)-($245);
      $transy=$246;
      var $247=$5;
      var $248=$9;
      var $249=$viewz;
      var $250=($248)*($249);
      var $251=($247)-($250);
      $transz=$251;
      var $252=$2;
      var $253=(($252+8)|0);
      var $254=HEAP32[(($253)>>2)];
      var $255=_HPDF_Array_New($254);
      $matrix=$255;
      var $256=$matrix;
      var $257=(($256)|0)!=0;
      if ($257) { __label__ = 23; break; } else { __label__ = 22; break; }
    case 22: 
      var $259=$2;
      var $260=(($259+12)|0);
      var $261=HEAP32[(($260)>>2)];
      var $262=_HPDF_Error_GetCode($261);
      $1=$262;
      __label__ = 55; break;
    case 23: 
      var $264=$matrix;
      var $265=$leftx;
      var $266=_HPDF_Array_AddReal($264, $265);
      $ret=$266;
      var $267=$ret;
      var $268=(($267)|0)!=0;
      if ($268) { __label__ = 24; break; } else { __label__ = 25; break; }
    case 24: 
      __label__ = 52; break;
    case 25: 
      var $271=$matrix;
      var $272=$lefty;
      var $273=_HPDF_Array_AddReal($271, $272);
      $ret=$273;
      var $274=$ret;
      var $275=(($274)|0)!=0;
      if ($275) { __label__ = 26; break; } else { __label__ = 27; break; }
    case 26: 
      __label__ = 52; break;
    case 27: 
      var $278=$matrix;
      var $279=$leftz;
      var $280=_HPDF_Array_AddReal($278, $279);
      $ret=$280;
      var $281=$ret;
      var $282=(($281)|0)!=0;
      if ($282) { __label__ = 28; break; } else { __label__ = 29; break; }
    case 28: 
      __label__ = 52; break;
    case 29: 
      var $285=$matrix;
      var $286=$upx;
      var $287=_HPDF_Array_AddReal($285, $286);
      $ret=$287;
      var $288=$ret;
      var $289=(($288)|0)!=0;
      if ($289) { __label__ = 30; break; } else { __label__ = 31; break; }
    case 30: 
      __label__ = 52; break;
    case 31: 
      var $292=$matrix;
      var $293=$upy;
      var $294=_HPDF_Array_AddReal($292, $293);
      $ret=$294;
      var $295=$ret;
      var $296=(($295)|0)!=0;
      if ($296) { __label__ = 32; break; } else { __label__ = 33; break; }
    case 32: 
      __label__ = 52; break;
    case 33: 
      var $299=$matrix;
      var $300=$upz;
      var $301=_HPDF_Array_AddReal($299, $300);
      $ret=$301;
      var $302=$ret;
      var $303=(($302)|0)!=0;
      if ($303) { __label__ = 34; break; } else { __label__ = 35; break; }
    case 34: 
      __label__ = 52; break;
    case 35: 
      var $306=$matrix;
      var $307=$viewx;
      var $308=_HPDF_Array_AddReal($306, $307);
      $ret=$308;
      var $309=$ret;
      var $310=(($309)|0)!=0;
      if ($310) { __label__ = 36; break; } else { __label__ = 37; break; }
    case 36: 
      __label__ = 52; break;
    case 37: 
      var $313=$matrix;
      var $314=$viewy;
      var $315=_HPDF_Array_AddReal($313, $314);
      $ret=$315;
      var $316=$ret;
      var $317=(($316)|0)!=0;
      if ($317) { __label__ = 38; break; } else { __label__ = 39; break; }
    case 38: 
      __label__ = 52; break;
    case 39: 
      var $320=$matrix;
      var $321=$viewz;
      var $322=_HPDF_Array_AddReal($320, $321);
      $ret=$322;
      var $323=$ret;
      var $324=(($323)|0)!=0;
      if ($324) { __label__ = 40; break; } else { __label__ = 41; break; }
    case 40: 
      __label__ = 52; break;
    case 41: 
      var $327=$matrix;
      var $328=$transx;
      var $329=_HPDF_Array_AddReal($327, $328);
      $ret=$329;
      var $330=$ret;
      var $331=(($330)|0)!=0;
      if ($331) { __label__ = 42; break; } else { __label__ = 43; break; }
    case 42: 
      __label__ = 52; break;
    case 43: 
      var $334=$matrix;
      var $335=$transy;
      var $336=_HPDF_Array_AddReal($334, $335);
      $ret=$336;
      var $337=$ret;
      var $338=(($337)|0)!=0;
      if ($338) { __label__ = 44; break; } else { __label__ = 45; break; }
    case 44: 
      __label__ = 52; break;
    case 45: 
      var $341=$matrix;
      var $342=$transz;
      var $343=_HPDF_Array_AddReal($341, $342);
      $ret=$343;
      var $344=$ret;
      var $345=(($344)|0)!=0;
      if ($345) { __label__ = 46; break; } else { __label__ = 47; break; }
    case 46: 
      __label__ = 52; break;
    case 47: 
      var $348=$2;
      var $349=_HPDF_Dict_AddName($348, ((STRING_TABLE.__str381770)|0), ((STRING_TABLE.__str391771)|0));
      $ret=$349;
      var $350=$ret;
      var $351=(($350)|0)!=0;
      if ($351) { __label__ = 48; break; } else { __label__ = 49; break; }
    case 48: 
      __label__ = 52; break;
    case 49: 
      var $354=$2;
      var $355=$matrix;
      var $356=$355;
      var $357=_HPDF_Dict_Add($354, ((STRING_TABLE.__str401772)|0), $356);
      $ret=$357;
      var $358=$ret;
      var $359=(($358)|0)!=0;
      if ($359) { __label__ = 50; break; } else { __label__ = 51; break; }
    case 50: 
      __label__ = 52; break;
    case 51: 
      var $362=$2;
      var $363=$9;
      var $364=(($363)&-1);
      var $365=_HPDF_Dict_AddNumber($362, ((STRING_TABLE.__str411773)|0), $364);
      $ret=$365;
      __label__ = 52; break;
    case 52: 
      var $367=$ret;
      var $368=(($367)|0)!=0;
      if ($368) { __label__ = 53; break; } else { __label__ = 54; break; }
    case 53: 
      var $370=$matrix;
      _HPDF_Array_Free($370);
      var $371=$ret;
      $1=$371;
      __label__ = 55; break;
    case 54: 
      var $373=$ret;
      $1=$373;
      __label__ = 55; break;
    case 55: 
      var $375=$1;
      ;
      return $375;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_3DView_SetCamera["X"]=1;

function _HPDF_FToA($s, $val, $eptr) {
  var __stackBase__  = STACKTOP; STACKTOP += 12; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $int_val;
      var $fpart_val;
      var $buf=__stackBase__;
      var $sptr;
      var $t;
      var $i;
      $1=$s;
      $2=$val;
      $3=$eptr;
      var $4=$1;
      $sptr=$4;
      var $5=$2;
      var $6=$5 > 32767;
      if ($6) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      $2=32767;
      __label__ = 7; break;
    case 4: 
      var $9=$2;
      var $10=$9 < -32767;
      if ($10) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      $2=-32767;
      __label__ = 6; break;
    case 6: 
      __label__ = 7; break;
    case 7: 
      var $14=(($buf)|0);
      var $15=(($14+11)|0);
      $t=$15;
      var $16=$t;
      var $17=((($16)-(1))|0);
      $t=$17;
      HEAP8[($16)]=0;
      var $18=$2;
      var $19=$18 < 0;
      if ($19) { __label__ = 8; break; } else { __label__ = 9; break; }
    case 8: 
      var $21=$1;
      var $22=(($21+1)|0);
      $1=$22;
      HEAP8[($21)]=45;
      var $23=$2;
      var $24=(-$23);
      $2=$24;
      __label__ = 9; break;
    case 9: 
      var $26=$2;
      var $27=$26;
      var $28=($27)+(0.000005);
      var $29=(($28)&-1);
      $int_val=$29;
      var $30=$2;
      var $31=$int_val;
      var $32=(($31)|0);
      var $33=($30)-($32);
      var $34=$33;
      var $35=($34)+(0.000005);
      var $36=$35;
      var $37=($36)*(100000);
      var $38=(($37)&-1);
      $fpart_val=$38;
      $i=0;
      __label__ = 10; break;
    case 10: 
      var $40=$i;
      var $41=(($40)>>>0) < 5;
      if ($41) { __label__ = 11; break; } else { __label__ = 13; break; }
    case 11: 
      var $43=$fpart_val;
      var $44=((($43)|0))%(10);
      var $45=(($44) & 255);
      var $46=(($45 << 24) >> 24);
      var $47=((($46)+(48))|0);
      var $48=(($47) & 255);
      var $49=$t;
      HEAP8[($49)]=$48;
      var $50=$fpart_val;
      var $51=((((($50)|0))/(10))&-1);
      $fpart_val=$51;
      var $52=$t;
      var $53=((($52)-(1))|0);
      $t=$53;
      __label__ = 12; break;
    case 12: 
      var $55=$i;
      var $56=((($55)+(1))|0);
      $i=$56;
      __label__ = 10; break;
    case 13: 
      var $58=$t;
      var $59=((($58)-(1))|0);
      $t=$59;
      HEAP8[($58)]=46;
      var $60=$t;
      HEAP8[($60)]=48;
      var $61=$int_val;
      var $62=(($61)|0)==0;
      if ($62) { __label__ = 14; break; } else { __label__ = 15; break; }
    case 14: 
      var $64=$t;
      var $65=((($64)-(1))|0);
      $t=$65;
      __label__ = 15; break;
    case 15: 
      __label__ = 16; break;
    case 16: 
      var $68=$int_val;
      var $69=(($68)|0) > 0;
      if ($69) { __label__ = 17; break; } else { __label__ = 18; break; }
    case 17: 
      var $71=$int_val;
      var $72=((($71)|0))%(10);
      var $73=(($72) & 255);
      var $74=(($73 << 24) >> 24);
      var $75=((($74)+(48))|0);
      var $76=(($75) & 255);
      var $77=$t;
      HEAP8[($77)]=$76;
      var $78=$int_val;
      var $79=((((($78)|0))/(10))&-1);
      $int_val=$79;
      var $80=$t;
      var $81=((($80)-(1))|0);
      $t=$81;
      __label__ = 16; break;
    case 18: 
      var $83=$t;
      var $84=(($83+1)|0);
      $t=$84;
      __label__ = 19; break;
    case 19: 
      var $86=$1;
      var $87=$3;
      var $88=(($86)>>>0) <= (($87)>>>0);
      if ($88) { __label__ = 20; break; } else { var $95 = 0;__label__ = 21; break; }
    case 20: 
      var $90=$t;
      var $91=HEAP8[($90)];
      var $92=(($91 << 24) >> 24);
      var $93=(($92)|0)!=0;
      var $95 = $93;__label__ = 21; break;
    case 21: 
      var $95;
      if ($95) { __label__ = 22; break; } else { __label__ = 23; break; }
    case 22: 
      var $97=$t;
      var $98=(($97+1)|0);
      $t=$98;
      var $99=HEAP8[($97)];
      var $100=$1;
      var $101=(($100+1)|0);
      $1=$101;
      HEAP8[($100)]=$99;
      __label__ = 19; break;
    case 23: 
      var $103=$1;
      var $104=((($103)-(1))|0);
      $1=$104;
      __label__ = 24; break;
    case 24: 
      var $106=$1;
      var $107=$sptr;
      var $108=(($106)>>>0) > (($107)>>>0);
      if ($108) { __label__ = 25; break; } else { __label__ = 31; break; }
    case 25: 
      var $110=$1;
      var $111=HEAP8[($110)];
      var $112=(($111 << 24) >> 24);
      var $113=(($112)|0)==48;
      if ($113) { __label__ = 26; break; } else { __label__ = 27; break; }
    case 26: 
      var $115=$1;
      HEAP8[($115)]=0;
      __label__ = 30; break;
    case 27: 
      var $117=$1;
      var $118=HEAP8[($117)];
      var $119=(($118 << 24) >> 24);
      var $120=(($119)|0)==46;
      if ($120) { __label__ = 28; break; } else { __label__ = 29; break; }
    case 28: 
      var $122=$1;
      HEAP8[($122)]=0;
      __label__ = 29; break;
    case 29: 
      __label__ = 31; break;
    case 30: 
      var $125=$1;
      var $126=((($125)-(1))|0);
      $1=$126;
      __label__ = 24; break;
    case 31: 
      var $128=$1;
      var $129=HEAP8[($128)];
      var $130=(($129 << 24) >> 24);
      var $131=(($130)|0)==0;
      if ($131) { __label__ = 32; break; } else { __label__ = 33; break; }
    case 32: 
      var $133=$1;
      var $138 = $133;__label__ = 34; break;
    case 33: 
      var $135=$1;
      var $136=(($135+1)|0);
      $1=$136;
      var $138 = $136;__label__ = 34; break;
    case 34: 
      var $138;
      STACKTOP = __stackBase__;
      return $138;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_FToA["X"]=1;

function _HPDF_MemCpy($out, $in, $n) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      $1=$out;
      $2=$in;
      $3=$n;
      __label__ = 3; break;
    case 3: 
      var $5=$3;
      var $6=(($5)>>>0) > 0;
      if ($6) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      var $8=$2;
      var $9=(($8+1)|0);
      $2=$9;
      var $10=HEAP8[($8)];
      var $11=$1;
      var $12=(($11+1)|0);
      $1=$12;
      HEAP8[($11)]=$10;
      var $13=$3;
      var $14=((($13)-(1))|0);
      $3=$14;
      __label__ = 3; break;
    case 5: 
      var $16=$1;
      ;
      return $16;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_StrCpy($out, $in, $eptr) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      $1=$out;
      $2=$in;
      $3=$eptr;
      var $4=$2;
      var $5=(($4)|0)!=0;
      if ($5) { __label__ = 3; break; } else { __label__ = 9; break; }
    case 3: 
      __label__ = 4; break;
    case 4: 
      var $8=$3;
      var $9=$1;
      var $10=(($8)>>>0) > (($9)>>>0);
      if ($10) { __label__ = 5; break; } else { var $17 = 0;__label__ = 6; break; }
    case 5: 
      var $12=$2;
      var $13=HEAP8[($12)];
      var $14=(($13 << 24) >> 24);
      var $15=(($14)|0)!=0;
      var $17 = $15;__label__ = 6; break;
    case 6: 
      var $17;
      if ($17) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $19=$2;
      var $20=(($19+1)|0);
      $2=$20;
      var $21=HEAP8[($19)];
      var $22=$1;
      var $23=(($22+1)|0);
      $1=$23;
      HEAP8[($22)]=$21;
      __label__ = 4; break;
    case 8: 
      __label__ = 9; break;
    case 9: 
      var $26=$1;
      HEAP8[($26)]=0;
      var $27=$1;
      ;
      return $27;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_MemCmp($s1, $s2, $n) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      $2=$s1;
      $3=$s2;
      $4=$n;
      var $5=$4;
      var $6=(($5)|0)==0;
      if ($6) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      $1=0;
      __label__ = 10; break;
    case 4: 
      __label__ = 5; break;
    case 5: 
      var $10=$2;
      var $11=HEAPU8[($10)];
      var $12=(($11)&255);
      var $13=$3;
      var $14=HEAPU8[($13)];
      var $15=(($14)&255);
      var $16=(($12)|0)==(($15)|0);
      if ($16) { __label__ = 6; break; } else { __label__ = 9; break; }
    case 6: 
      var $18=$4;
      var $19=((($18)-(1))|0);
      $4=$19;
      var $20=$4;
      var $21=(($20)|0)==0;
      if ($21) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      $1=0;
      __label__ = 10; break;
    case 8: 
      var $24=$2;
      var $25=(($24+1)|0);
      $2=$25;
      var $26=$3;
      var $27=(($26+1)|0);
      $3=$27;
      __label__ = 5; break;
    case 9: 
      var $29=$2;
      var $30=HEAPU8[($29)];
      var $31=(($30)&255);
      var $32=$3;
      var $33=HEAPU8[($32)];
      var $34=(($33)&255);
      var $35=((($31)-($34))|0);
      $1=$35;
      __label__ = 10; break;
    case 10: 
      var $37=$1;
      ;
      return $37;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_StrCmp($s1, $s2) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      $2=$s1;
      $3=$s2;
      var $4=$2;
      var $5=(($4)|0)!=0;
      if ($5) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $7=$3;
      var $8=(($7)|0)!=0;
      if ($8) { __label__ = 8; break; } else { __label__ = 4; break; }
    case 4: 
      var $10=$2;
      var $11=(($10)|0)!=0;
      if ($11) { __label__ = 7; break; } else { __label__ = 5; break; }
    case 5: 
      var $13=$3;
      var $14=(($13)|0)!=0;
      if ($14) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      $1=-1;
      __label__ = 15; break;
    case 7: 
      $1=1;
      __label__ = 15; break;
    case 8: 
      __label__ = 9; break;
    case 9: 
      var $19=$2;
      var $20=HEAP8[($19)];
      var $21=(($20 << 24) >> 24);
      var $22=$3;
      var $23=HEAP8[($22)];
      var $24=(($23 << 24) >> 24);
      var $25=(($21)|0)==(($24)|0);
      if ($25) { __label__ = 10; break; } else { __label__ = 14; break; }
    case 10: 
      var $27=$2;
      var $28=(($27+1)|0);
      $2=$28;
      var $29=$3;
      var $30=(($29+1)|0);
      $3=$30;
      var $31=$2;
      var $32=HEAP8[($31)];
      var $33=(($32 << 24) >> 24);
      var $34=(($33)|0)==0;
      if ($34) { __label__ = 12; break; } else { __label__ = 11; break; }
    case 11: 
      var $36=$3;
      var $37=HEAP8[($36)];
      var $38=(($37 << 24) >> 24);
      var $39=(($38)|0)==0;
      if ($39) { __label__ = 12; break; } else { __label__ = 13; break; }
    case 12: 
      __label__ = 14; break;
    case 13: 
      __label__ = 9; break;
    case 14: 
      var $43=$2;
      var $44=HEAPU8[($43)];
      var $45=(($44)&255);
      var $46=$3;
      var $47=HEAPU8[($46)];
      var $48=(($47)&255);
      var $49=((($45)-($48))|0);
      $1=$49;
      __label__ = 15; break;
    case 15: 
      var $51=$1;
      ;
      return $51;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_StrCmp["X"]=1;

function _HPDF_MemSet($s, $c, $n) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $b;
      $1=$s;
      $2=$c;
      $3=$n;
      var $4=$1;
      $b=$4;
      __label__ = 3; break;
    case 3: 
      var $6=$3;
      var $7=(($6)>>>0) > 0;
      if ($7) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      var $9=$2;
      var $10=$b;
      HEAP8[($10)]=$9;
      var $11=$b;
      var $12=(($11+1)|0);
      $b=$12;
      var $13=$3;
      var $14=((($13)-(1))|0);
      $3=$14;
      __label__ = 3; break;
    case 5: 
      var $16=$b;
      ;
      return $16;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_StrLen($s, $maxlen) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $len;
      $2=$s;
      $3=$maxlen;
      $len=0;
      var $4=$2;
      var $5=(($4)|0)!=0;
      if ($5) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=0;
      __label__ = 12; break;
    case 4: 
      __label__ = 5; break;
    case 5: 
      var $9=$2;
      var $10=HEAP8[($9)];
      var $11=(($10 << 24) >> 24);
      var $12=(($11)|0)!=0;
      if ($12) { __label__ = 6; break; } else { var $23 = 0;__label__ = 9; break; }
    case 6: 
      var $14=$3;
      var $15=(($14)|0) < 0;
      if ($15) { var $21 = 1;__label__ = 8; break; } else { __label__ = 7; break; }
    case 7: 
      var $17=$len;
      var $18=$3;
      var $19=(($17)|0) < (($18)|0);
      var $21 = $19;__label__ = 8; break;
    case 8: 
      var $21;
      var $23 = $21;__label__ = 9; break;
    case 9: 
      var $23;
      if ($23) { __label__ = 10; break; } else { __label__ = 11; break; }
    case 10: 
      var $25=$2;
      var $26=(($25+1)|0);
      $2=$26;
      var $27=$len;
      var $28=((($27)+(1))|0);
      $len=$28;
      __label__ = 5; break;
    case 11: 
      var $30=$len;
      $1=$30;
      __label__ = 12; break;
    case 12: 
      var $32=$1;
      ;
      return $32;
    default: assert(0, "bad label: " + __label__);
  }
}


function _HPDF_StrStr($s1, $s2, $maxlen) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $len;
      $2=$s1;
      $3=$s2;
      $4=$maxlen;
      var $5=$3;
      var $6=_HPDF_StrLen($5, -1);
      $len=$6;
      var $7=$2;
      var $8=(($7)|0)!=0;
      if ($8) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=0;
      __label__ = 16; break;
    case 4: 
      var $11=$len;
      var $12=(($11)|0)==0;
      if ($12) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      var $14=$2;
      $1=$14;
      __label__ = 16; break;
    case 6: 
      var $16=$4;
      var $17=(($16)|0)==0;
      if ($17) { __label__ = 7; break; } else { __label__ = 8; break; }
    case 7: 
      var $19=$2;
      var $20=_HPDF_StrLen($19, -1);
      $4=$20;
      __label__ = 8; break;
    case 8: 
      var $22=$4;
      var $23=$len;
      var $24=(($22)>>>0) < (($23)>>>0);
      if ($24) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      $1=0;
      __label__ = 16; break;
    case 10: 
      var $27=$len;
      var $28=$4;
      var $29=((($28)-($27))|0);
      $4=$29;
      var $30=$4;
      var $31=((($30)+(1))|0);
      $4=$31;
      __label__ = 11; break;
    case 11: 
      var $33=$4;
      var $34=(($33)>>>0) > 0;
      if ($34) { __label__ = 12; break; } else { __label__ = 15; break; }
    case 12: 
      var $36=$2;
      var $37=$3;
      var $38=$len;
      var $39=_HPDF_MemCmp($36, $37, $38);
      var $40=(($39)|0)==0;
      if ($40) { __label__ = 13; break; } else { __label__ = 14; break; }
    case 13: 
      var $42=$2;
      $1=$42;
      __label__ = 16; break;
    case 14: 
      var $44=$2;
      var $45=(($44+1)|0);
      $2=$45;
      var $46=$4;
      var $47=((($46)-(1))|0);
      $4=$47;
      __label__ = 11; break;
    case 15: 
      $1=0;
      __label__ = 16; break;
    case 16: 
      var $50=$1;
      ;
      return $50;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_StrStr["X"]=1;

function _HPDF_ToBox($agg_result, $left, $bottom, $right, $top) {
  var __stackBase__  = STACKTOP; STACKTOP += 16; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;

  var $1;
  var $2;
  var $3;
  var $4;
  var $box=__stackBase__;
  $1=$left;
  $2=$bottom;
  $3=$right;
  $4=$top;
  var $5=$1;
  var $6=(($5 << 16) >> 16);
  var $7=(($box)|0);
  HEAPF32[(($7)>>2)]=$6;
  var $8=$2;
  var $9=(($8 << 16) >> 16);
  var $10=(($box+4)|0);
  HEAPF32[(($10)>>2)]=$9;
  var $11=$3;
  var $12=(($11 << 16) >> 16);
  var $13=(($box+8)|0);
  HEAPF32[(($13)>>2)]=$12;
  var $14=$4;
  var $15=(($14 << 16) >> 16);
  var $16=(($box+12)|0);
  HEAPF32[(($16)>>2)]=$15;
  var $17=$agg_result;
  var $18=$box;
  assert(16 % 1 === 0, 'memcpy given ' + 16 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP32[(($17)>>2)]=HEAP32[(($18)>>2)];HEAP32[((($17)+(4))>>2)]=HEAP32[((($18)+(4))>>2)];HEAP32[((($17)+(8))>>2)]=HEAP32[((($18)+(8))>>2)];HEAP32[((($17)+(12))>>2)]=HEAP32[((($18)+(12))>>2)];
  STACKTOP = __stackBase__;
  return;
}


function _HPDF_ToPoint($agg_result, $x, $y) {
  var __stackBase__  = STACKTOP; STACKTOP += 8; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;

  var $1;
  var $2;
  var $point=__stackBase__;
  $1=$x;
  $2=$y;
  var $3=$1;
  var $4=(($3 << 16) >> 16);
  var $5=(($point)|0);
  HEAPF32[(($5)>>2)]=$4;
  var $6=$2;
  var $7=(($6 << 16) >> 16);
  var $8=(($point+4)|0);
  HEAPF32[(($8)>>2)]=$7;
  var $9=$agg_result;
  var $10=$point;
  assert(8 % 1 === 0, 'memcpy given ' + 8 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP32[(($9)>>2)]=HEAP32[(($10)>>2)];HEAP32[((($9)+(4))>>2)]=HEAP32[((($10)+(4))>>2)];
  STACKTOP = __stackBase__;
  return;
}


function _HPDF_UInt16Swap($value) {
  var __stackBase__  = STACKTOP; STACKTOP += 4; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;

  var $1;
  var $u=__stackBase__;
  $1=$value;
  var $2=(($u)|0);
  var $3=$1;
  var $4=$3;
  var $5=_HPDF_MemCpy($2, $4, 2);
  var $6=(($u)|0);
  var $7=HEAPU8[($6)];
  var $8=(($7)&255);
  var $9=(($8)&65535);
  var $10=$9 << 8;
  var $11=(($u+1)|0);
  var $12=HEAPU8[($11)];
  var $13=(($12)&255);
  var $14=(($13)&65535);
  var $15=$10 | $14;
  var $16=(($15) & 65535);
  var $17=$1;
  HEAP16[(($17)>>1)]=$16;
  STACKTOP = __stackBase__;
  return;
}


function _HPDF_Xref_New($mmgr, $offset) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $xref;
      var $new_entry;
      $2=$mmgr;
      $3=$offset;
      var $4=$2;
      var $5=_HPDF_GetMem($4, 28);
      var $6=$5;
      $xref=$6;
      var $7=$xref;
      var $8=(($7)|0)!=0;
      if ($8) { __label__ = 4; break; } else { __label__ = 3; break; }
    case 3: 
      $1=0;
      __label__ = 16; break;
    case 4: 
      var $11=$xref;
      var $12=$11;
      var $13=_HPDF_MemSet($12, 0, 28);
      var $14=$2;
      var $15=$xref;
      var $16=(($15)|0);
      HEAP32[(($16)>>2)]=$14;
      var $17=$2;
      var $18=(($17)|0);
      var $19=HEAP32[(($18)>>2)];
      var $20=$xref;
      var $21=(($20+4)|0);
      HEAP32[(($21)>>2)]=$19;
      var $22=$3;
      var $23=$xref;
      var $24=(($23+8)|0);
      HEAP32[(($24)>>2)]=$22;
      var $25=$2;
      var $26=_HPDF_List_New($25, 1024);
      var $27=$xref;
      var $28=(($27+12)|0);
      HEAP32[(($28)>>2)]=$26;
      var $29=$xref;
      var $30=(($29+12)|0);
      var $31=HEAP32[(($30)>>2)];
      var $32=(($31)|0)!=0;
      if ($32) { __label__ = 6; break; } else { __label__ = 5; break; }
    case 5: 
      __label__ = 15; break;
    case 6: 
      var $35=$xref;
      var $36=(($35+16)|0);
      HEAP32[(($36)>>2)]=0;
      var $37=$xref;
      var $38=(($37+8)|0);
      var $39=HEAP32[(($38)>>2)];
      var $40=(($39)|0)==0;
      if ($40) { __label__ = 7; break; } else { __label__ = 12; break; }
    case 7: 
      var $42=$2;
      var $43=_HPDF_GetMem($42, 16);
      var $44=$43;
      $new_entry=$44;
      var $45=$new_entry;
      var $46=(($45)|0)!=0;
      if ($46) { __label__ = 9; break; } else { __label__ = 8; break; }
    case 8: 
      __label__ = 15; break;
    case 9: 
      var $49=$xref;
      var $50=(($49+12)|0);
      var $51=HEAP32[(($50)>>2)];
      var $52=$new_entry;
      var $53=$52;
      var $54=_HPDF_List_Add($51, $53);
      var $55=(($54)|0)!=0;
      if ($55) { __label__ = 10; break; } else { __label__ = 11; break; }
    case 10: 
      var $57=$2;
      var $58=$new_entry;
      var $59=$58;
      _HPDF_FreeMem($57, $59);
      __label__ = 15; break;
    case 11: 
      var $61=$new_entry;
      var $62=(($61)|0);
      HEAP8[($62)]=102;
      var $63=$new_entry;
      var $64=(($63+4)|0);
      HEAP32[(($64)>>2)]=0;
      var $65=$new_entry;
      var $66=(($65+8)|0);
      HEAP16[(($66)>>1)]=-1;
      var $67=$new_entry;
      var $68=(($67+12)|0);
      HEAP32[(($68)>>2)]=0;
      __label__ = 12; break;
    case 12: 
      var $70=$2;
      var $71=_HPDF_Dict_New($70);
      var $72=$xref;
      var $73=(($72+24)|0);
      HEAP32[(($73)>>2)]=$71;
      var $74=$xref;
      var $75=(($74+24)|0);
      var $76=HEAP32[(($75)>>2)];
      var $77=(($76)|0)!=0;
      if ($77) { __label__ = 14; break; } else { __label__ = 13; break; }
    case 13: 
      __label__ = 15; break;
    case 14: 
      var $80=$xref;
      $1=$80;
      __label__ = 16; break;
    case 15: 
      var $82=$xref;
      _HPDF_Xref_Free($82);
      $1=0;
      __label__ = 16; break;
    case 16: 
      var $84=$1;
      ;
      return $84;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Xref_New["X"]=1;

function _HPDF_Xref_Free($xref) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $i;
      var $entry;
      var $tmp_xref;
      $1=$xref;
      __label__ = 3; break;
    case 3: 
      var $3=$1;
      var $4=(($3)|0)!=0;
      if ($4) { __label__ = 4; break; } else { __label__ = 15; break; }
    case 4: 
      var $6=$1;
      var $7=(($6+12)|0);
      var $8=HEAP32[(($7)>>2)];
      var $9=(($8)|0)!=0;
      if ($9) { __label__ = 5; break; } else { __label__ = 12; break; }
    case 5: 
      $i=0;
      __label__ = 6; break;
    case 6: 
      var $12=$i;
      var $13=$1;
      var $14=(($13+12)|0);
      var $15=HEAP32[(($14)>>2)];
      var $16=(($15+16)|0);
      var $17=HEAPU32[(($16)>>2)];
      var $18=(($12)>>>0) < (($17)>>>0);
      if ($18) { __label__ = 7; break; } else { __label__ = 11; break; }
    case 7: 
      var $20=$1;
      var $21=$i;
      var $22=_HPDF_Xref_GetEntry($20, $21);
      $entry=$22;
      var $23=$entry;
      var $24=(($23+12)|0);
      var $25=HEAP32[(($24)>>2)];
      var $26=(($25)|0)!=0;
      if ($26) { __label__ = 8; break; } else { __label__ = 9; break; }
    case 8: 
      var $28=$1;
      var $29=(($28)|0);
      var $30=HEAP32[(($29)>>2)];
      var $31=$entry;
      var $32=(($31+12)|0);
      var $33=HEAP32[(($32)>>2)];
      _HPDF_Obj_ForceFree($30, $33);
      __label__ = 9; break;
    case 9: 
      var $35=$1;
      var $36=(($35)|0);
      var $37=HEAP32[(($36)>>2)];
      var $38=$entry;
      var $39=$38;
      _HPDF_FreeMem($37, $39);
      __label__ = 10; break;
    case 10: 
      var $41=$i;
      var $42=((($41)+(1))|0);
      $i=$42;
      __label__ = 6; break;
    case 11: 
      var $44=$1;
      var $45=(($44+12)|0);
      var $46=HEAP32[(($45)>>2)];
      _HPDF_List_Free($46);
      __label__ = 12; break;
    case 12: 
      var $48=$1;
      var $49=(($48+24)|0);
      var $50=HEAP32[(($49)>>2)];
      var $51=(($50)|0)!=0;
      if ($51) { __label__ = 13; break; } else { __label__ = 14; break; }
    case 13: 
      var $53=$1;
      var $54=(($53+24)|0);
      var $55=HEAP32[(($54)>>2)];
      _HPDF_Dict_Free($55);
      __label__ = 14; break;
    case 14: 
      var $57=$1;
      var $58=(($57+20)|0);
      var $59=HEAP32[(($58)>>2)];
      $tmp_xref=$59;
      var $60=$1;
      var $61=(($60)|0);
      var $62=HEAP32[(($61)>>2)];
      var $63=$1;
      var $64=$63;
      _HPDF_FreeMem($62, $64);
      var $65=$tmp_xref;
      $1=$65;
      __label__ = 3; break;
    case 15: 
      ;
      return;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Xref_Free["X"]=1;

function _main() {
  ;
  var __label__;

  ;
  return 0;
}
Module["_main"] = _main;

function _HPDF_Xref_GetEntry($xref, $index) {
  ;
  var __label__;

  var $1;
  var $2;
  $1=$xref;
  $2=$index;
  var $3=$1;
  var $4=(($3+12)|0);
  var $5=HEAP32[(($4)>>2)];
  var $6=$2;
  var $7=_HPDF_List_ItemAt($5, $6);
  var $8=$7;
  ;
  return $8;
}


function _HPDF_Xref_Add($xref, $obj) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $entry;
      var $header;
      $2=$xref;
      $3=$obj;
      var $4=$3;
      var $5=(($4)|0)!=0;
      if ($5) { __label__ = 6; break; } else { __label__ = 3; break; }
    case 3: 
      var $7=$2;
      var $8=(($7+4)|0);
      var $9=HEAP32[(($8)>>2)];
      var $10=_HPDF_Error_GetCode($9);
      var $11=(($10)|0)==0;
      if ($11) { __label__ = 4; break; } else { __label__ = 5; break; }
    case 4: 
      var $13=$2;
      var $14=(($13+4)|0);
      var $15=HEAP32[(($14)>>2)];
      var $16=_HPDF_SetError($15, 4147, 0);
      $1=$16;
      __label__ = 17; break;
    case 5: 
      $1=4147;
      __label__ = 17; break;
    case 6: 
      var $19=$3;
      var $20=$19;
      $header=$20;
      var $21=$header;
      var $22=(($21)|0);
      var $23=HEAP32[(($22)>>2)];
      var $24=$23 & -2147483648;
      var $25=(($24)|0)!=0;
      if ($25) { __label__ = 8; break; } else { __label__ = 7; break; }
    case 7: 
      var $27=$header;
      var $28=(($27)|0);
      var $29=HEAP32[(($28)>>2)];
      var $30=$29 & 1073741824;
      var $31=(($30)|0)!=0;
      if ($31) { __label__ = 8; break; } else { __label__ = 9; break; }
    case 8: 
      var $33=$2;
      var $34=(($33+4)|0);
      var $35=HEAP32[(($34)>>2)];
      var $36=_HPDF_SetError($35, 4147, 0);
      $1=$36;
      __label__ = 17; break;
    case 9: 
      var $38=$2;
      var $39=(($38+12)|0);
      var $40=HEAP32[(($39)>>2)];
      var $41=(($40+16)|0);
      var $42=HEAPU32[(($41)>>2)];
      var $43=(($42)>>>0) >= 8388607;
      if ($43) { __label__ = 10; break; } else { __label__ = 11; break; }
    case 10: 
      var $45=$2;
      var $46=(($45+4)|0);
      var $47=HEAP32[(($46)>>2)];
      var $48=_HPDF_SetError($47, 4197, 0);
      __label__ = 16; break;
    case 11: 
      var $50=$2;
      var $51=(($50)|0);
      var $52=HEAP32[(($51)>>2)];
      var $53=_HPDF_GetMem($52, 16);
      var $54=$53;
      $entry=$54;
      var $55=$entry;
      var $56=(($55)|0)==0;
      if ($56) { __label__ = 12; break; } else { __label__ = 13; break; }
    case 12: 
      __label__ = 16; break;
    case 13: 
      var $59=$2;
      var $60=(($59+12)|0);
      var $61=HEAP32[(($60)>>2)];
      var $62=$entry;
      var $63=$62;
      var $64=_HPDF_List_Add($61, $63);
      var $65=(($64)|0)!=0;
      if ($65) { __label__ = 14; break; } else { __label__ = 15; break; }
    case 14: 
      var $67=$2;
      var $68=(($67)|0);
      var $69=HEAP32[(($68)>>2)];
      var $70=$entry;
      var $71=$70;
      _HPDF_FreeMem($69, $71);
      __label__ = 16; break;
    case 15: 
      var $73=$entry;
      var $74=(($73)|0);
      HEAP8[($74)]=110;
      var $75=$entry;
      var $76=(($75+4)|0);
      HEAP32[(($76)>>2)]=0;
      var $77=$entry;
      var $78=(($77+8)|0);
      HEAP16[(($78)>>1)]=0;
      var $79=$3;
      var $80=$entry;
      var $81=(($80+12)|0);
      HEAP32[(($81)>>2)]=$79;
      var $82=$2;
      var $83=(($82+8)|0);
      var $84=HEAP32[(($83)>>2)];
      var $85=$2;
      var $86=(($85+12)|0);
      var $87=HEAP32[(($86)>>2)];
      var $88=(($87+16)|0);
      var $89=HEAP32[(($88)>>2)];
      var $90=((($84)+($89))|0);
      var $91=((($90)-(1))|0);
      var $92=((($91)+(1073741824))|0);
      var $93=$header;
      var $94=(($93)|0);
      HEAP32[(($94)>>2)]=$92;
      var $95=$entry;
      var $96=(($95+8)|0);
      var $97=HEAP16[(($96)>>1)];
      var $98=$header;
      var $99=(($98+4)|0);
      HEAP16[(($99)>>1)]=$97;
      $1=0;
      __label__ = 17; break;
    case 16: 
      var $101=$2;
      var $102=(($101)|0);
      var $103=HEAP32[(($102)>>2)];
      var $104=$3;
      _HPDF_Obj_ForceFree($103, $104);
      var $105=$2;
      var $106=(($105+4)|0);
      var $107=HEAP32[(($106)>>2)];
      var $108=_HPDF_Error_GetCode($107);
      $1=$108;
      __label__ = 17; break;
    case 17: 
      var $110=$1;
      ;
      return $110;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Xref_Add["X"]=1;

function _HPDF_Xref_WriteToStream($xref, $stream, $e) {
  var __stackBase__  = STACKTOP; STACKTOP += 32; assert(STACKTOP % 4 == 0, "Stack is unaligned"); assert(STACKTOP < STACK_MAX, "Ran out of stack");
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $ret;
      var $i;
      var $buf=__stackBase__;
      var $pbuf;
      var $eptr;
      var $str_idx;
      var $tmp_xref;
      var $entry;
      var $obj_id;
      var $gen_no;
      var $entry1;
      $2=$xref;
      $3=$stream;
      $4=$e;
      var $5=(($buf)|0);
      var $6=(($5+32)|0);
      var $7=((($6)-(1))|0);
      $eptr=$7;
      var $8=$2;
      $tmp_xref=$8;
      __label__ = 3; break;
    case 3: 
      var $10=$tmp_xref;
      var $11=(($10)|0)!=0;
      if ($11) { __label__ = 4; break; } else { __label__ = 20; break; }
    case 4: 
      var $13=$tmp_xref;
      var $14=(($13+8)|0);
      var $15=HEAP32[(($14)>>2)];
      var $16=(($15)|0)==0;
      if ($16) { __label__ = 5; break; } else { __label__ = 6; break; }
    case 5: 
      $str_idx=1;
      __label__ = 7; break;
    case 6: 
      $str_idx=0;
      __label__ = 7; break;
    case 7: 
      var $20=$str_idx;
      $i=$20;
      __label__ = 8; break;
    case 8: 
      var $22=$i;
      var $23=$tmp_xref;
      var $24=(($23+12)|0);
      var $25=HEAP32[(($24)>>2)];
      var $26=(($25+16)|0);
      var $27=HEAPU32[(($26)>>2)];
      var $28=(($22)>>>0) < (($27)>>>0);
      if ($28) { __label__ = 9; break; } else { __label__ = 19; break; }
    case 9: 
      var $30=$tmp_xref;
      var $31=(($30+12)|0);
      var $32=HEAP32[(($31)>>2)];
      var $33=$i;
      var $34=_HPDF_List_ItemAt($32, $33);
      var $35=$34;
      $entry=$35;
      var $36=$tmp_xref;
      var $37=(($36+8)|0);
      var $38=HEAP32[(($37)>>2)];
      var $39=$i;
      var $40=((($38)+($39))|0);
      $obj_id=$40;
      var $41=$entry;
      var $42=(($41+8)|0);
      var $43=HEAP16[(($42)>>1)];
      $gen_no=$43;
      var $44=$3;
      var $45=(($44+16)|0);
      var $46=HEAP32[(($45)>>2)];
      var $47=$entry;
      var $48=(($47+4)|0);
      HEAP32[(($48)>>2)]=$46;
      var $49=(($buf)|0);
      $pbuf=$49;
      var $50=$pbuf;
      var $51=$obj_id;
      var $52=$eptr;
      var $53=_HPDF_IToA($50, $51, $52);
      $pbuf=$53;
      var $54=$pbuf;
      var $55=(($54+1)|0);
      $pbuf=$55;
      HEAP8[($54)]=32;
      var $56=$pbuf;
      var $57=$gen_no;
      var $58=(($57)&65535);
      var $59=$eptr;
      var $60=_HPDF_IToA($56, $58, $59);
      $pbuf=$60;
      var $61=$pbuf;
      var $62=$eptr;
      var $63=_HPDF_StrCpy($61, ((STRING_TABLE.__str1803)|0), $62);
      var $64=$3;
      var $65=(($buf)|0);
      var $66=_HPDF_Stream_WriteStr($64, $65);
      $ret=$66;
      var $67=(($66)|0)!=0;
      if ($67) { __label__ = 10; break; } else { __label__ = 11; break; }
    case 10: 
      var $69=$ret;
      $1=$69;
      __label__ = 32; break;
    case 11: 
      var $71=$4;
      var $72=(($71)|0)!=0;
      if ($72) { __label__ = 12; break; } else { __label__ = 13; break; }
    case 12: 
      var $74=$4;
      var $75=$obj_id;
      var $76=$gen_no;
      _HPDF_Encrypt_InitKey($74, $75, $76);
      __label__ = 13; break;
    case 13: 
      var $78=$entry;
      var $79=(($78+12)|0);
      var $80=HEAP32[(($79)>>2)];
      var $81=$3;
      var $82=$4;
      var $83=_HPDF_Obj_WriteValue($80, $81, $82);
      $ret=$83;
      var $84=(($83)|0)!=0;
      if ($84) { __label__ = 14; break; } else { __label__ = 15; break; }
    case 14: 
      var $86=$ret;
      $1=$86;
      __label__ = 32; break;
    case 15: 
      var $88=$3;
      var $89=_HPDF_Stream_WriteStr($88, ((STRING_TABLE.__str11804)|0));
      $ret=$89;
      var $90=(($89)|0)!=0;
      if ($90) { __label__ = 16; break; } else { __label__ = 17; break; }
    case 16: 
      var $92=$ret;
      $1=$92;
      __label__ = 32; break;
    case 17: 
      __label__ = 18; break;
    case 18: 
      var $95=$i;
      var $96=((($95)+(1))|0);
      $i=$96;
      __label__ = 8; break;
    case 19: 
      var $98=$tmp_xref;
      var $99=(($98+20)|0);
      var $100=HEAP32[(($99)>>2)];
      $tmp_xref=$100;
      __label__ = 3; break;
    case 20: 
      var $102=$2;
      $tmp_xref=$102;
      __label__ = 21; break;
    case 21: 
      var $104=$tmp_xref;
      var $105=(($104)|0)!=0;
      if ($105) { __label__ = 22; break; } else { __label__ = 31; break; }
    case 22: 
      var $107=$3;
      var $108=(($107+16)|0);
      var $109=HEAP32[(($108)>>2)];
      var $110=$tmp_xref;
      var $111=(($110+16)|0);
      HEAP32[(($111)>>2)]=$109;
      var $112=(($buf)|0);
      $pbuf=$112;
      var $113=$pbuf;
      var $114=$eptr;
      var $115=_HPDF_StrCpy($113, ((STRING_TABLE.__str21805)|0), $114);
      $pbuf=$115;
      var $116=$pbuf;
      var $117=$tmp_xref;
      var $118=(($117+8)|0);
      var $119=HEAP32[(($118)>>2)];
      var $120=$eptr;
      var $121=_HPDF_IToA($116, $119, $120);
      $pbuf=$121;
      var $122=$pbuf;
      var $123=(($122+1)|0);
      $pbuf=$123;
      HEAP8[($122)]=32;
      var $124=$pbuf;
      var $125=$tmp_xref;
      var $126=(($125+12)|0);
      var $127=HEAP32[(($126)>>2)];
      var $128=(($127+16)|0);
      var $129=HEAP32[(($128)>>2)];
      var $130=$eptr;
      var $131=_HPDF_IToA($124, $129, $130);
      $pbuf=$131;
      var $132=$pbuf;
      var $133=$eptr;
      var $134=_HPDF_StrCpy($132, ((STRING_TABLE.__str31806)|0), $133);
      var $135=$3;
      var $136=(($buf)|0);
      var $137=_HPDF_Stream_WriteStr($135, $136);
      $ret=$137;
      var $138=$ret;
      var $139=(($138)|0)!=0;
      if ($139) { __label__ = 23; break; } else { __label__ = 24; break; }
    case 23: 
      var $141=$ret;
      $1=$141;
      __label__ = 32; break;
    case 24: 
      $i=0;
      __label__ = 25; break;
    case 25: 
      var $144=$i;
      var $145=$tmp_xref;
      var $146=(($145+12)|0);
      var $147=HEAP32[(($146)>>2)];
      var $148=(($147+16)|0);
      var $149=HEAPU32[(($148)>>2)];
      var $150=(($144)>>>0) < (($149)>>>0);
      if ($150) { __label__ = 26; break; } else { __label__ = 30; break; }
    case 26: 
      var $152=$tmp_xref;
      var $153=$i;
      var $154=_HPDF_Xref_GetEntry($152, $153);
      $entry1=$154;
      var $155=(($buf)|0);
      $pbuf=$155;
      var $156=$pbuf;
      var $157=$entry1;
      var $158=(($157+4)|0);
      var $159=HEAP32[(($158)>>2)];
      var $160=_HPDF_IToA2($156, $159, 11);
      $pbuf=$160;
      var $161=$pbuf;
      var $162=(($161+1)|0);
      $pbuf=$162;
      HEAP8[($161)]=32;
      var $163=$pbuf;
      var $164=$entry1;
      var $165=(($164+8)|0);
      var $166=HEAPU16[(($165)>>1)];
      var $167=(($166)&65535);
      var $168=_HPDF_IToA2($163, $167, 6);
      $pbuf=$168;
      var $169=$pbuf;
      var $170=(($169+1)|0);
      $pbuf=$170;
      HEAP8[($169)]=32;
      var $171=$entry1;
      var $172=(($171)|0);
      var $173=HEAP8[($172)];
      var $174=$pbuf;
      var $175=(($174+1)|0);
      $pbuf=$175;
      HEAP8[($174)]=$173;
      var $176=$pbuf;
      var $177=$eptr;
      var $178=_HPDF_StrCpy($176, ((STRING_TABLE.__str31806)|0), $177);
      var $179=$3;
      var $180=(($buf)|0);
      var $181=_HPDF_Stream_WriteStr($179, $180);
      $ret=$181;
      var $182=$ret;
      var $183=(($182)|0)!=0;
      if ($183) { __label__ = 27; break; } else { __label__ = 28; break; }
    case 27: 
      var $185=$ret;
      $1=$185;
      __label__ = 32; break;
    case 28: 
      __label__ = 29; break;
    case 29: 
      var $188=$i;
      var $189=((($188)+(1))|0);
      $i=$189;
      __label__ = 25; break;
    case 30: 
      var $191=$tmp_xref;
      var $192=(($191+20)|0);
      var $193=HEAP32[(($192)>>2)];
      $tmp_xref=$193;
      __label__ = 21; break;
    case 31: 
      var $195=$2;
      var $196=$3;
      var $197=_WriteTrailer($195, $196);
      $ret=$197;
      var $198=$ret;
      $1=$198;
      __label__ = 32; break;
    case 32: 
      var $200=$1;
      STACKTOP = __stackBase__;
      return $200;
    default: assert(0, "bad label: " + __label__);
  }
}
_HPDF_Xref_WriteToStream["X"]=1;

function _WriteTrailer($xref, $stream) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $max_obj_id;
      var $ret;
      $2=$xref;
      $3=$stream;
      var $4=$2;
      var $5=(($4+12)|0);
      var $6=HEAP32[(($5)>>2)];
      var $7=(($6+16)|0);
      var $8=HEAP32[(($7)>>2)];
      var $9=$2;
      var $10=(($9+8)|0);
      var $11=HEAP32[(($10)>>2)];
      var $12=((($8)+($11))|0);
      $max_obj_id=$12;
      var $13=$2;
      var $14=(($13+24)|0);
      var $15=HEAP32[(($14)>>2)];
      var $16=$max_obj_id;
      var $17=_HPDF_Dict_AddNumber($15, ((STRING_TABLE.__str41807)|0), $16);
      $ret=$17;
      var $18=(($17)|0)!=0;
      if ($18) { __label__ = 3; break; } else { __label__ = 4; break; }
    case 3: 
      var $20=$ret;
      $1=$20;
      __label__ = 19; break;
    case 4: 
      var $22=$2;
      var $23=(($22+20)|0);
      var $24=HEAP32[(($23)>>2)];
      var $25=(($24)|0)!=0;
      if ($25) { __label__ = 5; break; } else { __label__ = 8; break; }
    case 5: 
      var $27=$2;
      var $28=(($27+24)|0);
      var $29=HEAP32[(($28)>>2)];
      var $30=$2;
      var $31=(($30+20)|0);
      var $32=HEAP32[(($31)>>2)];
      var $33=(($32+16)|0);
      var $34=HEAP32[(($33)>>2)];
      var $35=_HPDF_Dict_AddNumber($29, ((STRING_TABLE.__str51808)|0), $34);
      $ret=$35;
      var $36=(($35)|0)!=0;
      if ($36) { __label__ = 6; break; } else { __label__ = 7; break; }
    case 6: 
      var $38=$ret;
      $1=$38;
      __label__ = 19; break;
    case 7: 
      __label__ = 8; break;
    case 8: 
      var $41=$3;
      var $42=_HPDF_Stream_WriteStr($41, ((STRING_TABLE.__str61809)|0));
      $ret=$42;
      var $43=(($42)|0)!=0;
      if ($43) { __label__ = 9; break; } else { __label__ = 10; break; }
    case 9: 
      var $45=$ret;
      $1=$45;
      __label__ = 19; break;
    case 10: 
      var $47=$2;
      var $48=(($47+24)|0);
      var $49=HEAP32[(($48)>>2)];
      var $50=$3;
      var $51=_HPDF_Dict_Write($49, $50, 0);
      $ret=$51;
      var $52=(($51)|0)!=0;
      if ($52) { __label__ = 11; break; } else { __label__ = 12; break; }
    case 11: 
      var $54=$ret;
      $1=$54;
      __label__ = 19; break;
    case 12: 
      var $56=$3;
      var $57=_HPDF_Stream_WriteStr($56, ((STRING_TABLE.__str71810)|0));
      $ret=$57;
      var $58=(($57)|0)!=0;
      if ($58) { __label__ = 13; break; } else { __label__ = 14; break; }
    case 13: 
      var $60=$ret;
      $1=$60;
      __label__ = 19; break;
    case 14: 
      var $62=$3;
      var $63=$2;
      var $64=(($63+16)|0);
      var $65=HEAP32[(($64)>>2)];
      var $66=_HPDF_Stream_WriteUInt($62, $65);
      $ret=$66;
      var $67=(($66)|0)!=0;
      if ($67) { __label__ = 15; break; } else { __label__ = 16; break; }
    case 15: 
      var $69=$ret;
      $1=$69;
      __label__ = 19; break;
    case 16: 
      var $71=$3;
      var $72=_HPDF_Stream_WriteStr($71, ((STRING_TABLE.__str81811)|0));
      $ret=$72;
      var $73=(($72)|0)!=0;
      if ($73) { __label__ = 17; break; } else { __label__ = 18; break; }
    case 17: 
      var $75=$ret;
      $1=$75;
      __label__ = 19; break;
    case 18: 
      $1=0;
      __label__ = 19; break;
    case 19: 
      var $78=$1;
      ;
      return $78;
    default: assert(0, "bad label: " + __label__);
  }
}
_WriteTrailer["X"]=1;

function _malloc($bytes) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $mem;
      var $nb;
      var $idx;
      var $smallbits;
      var $b;
      var $p;
      var $F;
      var $b1;
      var $p2;
      var $r;
      var $rsize;
      var $i;
      var $leftbits;
      var $leastbit;
      var $Y;
      var $K;
      var $N;
      var $F3;
      var $DVS;
      var $DV;
      var $I;
      var $B;
      var $F4;
      var $rsize5;
      var $p6;
      var $r7;
      var $dvs;
      var $rsize8;
      var $p9;
      var $r10;
      $1=$bytes;
      var $2=$1; //@line 4628 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $3=(($2)>>>0) <= 244; //@line 4628 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($3) { __label__ = 3; break; } else { __label__ = 38; break; } //@line 4628 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 3: 
      var $5=$1; //@line 4631 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $6=(($5)>>>0) < 11; //@line 4631 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($6) { __label__ = 4; break; } else { __label__ = 5; break; } //@line 4631 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 4: 
      var $14 = 16;__label__ = 6; break; //@line 4631 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 5: 
      var $9=$1; //@line 4631 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $10=((($9)+(4))|0); //@line 4631 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $11=((($10)+(7))|0); //@line 4631 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $12=$11 & -8; //@line 4631 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $14 = $12;__label__ = 6; break; //@line 4631 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 6: 
      var $14; //@line 4631 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $nb=$14; //@line 4631 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $15=$nb; //@line 4632 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $16=$15 >>> 3; //@line 4632 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $idx=$16; //@line 4632 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $17=HEAPU32[((((__gm_)|0))>>2)]; //@line 4633 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $18=$idx; //@line 4633 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $19=$17 >>> (($18)>>>0); //@line 4633 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $smallbits=$19; //@line 4633 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $20=$smallbits; //@line 4635 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $21=$20 & 3; //@line 4635 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $22=(($21)|0)!=0; //@line 4635 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($22) { __label__ = 7; break; } else { __label__ = 14; break; } //@line 4635 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 7: 
      var $24=$smallbits; //@line 4637 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $25=$24 ^ -1; //@line 4637 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $26=$25 & 1; //@line 4637 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $27=$idx; //@line 4637 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $28=((($27)+($26))|0); //@line 4637 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $idx=$28; //@line 4637 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $29=$idx; //@line 4638 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $30=$29 << 1; //@line 4638 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $31=((((__gm_+40)|0)+($30<<2))|0); //@line 4638 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $32=$31; //@line 4638 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $33=$32; //@line 4638 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $b=$33; //@line 4638 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $34=$b; //@line 4639 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $35=(($34+8)|0); //@line 4639 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $36=HEAP32[(($35)>>2)]; //@line 4639 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $p=$36; //@line 4639 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $37=$p; //@line 4641 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $38=(($37+8)|0); //@line 4641 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $39=HEAP32[(($38)>>2)]; //@line 4641 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $F=$39; //@line 4641 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $40=$b; //@line 4641 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $41=$F; //@line 4641 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $42=(($40)|0)==(($41)|0); //@line 4641 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($42) { __label__ = 8; break; } else { __label__ = 9; break; } //@line 4641 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 8: 
      var $44=$idx; //@line 4641 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $45=1 << $44; //@line 4641 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $46=$45 ^ -1; //@line 4641 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $47=HEAP32[((((__gm_)|0))>>2)]; //@line 4641 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $48=$47 & $46; //@line 4641 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[((((__gm_)|0))>>2)]=$48; //@line 4641 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 13; break; //@line 4641 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 9: 
      var $50=$F; //@line 4641 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $51=$50; //@line 4641 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $52=HEAPU32[((((__gm_+16)|0))>>2)]; //@line 4641 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $53=(($51)>>>0) >= (($52)>>>0); //@line 4641 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $54=(($53)&1); //@line 4641 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $55=(($54)==(1)); //@line 4641 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $56=(($55)|0)!=0; //@line 4641 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($56) { __label__ = 10; break; } else { __label__ = 11; break; } //@line 4641 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 10: 
      var $58=$F; //@line 4641 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $59=$b; //@line 4641 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $60=(($59+8)|0); //@line 4641 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($60)>>2)]=$58; //@line 4641 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $61=$b; //@line 4641 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $62=$F; //@line 4641 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $63=(($62+12)|0); //@line 4641 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($63)>>2)]=$61; //@line 4641 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 12; break; //@line 4641 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 11: 
      _abort(); //@line 4641 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      throw "Reached an unreachable!" //@line 4641 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 12: 
      __label__ = 13; break;
    case 13: 
      var $67=$idx; //@line 4642 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $68=$67 << 3; //@line 4642 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $69=$68 | 1; //@line 4642 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $70=$69 | 2; //@line 4642 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $71=$p; //@line 4642 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $72=(($71+4)|0); //@line 4642 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($72)>>2)]=$70; //@line 4642 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $73=$p; //@line 4642 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $74=$73; //@line 4642 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $75=$idx; //@line 4642 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $76=$75 << 3; //@line 4642 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $77=(($74+$76)|0); //@line 4642 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $78=$77; //@line 4642 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $79=(($78+4)|0); //@line 4642 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $80=HEAP32[(($79)>>2)]; //@line 4642 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $81=$80 | 1; //@line 4642 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($79)>>2)]=$81; //@line 4642 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $82=$p; //@line 4643 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $83=$82; //@line 4643 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $84=(($83+8)|0); //@line 4643 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $mem=$84; //@line 4643 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 54; break; //@line 4645 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 14: 
      var $86=$nb; //@line 4648 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $87=HEAPU32[((((__gm_+8)|0))>>2)]; //@line 4648 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $88=(($86)>>>0) > (($87)>>>0); //@line 4648 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($88) { __label__ = 15; break; } else { __label__ = 36; break; } //@line 4648 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 15: 
      var $90=$smallbits; //@line 4649 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $91=(($90)|0)!=0; //@line 4649 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($91) { __label__ = 16; break; } else { __label__ = 31; break; } //@line 4649 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 16: 
      var $93=$smallbits; //@line 4653 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $94=$idx; //@line 4653 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $95=$93 << $94; //@line 4653 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $96=$idx; //@line 4653 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $97=1 << $96; //@line 4653 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $98=$97 << 1; //@line 4653 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $99=$idx; //@line 4653 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $100=1 << $99; //@line 4653 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $101=$100 << 1; //@line 4653 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $102=(((-$101))|0); //@line 4653 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $103=$98 | $102; //@line 4653 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $104=$95 & $103; //@line 4653 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $leftbits=$104; //@line 4653 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $105=$leftbits; //@line 4654 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $106=$leftbits; //@line 4654 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $107=(((-$106))|0); //@line 4654 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $108=$105 & $107; //@line 4654 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $leastbit=$108; //@line 4654 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $109=$leastbit; //@line 4655 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $110=((($109)-(1))|0); //@line 4655 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $Y=$110; //@line 4655 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $111=$Y; //@line 4655 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $112=$111 >>> 12; //@line 4655 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $113=$112 & 16; //@line 4655 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $K=$113; //@line 4655 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $114=$K; //@line 4655 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $N=$114; //@line 4655 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $115=$K; //@line 4655 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $116=$Y; //@line 4655 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $117=$116 >>> (($115)>>>0); //@line 4655 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $Y=$117; //@line 4655 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $118=$Y; //@line 4655 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $119=$118 >>> 5; //@line 4655 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $120=$119 & 8; //@line 4655 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $K=$120; //@line 4655 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $121=$N; //@line 4655 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $122=((($121)+($120))|0); //@line 4655 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $N=$122; //@line 4655 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $123=$K; //@line 4655 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $124=$Y; //@line 4655 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $125=$124 >>> (($123)>>>0); //@line 4655 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $Y=$125; //@line 4655 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $126=$Y; //@line 4655 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $127=$126 >>> 2; //@line 4655 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $128=$127 & 4; //@line 4655 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $K=$128; //@line 4655 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $129=$N; //@line 4655 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $130=((($129)+($128))|0); //@line 4655 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $N=$130; //@line 4655 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $131=$K; //@line 4655 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $132=$Y; //@line 4655 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $133=$132 >>> (($131)>>>0); //@line 4655 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $Y=$133; //@line 4655 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $134=$Y; //@line 4655 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $135=$134 >>> 1; //@line 4655 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $136=$135 & 2; //@line 4655 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $K=$136; //@line 4655 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $137=$N; //@line 4655 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $138=((($137)+($136))|0); //@line 4655 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $N=$138; //@line 4655 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $139=$K; //@line 4655 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $140=$Y; //@line 4655 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $141=$140 >>> (($139)>>>0); //@line 4655 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $Y=$141; //@line 4655 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $142=$Y; //@line 4655 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $143=$142 >>> 1; //@line 4655 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $144=$143 & 1; //@line 4655 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $K=$144; //@line 4655 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $145=$N; //@line 4655 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $146=((($145)+($144))|0); //@line 4655 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $N=$146; //@line 4655 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $147=$K; //@line 4655 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $148=$Y; //@line 4655 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $149=$148 >>> (($147)>>>0); //@line 4655 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $Y=$149; //@line 4655 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $150=$N; //@line 4655 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $151=$Y; //@line 4655 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $152=((($150)+($151))|0); //@line 4655 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $i=$152; //@line 4655 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $153=$i; //@line 4656 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $154=$153 << 1; //@line 4656 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $155=((((__gm_+40)|0)+($154<<2))|0); //@line 4656 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $156=$155; //@line 4656 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $157=$156; //@line 4656 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $b1=$157; //@line 4656 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $158=$b1; //@line 4657 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $159=(($158+8)|0); //@line 4657 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $160=HEAP32[(($159)>>2)]; //@line 4657 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $p2=$160; //@line 4657 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $161=$p2; //@line 4659 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $162=(($161+8)|0); //@line 4659 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $163=HEAP32[(($162)>>2)]; //@line 4659 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $F3=$163; //@line 4659 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $164=$b1; //@line 4659 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $165=$F3; //@line 4659 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $166=(($164)|0)==(($165)|0); //@line 4659 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($166) { __label__ = 17; break; } else { __label__ = 18; break; } //@line 4659 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 17: 
      var $168=$i; //@line 4659 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $169=1 << $168; //@line 4659 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $170=$169 ^ -1; //@line 4659 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $171=HEAP32[((((__gm_)|0))>>2)]; //@line 4659 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $172=$171 & $170; //@line 4659 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[((((__gm_)|0))>>2)]=$172; //@line 4659 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 22; break; //@line 4659 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 18: 
      var $174=$F3; //@line 4659 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $175=$174; //@line 4659 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $176=HEAPU32[((((__gm_+16)|0))>>2)]; //@line 4659 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $177=(($175)>>>0) >= (($176)>>>0); //@line 4659 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $178=(($177)&1); //@line 4659 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $179=(($178)==(1)); //@line 4659 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $180=(($179)|0)!=0; //@line 4659 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($180) { __label__ = 19; break; } else { __label__ = 20; break; } //@line 4659 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 19: 
      var $182=$F3; //@line 4659 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $183=$b1; //@line 4659 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $184=(($183+8)|0); //@line 4659 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($184)>>2)]=$182; //@line 4659 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $185=$b1; //@line 4659 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $186=$F3; //@line 4659 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $187=(($186+12)|0); //@line 4659 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($187)>>2)]=$185; //@line 4659 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 21; break; //@line 4659 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 20: 
      _abort(); //@line 4659 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      throw "Reached an unreachable!" //@line 4659 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 21: 
      __label__ = 22; break;
    case 22: 
      var $191=$i; //@line 4660 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $192=$191 << 3; //@line 4660 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $193=$nb; //@line 4660 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $194=((($192)-($193))|0); //@line 4660 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $rsize=$194; //@line 4660 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $195=$nb; //@line 4665 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $196=$195 | 1; //@line 4665 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $197=$196 | 2; //@line 4665 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $198=$p2; //@line 4665 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $199=(($198+4)|0); //@line 4665 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($199)>>2)]=$197; //@line 4665 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $200=$p2; //@line 4666 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $201=$200; //@line 4666 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $202=$nb; //@line 4666 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $203=(($201+$202)|0); //@line 4666 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $204=$203; //@line 4666 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $r=$204; //@line 4666 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $205=$rsize; //@line 4667 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $206=$205 | 1; //@line 4667 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $207=$r; //@line 4667 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $208=(($207+4)|0); //@line 4667 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($208)>>2)]=$206; //@line 4667 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $209=$rsize; //@line 4667 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $210=$r; //@line 4667 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $211=$210; //@line 4667 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $212=$rsize; //@line 4667 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $213=(($211+$212)|0); //@line 4667 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $214=$213; //@line 4667 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $215=(($214)|0); //@line 4667 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($215)>>2)]=$209; //@line 4667 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $216=HEAP32[((((__gm_+8)|0))>>2)]; //@line 4668 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $DVS=$216; //@line 4668 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $217=$DVS; //@line 4668 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $218=(($217)|0)!=0; //@line 4668 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($218) { __label__ = 23; break; } else { __label__ = 30; break; } //@line 4668 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 23: 
      var $220=HEAP32[((((__gm_+20)|0))>>2)]; //@line 4668 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $DV=$220; //@line 4668 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $221=$DVS; //@line 4668 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $222=$221 >>> 3; //@line 4668 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $I=$222; //@line 4668 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $223=$I; //@line 4668 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $224=$223 << 1; //@line 4668 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $225=((((__gm_+40)|0)+($224<<2))|0); //@line 4668 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $226=$225; //@line 4668 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $227=$226; //@line 4668 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $B=$227; //@line 4668 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $228=$B; //@line 4668 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $F4=$228; //@line 4668 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $229=HEAP32[((((__gm_)|0))>>2)]; //@line 4668 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $230=$I; //@line 4668 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $231=1 << $230; //@line 4668 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $232=$229 & $231; //@line 4668 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $233=(($232)|0)!=0; //@line 4668 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($233) { __label__ = 25; break; } else { __label__ = 24; break; } //@line 4668 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 24: 
      var $235=$I; //@line 4668 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $236=1 << $235; //@line 4668 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $237=HEAP32[((((__gm_)|0))>>2)]; //@line 4668 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $238=$237 | $236; //@line 4668 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[((((__gm_)|0))>>2)]=$238; //@line 4668 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 29; break; //@line 4668 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 25: 
      var $240=$B; //@line 4668 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $241=(($240+8)|0); //@line 4668 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $242=HEAP32[(($241)>>2)]; //@line 4668 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $243=$242; //@line 4668 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $244=HEAPU32[((((__gm_+16)|0))>>2)]; //@line 4668 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $245=(($243)>>>0) >= (($244)>>>0); //@line 4668 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $246=(($245)&1); //@line 4668 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $247=(($246)==(1)); //@line 4668 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $248=(($247)|0)!=0; //@line 4668 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($248) { __label__ = 26; break; } else { __label__ = 27; break; } //@line 4668 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 26: 
      var $250=$B; //@line 4668 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $251=(($250+8)|0); //@line 4668 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $252=HEAP32[(($251)>>2)]; //@line 4668 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $F4=$252; //@line 4668 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 28; break; //@line 4668 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 27: 
      _abort(); //@line 4668 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      throw "Reached an unreachable!" //@line 4668 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 28: 
      __label__ = 29; break;
    case 29: 
      var $256=$DV; //@line 4668 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $257=$B; //@line 4668 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $258=(($257+8)|0); //@line 4668 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($258)>>2)]=$256; //@line 4668 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $259=$DV; //@line 4668 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $260=$F4; //@line 4668 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $261=(($260+12)|0); //@line 4668 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($261)>>2)]=$259; //@line 4668 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $262=$F4; //@line 4668 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $263=$DV; //@line 4668 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $264=(($263+8)|0); //@line 4668 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($264)>>2)]=$262; //@line 4668 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $265=$B; //@line 4668 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $266=$DV; //@line 4668 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $267=(($266+12)|0); //@line 4668 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($267)>>2)]=$265; //@line 4668 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 30; break; //@line 4668 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 30: 
      var $269=$rsize; //@line 4668 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[((((__gm_+8)|0))>>2)]=$269; //@line 4668 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $270=$r; //@line 4668 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[((((__gm_+20)|0))>>2)]=$270; //@line 4668 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $271=$p2; //@line 4670 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $272=$271; //@line 4670 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $273=(($272+8)|0); //@line 4670 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $mem=$273; //@line 4670 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 54; break; //@line 4672 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 31: 
      var $275=HEAP32[((((__gm_+4)|0))>>2)]; //@line 4675 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $276=(($275)|0)!=0; //@line 4675 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($276) { __label__ = 32; break; } else { __label__ = 34; break; } //@line 4675 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 32: 
      var $278=$nb; //@line 4675 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $279=_tmalloc_small(__gm_, $278); //@line 4675 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $mem=$279; //@line 4675 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $280=(($279)|0)!=0; //@line 4675 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($280) { __label__ = 33; break; } else { __label__ = 34; break; } //@line 4675 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 33: 
      __label__ = 54; break; //@line 4677 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 34: 
      __label__ = 35; break;
    case 35: 
      __label__ = 36; break; //@line 4679 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 36: 
      __label__ = 37; break;
    case 37: 
      __label__ = 45; break; //@line 4680 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 38: 
      var $287=$1; //@line 4681 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $288=(($287)>>>0) >= 4294967232; //@line 4681 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($288) { __label__ = 39; break; } else { __label__ = 40; break; } //@line 4681 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 39: 
      $nb=-1; //@line 4682 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 44; break; //@line 4682 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 40: 
      var $291=$1; //@line 4684 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $292=((($291)+(4))|0); //@line 4684 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $293=((($292)+(7))|0); //@line 4684 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $294=$293 & -8; //@line 4684 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $nb=$294; //@line 4684 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $295=HEAP32[((((__gm_+4)|0))>>2)]; //@line 4685 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $296=(($295)|0)!=0; //@line 4685 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($296) { __label__ = 41; break; } else { __label__ = 43; break; } //@line 4685 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 41: 
      var $298=$nb; //@line 4685 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $299=_tmalloc_large(__gm_, $298); //@line 4685 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $mem=$299; //@line 4685 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $300=(($299)|0)!=0; //@line 4685 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($300) { __label__ = 42; break; } else { __label__ = 43; break; } //@line 4685 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 42: 
      __label__ = 54; break; //@line 4687 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 43: 
      __label__ = 44; break;
    case 44: 
      __label__ = 45; break;
    case 45: 
      var $305=$nb; //@line 4691 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $306=HEAPU32[((((__gm_+8)|0))>>2)]; //@line 4691 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $307=(($305)>>>0) <= (($306)>>>0); //@line 4691 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($307) { __label__ = 46; break; } else { __label__ = 50; break; } //@line 4691 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 46: 
      var $309=HEAP32[((((__gm_+8)|0))>>2)]; //@line 4692 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $310=$nb; //@line 4692 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $311=((($309)-($310))|0); //@line 4692 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $rsize5=$311; //@line 4692 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $312=HEAP32[((((__gm_+20)|0))>>2)]; //@line 4693 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $p6=$312; //@line 4693 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $313=$rsize5; //@line 4694 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $314=(($313)>>>0) >= 16; //@line 4694 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($314) { __label__ = 47; break; } else { __label__ = 48; break; } //@line 4694 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 47: 
      var $316=$p6; //@line 4695 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $317=$316; //@line 4695 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $318=$nb; //@line 4695 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $319=(($317+$318)|0); //@line 4695 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $320=$319; //@line 4695 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[((((__gm_+20)|0))>>2)]=$320; //@line 4695 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $r7=$320; //@line 4695 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $321=$rsize5; //@line 4696 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[((((__gm_+8)|0))>>2)]=$321; //@line 4696 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $322=$rsize5; //@line 4697 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $323=$322 | 1; //@line 4697 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $324=$r7; //@line 4697 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $325=(($324+4)|0); //@line 4697 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($325)>>2)]=$323; //@line 4697 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $326=$rsize5; //@line 4697 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $327=$r7; //@line 4697 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $328=$327; //@line 4697 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $329=$rsize5; //@line 4697 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $330=(($328+$329)|0); //@line 4697 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $331=$330; //@line 4697 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $332=(($331)|0); //@line 4697 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($332)>>2)]=$326; //@line 4697 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $333=$nb; //@line 4698 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $334=$333 | 1; //@line 4698 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $335=$334 | 2; //@line 4698 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $336=$p6; //@line 4698 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $337=(($336+4)|0); //@line 4698 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($337)>>2)]=$335; //@line 4698 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 49; break; //@line 4699 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 48: 
      var $339=HEAP32[((((__gm_+8)|0))>>2)]; //@line 4701 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $dvs=$339; //@line 4701 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[((((__gm_+8)|0))>>2)]=0; //@line 4702 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[((((__gm_+20)|0))>>2)]=0; //@line 4703 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $340=$dvs; //@line 4704 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $341=$340 | 1; //@line 4704 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $342=$341 | 2; //@line 4704 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $343=$p6; //@line 4704 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $344=(($343+4)|0); //@line 4704 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($344)>>2)]=$342; //@line 4704 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $345=$p6; //@line 4704 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $346=$345; //@line 4704 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $347=$dvs; //@line 4704 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $348=(($346+$347)|0); //@line 4704 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $349=$348; //@line 4704 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $350=(($349+4)|0); //@line 4704 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $351=HEAP32[(($350)>>2)]; //@line 4704 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $352=$351 | 1; //@line 4704 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($350)>>2)]=$352; //@line 4704 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 49; break;
    case 49: 
      var $354=$p6; //@line 4706 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $355=$354; //@line 4706 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $356=(($355+8)|0); //@line 4706 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $mem=$356; //@line 4706 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 54; break; //@line 4708 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 50: 
      var $358=$nb; //@line 4711 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $359=HEAPU32[((((__gm_+12)|0))>>2)]; //@line 4711 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $360=(($358)>>>0) < (($359)>>>0); //@line 4711 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($360) { __label__ = 51; break; } else { __label__ = 52; break; } //@line 4711 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 51: 
      var $362=$nb; //@line 4712 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $363=HEAP32[((((__gm_+12)|0))>>2)]; //@line 4712 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $364=((($363)-($362))|0); //@line 4712 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[((((__gm_+12)|0))>>2)]=$364; //@line 4712 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $rsize8=$364; //@line 4712 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $365=HEAP32[((((__gm_+24)|0))>>2)]; //@line 4713 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $p9=$365; //@line 4713 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $366=$p9; //@line 4714 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $367=$366; //@line 4714 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $368=$nb; //@line 4714 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $369=(($367+$368)|0); //@line 4714 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $370=$369; //@line 4714 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[((((__gm_+24)|0))>>2)]=$370; //@line 4714 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $r10=$370; //@line 4714 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $371=$rsize8; //@line 4715 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $372=$371 | 1; //@line 4715 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $373=$r10; //@line 4715 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $374=(($373+4)|0); //@line 4715 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($374)>>2)]=$372; //@line 4715 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $375=$nb; //@line 4716 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $376=$375 | 1; //@line 4716 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $377=$376 | 2; //@line 4716 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $378=$p9; //@line 4716 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $379=(($378+4)|0); //@line 4716 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($379)>>2)]=$377; //@line 4716 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $380=$p9; //@line 4717 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $381=$380; //@line 4717 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $382=(($381+8)|0); //@line 4717 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $mem=$382; //@line 4717 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 54; break; //@line 4720 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 52: 
      __label__ = 53; break;
    case 53: 
      var $385=$nb; //@line 4723 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $386=_sys_alloc(__gm_, $385); //@line 4723 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $mem=$386; //@line 4723 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 54; break; //@line 4723 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 54: 
      var $388=$mem; //@line 4727 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      ;
      return $388; //@line 4727 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    default: assert(0, "bad label: " + __label__);
  }
}
Module["_malloc"] = _malloc;_malloc["X"]=1;

function _tmalloc_small($m, $nb) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $t;
      var $v;
      var $rsize;
      var $i;
      var $leastbit;
      var $Y;
      var $K;
      var $N;
      var $trem;
      var $r;
      var $XP;
      var $R;
      var $F;
      var $RP;
      var $CP;
      var $H;
      var $C0;
      var $C1;
      var $DVS;
      var $DV;
      var $I;
      var $B;
      var $F1;
      $1=$m;
      $2=$nb;
      var $3=$1; //@line 4268 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $4=(($3+4)|0); //@line 4268 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $5=HEAP32[(($4)>>2)]; //@line 4268 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $6=$1; //@line 4268 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $7=(($6+4)|0); //@line 4268 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $8=HEAP32[(($7)>>2)]; //@line 4268 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $9=(((-$8))|0); //@line 4268 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $10=$5 & $9; //@line 4268 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $leastbit=$10; //@line 4268 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $11=$leastbit; //@line 4269 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $12=((($11)-(1))|0); //@line 4269 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $Y=$12; //@line 4269 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $13=$Y; //@line 4269 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $14=$13 >>> 12; //@line 4269 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $15=$14 & 16; //@line 4269 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $K=$15; //@line 4269 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $16=$K; //@line 4269 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $N=$16; //@line 4269 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $17=$K; //@line 4269 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $18=$Y; //@line 4269 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $19=$18 >>> (($17)>>>0); //@line 4269 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $Y=$19; //@line 4269 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $20=$Y; //@line 4269 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $21=$20 >>> 5; //@line 4269 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $22=$21 & 8; //@line 4269 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $K=$22; //@line 4269 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $23=$N; //@line 4269 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $24=((($23)+($22))|0); //@line 4269 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $N=$24; //@line 4269 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $25=$K; //@line 4269 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $26=$Y; //@line 4269 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $27=$26 >>> (($25)>>>0); //@line 4269 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $Y=$27; //@line 4269 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $28=$Y; //@line 4269 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $29=$28 >>> 2; //@line 4269 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $30=$29 & 4; //@line 4269 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $K=$30; //@line 4269 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $31=$N; //@line 4269 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $32=((($31)+($30))|0); //@line 4269 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $N=$32; //@line 4269 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $33=$K; //@line 4269 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $34=$Y; //@line 4269 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $35=$34 >>> (($33)>>>0); //@line 4269 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $Y=$35; //@line 4269 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $36=$Y; //@line 4269 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $37=$36 >>> 1; //@line 4269 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $38=$37 & 2; //@line 4269 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $K=$38; //@line 4269 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $39=$N; //@line 4269 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $40=((($39)+($38))|0); //@line 4269 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $N=$40; //@line 4269 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $41=$K; //@line 4269 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $42=$Y; //@line 4269 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $43=$42 >>> (($41)>>>0); //@line 4269 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $Y=$43; //@line 4269 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $44=$Y; //@line 4269 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $45=$44 >>> 1; //@line 4269 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $46=$45 & 1; //@line 4269 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $K=$46; //@line 4269 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $47=$N; //@line 4269 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $48=((($47)+($46))|0); //@line 4269 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $N=$48; //@line 4269 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $49=$K; //@line 4269 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $50=$Y; //@line 4269 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $51=$50 >>> (($49)>>>0); //@line 4269 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $Y=$51; //@line 4269 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $52=$N; //@line 4269 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $53=$Y; //@line 4269 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $54=((($52)+($53))|0); //@line 4269 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $i=$54; //@line 4269 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $55=$i; //@line 4270 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $56=$1; //@line 4270 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $57=(($56+304)|0); //@line 4270 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $58=(($57+($55<<2))|0); //@line 4270 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $59=HEAP32[(($58)>>2)]; //@line 4270 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $t=$59; //@line 4270 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $v=$59; //@line 4270 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $60=$t; //@line 4271 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $61=(($60+4)|0); //@line 4271 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $62=HEAP32[(($61)>>2)]; //@line 4271 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $63=$62 & -8; //@line 4271 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $64=$2; //@line 4271 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $65=((($63)-($64))|0); //@line 4271 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $rsize=$65; //@line 4271 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 3; break; //@line 4273 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 3: 
      var $67=$t; //@line 4273 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $68=(($67+16)|0); //@line 4273 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $69=(($68)|0); //@line 4273 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $70=HEAP32[(($69)>>2)]; //@line 4273 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $71=(($70)|0)!=0; //@line 4273 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($71) { __label__ = 4; break; } else { __label__ = 5; break; } //@line 4273 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 4: 
      var $73=$t; //@line 4273 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $74=(($73+16)|0); //@line 4273 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $75=(($74)|0); //@line 4273 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $76=HEAP32[(($75)>>2)]; //@line 4273 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $83 = $76;__label__ = 6; break; //@line 4273 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 5: 
      var $78=$t; //@line 4273 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $79=(($78+16)|0); //@line 4273 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $80=(($79+4)|0); //@line 4273 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $81=HEAP32[(($80)>>2)]; //@line 4273 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $83 = $81;__label__ = 6; break; //@line 4273 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 6: 
      var $83; //@line 4273 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $t=$83; //@line 4273 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $84=(($83)|0)!=0; //@line 4273 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($84) { __label__ = 7; break; } else { __label__ = 10; break; } //@line 4273 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 7: 
      var $86=$t; //@line 4274 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $87=(($86+4)|0); //@line 4274 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $88=HEAP32[(($87)>>2)]; //@line 4274 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $89=$88 & -8; //@line 4274 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $90=$2; //@line 4274 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $91=((($89)-($90))|0); //@line 4274 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $trem=$91; //@line 4274 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $92=$trem; //@line 4275 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $93=$rsize; //@line 4275 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $94=(($92)>>>0) < (($93)>>>0); //@line 4275 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($94) { __label__ = 8; break; } else { __label__ = 9; break; } //@line 4275 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 8: 
      var $96=$trem; //@line 4276 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $rsize=$96; //@line 4276 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $97=$t; //@line 4277 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $v=$97; //@line 4277 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 9; break; //@line 4278 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 9: 
      __label__ = 3; break; //@line 4279 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 10: 
      var $100=$v; //@line 4281 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $101=$100; //@line 4281 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $102=$1; //@line 4281 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $103=(($102+16)|0); //@line 4281 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $104=HEAPU32[(($103)>>2)]; //@line 4281 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $105=(($101)>>>0) >= (($104)>>>0); //@line 4281 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $106=(($105)&1); //@line 4281 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $107=(($106)==(1)); //@line 4281 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $108=(($107)|0)!=0; //@line 4281 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($108) { __label__ = 11; break; } else { __label__ = 70; break; } //@line 4281 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 11: 
      var $110=$v; //@line 4282 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $111=$110; //@line 4282 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $112=$2; //@line 4282 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $113=(($111+$112)|0); //@line 4282 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $114=$113; //@line 4282 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $r=$114; //@line 4282 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $115=$v; //@line 4284 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $116=$115; //@line 4284 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $117=$r; //@line 4284 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $118=$117; //@line 4284 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $119=(($116)>>>0) < (($118)>>>0); //@line 4284 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $120=(($119)&1); //@line 4284 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $121=(($120)==(1)); //@line 4284 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $122=(($121)|0)!=0; //@line 4284 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($122) { __label__ = 12; break; } else { __label__ = 69; break; } //@line 4284 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 12: 
      var $124=$v; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $125=(($124+24)|0); //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $126=HEAP32[(($125)>>2)]; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $XP=$126; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $127=$v; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $128=(($127+12)|0); //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $129=HEAP32[(($128)>>2)]; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $130=$v; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $131=(($129)|0)!=(($130)|0); //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($131) { __label__ = 13; break; } else { __label__ = 17; break; } //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 13: 
      var $133=$v; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $134=(($133+8)|0); //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $135=HEAP32[(($134)>>2)]; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $F=$135; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $136=$v; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $137=(($136+12)|0); //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $138=HEAP32[(($137)>>2)]; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $R=$138; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $139=$F; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $140=$139; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $141=$1; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $142=(($141+16)|0); //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $143=HEAPU32[(($142)>>2)]; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $144=(($140)>>>0) >= (($143)>>>0); //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $145=(($144)&1); //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $146=(($145)==(1)); //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $147=(($146)|0)!=0; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($147) { __label__ = 14; break; } else { __label__ = 15; break; } //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 14: 
      var $149=$R; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $150=$F; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $151=(($150+12)|0); //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($151)>>2)]=$149; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $152=$F; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $153=$R; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $154=(($153+8)|0); //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($154)>>2)]=$152; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 16; break; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 15: 
      _abort(); //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      throw "Reached an unreachable!" //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 16: 
      __label__ = 29; break; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 17: 
      var $158=$v; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $159=(($158+16)|0); //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $160=(($159+4)|0); //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $RP=$160; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $161=HEAP32[(($160)>>2)]; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $R=$161; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $162=(($161)|0)!=0; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($162) { __label__ = 19; break; } else { __label__ = 18; break; } //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 18: 
      var $164=$v; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $165=(($164+16)|0); //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $166=(($165)|0); //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $RP=$166; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $167=HEAP32[(($166)>>2)]; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $R=$167; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $168=(($167)|0)!=0; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($168) { __label__ = 19; break; } else { __label__ = 28; break; } //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 19: 
      __label__ = 20; break; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 20: 
      var $171=$R; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $172=(($171+16)|0); //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $173=(($172+4)|0); //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $CP=$173; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $174=HEAP32[(($173)>>2)]; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $175=(($174)|0)!=0; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($175) { var $183 = 1;__label__ = 22; break; } else { __label__ = 21; break; } //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 21: 
      var $177=$R; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $178=(($177+16)|0); //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $179=(($178)|0); //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $CP=$179; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $180=HEAP32[(($179)>>2)]; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $181=(($180)|0)!=0; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $183 = $181;__label__ = 22; break; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 22: 
      var $183;
      if ($183) { __label__ = 23; break; } else { __label__ = 24; break; } //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 23: 
      var $185=$CP; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $RP=$185; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $186=HEAP32[(($185)>>2)]; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $R=$186; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 20; break; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 24: 
      var $188=$RP; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $189=$188; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $190=$1; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $191=(($190+16)|0); //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $192=HEAPU32[(($191)>>2)]; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $193=(($189)>>>0) >= (($192)>>>0); //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $194=(($193)&1); //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $195=(($194)==(1)); //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $196=(($195)|0)!=0; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($196) { __label__ = 25; break; } else { __label__ = 26; break; } //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 25: 
      var $198=$RP; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($198)>>2)]=0; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 27; break; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 26: 
      _abort(); //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      throw "Reached an unreachable!" //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 27: 
      __label__ = 28; break; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 28: 
      __label__ = 29; break;
    case 29: 
      var $203=$XP; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $204=(($203)|0)!=0; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($204) { __label__ = 30; break; } else { __label__ = 57; break; } //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 30: 
      var $206=$v; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $207=(($206+28)|0); //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $208=HEAP32[(($207)>>2)]; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $209=$1; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $210=(($209+304)|0); //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $211=(($210+($208<<2))|0); //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $H=$211; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $212=$v; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $213=$H; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $214=HEAP32[(($213)>>2)]; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $215=(($212)|0)==(($214)|0); //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($215) { __label__ = 31; break; } else { __label__ = 34; break; } //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 31: 
      var $217=$R; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $218=$H; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($218)>>2)]=$217; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $219=(($217)|0)==0; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($219) { __label__ = 32; break; } else { __label__ = 33; break; } //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 32: 
      var $221=$v; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $222=(($221+28)|0); //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $223=HEAP32[(($222)>>2)]; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $224=1 << $223; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $225=$224 ^ -1; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $226=$1; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $227=(($226+4)|0); //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $228=HEAP32[(($227)>>2)]; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $229=$228 & $225; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($227)>>2)]=$229; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 33; break; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 33: 
      __label__ = 41; break; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 34: 
      var $232=$XP; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $233=$232; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $234=$1; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $235=(($234+16)|0); //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $236=HEAPU32[(($235)>>2)]; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $237=(($233)>>>0) >= (($236)>>>0); //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $238=(($237)&1); //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $239=(($238)==(1)); //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $240=(($239)|0)!=0; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($240) { __label__ = 35; break; } else { __label__ = 39; break; } //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 35: 
      var $242=$XP; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $243=(($242+16)|0); //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $244=(($243)|0); //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $245=HEAP32[(($244)>>2)]; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $246=$v; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $247=(($245)|0)==(($246)|0); //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($247) { __label__ = 36; break; } else { __label__ = 37; break; } //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 36: 
      var $249=$R; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $250=$XP; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $251=(($250+16)|0); //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $252=(($251)|0); //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($252)>>2)]=$249; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 38; break; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 37: 
      var $254=$R; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $255=$XP; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $256=(($255+16)|0); //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $257=(($256+4)|0); //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($257)>>2)]=$254; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 38; break;
    case 38: 
      __label__ = 40; break; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 39: 
      _abort(); //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      throw "Reached an unreachable!" //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 40: 
      __label__ = 41; break;
    case 41: 
      var $262=$R; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $263=(($262)|0)!=0; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($263) { __label__ = 42; break; } else { __label__ = 56; break; } //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 42: 
      var $265=$R; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $266=$265; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $267=$1; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $268=(($267+16)|0); //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $269=HEAPU32[(($268)>>2)]; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $270=(($266)>>>0) >= (($269)>>>0); //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $271=(($270)&1); //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $272=(($271)==(1)); //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $273=(($272)|0)!=0; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($273) { __label__ = 43; break; } else { __label__ = 54; break; } //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 43: 
      var $275=$XP; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $276=$R; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $277=(($276+24)|0); //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($277)>>2)]=$275; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $278=$v; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $279=(($278+16)|0); //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $280=(($279)|0); //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $281=HEAP32[(($280)>>2)]; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $C0=$281; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $282=(($281)|0)!=0; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($282) { __label__ = 44; break; } else { __label__ = 48; break; } //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 44: 
      var $284=$C0; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $285=$284; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $286=$1; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $287=(($286+16)|0); //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $288=HEAPU32[(($287)>>2)]; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $289=(($285)>>>0) >= (($288)>>>0); //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $290=(($289)&1); //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $291=(($290)==(1)); //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $292=(($291)|0)!=0; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($292) { __label__ = 45; break; } else { __label__ = 46; break; } //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 45: 
      var $294=$C0; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $295=$R; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $296=(($295+16)|0); //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $297=(($296)|0); //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($297)>>2)]=$294; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $298=$R; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $299=$C0; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $300=(($299+24)|0); //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($300)>>2)]=$298; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 47; break; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 46: 
      _abort(); //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      throw "Reached an unreachable!" //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 47: 
      __label__ = 48; break; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 48: 
      var $304=$v; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $305=(($304+16)|0); //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $306=(($305+4)|0); //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $307=HEAP32[(($306)>>2)]; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $C1=$307; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $308=(($307)|0)!=0; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($308) { __label__ = 49; break; } else { __label__ = 53; break; } //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 49: 
      var $310=$C1; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $311=$310; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $312=$1; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $313=(($312+16)|0); //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $314=HEAPU32[(($313)>>2)]; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $315=(($311)>>>0) >= (($314)>>>0); //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $316=(($315)&1); //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $317=(($316)==(1)); //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $318=(($317)|0)!=0; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($318) { __label__ = 50; break; } else { __label__ = 51; break; } //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 50: 
      var $320=$C1; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $321=$R; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $322=(($321+16)|0); //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $323=(($322+4)|0); //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($323)>>2)]=$320; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $324=$R; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $325=$C1; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $326=(($325+24)|0); //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($326)>>2)]=$324; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 52; break; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 51: 
      _abort(); //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      throw "Reached an unreachable!" //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 52: 
      __label__ = 53; break; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 53: 
      __label__ = 55; break; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 54: 
      _abort(); //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      throw "Reached an unreachable!" //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 55: 
      __label__ = 56; break; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 56: 
      __label__ = 57; break; //@line 4285 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 57: 
      var $334=$rsize; //@line 4286 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $335=(($334)>>>0) < 16; //@line 4286 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($335) { __label__ = 58; break; } else { __label__ = 59; break; } //@line 4286 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 58: 
      var $337=$rsize; //@line 4287 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $338=$2; //@line 4287 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $339=((($337)+($338))|0); //@line 4287 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $340=$339 | 1; //@line 4287 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $341=$340 | 2; //@line 4287 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $342=$v; //@line 4287 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $343=(($342+4)|0); //@line 4287 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($343)>>2)]=$341; //@line 4287 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $344=$v; //@line 4287 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $345=$344; //@line 4287 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $346=$rsize; //@line 4287 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $347=$2; //@line 4287 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $348=((($346)+($347))|0); //@line 4287 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $349=(($345+$348)|0); //@line 4287 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $350=$349; //@line 4287 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $351=(($350+4)|0); //@line 4287 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $352=HEAP32[(($351)>>2)]; //@line 4287 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $353=$352 | 1; //@line 4287 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($351)>>2)]=$353; //@line 4287 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 68; break; //@line 4287 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 59: 
      var $355=$2; //@line 4289 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $356=$355 | 1; //@line 4289 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $357=$356 | 2; //@line 4289 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $358=$v; //@line 4289 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $359=(($358+4)|0); //@line 4289 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($359)>>2)]=$357; //@line 4289 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $360=$rsize; //@line 4290 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $361=$360 | 1; //@line 4290 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $362=$r; //@line 4290 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $363=(($362+4)|0); //@line 4290 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($363)>>2)]=$361; //@line 4290 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $364=$rsize; //@line 4290 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $365=$r; //@line 4290 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $366=$365; //@line 4290 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $367=$rsize; //@line 4290 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $368=(($366+$367)|0); //@line 4290 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $369=$368; //@line 4290 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $370=(($369)|0); //@line 4290 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($370)>>2)]=$364; //@line 4290 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $371=$1; //@line 4291 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $372=(($371+8)|0); //@line 4291 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $373=HEAP32[(($372)>>2)]; //@line 4291 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $DVS=$373; //@line 4291 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $374=$DVS; //@line 4291 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $375=(($374)|0)!=0; //@line 4291 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($375) { __label__ = 60; break; } else { __label__ = 67; break; } //@line 4291 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 60: 
      var $377=$1; //@line 4291 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $378=(($377+20)|0); //@line 4291 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $379=HEAP32[(($378)>>2)]; //@line 4291 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $DV=$379; //@line 4291 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $380=$DVS; //@line 4291 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $381=$380 >>> 3; //@line 4291 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $I=$381; //@line 4291 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $382=$I; //@line 4291 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $383=$382 << 1; //@line 4291 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $384=$1; //@line 4291 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $385=(($384+40)|0); //@line 4291 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $386=(($385+($383<<2))|0); //@line 4291 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $387=$386; //@line 4291 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $388=$387; //@line 4291 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $B=$388; //@line 4291 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $389=$B; //@line 4291 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $F1=$389; //@line 4291 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $390=$1; //@line 4291 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $391=(($390)|0); //@line 4291 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $392=HEAP32[(($391)>>2)]; //@line 4291 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $393=$I; //@line 4291 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $394=1 << $393; //@line 4291 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $395=$392 & $394; //@line 4291 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $396=(($395)|0)!=0; //@line 4291 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($396) { __label__ = 62; break; } else { __label__ = 61; break; } //@line 4291 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 61: 
      var $398=$I; //@line 4291 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $399=1 << $398; //@line 4291 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $400=$1; //@line 4291 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $401=(($400)|0); //@line 4291 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $402=HEAP32[(($401)>>2)]; //@line 4291 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $403=$402 | $399; //@line 4291 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($401)>>2)]=$403; //@line 4291 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 66; break; //@line 4291 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 62: 
      var $405=$B; //@line 4291 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $406=(($405+8)|0); //@line 4291 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $407=HEAP32[(($406)>>2)]; //@line 4291 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $408=$407; //@line 4291 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $409=$1; //@line 4291 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $410=(($409+16)|0); //@line 4291 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $411=HEAPU32[(($410)>>2)]; //@line 4291 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $412=(($408)>>>0) >= (($411)>>>0); //@line 4291 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $413=(($412)&1); //@line 4291 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $414=(($413)==(1)); //@line 4291 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $415=(($414)|0)!=0; //@line 4291 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($415) { __label__ = 63; break; } else { __label__ = 64; break; } //@line 4291 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 63: 
      var $417=$B; //@line 4291 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $418=(($417+8)|0); //@line 4291 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $419=HEAP32[(($418)>>2)]; //@line 4291 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $F1=$419; //@line 4291 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 65; break; //@line 4291 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 64: 
      _abort(); //@line 4291 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      throw "Reached an unreachable!" //@line 4291 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 65: 
      __label__ = 66; break;
    case 66: 
      var $423=$DV; //@line 4291 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $424=$B; //@line 4291 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $425=(($424+8)|0); //@line 4291 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($425)>>2)]=$423; //@line 4291 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $426=$DV; //@line 4291 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $427=$F1; //@line 4291 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $428=(($427+12)|0); //@line 4291 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($428)>>2)]=$426; //@line 4291 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $429=$F1; //@line 4291 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $430=$DV; //@line 4291 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $431=(($430+8)|0); //@line 4291 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($431)>>2)]=$429; //@line 4291 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $432=$B; //@line 4291 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $433=$DV; //@line 4291 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $434=(($433+12)|0); //@line 4291 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($434)>>2)]=$432; //@line 4291 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 67; break; //@line 4291 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 67: 
      var $436=$rsize; //@line 4291 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $437=$1; //@line 4291 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $438=(($437+8)|0); //@line 4291 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($438)>>2)]=$436; //@line 4291 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $439=$r; //@line 4291 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $440=$1; //@line 4291 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $441=(($440+20)|0); //@line 4291 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($441)>>2)]=$439; //@line 4291 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 68; break;
    case 68: 
      var $443=$v; //@line 4293 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $444=$443; //@line 4293 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $445=(($444+8)|0); //@line 4293 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      ;
      return $445; //@line 4293 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 69: 
      __label__ = 70; break; //@line 4295 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 70: 
      _abort(); //@line 4297 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      throw "Reached an unreachable!" //@line 4297 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    default: assert(0, "bad label: " + __label__);
  }
}
_tmalloc_small["X"]=1;

function _tmalloc_large($m, $nb) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $v;
      var $rsize;
      var $t;
      var $idx;
      var $X;
      var $Y;
      var $N;
      var $K;
      var $sizebits;
      var $rst;
      var $rt;
      var $trem;
      var $leftbits;
      var $i;
      var $leastbit;
      var $Y1;
      var $K2;
      var $N3;
      var $trem4;
      var $r;
      var $XP;
      var $R;
      var $F;
      var $RP;
      var $CP;
      var $H;
      var $C0;
      var $C1;
      var $I;
      var $B;
      var $F5;
      var $TP;
      var $H6;
      var $I7;
      var $X8;
      var $Y9;
      var $N10;
      var $K11;
      var $T;
      var $K12;
      var $C;
      var $F13;
      $2=$m;
      $3=$nb;
      $v=0; //@line 4194 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $4=$3; //@line 4195 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $5=(((-$4))|0); //@line 4195 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $rsize=$5; //@line 4195 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $6=$3; //@line 4198 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $7=$6 >>> 8; //@line 4198 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $X=$7; //@line 4198 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $8=$X; //@line 4198 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $9=(($8)|0)==0; //@line 4198 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($9) { __label__ = 3; break; } else { __label__ = 4; break; } //@line 4198 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 3: 
      $idx=0; //@line 4198 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 8; break; //@line 4198 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 4: 
      var $12=$X; //@line 4198 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $13=(($12)>>>0) > 65535; //@line 4198 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($13) { __label__ = 5; break; } else { __label__ = 6; break; } //@line 4198 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 5: 
      $idx=31; //@line 4198 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 7; break; //@line 4198 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 6: 
      var $16=$X; //@line 4198 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $Y=$16; //@line 4198 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $17=$Y; //@line 4198 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $18=((($17)-(256))|0); //@line 4198 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $19=$18 >>> 16; //@line 4198 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $20=$19 & 8; //@line 4198 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $N=$20; //@line 4198 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $21=$N; //@line 4198 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $22=$Y; //@line 4198 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $23=$22 << $21; //@line 4198 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $Y=$23; //@line 4198 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $24=((($23)-(4096))|0); //@line 4198 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $25=$24 >>> 16; //@line 4198 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $26=$25 & 4; //@line 4198 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $K=$26; //@line 4198 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $27=$K; //@line 4198 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $28=$N; //@line 4198 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $29=((($28)+($27))|0); //@line 4198 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $N=$29; //@line 4198 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $30=$K; //@line 4198 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $31=$Y; //@line 4198 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $32=$31 << $30; //@line 4198 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $Y=$32; //@line 4198 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $33=((($32)-(16384))|0); //@line 4198 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $34=$33 >>> 16; //@line 4198 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $35=$34 & 2; //@line 4198 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $K=$35; //@line 4198 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $36=$N; //@line 4198 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $37=((($36)+($35))|0); //@line 4198 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $N=$37; //@line 4198 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $38=$N; //@line 4198 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $39=(((14)-($38))|0); //@line 4198 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $40=$K; //@line 4198 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $41=$Y; //@line 4198 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $42=$41 << $40; //@line 4198 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $Y=$42; //@line 4198 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $43=$42 >>> 15; //@line 4198 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $44=((($39)+($43))|0); //@line 4198 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $K=$44; //@line 4198 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $45=$K; //@line 4198 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $46=$45 << 1; //@line 4198 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $47=$3; //@line 4198 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $48=$K; //@line 4198 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $49=((($48)+(7))|0); //@line 4198 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $50=$47 >>> (($49)>>>0); //@line 4198 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $51=$50 & 1; //@line 4198 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $52=((($46)+($51))|0); //@line 4198 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $idx=$52; //@line 4198 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 7; break;
    case 7: 
      __label__ = 8; break;
    case 8: 
      var $55=$idx; //@line 4199 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $56=$2; //@line 4199 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $57=(($56+304)|0); //@line 4199 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $58=(($57+($55<<2))|0); //@line 4199 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $59=HEAP32[(($58)>>2)]; //@line 4199 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $t=$59; //@line 4199 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $60=(($59)|0)!=0; //@line 4199 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($60) { __label__ = 9; break; } else { __label__ = 24; break; } //@line 4199 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 9: 
      var $62=$3; //@line 4201 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $63=$idx; //@line 4201 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $64=(($63)|0)==31; //@line 4201 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($64) { __label__ = 10; break; } else { __label__ = 11; break; } //@line 4201 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 10: 
      var $73 = 0;__label__ = 12; break; //@line 4201 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 11: 
      var $67=$idx; //@line 4201 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $68=$67 >>> 1; //@line 4201 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $69=((($68)+(8))|0); //@line 4201 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $70=((($69)-(2))|0); //@line 4201 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $71=(((31)-($70))|0); //@line 4201 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $73 = $71;__label__ = 12; break; //@line 4201 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 12: 
      var $73; //@line 4201 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $74=$62 << $73; //@line 4201 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $sizebits=$74; //@line 4201 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $rst=0; //@line 4202 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 13; break; //@line 4203 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 13: 
      var $76=$t; //@line 4205 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $77=(($76+4)|0); //@line 4205 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $78=HEAP32[(($77)>>2)]; //@line 4205 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $79=$78 & -8; //@line 4205 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $80=$3; //@line 4205 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $81=((($79)-($80))|0); //@line 4205 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $trem=$81; //@line 4205 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $82=$trem; //@line 4206 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $83=$rsize; //@line 4206 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $84=(($82)>>>0) < (($83)>>>0); //@line 4206 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($84) { __label__ = 14; break; } else { __label__ = 17; break; } //@line 4206 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 14: 
      var $86=$t; //@line 4207 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $v=$86; //@line 4207 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $87=$trem; //@line 4208 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $rsize=$87; //@line 4208 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $88=(($87)|0)==0; //@line 4208 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($88) { __label__ = 15; break; } else { __label__ = 16; break; } //@line 4208 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 15: 
      __label__ = 23; break; //@line 4209 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 16: 
      __label__ = 17; break; //@line 4210 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 17: 
      var $92=$t; //@line 4211 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $93=(($92+16)|0); //@line 4211 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $94=(($93+4)|0); //@line 4211 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $95=HEAP32[(($94)>>2)]; //@line 4211 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $rt=$95; //@line 4211 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $96=$sizebits; //@line 4212 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $97=$96 >>> 31; //@line 4212 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $98=$97 & 1; //@line 4212 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $99=$t; //@line 4212 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $100=(($99+16)|0); //@line 4212 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $101=(($100+($98<<2))|0); //@line 4212 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $102=HEAP32[(($101)>>2)]; //@line 4212 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $t=$102; //@line 4212 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $103=$rt; //@line 4213 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $104=(($103)|0)!=0; //@line 4213 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($104) { __label__ = 18; break; } else { __label__ = 20; break; } //@line 4213 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 18: 
      var $106=$rt; //@line 4213 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $107=$t; //@line 4213 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $108=(($106)|0)!=(($107)|0); //@line 4213 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($108) { __label__ = 19; break; } else { __label__ = 20; break; } //@line 4213 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 19: 
      var $110=$rt; //@line 4214 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $rst=$110; //@line 4214 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 20; break; //@line 4214 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 20: 
      var $112=$t; //@line 4215 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $113=(($112)|0)==0; //@line 4215 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($113) { __label__ = 21; break; } else { __label__ = 22; break; } //@line 4215 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 21: 
      var $115=$rst; //@line 4216 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $t=$115; //@line 4216 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 23; break; //@line 4217 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 22: 
      var $117=$sizebits; //@line 4219 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $118=$117 << 1; //@line 4219 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $sizebits=$118; //@line 4219 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 13; break; //@line 4220 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 23: 
      __label__ = 24; break; //@line 4221 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 24: 
      var $121=$t; //@line 4222 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $122=(($121)|0)==0; //@line 4222 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($122) { __label__ = 25; break; } else { __label__ = 29; break; } //@line 4222 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 25: 
      var $124=$v; //@line 4222 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $125=(($124)|0)==0; //@line 4222 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($125) { __label__ = 26; break; } else { __label__ = 29; break; } //@line 4222 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 26: 
      var $127=$idx; //@line 4223 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $128=1 << $127; //@line 4223 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $129=$128 << 1; //@line 4223 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $130=$idx; //@line 4223 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $131=1 << $130; //@line 4223 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $132=$131 << 1; //@line 4223 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $133=(((-$132))|0); //@line 4223 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $134=$129 | $133; //@line 4223 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $135=$2; //@line 4223 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $136=(($135+4)|0); //@line 4223 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $137=HEAP32[(($136)>>2)]; //@line 4223 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $138=$134 & $137; //@line 4223 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $leftbits=$138; //@line 4223 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $139=$leftbits; //@line 4224 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $140=(($139)|0)!=0; //@line 4224 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($140) { __label__ = 27; break; } else { __label__ = 28; break; } //@line 4224 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 27: 
      var $142=$leftbits; //@line 4226 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $143=$leftbits; //@line 4226 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $144=(((-$143))|0); //@line 4226 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $145=$142 & $144; //@line 4226 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $leastbit=$145; //@line 4226 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $146=$leastbit; //@line 4227 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $147=((($146)-(1))|0); //@line 4227 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $Y1=$147; //@line 4227 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $148=$Y1; //@line 4227 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $149=$148 >>> 12; //@line 4227 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $150=$149 & 16; //@line 4227 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $K2=$150; //@line 4227 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $151=$K2; //@line 4227 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $N3=$151; //@line 4227 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $152=$K2; //@line 4227 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $153=$Y1; //@line 4227 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $154=$153 >>> (($152)>>>0); //@line 4227 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $Y1=$154; //@line 4227 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $155=$Y1; //@line 4227 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $156=$155 >>> 5; //@line 4227 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $157=$156 & 8; //@line 4227 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $K2=$157; //@line 4227 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $158=$N3; //@line 4227 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $159=((($158)+($157))|0); //@line 4227 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $N3=$159; //@line 4227 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $160=$K2; //@line 4227 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $161=$Y1; //@line 4227 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $162=$161 >>> (($160)>>>0); //@line 4227 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $Y1=$162; //@line 4227 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $163=$Y1; //@line 4227 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $164=$163 >>> 2; //@line 4227 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $165=$164 & 4; //@line 4227 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $K2=$165; //@line 4227 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $166=$N3; //@line 4227 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $167=((($166)+($165))|0); //@line 4227 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $N3=$167; //@line 4227 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $168=$K2; //@line 4227 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $169=$Y1; //@line 4227 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $170=$169 >>> (($168)>>>0); //@line 4227 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $Y1=$170; //@line 4227 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $171=$Y1; //@line 4227 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $172=$171 >>> 1; //@line 4227 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $173=$172 & 2; //@line 4227 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $K2=$173; //@line 4227 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $174=$N3; //@line 4227 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $175=((($174)+($173))|0); //@line 4227 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $N3=$175; //@line 4227 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $176=$K2; //@line 4227 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $177=$Y1; //@line 4227 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $178=$177 >>> (($176)>>>0); //@line 4227 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $Y1=$178; //@line 4227 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $179=$Y1; //@line 4227 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $180=$179 >>> 1; //@line 4227 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $181=$180 & 1; //@line 4227 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $K2=$181; //@line 4227 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $182=$N3; //@line 4227 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $183=((($182)+($181))|0); //@line 4227 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $N3=$183; //@line 4227 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $184=$K2; //@line 4227 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $185=$Y1; //@line 4227 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $186=$185 >>> (($184)>>>0); //@line 4227 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $Y1=$186; //@line 4227 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $187=$N3; //@line 4227 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $188=$Y1; //@line 4227 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $189=((($187)+($188))|0); //@line 4227 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $i=$189; //@line 4227 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $190=$i; //@line 4228 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $191=$2; //@line 4228 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $192=(($191+304)|0); //@line 4228 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $193=(($192+($190<<2))|0); //@line 4228 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $194=HEAP32[(($193)>>2)]; //@line 4228 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $t=$194; //@line 4228 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 28; break; //@line 4229 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 28: 
      __label__ = 29; break; //@line 4230 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 29: 
      __label__ = 30; break; //@line 4232 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 30: 
      var $198=$t; //@line 4232 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $199=(($198)|0)!=0; //@line 4232 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($199) { __label__ = 31; break; } else { __label__ = 37; break; } //@line 4232 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 31: 
      var $201=$t; //@line 4233 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $202=(($201+4)|0); //@line 4233 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $203=HEAP32[(($202)>>2)]; //@line 4233 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $204=$203 & -8; //@line 4233 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $205=$3; //@line 4233 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $206=((($204)-($205))|0); //@line 4233 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $trem4=$206; //@line 4233 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $207=$trem4; //@line 4234 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $208=$rsize; //@line 4234 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $209=(($207)>>>0) < (($208)>>>0); //@line 4234 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($209) { __label__ = 32; break; } else { __label__ = 33; break; } //@line 4234 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 32: 
      var $211=$trem4; //@line 4235 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $rsize=$211; //@line 4235 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $212=$t; //@line 4236 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $v=$212; //@line 4236 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 33; break; //@line 4237 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 33: 
      var $214=$t; //@line 4238 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $215=(($214+16)|0); //@line 4238 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $216=(($215)|0); //@line 4238 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $217=HEAP32[(($216)>>2)]; //@line 4238 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $218=(($217)|0)!=0; //@line 4238 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($218) { __label__ = 34; break; } else { __label__ = 35; break; } //@line 4238 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 34: 
      var $220=$t; //@line 4238 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $221=(($220+16)|0); //@line 4238 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $222=(($221)|0); //@line 4238 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $223=HEAP32[(($222)>>2)]; //@line 4238 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $230 = $223;__label__ = 36; break; //@line 4238 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 35: 
      var $225=$t; //@line 4238 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $226=(($225+16)|0); //@line 4238 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $227=(($226+4)|0); //@line 4238 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $228=HEAP32[(($227)>>2)]; //@line 4238 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $230 = $228;__label__ = 36; break; //@line 4238 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 36: 
      var $230; //@line 4238 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $t=$230; //@line 4238 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 30; break; //@line 4239 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 37: 
      var $232=$v; //@line 4242 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $233=(($232)|0)!=0; //@line 4242 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($233) { __label__ = 38; break; } else { __label__ = 127; break; } //@line 4242 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 38: 
      var $235=$rsize; //@line 4242 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $236=$2; //@line 4242 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $237=(($236+8)|0); //@line 4242 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $238=HEAP32[(($237)>>2)]; //@line 4242 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $239=$3; //@line 4242 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $240=((($238)-($239))|0); //@line 4242 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $241=(($235)>>>0) < (($240)>>>0); //@line 4242 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($241) { __label__ = 39; break; } else { __label__ = 127; break; } //@line 4242 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 39: 
      var $243=$v; //@line 4243 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $244=$243; //@line 4243 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $245=$2; //@line 4243 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $246=(($245+16)|0); //@line 4243 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $247=HEAPU32[(($246)>>2)]; //@line 4243 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $248=(($244)>>>0) >= (($247)>>>0); //@line 4243 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $249=(($248)&1); //@line 4243 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $250=(($249)==(1)); //@line 4243 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $251=(($250)|0)!=0; //@line 4243 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($251) { __label__ = 40; break; } else { __label__ = 126; break; } //@line 4243 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 40: 
      var $253=$v; //@line 4244 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $254=$253; //@line 4244 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $255=$3; //@line 4244 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $256=(($254+$255)|0); //@line 4244 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $257=$256; //@line 4244 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $r=$257; //@line 4244 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $258=$v; //@line 4246 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $259=$258; //@line 4246 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $260=$r; //@line 4246 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $261=$260; //@line 4246 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $262=(($259)>>>0) < (($261)>>>0); //@line 4246 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $263=(($262)&1); //@line 4246 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $264=(($263)==(1)); //@line 4246 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $265=(($264)|0)!=0; //@line 4246 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($265) { __label__ = 41; break; } else { __label__ = 125; break; } //@line 4246 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 41: 
      var $267=$v; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $268=(($267+24)|0); //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $269=HEAP32[(($268)>>2)]; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $XP=$269; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $270=$v; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $271=(($270+12)|0); //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $272=HEAP32[(($271)>>2)]; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $273=$v; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $274=(($272)|0)!=(($273)|0); //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($274) { __label__ = 42; break; } else { __label__ = 46; break; } //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 42: 
      var $276=$v; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $277=(($276+8)|0); //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $278=HEAP32[(($277)>>2)]; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $F=$278; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $279=$v; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $280=(($279+12)|0); //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $281=HEAP32[(($280)>>2)]; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $R=$281; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $282=$F; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $283=$282; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $284=$2; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $285=(($284+16)|0); //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $286=HEAPU32[(($285)>>2)]; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $287=(($283)>>>0) >= (($286)>>>0); //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $288=(($287)&1); //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $289=(($288)==(1)); //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $290=(($289)|0)!=0; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($290) { __label__ = 43; break; } else { __label__ = 44; break; } //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 43: 
      var $292=$R; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $293=$F; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $294=(($293+12)|0); //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($294)>>2)]=$292; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $295=$F; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $296=$R; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $297=(($296+8)|0); //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($297)>>2)]=$295; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 45; break; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 44: 
      _abort(); //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      throw "Reached an unreachable!" //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 45: 
      __label__ = 58; break; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 46: 
      var $301=$v; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $302=(($301+16)|0); //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $303=(($302+4)|0); //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $RP=$303; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $304=HEAP32[(($303)>>2)]; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $R=$304; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $305=(($304)|0)!=0; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($305) { __label__ = 48; break; } else { __label__ = 47; break; } //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 47: 
      var $307=$v; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $308=(($307+16)|0); //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $309=(($308)|0); //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $RP=$309; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $310=HEAP32[(($309)>>2)]; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $R=$310; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $311=(($310)|0)!=0; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($311) { __label__ = 48; break; } else { __label__ = 57; break; } //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 48: 
      __label__ = 49; break; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 49: 
      var $314=$R; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $315=(($314+16)|0); //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $316=(($315+4)|0); //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $CP=$316; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $317=HEAP32[(($316)>>2)]; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $318=(($317)|0)!=0; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($318) { var $326 = 1;__label__ = 51; break; } else { __label__ = 50; break; } //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 50: 
      var $320=$R; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $321=(($320+16)|0); //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $322=(($321)|0); //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $CP=$322; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $323=HEAP32[(($322)>>2)]; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $324=(($323)|0)!=0; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $326 = $324;__label__ = 51; break; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 51: 
      var $326;
      if ($326) { __label__ = 52; break; } else { __label__ = 53; break; } //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 52: 
      var $328=$CP; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $RP=$328; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $329=HEAP32[(($328)>>2)]; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $R=$329; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 49; break; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 53: 
      var $331=$RP; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $332=$331; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $333=$2; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $334=(($333+16)|0); //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $335=HEAPU32[(($334)>>2)]; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $336=(($332)>>>0) >= (($335)>>>0); //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $337=(($336)&1); //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $338=(($337)==(1)); //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $339=(($338)|0)!=0; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($339) { __label__ = 54; break; } else { __label__ = 55; break; } //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 54: 
      var $341=$RP; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($341)>>2)]=0; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 56; break; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 55: 
      _abort(); //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      throw "Reached an unreachable!" //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 56: 
      __label__ = 57; break; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 57: 
      __label__ = 58; break;
    case 58: 
      var $346=$XP; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $347=(($346)|0)!=0; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($347) { __label__ = 59; break; } else { __label__ = 86; break; } //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 59: 
      var $349=$v; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $350=(($349+28)|0); //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $351=HEAP32[(($350)>>2)]; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $352=$2; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $353=(($352+304)|0); //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $354=(($353+($351<<2))|0); //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $H=$354; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $355=$v; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $356=$H; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $357=HEAP32[(($356)>>2)]; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $358=(($355)|0)==(($357)|0); //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($358) { __label__ = 60; break; } else { __label__ = 63; break; } //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 60: 
      var $360=$R; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $361=$H; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($361)>>2)]=$360; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $362=(($360)|0)==0; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($362) { __label__ = 61; break; } else { __label__ = 62; break; } //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 61: 
      var $364=$v; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $365=(($364+28)|0); //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $366=HEAP32[(($365)>>2)]; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $367=1 << $366; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $368=$367 ^ -1; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $369=$2; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $370=(($369+4)|0); //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $371=HEAP32[(($370)>>2)]; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $372=$371 & $368; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($370)>>2)]=$372; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 62; break; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 62: 
      __label__ = 70; break; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 63: 
      var $375=$XP; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $376=$375; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $377=$2; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $378=(($377+16)|0); //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $379=HEAPU32[(($378)>>2)]; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $380=(($376)>>>0) >= (($379)>>>0); //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $381=(($380)&1); //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $382=(($381)==(1)); //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $383=(($382)|0)!=0; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($383) { __label__ = 64; break; } else { __label__ = 68; break; } //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 64: 
      var $385=$XP; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $386=(($385+16)|0); //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $387=(($386)|0); //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $388=HEAP32[(($387)>>2)]; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $389=$v; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $390=(($388)|0)==(($389)|0); //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($390) { __label__ = 65; break; } else { __label__ = 66; break; } //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 65: 
      var $392=$R; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $393=$XP; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $394=(($393+16)|0); //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $395=(($394)|0); //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($395)>>2)]=$392; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 67; break; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 66: 
      var $397=$R; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $398=$XP; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $399=(($398+16)|0); //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $400=(($399+4)|0); //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($400)>>2)]=$397; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 67; break;
    case 67: 
      __label__ = 69; break; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 68: 
      _abort(); //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      throw "Reached an unreachable!" //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 69: 
      __label__ = 70; break;
    case 70: 
      var $405=$R; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $406=(($405)|0)!=0; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($406) { __label__ = 71; break; } else { __label__ = 85; break; } //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 71: 
      var $408=$R; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $409=$408; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $410=$2; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $411=(($410+16)|0); //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $412=HEAPU32[(($411)>>2)]; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $413=(($409)>>>0) >= (($412)>>>0); //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $414=(($413)&1); //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $415=(($414)==(1)); //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $416=(($415)|0)!=0; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($416) { __label__ = 72; break; } else { __label__ = 83; break; } //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 72: 
      var $418=$XP; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $419=$R; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $420=(($419+24)|0); //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($420)>>2)]=$418; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $421=$v; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $422=(($421+16)|0); //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $423=(($422)|0); //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $424=HEAP32[(($423)>>2)]; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $C0=$424; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $425=(($424)|0)!=0; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($425) { __label__ = 73; break; } else { __label__ = 77; break; } //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 73: 
      var $427=$C0; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $428=$427; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $429=$2; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $430=(($429+16)|0); //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $431=HEAPU32[(($430)>>2)]; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $432=(($428)>>>0) >= (($431)>>>0); //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $433=(($432)&1); //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $434=(($433)==(1)); //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $435=(($434)|0)!=0; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($435) { __label__ = 74; break; } else { __label__ = 75; break; } //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 74: 
      var $437=$C0; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $438=$R; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $439=(($438+16)|0); //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $440=(($439)|0); //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($440)>>2)]=$437; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $441=$R; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $442=$C0; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $443=(($442+24)|0); //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($443)>>2)]=$441; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 76; break; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 75: 
      _abort(); //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      throw "Reached an unreachable!" //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 76: 
      __label__ = 77; break; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 77: 
      var $447=$v; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $448=(($447+16)|0); //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $449=(($448+4)|0); //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $450=HEAP32[(($449)>>2)]; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $C1=$450; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $451=(($450)|0)!=0; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($451) { __label__ = 78; break; } else { __label__ = 82; break; } //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 78: 
      var $453=$C1; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $454=$453; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $455=$2; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $456=(($455+16)|0); //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $457=HEAPU32[(($456)>>2)]; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $458=(($454)>>>0) >= (($457)>>>0); //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $459=(($458)&1); //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $460=(($459)==(1)); //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $461=(($460)|0)!=0; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($461) { __label__ = 79; break; } else { __label__ = 80; break; } //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 79: 
      var $463=$C1; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $464=$R; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $465=(($464+16)|0); //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $466=(($465+4)|0); //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($466)>>2)]=$463; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $467=$R; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $468=$C1; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $469=(($468+24)|0); //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($469)>>2)]=$467; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 81; break; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 80: 
      _abort(); //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      throw "Reached an unreachable!" //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 81: 
      __label__ = 82; break; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 82: 
      __label__ = 84; break; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 83: 
      _abort(); //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      throw "Reached an unreachable!" //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 84: 
      __label__ = 85; break; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 85: 
      __label__ = 86; break; //@line 4247 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 86: 
      var $477=$rsize; //@line 4248 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $478=(($477)>>>0) < 16; //@line 4248 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($478) { __label__ = 87; break; } else { __label__ = 88; break; } //@line 4248 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 87: 
      var $480=$rsize; //@line 4249 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $481=$3; //@line 4249 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $482=((($480)+($481))|0); //@line 4249 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $483=$482 | 1; //@line 4249 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $484=$483 | 2; //@line 4249 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $485=$v; //@line 4249 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $486=(($485+4)|0); //@line 4249 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($486)>>2)]=$484; //@line 4249 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $487=$v; //@line 4249 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $488=$487; //@line 4249 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $489=$rsize; //@line 4249 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $490=$3; //@line 4249 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $491=((($489)+($490))|0); //@line 4249 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $492=(($488+$491)|0); //@line 4249 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $493=$492; //@line 4249 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $494=(($493+4)|0); //@line 4249 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $495=HEAP32[(($494)>>2)]; //@line 4249 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $496=$495 | 1; //@line 4249 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($494)>>2)]=$496; //@line 4249 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 124; break; //@line 4249 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 88: 
      var $498=$3; //@line 4251 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $499=$498 | 1; //@line 4251 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $500=$499 | 2; //@line 4251 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $501=$v; //@line 4251 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $502=(($501+4)|0); //@line 4251 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($502)>>2)]=$500; //@line 4251 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $503=$rsize; //@line 4252 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $504=$503 | 1; //@line 4252 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $505=$r; //@line 4252 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $506=(($505+4)|0); //@line 4252 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($506)>>2)]=$504; //@line 4252 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $507=$rsize; //@line 4252 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $508=$r; //@line 4252 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $509=$508; //@line 4252 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $510=$rsize; //@line 4252 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $511=(($509+$510)|0); //@line 4252 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $512=$511; //@line 4252 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $513=(($512)|0); //@line 4252 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($513)>>2)]=$507; //@line 4252 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $514=$rsize; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $515=$514 >>> 3; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $516=(($515)>>>0) < 32; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($516) { __label__ = 89; break; } else { __label__ = 96; break; } //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 89: 
      var $518=$rsize; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $519=$518 >>> 3; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $I=$519; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $520=$I; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $521=$520 << 1; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $522=$2; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $523=(($522+40)|0); //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $524=(($523+($521<<2))|0); //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $525=$524; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $526=$525; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $B=$526; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $527=$B; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $F5=$527; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $528=$2; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $529=(($528)|0); //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $530=HEAP32[(($529)>>2)]; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $531=$I; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $532=1 << $531; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $533=$530 & $532; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $534=(($533)|0)!=0; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($534) { __label__ = 91; break; } else { __label__ = 90; break; } //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 90: 
      var $536=$I; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $537=1 << $536; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $538=$2; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $539=(($538)|0); //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $540=HEAP32[(($539)>>2)]; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $541=$540 | $537; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($539)>>2)]=$541; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 95; break; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 91: 
      var $543=$B; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $544=(($543+8)|0); //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $545=HEAP32[(($544)>>2)]; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $546=$545; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $547=$2; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $548=(($547+16)|0); //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $549=HEAPU32[(($548)>>2)]; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $550=(($546)>>>0) >= (($549)>>>0); //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $551=(($550)&1); //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $552=(($551)==(1)); //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $553=(($552)|0)!=0; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($553) { __label__ = 92; break; } else { __label__ = 93; break; } //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 92: 
      var $555=$B; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $556=(($555+8)|0); //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $557=HEAP32[(($556)>>2)]; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $F5=$557; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 94; break; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 93: 
      _abort(); //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      throw "Reached an unreachable!" //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 94: 
      __label__ = 95; break;
    case 95: 
      var $561=$r; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $562=$B; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $563=(($562+8)|0); //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($563)>>2)]=$561; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $564=$r; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $565=$F5; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $566=(($565+12)|0); //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($566)>>2)]=$564; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $567=$F5; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $568=$r; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $569=(($568+8)|0); //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($569)>>2)]=$567; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $570=$B; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $571=$r; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $572=(($571+12)|0); //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($572)>>2)]=$570; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 123; break; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 96: 
      var $574=$r; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $575=$574; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $TP=$575; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $576=$rsize; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $577=$576 >>> 8; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $X8=$577; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $578=$X8; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $579=(($578)|0)==0; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($579) { __label__ = 97; break; } else { __label__ = 98; break; } //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 97: 
      $I7=0; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 102; break; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 98: 
      var $582=$X8; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $583=(($582)>>>0) > 65535; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($583) { __label__ = 99; break; } else { __label__ = 100; break; } //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 99: 
      $I7=31; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 101; break; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 100: 
      var $586=$X8; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $Y9=$586; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $587=$Y9; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $588=((($587)-(256))|0); //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $589=$588 >>> 16; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $590=$589 & 8; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $N10=$590; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $591=$N10; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $592=$Y9; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $593=$592 << $591; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $Y9=$593; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $594=((($593)-(4096))|0); //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $595=$594 >>> 16; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $596=$595 & 4; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $K11=$596; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $597=$K11; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $598=$N10; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $599=((($598)+($597))|0); //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $N10=$599; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $600=$K11; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $601=$Y9; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $602=$601 << $600; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $Y9=$602; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $603=((($602)-(16384))|0); //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $604=$603 >>> 16; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $605=$604 & 2; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $K11=$605; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $606=$N10; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $607=((($606)+($605))|0); //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $N10=$607; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $608=$N10; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $609=(((14)-($608))|0); //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $610=$K11; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $611=$Y9; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $612=$611 << $610; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $Y9=$612; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $613=$612 >>> 15; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $614=((($609)+($613))|0); //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $K11=$614; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $615=$K11; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $616=$615 << 1; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $617=$rsize; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $618=$K11; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $619=((($618)+(7))|0); //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $620=$617 >>> (($619)>>>0); //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $621=$620 & 1; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $622=((($616)+($621))|0); //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $I7=$622; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 101; break;
    case 101: 
      __label__ = 102; break;
    case 102: 
      var $625=$I7; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $626=$2; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $627=(($626+304)|0); //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $628=(($627+($625<<2))|0); //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $H6=$628; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $629=$I7; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $630=$TP; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $631=(($630+28)|0); //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($631)>>2)]=$629; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $632=$TP; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $633=(($632+16)|0); //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $634=(($633+4)|0); //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($634)>>2)]=0; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $635=$TP; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $636=(($635+16)|0); //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $637=(($636)|0); //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($637)>>2)]=0; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $638=$2; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $639=(($638+4)|0); //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $640=HEAP32[(($639)>>2)]; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $641=$I7; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $642=1 << $641; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $643=$640 & $642; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $644=(($643)|0)!=0; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($644) { __label__ = 104; break; } else { __label__ = 103; break; } //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 103: 
      var $646=$I7; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $647=1 << $646; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $648=$2; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $649=(($648+4)|0); //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $650=HEAP32[(($649)>>2)]; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $651=$650 | $647; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($649)>>2)]=$651; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $652=$TP; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $653=$H6; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($653)>>2)]=$652; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $654=$H6; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $655=$654; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $656=$TP; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $657=(($656+24)|0); //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($657)>>2)]=$655; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $658=$TP; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $659=$TP; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $660=(($659+12)|0); //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($660)>>2)]=$658; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $661=$TP; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $662=(($661+8)|0); //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($662)>>2)]=$658; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 122; break; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 104: 
      var $664=$H6; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $665=HEAP32[(($664)>>2)]; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $T=$665; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $666=$rsize; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $667=$I7; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $668=(($667)|0)==31; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($668) { __label__ = 105; break; } else { __label__ = 106; break; } //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 105: 
      var $677 = 0;__label__ = 107; break; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 106: 
      var $671=$I7; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $672=$671 >>> 1; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $673=((($672)+(8))|0); //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $674=((($673)-(2))|0); //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $675=(((31)-($674))|0); //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $677 = $675;__label__ = 107; break; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 107: 
      var $677; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $678=$666 << $677; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $K12=$678; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 108; break; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 108: 
      var $680=$T; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $681=(($680+4)|0); //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $682=HEAP32[(($681)>>2)]; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $683=$682 & -8; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $684=$rsize; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $685=(($683)|0)!=(($684)|0); //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($685) { __label__ = 109; break; } else { __label__ = 115; break; } //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 109: 
      var $687=$K12; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $688=$687 >>> 31; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $689=$688 & 1; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $690=$T; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $691=(($690+16)|0); //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $692=(($691+($689<<2))|0); //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $C=$692; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $693=$K12; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $694=$693 << 1; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $K12=$694; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $695=$C; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $696=HEAP32[(($695)>>2)]; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $697=(($696)|0)!=0; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($697) { __label__ = 110; break; } else { __label__ = 111; break; } //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 110: 
      var $699=$C; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $700=HEAP32[(($699)>>2)]; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $T=$700; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 114; break; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 111: 
      var $702=$C; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $703=$702; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $704=$2; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $705=(($704+16)|0); //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $706=HEAPU32[(($705)>>2)]; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $707=(($703)>>>0) >= (($706)>>>0); //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $708=(($707)&1); //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $709=(($708)==(1)); //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $710=(($709)|0)!=0; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($710) { __label__ = 112; break; } else { __label__ = 113; break; } //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 112: 
      var $712=$TP; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $713=$C; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($713)>>2)]=$712; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $714=$T; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $715=$TP; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $716=(($715+24)|0); //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($716)>>2)]=$714; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $717=$TP; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $718=$TP; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $719=(($718+12)|0); //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($719)>>2)]=$717; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $720=$TP; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $721=(($720+8)|0); //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($721)>>2)]=$717; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 121; break; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 113: 
      _abort(); //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      throw "Reached an unreachable!" //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 114: 
      __label__ = 120; break; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 115: 
      var $725=$T; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $726=(($725+8)|0); //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $727=HEAP32[(($726)>>2)]; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $F13=$727; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $728=$T; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $729=$728; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $730=$2; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $731=(($730+16)|0); //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $732=HEAPU32[(($731)>>2)]; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $733=(($729)>>>0) >= (($732)>>>0); //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($733) { __label__ = 116; break; } else { var $742 = 0;__label__ = 117; break; } //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 116: 
      var $735=$F13; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $736=$735; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $737=$2; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $738=(($737+16)|0); //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $739=HEAPU32[(($738)>>2)]; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $740=(($736)>>>0) >= (($739)>>>0); //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $742 = $740;__label__ = 117; break;
    case 117: 
      var $742;
      var $743=(($742)&1);
      var $744=(($743)==(1));
      var $745=(($744)|0)!=0;
      if ($745) { __label__ = 118; break; } else { __label__ = 119; break; }
    case 118: 
      var $747=$TP; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $748=$F13; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $749=(($748+12)|0); //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($749)>>2)]=$747; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $750=$T; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $751=(($750+8)|0); //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($751)>>2)]=$747; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $752=$F13; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $753=$TP; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $754=(($753+8)|0); //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($754)>>2)]=$752; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $755=$T; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $756=$TP; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $757=(($756+12)|0); //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($757)>>2)]=$755; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $758=$TP; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $759=(($758+24)|0); //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($759)>>2)]=0; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 121; break; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 119: 
      _abort(); //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      throw "Reached an unreachable!" //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 120: 
      __label__ = 108; break; //@line 4253 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 121: 
      __label__ = 122; break;
    case 122: 
      __label__ = 123; break;
    case 123: 
      __label__ = 124; break;
    case 124: 
      var $766=$v; //@line 4255 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $767=$766; //@line 4255 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $768=(($767+8)|0); //@line 4255 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $1=$768; //@line 4255 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 128; break; //@line 4255 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 125: 
      __label__ = 126; break; //@line 4257 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 126: 
      _abort(); //@line 4258 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      throw "Reached an unreachable!" //@line 4258 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 127: 
      $1=0; //@line 4260 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 128; break; //@line 4260 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 128: 
      var $773=$1; //@line 4261 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      ;
      return $773; //@line 4261 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    default: assert(0, "bad label: " + __label__);
  }
}
_tmalloc_large["X"]=1;

function _sys_alloc($m, $nb) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $tbase;
      var $tsize;
      var $mmap_flag;
      var $mem;
      var $br;
      var $ss;
      var $asize;
      var $base;
      var $esize;
      var $end;
      var $asize1;
      var $br2;
      var $end3;
      var $ssize;
      var $mn;
      var $sp;
      var $oldbase;
      var $rsize;
      var $p;
      var $r;
      $2=$m;
      $3=$nb;
      $tbase=-1; //@line 3876 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $tsize=0; //@line 3877 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $mmap_flag=0; //@line 3878 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $4=HEAP32[((((_mparams)|0))>>2)]; //@line 3880 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $5=(($4)|0)!=0; //@line 3880 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($5) { var $10 = 1;__label__ = 4; break; } else { __label__ = 3; break; } //@line 3880 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 3: 
      var $7=_init_mparams(); //@line 3880 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $8=(($7)|0)!=0; //@line 3880 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $10 = $8;__label__ = 4; break; //@line 3880 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 4: 
      var $10;
      var $11=(($10)&1); //@line 3880 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $12=$2; //@line 3883 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $13=(($12+440)|0); //@line 3883 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $14=HEAP32[(($13)>>2)]; //@line 3883 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $15=$14 & 0; //@line 3883 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $16=(($15)|0)!=0; //@line 3883 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($16) { __label__ = 5; break; } else { __label__ = 10; break; } //@line 3883 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 5: 
      var $18=$3; //@line 3883 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $19=HEAPU32[((((_mparams+12)|0))>>2)]; //@line 3883 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $20=(($18)>>>0) >= (($19)>>>0); //@line 3883 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($20) { __label__ = 6; break; } else { __label__ = 10; break; } //@line 3883 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 6: 
      var $22=$2; //@line 3883 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $23=(($22+12)|0); //@line 3883 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $24=HEAP32[(($23)>>2)]; //@line 3883 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $25=(($24)|0)!=0; //@line 3883 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($25) { __label__ = 7; break; } else { __label__ = 10; break; } //@line 3883 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 7: 
      var $27=$2; //@line 3884 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $28=$3; //@line 3884 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $29=_mmap_alloc($27, $28); //@line 3884 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $mem=$29; //@line 3884 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $30=$mem; //@line 3885 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $31=(($30)|0)!=0; //@line 3885 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($31) { __label__ = 8; break; } else { __label__ = 9; break; } //@line 3885 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 8: 
      var $33=$mem; //@line 3886 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $1=$33; //@line 3886 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 93; break; //@line 3886 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 9: 
      __label__ = 10; break; //@line 3887 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 10: 
      var $36=$2; //@line 3911 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $37=(($36+440)|0); //@line 3911 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $38=HEAP32[(($37)>>2)]; //@line 3911 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $39=$38 & 4; //@line 3911 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $40=(($39)|0)!=0; //@line 3911 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($40) { __label__ = 43; break; } else { __label__ = 11; break; } //@line 3911 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 11: 
      $br=-1; //@line 3912 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $42=$2; //@line 3913 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $43=(($42+24)|0); //@line 3913 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $44=HEAP32[(($43)>>2)]; //@line 3913 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $45=(($44)|0)==0; //@line 3913 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($45) { __label__ = 12; break; } else { __label__ = 13; break; } //@line 3913 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 12: 
      var $55 = 0;__label__ = 14; break; //@line 3913 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 13: 
      var $48=$2; //@line 3913 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $49=$2; //@line 3913 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $50=(($49+24)|0); //@line 3913 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $51=HEAP32[(($50)>>2)]; //@line 3913 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $52=$51; //@line 3913 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $53=_segment_holding($48, $52); //@line 3913 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $55 = $53;__label__ = 14; break; //@line 3913 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 14: 
      var $55; //@line 3913 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $ss=$55; //@line 3913 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $asize=0; //@line 3914 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $56=$ss; //@line 3917 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $57=(($56)|0)==0; //@line 3917 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($57) { __label__ = 15; break; } else { __label__ = 23; break; } //@line 3917 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 15: 
      var $59=_sbrk(0); //@line 3918 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $base=$59; //@line 3918 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $60=$base; //@line 3919 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $61=(($60)|0)!=-1; //@line 3919 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($61) { __label__ = 16; break; } else { __label__ = 22; break; } //@line 3919 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 16: 
      var $63=$3; //@line 3920 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $64=((($63)+(48))|0); //@line 3920 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $65=HEAP32[((((_mparams+8)|0))>>2)]; //@line 3920 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $66=((($65)-(1))|0); //@line 3920 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $67=((($64)+($66))|0); //@line 3920 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $68=HEAP32[((((_mparams+8)|0))>>2)]; //@line 3920 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $69=((($68)-(1))|0); //@line 3920 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $70=$69 ^ -1; //@line 3920 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $71=$67 & $70; //@line 3920 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $asize=$71; //@line 3920 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $72=$base; //@line 3922 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $73=$72; //@line 3922 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $74=HEAP32[((((_mparams+4)|0))>>2)]; //@line 3922 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $75=((($74)-(1))|0); //@line 3922 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $76=$73 & $75; //@line 3922 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $77=(($76)|0)==0; //@line 3922 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($77) { __label__ = 18; break; } else { __label__ = 17; break; } //@line 3922 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 17: 
      var $79=$base; //@line 3923 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $80=$79; //@line 3923 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $81=HEAP32[((((_mparams+4)|0))>>2)]; //@line 3923 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $82=((($81)-(1))|0); //@line 3923 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $83=((($80)+($82))|0); //@line 3923 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $84=HEAP32[((((_mparams+4)|0))>>2)]; //@line 3923 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $85=((($84)-(1))|0); //@line 3923 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $86=$85 ^ -1; //@line 3923 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $87=$83 & $86; //@line 3923 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $88=$base; //@line 3923 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $89=$88; //@line 3923 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $90=((($87)-($89))|0); //@line 3923 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $91=$asize; //@line 3923 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $92=((($91)+($90))|0); //@line 3923 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $asize=$92; //@line 3923 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 18; break; //@line 3923 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 18: 
      var $94=$asize; //@line 3925 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $95=(($94)>>>0) < 2147483647; //@line 3925 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($95) { __label__ = 19; break; } else { __label__ = 21; break; } //@line 3925 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 19: 
      var $97=$asize; //@line 3926 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $98=_sbrk($97); //@line 3926 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $br=$98; //@line 3926 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $99=$base; //@line 3926 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $100=(($98)|0)==(($99)|0); //@line 3926 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($100) { __label__ = 20; break; } else { __label__ = 21; break; } //@line 3926 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 20: 
      var $102=$base; //@line 3927 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $tbase=$102; //@line 3927 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $103=$asize; //@line 3928 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $tsize=$103; //@line 3928 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 21; break; //@line 3929 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 21: 
      __label__ = 22; break; //@line 3930 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 22: 
      __label__ = 27; break; //@line 3931 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 23: 
      var $107=$3; //@line 3934 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $108=$2; //@line 3934 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $109=(($108+12)|0); //@line 3934 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $110=HEAP32[(($109)>>2)]; //@line 3934 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $111=((($107)-($110))|0); //@line 3934 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $112=((($111)+(48))|0); //@line 3934 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $113=HEAP32[((((_mparams+8)|0))>>2)]; //@line 3934 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $114=((($113)-(1))|0); //@line 3934 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $115=((($112)+($114))|0); //@line 3934 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $116=HEAP32[((((_mparams+8)|0))>>2)]; //@line 3934 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $117=((($116)-(1))|0); //@line 3934 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $118=$117 ^ -1; //@line 3934 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $119=$115 & $118; //@line 3934 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $asize=$119; //@line 3934 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $120=$asize; //@line 3936 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $121=(($120)>>>0) < 2147483647; //@line 3936 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($121) { __label__ = 24; break; } else { __label__ = 26; break; } //@line 3936 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 24: 
      var $123=$asize; //@line 3937 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $124=_sbrk($123); //@line 3937 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $br=$124; //@line 3937 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $125=$ss; //@line 3937 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $126=(($125)|0); //@line 3937 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $127=HEAP32[(($126)>>2)]; //@line 3937 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $128=$ss; //@line 3937 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $129=(($128+4)|0); //@line 3937 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $130=HEAP32[(($129)>>2)]; //@line 3937 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $131=(($127+$130)|0); //@line 3937 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $132=(($124)|0)==(($131)|0); //@line 3937 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($132) { __label__ = 25; break; } else { __label__ = 26; break; } //@line 3937 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 25: 
      var $134=$br; //@line 3938 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $tbase=$134; //@line 3938 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $135=$asize; //@line 3939 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $tsize=$135; //@line 3939 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 26; break; //@line 3940 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 26: 
      __label__ = 27; break;
    case 27: 
      var $138=$tbase; //@line 3943 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $139=(($138)|0)==-1; //@line 3943 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($139) { __label__ = 28; break; } else { __label__ = 42; break; } //@line 3943 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 28: 
      var $141=$br; //@line 3944 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $142=(($141)|0)!=-1; //@line 3944 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($142) { __label__ = 29; break; } else { __label__ = 38; break; } //@line 3944 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 29: 
      var $144=$asize; //@line 3945 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $145=(($144)>>>0) < 2147483647; //@line 3945 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($145) { __label__ = 30; break; } else { __label__ = 37; break; } //@line 3945 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 30: 
      var $147=$asize; //@line 3945 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $148=$3; //@line 3945 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $149=((($148)+(48))|0); //@line 3945 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $150=(($147)>>>0) < (($149)>>>0); //@line 3945 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($150) { __label__ = 31; break; } else { __label__ = 37; break; } //@line 3945 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 31: 
      var $152=$3; //@line 3947 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $153=((($152)+(48))|0); //@line 3947 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $154=$asize; //@line 3947 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $155=((($153)-($154))|0); //@line 3947 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $156=HEAP32[((((_mparams+8)|0))>>2)]; //@line 3947 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $157=((($156)-(1))|0); //@line 3947 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $158=((($155)+($157))|0); //@line 3947 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $159=HEAP32[((((_mparams+8)|0))>>2)]; //@line 3947 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $160=((($159)-(1))|0); //@line 3947 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $161=$160 ^ -1; //@line 3947 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $162=$158 & $161; //@line 3947 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $esize=$162; //@line 3947 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $163=$esize; //@line 3948 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $164=(($163)>>>0) < 2147483647; //@line 3948 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($164) { __label__ = 32; break; } else { __label__ = 36; break; } //@line 3948 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 32: 
      var $166=$esize; //@line 3949 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $167=_sbrk($166); //@line 3949 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $end=$167; //@line 3949 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $168=$end; //@line 3950 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $169=(($168)|0)!=-1; //@line 3950 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($169) { __label__ = 33; break; } else { __label__ = 34; break; } //@line 3950 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 33: 
      var $171=$esize; //@line 3951 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $172=$asize; //@line 3951 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $173=((($172)+($171))|0); //@line 3951 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $asize=$173; //@line 3951 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 35; break; //@line 3951 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 34: 
      var $175=$asize; //@line 3953 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $176=(((-$175))|0); //@line 3953 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $177=_sbrk($176); //@line 3953 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $br=-1; //@line 3954 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 35; break;
    case 35: 
      __label__ = 36; break; //@line 3956 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 36: 
      __label__ = 37; break; //@line 3957 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 37: 
      __label__ = 38; break; //@line 3958 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 38: 
      var $182=$br; //@line 3959 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $183=(($182)|0)!=-1; //@line 3959 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($183) { __label__ = 39; break; } else { __label__ = 40; break; } //@line 3959 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 39: 
      var $185=$br; //@line 3960 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $tbase=$185; //@line 3960 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $186=$asize; //@line 3961 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $tsize=$186; //@line 3961 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 41; break; //@line 3962 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 40: 
      var $188=$2; //@line 3964 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $189=(($188+440)|0); //@line 3964 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $190=HEAP32[(($189)>>2)]; //@line 3964 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $191=$190 | 4; //@line 3964 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($189)>>2)]=$191; //@line 3964 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 41; break;
    case 41: 
      __label__ = 42; break; //@line 3965 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 42: 
      __label__ = 43; break; //@line 3968 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 43: 
      var $195=$tbase; //@line 3982 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $196=(($195)|0)==-1; //@line 3982 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($196) { __label__ = 44; break; } else { __label__ = 53; break; } //@line 3982 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 44: 
      var $198=$3; //@line 3983 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $199=((($198)+(48))|0); //@line 3983 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $200=HEAP32[((((_mparams+8)|0))>>2)]; //@line 3983 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $201=((($200)-(1))|0); //@line 3983 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $202=((($199)+($201))|0); //@line 3983 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $203=HEAP32[((((_mparams+8)|0))>>2)]; //@line 3983 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $204=((($203)-(1))|0); //@line 3983 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $205=$204 ^ -1; //@line 3983 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $206=$202 & $205; //@line 3983 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $asize1=$206; //@line 3983 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $207=$asize1; //@line 3984 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $208=(($207)>>>0) < 2147483647; //@line 3984 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($208) { __label__ = 45; break; } else { __label__ = 52; break; } //@line 3984 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 45: 
      $br2=-1; //@line 3985 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $end3=-1; //@line 3986 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $210=$asize1; //@line 3988 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $211=_sbrk($210); //@line 3988 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $br2=$211; //@line 3988 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $212=_sbrk(0); //@line 3989 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $end3=$212; //@line 3989 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $213=$br2; //@line 3991 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $214=(($213)|0)!=-1; //@line 3991 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($214) { __label__ = 46; break; } else { __label__ = 51; break; } //@line 3991 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 46: 
      var $216=$end3; //@line 3991 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $217=(($216)|0)!=-1; //@line 3991 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($217) { __label__ = 47; break; } else { __label__ = 51; break; } //@line 3991 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 47: 
      var $219=$br2; //@line 3991 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $220=$end3; //@line 3991 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $221=(($219)>>>0) < (($220)>>>0); //@line 3991 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($221) { __label__ = 48; break; } else { __label__ = 51; break; } //@line 3991 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 48: 
      var $223=$end3; //@line 3992 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $224=$br2; //@line 3992 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $225=$223; //@line 3992 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $226=$224; //@line 3992 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $227=((($225)-($226))|0); //@line 3992 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $ssize=$227; //@line 3992 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $228=$ssize; //@line 3993 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $229=$3; //@line 3993 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $230=((($229)+(40))|0); //@line 3993 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $231=(($228)>>>0) > (($230)>>>0); //@line 3993 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($231) { __label__ = 49; break; } else { __label__ = 50; break; } //@line 3993 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 49: 
      var $233=$br2; //@line 3994 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $tbase=$233; //@line 3994 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $234=$ssize; //@line 3995 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $tsize=$234; //@line 3995 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 50; break; //@line 3996 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 50: 
      __label__ = 51; break; //@line 3997 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 51: 
      __label__ = 52; break; //@line 3998 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 52: 
      __label__ = 53; break; //@line 3999 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 53: 
      var $239=$tbase; //@line 4001 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $240=(($239)|0)!=-1; //@line 4001 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($240) { __label__ = 54; break; } else { __label__ = 92; break; } //@line 4001 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 54: 
      var $242=$tsize; //@line 4003 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $243=$2; //@line 4003 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $244=(($243+432)|0); //@line 4003 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $245=HEAP32[(($244)>>2)]; //@line 4003 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $246=((($245)+($242))|0); //@line 4003 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($244)>>2)]=$246; //@line 4003 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $247=$2; //@line 4003 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $248=(($247+436)|0); //@line 4003 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $249=HEAPU32[(($248)>>2)]; //@line 4003 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $250=(($246)>>>0) > (($249)>>>0); //@line 4003 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($250) { __label__ = 55; break; } else { __label__ = 56; break; } //@line 4003 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 55: 
      var $252=$2; //@line 4004 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $253=(($252+432)|0); //@line 4004 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $254=HEAP32[(($253)>>2)]; //@line 4004 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $255=$2; //@line 4004 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $256=(($255+436)|0); //@line 4004 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($256)>>2)]=$254; //@line 4004 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 56; break; //@line 4004 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 56: 
      var $258=$2; //@line 4006 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $259=(($258+24)|0); //@line 4006 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $260=HEAP32[(($259)>>2)]; //@line 4006 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $261=(($260)|0)!=0; //@line 4006 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($261) { __label__ = 64; break; } else { __label__ = 57; break; } //@line 4006 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 57: 
      var $263=$2; //@line 4007 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $264=(($263+16)|0); //@line 4007 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $265=HEAP32[(($264)>>2)]; //@line 4007 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $266=(($265)|0)==0; //@line 4007 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($266) { __label__ = 59; break; } else { __label__ = 58; break; } //@line 4007 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 58: 
      var $268=$tbase; //@line 4007 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $269=$2; //@line 4007 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $270=(($269+16)|0); //@line 4007 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $271=HEAPU32[(($270)>>2)]; //@line 4007 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $272=(($268)>>>0) < (($271)>>>0); //@line 4007 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($272) { __label__ = 59; break; } else { __label__ = 60; break; } //@line 4007 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 59: 
      var $274=$tbase; //@line 4008 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $275=$2; //@line 4008 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $276=(($275+16)|0); //@line 4008 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($276)>>2)]=$274; //@line 4008 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 60; break; //@line 4008 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 60: 
      var $278=$tbase; //@line 4009 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $279=$2; //@line 4009 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $280=(($279+444)|0); //@line 4009 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $281=(($280)|0); //@line 4009 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($281)>>2)]=$278; //@line 4009 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $282=$tsize; //@line 4010 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $283=$2; //@line 4010 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $284=(($283+444)|0); //@line 4010 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $285=(($284+4)|0); //@line 4010 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($285)>>2)]=$282; //@line 4010 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $286=$mmap_flag; //@line 4011 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $287=$2; //@line 4011 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $288=(($287+444)|0); //@line 4011 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $289=(($288+12)|0); //@line 4011 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($289)>>2)]=$286; //@line 4011 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $290=HEAP32[((((_mparams)|0))>>2)]; //@line 4012 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $291=$2; //@line 4012 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $292=(($291+36)|0); //@line 4012 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($292)>>2)]=$290; //@line 4012 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $293=$2; //@line 4013 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $294=(($293+32)|0); //@line 4013 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($294)>>2)]=-1; //@line 4013 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $295=$2; //@line 4014 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      _init_bins($295); //@line 4014 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $296=$2; //@line 4016 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $297=(($296)|0)==((__gm_)|0); //@line 4016 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($297) { __label__ = 61; break; } else { __label__ = 62; break; } //@line 4016 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 61: 
      var $299=$2; //@line 4017 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $300=$tbase; //@line 4017 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $301=$300; //@line 4017 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $302=$tsize; //@line 4017 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $303=((($302)-(40))|0); //@line 4017 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      _init_top($299, $301, $303); //@line 4017 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 63; break; //@line 4017 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 62: 
      var $305=$2; //@line 4022 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $306=$305; //@line 4022 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $307=((($306)-(8))|0); //@line 4022 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $308=$307; //@line 4022 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $309=$308; //@line 4022 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $310=$2; //@line 4022 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $311=$310; //@line 4022 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $312=((($311)-(8))|0); //@line 4022 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $313=$312; //@line 4022 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $314=(($313+4)|0); //@line 4022 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $315=HEAP32[(($314)>>2)]; //@line 4022 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $316=$315 & -8; //@line 4022 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $317=(($309+$316)|0); //@line 4022 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $318=$317; //@line 4022 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $mn=$318; //@line 4022 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $319=$2; //@line 4023 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $320=$mn; //@line 4023 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $321=$tbase; //@line 4023 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $322=$tsize; //@line 4023 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $323=(($321+$322)|0); //@line 4023 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $324=$mn; //@line 4023 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $325=$324; //@line 4023 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $326=$323; //@line 4023 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $327=$325; //@line 4023 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $328=((($326)-($327))|0); //@line 4023 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $329=((($328)-(40))|0); //@line 4023 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      _init_top($319, $320, $329); //@line 4023 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 63; break;
    case 63: 
      __label__ = 89; break; //@line 4025 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 64: 
      var $332=$2; //@line 4029 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $333=(($332+444)|0); //@line 4029 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $sp=$333; //@line 4029 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 65; break; //@line 4031 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 65: 
      var $335=$sp; //@line 4031 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $336=(($335)|0)!=0; //@line 4031 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($336) { __label__ = 66; break; } else { var $348 = 0;__label__ = 67; break; } //@line 4031 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 66: 
      var $338=$tbase; //@line 4031 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $339=$sp; //@line 4031 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $340=(($339)|0); //@line 4031 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $341=HEAP32[(($340)>>2)]; //@line 4031 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $342=$sp; //@line 4031 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $343=(($342+4)|0); //@line 4031 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $344=HEAP32[(($343)>>2)]; //@line 4031 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $345=(($341+$344)|0); //@line 4031 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $346=(($338)|0)!=(($345)|0); //@line 4031 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $348 = $346;__label__ = 67; break;
    case 67: 
      var $348;
      if ($348) { __label__ = 68; break; } else { __label__ = 69; break; }
    case 68: 
      var $350=$sp; //@line 4032 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $351=(($350+8)|0); //@line 4032 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $352=HEAP32[(($351)>>2)]; //@line 4032 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $sp=$352; //@line 4032 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 65; break; //@line 4032 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 69: 
      var $354=$sp; //@line 4033 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $355=(($354)|0)!=0; //@line 4033 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($355) { __label__ = 70; break; } else { __label__ = 75; break; } //@line 4033 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 70: 
      var $357=$sp; //@line 4033 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $358=(($357+12)|0); //@line 4033 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $359=HEAP32[(($358)>>2)]; //@line 4033 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $360=$359 & 8; //@line 4033 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $361=(($360)|0)!=0; //@line 4033 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($361) { __label__ = 75; break; } else { __label__ = 71; break; } //@line 4033 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 71: 
      var $363=$sp; //@line 4033 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $364=(($363+12)|0); //@line 4033 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $365=HEAP32[(($364)>>2)]; //@line 4033 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $366=$365 & 0; //@line 4033 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $367=$mmap_flag; //@line 4033 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $368=(($366)|0)==(($367)|0); //@line 4033 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($368) { __label__ = 72; break; } else { __label__ = 75; break; } //@line 4033 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 72: 
      var $370=$2; //@line 4033 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $371=(($370+24)|0); //@line 4033 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $372=HEAP32[(($371)>>2)]; //@line 4033 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $373=$372; //@line 4033 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $374=$sp; //@line 4033 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $375=(($374)|0); //@line 4033 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $376=HEAPU32[(($375)>>2)]; //@line 4033 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $377=(($373)>>>0) >= (($376)>>>0); //@line 4033 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($377) { __label__ = 73; break; } else { __label__ = 75; break; } //@line 4033 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 73: 
      var $379=$2; //@line 4033 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $380=(($379+24)|0); //@line 4033 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $381=HEAP32[(($380)>>2)]; //@line 4033 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $382=$381; //@line 4033 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $383=$sp; //@line 4033 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $384=(($383)|0); //@line 4033 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $385=HEAP32[(($384)>>2)]; //@line 4033 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $386=$sp; //@line 4033 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $387=(($386+4)|0); //@line 4033 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $388=HEAP32[(($387)>>2)]; //@line 4033 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $389=(($385+$388)|0); //@line 4033 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $390=(($382)>>>0) < (($389)>>>0); //@line 4033 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($390) { __label__ = 74; break; } else { __label__ = 75; break; } //@line 4033 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 74: 
      var $392=$tsize; //@line 4037 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $393=$sp; //@line 4037 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $394=(($393+4)|0); //@line 4037 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $395=HEAP32[(($394)>>2)]; //@line 4037 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $396=((($395)+($392))|0); //@line 4037 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($394)>>2)]=$396; //@line 4037 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $397=$2; //@line 4038 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $398=$2; //@line 4038 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $399=(($398+24)|0); //@line 4038 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $400=HEAP32[(($399)>>2)]; //@line 4038 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $401=$2; //@line 4038 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $402=(($401+12)|0); //@line 4038 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $403=HEAP32[(($402)>>2)]; //@line 4038 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $404=$tsize; //@line 4038 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $405=((($403)+($404))|0); //@line 4038 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      _init_top($397, $400, $405); //@line 4038 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 88; break; //@line 4039 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 75: 
      var $407=$tbase; //@line 4041 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $408=$2; //@line 4041 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $409=(($408+16)|0); //@line 4041 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $410=HEAPU32[(($409)>>2)]; //@line 4041 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $411=(($407)>>>0) < (($410)>>>0); //@line 4041 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($411) { __label__ = 76; break; } else { __label__ = 77; break; } //@line 4041 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 76: 
      var $413=$tbase; //@line 4042 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $414=$2; //@line 4042 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $415=(($414+16)|0); //@line 4042 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($415)>>2)]=$413; //@line 4042 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 77; break; //@line 4042 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 77: 
      var $417=$2; //@line 4043 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $418=(($417+444)|0); //@line 4043 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $sp=$418; //@line 4043 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 78; break; //@line 4044 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 78: 
      var $420=$sp; //@line 4044 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $421=(($420)|0)!=0; //@line 4044 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($421) { __label__ = 79; break; } else { var $431 = 0;__label__ = 80; break; } //@line 4044 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 79: 
      var $423=$sp; //@line 4044 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $424=(($423)|0); //@line 4044 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $425=HEAP32[(($424)>>2)]; //@line 4044 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $426=$tbase; //@line 4044 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $427=$tsize; //@line 4044 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $428=(($426+$427)|0); //@line 4044 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $429=(($425)|0)!=(($428)|0); //@line 4044 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $431 = $429;__label__ = 80; break;
    case 80: 
      var $431;
      if ($431) { __label__ = 81; break; } else { __label__ = 82; break; }
    case 81: 
      var $433=$sp; //@line 4045 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $434=(($433+8)|0); //@line 4045 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $435=HEAP32[(($434)>>2)]; //@line 4045 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $sp=$435; //@line 4045 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 78; break; //@line 4045 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 82: 
      var $437=$sp; //@line 4046 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $438=(($437)|0)!=0; //@line 4046 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($438) { __label__ = 83; break; } else { __label__ = 86; break; } //@line 4046 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 83: 
      var $440=$sp; //@line 4046 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $441=(($440+12)|0); //@line 4046 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $442=HEAP32[(($441)>>2)]; //@line 4046 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $443=$442 & 8; //@line 4046 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $444=(($443)|0)!=0; //@line 4046 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($444) { __label__ = 86; break; } else { __label__ = 84; break; } //@line 4046 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 84: 
      var $446=$sp; //@line 4046 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $447=(($446+12)|0); //@line 4046 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $448=HEAP32[(($447)>>2)]; //@line 4046 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $449=$448 & 0; //@line 4046 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $450=$mmap_flag; //@line 4046 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $451=(($449)|0)==(($450)|0); //@line 4046 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($451) { __label__ = 85; break; } else { __label__ = 86; break; } //@line 4046 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 85: 
      var $453=$sp; //@line 4049 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $454=(($453)|0); //@line 4049 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $455=HEAP32[(($454)>>2)]; //@line 4049 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $oldbase=$455; //@line 4049 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $456=$tbase; //@line 4050 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $457=$sp; //@line 4050 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $458=(($457)|0); //@line 4050 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($458)>>2)]=$456; //@line 4050 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $459=$tsize; //@line 4051 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $460=$sp; //@line 4051 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $461=(($460+4)|0); //@line 4051 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $462=HEAP32[(($461)>>2)]; //@line 4051 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $463=((($462)+($459))|0); //@line 4051 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($461)>>2)]=$463; //@line 4051 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $464=$2; //@line 4052 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $465=$tbase; //@line 4052 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $466=$oldbase; //@line 4052 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $467=$3; //@line 4052 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $468=_prepend_alloc($464, $465, $466, $467); //@line 4052 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $1=$468; //@line 4052 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 93; break; //@line 4052 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 86: 
      var $470=$2; //@line 4055 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $471=$tbase; //@line 4055 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $472=$tsize; //@line 4055 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $473=$mmap_flag; //@line 4055 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      _add_segment($470, $471, $472, $473); //@line 4055 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 87; break;
    case 87: 
      __label__ = 88; break;
    case 88: 
      __label__ = 89; break;
    case 89: 
      var $477=$3; //@line 4059 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $478=$2; //@line 4059 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $479=(($478+12)|0); //@line 4059 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $480=HEAPU32[(($479)>>2)]; //@line 4059 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $481=(($477)>>>0) < (($480)>>>0); //@line 4059 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($481) { __label__ = 90; break; } else { __label__ = 91; break; } //@line 4059 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 90: 
      var $483=$3; //@line 4060 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $484=$2; //@line 4060 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $485=(($484+12)|0); //@line 4060 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $486=HEAP32[(($485)>>2)]; //@line 4060 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $487=((($486)-($483))|0); //@line 4060 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($485)>>2)]=$487; //@line 4060 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $rsize=$487; //@line 4060 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $488=$2; //@line 4061 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $489=(($488+24)|0); //@line 4061 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $490=HEAP32[(($489)>>2)]; //@line 4061 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $p=$490; //@line 4061 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $491=$p; //@line 4062 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $492=$491; //@line 4062 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $493=$3; //@line 4062 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $494=(($492+$493)|0); //@line 4062 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $495=$494; //@line 4062 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $496=$2; //@line 4062 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $497=(($496+24)|0); //@line 4062 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($497)>>2)]=$495; //@line 4062 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $r=$495; //@line 4062 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $498=$rsize; //@line 4063 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $499=$498 | 1; //@line 4063 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $500=$r; //@line 4063 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $501=(($500+4)|0); //@line 4063 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($501)>>2)]=$499; //@line 4063 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $502=$3; //@line 4064 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $503=$502 | 1; //@line 4064 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $504=$503 | 2; //@line 4064 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $505=$p; //@line 4064 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $506=(($505+4)|0); //@line 4064 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($506)>>2)]=$504; //@line 4064 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $507=$p; //@line 4067 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $508=$507; //@line 4067 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $509=(($508+8)|0); //@line 4067 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $1=$509; //@line 4067 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 93; break; //@line 4067 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 91: 
      __label__ = 92; break; //@line 4069 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 92: 
      var $512=___errno(); //@line 4071 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($512)>>2)]=12; //@line 4071 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $1=0; //@line 4072 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 93; break; //@line 4072 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 93: 
      var $514=$1; //@line 4073 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      ;
      return $514; //@line 4073 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    default: assert(0, "bad label: " + __label__);
  }
}
_sys_alloc["X"]=1;

function _free($mem) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $p;
      var $psize;
      var $next;
      var $prevsize;
      var $prev;
      var $F;
      var $B;
      var $I;
      var $TP;
      var $XP;
      var $R;
      var $F1;
      var $RP;
      var $CP;
      var $H;
      var $C0;
      var $C1;
      var $tsize;
      var $dsize;
      var $nsize;
      var $F2;
      var $B3;
      var $I4;
      var $TP5;
      var $XP6;
      var $R7;
      var $F8;
      var $RP9;
      var $CP10;
      var $H11;
      var $C012;
      var $C113;
      var $I14;
      var $B15;
      var $F16;
      var $tp;
      var $H17;
      var $I18;
      var $X;
      var $Y;
      var $N;
      var $K;
      var $T;
      var $K19;
      var $C;
      var $F20;
      $1=$mem;
      var $2=$1; //@line 4740 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $3=(($2)|0)!=0; //@line 4740 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($3) { __label__ = 3; break; } else { __label__ = 197; break; } //@line 4740 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 3: 
      var $5=$1; //@line 4741 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $6=((($5)-(8))|0); //@line 4741 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $7=$6; //@line 4741 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $p=$7; //@line 4741 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $8=$p; //@line 4753 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $9=$8; //@line 4753 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $10=HEAPU32[((((__gm_+16)|0))>>2)]; //@line 4753 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $11=(($9)>>>0) >= (($10)>>>0); //@line 4753 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($11) { __label__ = 4; break; } else { var $19 = 0;__label__ = 5; break; } //@line 4753 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 4: 
      var $13=$p; //@line 4753 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $14=(($13+4)|0); //@line 4753 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $15=HEAP32[(($14)>>2)]; //@line 4753 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $16=$15 & 3; //@line 4753 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $17=(($16)|0)!=1; //@line 4753 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $19 = $17;__label__ = 5; break;
    case 5: 
      var $19;
      var $20=(($19)&1);
      var $21=(($20)==(1));
      var $22=(($21)|0)!=0;
      if ($22) { __label__ = 6; break; } else { __label__ = 194; break; }
    case 6: 
      var $24=$p; //@line 4754 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $25=(($24+4)|0); //@line 4754 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $26=HEAP32[(($25)>>2)]; //@line 4754 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $27=$26 & -8; //@line 4754 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $psize=$27; //@line 4754 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $28=$p; //@line 4755 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $29=$28; //@line 4755 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $30=$psize; //@line 4755 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $31=(($29+$30)|0); //@line 4755 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $32=$31; //@line 4755 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $next=$32; //@line 4755 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $33=$p; //@line 4756 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $34=(($33+4)|0); //@line 4756 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $35=HEAP32[(($34)>>2)]; //@line 4756 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $36=$35 & 1; //@line 4756 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $37=(($36)|0)!=0; //@line 4756 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($37) { __label__ = 78; break; } else { __label__ = 7; break; } //@line 4756 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 7: 
      var $39=$p; //@line 4757 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $40=(($39)|0); //@line 4757 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $41=HEAP32[(($40)>>2)]; //@line 4757 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $prevsize=$41; //@line 4757 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $42=$p; //@line 4758 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $43=(($42+4)|0); //@line 4758 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $44=HEAP32[(($43)>>2)]; //@line 4758 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $45=$44 & 3; //@line 4758 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $46=(($45)|0)==0; //@line 4758 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($46) { __label__ = 8; break; } else { __label__ = 9; break; } //@line 4758 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 8: 
      var $48=$prevsize; //@line 4759 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $49=((($48)+(16))|0); //@line 4759 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $50=$psize; //@line 4759 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $51=((($50)+($49))|0); //@line 4759 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $psize=$51; //@line 4759 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 196; break; //@line 4762 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 9: 
      var $53=$p; //@line 4765 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $54=$53; //@line 4765 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $55=$prevsize; //@line 4765 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $56=(((-$55))|0); //@line 4765 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $57=(($54+$56)|0); //@line 4765 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $58=$57; //@line 4765 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $prev=$58; //@line 4765 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $59=$prevsize; //@line 4766 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $60=$psize; //@line 4766 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $61=((($60)+($59))|0); //@line 4766 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $psize=$61; //@line 4766 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $62=$prev; //@line 4767 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $p=$62; //@line 4767 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $63=$prev; //@line 4768 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $64=$63; //@line 4768 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $65=HEAPU32[((((__gm_+16)|0))>>2)]; //@line 4768 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $66=(($64)>>>0) >= (($65)>>>0); //@line 4768 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $67=(($66)&1); //@line 4768 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $68=(($67)==(1)); //@line 4768 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $69=(($68)|0)!=0; //@line 4768 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($69) { __label__ = 10; break; } else { __label__ = 75; break; } //@line 4768 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 10: 
      var $71=$p; //@line 4769 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $72=HEAP32[((((__gm_+20)|0))>>2)]; //@line 4769 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $73=(($71)|0)!=(($72)|0); //@line 4769 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($73) { __label__ = 11; break; } else { __label__ = 71; break; } //@line 4769 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 11: 
      var $75=$prevsize; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $76=$75 >>> 3; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $77=(($76)>>>0) < 32; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($77) { __label__ = 12; break; } else { __label__ = 24; break; } //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 12: 
      var $79=$p; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $80=(($79+8)|0); //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $81=HEAP32[(($80)>>2)]; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $F=$81; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $82=$p; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $83=(($82+12)|0); //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $84=HEAP32[(($83)>>2)]; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $B=$84; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $85=$prevsize; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $86=$85 >>> 3; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $I=$86; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $87=$F; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $88=$B; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $89=(($87)|0)==(($88)|0); //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($89) { __label__ = 13; break; } else { __label__ = 14; break; } //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 13: 
      var $91=$I; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $92=1 << $91; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $93=$92 ^ -1; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $94=HEAP32[((((__gm_)|0))>>2)]; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $95=$94 & $93; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[((((__gm_)|0))>>2)]=$95; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 23; break; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 14: 
      var $97=$F; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $98=$I; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $99=$98 << 1; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $100=((((__gm_+40)|0)+($99<<2))|0); //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $101=$100; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $102=$101; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $103=(($97)|0)==(($102)|0); //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($103) { __label__ = 16; break; } else { __label__ = 15; break; } //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 15: 
      var $105=$F; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $106=$105; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $107=HEAPU32[((((__gm_+16)|0))>>2)]; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $108=(($106)>>>0) >= (($107)>>>0); //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($108) { __label__ = 16; break; } else { var $125 = 0;__label__ = 19; break; } //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 16: 
      var $110=$B; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $111=$I; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $112=$111 << 1; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $113=((((__gm_+40)|0)+($112<<2))|0); //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $114=$113; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $115=$114; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $116=(($110)|0)==(($115)|0); //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($116) { var $123 = 1;__label__ = 18; break; } else { __label__ = 17; break; } //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 17: 
      var $118=$B; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $119=$118; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $120=HEAPU32[((((__gm_+16)|0))>>2)]; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $121=(($119)>>>0) >= (($120)>>>0); //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $123 = $121;__label__ = 18; break; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 18: 
      var $123;
      var $125 = $123;__label__ = 19; break;
    case 19: 
      var $125;
      var $126=(($125)&1);
      var $127=(($126)==(1));
      var $128=(($127)|0)!=0;
      if ($128) { __label__ = 20; break; } else { __label__ = 21; break; }
    case 20: 
      var $130=$B; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $131=$F; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $132=(($131+12)|0); //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($132)>>2)]=$130; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $133=$F; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $134=$B; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $135=(($134+8)|0); //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($135)>>2)]=$133; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 22; break; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 21: 
      _abort(); //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      throw "Reached an unreachable!" //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 22: 
      __label__ = 23; break;
    case 23: 
      __label__ = 70; break; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 24: 
      var $140=$p; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $141=$140; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $TP=$141; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $142=$TP; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $143=(($142+24)|0); //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $144=HEAP32[(($143)>>2)]; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $XP=$144; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $145=$TP; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $146=(($145+12)|0); //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $147=HEAP32[(($146)>>2)]; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $148=$TP; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $149=(($147)|0)!=(($148)|0); //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($149) { __label__ = 25; break; } else { __label__ = 29; break; } //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 25: 
      var $151=$TP; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $152=(($151+8)|0); //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $153=HEAP32[(($152)>>2)]; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $F1=$153; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $154=$TP; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $155=(($154+12)|0); //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $156=HEAP32[(($155)>>2)]; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $R=$156; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $157=$F1; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $158=$157; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $159=HEAPU32[((((__gm_+16)|0))>>2)]; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $160=(($158)>>>0) >= (($159)>>>0); //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $161=(($160)&1); //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $162=(($161)==(1)); //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $163=(($162)|0)!=0; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($163) { __label__ = 26; break; } else { __label__ = 27; break; } //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 26: 
      var $165=$R; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $166=$F1; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $167=(($166+12)|0); //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($167)>>2)]=$165; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $168=$F1; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $169=$R; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $170=(($169+8)|0); //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($170)>>2)]=$168; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 28; break; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 27: 
      _abort(); //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      throw "Reached an unreachable!" //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 28: 
      __label__ = 41; break; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 29: 
      var $174=$TP; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $175=(($174+16)|0); //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $176=(($175+4)|0); //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $RP=$176; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $177=HEAP32[(($176)>>2)]; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $R=$177; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $178=(($177)|0)!=0; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($178) { __label__ = 31; break; } else { __label__ = 30; break; } //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 30: 
      var $180=$TP; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $181=(($180+16)|0); //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $182=(($181)|0); //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $RP=$182; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $183=HEAP32[(($182)>>2)]; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $R=$183; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $184=(($183)|0)!=0; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($184) { __label__ = 31; break; } else { __label__ = 40; break; } //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 31: 
      __label__ = 32; break; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 32: 
      var $187=$R; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $188=(($187+16)|0); //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $189=(($188+4)|0); //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $CP=$189; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $190=HEAP32[(($189)>>2)]; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $191=(($190)|0)!=0; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($191) { var $199 = 1;__label__ = 34; break; } else { __label__ = 33; break; } //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 33: 
      var $193=$R; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $194=(($193+16)|0); //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $195=(($194)|0); //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $CP=$195; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $196=HEAP32[(($195)>>2)]; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $197=(($196)|0)!=0; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $199 = $197;__label__ = 34; break; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 34: 
      var $199;
      if ($199) { __label__ = 35; break; } else { __label__ = 36; break; } //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 35: 
      var $201=$CP; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $RP=$201; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $202=HEAP32[(($201)>>2)]; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $R=$202; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 32; break; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 36: 
      var $204=$RP; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $205=$204; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $206=HEAPU32[((((__gm_+16)|0))>>2)]; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $207=(($205)>>>0) >= (($206)>>>0); //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $208=(($207)&1); //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $209=(($208)==(1)); //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $210=(($209)|0)!=0; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($210) { __label__ = 37; break; } else { __label__ = 38; break; } //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 37: 
      var $212=$RP; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($212)>>2)]=0; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 39; break; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 38: 
      _abort(); //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      throw "Reached an unreachable!" //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 39: 
      __label__ = 40; break; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 40: 
      __label__ = 41; break;
    case 41: 
      var $217=$XP; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $218=(($217)|0)!=0; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($218) { __label__ = 42; break; } else { __label__ = 69; break; } //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 42: 
      var $220=$TP; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $221=(($220+28)|0); //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $222=HEAP32[(($221)>>2)]; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $223=((((__gm_+304)|0)+($222<<2))|0); //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $H=$223; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $224=$TP; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $225=$H; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $226=HEAP32[(($225)>>2)]; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $227=(($224)|0)==(($226)|0); //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($227) { __label__ = 43; break; } else { __label__ = 46; break; } //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 43: 
      var $229=$R; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $230=$H; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($230)>>2)]=$229; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $231=(($229)|0)==0; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($231) { __label__ = 44; break; } else { __label__ = 45; break; } //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 44: 
      var $233=$TP; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $234=(($233+28)|0); //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $235=HEAP32[(($234)>>2)]; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $236=1 << $235; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $237=$236 ^ -1; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $238=HEAP32[((((__gm_+4)|0))>>2)]; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $239=$238 & $237; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[((((__gm_+4)|0))>>2)]=$239; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 45; break; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 45: 
      __label__ = 53; break; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 46: 
      var $242=$XP; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $243=$242; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $244=HEAPU32[((((__gm_+16)|0))>>2)]; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $245=(($243)>>>0) >= (($244)>>>0); //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $246=(($245)&1); //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $247=(($246)==(1)); //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $248=(($247)|0)!=0; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($248) { __label__ = 47; break; } else { __label__ = 51; break; } //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 47: 
      var $250=$XP; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $251=(($250+16)|0); //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $252=(($251)|0); //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $253=HEAP32[(($252)>>2)]; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $254=$TP; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $255=(($253)|0)==(($254)|0); //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($255) { __label__ = 48; break; } else { __label__ = 49; break; } //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 48: 
      var $257=$R; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $258=$XP; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $259=(($258+16)|0); //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $260=(($259)|0); //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($260)>>2)]=$257; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 50; break; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 49: 
      var $262=$R; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $263=$XP; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $264=(($263+16)|0); //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $265=(($264+4)|0); //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($265)>>2)]=$262; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 50; break;
    case 50: 
      __label__ = 52; break; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 51: 
      _abort(); //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      throw "Reached an unreachable!" //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 52: 
      __label__ = 53; break;
    case 53: 
      var $270=$R; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $271=(($270)|0)!=0; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($271) { __label__ = 54; break; } else { __label__ = 68; break; } //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 54: 
      var $273=$R; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $274=$273; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $275=HEAPU32[((((__gm_+16)|0))>>2)]; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $276=(($274)>>>0) >= (($275)>>>0); //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $277=(($276)&1); //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $278=(($277)==(1)); //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $279=(($278)|0)!=0; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($279) { __label__ = 55; break; } else { __label__ = 66; break; } //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 55: 
      var $281=$XP; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $282=$R; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $283=(($282+24)|0); //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($283)>>2)]=$281; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $284=$TP; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $285=(($284+16)|0); //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $286=(($285)|0); //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $287=HEAP32[(($286)>>2)]; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $C0=$287; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $288=(($287)|0)!=0; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($288) { __label__ = 56; break; } else { __label__ = 60; break; } //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 56: 
      var $290=$C0; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $291=$290; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $292=HEAPU32[((((__gm_+16)|0))>>2)]; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $293=(($291)>>>0) >= (($292)>>>0); //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $294=(($293)&1); //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $295=(($294)==(1)); //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $296=(($295)|0)!=0; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($296) { __label__ = 57; break; } else { __label__ = 58; break; } //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 57: 
      var $298=$C0; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $299=$R; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $300=(($299+16)|0); //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $301=(($300)|0); //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($301)>>2)]=$298; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $302=$R; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $303=$C0; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $304=(($303+24)|0); //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($304)>>2)]=$302; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 59; break; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 58: 
      _abort(); //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      throw "Reached an unreachable!" //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 59: 
      __label__ = 60; break; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 60: 
      var $308=$TP; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $309=(($308+16)|0); //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $310=(($309+4)|0); //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $311=HEAP32[(($310)>>2)]; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $C1=$311; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $312=(($311)|0)!=0; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($312) { __label__ = 61; break; } else { __label__ = 65; break; } //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 61: 
      var $314=$C1; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $315=$314; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $316=HEAPU32[((((__gm_+16)|0))>>2)]; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $317=(($315)>>>0) >= (($316)>>>0); //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $318=(($317)&1); //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $319=(($318)==(1)); //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $320=(($319)|0)!=0; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($320) { __label__ = 62; break; } else { __label__ = 63; break; } //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 62: 
      var $322=$C1; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $323=$R; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $324=(($323+16)|0); //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $325=(($324+4)|0); //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($325)>>2)]=$322; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $326=$R; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $327=$C1; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $328=(($327+24)|0); //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($328)>>2)]=$326; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 64; break; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 63: 
      _abort(); //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      throw "Reached an unreachable!" //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 64: 
      __label__ = 65; break; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 65: 
      __label__ = 67; break; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 66: 
      _abort(); //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      throw "Reached an unreachable!" //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 67: 
      __label__ = 68; break; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 68: 
      __label__ = 69; break; //@line 4770 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 69: 
      __label__ = 70; break;
    case 70: 
      __label__ = 74; break; //@line 4771 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 71: 
      var $338=$next; //@line 4772 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $339=(($338+4)|0); //@line 4772 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $340=HEAP32[(($339)>>2)]; //@line 4772 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $341=$340 & 3; //@line 4772 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $342=(($341)|0)==3; //@line 4772 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($342) { __label__ = 72; break; } else { __label__ = 73; break; } //@line 4772 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 72: 
      var $344=$psize; //@line 4773 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[((((__gm_+8)|0))>>2)]=$344; //@line 4773 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $345=$next; //@line 4774 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $346=(($345+4)|0); //@line 4774 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $347=HEAP32[(($346)>>2)]; //@line 4774 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $348=$347 & -2; //@line 4774 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($346)>>2)]=$348; //@line 4774 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $349=$psize; //@line 4774 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $350=$349 | 1; //@line 4774 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $351=$p; //@line 4774 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $352=(($351+4)|0); //@line 4774 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($352)>>2)]=$350; //@line 4774 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $353=$psize; //@line 4774 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $354=$p; //@line 4774 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $355=$354; //@line 4774 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $356=$psize; //@line 4774 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $357=(($355+$356)|0); //@line 4774 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $358=$357; //@line 4774 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $359=(($358)|0); //@line 4774 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($359)>>2)]=$353; //@line 4774 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 196; break; //@line 4775 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 73: 
      __label__ = 74; break;
    case 74: 
      __label__ = 76; break; //@line 4777 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 75: 
      __label__ = 195; break; //@line 4779 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 76: 
      __label__ = 77; break;
    case 77: 
      __label__ = 78; break; //@line 4781 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 78: 
      var $366=$p; //@line 4783 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $367=$366; //@line 4783 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $368=$next; //@line 4783 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $369=$368; //@line 4783 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $370=(($367)>>>0) < (($369)>>>0); //@line 4783 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($370) { __label__ = 79; break; } else { var $378 = 0;__label__ = 80; break; } //@line 4783 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 79: 
      var $372=$next; //@line 4783 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $373=(($372+4)|0); //@line 4783 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $374=HEAP32[(($373)>>2)]; //@line 4783 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $375=$374 & 1; //@line 4783 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $376=(($375)|0)!=0; //@line 4783 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $378 = $376;__label__ = 80; break;
    case 80: 
      var $378;
      var $379=(($378)&1);
      var $380=(($379)==(1));
      var $381=(($380)|0)!=0;
      if ($381) { __label__ = 81; break; } else { __label__ = 193; break; }
    case 81: 
      var $383=$next; //@line 4784 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $384=(($383+4)|0); //@line 4784 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $385=HEAP32[(($384)>>2)]; //@line 4784 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $386=$385 & 2; //@line 4784 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $387=(($386)|0)!=0; //@line 4784 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($387) { __label__ = 154; break; } else { __label__ = 82; break; } //@line 4784 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 82: 
      var $389=$next; //@line 4785 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $390=HEAP32[((((__gm_+24)|0))>>2)]; //@line 4785 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $391=(($389)|0)==(($390)|0); //@line 4785 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($391) { __label__ = 83; break; } else { __label__ = 88; break; } //@line 4785 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 83: 
      var $393=$psize; //@line 4786 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $394=HEAP32[((((__gm_+12)|0))>>2)]; //@line 4786 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $395=((($394)+($393))|0); //@line 4786 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[((((__gm_+12)|0))>>2)]=$395; //@line 4786 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $tsize=$395; //@line 4786 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $396=$p; //@line 4787 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[((((__gm_+24)|0))>>2)]=$396; //@line 4787 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $397=$tsize; //@line 4788 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $398=$397 | 1; //@line 4788 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $399=$p; //@line 4788 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $400=(($399+4)|0); //@line 4788 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($400)>>2)]=$398; //@line 4788 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $401=$p; //@line 4789 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $402=HEAP32[((((__gm_+20)|0))>>2)]; //@line 4789 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $403=(($401)|0)==(($402)|0); //@line 4789 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($403) { __label__ = 84; break; } else { __label__ = 85; break; } //@line 4789 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 84: 
      HEAP32[((((__gm_+20)|0))>>2)]=0; //@line 4790 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[((((__gm_+8)|0))>>2)]=0; //@line 4791 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 85; break; //@line 4792 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 85: 
      var $406=$tsize; //@line 4793 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $407=HEAPU32[((((__gm_+28)|0))>>2)]; //@line 4793 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $408=(($406)>>>0) > (($407)>>>0); //@line 4793 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($408) { __label__ = 86; break; } else { __label__ = 87; break; } //@line 4793 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 86: 
      var $410=_sys_trim(__gm_, 0); //@line 4794 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 87; break; //@line 4794 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 87: 
      __label__ = 196; break; //@line 4795 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 88: 
      var $413=$next; //@line 4797 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $414=HEAP32[((((__gm_+20)|0))>>2)]; //@line 4797 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $415=(($413)|0)==(($414)|0); //@line 4797 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($415) { __label__ = 89; break; } else { __label__ = 90; break; } //@line 4797 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 89: 
      var $417=$psize; //@line 4798 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $418=HEAP32[((((__gm_+8)|0))>>2)]; //@line 4798 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $419=((($418)+($417))|0); //@line 4798 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[((((__gm_+8)|0))>>2)]=$419; //@line 4798 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $dsize=$419; //@line 4798 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $420=$p; //@line 4799 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[((((__gm_+20)|0))>>2)]=$420; //@line 4799 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $421=$dsize; //@line 4800 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $422=$421 | 1; //@line 4800 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $423=$p; //@line 4800 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $424=(($423+4)|0); //@line 4800 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($424)>>2)]=$422; //@line 4800 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $425=$dsize; //@line 4800 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $426=$p; //@line 4800 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $427=$426; //@line 4800 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $428=$dsize; //@line 4800 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $429=(($427+$428)|0); //@line 4800 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $430=$429; //@line 4800 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $431=(($430)|0); //@line 4800 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($431)>>2)]=$425; //@line 4800 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 196; break; //@line 4801 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 90: 
      var $433=$next; //@line 4804 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $434=(($433+4)|0); //@line 4804 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $435=HEAP32[(($434)>>2)]; //@line 4804 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $436=$435 & -8; //@line 4804 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $nsize=$436; //@line 4804 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $437=$nsize; //@line 4805 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $438=$psize; //@line 4805 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $439=((($438)+($437))|0); //@line 4805 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $psize=$439; //@line 4805 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $440=$nsize; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $441=$440 >>> 3; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $442=(($441)>>>0) < 32; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($442) { __label__ = 91; break; } else { __label__ = 103; break; } //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 91: 
      var $444=$next; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $445=(($444+8)|0); //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $446=HEAP32[(($445)>>2)]; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $F2=$446; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $447=$next; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $448=(($447+12)|0); //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $449=HEAP32[(($448)>>2)]; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $B3=$449; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $450=$nsize; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $451=$450 >>> 3; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $I4=$451; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $452=$F2; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $453=$B3; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $454=(($452)|0)==(($453)|0); //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($454) { __label__ = 92; break; } else { __label__ = 93; break; } //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 92: 
      var $456=$I4; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $457=1 << $456; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $458=$457 ^ -1; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $459=HEAP32[((((__gm_)|0))>>2)]; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $460=$459 & $458; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[((((__gm_)|0))>>2)]=$460; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 102; break; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 93: 
      var $462=$F2; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $463=$I4; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $464=$463 << 1; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $465=((((__gm_+40)|0)+($464<<2))|0); //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $466=$465; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $467=$466; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $468=(($462)|0)==(($467)|0); //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($468) { __label__ = 95; break; } else { __label__ = 94; break; } //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 94: 
      var $470=$F2; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $471=$470; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $472=HEAPU32[((((__gm_+16)|0))>>2)]; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $473=(($471)>>>0) >= (($472)>>>0); //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($473) { __label__ = 95; break; } else { var $490 = 0;__label__ = 98; break; } //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 95: 
      var $475=$B3; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $476=$I4; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $477=$476 << 1; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $478=((((__gm_+40)|0)+($477<<2))|0); //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $479=$478; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $480=$479; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $481=(($475)|0)==(($480)|0); //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($481) { var $488 = 1;__label__ = 97; break; } else { __label__ = 96; break; } //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 96: 
      var $483=$B3; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $484=$483; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $485=HEAPU32[((((__gm_+16)|0))>>2)]; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $486=(($484)>>>0) >= (($485)>>>0); //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $488 = $486;__label__ = 97; break; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 97: 
      var $488;
      var $490 = $488;__label__ = 98; break;
    case 98: 
      var $490;
      var $491=(($490)&1);
      var $492=(($491)==(1));
      var $493=(($492)|0)!=0;
      if ($493) { __label__ = 99; break; } else { __label__ = 100; break; }
    case 99: 
      var $495=$B3; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $496=$F2; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $497=(($496+12)|0); //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($497)>>2)]=$495; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $498=$F2; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $499=$B3; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $500=(($499+8)|0); //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($500)>>2)]=$498; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 101; break; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 100: 
      _abort(); //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      throw "Reached an unreachable!" //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 101: 
      __label__ = 102; break;
    case 102: 
      __label__ = 149; break; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 103: 
      var $505=$next; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $506=$505; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $TP5=$506; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $507=$TP5; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $508=(($507+24)|0); //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $509=HEAP32[(($508)>>2)]; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $XP6=$509; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $510=$TP5; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $511=(($510+12)|0); //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $512=HEAP32[(($511)>>2)]; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $513=$TP5; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $514=(($512)|0)!=(($513)|0); //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($514) { __label__ = 104; break; } else { __label__ = 108; break; } //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 104: 
      var $516=$TP5; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $517=(($516+8)|0); //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $518=HEAP32[(($517)>>2)]; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $F8=$518; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $519=$TP5; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $520=(($519+12)|0); //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $521=HEAP32[(($520)>>2)]; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $R7=$521; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $522=$F8; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $523=$522; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $524=HEAPU32[((((__gm_+16)|0))>>2)]; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $525=(($523)>>>0) >= (($524)>>>0); //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $526=(($525)&1); //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $527=(($526)==(1)); //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $528=(($527)|0)!=0; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($528) { __label__ = 105; break; } else { __label__ = 106; break; } //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 105: 
      var $530=$R7; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $531=$F8; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $532=(($531+12)|0); //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($532)>>2)]=$530; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $533=$F8; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $534=$R7; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $535=(($534+8)|0); //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($535)>>2)]=$533; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 107; break; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 106: 
      _abort(); //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      throw "Reached an unreachable!" //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 107: 
      __label__ = 120; break; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 108: 
      var $539=$TP5; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $540=(($539+16)|0); //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $541=(($540+4)|0); //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $RP9=$541; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $542=HEAP32[(($541)>>2)]; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $R7=$542; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $543=(($542)|0)!=0; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($543) { __label__ = 110; break; } else { __label__ = 109; break; } //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 109: 
      var $545=$TP5; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $546=(($545+16)|0); //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $547=(($546)|0); //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $RP9=$547; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $548=HEAP32[(($547)>>2)]; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $R7=$548; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $549=(($548)|0)!=0; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($549) { __label__ = 110; break; } else { __label__ = 119; break; } //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 110: 
      __label__ = 111; break; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 111: 
      var $552=$R7; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $553=(($552+16)|0); //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $554=(($553+4)|0); //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $CP10=$554; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $555=HEAP32[(($554)>>2)]; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $556=(($555)|0)!=0; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($556) { var $564 = 1;__label__ = 113; break; } else { __label__ = 112; break; } //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 112: 
      var $558=$R7; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $559=(($558+16)|0); //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $560=(($559)|0); //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $CP10=$560; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $561=HEAP32[(($560)>>2)]; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $562=(($561)|0)!=0; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $564 = $562;__label__ = 113; break; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 113: 
      var $564;
      if ($564) { __label__ = 114; break; } else { __label__ = 115; break; } //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 114: 
      var $566=$CP10; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $RP9=$566; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $567=HEAP32[(($566)>>2)]; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $R7=$567; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 111; break; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 115: 
      var $569=$RP9; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $570=$569; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $571=HEAPU32[((((__gm_+16)|0))>>2)]; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $572=(($570)>>>0) >= (($571)>>>0); //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $573=(($572)&1); //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $574=(($573)==(1)); //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $575=(($574)|0)!=0; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($575) { __label__ = 116; break; } else { __label__ = 117; break; } //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 116: 
      var $577=$RP9; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($577)>>2)]=0; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 118; break; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 117: 
      _abort(); //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      throw "Reached an unreachable!" //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 118: 
      __label__ = 119; break; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 119: 
      __label__ = 120; break;
    case 120: 
      var $582=$XP6; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $583=(($582)|0)!=0; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($583) { __label__ = 121; break; } else { __label__ = 148; break; } //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 121: 
      var $585=$TP5; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $586=(($585+28)|0); //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $587=HEAP32[(($586)>>2)]; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $588=((((__gm_+304)|0)+($587<<2))|0); //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $H11=$588; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $589=$TP5; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $590=$H11; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $591=HEAP32[(($590)>>2)]; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $592=(($589)|0)==(($591)|0); //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($592) { __label__ = 122; break; } else { __label__ = 125; break; } //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 122: 
      var $594=$R7; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $595=$H11; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($595)>>2)]=$594; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $596=(($594)|0)==0; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($596) { __label__ = 123; break; } else { __label__ = 124; break; } //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 123: 
      var $598=$TP5; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $599=(($598+28)|0); //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $600=HEAP32[(($599)>>2)]; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $601=1 << $600; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $602=$601 ^ -1; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $603=HEAP32[((((__gm_+4)|0))>>2)]; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $604=$603 & $602; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[((((__gm_+4)|0))>>2)]=$604; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 124; break; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 124: 
      __label__ = 132; break; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 125: 
      var $607=$XP6; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $608=$607; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $609=HEAPU32[((((__gm_+16)|0))>>2)]; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $610=(($608)>>>0) >= (($609)>>>0); //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $611=(($610)&1); //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $612=(($611)==(1)); //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $613=(($612)|0)!=0; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($613) { __label__ = 126; break; } else { __label__ = 130; break; } //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 126: 
      var $615=$XP6; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $616=(($615+16)|0); //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $617=(($616)|0); //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $618=HEAP32[(($617)>>2)]; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $619=$TP5; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $620=(($618)|0)==(($619)|0); //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($620) { __label__ = 127; break; } else { __label__ = 128; break; } //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 127: 
      var $622=$R7; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $623=$XP6; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $624=(($623+16)|0); //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $625=(($624)|0); //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($625)>>2)]=$622; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 129; break; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 128: 
      var $627=$R7; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $628=$XP6; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $629=(($628+16)|0); //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $630=(($629+4)|0); //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($630)>>2)]=$627; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 129; break;
    case 129: 
      __label__ = 131; break; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 130: 
      _abort(); //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      throw "Reached an unreachable!" //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 131: 
      __label__ = 132; break;
    case 132: 
      var $635=$R7; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $636=(($635)|0)!=0; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($636) { __label__ = 133; break; } else { __label__ = 147; break; } //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 133: 
      var $638=$R7; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $639=$638; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $640=HEAPU32[((((__gm_+16)|0))>>2)]; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $641=(($639)>>>0) >= (($640)>>>0); //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $642=(($641)&1); //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $643=(($642)==(1)); //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $644=(($643)|0)!=0; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($644) { __label__ = 134; break; } else { __label__ = 145; break; } //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 134: 
      var $646=$XP6; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $647=$R7; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $648=(($647+24)|0); //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($648)>>2)]=$646; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $649=$TP5; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $650=(($649+16)|0); //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $651=(($650)|0); //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $652=HEAP32[(($651)>>2)]; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $C012=$652; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $653=(($652)|0)!=0; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($653) { __label__ = 135; break; } else { __label__ = 139; break; } //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 135: 
      var $655=$C012; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $656=$655; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $657=HEAPU32[((((__gm_+16)|0))>>2)]; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $658=(($656)>>>0) >= (($657)>>>0); //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $659=(($658)&1); //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $660=(($659)==(1)); //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $661=(($660)|0)!=0; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($661) { __label__ = 136; break; } else { __label__ = 137; break; } //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 136: 
      var $663=$C012; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $664=$R7; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $665=(($664+16)|0); //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $666=(($665)|0); //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($666)>>2)]=$663; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $667=$R7; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $668=$C012; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $669=(($668+24)|0); //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($669)>>2)]=$667; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 138; break; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 137: 
      _abort(); //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      throw "Reached an unreachable!" //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 138: 
      __label__ = 139; break; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 139: 
      var $673=$TP5; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $674=(($673+16)|0); //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $675=(($674+4)|0); //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $676=HEAP32[(($675)>>2)]; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $C113=$676; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $677=(($676)|0)!=0; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($677) { __label__ = 140; break; } else { __label__ = 144; break; } //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 140: 
      var $679=$C113; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $680=$679; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $681=HEAPU32[((((__gm_+16)|0))>>2)]; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $682=(($680)>>>0) >= (($681)>>>0); //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $683=(($682)&1); //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $684=(($683)==(1)); //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $685=(($684)|0)!=0; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($685) { __label__ = 141; break; } else { __label__ = 142; break; } //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 141: 
      var $687=$C113; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $688=$R7; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $689=(($688+16)|0); //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $690=(($689+4)|0); //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($690)>>2)]=$687; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $691=$R7; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $692=$C113; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $693=(($692+24)|0); //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($693)>>2)]=$691; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 143; break; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 142: 
      _abort(); //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      throw "Reached an unreachable!" //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 143: 
      __label__ = 144; break; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 144: 
      __label__ = 146; break; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 145: 
      _abort(); //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      throw "Reached an unreachable!" //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 146: 
      __label__ = 147; break; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 147: 
      __label__ = 148; break; //@line 4806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 148: 
      __label__ = 149; break;
    case 149: 
      var $702=$psize; //@line 4807 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $703=$702 | 1; //@line 4807 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $704=$p; //@line 4807 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $705=(($704+4)|0); //@line 4807 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($705)>>2)]=$703; //@line 4807 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $706=$psize; //@line 4807 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $707=$p; //@line 4807 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $708=$707; //@line 4807 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $709=$psize; //@line 4807 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $710=(($708+$709)|0); //@line 4807 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $711=$710; //@line 4807 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $712=(($711)|0); //@line 4807 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($712)>>2)]=$706; //@line 4807 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $713=$p; //@line 4808 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $714=HEAP32[((((__gm_+20)|0))>>2)]; //@line 4808 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $715=(($713)|0)==(($714)|0); //@line 4808 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($715) { __label__ = 150; break; } else { __label__ = 151; break; } //@line 4808 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 150: 
      var $717=$psize; //@line 4809 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[((((__gm_+8)|0))>>2)]=$717; //@line 4809 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 196; break; //@line 4810 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 151: 
      __label__ = 152; break;
    case 152: 
      __label__ = 153; break;
    case 153: 
      __label__ = 155; break; //@line 4813 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 154: 
      var $722=$next; //@line 4815 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $723=(($722+4)|0); //@line 4815 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $724=HEAP32[(($723)>>2)]; //@line 4815 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $725=$724 & -2; //@line 4815 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($723)>>2)]=$725; //@line 4815 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $726=$psize; //@line 4815 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $727=$726 | 1; //@line 4815 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $728=$p; //@line 4815 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $729=(($728+4)|0); //@line 4815 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($729)>>2)]=$727; //@line 4815 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $730=$psize; //@line 4815 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $731=$p; //@line 4815 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $732=$731; //@line 4815 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $733=$psize; //@line 4815 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $734=(($732+$733)|0); //@line 4815 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $735=$734; //@line 4815 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $736=(($735)|0); //@line 4815 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($736)>>2)]=$730; //@line 4815 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 155; break;
    case 155: 
      var $738=$psize; //@line 4817 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $739=$738 >>> 3; //@line 4817 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $740=(($739)>>>0) < 32; //@line 4817 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($740) { __label__ = 156; break; } else { __label__ = 163; break; } //@line 4817 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 156: 
      var $742=$psize; //@line 4818 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $743=$742 >>> 3; //@line 4818 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $I14=$743; //@line 4818 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $744=$I14; //@line 4818 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $745=$744 << 1; //@line 4818 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $746=((((__gm_+40)|0)+($745<<2))|0); //@line 4818 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $747=$746; //@line 4818 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $748=$747; //@line 4818 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $B15=$748; //@line 4818 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $749=$B15; //@line 4818 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $F16=$749; //@line 4818 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $750=HEAP32[((((__gm_)|0))>>2)]; //@line 4818 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $751=$I14; //@line 4818 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $752=1 << $751; //@line 4818 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $753=$750 & $752; //@line 4818 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $754=(($753)|0)!=0; //@line 4818 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($754) { __label__ = 158; break; } else { __label__ = 157; break; } //@line 4818 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 157: 
      var $756=$I14; //@line 4818 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $757=1 << $756; //@line 4818 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $758=HEAP32[((((__gm_)|0))>>2)]; //@line 4818 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $759=$758 | $757; //@line 4818 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[((((__gm_)|0))>>2)]=$759; //@line 4818 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 162; break; //@line 4818 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 158: 
      var $761=$B15; //@line 4818 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $762=(($761+8)|0); //@line 4818 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $763=HEAP32[(($762)>>2)]; //@line 4818 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $764=$763; //@line 4818 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $765=HEAPU32[((((__gm_+16)|0))>>2)]; //@line 4818 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $766=(($764)>>>0) >= (($765)>>>0); //@line 4818 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $767=(($766)&1); //@line 4818 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $768=(($767)==(1)); //@line 4818 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $769=(($768)|0)!=0; //@line 4818 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($769) { __label__ = 159; break; } else { __label__ = 160; break; } //@line 4818 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 159: 
      var $771=$B15; //@line 4818 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $772=(($771+8)|0); //@line 4818 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $773=HEAP32[(($772)>>2)]; //@line 4818 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $F16=$773; //@line 4818 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 161; break; //@line 4818 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 160: 
      _abort(); //@line 4818 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      throw "Reached an unreachable!" //@line 4818 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 161: 
      __label__ = 162; break;
    case 162: 
      var $777=$p; //@line 4818 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $778=$B15; //@line 4818 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $779=(($778+8)|0); //@line 4818 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($779)>>2)]=$777; //@line 4818 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $780=$p; //@line 4818 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $781=$F16; //@line 4818 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $782=(($781+12)|0); //@line 4818 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($782)>>2)]=$780; //@line 4818 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $783=$F16; //@line 4818 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $784=$p; //@line 4818 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $785=(($784+8)|0); //@line 4818 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($785)>>2)]=$783; //@line 4818 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $786=$B15; //@line 4818 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $787=$p; //@line 4818 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $788=(($787+12)|0); //@line 4818 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($788)>>2)]=$786; //@line 4818 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 192; break; //@line 4820 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 163: 
      var $790=$p; //@line 4822 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $791=$790; //@line 4822 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $tp=$791; //@line 4822 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $792=$psize; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $793=$792 >>> 8; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $X=$793; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $794=$X; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $795=(($794)|0)==0; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($795) { __label__ = 164; break; } else { __label__ = 165; break; } //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 164: 
      $I18=0; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 169; break; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 165: 
      var $798=$X; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $799=(($798)>>>0) > 65535; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($799) { __label__ = 166; break; } else { __label__ = 167; break; } //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 166: 
      $I18=31; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 168; break; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 167: 
      var $802=$X; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $Y=$802; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $803=$Y; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $804=((($803)-(256))|0); //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $805=$804 >>> 16; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $806=$805 & 8; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $N=$806; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $807=$N; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $808=$Y; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $809=$808 << $807; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $Y=$809; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $810=((($809)-(4096))|0); //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $811=$810 >>> 16; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $812=$811 & 4; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $K=$812; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $813=$K; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $814=$N; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $815=((($814)+($813))|0); //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $N=$815; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $816=$K; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $817=$Y; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $818=$817 << $816; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $Y=$818; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $819=((($818)-(16384))|0); //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $820=$819 >>> 16; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $821=$820 & 2; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $K=$821; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $822=$N; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $823=((($822)+($821))|0); //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $N=$823; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $824=$N; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $825=(((14)-($824))|0); //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $826=$K; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $827=$Y; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $828=$827 << $826; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $Y=$828; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $829=$828 >>> 15; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $830=((($825)+($829))|0); //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $K=$830; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $831=$K; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $832=$831 << 1; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $833=$psize; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $834=$K; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $835=((($834)+(7))|0); //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $836=$833 >>> (($835)>>>0); //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $837=$836 & 1; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $838=((($832)+($837))|0); //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $I18=$838; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 168; break;
    case 168: 
      __label__ = 169; break;
    case 169: 
      var $841=$I18; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $842=((((__gm_+304)|0)+($841<<2))|0); //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $H17=$842; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $843=$I18; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $844=$tp; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $845=(($844+28)|0); //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($845)>>2)]=$843; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $846=$tp; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $847=(($846+16)|0); //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $848=(($847+4)|0); //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($848)>>2)]=0; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $849=$tp; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $850=(($849+16)|0); //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $851=(($850)|0); //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($851)>>2)]=0; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $852=HEAP32[((((__gm_+4)|0))>>2)]; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $853=$I18; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $854=1 << $853; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $855=$852 & $854; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $856=(($855)|0)!=0; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($856) { __label__ = 171; break; } else { __label__ = 170; break; } //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 170: 
      var $858=$I18; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $859=1 << $858; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $860=HEAP32[((((__gm_+4)|0))>>2)]; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $861=$860 | $859; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[((((__gm_+4)|0))>>2)]=$861; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $862=$tp; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $863=$H17; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($863)>>2)]=$862; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $864=$H17; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $865=$864; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $866=$tp; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $867=(($866+24)|0); //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($867)>>2)]=$865; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $868=$tp; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $869=$tp; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $870=(($869+12)|0); //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($870)>>2)]=$868; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $871=$tp; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $872=(($871+8)|0); //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($872)>>2)]=$868; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 189; break; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 171: 
      var $874=$H17; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $875=HEAP32[(($874)>>2)]; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $T=$875; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $876=$psize; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $877=$I18; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $878=(($877)|0)==31; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($878) { __label__ = 172; break; } else { __label__ = 173; break; } //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 172: 
      var $887 = 0;__label__ = 174; break; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 173: 
      var $881=$I18; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $882=$881 >>> 1; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $883=((($882)+(8))|0); //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $884=((($883)-(2))|0); //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $885=(((31)-($884))|0); //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $887 = $885;__label__ = 174; break; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 174: 
      var $887; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $888=$876 << $887; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $K19=$888; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 175; break; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 175: 
      var $890=$T; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $891=(($890+4)|0); //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $892=HEAP32[(($891)>>2)]; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $893=$892 & -8; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $894=$psize; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $895=(($893)|0)!=(($894)|0); //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($895) { __label__ = 176; break; } else { __label__ = 182; break; } //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 176: 
      var $897=$K19; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $898=$897 >>> 31; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $899=$898 & 1; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $900=$T; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $901=(($900+16)|0); //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $902=(($901+($899<<2))|0); //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $C=$902; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $903=$K19; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $904=$903 << 1; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $K19=$904; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $905=$C; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $906=HEAP32[(($905)>>2)]; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $907=(($906)|0)!=0; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($907) { __label__ = 177; break; } else { __label__ = 178; break; } //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 177: 
      var $909=$C; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $910=HEAP32[(($909)>>2)]; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $T=$910; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 181; break; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 178: 
      var $912=$C; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $913=$912; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $914=HEAPU32[((((__gm_+16)|0))>>2)]; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $915=(($913)>>>0) >= (($914)>>>0); //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $916=(($915)&1); //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $917=(($916)==(1)); //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $918=(($917)|0)!=0; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($918) { __label__ = 179; break; } else { __label__ = 180; break; } //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 179: 
      var $920=$tp; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $921=$C; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($921)>>2)]=$920; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $922=$T; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $923=$tp; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $924=(($923+24)|0); //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($924)>>2)]=$922; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $925=$tp; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $926=$tp; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $927=(($926+12)|0); //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($927)>>2)]=$925; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $928=$tp; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $929=(($928+8)|0); //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($929)>>2)]=$925; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 188; break; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 180: 
      _abort(); //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      throw "Reached an unreachable!" //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 181: 
      __label__ = 187; break; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 182: 
      var $933=$T; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $934=(($933+8)|0); //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $935=HEAP32[(($934)>>2)]; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $F20=$935; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $936=$T; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $937=$936; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $938=HEAPU32[((((__gm_+16)|0))>>2)]; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $939=(($937)>>>0) >= (($938)>>>0); //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($939) { __label__ = 183; break; } else { var $946 = 0;__label__ = 184; break; } //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 183: 
      var $941=$F20; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $942=$941; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $943=HEAPU32[((((__gm_+16)|0))>>2)]; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $944=(($942)>>>0) >= (($943)>>>0); //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $946 = $944;__label__ = 184; break;
    case 184: 
      var $946;
      var $947=(($946)&1);
      var $948=(($947)==(1));
      var $949=(($948)|0)!=0;
      if ($949) { __label__ = 185; break; } else { __label__ = 186; break; }
    case 185: 
      var $951=$tp; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $952=$F20; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $953=(($952+12)|0); //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($953)>>2)]=$951; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $954=$T; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $955=(($954+8)|0); //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($955)>>2)]=$951; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $956=$F20; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $957=$tp; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $958=(($957+8)|0); //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($958)>>2)]=$956; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $959=$T; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $960=$tp; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $961=(($960+12)|0); //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($961)>>2)]=$959; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $962=$tp; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $963=(($962+24)|0); //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($963)>>2)]=0; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 188; break; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 186: 
      _abort(); //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      throw "Reached an unreachable!" //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 187: 
      __label__ = 175; break; //@line 4823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 188: 
      __label__ = 189; break;
    case 189: 
      var $968=HEAP32[((((__gm_+32)|0))>>2)]; //@line 4825 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $969=((($968)-(1))|0); //@line 4825 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[((((__gm_+32)|0))>>2)]=$969; //@line 4825 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $970=(($969)|0)==0; //@line 4825 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($970) { __label__ = 190; break; } else { __label__ = 191; break; } //@line 4825 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 190: 
      var $972=_release_unused_segments(__gm_); //@line 4826 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 191; break; //@line 4826 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 191: 
      __label__ = 192; break;
    case 192: 
      __label__ = 196; break; //@line 4828 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 193: 
      __label__ = 194; break; //@line 4830 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 194: 
      __label__ = 195; break; //@line 4830 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 195: 
      _abort(); //@line 4832 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      throw "Reached an unreachable!" //@line 4832 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 196: 
      __label__ = 197; break; //@line 4836 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 197: 
      ;
      return; //@line 4840 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    default: assert(0, "bad label: " + __label__);
  }
}
Module["_free"] = _free;_free["X"]=1;

function _sys_trim($m, $pad) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $released;
      var $unit;
      var $extra;
      var $sp;
      var $old_br;
      var $rel_br;
      var $new_br;
      $1=$m;
      $2=$pad;
      $released=0; //@line 4126 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $3=HEAP32[((((_mparams)|0))>>2)]; //@line 4127 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $4=(($3)|0)!=0; //@line 4127 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($4) { var $9 = 1;__label__ = 4; break; } else { __label__ = 3; break; } //@line 4127 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 3: 
      var $6=_init_mparams(); //@line 4127 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $7=(($6)|0)!=0; //@line 4127 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $9 = $7;__label__ = 4; break; //@line 4127 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 4: 
      var $9;
      var $10=(($9)&1); //@line 4127 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $11=$2; //@line 4128 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $12=(($11)>>>0) < 4294967232; //@line 4128 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($12) { __label__ = 5; break; } else { __label__ = 26; break; } //@line 4128 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 5: 
      var $14=$1; //@line 4128 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $15=(($14+24)|0); //@line 4128 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $16=HEAP32[(($15)>>2)]; //@line 4128 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $17=(($16)|0)!=0; //@line 4128 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($17) { __label__ = 6; break; } else { __label__ = 26; break; } //@line 4128 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 6: 
      var $19=$2; //@line 4129 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $20=((($19)+(40))|0); //@line 4129 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $2=$20; //@line 4129 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $21=$1; //@line 4131 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $22=(($21+12)|0); //@line 4131 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $23=HEAPU32[(($22)>>2)]; //@line 4131 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $24=$2; //@line 4131 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $25=(($23)>>>0) > (($24)>>>0); //@line 4131 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($25) { __label__ = 7; break; } else { __label__ = 22; break; } //@line 4131 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 7: 
      var $27=HEAP32[((((_mparams+8)|0))>>2)]; //@line 4133 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $unit=$27; //@line 4133 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $28=$1; //@line 4135 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $29=(($28+12)|0); //@line 4135 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $30=HEAP32[(($29)>>2)]; //@line 4135 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $31=$2; //@line 4135 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $32=((($30)-($31))|0); //@line 4135 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $33=$unit; //@line 4135 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $34=((($33)-(1))|0); //@line 4135 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $35=((($32)+($34))|0); //@line 4135 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $36=$unit; //@line 4135 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $37=Math.floor(((($35)>>>0))/((($36)>>>0))); //@line 4135 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $38=((($37)-(1))|0); //@line 4135 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $39=$unit; //@line 4135 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $40=((($38)*($39))|0); //@line 4135 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $extra=$40; //@line 4135 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $41=$1; //@line 4136 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $42=$1; //@line 4136 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $43=(($42+24)|0); //@line 4136 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $44=HEAP32[(($43)>>2)]; //@line 4136 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $45=$44; //@line 4136 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $46=_segment_holding($41, $45); //@line 4136 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $sp=$46; //@line 4136 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $47=$sp; //@line 4138 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $48=(($47+12)|0); //@line 4138 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $49=HEAP32[(($48)>>2)]; //@line 4138 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $50=$49 & 8; //@line 4138 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $51=(($50)|0)!=0; //@line 4138 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($51) { __label__ = 19; break; } else { __label__ = 8; break; } //@line 4138 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 8: 
      var $53=$sp; //@line 4139 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $54=(($53+12)|0); //@line 4139 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $55=HEAP32[(($54)>>2)]; //@line 4139 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $56=$55 & 0; //@line 4139 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $57=(($56)|0)!=0; //@line 4139 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($57) { __label__ = 9; break; } else { __label__ = 10; break; } //@line 4139 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 9: 
      __label__ = 18; break; //@line 4150 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 10: 
      var $60=$extra; //@line 4152 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $61=(($60)>>>0) >= 2147483647; //@line 4152 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($61) { __label__ = 11; break; } else { __label__ = 12; break; } //@line 4152 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 11: 
      var $63=$unit; //@line 4153 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $64=(((-2147483648)-($63))|0); //@line 4153 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $extra=$64; //@line 4153 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 12; break; //@line 4153 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 12: 
      var $66=_sbrk(0); //@line 4157 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $old_br=$66; //@line 4157 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $67=$old_br; //@line 4158 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $68=$sp; //@line 4158 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $69=(($68)|0); //@line 4158 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $70=HEAP32[(($69)>>2)]; //@line 4158 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $71=$sp; //@line 4158 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $72=(($71+4)|0); //@line 4158 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $73=HEAP32[(($72)>>2)]; //@line 4158 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $74=(($70+$73)|0); //@line 4158 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $75=(($67)|0)==(($74)|0); //@line 4158 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($75) { __label__ = 13; break; } else { __label__ = 17; break; } //@line 4158 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 13: 
      var $77=$extra; //@line 4159 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $78=(((-$77))|0); //@line 4159 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $79=_sbrk($78); //@line 4159 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $rel_br=$79; //@line 4159 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $80=_sbrk(0); //@line 4160 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $new_br=$80; //@line 4160 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $81=$rel_br; //@line 4161 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $82=(($81)|0)!=-1; //@line 4161 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($82) { __label__ = 14; break; } else { __label__ = 16; break; } //@line 4161 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 14: 
      var $84=$new_br; //@line 4161 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $85=$old_br; //@line 4161 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $86=(($84)>>>0) < (($85)>>>0); //@line 4161 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($86) { __label__ = 15; break; } else { __label__ = 16; break; } //@line 4161 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 15: 
      var $88=$old_br; //@line 4162 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $89=$new_br; //@line 4162 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $90=$88; //@line 4162 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $91=$89; //@line 4162 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $92=((($90)-($91))|0); //@line 4162 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $released=$92; //@line 4162 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 16; break; //@line 4162 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 16: 
      __label__ = 17; break; //@line 4163 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 17: 
      __label__ = 18; break;
    case 18: 
      __label__ = 19; break; //@line 4167 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 19: 
      var $97=$released; //@line 4169 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $98=(($97)|0)!=0; //@line 4169 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($98) { __label__ = 20; break; } else { __label__ = 21; break; } //@line 4169 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 20: 
      var $100=$released; //@line 4170 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $101=$sp; //@line 4170 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $102=(($101+4)|0); //@line 4170 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $103=HEAP32[(($102)>>2)]; //@line 4170 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $104=((($103)-($100))|0); //@line 4170 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($102)>>2)]=$104; //@line 4170 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $105=$released; //@line 4171 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $106=$1; //@line 4171 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $107=(($106+432)|0); //@line 4171 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $108=HEAP32[(($107)>>2)]; //@line 4171 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $109=((($108)-($105))|0); //@line 4171 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($107)>>2)]=$109; //@line 4171 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $110=$1; //@line 4172 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $111=$1; //@line 4172 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $112=(($111+24)|0); //@line 4172 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $113=HEAP32[(($112)>>2)]; //@line 4172 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $114=$1; //@line 4172 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $115=(($114+12)|0); //@line 4172 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $116=HEAP32[(($115)>>2)]; //@line 4172 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $117=$released; //@line 4172 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $118=((($116)-($117))|0); //@line 4172 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      _init_top($110, $113, $118); //@line 4172 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 21; break; //@line 4174 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 21: 
      __label__ = 22; break; //@line 4175 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 22: 
      var $121=$released; //@line 4182 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $122=(($121)|0)==0; //@line 4182 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($122) { __label__ = 23; break; } else { __label__ = 25; break; } //@line 4182 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 23: 
      var $124=$1; //@line 4182 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $125=(($124+12)|0); //@line 4182 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $126=HEAPU32[(($125)>>2)]; //@line 4182 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $127=$1; //@line 4182 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $128=(($127+28)|0); //@line 4182 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $129=HEAPU32[(($128)>>2)]; //@line 4182 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $130=(($126)>>>0) > (($129)>>>0); //@line 4182 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($130) { __label__ = 24; break; } else { __label__ = 25; break; } //@line 4182 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 24: 
      var $132=$1; //@line 4183 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $133=(($132+28)|0); //@line 4183 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($133)>>2)]=-1; //@line 4183 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 25; break; //@line 4183 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 25: 
      __label__ = 26; break; //@line 4184 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 26: 
      var $136=$released; //@line 4186 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $137=(($136)|0)!=0; //@line 4186 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $138=$137 ? 1 : 0; //@line 4186 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      ;
      return $138; //@line 4186 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    default: assert(0, "bad label: " + __label__);
  }
}
_sys_trim["X"]=1;

function _segment_holding($m, $addr) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $sp;
      $2=$m;
      $3=$addr;
      var $4=$2; //@line 2562 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $5=(($4+444)|0); //@line 2562 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $sp=$5; //@line 2562 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 3; break; //@line 2563 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 3: 
      var $7=$3; //@line 2564 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $8=$sp; //@line 2564 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $9=(($8)|0); //@line 2564 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $10=HEAPU32[(($9)>>2)]; //@line 2564 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $11=(($7)>>>0) >= (($10)>>>0); //@line 2564 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($11) { __label__ = 4; break; } else { __label__ = 6; break; } //@line 2564 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 4: 
      var $13=$3; //@line 2564 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $14=$sp; //@line 2564 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $15=(($14)|0); //@line 2564 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $16=HEAP32[(($15)>>2)]; //@line 2564 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $17=$sp; //@line 2564 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $18=(($17+4)|0); //@line 2564 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $19=HEAP32[(($18)>>2)]; //@line 2564 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $20=(($16+$19)|0); //@line 2564 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $21=(($13)>>>0) < (($20)>>>0); //@line 2564 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($21) { __label__ = 5; break; } else { __label__ = 6; break; } //@line 2564 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 5: 
      var $23=$sp; //@line 2565 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $1=$23; //@line 2565 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 9; break; //@line 2565 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 6: 
      var $25=$sp; //@line 2566 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $26=(($25+8)|0); //@line 2566 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $27=HEAP32[(($26)>>2)]; //@line 2566 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $sp=$27; //@line 2566 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $28=(($27)|0)==0; //@line 2566 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($28) { __label__ = 7; break; } else { __label__ = 8; break; } //@line 2566 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 7: 
      $1=0; //@line 2567 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 9; break; //@line 2567 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 8: 
      __label__ = 3; break; //@line 2568 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 9: 
      var $32=$1; //@line 2569 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      ;
      return $32; //@line 2569 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    default: assert(0, "bad label: " + __label__);
  }
}


function _release_unused_segments($m) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $released;
      var $nsegs;
      var $pred;
      var $sp;
      var $base;
      var $size;
      var $next;
      var $p;
      var $psize;
      var $tp;
      var $XP;
      var $R;
      var $F;
      var $RP;
      var $CP;
      var $H;
      var $C0;
      var $C1;
      var $H1;
      var $I;
      var $X;
      var $Y;
      var $N;
      var $K;
      var $T;
      var $K2;
      var $C;
      var $F3;
      $1=$m;
      $released=0; //@line 4079 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $nsegs=0; //@line 4080 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $2=$1; //@line 4081 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $3=(($2+444)|0); //@line 4081 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $pred=$3; //@line 4081 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $4=$pred; //@line 4082 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $5=(($4+8)|0); //@line 4082 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $6=HEAP32[(($5)>>2)]; //@line 4082 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $sp=$6; //@line 4082 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 3; break; //@line 4083 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 3: 
      var $8=$sp; //@line 4083 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $9=(($8)|0)!=0; //@line 4083 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($9) { __label__ = 4; break; } else { __label__ = 88; break; } //@line 4083 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 4: 
      var $11=$sp; //@line 4084 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $12=(($11)|0); //@line 4084 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $13=HEAP32[(($12)>>2)]; //@line 4084 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $base=$13; //@line 4084 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $14=$sp; //@line 4085 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $15=(($14+4)|0); //@line 4085 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $16=HEAP32[(($15)>>2)]; //@line 4085 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $size=$16; //@line 4085 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $17=$sp; //@line 4086 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $18=(($17+8)|0); //@line 4086 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $19=HEAP32[(($18)>>2)]; //@line 4086 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $next=$19; //@line 4086 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $20=$nsegs; //@line 4087 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $21=((($20)+(1))|0); //@line 4087 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $nsegs=$21; //@line 4087 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $22=$sp; //@line 4088 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $23=(($22+12)|0); //@line 4088 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $24=HEAP32[(($23)>>2)]; //@line 4088 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $25=$24 & 0; //@line 4088 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $26=(($25)|0)!=0; //@line 4088 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($26) { __label__ = 5; break; } else { __label__ = 87; break; } //@line 4088 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 5: 
      var $28=$sp; //@line 4088 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $29=(($28+12)|0); //@line 4088 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $30=HEAP32[(($29)>>2)]; //@line 4088 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $31=$30 & 8; //@line 4088 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $32=(($31)|0)!=0; //@line 4088 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($32) { __label__ = 87; break; } else { __label__ = 6; break; } //@line 4088 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 6: 
      var $34=$base; //@line 4089 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $35=$base; //@line 4089 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $36=(($35+8)|0); //@line 4089 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $37=$36; //@line 4089 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $38=$37 & 7; //@line 4089 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $39=(($38)|0)==0; //@line 4089 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($39) { __label__ = 7; break; } else { __label__ = 8; break; } //@line 4089 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 7: 
      var $49 = 0;__label__ = 9; break; //@line 4089 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 8: 
      var $42=$base; //@line 4089 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $43=(($42+8)|0); //@line 4089 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $44=$43; //@line 4089 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $45=$44 & 7; //@line 4089 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $46=(((8)-($45))|0); //@line 4089 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $47=$46 & 7; //@line 4089 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $49 = $47;__label__ = 9; break; //@line 4089 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 9: 
      var $49; //@line 4089 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $50=(($34+$49)|0); //@line 4089 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $51=$50; //@line 4089 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $p=$51; //@line 4089 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $52=$p; //@line 4090 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $53=(($52+4)|0); //@line 4090 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $54=HEAP32[(($53)>>2)]; //@line 4090 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $55=$54 & -8; //@line 4090 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $psize=$55; //@line 4090 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $56=$p; //@line 4092 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $57=(($56+4)|0); //@line 4092 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $58=HEAP32[(($57)>>2)]; //@line 4092 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $59=$58 & 3; //@line 4092 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $60=(($59)|0)!=1; //@line 4092 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($60) { __label__ = 86; break; } else { __label__ = 10; break; } //@line 4092 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 10: 
      var $62=$p; //@line 4092 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $63=$62; //@line 4092 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $64=$psize; //@line 4092 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $65=(($63+$64)|0); //@line 4092 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $66=$base; //@line 4092 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $67=$size; //@line 4092 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $68=(($66+$67)|0); //@line 4092 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $69=((($68)-(40))|0); //@line 4092 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $70=(($65)>>>0) >= (($69)>>>0); //@line 4092 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($70) { __label__ = 11; break; } else { __label__ = 86; break; } //@line 4092 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 11: 
      var $72=$p; //@line 4093 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $73=$72; //@line 4093 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $tp=$73; //@line 4093 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $74=$p; //@line 4095 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $75=$1; //@line 4095 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $76=(($75+20)|0); //@line 4095 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $77=HEAP32[(($76)>>2)]; //@line 4095 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $78=(($74)|0)==(($77)|0); //@line 4095 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($78) { __label__ = 12; break; } else { __label__ = 13; break; } //@line 4095 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 12: 
      var $80=$1; //@line 4096 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $81=(($80+20)|0); //@line 4096 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($81)>>2)]=0; //@line 4096 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $82=$1; //@line 4097 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $83=(($82+8)|0); //@line 4097 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($83)>>2)]=0; //@line 4097 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 59; break; //@line 4098 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 13: 
      var $85=$tp; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $86=(($85+24)|0); //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $87=HEAP32[(($86)>>2)]; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $XP=$87; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $88=$tp; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $89=(($88+12)|0); //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $90=HEAP32[(($89)>>2)]; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $91=$tp; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $92=(($90)|0)!=(($91)|0); //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($92) { __label__ = 14; break; } else { __label__ = 18; break; } //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 14: 
      var $94=$tp; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $95=(($94+8)|0); //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $96=HEAP32[(($95)>>2)]; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $F=$96; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $97=$tp; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $98=(($97+12)|0); //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $99=HEAP32[(($98)>>2)]; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $R=$99; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $100=$F; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $101=$100; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $102=$1; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $103=(($102+16)|0); //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $104=HEAPU32[(($103)>>2)]; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $105=(($101)>>>0) >= (($104)>>>0); //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $106=(($105)&1); //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $107=(($106)==(1)); //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $108=(($107)|0)!=0; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($108) { __label__ = 15; break; } else { __label__ = 16; break; } //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 15: 
      var $110=$R; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $111=$F; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $112=(($111+12)|0); //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($112)>>2)]=$110; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $113=$F; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $114=$R; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $115=(($114+8)|0); //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($115)>>2)]=$113; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 17; break; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 16: 
      _abort(); //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      throw "Reached an unreachable!" //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 17: 
      __label__ = 30; break; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 18: 
      var $119=$tp; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $120=(($119+16)|0); //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $121=(($120+4)|0); //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $RP=$121; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $122=HEAP32[(($121)>>2)]; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $R=$122; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $123=(($122)|0)!=0; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($123) { __label__ = 20; break; } else { __label__ = 19; break; } //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 19: 
      var $125=$tp; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $126=(($125+16)|0); //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $127=(($126)|0); //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $RP=$127; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $128=HEAP32[(($127)>>2)]; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $R=$128; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $129=(($128)|0)!=0; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($129) { __label__ = 20; break; } else { __label__ = 29; break; } //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 20: 
      __label__ = 21; break; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 21: 
      var $132=$R; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $133=(($132+16)|0); //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $134=(($133+4)|0); //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $CP=$134; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $135=HEAP32[(($134)>>2)]; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $136=(($135)|0)!=0; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($136) { var $144 = 1;__label__ = 23; break; } else { __label__ = 22; break; } //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 22: 
      var $138=$R; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $139=(($138+16)|0); //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $140=(($139)|0); //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $CP=$140; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $141=HEAP32[(($140)>>2)]; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $142=(($141)|0)!=0; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $144 = $142;__label__ = 23; break; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 23: 
      var $144;
      if ($144) { __label__ = 24; break; } else { __label__ = 25; break; } //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 24: 
      var $146=$CP; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $RP=$146; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $147=HEAP32[(($146)>>2)]; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $R=$147; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 21; break; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 25: 
      var $149=$RP; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $150=$149; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $151=$1; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $152=(($151+16)|0); //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $153=HEAPU32[(($152)>>2)]; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $154=(($150)>>>0) >= (($153)>>>0); //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $155=(($154)&1); //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $156=(($155)==(1)); //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $157=(($156)|0)!=0; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($157) { __label__ = 26; break; } else { __label__ = 27; break; } //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 26: 
      var $159=$RP; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($159)>>2)]=0; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 28; break; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 27: 
      _abort(); //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      throw "Reached an unreachable!" //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 28: 
      __label__ = 29; break; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 29: 
      __label__ = 30; break;
    case 30: 
      var $164=$XP; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $165=(($164)|0)!=0; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($165) { __label__ = 31; break; } else { __label__ = 58; break; } //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 31: 
      var $167=$tp; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $168=(($167+28)|0); //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $169=HEAP32[(($168)>>2)]; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $170=$1; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $171=(($170+304)|0); //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $172=(($171+($169<<2))|0); //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $H=$172; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $173=$tp; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $174=$H; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $175=HEAP32[(($174)>>2)]; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $176=(($173)|0)==(($175)|0); //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($176) { __label__ = 32; break; } else { __label__ = 35; break; } //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 32: 
      var $178=$R; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $179=$H; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($179)>>2)]=$178; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $180=(($178)|0)==0; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($180) { __label__ = 33; break; } else { __label__ = 34; break; } //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 33: 
      var $182=$tp; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $183=(($182+28)|0); //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $184=HEAP32[(($183)>>2)]; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $185=1 << $184; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $186=$185 ^ -1; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $187=$1; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $188=(($187+4)|0); //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $189=HEAP32[(($188)>>2)]; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $190=$189 & $186; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($188)>>2)]=$190; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 34; break; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 34: 
      __label__ = 42; break; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 35: 
      var $193=$XP; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $194=$193; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $195=$1; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $196=(($195+16)|0); //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $197=HEAPU32[(($196)>>2)]; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $198=(($194)>>>0) >= (($197)>>>0); //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $199=(($198)&1); //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $200=(($199)==(1)); //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $201=(($200)|0)!=0; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($201) { __label__ = 36; break; } else { __label__ = 40; break; } //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 36: 
      var $203=$XP; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $204=(($203+16)|0); //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $205=(($204)|0); //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $206=HEAP32[(($205)>>2)]; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $207=$tp; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $208=(($206)|0)==(($207)|0); //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($208) { __label__ = 37; break; } else { __label__ = 38; break; } //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 37: 
      var $210=$R; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $211=$XP; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $212=(($211+16)|0); //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $213=(($212)|0); //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($213)>>2)]=$210; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 39; break; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 38: 
      var $215=$R; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $216=$XP; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $217=(($216+16)|0); //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $218=(($217+4)|0); //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($218)>>2)]=$215; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 39; break;
    case 39: 
      __label__ = 41; break; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 40: 
      _abort(); //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      throw "Reached an unreachable!" //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 41: 
      __label__ = 42; break;
    case 42: 
      var $223=$R; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $224=(($223)|0)!=0; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($224) { __label__ = 43; break; } else { __label__ = 57; break; } //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 43: 
      var $226=$R; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $227=$226; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $228=$1; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $229=(($228+16)|0); //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $230=HEAPU32[(($229)>>2)]; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $231=(($227)>>>0) >= (($230)>>>0); //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $232=(($231)&1); //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $233=(($232)==(1)); //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $234=(($233)|0)!=0; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($234) { __label__ = 44; break; } else { __label__ = 55; break; } //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 44: 
      var $236=$XP; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $237=$R; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $238=(($237+24)|0); //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($238)>>2)]=$236; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $239=$tp; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $240=(($239+16)|0); //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $241=(($240)|0); //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $242=HEAP32[(($241)>>2)]; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $C0=$242; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $243=(($242)|0)!=0; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($243) { __label__ = 45; break; } else { __label__ = 49; break; } //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 45: 
      var $245=$C0; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $246=$245; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $247=$1; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $248=(($247+16)|0); //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $249=HEAPU32[(($248)>>2)]; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $250=(($246)>>>0) >= (($249)>>>0); //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $251=(($250)&1); //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $252=(($251)==(1)); //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $253=(($252)|0)!=0; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($253) { __label__ = 46; break; } else { __label__ = 47; break; } //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 46: 
      var $255=$C0; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $256=$R; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $257=(($256+16)|0); //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $258=(($257)|0); //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($258)>>2)]=$255; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $259=$R; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $260=$C0; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $261=(($260+24)|0); //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($261)>>2)]=$259; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 48; break; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 47: 
      _abort(); //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      throw "Reached an unreachable!" //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 48: 
      __label__ = 49; break; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 49: 
      var $265=$tp; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $266=(($265+16)|0); //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $267=(($266+4)|0); //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $268=HEAP32[(($267)>>2)]; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $C1=$268; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $269=(($268)|0)!=0; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($269) { __label__ = 50; break; } else { __label__ = 54; break; } //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 50: 
      var $271=$C1; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $272=$271; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $273=$1; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $274=(($273+16)|0); //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $275=HEAPU32[(($274)>>2)]; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $276=(($272)>>>0) >= (($275)>>>0); //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $277=(($276)&1); //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $278=(($277)==(1)); //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $279=(($278)|0)!=0; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($279) { __label__ = 51; break; } else { __label__ = 52; break; } //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 51: 
      var $281=$C1; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $282=$R; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $283=(($282+16)|0); //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $284=(($283+4)|0); //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($284)>>2)]=$281; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $285=$R; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $286=$C1; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $287=(($286+24)|0); //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($287)>>2)]=$285; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 53; break; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 52: 
      _abort(); //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      throw "Reached an unreachable!" //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 53: 
      __label__ = 54; break; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 54: 
      __label__ = 56; break; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 55: 
      _abort(); //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      throw "Reached an unreachable!" //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 56: 
      __label__ = 57; break; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 57: 
      __label__ = 58; break; //@line 4100 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 58: 
      __label__ = 59; break;
    case 59: 
      var $296=$psize; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $297=$296 >>> 8; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $X=$297; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $298=$X; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $299=(($298)|0)==0; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($299) { __label__ = 60; break; } else { __label__ = 61; break; } //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 60: 
      $I=0; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 65; break; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 61: 
      var $302=$X; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $303=(($302)>>>0) > 65535; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($303) { __label__ = 62; break; } else { __label__ = 63; break; } //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 62: 
      $I=31; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 64; break; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 63: 
      var $306=$X; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $Y=$306; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $307=$Y; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $308=((($307)-(256))|0); //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $309=$308 >>> 16; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $310=$309 & 8; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $N=$310; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $311=$N; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $312=$Y; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $313=$312 << $311; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $Y=$313; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $314=((($313)-(4096))|0); //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $315=$314 >>> 16; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $316=$315 & 4; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $K=$316; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $317=$K; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $318=$N; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $319=((($318)+($317))|0); //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $N=$319; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $320=$K; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $321=$Y; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $322=$321 << $320; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $Y=$322; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $323=((($322)-(16384))|0); //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $324=$323 >>> 16; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $325=$324 & 2; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $K=$325; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $326=$N; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $327=((($326)+($325))|0); //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $N=$327; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $328=$N; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $329=(((14)-($328))|0); //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $330=$K; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $331=$Y; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $332=$331 << $330; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $Y=$332; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $333=$332 >>> 15; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $334=((($329)+($333))|0); //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $K=$334; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $335=$K; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $336=$335 << 1; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $337=$psize; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $338=$K; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $339=((($338)+(7))|0); //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $340=$337 >>> (($339)>>>0); //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $341=$340 & 1; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $342=((($336)+($341))|0); //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $I=$342; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 64; break;
    case 64: 
      __label__ = 65; break;
    case 65: 
      var $345=$I; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $346=$1; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $347=(($346+304)|0); //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $348=(($347+($345<<2))|0); //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $H1=$348; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $349=$I; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $350=$tp; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $351=(($350+28)|0); //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($351)>>2)]=$349; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $352=$tp; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $353=(($352+16)|0); //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $354=(($353+4)|0); //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($354)>>2)]=0; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $355=$tp; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $356=(($355+16)|0); //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $357=(($356)|0); //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($357)>>2)]=0; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $358=$1; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $359=(($358+4)|0); //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $360=HEAP32[(($359)>>2)]; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $361=$I; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $362=1 << $361; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $363=$360 & $362; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $364=(($363)|0)!=0; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($364) { __label__ = 67; break; } else { __label__ = 66; break; } //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 66: 
      var $366=$I; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $367=1 << $366; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $368=$1; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $369=(($368+4)|0); //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $370=HEAP32[(($369)>>2)]; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $371=$370 | $367; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($369)>>2)]=$371; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $372=$tp; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $373=$H1; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($373)>>2)]=$372; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $374=$H1; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $375=$374; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $376=$tp; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $377=(($376+24)|0); //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($377)>>2)]=$375; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $378=$tp; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $379=$tp; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $380=(($379+12)|0); //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($380)>>2)]=$378; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $381=$tp; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $382=(($381+8)|0); //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($382)>>2)]=$378; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 85; break; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 67: 
      var $384=$H1; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $385=HEAP32[(($384)>>2)]; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $T=$385; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $386=$psize; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $387=$I; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $388=(($387)|0)==31; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($388) { __label__ = 68; break; } else { __label__ = 69; break; } //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 68: 
      var $397 = 0;__label__ = 70; break; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 69: 
      var $391=$I; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $392=$391 >>> 1; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $393=((($392)+(8))|0); //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $394=((($393)-(2))|0); //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $395=(((31)-($394))|0); //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $397 = $395;__label__ = 70; break; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 70: 
      var $397; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $398=$386 << $397; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $K2=$398; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 71; break; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 71: 
      var $400=$T; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $401=(($400+4)|0); //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $402=HEAP32[(($401)>>2)]; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $403=$402 & -8; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $404=$psize; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $405=(($403)|0)!=(($404)|0); //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($405) { __label__ = 72; break; } else { __label__ = 78; break; } //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 72: 
      var $407=$K2; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $408=$407 >>> 31; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $409=$408 & 1; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $410=$T; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $411=(($410+16)|0); //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $412=(($411+($409<<2))|0); //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $C=$412; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $413=$K2; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $414=$413 << 1; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $K2=$414; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $415=$C; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $416=HEAP32[(($415)>>2)]; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $417=(($416)|0)!=0; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($417) { __label__ = 73; break; } else { __label__ = 74; break; } //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 73: 
      var $419=$C; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $420=HEAP32[(($419)>>2)]; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $T=$420; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 77; break; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 74: 
      var $422=$C; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $423=$422; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $424=$1; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $425=(($424+16)|0); //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $426=HEAPU32[(($425)>>2)]; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $427=(($423)>>>0) >= (($426)>>>0); //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $428=(($427)&1); //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $429=(($428)==(1)); //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $430=(($429)|0)!=0; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($430) { __label__ = 75; break; } else { __label__ = 76; break; } //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 75: 
      var $432=$tp; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $433=$C; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($433)>>2)]=$432; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $434=$T; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $435=$tp; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $436=(($435+24)|0); //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($436)>>2)]=$434; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $437=$tp; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $438=$tp; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $439=(($438+12)|0); //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($439)>>2)]=$437; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $440=$tp; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $441=(($440+8)|0); //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($441)>>2)]=$437; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 84; break; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 76: 
      _abort(); //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      throw "Reached an unreachable!" //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 77: 
      __label__ = 83; break; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 78: 
      var $445=$T; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $446=(($445+8)|0); //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $447=HEAP32[(($446)>>2)]; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $F3=$447; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $448=$T; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $449=$448; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $450=$1; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $451=(($450+16)|0); //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $452=HEAPU32[(($451)>>2)]; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $453=(($449)>>>0) >= (($452)>>>0); //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($453) { __label__ = 79; break; } else { var $462 = 0;__label__ = 80; break; } //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 79: 
      var $455=$F3; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $456=$455; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $457=$1; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $458=(($457+16)|0); //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $459=HEAPU32[(($458)>>2)]; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $460=(($456)>>>0) >= (($459)>>>0); //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $462 = $460;__label__ = 80; break;
    case 80: 
      var $462;
      var $463=(($462)&1);
      var $464=(($463)==(1));
      var $465=(($464)|0)!=0;
      if ($465) { __label__ = 81; break; } else { __label__ = 82; break; }
    case 81: 
      var $467=$tp; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $468=$F3; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $469=(($468+12)|0); //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($469)>>2)]=$467; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $470=$T; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $471=(($470+8)|0); //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($471)>>2)]=$467; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $472=$F3; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $473=$tp; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $474=(($473+8)|0); //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($474)>>2)]=$472; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $475=$T; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $476=$tp; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $477=(($476+12)|0); //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($477)>>2)]=$475; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $478=$tp; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $479=(($478+24)|0); //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($479)>>2)]=0; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 84; break; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 82: 
      _abort(); //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      throw "Reached an unreachable!" //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 83: 
      __label__ = 71; break; //@line 4110 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 84: 
      __label__ = 85; break;
    case 85: 
      __label__ = 86; break; //@line 4112 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 86: 
      __label__ = 87; break; //@line 4113 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 87: 
      var $486=$sp; //@line 4116 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $pred=$486; //@line 4116 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $487=$next; //@line 4117 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $sp=$487; //@line 4117 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 3; break; //@line 4118 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 88: 
      var $489=$nsegs; //@line 4120 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $490=(($489)>>>0) > 4294967295; //@line 4120 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($490) { __label__ = 89; break; } else { __label__ = 90; break; } //@line 4120 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 89: 
      var $492=$nsegs; //@line 4120 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $495 = $492;__label__ = 91; break; //@line 4120 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 90: 
      var $495 = -1;__label__ = 91; break; //@line 4120 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 91: 
      var $495; //@line 4120 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $496=$1; //@line 4120 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $497=(($496+32)|0); //@line 4120 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($497)>>2)]=$495; //@line 4120 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $498=$released; //@line 4122 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      ;
      return $498; //@line 4122 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    default: assert(0, "bad label: " + __label__);
  }
}
_release_unused_segments["X"]=1;

function _init_mparams() {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $magic;
      var $psize;
      var $gsize;
      var $1=HEAP32[((((_mparams)|0))>>2)]; //@line 2965 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $2=(($1)|0)==0; //@line 2965 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($2) { __label__ = 3; break; } else { __label__ = 7; break; } //@line 2965 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 3: 
      var $4=_sysconf(8); //@line 2971 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $psize=$4; //@line 2971 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $5=$psize; //@line 2972 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $gsize=$5; //@line 2972 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $6=$gsize; //@line 2989 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $7=$gsize; //@line 2989 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $8=((($7)-(1))|0); //@line 2989 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $9=$6 & $8; //@line 2989 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $10=(($9)|0)!=0; //@line 2989 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($10) { __label__ = 5; break; } else { __label__ = 4; break; } //@line 2989 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 4: 
      var $12=$psize; //@line 2989 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $13=$psize; //@line 2989 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $14=((($13)-(1))|0); //@line 2989 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $15=$12 & $14; //@line 2989 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $16=(($15)|0)!=0; //@line 2989 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($16) { __label__ = 5; break; } else { __label__ = 6; break; } //@line 2989 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 5: 
      _abort(); //@line 2997 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      throw "Reached an unreachable!" //@line 2997 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 6: 
      var $19=$gsize; //@line 2999 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[((((_mparams+8)|0))>>2)]=$19; //@line 2999 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $20=$psize; //@line 3000 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[((((_mparams+4)|0))>>2)]=$20; //@line 3000 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[((((_mparams+12)|0))>>2)]=-1; //@line 3001 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[((((_mparams+16)|0))>>2)]=2097152; //@line 3002 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[((((_mparams+20)|0))>>2)]=0; //@line 3004 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $21=HEAP32[((((_mparams+20)|0))>>2)]; //@line 3011 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[((((__gm_+440)|0))>>2)]=$21; //@line 3011 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $22=_time(0); //@line 3030 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $23=$22 ^ 1431655765; //@line 3030 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $magic=$23; //@line 3030 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $24=$magic; //@line 3032 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $25=$24 | 8; //@line 3032 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $magic=$25; //@line 3032 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $26=$magic; //@line 3033 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $27=$26 & -8; //@line 3033 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $magic=$27; //@line 3033 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $28=$magic; //@line 3034 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[((((_mparams)|0))>>2)]=$28; //@line 3034 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 7; break; //@line 3036 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 7: 
      ;
      return 1; //@line 3039 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    default: assert(0, "bad label: " + __label__);
  }
}


function _init_top($m, $p, $psize) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $offset;
      $1=$m;
      $2=$p;
      $3=$psize;
      var $4=$2; //@line 3736 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $5=$4; //@line 3736 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $6=(($5+8)|0); //@line 3736 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $7=$6; //@line 3736 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $8=$7 & 7; //@line 3736 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $9=(($8)|0)==0; //@line 3736 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($9) { __label__ = 3; break; } else { __label__ = 4; break; } //@line 3736 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 3: 
      var $20 = 0;__label__ = 5; break; //@line 3736 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 4: 
      var $12=$2; //@line 3736 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $13=$12; //@line 3736 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $14=(($13+8)|0); //@line 3736 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $15=$14; //@line 3736 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $16=$15 & 7; //@line 3736 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $17=(((8)-($16))|0); //@line 3736 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $18=$17 & 7; //@line 3736 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $20 = $18;__label__ = 5; break; //@line 3736 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 5: 
      var $20; //@line 3736 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $offset=$20; //@line 3736 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $21=$2; //@line 3737 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $22=$21; //@line 3737 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $23=$offset; //@line 3737 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $24=(($22+$23)|0); //@line 3737 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $25=$24; //@line 3737 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $2=$25; //@line 3737 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $26=$offset; //@line 3738 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $27=$3; //@line 3738 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $28=((($27)-($26))|0); //@line 3738 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $3=$28; //@line 3738 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $29=$2; //@line 3740 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $30=$1; //@line 3740 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $31=(($30+24)|0); //@line 3740 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($31)>>2)]=$29; //@line 3740 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $32=$3; //@line 3741 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $33=$1; //@line 3741 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $34=(($33+12)|0); //@line 3741 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($34)>>2)]=$32; //@line 3741 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $35=$3; //@line 3742 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $36=$35 | 1; //@line 3742 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $37=$2; //@line 3742 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $38=(($37+4)|0); //@line 3742 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($38)>>2)]=$36; //@line 3742 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $39=$2; //@line 3744 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $40=$39; //@line 3744 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $41=$3; //@line 3744 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $42=(($40+$41)|0); //@line 3744 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $43=$42; //@line 3744 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $44=(($43+4)|0); //@line 3744 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($44)>>2)]=40; //@line 3744 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $45=HEAP32[((((_mparams+16)|0))>>2)]; //@line 3745 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $46=$1; //@line 3745 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $47=(($46+28)|0); //@line 3745 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($47)>>2)]=$45; //@line 3745 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      ;
      return; //@line 3746 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    default: assert(0, "bad label: " + __label__);
  }
}
_init_top["X"]=1;

function _mmap_alloc($m, $nb) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $mmsize;
      var $mm;
      var $offset;
      var $psize;
      var $p;
      $2=$m;
      $3=$nb;
      var $4=$3; //@line 3672 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $5=((($4)+(24))|0); //@line 3672 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $6=((($5)+(7))|0); //@line 3672 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $7=HEAP32[((((_mparams+4)|0))>>2)]; //@line 3672 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $8=((($7)-(1))|0); //@line 3672 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $9=((($6)+($8))|0); //@line 3672 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $10=HEAP32[((((_mparams+4)|0))>>2)]; //@line 3672 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $11=((($10)-(1))|0); //@line 3672 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $12=$11 ^ -1; //@line 3672 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $13=$9 & $12; //@line 3672 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $mmsize=$13; //@line 3672 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $14=$mmsize; //@line 3673 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $15=$3; //@line 3673 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $16=(($14)>>>0) > (($15)>>>0); //@line 3673 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($16) { __label__ = 3; break; } else { __label__ = 14; break; } //@line 3673 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 3: 
      $mm=-1; //@line 3674 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $18=$mm; //@line 3675 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $19=(($18)|0)!=-1; //@line 3675 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($19) { __label__ = 4; break; } else { __label__ = 13; break; } //@line 3675 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 4: 
      var $21=$mm; //@line 3676 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $22=(($21+8)|0); //@line 3676 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $23=$22; //@line 3676 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $24=$23 & 7; //@line 3676 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $25=(($24)|0)==0; //@line 3676 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($25) { __label__ = 5; break; } else { __label__ = 6; break; } //@line 3676 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 5: 
      var $35 = 0;__label__ = 7; break; //@line 3676 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 6: 
      var $28=$mm; //@line 3676 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $29=(($28+8)|0); //@line 3676 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $30=$29; //@line 3676 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $31=$30 & 7; //@line 3676 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $32=(((8)-($31))|0); //@line 3676 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $33=$32 & 7; //@line 3676 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $35 = $33;__label__ = 7; break; //@line 3676 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 7: 
      var $35; //@line 3676 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $offset=$35; //@line 3676 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $36=$mmsize; //@line 3677 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $37=$offset; //@line 3677 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $38=((($36)-($37))|0); //@line 3677 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $39=((($38)-(16))|0); //@line 3677 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $psize=$39; //@line 3677 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $40=$mm; //@line 3678 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $41=$offset; //@line 3678 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $42=(($40+$41)|0); //@line 3678 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $43=$42; //@line 3678 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $p=$43; //@line 3678 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $44=$offset; //@line 3679 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $45=$p; //@line 3679 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $46=(($45)|0); //@line 3679 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($46)>>2)]=$44; //@line 3679 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $47=$psize; //@line 3680 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $48=$p; //@line 3680 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $49=(($48+4)|0); //@line 3680 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($49)>>2)]=$47; //@line 3680 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $50=$p; //@line 3682 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $51=$50; //@line 3682 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $52=$psize; //@line 3682 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $53=(($51+$52)|0); //@line 3682 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $54=$53; //@line 3682 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $55=(($54+4)|0); //@line 3682 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($55)>>2)]=7; //@line 3682 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $56=$p; //@line 3683 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $57=$56; //@line 3683 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $58=$psize; //@line 3683 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $59=((($58)+(4))|0); //@line 3683 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $60=(($57+$59)|0); //@line 3683 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $61=$60; //@line 3683 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $62=(($61+4)|0); //@line 3683 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($62)>>2)]=0; //@line 3683 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $63=$2; //@line 3685 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $64=(($63+16)|0); //@line 3685 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $65=HEAP32[(($64)>>2)]; //@line 3685 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $66=(($65)|0)==0; //@line 3685 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($66) { __label__ = 9; break; } else { __label__ = 8; break; } //@line 3685 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 8: 
      var $68=$mm; //@line 3685 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $69=$2; //@line 3685 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $70=(($69+16)|0); //@line 3685 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $71=HEAPU32[(($70)>>2)]; //@line 3685 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $72=(($68)>>>0) < (($71)>>>0); //@line 3685 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($72) { __label__ = 9; break; } else { __label__ = 10; break; } //@line 3685 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 9: 
      var $74=$mm; //@line 3686 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $75=$2; //@line 3686 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $76=(($75+16)|0); //@line 3686 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($76)>>2)]=$74; //@line 3686 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 10; break; //@line 3686 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 10: 
      var $78=$mmsize; //@line 3687 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $79=$2; //@line 3687 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $80=(($79+432)|0); //@line 3687 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $81=HEAP32[(($80)>>2)]; //@line 3687 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $82=((($81)+($78))|0); //@line 3687 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($80)>>2)]=$82; //@line 3687 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $83=$2; //@line 3687 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $84=(($83+436)|0); //@line 3687 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $85=HEAPU32[(($84)>>2)]; //@line 3687 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $86=(($82)>>>0) > (($85)>>>0); //@line 3687 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($86) { __label__ = 11; break; } else { __label__ = 12; break; } //@line 3687 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 11: 
      var $88=$2; //@line 3688 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $89=(($88+432)|0); //@line 3688 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $90=HEAP32[(($89)>>2)]; //@line 3688 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $91=$2; //@line 3688 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $92=(($91+436)|0); //@line 3688 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($92)>>2)]=$90; //@line 3688 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 12; break; //@line 3688 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 12: 
      var $94=$p; //@line 3691 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $95=$94; //@line 3691 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $96=(($95+8)|0); //@line 3691 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $1=$96; //@line 3691 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 15; break; //@line 3691 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 13: 
      __label__ = 14; break; //@line 3693 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 14: 
      $1=0; //@line 3694 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 15; break; //@line 3694 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 15: 
      var $100=$1; //@line 3695 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      ;
      return $100; //@line 3695 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    default: assert(0, "bad label: " + __label__);
  }
}
_mmap_alloc["X"]=1;

function _init_bins($m) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $i;
      var $bin;
      $1=$m;
      $i=0; //@line 3752 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 3; break; //@line 3752 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 3: 
      var $3=$i; //@line 3752 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $4=(($3)>>>0) < 32; //@line 3752 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($4) { __label__ = 4; break; } else { __label__ = 6; break; } //@line 3752 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 4: 
      var $6=$i; //@line 3753 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $7=$6 << 1; //@line 3753 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $8=$1; //@line 3753 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $9=(($8+40)|0); //@line 3753 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $10=(($9+($7<<2))|0); //@line 3753 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $11=$10; //@line 3753 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $12=$11; //@line 3753 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $bin=$12; //@line 3753 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $13=$bin; //@line 3754 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $14=$bin; //@line 3754 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $15=(($14+12)|0); //@line 3754 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($15)>>2)]=$13; //@line 3754 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $16=$bin; //@line 3754 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $17=(($16+8)|0); //@line 3754 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($17)>>2)]=$13; //@line 3754 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 5; break; //@line 3755 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 5: 
      var $19=$i; //@line 3752 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $20=((($19)+(1))|0); //@line 3752 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $i=$20; //@line 3752 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 3; break; //@line 3752 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 6: 
      ;
      return; //@line 3756 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    default: assert(0, "bad label: " + __label__);
  }
}


function _prepend_alloc($m, $newbase, $oldbase, $nb) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $p;
      var $oldfirst;
      var $psize;
      var $q;
      var $qsize;
      var $tsize;
      var $dsize;
      var $nsize;
      var $F;
      var $B;
      var $I;
      var $TP;
      var $XP;
      var $R;
      var $F1;
      var $RP;
      var $CP;
      var $H;
      var $C0;
      var $C1;
      var $I2;
      var $B3;
      var $F4;
      var $TP5;
      var $H6;
      var $I7;
      var $X;
      var $Y;
      var $N;
      var $K;
      var $T;
      var $K8;
      var $C;
      var $F9;
      $1=$m;
      $2=$newbase;
      $3=$oldbase;
      $4=$nb;
      var $5=$2; //@line 3780 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $6=$2; //@line 3780 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $7=(($6+8)|0); //@line 3780 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $8=$7; //@line 3780 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $9=$8 & 7; //@line 3780 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $10=(($9)|0)==0; //@line 3780 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($10) { __label__ = 3; break; } else { __label__ = 4; break; } //@line 3780 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 3: 
      var $20 = 0;__label__ = 5; break; //@line 3780 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 4: 
      var $13=$2; //@line 3780 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $14=(($13+8)|0); //@line 3780 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $15=$14; //@line 3780 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $16=$15 & 7; //@line 3780 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $17=(((8)-($16))|0); //@line 3780 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $18=$17 & 7; //@line 3780 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $20 = $18;__label__ = 5; break; //@line 3780 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 5: 
      var $20; //@line 3780 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $21=(($5+$20)|0); //@line 3780 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $22=$21; //@line 3780 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $p=$22; //@line 3780 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $23=$3; //@line 3781 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $24=$3; //@line 3781 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $25=(($24+8)|0); //@line 3781 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $26=$25; //@line 3781 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $27=$26 & 7; //@line 3781 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $28=(($27)|0)==0; //@line 3781 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($28) { __label__ = 6; break; } else { __label__ = 7; break; } //@line 3781 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 6: 
      var $38 = 0;__label__ = 8; break; //@line 3781 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 7: 
      var $31=$3; //@line 3781 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $32=(($31+8)|0); //@line 3781 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $33=$32; //@line 3781 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $34=$33 & 7; //@line 3781 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $35=(((8)-($34))|0); //@line 3781 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $36=$35 & 7; //@line 3781 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $38 = $36;__label__ = 8; break; //@line 3781 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 8: 
      var $38; //@line 3781 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $39=(($23+$38)|0); //@line 3781 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $40=$39; //@line 3781 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $oldfirst=$40; //@line 3781 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $41=$oldfirst; //@line 3782 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $42=$41; //@line 3782 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $43=$p; //@line 3782 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $44=$43; //@line 3782 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $45=$42; //@line 3782 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $46=$44; //@line 3782 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $47=((($45)-($46))|0); //@line 3782 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $psize=$47; //@line 3782 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $48=$p; //@line 3783 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $49=$48; //@line 3783 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $50=$4; //@line 3783 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $51=(($49+$50)|0); //@line 3783 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $52=$51; //@line 3783 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $q=$52; //@line 3783 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $53=$psize; //@line 3784 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $54=$4; //@line 3784 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $55=((($53)-($54))|0); //@line 3784 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $qsize=$55; //@line 3784 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $56=$4; //@line 3785 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $57=$56 | 1; //@line 3785 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $58=$57 | 2; //@line 3785 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $59=$p; //@line 3785 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $60=(($59+4)|0); //@line 3785 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($60)>>2)]=$58; //@line 3785 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $61=$oldfirst; //@line 3792 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $62=$1; //@line 3792 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $63=(($62+24)|0); //@line 3792 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $64=HEAP32[(($63)>>2)]; //@line 3792 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $65=(($61)|0)==(($64)|0); //@line 3792 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($65) { __label__ = 9; break; } else { __label__ = 10; break; } //@line 3792 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 9: 
      var $67=$qsize; //@line 3793 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $68=$1; //@line 3793 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $69=(($68+12)|0); //@line 3793 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $70=HEAP32[(($69)>>2)]; //@line 3793 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $71=((($70)+($67))|0); //@line 3793 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($69)>>2)]=$71; //@line 3793 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $tsize=$71; //@line 3793 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $72=$q; //@line 3794 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $73=$1; //@line 3794 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $74=(($73+24)|0); //@line 3794 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($74)>>2)]=$72; //@line 3794 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $75=$tsize; //@line 3795 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $76=$75 | 1; //@line 3795 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $77=$q; //@line 3795 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $78=(($77+4)|0); //@line 3795 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($78)>>2)]=$76; //@line 3795 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 110; break; //@line 3797 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 10: 
      var $80=$oldfirst; //@line 3798 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $81=$1; //@line 3798 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $82=(($81+20)|0); //@line 3798 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $83=HEAP32[(($82)>>2)]; //@line 3798 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $84=(($80)|0)==(($83)|0); //@line 3798 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($84) { __label__ = 11; break; } else { __label__ = 12; break; } //@line 3798 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 11: 
      var $86=$qsize; //@line 3799 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $87=$1; //@line 3799 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $88=(($87+8)|0); //@line 3799 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $89=HEAP32[(($88)>>2)]; //@line 3799 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $90=((($89)+($86))|0); //@line 3799 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($88)>>2)]=$90; //@line 3799 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $dsize=$90; //@line 3799 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $91=$q; //@line 3800 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $92=$1; //@line 3800 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $93=(($92+20)|0); //@line 3800 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($93)>>2)]=$91; //@line 3800 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $94=$dsize; //@line 3801 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $95=$94 | 1; //@line 3801 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $96=$q; //@line 3801 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $97=(($96+4)|0); //@line 3801 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($97)>>2)]=$95; //@line 3801 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $98=$dsize; //@line 3801 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $99=$q; //@line 3801 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $100=$99; //@line 3801 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $101=$dsize; //@line 3801 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $102=(($100+$101)|0); //@line 3801 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $103=$102; //@line 3801 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $104=(($103)|0); //@line 3801 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($104)>>2)]=$98; //@line 3801 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 109; break; //@line 3802 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 12: 
      var $106=$oldfirst; //@line 3804 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $107=(($106+4)|0); //@line 3804 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $108=HEAP32[(($107)>>2)]; //@line 3804 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $109=$108 & 3; //@line 3804 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $110=(($109)|0)!=1; //@line 3804 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($110) { __label__ = 73; break; } else { __label__ = 13; break; } //@line 3804 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 13: 
      var $112=$oldfirst; //@line 3805 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $113=(($112+4)|0); //@line 3805 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $114=HEAP32[(($113)>>2)]; //@line 3805 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $115=$114 & -8; //@line 3805 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $nsize=$115; //@line 3805 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $116=$nsize; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $117=$116 >>> 3; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $118=(($117)>>>0) < 32; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($118) { __label__ = 14; break; } else { __label__ = 26; break; } //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 14: 
      var $120=$oldfirst; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $121=(($120+8)|0); //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $122=HEAP32[(($121)>>2)]; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $F=$122; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $123=$oldfirst; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $124=(($123+12)|0); //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $125=HEAP32[(($124)>>2)]; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $B=$125; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $126=$nsize; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $127=$126 >>> 3; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $I=$127; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $128=$F; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $129=$B; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $130=(($128)|0)==(($129)|0); //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($130) { __label__ = 15; break; } else { __label__ = 16; break; } //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 15: 
      var $132=$I; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $133=1 << $132; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $134=$133 ^ -1; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $135=$1; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $136=(($135)|0); //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $137=HEAP32[(($136)>>2)]; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $138=$137 & $134; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($136)>>2)]=$138; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 25; break; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 16: 
      var $140=$F; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $141=$I; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $142=$141 << 1; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $143=$1; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $144=(($143+40)|0); //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $145=(($144+($142<<2))|0); //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $146=$145; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $147=$146; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $148=(($140)|0)==(($147)|0); //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($148) { __label__ = 18; break; } else { __label__ = 17; break; } //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 17: 
      var $150=$F; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $151=$150; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $152=$1; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $153=(($152+16)|0); //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $154=HEAPU32[(($153)>>2)]; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $155=(($151)>>>0) >= (($154)>>>0); //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($155) { __label__ = 18; break; } else { var $176 = 0;__label__ = 21; break; } //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 18: 
      var $157=$B; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $158=$I; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $159=$158 << 1; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $160=$1; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $161=(($160+40)|0); //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $162=(($161+($159<<2))|0); //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $163=$162; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $164=$163; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $165=(($157)|0)==(($164)|0); //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($165) { var $174 = 1;__label__ = 20; break; } else { __label__ = 19; break; } //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 19: 
      var $167=$B; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $168=$167; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $169=$1; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $170=(($169+16)|0); //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $171=HEAPU32[(($170)>>2)]; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $172=(($168)>>>0) >= (($171)>>>0); //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $174 = $172;__label__ = 20; break; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 20: 
      var $174;
      var $176 = $174;__label__ = 21; break;
    case 21: 
      var $176;
      var $177=(($176)&1);
      var $178=(($177)==(1));
      var $179=(($178)|0)!=0;
      if ($179) { __label__ = 22; break; } else { __label__ = 23; break; }
    case 22: 
      var $181=$B; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $182=$F; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $183=(($182+12)|0); //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($183)>>2)]=$181; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $184=$F; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $185=$B; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $186=(($185+8)|0); //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($186)>>2)]=$184; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 24; break; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 23: 
      _abort(); //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      throw "Reached an unreachable!" //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 24: 
      __label__ = 25; break;
    case 25: 
      __label__ = 72; break; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 26: 
      var $191=$oldfirst; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $192=$191; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $TP=$192; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $193=$TP; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $194=(($193+24)|0); //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $195=HEAP32[(($194)>>2)]; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $XP=$195; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $196=$TP; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $197=(($196+12)|0); //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $198=HEAP32[(($197)>>2)]; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $199=$TP; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $200=(($198)|0)!=(($199)|0); //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($200) { __label__ = 27; break; } else { __label__ = 31; break; } //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 27: 
      var $202=$TP; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $203=(($202+8)|0); //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $204=HEAP32[(($203)>>2)]; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $F1=$204; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $205=$TP; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $206=(($205+12)|0); //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $207=HEAP32[(($206)>>2)]; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $R=$207; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $208=$F1; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $209=$208; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $210=$1; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $211=(($210+16)|0); //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $212=HEAPU32[(($211)>>2)]; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $213=(($209)>>>0) >= (($212)>>>0); //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $214=(($213)&1); //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $215=(($214)==(1)); //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $216=(($215)|0)!=0; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($216) { __label__ = 28; break; } else { __label__ = 29; break; } //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 28: 
      var $218=$R; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $219=$F1; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $220=(($219+12)|0); //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($220)>>2)]=$218; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $221=$F1; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $222=$R; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $223=(($222+8)|0); //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($223)>>2)]=$221; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 30; break; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 29: 
      _abort(); //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      throw "Reached an unreachable!" //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 30: 
      __label__ = 43; break; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 31: 
      var $227=$TP; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $228=(($227+16)|0); //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $229=(($228+4)|0); //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $RP=$229; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $230=HEAP32[(($229)>>2)]; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $R=$230; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $231=(($230)|0)!=0; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($231) { __label__ = 33; break; } else { __label__ = 32; break; } //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 32: 
      var $233=$TP; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $234=(($233+16)|0); //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $235=(($234)|0); //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $RP=$235; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $236=HEAP32[(($235)>>2)]; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $R=$236; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $237=(($236)|0)!=0; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($237) { __label__ = 33; break; } else { __label__ = 42; break; } //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 33: 
      __label__ = 34; break; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 34: 
      var $240=$R; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $241=(($240+16)|0); //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $242=(($241+4)|0); //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $CP=$242; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $243=HEAP32[(($242)>>2)]; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $244=(($243)|0)!=0; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($244) { var $252 = 1;__label__ = 36; break; } else { __label__ = 35; break; } //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 35: 
      var $246=$R; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $247=(($246+16)|0); //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $248=(($247)|0); //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $CP=$248; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $249=HEAP32[(($248)>>2)]; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $250=(($249)|0)!=0; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $252 = $250;__label__ = 36; break; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 36: 
      var $252;
      if ($252) { __label__ = 37; break; } else { __label__ = 38; break; } //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 37: 
      var $254=$CP; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $RP=$254; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $255=HEAP32[(($254)>>2)]; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $R=$255; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 34; break; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 38: 
      var $257=$RP; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $258=$257; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $259=$1; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $260=(($259+16)|0); //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $261=HEAPU32[(($260)>>2)]; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $262=(($258)>>>0) >= (($261)>>>0); //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $263=(($262)&1); //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $264=(($263)==(1)); //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $265=(($264)|0)!=0; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($265) { __label__ = 39; break; } else { __label__ = 40; break; } //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 39: 
      var $267=$RP; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($267)>>2)]=0; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 41; break; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 40: 
      _abort(); //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      throw "Reached an unreachable!" //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 41: 
      __label__ = 42; break; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 42: 
      __label__ = 43; break;
    case 43: 
      var $272=$XP; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $273=(($272)|0)!=0; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($273) { __label__ = 44; break; } else { __label__ = 71; break; } //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 44: 
      var $275=$TP; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $276=(($275+28)|0); //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $277=HEAP32[(($276)>>2)]; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $278=$1; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $279=(($278+304)|0); //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $280=(($279+($277<<2))|0); //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $H=$280; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $281=$TP; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $282=$H; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $283=HEAP32[(($282)>>2)]; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $284=(($281)|0)==(($283)|0); //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($284) { __label__ = 45; break; } else { __label__ = 48; break; } //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 45: 
      var $286=$R; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $287=$H; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($287)>>2)]=$286; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $288=(($286)|0)==0; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($288) { __label__ = 46; break; } else { __label__ = 47; break; } //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 46: 
      var $290=$TP; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $291=(($290+28)|0); //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $292=HEAP32[(($291)>>2)]; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $293=1 << $292; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $294=$293 ^ -1; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $295=$1; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $296=(($295+4)|0); //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $297=HEAP32[(($296)>>2)]; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $298=$297 & $294; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($296)>>2)]=$298; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 47; break; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 47: 
      __label__ = 55; break; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 48: 
      var $301=$XP; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $302=$301; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $303=$1; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $304=(($303+16)|0); //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $305=HEAPU32[(($304)>>2)]; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $306=(($302)>>>0) >= (($305)>>>0); //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $307=(($306)&1); //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $308=(($307)==(1)); //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $309=(($308)|0)!=0; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($309) { __label__ = 49; break; } else { __label__ = 53; break; } //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 49: 
      var $311=$XP; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $312=(($311+16)|0); //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $313=(($312)|0); //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $314=HEAP32[(($313)>>2)]; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $315=$TP; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $316=(($314)|0)==(($315)|0); //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($316) { __label__ = 50; break; } else { __label__ = 51; break; } //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 50: 
      var $318=$R; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $319=$XP; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $320=(($319+16)|0); //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $321=(($320)|0); //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($321)>>2)]=$318; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 52; break; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 51: 
      var $323=$R; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $324=$XP; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $325=(($324+16)|0); //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $326=(($325+4)|0); //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($326)>>2)]=$323; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 52; break;
    case 52: 
      __label__ = 54; break; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 53: 
      _abort(); //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      throw "Reached an unreachable!" //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 54: 
      __label__ = 55; break;
    case 55: 
      var $331=$R; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $332=(($331)|0)!=0; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($332) { __label__ = 56; break; } else { __label__ = 70; break; } //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 56: 
      var $334=$R; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $335=$334; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $336=$1; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $337=(($336+16)|0); //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $338=HEAPU32[(($337)>>2)]; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $339=(($335)>>>0) >= (($338)>>>0); //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $340=(($339)&1); //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $341=(($340)==(1)); //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $342=(($341)|0)!=0; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($342) { __label__ = 57; break; } else { __label__ = 68; break; } //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 57: 
      var $344=$XP; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $345=$R; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $346=(($345+24)|0); //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($346)>>2)]=$344; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $347=$TP; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $348=(($347+16)|0); //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $349=(($348)|0); //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $350=HEAP32[(($349)>>2)]; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $C0=$350; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $351=(($350)|0)!=0; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($351) { __label__ = 58; break; } else { __label__ = 62; break; } //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 58: 
      var $353=$C0; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $354=$353; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $355=$1; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $356=(($355+16)|0); //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $357=HEAPU32[(($356)>>2)]; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $358=(($354)>>>0) >= (($357)>>>0); //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $359=(($358)&1); //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $360=(($359)==(1)); //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $361=(($360)|0)!=0; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($361) { __label__ = 59; break; } else { __label__ = 60; break; } //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 59: 
      var $363=$C0; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $364=$R; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $365=(($364+16)|0); //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $366=(($365)|0); //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($366)>>2)]=$363; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $367=$R; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $368=$C0; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $369=(($368+24)|0); //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($369)>>2)]=$367; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 61; break; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 60: 
      _abort(); //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      throw "Reached an unreachable!" //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 61: 
      __label__ = 62; break; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 62: 
      var $373=$TP; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $374=(($373+16)|0); //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $375=(($374+4)|0); //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $376=HEAP32[(($375)>>2)]; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $C1=$376; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $377=(($376)|0)!=0; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($377) { __label__ = 63; break; } else { __label__ = 67; break; } //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 63: 
      var $379=$C1; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $380=$379; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $381=$1; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $382=(($381+16)|0); //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $383=HEAPU32[(($382)>>2)]; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $384=(($380)>>>0) >= (($383)>>>0); //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $385=(($384)&1); //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $386=(($385)==(1)); //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $387=(($386)|0)!=0; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($387) { __label__ = 64; break; } else { __label__ = 65; break; } //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 64: 
      var $389=$C1; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $390=$R; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $391=(($390+16)|0); //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $392=(($391+4)|0); //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($392)>>2)]=$389; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $393=$R; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $394=$C1; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $395=(($394+24)|0); //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($395)>>2)]=$393; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 66; break; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 65: 
      _abort(); //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      throw "Reached an unreachable!" //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 66: 
      __label__ = 67; break; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 67: 
      __label__ = 69; break; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 68: 
      _abort(); //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      throw "Reached an unreachable!" //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 69: 
      __label__ = 70; break; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 70: 
      __label__ = 71; break; //@line 3806 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 71: 
      __label__ = 72; break;
    case 72: 
      var $404=$oldfirst; //@line 3807 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $405=$404; //@line 3807 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $406=$nsize; //@line 3807 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $407=(($405+$406)|0); //@line 3807 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $408=$407; //@line 3807 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $oldfirst=$408; //@line 3807 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $409=$nsize; //@line 3808 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $410=$qsize; //@line 3808 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $411=((($410)+($409))|0); //@line 3808 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $qsize=$411; //@line 3808 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 73; break; //@line 3809 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 73: 
      var $413=$oldfirst; //@line 3810 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $414=(($413+4)|0); //@line 3810 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $415=HEAP32[(($414)>>2)]; //@line 3810 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $416=$415 & -2; //@line 3810 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($414)>>2)]=$416; //@line 3810 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $417=$qsize; //@line 3810 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $418=$417 | 1; //@line 3810 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $419=$q; //@line 3810 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $420=(($419+4)|0); //@line 3810 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($420)>>2)]=$418; //@line 3810 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $421=$qsize; //@line 3810 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $422=$q; //@line 3810 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $423=$422; //@line 3810 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $424=$qsize; //@line 3810 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $425=(($423+$424)|0); //@line 3810 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $426=$425; //@line 3810 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $427=(($426)|0); //@line 3810 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($427)>>2)]=$421; //@line 3810 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $428=$qsize; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $429=$428 >>> 3; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $430=(($429)>>>0) < 32; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($430) { __label__ = 74; break; } else { __label__ = 81; break; } //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 74: 
      var $432=$qsize; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $433=$432 >>> 3; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $I2=$433; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $434=$I2; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $435=$434 << 1; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $436=$1; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $437=(($436+40)|0); //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $438=(($437+($435<<2))|0); //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $439=$438; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $440=$439; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $B3=$440; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $441=$B3; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $F4=$441; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $442=$1; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $443=(($442)|0); //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $444=HEAP32[(($443)>>2)]; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $445=$I2; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $446=1 << $445; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $447=$444 & $446; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $448=(($447)|0)!=0; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($448) { __label__ = 76; break; } else { __label__ = 75; break; } //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 75: 
      var $450=$I2; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $451=1 << $450; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $452=$1; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $453=(($452)|0); //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $454=HEAP32[(($453)>>2)]; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $455=$454 | $451; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($453)>>2)]=$455; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 80; break; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 76: 
      var $457=$B3; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $458=(($457+8)|0); //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $459=HEAP32[(($458)>>2)]; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $460=$459; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $461=$1; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $462=(($461+16)|0); //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $463=HEAPU32[(($462)>>2)]; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $464=(($460)>>>0) >= (($463)>>>0); //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $465=(($464)&1); //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $466=(($465)==(1)); //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $467=(($466)|0)!=0; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($467) { __label__ = 77; break; } else { __label__ = 78; break; } //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 77: 
      var $469=$B3; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $470=(($469+8)|0); //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $471=HEAP32[(($470)>>2)]; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $F4=$471; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 79; break; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 78: 
      _abort(); //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      throw "Reached an unreachable!" //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 79: 
      __label__ = 80; break;
    case 80: 
      var $475=$q; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $476=$B3; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $477=(($476+8)|0); //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($477)>>2)]=$475; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $478=$q; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $479=$F4; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $480=(($479+12)|0); //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($480)>>2)]=$478; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $481=$F4; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $482=$q; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $483=(($482+8)|0); //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($483)>>2)]=$481; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $484=$B3; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $485=$q; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $486=(($485+12)|0); //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($486)>>2)]=$484; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 108; break; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 81: 
      var $488=$q; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $489=$488; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $TP5=$489; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $490=$qsize; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $491=$490 >>> 8; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $X=$491; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $492=$X; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $493=(($492)|0)==0; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($493) { __label__ = 82; break; } else { __label__ = 83; break; } //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 82: 
      $I7=0; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 87; break; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 83: 
      var $496=$X; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $497=(($496)>>>0) > 65535; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($497) { __label__ = 84; break; } else { __label__ = 85; break; } //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 84: 
      $I7=31; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 86; break; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 85: 
      var $500=$X; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $Y=$500; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $501=$Y; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $502=((($501)-(256))|0); //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $503=$502 >>> 16; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $504=$503 & 8; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $N=$504; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $505=$N; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $506=$Y; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $507=$506 << $505; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $Y=$507; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $508=((($507)-(4096))|0); //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $509=$508 >>> 16; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $510=$509 & 4; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $K=$510; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $511=$K; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $512=$N; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $513=((($512)+($511))|0); //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $N=$513; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $514=$K; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $515=$Y; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $516=$515 << $514; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $Y=$516; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $517=((($516)-(16384))|0); //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $518=$517 >>> 16; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $519=$518 & 2; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $K=$519; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $520=$N; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $521=((($520)+($519))|0); //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $N=$521; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $522=$N; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $523=(((14)-($522))|0); //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $524=$K; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $525=$Y; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $526=$525 << $524; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $Y=$526; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $527=$526 >>> 15; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $528=((($523)+($527))|0); //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $K=$528; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $529=$K; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $530=$529 << 1; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $531=$qsize; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $532=$K; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $533=((($532)+(7))|0); //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $534=$531 >>> (($533)>>>0); //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $535=$534 & 1; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $536=((($530)+($535))|0); //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $I7=$536; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 86; break;
    case 86: 
      __label__ = 87; break;
    case 87: 
      var $539=$I7; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $540=$1; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $541=(($540+304)|0); //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $542=(($541+($539<<2))|0); //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $H6=$542; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $543=$I7; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $544=$TP5; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $545=(($544+28)|0); //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($545)>>2)]=$543; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $546=$TP5; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $547=(($546+16)|0); //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $548=(($547+4)|0); //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($548)>>2)]=0; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $549=$TP5; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $550=(($549+16)|0); //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $551=(($550)|0); //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($551)>>2)]=0; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $552=$1; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $553=(($552+4)|0); //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $554=HEAP32[(($553)>>2)]; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $555=$I7; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $556=1 << $555; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $557=$554 & $556; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $558=(($557)|0)!=0; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($558) { __label__ = 89; break; } else { __label__ = 88; break; } //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 88: 
      var $560=$I7; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $561=1 << $560; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $562=$1; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $563=(($562+4)|0); //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $564=HEAP32[(($563)>>2)]; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $565=$564 | $561; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($563)>>2)]=$565; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $566=$TP5; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $567=$H6; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($567)>>2)]=$566; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $568=$H6; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $569=$568; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $570=$TP5; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $571=(($570+24)|0); //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($571)>>2)]=$569; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $572=$TP5; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $573=$TP5; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $574=(($573+12)|0); //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($574)>>2)]=$572; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $575=$TP5; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $576=(($575+8)|0); //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($576)>>2)]=$572; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 107; break; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 89: 
      var $578=$H6; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $579=HEAP32[(($578)>>2)]; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $T=$579; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $580=$qsize; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $581=$I7; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $582=(($581)|0)==31; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($582) { __label__ = 90; break; } else { __label__ = 91; break; } //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 90: 
      var $591 = 0;__label__ = 92; break; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 91: 
      var $585=$I7; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $586=$585 >>> 1; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $587=((($586)+(8))|0); //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $588=((($587)-(2))|0); //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $589=(((31)-($588))|0); //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $591 = $589;__label__ = 92; break; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 92: 
      var $591; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $592=$580 << $591; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $K8=$592; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 93; break; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 93: 
      var $594=$T; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $595=(($594+4)|0); //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $596=HEAP32[(($595)>>2)]; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $597=$596 & -8; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $598=$qsize; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $599=(($597)|0)!=(($598)|0); //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($599) { __label__ = 94; break; } else { __label__ = 100; break; } //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 94: 
      var $601=$K8; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $602=$601 >>> 31; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $603=$602 & 1; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $604=$T; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $605=(($604+16)|0); //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $606=(($605+($603<<2))|0); //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $C=$606; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $607=$K8; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $608=$607 << 1; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $K8=$608; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $609=$C; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $610=HEAP32[(($609)>>2)]; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $611=(($610)|0)!=0; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($611) { __label__ = 95; break; } else { __label__ = 96; break; } //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 95: 
      var $613=$C; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $614=HEAP32[(($613)>>2)]; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $T=$614; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 99; break; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 96: 
      var $616=$C; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $617=$616; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $618=$1; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $619=(($618+16)|0); //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $620=HEAPU32[(($619)>>2)]; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $621=(($617)>>>0) >= (($620)>>>0); //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $622=(($621)&1); //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $623=(($622)==(1)); //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $624=(($623)|0)!=0; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($624) { __label__ = 97; break; } else { __label__ = 98; break; } //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 97: 
      var $626=$TP5; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $627=$C; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($627)>>2)]=$626; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $628=$T; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $629=$TP5; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $630=(($629+24)|0); //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($630)>>2)]=$628; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $631=$TP5; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $632=$TP5; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $633=(($632+12)|0); //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($633)>>2)]=$631; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $634=$TP5; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $635=(($634+8)|0); //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($635)>>2)]=$631; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 106; break; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 98: 
      _abort(); //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      throw "Reached an unreachable!" //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 99: 
      __label__ = 105; break; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 100: 
      var $639=$T; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $640=(($639+8)|0); //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $641=HEAP32[(($640)>>2)]; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $F9=$641; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $642=$T; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $643=$642; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $644=$1; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $645=(($644+16)|0); //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $646=HEAPU32[(($645)>>2)]; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $647=(($643)>>>0) >= (($646)>>>0); //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($647) { __label__ = 101; break; } else { var $656 = 0;__label__ = 102; break; } //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 101: 
      var $649=$F9; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $650=$649; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $651=$1; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $652=(($651+16)|0); //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $653=HEAPU32[(($652)>>2)]; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $654=(($650)>>>0) >= (($653)>>>0); //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $656 = $654;__label__ = 102; break;
    case 102: 
      var $656;
      var $657=(($656)&1);
      var $658=(($657)==(1));
      var $659=(($658)|0)!=0;
      if ($659) { __label__ = 103; break; } else { __label__ = 104; break; }
    case 103: 
      var $661=$TP5; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $662=$F9; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $663=(($662+12)|0); //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($663)>>2)]=$661; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $664=$T; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $665=(($664+8)|0); //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($665)>>2)]=$661; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $666=$F9; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $667=$TP5; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $668=(($667+8)|0); //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($668)>>2)]=$666; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $669=$T; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $670=$TP5; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $671=(($670+12)|0); //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($671)>>2)]=$669; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $672=$TP5; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $673=(($672+24)|0); //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($673)>>2)]=0; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 106; break; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 104: 
      _abort(); //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      throw "Reached an unreachable!" //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 105: 
      __label__ = 93; break; //@line 3811 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 106: 
      __label__ = 107; break;
    case 107: 
      __label__ = 108; break;
    case 108: 
      __label__ = 109; break;
    case 109: 
      __label__ = 110; break;
    case 110: 
      var $681=$p; //@line 3816 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $682=$681; //@line 3816 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $683=(($682+8)|0); //@line 3816 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      ;
      return $683; //@line 3816 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    default: assert(0, "bad label: " + __label__);
  }
}
_prepend_alloc["X"]=1;

function _add_segment($m, $tbase, $tsize, $mmapped) {
  ;
  var __label__;
  __label__ = 2; 
  while(1) switch(__label__) {
    case 2: 
      var $1;
      var $2;
      var $3;
      var $4;
      var $old_top;
      var $oldsp;
      var $old_end;
      var $ssize;
      var $rawsp;
      var $offset;
      var $asp;
      var $csp;
      var $sp;
      var $ss;
      var $tnext;
      var $p;
      var $nfences;
      var $nextp;
      var $q;
      var $psize;
      var $tn;
      var $I;
      var $B;
      var $F;
      var $TP;
      var $H;
      var $I1;
      var $X;
      var $Y;
      var $N;
      var $K;
      var $T;
      var $K2;
      var $C;
      var $F3;
      $1=$m;
      $2=$tbase;
      $3=$tsize;
      $4=$mmapped;
      var $5=$1; //@line 3822 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $6=(($5+24)|0); //@line 3822 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $7=HEAP32[(($6)>>2)]; //@line 3822 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $8=$7; //@line 3822 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $old_top=$8; //@line 3822 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $9=$1; //@line 3823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $10=$old_top; //@line 3823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $11=_segment_holding($9, $10); //@line 3823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $oldsp=$11; //@line 3823 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $12=$oldsp; //@line 3824 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $13=(($12)|0); //@line 3824 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $14=HEAP32[(($13)>>2)]; //@line 3824 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $15=$oldsp; //@line 3824 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $16=(($15+4)|0); //@line 3824 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $17=HEAP32[(($16)>>2)]; //@line 3824 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $18=(($14+$17)|0); //@line 3824 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $old_end=$18; //@line 3824 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $ssize=24; //@line 3825 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $19=$old_end; //@line 3826 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $20=$ssize; //@line 3826 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $21=((($20)+(16))|0); //@line 3826 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $22=((($21)+(7))|0); //@line 3826 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $23=(((-$22))|0); //@line 3826 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $24=(($19+$23)|0); //@line 3826 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $rawsp=$24; //@line 3826 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $25=$rawsp; //@line 3827 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $26=(($25+8)|0); //@line 3827 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $27=$26; //@line 3827 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $28=$27 & 7; //@line 3827 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $29=(($28)|0)==0; //@line 3827 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($29) { __label__ = 3; break; } else { __label__ = 4; break; } //@line 3827 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 3: 
      var $39 = 0;__label__ = 5; break; //@line 3827 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 4: 
      var $32=$rawsp; //@line 3827 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $33=(($32+8)|0); //@line 3827 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $34=$33; //@line 3827 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $35=$34 & 7; //@line 3827 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $36=(((8)-($35))|0); //@line 3827 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $37=$36 & 7; //@line 3827 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $39 = $37;__label__ = 5; break; //@line 3827 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 5: 
      var $39; //@line 3827 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $offset=$39; //@line 3827 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $40=$rawsp; //@line 3828 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $41=$offset; //@line 3828 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $42=(($40+$41)|0); //@line 3828 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $asp=$42; //@line 3828 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $43=$asp; //@line 3829 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $44=$old_top; //@line 3829 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $45=(($44+16)|0); //@line 3829 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $46=(($43)>>>0) < (($45)>>>0); //@line 3829 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($46) { __label__ = 6; break; } else { __label__ = 7; break; } //@line 3829 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 6: 
      var $48=$old_top; //@line 3829 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $52 = $48;__label__ = 8; break; //@line 3829 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 7: 
      var $50=$asp; //@line 3829 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $52 = $50;__label__ = 8; break; //@line 3829 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 8: 
      var $52; //@line 3829 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $csp=$52; //@line 3829 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $53=$csp; //@line 3830 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $54=$53; //@line 3830 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $sp=$54; //@line 3830 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $55=$sp; //@line 3831 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $56=$55; //@line 3831 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $57=(($56+8)|0); //@line 3831 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $58=$57; //@line 3831 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $ss=$58; //@line 3831 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $59=$sp; //@line 3832 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $60=$59; //@line 3832 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $61=$ssize; //@line 3832 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $62=(($60+$61)|0); //@line 3832 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $63=$62; //@line 3832 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $tnext=$63; //@line 3832 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $64=$tnext; //@line 3833 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $p=$64; //@line 3833 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $nfences=0; //@line 3834 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $65=$1; //@line 3837 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $66=$2; //@line 3837 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $67=$66; //@line 3837 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $68=$3; //@line 3837 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $69=((($68)-(40))|0); //@line 3837 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      _init_top($65, $67, $69); //@line 3837 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $70=$ssize; //@line 3841 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $71=$70 | 1; //@line 3841 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $72=$71 | 2; //@line 3841 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $73=$sp; //@line 3841 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $74=(($73+4)|0); //@line 3841 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($74)>>2)]=$72; //@line 3841 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $75=$ss; //@line 3842 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $76=$1; //@line 3842 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $77=(($76+444)|0); //@line 3842 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $78=$75; //@line 3842 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $79=$77; //@line 3842 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      assert(16 % 1 === 0, 'memcpy given ' + 16 + ' bytes to copy. Problem with quantum=1 corrections perhaps?');HEAP32[(($78)>>2)]=HEAP32[(($79)>>2)];HEAP32[((($78)+(4))>>2)]=HEAP32[((($79)+(4))>>2)];HEAP32[((($78)+(8))>>2)]=HEAP32[((($79)+(8))>>2)];HEAP32[((($78)+(12))>>2)]=HEAP32[((($79)+(12))>>2)]; //@line 3842 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $80=$2; //@line 3843 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $81=$1; //@line 3843 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $82=(($81+444)|0); //@line 3843 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $83=(($82)|0); //@line 3843 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($83)>>2)]=$80; //@line 3843 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $84=$3; //@line 3844 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $85=$1; //@line 3844 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $86=(($85+444)|0); //@line 3844 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $87=(($86+4)|0); //@line 3844 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($87)>>2)]=$84; //@line 3844 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $88=$4; //@line 3845 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $89=$1; //@line 3845 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $90=(($89+444)|0); //@line 3845 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $91=(($90+12)|0); //@line 3845 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($91)>>2)]=$88; //@line 3845 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $92=$ss; //@line 3846 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $93=$1; //@line 3846 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $94=(($93+444)|0); //@line 3846 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $95=(($94+8)|0); //@line 3846 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($95)>>2)]=$92; //@line 3846 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 9; break; //@line 3849 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 9: 
      var $97=$p; //@line 3850 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $98=$97; //@line 3850 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $99=(($98+4)|0); //@line 3850 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $100=$99; //@line 3850 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $nextp=$100; //@line 3850 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $101=$p; //@line 3851 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $102=(($101+4)|0); //@line 3851 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($102)>>2)]=7; //@line 3851 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $103=$nfences; //@line 3852 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $104=((($103)+(1))|0); //@line 3852 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $nfences=$104; //@line 3852 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $105=$nextp; //@line 3853 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $106=(($105+4)|0); //@line 3853 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $107=$106; //@line 3853 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $108=$old_end; //@line 3853 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $109=(($107)>>>0) < (($108)>>>0); //@line 3853 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($109) { __label__ = 10; break; } else { __label__ = 11; break; } //@line 3853 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 10: 
      var $111=$nextp; //@line 3854 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $p=$111; //@line 3854 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 12; break; //@line 3854 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 11: 
      __label__ = 13; break; //@line 3856 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 12: 
      __label__ = 9; break; //@line 3857 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 13: 
      var $115=$csp; //@line 3861 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $116=$old_top; //@line 3861 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $117=(($115)|0)!=(($116)|0); //@line 3861 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($117) { __label__ = 14; break; } else { __label__ = 50; break; } //@line 3861 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 14: 
      var $119=$old_top; //@line 3862 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $120=$119; //@line 3862 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $q=$120; //@line 3862 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $121=$csp; //@line 3863 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $122=$old_top; //@line 3863 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $123=$121; //@line 3863 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $124=$122; //@line 3863 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $125=((($123)-($124))|0); //@line 3863 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $psize=$125; //@line 3863 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $126=$q; //@line 3864 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $127=$126; //@line 3864 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $128=$psize; //@line 3864 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $129=(($127+$128)|0); //@line 3864 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $130=$129; //@line 3864 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $tn=$130; //@line 3864 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $131=$tn; //@line 3865 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $132=(($131+4)|0); //@line 3865 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $133=HEAP32[(($132)>>2)]; //@line 3865 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $134=$133 & -2; //@line 3865 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($132)>>2)]=$134; //@line 3865 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $135=$psize; //@line 3865 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $136=$135 | 1; //@line 3865 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $137=$q; //@line 3865 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $138=(($137+4)|0); //@line 3865 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($138)>>2)]=$136; //@line 3865 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $139=$psize; //@line 3865 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $140=$q; //@line 3865 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $141=$140; //@line 3865 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $142=$psize; //@line 3865 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $143=(($141+$142)|0); //@line 3865 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $144=$143; //@line 3865 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $145=(($144)|0); //@line 3865 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($145)>>2)]=$139; //@line 3865 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $146=$psize; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $147=$146 >>> 3; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $148=(($147)>>>0) < 32; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($148) { __label__ = 15; break; } else { __label__ = 22; break; } //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 15: 
      var $150=$psize; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $151=$150 >>> 3; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $I=$151; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $152=$I; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $153=$152 << 1; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $154=$1; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $155=(($154+40)|0); //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $156=(($155+($153<<2))|0); //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $157=$156; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $158=$157; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $B=$158; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $159=$B; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $F=$159; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $160=$1; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $161=(($160)|0); //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $162=HEAP32[(($161)>>2)]; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $163=$I; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $164=1 << $163; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $165=$162 & $164; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $166=(($165)|0)!=0; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($166) { __label__ = 17; break; } else { __label__ = 16; break; } //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 16: 
      var $168=$I; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $169=1 << $168; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $170=$1; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $171=(($170)|0); //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $172=HEAP32[(($171)>>2)]; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $173=$172 | $169; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($171)>>2)]=$173; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 21; break; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 17: 
      var $175=$B; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $176=(($175+8)|0); //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $177=HEAP32[(($176)>>2)]; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $178=$177; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $179=$1; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $180=(($179+16)|0); //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $181=HEAPU32[(($180)>>2)]; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $182=(($178)>>>0) >= (($181)>>>0); //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $183=(($182)&1); //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $184=(($183)==(1)); //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $185=(($184)|0)!=0; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($185) { __label__ = 18; break; } else { __label__ = 19; break; } //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 18: 
      var $187=$B; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $188=(($187+8)|0); //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $189=HEAP32[(($188)>>2)]; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $F=$189; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 20; break; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 19: 
      _abort(); //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      throw "Reached an unreachable!" //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 20: 
      __label__ = 21; break;
    case 21: 
      var $193=$q; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $194=$B; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $195=(($194+8)|0); //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($195)>>2)]=$193; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $196=$q; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $197=$F; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $198=(($197+12)|0); //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($198)>>2)]=$196; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $199=$F; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $200=$q; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $201=(($200+8)|0); //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($201)>>2)]=$199; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $202=$B; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $203=$q; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $204=(($203+12)|0); //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($204)>>2)]=$202; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 49; break; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 22: 
      var $206=$q; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $207=$206; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $TP=$207; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $208=$psize; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $209=$208 >>> 8; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $X=$209; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $210=$X; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $211=(($210)|0)==0; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($211) { __label__ = 23; break; } else { __label__ = 24; break; } //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 23: 
      $I1=0; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 28; break; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 24: 
      var $214=$X; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $215=(($214)>>>0) > 65535; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($215) { __label__ = 25; break; } else { __label__ = 26; break; } //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 25: 
      $I1=31; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 27; break; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 26: 
      var $218=$X; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $Y=$218; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $219=$Y; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $220=((($219)-(256))|0); //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $221=$220 >>> 16; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $222=$221 & 8; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $N=$222; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $223=$N; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $224=$Y; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $225=$224 << $223; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $Y=$225; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $226=((($225)-(4096))|0); //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $227=$226 >>> 16; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $228=$227 & 4; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $K=$228; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $229=$K; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $230=$N; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $231=((($230)+($229))|0); //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $N=$231; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $232=$K; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $233=$Y; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $234=$233 << $232; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $Y=$234; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $235=((($234)-(16384))|0); //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $236=$235 >>> 16; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $237=$236 & 2; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $K=$237; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $238=$N; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $239=((($238)+($237))|0); //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $N=$239; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $240=$N; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $241=(((14)-($240))|0); //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $242=$K; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $243=$Y; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $244=$243 << $242; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $Y=$244; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $245=$244 >>> 15; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $246=((($241)+($245))|0); //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $K=$246; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $247=$K; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $248=$247 << 1; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $249=$psize; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $250=$K; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $251=((($250)+(7))|0); //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $252=$249 >>> (($251)>>>0); //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $253=$252 & 1; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $254=((($248)+($253))|0); //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $I1=$254; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 27; break;
    case 27: 
      __label__ = 28; break;
    case 28: 
      var $257=$I1; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $258=$1; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $259=(($258+304)|0); //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $260=(($259+($257<<2))|0); //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $H=$260; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $261=$I1; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $262=$TP; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $263=(($262+28)|0); //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($263)>>2)]=$261; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $264=$TP; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $265=(($264+16)|0); //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $266=(($265+4)|0); //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($266)>>2)]=0; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $267=$TP; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $268=(($267+16)|0); //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $269=(($268)|0); //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($269)>>2)]=0; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $270=$1; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $271=(($270+4)|0); //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $272=HEAP32[(($271)>>2)]; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $273=$I1; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $274=1 << $273; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $275=$272 & $274; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $276=(($275)|0)!=0; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($276) { __label__ = 30; break; } else { __label__ = 29; break; } //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 29: 
      var $278=$I1; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $279=1 << $278; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $280=$1; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $281=(($280+4)|0); //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $282=HEAP32[(($281)>>2)]; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $283=$282 | $279; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($281)>>2)]=$283; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $284=$TP; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $285=$H; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($285)>>2)]=$284; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $286=$H; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $287=$286; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $288=$TP; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $289=(($288+24)|0); //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($289)>>2)]=$287; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $290=$TP; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $291=$TP; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $292=(($291+12)|0); //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($292)>>2)]=$290; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $293=$TP; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $294=(($293+8)|0); //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($294)>>2)]=$290; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 48; break; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 30: 
      var $296=$H; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $297=HEAP32[(($296)>>2)]; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $T=$297; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $298=$psize; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $299=$I1; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $300=(($299)|0)==31; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($300) { __label__ = 31; break; } else { __label__ = 32; break; } //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 31: 
      var $309 = 0;__label__ = 33; break; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 32: 
      var $303=$I1; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $304=$303 >>> 1; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $305=((($304)+(8))|0); //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $306=((($305)-(2))|0); //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $307=(((31)-($306))|0); //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $309 = $307;__label__ = 33; break; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 33: 
      var $309; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $310=$298 << $309; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $K2=$310; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 34; break; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 34: 
      var $312=$T; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $313=(($312+4)|0); //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $314=HEAP32[(($313)>>2)]; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $315=$314 & -8; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $316=$psize; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $317=(($315)|0)!=(($316)|0); //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($317) { __label__ = 35; break; } else { __label__ = 41; break; } //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 35: 
      var $319=$K2; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $320=$319 >>> 31; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $321=$320 & 1; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $322=$T; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $323=(($322+16)|0); //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $324=(($323+($321<<2))|0); //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $C=$324; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $325=$K2; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $326=$325 << 1; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $K2=$326; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $327=$C; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $328=HEAP32[(($327)>>2)]; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $329=(($328)|0)!=0; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($329) { __label__ = 36; break; } else { __label__ = 37; break; } //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 36: 
      var $331=$C; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $332=HEAP32[(($331)>>2)]; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $T=$332; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 40; break; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 37: 
      var $334=$C; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $335=$334; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $336=$1; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $337=(($336+16)|0); //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $338=HEAPU32[(($337)>>2)]; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $339=(($335)>>>0) >= (($338)>>>0); //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $340=(($339)&1); //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $341=(($340)==(1)); //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $342=(($341)|0)!=0; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($342) { __label__ = 38; break; } else { __label__ = 39; break; } //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 38: 
      var $344=$TP; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $345=$C; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($345)>>2)]=$344; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $346=$T; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $347=$TP; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $348=(($347+24)|0); //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($348)>>2)]=$346; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $349=$TP; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $350=$TP; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $351=(($350+12)|0); //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($351)>>2)]=$349; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $352=$TP; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $353=(($352+8)|0); //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($353)>>2)]=$349; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 47; break; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 39: 
      _abort(); //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      throw "Reached an unreachable!" //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 40: 
      __label__ = 46; break; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 41: 
      var $357=$T; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $358=(($357+8)|0); //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $359=HEAP32[(($358)>>2)]; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      $F3=$359; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $360=$T; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $361=$360; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $362=$1; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $363=(($362+16)|0); //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $364=HEAPU32[(($363)>>2)]; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $365=(($361)>>>0) >= (($364)>>>0); //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      if ($365) { __label__ = 42; break; } else { var $374 = 0;__label__ = 43; break; } //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 42: 
      var $367=$F3; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $368=$367; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $369=$1; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $370=(($369+16)|0); //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $371=HEAPU32[(($370)>>2)]; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $372=(($368)>>>0) >= (($371)>>>0); //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $374 = $372;__label__ = 43; break;
    case 43: 
      var $374;
      var $375=(($374)&1);
      var $376=(($375)==(1));
      var $377=(($376)|0)!=0;
      if ($377) { __label__ = 44; break; } else { __label__ = 45; break; }
    case 44: 
      var $379=$TP; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $380=$F3; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $381=(($380+12)|0); //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($381)>>2)]=$379; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $382=$T; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $383=(($382+8)|0); //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($383)>>2)]=$379; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $384=$F3; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $385=$TP; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $386=(($385+8)|0); //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($386)>>2)]=$384; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $387=$T; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $388=$TP; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $389=(($388+12)|0); //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($389)>>2)]=$387; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $390=$TP; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      var $391=(($390+24)|0); //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      HEAP32[(($391)>>2)]=0; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      __label__ = 47; break; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 45: 
      _abort(); //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
      throw "Reached an unreachable!" //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 46: 
      __label__ = 34; break; //@line 3866 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 47: 
      __label__ = 48; break;
    case 48: 
      __label__ = 49; break;
    case 49: 
      __label__ = 50; break; //@line 3867 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    case 50: 
      ;
      return; //@line 3870 "/home/manuel/tmp/mypdf/emscripten/system/lib/dlmalloc.c"
    default: assert(0, "bad label: " + __label__);
  }
}
_add_segment["X"]=1;
// Warning: printing of i64 values may be slightly rounded! No deep i64 math used, so precise i64 code not included
var i64Math = null;

  
  function _memset(ptr, value, num, align) {
      // TODO: make these settings, and in memcpy, {{'s
      if (num >= 20) {
        // This is unaligned, but quite large, so work hard to get to aligned settings
        var stop = ptr + num;
        while (ptr % 4) { // no need to check for stop, since we have large num
          HEAP8[ptr++] = value;
        }
        if (value < 0) value += 256; // make it unsigned
        var ptr4 = ptr >> 2, stop4 = stop >> 2, value4 = value | (value << 8) | (value << 16) | (value << 24);
        while (ptr4 < stop4) {
          HEAP32[ptr4++] = value4;
        }
        ptr = ptr4 << 2;
        while (ptr < stop) {
          HEAP8[ptr++] = value;
        }
      } else {
        while (num--) {
          HEAP8[ptr++] = value;
        }
      }
    }var _llvm_memset_p0i8_i32=_memset;

  
  function _memcpy(dest, src, num, align) {
      assert(num % 1 === 0, 'memcpy given ' + num + ' bytes to copy. Problem with quantum=1 corrections perhaps?');
      if (num >= 20 && src % 2 == dest % 2) {
        // This is unaligned, but quite large, and potentially alignable, so work hard to get to aligned settings
        if (src % 4 == dest % 4) {
          var stop = src + num;
          while (src % 4) { // no need to check for stop, since we have large num
            HEAP8[dest++] = HEAP8[src++];
          }
          var src4 = src >> 2, dest4 = dest >> 2, stop4 = stop >> 2;
          while (src4 < stop4) {
            HEAP32[dest4++] = HEAP32[src4++];
          }
          src = src4 << 2;
          dest = dest4 << 2;
          while (src < stop) {
            HEAP8[dest++] = HEAP8[src++];
          }
        } else {
          var stop = src + num;
          if (src % 2) { // no need to check for stop, since we have large num
            HEAP8[dest++] = HEAP8[src++];
          }
          var src2 = src >> 1, dest2 = dest >> 1, stop2 = stop >> 1;
          while (src2 < stop2) {
            HEAP16[dest2++] = HEAP16[src2++];
          }
          src = src2 << 1;
          dest = dest2 << 1;
          if (src < stop) {
            HEAP8[dest++] = HEAP8[src++];
          }
        }
      } else {
        while (num--) {
          HEAP8[dest++] = HEAP8[src++];
        }
      }
    }var _llvm_memcpy_p0i8_p0i8_i32=_memcpy;

  function _strlen(ptr) {
      return String_len(ptr);
    }

  
  
  function ___setErrNo(value) {
      // For convenient setting and returning of errno.
      if (!___setErrNo.ret) ___setErrNo.ret = allocate([0], 'i32', ALLOC_STATIC);
      HEAP32[((___setErrNo.ret)>>2)]=value
      return value;
    }function ___errno_location() {
      return ___setErrNo.ret;
    }var ___errno=___errno_location;

  function _memcmp(p1, p2, num) {
      for (var i = 0; i < num; i++) {
        var v1 = HEAPU8[((p1)+(i))];
        var v2 = HEAPU8[((p2)+(i))];
        if (v1 != v2) return v1 > v2 ? 1 : -1;
      }
      return 0;
    }

  
  function __formatString(format, varargs) {
      var textIndex = format;
      var argIndex = 0;
      function getNextArg(type) {
        // NOTE: Explicitly ignoring type safety. Otherwise this fails:
        //       int x = 4; printf("%c\n", (char)x);
        var ret;
        if (type === 'double') {
          ret = (tempDoubleI32[0]=HEAP32[(((varargs)+(argIndex))>>2)],tempDoubleI32[1]=HEAP32[(((varargs)+((argIndex)+(4)))>>2)],tempDoubleF64[0]);
        } else if (type == 'i64') {
          ret = [HEAP32[(((varargs)+(argIndex))>>2)],
                 HEAP32[(((varargs)+(argIndex+4))>>2)]];
        } else {
          type = 'i32'; // varargs are always i32, i64, or double
          ret = HEAP32[(((varargs)+(argIndex))>>2)];
        }
        argIndex += Runtime.getNativeFieldSize(type);
        return ret;
      }
  
      var ret = [];
      var curr, next, currArg;
      while(1) {
        var startTextIndex = textIndex;
        curr = HEAP8[(textIndex)];
        if (curr === 0) break;
        next = HEAP8[(textIndex+1)];
        if (curr == '%'.charCodeAt(0)) {
          // Handle flags.
          var flagAlwaysSigned = false;
          var flagLeftAlign = false;
          var flagAlternative = false;
          var flagZeroPad = false;
          flagsLoop: while (1) {
            switch (next) {
              case '+'.charCodeAt(0):
                flagAlwaysSigned = true;
                break;
              case '-'.charCodeAt(0):
                flagLeftAlign = true;
                break;
              case '#'.charCodeAt(0):
                flagAlternative = true;
                break;
              case '0'.charCodeAt(0):
                if (flagZeroPad) {
                  break flagsLoop;
                } else {
                  flagZeroPad = true;
                  break;
                }
              default:
                break flagsLoop;
            }
            textIndex++;
            next = HEAP8[(textIndex+1)];
          }
  
          // Handle width.
          var width = 0;
          if (next == '*'.charCodeAt(0)) {
            width = getNextArg('i32');
            textIndex++;
            next = HEAP8[(textIndex+1)];
          } else {
            while (next >= '0'.charCodeAt(0) && next <= '9'.charCodeAt(0)) {
              width = width * 10 + (next - '0'.charCodeAt(0));
              textIndex++;
              next = HEAP8[(textIndex+1)];
            }
          }
  
          // Handle precision.
          var precisionSet = false;
          if (next == '.'.charCodeAt(0)) {
            var precision = 0;
            precisionSet = true;
            textIndex++;
            next = HEAP8[(textIndex+1)];
            if (next == '*'.charCodeAt(0)) {
              precision = getNextArg('i32');
              textIndex++;
            } else {
              while(1) {
                var precisionChr = HEAP8[(textIndex+1)];
                if (precisionChr < '0'.charCodeAt(0) ||
                    precisionChr > '9'.charCodeAt(0)) break;
                precision = precision * 10 + (precisionChr - '0'.charCodeAt(0));
                textIndex++;
              }
            }
            next = HEAP8[(textIndex+1)];
          } else {
            var precision = 6; // Standard default.
          }
  
          // Handle integer sizes. WARNING: These assume a 32-bit architecture!
          var argSize;
          switch (String.fromCharCode(next)) {
            case 'h':
              var nextNext = HEAP8[(textIndex+2)];
              if (nextNext == 'h'.charCodeAt(0)) {
                textIndex++;
                argSize = 1; // char (actually i32 in varargs)
              } else {
                argSize = 2; // short (actually i32 in varargs)
              }
              break;
            case 'l':
              var nextNext = HEAP8[(textIndex+2)];
              if (nextNext == 'l'.charCodeAt(0)) {
                textIndex++;
                argSize = 8; // long long
              } else {
                argSize = 4; // long
              }
              break;
            case 'L': // long long
            case 'q': // int64_t
            case 'j': // intmax_t
              argSize = 8;
              break;
            case 'z': // size_t
            case 't': // ptrdiff_t
            case 'I': // signed ptrdiff_t or unsigned size_t
              argSize = 4;
              break;
            default:
              argSize = null;
          }
          if (argSize) textIndex++;
          next = HEAP8[(textIndex+1)];
  
          // Handle type specifier.
          if (['d', 'i', 'u', 'o', 'x', 'X', 'p'].indexOf(String.fromCharCode(next)) != -1) {
            // Integer.
            var signed = next == 'd'.charCodeAt(0) || next == 'i'.charCodeAt(0);
            argSize = argSize || 4;
            var currArg = getNextArg('i' + (argSize * 8));
            var origArg = currArg;
            var argText;
            // Flatten i64-1 [low, high] into a (slightly rounded) double
            if (argSize == 8) {
              currArg = Runtime.makeBigInt(currArg[0], currArg[1], next == 'u'.charCodeAt(0));
            }
            // Truncate to requested size.
            if (argSize <= 4) {
              var limit = Math.pow(256, argSize) - 1;
              currArg = (signed ? reSign : unSign)(currArg & limit, argSize * 8);
            }
            // Format the number.
            var currAbsArg = Math.abs(currArg);
            var prefix = '';
            if (next == 'd'.charCodeAt(0) || next == 'i'.charCodeAt(0)) {
              if (argSize == 8 && i64Math) argText = i64Math.stringify(origArg[0], origArg[1]); else
              argText = reSign(currArg, 8 * argSize, 1).toString(10);
            } else if (next == 'u'.charCodeAt(0)) {
              if (argSize == 8 && i64Math) argText = i64Math.stringify(origArg[0], origArg[1], true); else
              argText = unSign(currArg, 8 * argSize, 1).toString(10);
              currArg = Math.abs(currArg);
            } else if (next == 'o'.charCodeAt(0)) {
              argText = (flagAlternative ? '0' : '') + currAbsArg.toString(8);
            } else if (next == 'x'.charCodeAt(0) || next == 'X'.charCodeAt(0)) {
              prefix = flagAlternative ? '0x' : '';
              if (currArg < 0) {
                // Represent negative numbers in hex as 2's complement.
                currArg = -currArg;
                argText = (currAbsArg - 1).toString(16);
                var buffer = [];
                for (var i = 0; i < argText.length; i++) {
                  buffer.push((0xF - parseInt(argText[i], 16)).toString(16));
                }
                argText = buffer.join('');
                while (argText.length < argSize * 2) argText = 'f' + argText;
              } else {
                argText = currAbsArg.toString(16);
              }
              if (next == 'X'.charCodeAt(0)) {
                prefix = prefix.toUpperCase();
                argText = argText.toUpperCase();
              }
            } else if (next == 'p'.charCodeAt(0)) {
              if (currAbsArg === 0) {
                argText = '(nil)';
              } else {
                prefix = '0x';
                argText = currAbsArg.toString(16);
              }
            }
            if (precisionSet) {
              while (argText.length < precision) {
                argText = '0' + argText;
              }
            }
  
            // Add sign if needed
            if (flagAlwaysSigned) {
              if (currArg < 0) {
                prefix = '-' + prefix;
              } else {
                prefix = '+' + prefix;
              }
            }
  
            // Add padding.
            while (prefix.length + argText.length < width) {
              if (flagLeftAlign) {
                argText += ' ';
              } else {
                if (flagZeroPad) {
                  argText = '0' + argText;
                } else {
                  prefix = ' ' + prefix;
                }
              }
            }
  
            // Insert the result into the buffer.
            argText = prefix + argText;
            argText.split('').forEach(function(chr) {
              ret.push(chr.charCodeAt(0));
            });
          } else if (['f', 'F', 'e', 'E', 'g', 'G'].indexOf(String.fromCharCode(next)) != -1) {
            // Float.
            var currArg = getNextArg('double');
            var argText;
  
            if (isNaN(currArg)) {
              argText = 'nan';
              flagZeroPad = false;
            } else if (!isFinite(currArg)) {
              argText = (currArg < 0 ? '-' : '') + 'inf';
              flagZeroPad = false;
            } else {
              var isGeneral = false;
              var effectivePrecision = Math.min(precision, 20);
  
              // Convert g/G to f/F or e/E, as per:
              // http://pubs.opengroup.org/onlinepubs/9699919799/functions/printf.html
              if (next == 'g'.charCodeAt(0) || next == 'G'.charCodeAt(0)) {
                isGeneral = true;
                precision = precision || 1;
                var exponent = parseInt(currArg.toExponential(effectivePrecision).split('e')[1], 10);
                if (precision > exponent && exponent >= -4) {
                  next = ((next == 'g'.charCodeAt(0)) ? 'f' : 'F').charCodeAt(0);
                  precision -= exponent + 1;
                } else {
                  next = ((next == 'g'.charCodeAt(0)) ? 'e' : 'E').charCodeAt(0);
                  precision--;
                }
                effectivePrecision = Math.min(precision, 20);
              }
  
              if (next == 'e'.charCodeAt(0) || next == 'E'.charCodeAt(0)) {
                argText = currArg.toExponential(effectivePrecision);
                // Make sure the exponent has at least 2 digits.
                if (/[eE][-+]\d$/.test(argText)) {
                  argText = argText.slice(0, -1) + '0' + argText.slice(-1);
                }
              } else if (next == 'f'.charCodeAt(0) || next == 'F'.charCodeAt(0)) {
                argText = currArg.toFixed(effectivePrecision);
              }
  
              var parts = argText.split('e');
              if (isGeneral && !flagAlternative) {
                // Discard trailing zeros and periods.
                while (parts[0].length > 1 && parts[0].indexOf('.') != -1 &&
                       (parts[0].slice(-1) == '0' || parts[0].slice(-1) == '.')) {
                  parts[0] = parts[0].slice(0, -1);
                }
              } else {
                // Make sure we have a period in alternative mode.
                if (flagAlternative && argText.indexOf('.') == -1) parts[0] += '.';
                // Zero pad until required precision.
                while (precision > effectivePrecision++) parts[0] += '0';
              }
              argText = parts[0] + (parts.length > 1 ? 'e' + parts[1] : '');
  
              // Capitalize 'E' if needed.
              if (next == 'E'.charCodeAt(0)) argText = argText.toUpperCase();
  
              // Add sign.
              if (flagAlwaysSigned && currArg >= 0) {
                argText = '+' + argText;
              }
            }
  
            // Add padding.
            while (argText.length < width) {
              if (flagLeftAlign) {
                argText += ' ';
              } else {
                if (flagZeroPad && (argText[0] == '-' || argText[0] == '+')) {
                  argText = argText[0] + '0' + argText.slice(1);
                } else {
                  argText = (flagZeroPad ? '0' : ' ') + argText;
                }
              }
            }
  
            // Adjust case.
            if (next < 'a'.charCodeAt(0)) argText = argText.toUpperCase();
  
            // Insert the result into the buffer.
            argText.split('').forEach(function(chr) {
              ret.push(chr.charCodeAt(0));
            });
          } else if (next == 's'.charCodeAt(0)) {
            // String.
            var arg = getNextArg('i8*') || nullString;
            var argLength = String_len(arg);
            if (precisionSet) argLength = Math.min(argLength, precision);
            if (!flagLeftAlign) {
              while (argLength < width--) {
                ret.push(' '.charCodeAt(0));
              }
            }
            for (var i = 0; i < argLength; i++) {
              ret.push(HEAPU8[(arg++)]);
            }
            if (flagLeftAlign) {
              while (argLength < width--) {
                ret.push(' '.charCodeAt(0));
              }
            }
          } else if (next == 'c'.charCodeAt(0)) {
            // Character.
            if (flagLeftAlign) ret.push(getNextArg('i8'));
            while (--width > 0) {
              ret.push(' '.charCodeAt(0));
            }
            if (!flagLeftAlign) ret.push(getNextArg('i8'));
          } else if (next == 'n'.charCodeAt(0)) {
            // Write the length written so far to the next parameter.
            var ptr = getNextArg('i32*');
            HEAP32[((ptr)>>2)]=ret.length
          } else if (next == '%'.charCodeAt(0)) {
            // Literal percent sign.
            ret.push(curr);
          } else {
            // Unknown specifiers remain untouched.
            for (var i = startTextIndex; i < textIndex + 2; i++) {
              ret.push(HEAP8[(i)]);
            }
          }
          textIndex += 2;
          // TODO: Support a/A (hex float) and m (last error) specifiers.
          // TODO: Support %1${specifier} for arg selection.
        } else {
          ret.push(curr);
          textIndex += 1;
        }
      }
      return ret;
    }function _snprintf(s, n, format, varargs) {
      // int snprintf(char *restrict s, size_t n, const char *restrict format, ...);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/printf.html
      var result = __formatString(format, varargs);
      var limit = (n === undefined) ? result.length
                                    : Math.min(result.length, n - 1);
      for (var i = 0; i < limit; i++) {
        HEAP8[((s)+(i))]=result[i];
      }
      HEAP8[((s)+(i))]=0;
      return result.length;
    }

  
  
  
  var ERRNO_CODES={E2BIG:7,EACCES:13,EADDRINUSE:98,EADDRNOTAVAIL:99,EAFNOSUPPORT:97,EAGAIN:11,EALREADY:114,EBADF:9,EBADMSG:74,EBUSY:16,ECANCELED:125,ECHILD:10,ECONNABORTED:103,ECONNREFUSED:111,ECONNRESET:104,EDEADLK:35,EDESTADDRREQ:89,EDOM:33,EDQUOT:122,EEXIST:17,EFAULT:14,EFBIG:27,EHOSTUNREACH:113,EIDRM:43,EILSEQ:84,EINPROGRESS:115,EINTR:4,EINVAL:22,EIO:5,EISCONN:106,EISDIR:21,ELOOP:40,EMFILE:24,EMLINK:31,EMSGSIZE:90,EMULTIHOP:72,ENAMETOOLONG:36,ENETDOWN:100,ENETRESET:102,ENETUNREACH:101,ENFILE:23,ENOBUFS:105,ENODATA:61,ENODEV:19,ENOENT:2,ENOEXEC:8,ENOLCK:37,ENOLINK:67,ENOMEM:12,ENOMSG:42,ENOPROTOOPT:92,ENOSPC:28,ENOSR:63,ENOSTR:60,ENOSYS:38,ENOTCONN:107,ENOTDIR:20,ENOTEMPTY:39,ENOTRECOVERABLE:131,ENOTSOCK:88,ENOTSUP:95,ENOTTY:25,ENXIO:6,EOVERFLOW:75,EOWNERDEAD:130,EPERM:1,EPIPE:32,EPROTO:71,EPROTONOSUPPORT:93,EPROTOTYPE:91,ERANGE:34,EROFS:30,ESPIPE:29,ESRCH:3,ESTALE:116,ETIME:62,ETIMEDOUT:110,ETXTBSY:26,EWOULDBLOCK:11,EXDEV:18};
  
  var _stdin=0;
  
  var _stdout=0;
  
  var _stderr=0;
  
  var __impure_ptr=0;var FS={currentPath:"/",nextInode:2,streams:[null],checkStreams:function () {
        for (var i in FS.streams) assert(i >= 0 && i < FS.streams.length); // no keys not in dense span
        for (var i = 0; i < FS.streams.length; i++) assert(typeof FS.streams[i] == 'object'); // no non-null holes in dense span
      },ignorePermissions:true,joinPath:function (parts, forceRelative) {
        var ret = parts[0];
        for (var i = 1; i < parts.length; i++) {
          if (ret[ret.length-1] != '/') ret += '/';
          ret += parts[i];
        }
        if (forceRelative && ret[0] == '/') ret = ret.substr(1);
        return ret;
      },absolutePath:function (relative, base) {
        if (typeof relative !== 'string') return null;
        if (base === undefined) base = FS.currentPath;
        if (relative && relative[0] == '/') base = '';
        var full = base + '/' + relative;
        var parts = full.split('/').reverse();
        var absolute = [''];
        while (parts.length) {
          var part = parts.pop();
          if (part == '' || part == '.') {
            // Nothing.
          } else if (part == '..') {
            if (absolute.length > 1) absolute.pop();
          } else {
            absolute.push(part);
          }
        }
        return absolute.length == 1 ? '/' : absolute.join('/');
      },analyzePath:function (path, dontResolveLastLink, linksVisited) {
        var ret = {
          isRoot: false,
          exists: false,
          error: 0,
          name: null,
          path: null,
          object: null,
          parentExists: false,
          parentPath: null,
          parentObject: null
        };
        path = FS.absolutePath(path);
        if (path == '/') {
          ret.isRoot = true;
          ret.exists = ret.parentExists = true;
          ret.name = '/';
          ret.path = ret.parentPath = '/';
          ret.object = ret.parentObject = FS.root;
        } else if (path !== null) {
          linksVisited = linksVisited || 0;
          path = path.slice(1).split('/');
          var current = FS.root;
          var traversed = [''];
          while (path.length) {
            if (path.length == 1 && current.isFolder) {
              ret.parentExists = true;
              ret.parentPath = traversed.length == 1 ? '/' : traversed.join('/');
              ret.parentObject = current;
              ret.name = path[0];
            }
            var target = path.shift();
            if (!current.isFolder) {
              ret.error = ERRNO_CODES.ENOTDIR;
              break;
            } else if (!current.read) {
              ret.error = ERRNO_CODES.EACCES;
              break;
            } else if (!current.contents.hasOwnProperty(target)) {
              ret.error = ERRNO_CODES.ENOENT;
              break;
            }
            current = current.contents[target];
            if (current.link && !(dontResolveLastLink && path.length == 0)) {
              if (linksVisited > 40) { // Usual Linux SYMLOOP_MAX.
                ret.error = ERRNO_CODES.ELOOP;
                break;
              }
              var link = FS.absolutePath(current.link, traversed.join('/'));
              ret = FS.analyzePath([link].concat(path).join('/'),
                                   dontResolveLastLink, linksVisited + 1);
              return ret;
            }
            traversed.push(target);
            if (path.length == 0) {
              ret.exists = true;
              ret.path = traversed.join('/');
              ret.object = current;
            }
          }
        }
        return ret;
      },findObject:function (path, dontResolveLastLink) {
        FS.ensureRoot();
        var ret = FS.analyzePath(path, dontResolveLastLink);
        if (ret.exists) {
          return ret.object;
        } else {
          ___setErrNo(ret.error);
          return null;
        }
      },createObject:function (parent, name, properties, canRead, canWrite) {
        if (!parent) parent = '/';
        if (typeof parent === 'string') parent = FS.findObject(parent);
  
        if (!parent) {
          ___setErrNo(ERRNO_CODES.EACCES);
          throw new Error('Parent path must exist.');
        }
        if (!parent.isFolder) {
          ___setErrNo(ERRNO_CODES.ENOTDIR);
          throw new Error('Parent must be a folder.');
        }
        if (!parent.write && !FS.ignorePermissions) {
          ___setErrNo(ERRNO_CODES.EACCES);
          throw new Error('Parent folder must be writeable.');
        }
        if (!name || name == '.' || name == '..') {
          ___setErrNo(ERRNO_CODES.ENOENT);
          throw new Error('Name must not be empty.');
        }
        if (parent.contents.hasOwnProperty(name)) {
          ___setErrNo(ERRNO_CODES.EEXIST);
          throw new Error("Can't overwrite object.");
        }
  
        parent.contents[name] = {
          read: canRead === undefined ? true : canRead,
          write: canWrite === undefined ? false : canWrite,
          timestamp: Date.now(),
          inodeNumber: FS.nextInode++
        };
        for (var key in properties) {
          if (properties.hasOwnProperty(key)) {
            parent.contents[name][key] = properties[key];
          }
        }
  
        return parent.contents[name];
      },createFolder:function (parent, name, canRead, canWrite) {
        var properties = {isFolder: true, isDevice: false, contents: {}};
        return FS.createObject(parent, name, properties, canRead, canWrite);
      },createPath:function (parent, path, canRead, canWrite) {
        var current = FS.findObject(parent);
        if (current === null) throw new Error('Invalid parent.');
        path = path.split('/').reverse();
        while (path.length) {
          var part = path.pop();
          if (!part) continue;
          if (!current.contents.hasOwnProperty(part)) {
            FS.createFolder(current, part, canRead, canWrite);
          }
          current = current.contents[part];
        }
        return current;
      },createFile:function (parent, name, properties, canRead, canWrite) {
        properties.isFolder = false;
        return FS.createObject(parent, name, properties, canRead, canWrite);
      },createDataFile:function (parent, name, data, canRead, canWrite) {
        if (typeof data === 'string') {
          var dataArray = new Array(data.length);
          for (var i = 0, len = data.length; i < len; ++i) dataArray[i] = data.charCodeAt(i);
          data = dataArray;
        }
        var properties = {
          isDevice: false,
          contents: data.subarray ? data.subarray(0) : data // as an optimization, create a new array wrapper (not buffer) here, to help JS engines understand this object
        };
        return FS.createFile(parent, name, properties, canRead, canWrite);
      },createLazyFile:function (parent, name, url, canRead, canWrite) {
        var properties = {isDevice: false, url: url};
        return FS.createFile(parent, name, properties, canRead, canWrite);
      },createPreloadedFile:function (parent, name, url, canRead, canWrite, onload, onerror) {
        Browser.ensureObjects();
        var fullname = FS.joinPath([parent, name], true);
        function processData(byteArray) {
          function finish(byteArray) {
            FS.createDataFile(parent, name, byteArray, canRead, canWrite);
            if (onload) onload();
            removeRunDependency('cp ' + fullname);
          }
          var handled = false;
          Module['preloadPlugins'].forEach(function(plugin) {
            if (handled) return;
            if (plugin['canHandle'](fullname)) {
              plugin['handle'](byteArray, fullname, finish, function() {
                if (onerror) onerror();
                removeRunDependency('cp ' + fullname);
              });
              handled = true;
            }
          });
          if (!handled) finish(byteArray);
        }
        addRunDependency('cp ' + fullname);
        if (typeof url == 'string') {
          Browser.asyncLoad(url, function(byteArray) {
            processData(byteArray);
          }, onerror);
        } else {
          processData(url);
        }
      },createLink:function (parent, name, target, canRead, canWrite) {
        var properties = {isDevice: false, link: target};
        return FS.createFile(parent, name, properties, canRead, canWrite);
      },createDevice:function (parent, name, input, output) {
        if (!(input || output)) {
          throw new Error('A device must have at least one callback defined.');
        }
        var ops = {isDevice: true, input: input, output: output};
        return FS.createFile(parent, name, ops, Boolean(input), Boolean(output));
      },forceLoadFile:function (obj) {
        if (obj.isDevice || obj.isFolder || obj.link || obj.contents) return true;
        var success = true;
        if (typeof XMLHttpRequest !== 'undefined') {
          // Browser.
          assert('Cannot do synchronous binary XHRs in modern browsers. Use --embed-file or --preload-file in emcc');
        } else if (Module['read']) {
          // Command-line.
          try {
            // WARNING: Can't read binary files in V8's d8 or tracemonkey's js, as
            //          read() will try to parse UTF8.
            obj.contents = intArrayFromString(Module['read'](obj.url), true);
          } catch (e) {
            success = false;
          }
        } else {
          throw new Error('Cannot load without read() or XMLHttpRequest.');
        }
        if (!success) ___setErrNo(ERRNO_CODES.EIO);
        return success;
      },ensureRoot:function () {
        if (FS.root) return;
        // The main file system tree. All the contents are inside this.
        FS.root = {
          read: true,
          write: true,
          isFolder: true,
          isDevice: false,
          timestamp: Date.now(),
          inodeNumber: 1,
          contents: {}
        };
      },init:function (input, output, error) {
        // Make sure we initialize only once.
        assert(!FS.init.initialized, 'FS.init was previously called. If you want to initialize later with custom parameters, remove any earlier calls (note that one is automatically added to the generated code)');
        FS.init.initialized = true;
  
        FS.ensureRoot();
  
        // Allow Module.stdin etc. to provide defaults, if none explicitly passed to us here
        input = input || Module['stdin'];
        output = output || Module['stdout'];
        error = error || Module['stderr'];
  
        // Default handlers.
        var stdinOverridden = true, stdoutOverridden = true, stderrOverridden = true;
        if (!input) {
          stdinOverridden = false;
          input = function() {
            if (!input.cache || !input.cache.length) {
              var result;
              if (typeof window != 'undefined' &&
                  typeof window.prompt == 'function') {
                // Browser.
                result = window.prompt('Input: ');
                if (result === null) result = String.fromCharCode(0); // cancel ==> EOF
              } else if (typeof readline == 'function') {
                // Command line.
                result = readline();
              }
              if (!result) result = '';
              input.cache = intArrayFromString(result + '\n', true);
            }
            return input.cache.shift();
          };
        }
        var utf8 = new Runtime.UTF8Processor();
        function simpleOutput(val) {
          if (val === null || val === '\n'.charCodeAt(0)) {
            output.printer(output.buffer.join(''));
            output.buffer = [];
          } else {
            output.buffer.push(utf8.processCChar(val));
          }
        }
        if (!output) {
          stdoutOverridden = false;
          output = simpleOutput;
        }
        if (!output.printer) output.printer = Module['print'];
        if (!output.buffer) output.buffer = [];
        if (!error) {
          stderrOverridden = false;
          error = simpleOutput;
        }
        if (!error.printer) error.printer = Module['print'];
        if (!error.buffer) error.buffer = [];
  
        // Create the temporary folder, if not already created
        try {
          FS.createFolder('/', 'tmp', true, true);
        } catch(e) {}
  
        // Create the I/O devices.
        var devFolder = FS.createFolder('/', 'dev', true, true);
        var stdin = FS.createDevice(devFolder, 'stdin', input);
        var stdout = FS.createDevice(devFolder, 'stdout', null, output);
        var stderr = FS.createDevice(devFolder, 'stderr', null, error);
        FS.createDevice(devFolder, 'tty', input, output);
  
        // Create default streams.
        FS.streams[1] = {
          path: '/dev/stdin',
          object: stdin,
          position: 0,
          isRead: true,
          isWrite: false,
          isAppend: false,
          isTerminal: !stdinOverridden,
          error: false,
          eof: false,
          ungotten: []
        };
        FS.streams[2] = {
          path: '/dev/stdout',
          object: stdout,
          position: 0,
          isRead: false,
          isWrite: true,
          isAppend: false,
          isTerminal: !stdoutOverridden,
          error: false,
          eof: false,
          ungotten: []
        };
        FS.streams[3] = {
          path: '/dev/stderr',
          object: stderr,
          position: 0,
          isRead: false,
          isWrite: true,
          isAppend: false,
          isTerminal: !stderrOverridden,
          error: false,
          eof: false,
          ungotten: []
        };
        // Allocate these on the stack (and never free, we are called from ATINIT or earlier), to keep their locations low
        _stdin = allocate([1], 'void*', ALLOC_STACK);
        _stdout = allocate([2], 'void*', ALLOC_STACK);
        _stderr = allocate([3], 'void*', ALLOC_STACK);
  
        // Other system paths
        FS.createPath('/', 'dev/shm/tmp', true, true); // temp files
  
        // Newlib initialization
        for (var i = FS.streams.length; i < Math.max(_stdin, _stdout, _stderr) + 4; i++) {
          FS.streams[i] = null; // Make sure to keep FS.streams dense
        }
        FS.streams[_stdin] = FS.streams[1];
        FS.streams[_stdout] = FS.streams[2];
        FS.streams[_stderr] = FS.streams[3];
        FS.checkStreams();
        assert(FS.streams.length < 1024); // at this early stage, we should not have a large set of file descriptors - just a few
        __impure_ptr = allocate([ allocate(
          [0, 0, 0, 0, _stdin, 0, 0, 0, _stdout, 0, 0, 0, _stderr, 0, 0, 0],
          'void*', ALLOC_STATIC) ], 'void*', ALLOC_STATIC);
      },quit:function () {
        if (!FS.init.initialized) return;
        // Flush any partially-printed lines in stdout and stderr. Careful, they may have been closed
        if (FS.streams[2] && FS.streams[2].object.output.buffer.length > 0) FS.streams[2].object.output('\n'.charCodeAt(0));
        if (FS.streams[3] && FS.streams[3].object.output.buffer.length > 0) FS.streams[3].object.output('\n'.charCodeAt(0));
      },standardizePath:function (path) {
        if (path.substr(0, 2) == './') path = path.substr(2);
        return path;
      },deleteFile:function (path) {
        var path = FS.analyzePath(path);
        if (!path.parentExists || !path.exists) {
          throw 'Invalid path ' + path;
        }
        delete path.parentObject.contents[path.name];
      }};
  
  
  function _pwrite(fildes, buf, nbyte, offset) {
      // ssize_t pwrite(int fildes, const void *buf, size_t nbyte, off_t offset);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/write.html
      var stream = FS.streams[fildes];
      if (!stream || stream.object.isDevice) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      } else if (!stream.isWrite) {
        ___setErrNo(ERRNO_CODES.EACCES);
        return -1;
      } else if (stream.object.isFolder) {
        ___setErrNo(ERRNO_CODES.EISDIR);
        return -1;
      } else if (nbyte < 0 || offset < 0) {
        ___setErrNo(ERRNO_CODES.EINVAL);
        return -1;
      } else {
        var contents = stream.object.contents;
        while (contents.length < offset) contents.push(0);
        for (var i = 0; i < nbyte; i++) {
          contents[offset + i] = HEAPU8[((buf)+(i))];
        }
        stream.object.timestamp = Date.now();
        return i;
      }
    }function _write(fildes, buf, nbyte) {
      // ssize_t write(int fildes, const void *buf, size_t nbyte);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/write.html
      var stream = FS.streams[fildes];
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      } else if (!stream.isWrite) {
        ___setErrNo(ERRNO_CODES.EACCES);
        return -1;
      } else if (nbyte < 0) {
        ___setErrNo(ERRNO_CODES.EINVAL);
        return -1;
      } else {
        if (stream.object.isDevice) {
          if (stream.object.output) {
            for (var i = 0; i < nbyte; i++) {
              try {
                stream.object.output(HEAP8[((buf)+(i))]);
              } catch (e) {
                ___setErrNo(ERRNO_CODES.EIO);
                return -1;
              }
            }
            stream.object.timestamp = Date.now();
            return i;
          } else {
            ___setErrNo(ERRNO_CODES.ENXIO);
            return -1;
          }
        } else {
          var bytesWritten = _pwrite(fildes, buf, nbyte, stream.position);
          if (bytesWritten != -1) stream.position += bytesWritten;
          return bytesWritten;
        }
      }
    }function _fwrite(ptr, size, nitems, stream) {
      // size_t fwrite(const void *restrict ptr, size_t size, size_t nitems, FILE *restrict stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fwrite.html
      var bytesToWrite = nitems * size;
      if (bytesToWrite == 0) return 0;
      var bytesWritten = _write(stream, ptr, bytesToWrite);
      if (bytesWritten == -1) {
        if (FS.streams[stream]) FS.streams[stream].error = true;
        return -1;
      } else {
        return Math.floor(bytesWritten / size);
      }
    }function _fprintf(stream, format, varargs) {
      // int fprintf(FILE *restrict stream, const char *restrict format, ...);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/printf.html
      var result = __formatString(format, varargs);
      var stack = Runtime.stackSave();
      var ret = _fwrite(allocate(result, 'i8', ALLOC_STACK), 1, result.length, stream);
      Runtime.stackRestore(stack);
      return ret;
    }

  function _abort() {
      ABORT = true;
      throw 'abort() at ' + (new Error().stack);
    }
var _setjmp; // stub for _setjmp

  function _longjmp(env, value) {
      throw { longjmp: true, label: HEAP32[((env)>>2)], value: value || 1 };
    }

  
  
  function _pread(fildes, buf, nbyte, offset) {
      // ssize_t pread(int fildes, void *buf, size_t nbyte, off_t offset);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/read.html
      var stream = FS.streams[fildes];
      if (!stream || stream.object.isDevice) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      } else if (!stream.isRead) {
        ___setErrNo(ERRNO_CODES.EACCES);
        return -1;
      } else if (stream.object.isFolder) {
        ___setErrNo(ERRNO_CODES.EISDIR);
        return -1;
      } else if (nbyte < 0 || offset < 0) {
        ___setErrNo(ERRNO_CODES.EINVAL);
        return -1;
      } else {
        var bytesRead = 0;
        while (stream.ungotten.length && nbyte > 0) {
          HEAP8[(buf++)]=stream.ungotten.pop()
          nbyte--;
          bytesRead++;
        }
        var contents = stream.object.contents;
        var size = Math.min(contents.length - offset, nbyte);
        for (var i = 0; i < size; i++) {
          HEAP8[((buf)+(i))]=contents[offset + i]
        }
        bytesRead += size;
        return bytesRead;
      }
    }function _read(fildes, buf, nbyte) {
      // ssize_t read(int fildes, void *buf, size_t nbyte);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/read.html
      var stream = FS.streams[fildes];
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      } else if (!stream.isRead) {
        ___setErrNo(ERRNO_CODES.EACCES);
        return -1;
      } else if (nbyte < 0) {
        ___setErrNo(ERRNO_CODES.EINVAL);
        return -1;
      } else {
        var bytesRead;
        if (stream.object.isDevice) {
          if (stream.object.input) {
            bytesRead = 0;
            while (stream.ungotten.length && nbyte > 0) {
              HEAP8[(buf++)]=stream.ungotten.pop()
              nbyte--;
              bytesRead++;
            }
            for (var i = 0; i < nbyte; i++) {
              try {
                var result = stream.object.input();
              } catch (e) {
                ___setErrNo(ERRNO_CODES.EIO);
                return -1;
              }
              if (result === null || result === undefined) break;
              bytesRead++;
              HEAP8[((buf)+(i))]=result
            }
            return bytesRead;
          } else {
            ___setErrNo(ERRNO_CODES.ENXIO);
            return -1;
          }
        } else {
          var ungotSize = stream.ungotten.length;
          bytesRead = _pread(fildes, buf, nbyte, stream.position);
          if (bytesRead != -1) {
            stream.position += (stream.ungotten.length - ungotSize) + bytesRead;
          }
          return bytesRead;
        }
      }
    }function _fread(ptr, size, nitems, stream) {
      // size_t fread(void *restrict ptr, size_t size, size_t nitems, FILE *restrict stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fread.html
      var bytesToRead = nitems * size;
      if (bytesToRead == 0) return 0;
      var bytesRead = _read(stream, ptr, bytesToRead);
      var streamObj = FS.streams[stream];
      if (bytesRead == -1) {
        if (streamObj) streamObj.error = true;
        return -1;
      } else {
        if (bytesRead < bytesToRead) streamObj.eof = true;
        return Math.floor(bytesRead / size);
      }
    }

  var _fabs=Math.abs;

  var _llvm_pow_f64=Math.pow;

  
  function _isspace(chr) {
      return chr in { 32: 0, 9: 0, 10: 0, 11: 0, 12: 0, 13: 0 };
    }
  
  function _isdigit(chr) {
      return chr >= '0'.charCodeAt(0) && chr <= '9'.charCodeAt(0);
    }function _strtod(str, endptr) {
      var origin = str;
  
      // Skip space.
      while (_isspace(HEAP8[(str)])) str++;
  
      // Check for a plus/minus sign.
      var multiplier = 1;
      if (HEAP8[(str)] == '-'.charCodeAt(0)) {
        multiplier = -1;
        str++;
      } else if (HEAP8[(str)] == '+'.charCodeAt(0)) {
        str++;
      }
  
      var chr;
      var ret = 0;
  
      // Get whole part.
      var whole = false;
      while(1) {
        chr = HEAP8[(str)];
        if (!_isdigit(chr)) break;
        whole = true;
        ret = ret*10 + chr - '0'.charCodeAt(0);
        str++;
      }
  
      // Get fractional part.
      var fraction = false;
      if (HEAP8[(str)] == '.'.charCodeAt(0)) {
        str++;
        var mul = 1/10;
        while(1) {
          chr = HEAP8[(str)];
          if (!_isdigit(chr)) break;
          fraction = true;
          ret += mul*(chr - '0'.charCodeAt(0));
          mul /= 10;
          str++;
        }
      }
  
      if (!whole && !fraction) {
        if (endptr) {
          HEAP32[((endptr)>>2)]=origin
        }
        return 0;
      }
  
      // Get exponent part.
      chr = HEAP8[(str)];
      if (chr == 'e'.charCodeAt(0) || chr == 'E'.charCodeAt(0)) {
        str++;
        var exponent = 0;
        var expNegative = false;
        chr = HEAP8[(str)];
        if (chr == '-'.charCodeAt(0)) {
          expNegative = true;
          str++;
        } else if (chr == '+'.charCodeAt(0)) {
          str++;
        }
        chr = HEAP8[(str)];
        while(1) {
          if (!_isdigit(chr)) break;
          exponent = exponent*10 + chr - '0'.charCodeAt(0);
          str++;
          chr = HEAP8[(str)];
        }
        if (expNegative) exponent = -exponent;
        ret *= Math.pow(10, exponent);
      }
  
      // Set end pointer.
      if (endptr) {
        HEAP32[((endptr)>>2)]=str
      }
  
      return ret * multiplier;
    }


  function _time(ptr) {
      var ret = Math.floor(Date.now()/1000);
      if (ptr) {
        HEAP32[((ptr)>>2)]=ret
      }
      return ret;
    }

  
  function _memmove(dest, src, num, align) {
      if (src < dest && dest < src + num) {
        // Copy backwards in a safe manner
        src += num;
        dest += num;
        while (num--) {
          dest--;
          src--;
          HEAP8[(dest)]=HEAP8[(src)];
        }
      } else {
        _memcpy(dest, src, num, align);
      }
    }var _llvm_memmove_p0i8_p0i8_i32=_memmove;

  var _cos=Math.cos;

  var _sin=Math.sin;

  
  
  var ___dirent_struct_layout=null;function _open(path, oflag, varargs) {
      // int open(const char *path, int oflag, ...);
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/open.html
      // NOTE: This implementation tries to mimic glibc rather that strictly
      // following the POSIX standard.
  
      var mode = HEAP32[((varargs)>>2)];
  
      // Simplify flags.
      var accessMode = oflag & 3;
      var isWrite = accessMode != 0;
      var isRead = accessMode != 1;
      var isCreate = Boolean(oflag & 512);
      var isExistCheck = Boolean(oflag & 2048);
      var isTruncate = Boolean(oflag & 1024);
      var isAppend = Boolean(oflag & 8);
  
      // Verify path.
      var origPath = path;
      path = FS.analyzePath(Pointer_stringify(path));
      if (!path.parentExists) {
        ___setErrNo(path.error);
        return -1;
      }
      var target = path.object || null;
      var finalPath;
  
      // Verify the file exists, create if needed and allowed.
      if (target) {
        if (isCreate && isExistCheck) {
          ___setErrNo(ERRNO_CODES.EEXIST);
          return -1;
        }
        if ((isWrite || isCreate || isTruncate) && target.isFolder) {
          ___setErrNo(ERRNO_CODES.EISDIR);
          return -1;
        }
        if (isRead && !target.read || isWrite && !target.write) {
          ___setErrNo(ERRNO_CODES.EACCES);
          return -1;
        }
        if (isTruncate && !target.isDevice) {
          target.contents = [];
        } else {
          if (!FS.forceLoadFile(target)) {
            ___setErrNo(ERRNO_CODES.EIO);
            return -1;
          }
        }
        finalPath = path.path;
      } else {
        if (!isCreate) {
          ___setErrNo(ERRNO_CODES.ENOENT);
          return -1;
        }
        if (!path.parentObject.write) {
          ___setErrNo(ERRNO_CODES.EACCES);
          return -1;
        }
        target = FS.createDataFile(path.parentObject, path.name, [],
                                   mode & 0x100, mode & 0x80);  // S_IRUSR, S_IWUSR.
        finalPath = path.parentPath + '/' + path.name;
      }
      // Actually create an open stream.
      var id = FS.streams.length; // Keep dense
      if (target.isFolder) {
        var entryBuffer = 0;
        if (___dirent_struct_layout) {
          entryBuffer = _malloc(___dirent_struct_layout.__size__);
        }
        var contents = [];
        for (var key in target.contents) contents.push(key);
        FS.streams[id] = {
          path: finalPath,
          object: target,
          // An index into contents. Special values: -2 is ".", -1 is "..".
          position: -2,
          isRead: true,
          isWrite: false,
          isAppend: false,
          error: false,
          eof: false,
          ungotten: [],
          // Folder-specific properties:
          // Remember the contents at the time of opening in an array, so we can
          // seek between them relying on a single order.
          contents: contents,
          // Each stream has its own area for readdir() returns.
          currentEntry: entryBuffer
        };
      } else {
        FS.streams[id] = {
          path: finalPath,
          object: target,
          position: 0,
          isRead: isRead,
          isWrite: isWrite,
          isAppend: isAppend,
          error: false,
          eof: false,
          ungotten: []
        };
      }
      FS.checkStreams();
      return id;
    }function _fopen(filename, mode) {
      // FILE *fopen(const char *restrict filename, const char *restrict mode);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fopen.html
      var flags;
      mode = Pointer_stringify(mode);
      if (mode[0] == 'r') {
        if (mode.indexOf('+') != -1) {
          flags = 2;
        } else {
          flags = 0;
        }
      } else if (mode[0] == 'w') {
        if (mode.indexOf('+') != -1) {
          flags = 2;
        } else {
          flags = 1;
        }
        flags |= 512;
        flags |= 1024;
      } else if (mode[0] == 'a') {
        if (mode.indexOf('+') != -1) {
          flags = 2;
        } else {
          flags = 1;
        }
        flags |= 512;
        flags |= 8;
      } else {
        ___setErrNo(ERRNO_CODES.EINVAL);
        return 0;
      }
      var ret = _open(filename, flags, allocate([0x1FF, 0, 0, 0], 'i32', ALLOC_STACK));  // All creation permissions.
      return (ret == -1) ? 0 : ret;
    }

  function _feof(stream) {
      // int feof(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/feof.html
      return Number(FS.streams[stream] && FS.streams[stream].eof);
    }

  function _ferror(stream) {
      // int ferror(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/ferror.html
      return Number(FS.streams[stream] && FS.streams[stream].error);
    }

  
  function _lseek(fildes, offset, whence) {
      // off_t lseek(int fildes, off_t offset, int whence);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/lseek.html
      if (FS.streams[fildes] && !FS.streams[fildes].object.isDevice) {
        var stream = FS.streams[fildes];
        var position = offset;
        if (whence === 1) {  // SEEK_CUR.
          position += stream.position;
        } else if (whence === 2) {  // SEEK_END.
          position += stream.object.contents.length;
        }
        if (position < 0) {
          ___setErrNo(ERRNO_CODES.EINVAL);
          return -1;
        } else {
          stream.ungotten = [];
          stream.position = position;
          return position;
        }
      } else {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
    }function _fseek(stream, offset, whence) {
      // int fseek(FILE *stream, long offset, int whence);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fseek.html
      var ret = _lseek(stream, offset, whence);
      if (ret == -1) {
        return -1;
      } else {
        FS.streams[stream].eof = false;
        return 0;
      }
    }

  function _ftell(stream) {
      // long ftell(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/ftell.html
      if (FS.streams[stream]) {
        stream = FS.streams[stream];
        if (stream.object.isDevice) {
          ___setErrNo(ERRNO_CODES.ESPIPE);
          return -1;
        } else {
          return stream.position;
        }
      } else {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
    }

  
  function _close(fildes) {
      // int close(int fildes);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/close.html
      if (FS.streams[fildes]) {
        if (FS.streams[fildes].currentEntry) {
          _free(FS.streams[fildes].currentEntry);
        }
        FS.streams[fildes] = null;
        return 0;
      } else {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
    }
  
  function _fsync(fildes) {
      // int fsync(int fildes);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fsync.html
      if (FS.streams[fildes]) {
        // We write directly to the file system, so there's nothing to do here.
        return 0;
      } else {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
    }function _fclose(stream) {
      // int fclose(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fclose.html
      _fsync(stream);
      return _close(stream);
    }

  
  function _strncmp(px, py, n) {
      var i = 0;
      while (i < n) {
        var x = HEAPU8[((px)+(i))];
        var y = HEAPU8[((py)+(i))];
        if (x == y && x == 0) return 0;
        if (x == 0) return -1;
        if (y == 0) return 1;
        if (x == y) {
          i ++;
          continue;
        } else {
          return x > y ? 1 : -1;
        }
      }
      return 0;
    }function _strcmp(px, py) {
      return _strncmp(px, py, TOTAL_MEMORY);
    }

  var _sqrt=Math.sqrt;
var _llvm_dbg_declare; // stub for _llvm_dbg_declare
var _llvm_expect_i32; // stub for _llvm_expect_i32

  function _sysconf(name) {
      // long sysconf(int name);
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/sysconf.html
      switch(name) {
        case 8: return PAGE_SIZE;
        case 54:
        case 56:
        case 21:
        case 61:
        case 63:
        case 22:
        case 67:
        case 23:
        case 24:
        case 25:
        case 26:
        case 27:
        case 69:
        case 28:
        case 101:
        case 70:
        case 71:
        case 29:
        case 30:
        case 199:
        case 75:
        case 76:
        case 32:
        case 43:
        case 44:
        case 80:
        case 46:
        case 47:
        case 45:
        case 48:
        case 49:
        case 42:
        case 82:
        case 33:
        case 7:
        case 108:
        case 109:
        case 107:
        case 112:
        case 119:
        case 121:
          return 200809;
        case 13:
        case 104:
        case 94:
        case 95:
        case 34:
        case 35:
        case 77:
        case 81:
        case 83:
        case 84:
        case 85:
        case 86:
        case 87:
        case 88:
        case 89:
        case 90:
        case 91:
        case 94:
        case 95:
        case 110:
        case 111:
        case 113:
        case 114:
        case 115:
        case 116:
        case 117:
        case 118:
        case 120:
        case 40:
        case 16:
        case 79:
        case 19:
          return -1;
        case 92:
        case 93:
        case 5:
        case 72:
        case 6:
        case 74:
        case 92:
        case 93:
        case 96:
        case 97:
        case 98:
        case 99:
        case 102:
        case 103:
        case 105:
          return 1;
        case 38:
        case 66:
        case 50:
        case 51:
        case 4:
          return 1024;
        case 15:
        case 64:
        case 41:
          return 32;
        case 55:
        case 37:
        case 17:
          return 2147483647;
        case 18:
        case 1:
          return 47839;
        case 59:
        case 57:
          return 99;
        case 68:
        case 58:
          return 2048;
        case 0: return 2097152;
        case 3: return 65536;
        case 14: return 32768;
        case 73: return 32767;
        case 39: return 16384;
        case 60: return 1000;
        case 106: return 700;
        case 52: return 256;
        case 62: return 255;
        case 2: return 100;
        case 65: return 64;
        case 36: return 20;
        case 100: return 16;
        case 20: return 6;
        case 53: return 4;
      }
      ___setErrNo(ERRNO_CODES.EINVAL);
      return -1;
    }

  function _sbrk(bytes) {
      // Implement a Linux-like 'memory area' for our 'process'.
      // Changes the size of the memory area by |bytes|; returns the
      // address of the previous top ('break') of the memory area
  
      // We need to make sure no one else allocates unfreeable memory!
      // We must control this entirely. So we don't even need to do
      // unfreeable allocations - the HEAP is ours, from STATICTOP up.
      // TODO: We could in theory slice off the top of the HEAP when
      //       sbrk gets a negative increment in |bytes|...
      var self = _sbrk;
      if (!self.called) {
        STATICTOP = alignMemoryPage(STATICTOP); // make sure we start out aligned
        self.called = true;
        _sbrk.DYNAMIC_START = STATICTOP;
      }
      var ret = STATICTOP;
      if (bytes != 0) Runtime.staticAlloc(bytes);
      return ret;  // Previous break location.
    }





  var Browser={mainLoop:{scheduler:null,shouldPause:false,paused:false,queue:[],pause:function () {
          Browser.mainLoop.shouldPause = true;
        },resume:function () {
          if (Browser.mainLoop.paused) {
            Browser.mainLoop.paused = false;
            Browser.mainLoop.scheduler();
          }
          Browser.mainLoop.shouldPause = false;
        },updateStatus:function () {
          if (Module['setStatus']) {
            var message = Module['statusMessage'] || 'Please wait...';
            var remaining = Browser.mainLoop.remainingBlockers;
            var expected = Browser.mainLoop.expectedBlockers;
            if (remaining) {
              if (remaining < expected) {
                Module['setStatus'](message + ' (' + (expected - remaining) + '/' + expected + ')');
              } else {
                Module['setStatus'](message);
              }
            } else {
              Module['setStatus']('');
            }
          }
        }},pointerLock:false,moduleContextCreatedCallbacks:[],ensureObjects:function () {
        if (Browser.ensured) return;
        Browser.ensured = true;
        try {
          new Blob();
          Browser.hasBlobConstructor = true;
        } catch(e) {
          Browser.hasBlobConstructor = false;
          console.log("warning: no blob constructor, cannot create blobs with mimetypes");
        }
        Browser.BlobBuilder = typeof MozBlobBuilder != "undefined" ? MozBlobBuilder : (typeof WebKitBlobBuilder != "undefined" ? WebKitBlobBuilder : (!Browser.hasBlobConstructor ? console.log("warning: no BlobBuilder") : null));
        Browser.URLObject = typeof window != "undefined" ? (window.URL ? window.URL : window.webkitURL) : console.log("warning: cannot create object URLs");
  
        // Support for plugins that can process preloaded files. You can add more of these to
        // your app by creating and appending to Module.preloadPlugins.
        //
        // Each plugin is asked if it can handle a file based on the file's name. If it can,
        // it is given the file's raw data. When it is done, it calls a callback with the file's
        // (possibly modified) data. For example, a plugin might decompress a file, or it
        // might create some side data structure for use later (like an Image element, etc.).
  
        function getMimetype(name) {
          return {
            'jpg': 'image/jpeg',
            'png': 'image/png',
            'bmp': 'image/bmp',
            'ogg': 'audio/ogg',
            'wav': 'audio/wav',
            'mp3': 'audio/mpeg'
          }[name.substr(-3)];
          return ret;
        }
  
        if (!Module["preloadPlugins"]) Module["preloadPlugins"] = [];
  
        var imagePlugin = {};
        imagePlugin['canHandle'] = function(name) {
          return name.substr(-4) in { '.jpg': 1, '.png': 1, '.bmp': 1 };
        };
        imagePlugin['handle'] = function(byteArray, name, onload, onerror) {
          var b = null;
          if (Browser.hasBlobConstructor) {
            try {
              b = new Blob([byteArray], { type: getMimetype(name) });
            } catch(e) {
              Runtime.warnOnce('Blob constructor present but fails: ' + e + '; falling back to blob builder');
            }
          }
          if (!b) {
            var bb = new Browser.BlobBuilder();
            bb.append((new Uint8Array(byteArray)).buffer); // we need to pass a buffer, and must copy the array to get the right data range
            b = bb.getBlob();
          }
          var url = Browser.URLObject.createObjectURL(b);
          var img = new Image();
          img.onload = function() {
            assert(img.complete, 'Image ' + name + ' could not be decoded');
            var canvas = document.createElement('canvas');
            canvas.width = img.width;
            canvas.height = img.height;
            var ctx = canvas.getContext('2d');
            ctx.drawImage(img, 0, 0);
            Module["preloadedImages"][name] = canvas;
            Browser.URLObject.revokeObjectURL(url);
            if (onload) onload(byteArray);
          };
          img.onerror = function(event) {
            console.log('Image ' + url + ' could not be decoded');
            if (onerror) onerror();
          };
          img.src = url;
        };
        Module['preloadPlugins'].push(imagePlugin);
  
        var audioPlugin = {};
        audioPlugin['canHandle'] = function(name) {
          return name.substr(-4) in { '.ogg': 1, '.wav': 1, '.mp3': 1 };
        };
        audioPlugin['handle'] = function(byteArray, name, onload, onerror) {
          var done = false;
          function finish(audio) {
            if (done) return;
            done = true;
            Module["preloadedAudios"][name] = audio;
            if (onload) onload(byteArray);
          }
          function fail() {
            if (done) return;
            done = true;
            Module["preloadedAudios"][name] = new Audio(); // empty shim
            if (onerror) onerror();
          }
          if (Browser.hasBlobConstructor) {
            try {
              var b = new Blob([byteArray], { type: getMimetype(name) });
            } catch(e) {
              return fail();
            }
            var url = Browser.URLObject.createObjectURL(b); // XXX we never revoke this!
            var audio = new Audio();
            audio.addEventListener('canplaythrough', function() { finish(audio) }, false); // use addEventListener due to chromium bug 124926
            audio.onerror = function(event) {
              if (done) return;
              console.log('warning: browser could not fully decode audio ' + name + ', trying slower base64 approach');
              function encode64(data) {
                var BASE = 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/';
                var PAD = '=';
                var ret = '';
                var leftchar = 0;
                var leftbits = 0;
                for (var i = 0; i < data.length; i++) {
                  leftchar = (leftchar << 8) | data[i];
                  leftbits += 8;
                  while (leftbits >= 6) {
                    var curr = (leftchar >> (leftbits-6)) & 0x3f;
                    leftbits -= 6;
                    ret += BASE[curr];
                  }
                }
                if (leftbits == 2) {
                  ret += BASE[(leftchar&3) << 4];
                  ret += PAD + PAD;
                } else if (leftbits == 4) {
                  ret += BASE[(leftchar&0xf) << 2];
                  ret += PAD;
                }
                return ret;
              }
              audio.src = 'data:audio/x-' + name.substr(-3) + ';base64,' + encode64(byteArray);
              finish(audio); // we don't wait for confirmation this worked - but it's worth trying
            };
            audio.src = url;
            // workaround for chrome bug 124926 - we do not always get oncanplaythrough or onerror
            setTimeout(function() {
              finish(audio); // try to use it even though it is not necessarily ready to play
            }, 10000);
          } else {
            return fail();
          }
        };
        Module['preloadPlugins'].push(audioPlugin);
      },createContext:function (canvas, useWebGL, setInModule) {
        try {
          var ctx = canvas.getContext(useWebGL ? 'experimental-webgl' : '2d');
          if (!ctx) throw ':(';
        } catch (e) {
          Module.print('Could not create canvas - ' + e);
          return null;
        }
        if (useWebGL) {
          // Set the background of the WebGL canvas to black
          canvas.style.backgroundColor = "black";
  
          // Warn on context loss
          canvas.addEventListener('webglcontextlost', function(event) {
            alert('WebGL context lost. You will need to reload the page.');
          }, false);
        }
        if (setInModule) {
          Module.ctx = ctx;
          Module.useWebGL = useWebGL;
          Browser.moduleContextCreatedCallbacks.forEach(function(callback) { callback() });
        }
        return ctx;
      },requestFullScreen:function () {
        var canvas = Module['canvas'];
        function fullScreenChange() {
          var isFullScreen = false;
          if ((document['webkitFullScreenElement'] || document['webkitFullscreenElement'] ||
               document['mozFullScreenElement'] || document['mozFullscreenElement'] ||
               document['fullScreenElement'] || document['fullscreenElement']) === canvas) {
            canvas.requestPointerLock = canvas['requestPointerLock'] ||
                                        canvas['mozRequestPointerLock'] ||
                                        canvas['webkitRequestPointerLock'];
            canvas.requestPointerLock();
            isFullScreen = true;
          }
          if (Module['onFullScreen']) Module['onFullScreen'](isFullScreen);
        }
  
        document.addEventListener('fullscreenchange', fullScreenChange, false);
        document.addEventListener('mozfullscreenchange', fullScreenChange, false);
        document.addEventListener('webkitfullscreenchange', fullScreenChange, false);
  
        function pointerLockChange() {
          Browser.pointerLock = document['pointerLockElement'] === canvas ||
                                document['mozPointerLockElement'] === canvas ||
                                document['webkitPointerLockElement'] === canvas;
        }
  
        document.addEventListener('pointerlockchange', pointerLockChange, false);
        document.addEventListener('mozpointerlockchange', pointerLockChange, false);
        document.addEventListener('webkitpointerlockchange', pointerLockChange, false);
  
        canvas.requestFullScreen = canvas['requestFullScreen'] ||
                                   canvas['mozRequestFullScreen'] ||
                                   (canvas['webkitRequestFullScreen'] ? function() { canvas['webkitRequestFullScreen'](Element['ALLOW_KEYBOARD_INPUT']) } : null);
        canvas.requestFullScreen(); 
      },requestAnimationFrame:function (func) {
        if (!window.requestAnimationFrame) {
          window.requestAnimationFrame = window['requestAnimationFrame'] ||
                                         window['mozRequestAnimationFrame'] ||
                                         window['webkitRequestAnimationFrame'] ||
                                         window['msRequestAnimationFrame'] ||
                                         window['oRequestAnimationFrame'] ||
                                         window['setTimeout'];
        }
        window.requestAnimationFrame(func);
      },getMovementX:function (event) {
        return event['movementX'] ||
               event['mozMovementX'] ||
               event['webkitMovementX'] ||
               0;
      },getMovementY:function (event) {
        return event['movementY'] ||
               event['mozMovementY'] ||
               event['webkitMovementY'] ||
               0;
      },xhrLoad:function (url, onload, onerror) {
        var xhr = new XMLHttpRequest();
        xhr.open('GET', url, true);
        xhr.responseType = 'arraybuffer';
        xhr.onload = function() {
          if (xhr.status == 200) {
            onload(xhr.response);
          } else {
            onerror();
          }
        };
        xhr.onerror = onerror;
        xhr.send(null);
      },asyncLoad:function (url, onload, onerror) {
        Browser.xhrLoad(url, function(arrayBuffer) {
          assert(arrayBuffer, 'Loading data file "' + url + '" failed (no arrayBuffer).');
          onload(new Uint8Array(arrayBuffer));
          removeRunDependency('al ' + url);
        }, function(event) {
          if (onerror) {
            onerror();
          } else {
            throw 'Loading data file "' + url + '" failed.';
          }
        });
        addRunDependency('al ' + url);
      }};
___setErrNo(0);
__ATINIT__.unshift({ func: function() { if (!Module["noFSInit"] && !FS.init.initialized) FS.init() } });__ATMAIN__.push({ func: function() { FS.ignorePermissions = false } });__ATEXIT__.push({ func: function() { FS.quit() } });Module["FS_createFolder"] = FS.createFolder;Module["FS_createPath"] = FS.createPath;Module["FS_createDataFile"] = FS.createDataFile;Module["FS_createPreloadedFile"] = FS.createPreloadedFile;Module["FS_createLazyFile"] = FS.createLazyFile;Module["FS_createLink"] = FS.createLink;Module["FS_createDevice"] = FS.createDevice;
Module["requestFullScreen"] = function() { Browser.requestFullScreen() };
  Module["requestAnimationFrame"] = function(func) { Browser.requestAnimationFrame(func) };
  Module["pauseMainLoop"] = function() { Browser.mainLoop.pause() };
  Module["resumeMainLoop"] = function() { Browser.mainLoop.resume() };
  

// === Auto-generated postamble setup entry stuff ===

Module.callMain = function callMain(args) {
  var argc = args.length+1;
  function pad() {
    for (var i = 0; i < 4-1; i++) {
      argv.push(0);
    }
  }
  var argv = [allocate(intArrayFromString("/bin/this.program"), 'i8', ALLOC_STATIC) ];
  pad();
  for (var i = 0; i < argc-1; i = i + 1) {
    argv.push(allocate(intArrayFromString(args[i]), 'i8', ALLOC_STATIC));
    pad();
  }
  argv.push(0);
  argv = allocate(argv, 'i32', ALLOC_STATIC);

  return _main(argc, argv, 0);
}


var _crc_table;

var _configuration_table;




var _inflate_order;


















var _fixedtables_lenfix47;
var _fixedtables_distfix48;
var _inflate_table_lbase;
var _inflate_table_lext;
var _inflate_table_dbase;
var _inflate_table_dext;


var _static_l_desc;
var _static_d_desc;
var _static_bl_desc;
var _static_ltree;
var _static_dtree;
var _extra_lbits;
var _base_length;
var _extra_dbits;
var _base_dist;

var _extra_blbits;


var __str277;






var _z_errmsg;



























var _stderr;





































var _png_read_row_png_pass_dsp_mask;
var _png_read_row_png_pass_mask;












var _png_gamma_shift;







































































































































var _png_do_read_interlace_png_pass_inc;

var _png_read_finish_row_png_pass_start;
var _png_read_finish_row_png_pass_inc;
var _png_read_finish_row_png_pass_ystart;
var _png_read_finish_row_png_pass_yinc;





var _png_read_start_row_png_pass_start;
var _png_read_start_row_png_pass_inc;
var _png_read_start_row_png_pass_ystart;
var _png_read_start_row_png_pass_yinc;




























var _HPDF_ANNOT_TYPE_NAMES;


















var _HPDF_ANNOT_ICON_NAMES_NAMES;






















var _llvm_used;








var _HPDF_PAGE_LAYOUT_NAMES;

var _HPDF_PAGE_MODE_NAMES;



























var _HPDF_DESTINATION_TYPE_NAMES;



















var _HPDF_VERSION_STR;








var _HPDF_UNICODE_MAP_STANDARD;

var _HPDF_UNICODE_MAP_WIN_ANSI;

var _HPDF_UNICODE_MAP_MAC_ROMAN;

var _HPDF_UNICODE_MAP_FONT_SPECIFIC;
var _HPDF_BUILTIN_ENCODINGS;
var _HPDF_UNICODE_GRYPH_NAME_MAP;






















































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































var _HPDF_UNICODE_MAP_ISO8859_2;

var _HPDF_UNICODE_MAP_ISO8859_3;

var _HPDF_UNICODE_MAP_ISO8859_4;

var _HPDF_UNICODE_MAP_ISO8859_5;

var _HPDF_UNICODE_MAP_ISO8859_6;

var _HPDF_UNICODE_MAP_ISO8859_7;

var _HPDF_UNICODE_MAP_ISO8859_8;

var _HPDF_UNICODE_MAP_ISO8859_9;

var _HPDF_UNICODE_MAP_ISO8859_10;

var _HPDF_UNICODE_MAP_ISO8859_11;

var _HPDF_UNICODE_MAP_ISO8859_13;

var _HPDF_UNICODE_MAP_ISO8859_14;

var _HPDF_UNICODE_MAP_ISO8859_15;

var _HPDF_UNICODE_MAP_ISO8859_16;

var _HPDF_UNICODE_MAP_CP1250;

var _HPDF_UNICODE_MAP_CP1251;

var _HPDF_UNICODE_MAP_CP1252;

var _HPDF_UNICODE_MAP_CP1253;

var _HPDF_UNICODE_MAP_CP1254;

var _HPDF_UNICODE_MAP_CP1255;

var _HPDF_UNICODE_MAP_CP1256;

var _HPDF_UNICODE_MAP_CP1257;

var _HPDF_UNICODE_MAP_CP1258;

var _HPDF_UNICODE_MAP_KOI8_R;




var _CMAP_ARRAY_GB_EUC_H;
var _CMAP_ARRAY_GB_EUC_V;
var _GB_EUC_NOTDEF_RANGE;
var _EUC_CN_UNICODE_ARRAY;


var _GB_EUC_AddCodeSpaceRange_code_space_range1;
var _GB_EUC_AddCodeSpaceRange_code_space_range2;
var _CMAP_ARRAY_GBK_EUC_H;
var _CMAP_ARRAY_GBK_EUC_V;
var _GBK_EUC_NOTDEF_RANGE;
var _CP936_UNICODE_ARRAY;
var _GBK_EUC_AddCodeSpaceRange_code_space_range1;
var _GBK_EUC_AddCodeSpaceRange_code_space_range2;


var _CMAP_ARRAY_ETen_B5_H;
var _CMAP_ARRAY_ETen_B5_V;
var _ETen_B5_NOTDEF_RANGE;
var _CP950_UNICODE_ARRAY;


var _ETen_B5_AddCodeSpaceRange_code_space_range1;
var _ETen_B5_AddCodeSpaceRange_code_space_range2;





var _CMAP_ARRAY_EUC_H;
var _CMAP_ARRAY_EUC_V;
var _EUC_NOTDEF_RANGE;
var _EUC_UNICODE_ARRAY;


var _JWW_LINE_HEAD_EUC;
var _EUC_AddCodeSpaceRange_code_space_range1;
var _EUC_AddCodeSpaceRange_code_space_range2;
var _EUC_AddCodeSpaceRange_code_space_range3;
var _CMAP_ARRAY_90msp_RKSJ_H;
var _MSP_RKSJ_NOTDEF_RANGE;
var _CP932_UNICODE_ARRAY;
var _JWW_LINE_HEAD_SJIS;
var _RKSJ_AddCodeSpaceRange_code_space_range1;
var _RKSJ_AddCodeSpaceRange_code_space_range2;
var _RKSJ_AddCodeSpaceRange_code_space_range3;
var _RKSJ_AddCodeSpaceRange_code_space_range4;
var _CMAP_ARRAY_90ms_RKSJ_H;
var _CMAP_ARRAY_90ms_RKSJ_V;
var _MS_RKSJ_NOTDEF_RANGE;





var _CMAP_ARRAY_KSC_EUC_H;
var _CMAP_ARRAY_KSC_EUC_V;
var _KSC_EUC_NOTDEF_RANGE;
var _KSC_EUC_UNICODE_ARRAY;


var _KSC_EUC_AddCodeSpaceRange_code_space_range1;
var _KSC_EUC_AddCodeSpaceRange_code_space_range2;
var _CMAP_ARRAY_KSCms_UHC_HW_H;
var _CMAP_ARRAY_KSCms_UHC_HW_V;
var _KSCms_UHC_HW_NOTDEF_RANGE;
var _CP949_UNICODE_ARRAY;
var _KSCms_UHC_AddCodeSpaceRange_code_space_range1;
var _KSCms_UHC_AddCodeSpaceRange_code_space_range2;
var _CMAP_ARRAY_KSCms_UHC_H;
var _KSCms_UHC_NOTDEF_RANGE;














var _HPDF_BM_NAMES;























































































var _HPDF_BUILTIN_FONTS;


var _CHAR_DATA_COURIER;

var _CHAR_DATA_COURIER_BOLD;

var _CHAR_DATA_COURIER_OBLIQUE;

var _CHAR_DATA_COURIER_BOLD_OBLIQUE;

var _CHAR_DATA_HELVETICA;

var _CHAR_DATA_HELVETICA_BOLD;

var _CHAR_DATA_HELVETICA_OBLIQUE;

var _CHAR_DATA_HELVETICA_BOLD_OBLIQUE;

var _CHAR_DATA_TIMES_ROMAN;

var _CHAR_DATA_TIMES_BOLD;

var _CHAR_DATA_TIMES_ITALIC;

var _CHAR_DATA_TIMES_BOLD_ITALIC;

var _CHAR_DATA_SYMBOL;

var _CHAR_DATA_ZAPF_DINGBATS;








var _SIMHEI_W_ARRAY;
var _SIMSUN_W_ARRAY;




var _MING_LIU_W_ARRAY;
















var _MS_PGothic_W_ARRAY;
var _MS_Gothic_W_ARRAY;
















var _Dotum_W_ARRAY;
var _DotumChe_W_ARRAY;
var _REQUIRED_TAGS;



























































































var _HPDF_GState_New_DEF_MATRIX;





var _COL_GRAY;
var _COL_CMYK;
var _COL_RGB;

























var _HPDF_INFO_ATTR_NAMES;


































var _INIT_MODE;













var _INIT_POS;










var _HPDF_Page_BeginText_INIT_MATRIX;




















































var _HPDF_INHERITABLE_ENTRIES;







var _HPDF_Page_GetTransMatrix_DEF_MATRIX;
var _HPDF_Page_GetTextMatrix_DEF_MATRIX;


var _HPDF_PREDEFINED_PAGE_SIZES;


























var _HPDF_3DView_SetLighting_schemes;





































var __gm_;
var _mparams;
_crc_table=allocate([0, 0, 0, 0, 1996959894, 0, 0, 0, -301047508, 0, 0, 0, -1727442502, 0, 0, 0, 124634137, 0, 0, 0, 1886057615, 0, 0, 0, -379345611, 0, 0, 0, -1637575261, 0, 0, 0, 249268274, 0, 0, 0, 2044508324, 0, 0, 0, -522852066, 0, 0, 0, -1747789432, 0, 0, 0, 162941995, 0, 0, 0, 2125561021, 0, 0, 0, -407360249, 0, 0, 0, -1866523247, 0, 0, 0, 498536548, 0, 0, 0, 1789927666, 0, 0, 0, -205950648, 0, 0, 0, -2067906082, 0, 0, 0, 450548861, 0, 0, 0, 1843258603, 0, 0, 0, -187386543, 0, 0, 0, -2083289657, 0, 0, 0, 325883990, 0, 0, 0, 1684777152, 0, 0, 0, -43845254, 0, 0, 0, -1973040660, 0, 0, 0, 335633487, 0, 0, 0, 1661365465, 0, 0, 0, -99664541, 0, 0, 0, -1928851979, 0, 0, 0, 997073096, 0, 0, 0, 1281953886, 0, 0, 0, -715111964, 0, 0, 0, -1570279054, 0, 0, 0, 1006888145, 0, 0, 0, 1258607687, 0, 0, 0, -770865667, 0, 0, 0, -1526024853, 0, 0, 0, 901097722, 0, 0, 0, 1119000684, 0, 0, 0, -608450090, 0, 0, 0, -1396901568, 0, 0, 0, 853044451, 0, 0, 0, 1172266101, 0, 0, 0, -589951537, 0, 0, 0, -1412350631, 0, 0, 0, 651767980, 0, 0, 0, 1373503546, 0, 0, 0, -925412992, 0, 0, 0, -1076862698, 0, 0, 0, 565507253, 0, 0, 0, 1454621731, 0, 0, 0, -809855591, 0, 0, 0, -1195530993, 0, 0, 0, 671266974, 0, 0, 0, 1594198024, 0, 0, 0, -972236366, 0, 0, 0, -1324619484, 0, 0, 0, 795835527, 0, 0, 0, 1483230225, 0, 0, 0, -1050600021, 0, 0, 0, -1234817731, 0, 0, 0, 1994146192, 0, 0, 0, 31158534, 0, 0, 0, -1731059524, 0, 0, 0, -271249366, 0, 0, 0, 1907459465, 0, 0, 0, 112637215, 0, 0, 0, -1614814043, 0, 0, 0, -390540237, 0, 0, 0, 2013776290, 0, 0, 0, 251722036, 0, 0, 0, -1777751922, 0, 0, 0, -519137256, 0, 0, 0, 2137656763, 0, 0, 0, 141376813, 0, 0, 0, -1855689577, 0, 0, 0, -429695999, 0, 0, 0, 1802195444, 0, 0, 0, 476864866, 0, 0, 0, -2056965928, 0, 0, 0, -228458418, 0, 0, 0, 1812370925, 0, 0, 0, 453092731, 0, 0, 0, -2113342271, 0, 0, 0, -183516073, 0, 0, 0, 1706088902, 0, 0, 0, 314042704, 0, 0, 0, -1950435094, 0, 0, 0, -54949764, 0, 0, 0, 1658658271, 0, 0, 0, 366619977, 0, 0, 0, -1932296973, 0, 0, 0, -69972891, 0, 0, 0, 1303535960, 0, 0, 0, 984961486, 0, 0, 0, -1547960204, 0, 0, 0, -725929758, 0, 0, 0, 1256170817, 0, 0, 0, 1037604311, 0, 0, 0, -1529756563, 0, 0, 0, -740887301, 0, 0, 0, 1131014506, 0, 0, 0, 879679996, 0, 0, 0, -1385723834, 0, 0, 0, -631195440, 0, 0, 0, 1141124467, 0, 0, 0, 855842277, 0, 0, 0, -1442165665, 0, 0, 0, -586318647, 0, 0, 0, 1342533948, 0, 0, 0, 654459306, 0, 0, 0, -1106571248, 0, 0, 0, -921952122, 0, 0, 0, 1466479909, 0, 0, 0, 544179635, 0, 0, 0, -1184443383, 0, 0, 0, -832445281, 0, 0, 0, 1591671054, 0, 0, 0, 702138776, 0, 0, 0, -1328506846, 0, 0, 0, -942167884, 0, 0, 0, 1504918807, 0, 0, 0, 783551873, 0, 0, 0, -1212326853, 0, 0, 0, -1061524307, 0, 0, 0, -306674912, 0, 0, 0, -1698712650, 0, 0, 0, 62317068, 0, 0, 0, 1957810842, 0, 0, 0, -355121351, 0, 0, 0, -1647151185, 0, 0, 0, 81470997, 0, 0, 0, 1943803523, 0, 0, 0, -480048366, 0, 0, 0, -1805370492, 0, 0, 0, 225274430, 0, 0, 0, 2053790376, 0, 0, 0, -468791541, 0, 0, 0, -1828061283, 0, 0, 0, 167816743, 0, 0, 0, 2097651377, 0, 0, 0, -267414716, 0, 0, 0, -2029476910, 0, 0, 0, 503444072, 0, 0, 0, 1762050814, 0, 0, 0, -144550051, 0, 0, 0, -2140837941, 0, 0, 0, 426522225, 0, 0, 0, 1852507879, 0, 0, 0, -19653770, 0, 0, 0, -1982649376, 0, 0, 0, 282753626, 0, 0, 0, 1742555852, 0, 0, 0, -105259153, 0, 0, 0, -1900089351, 0, 0, 0, 397917763, 0, 0, 0, 1622183637, 0, 0, 0, -690576408, 0, 0, 0, -1580100738, 0, 0, 0, 953729732, 0, 0, 0, 1340076626, 0, 0, 0, -776247311, 0, 0, 0, -1497606297, 0, 0, 0, 1068828381, 0, 0, 0, 1219638859, 0, 0, 0, -670225446, 0, 0, 0, -1358292148, 0, 0, 0, 906185462, 0, 0, 0, 1090812512, 0, 0, 0, -547295293, 0, 0, 0, -1469587627, 0, 0, 0, 829329135, 0, 0, 0, 1181335161, 0, 0, 0, -882789492, 0, 0, 0, -1134132454, 0, 0, 0, 628085408, 0, 0, 0, 1382605366, 0, 0, 0, -871598187, 0, 0, 0, -1156888829, 0, 0, 0, 570562233, 0, 0, 0, 1426400815, 0, 0, 0, -977650754, 0, 0, 0, -1296233688, 0, 0, 0, 733239954, 0, 0, 0, 1555261956, 0, 0, 0, -1026031705, 0, 0, 0, -1244606671, 0, 0, 0, 752459403, 0, 0, 0, 1541320221, 0, 0, 0, -1687895376, 0, 0, 0, -328994266, 0, 0, 0, 1969922972, 0, 0, 0, 40735498, 0, 0, 0, -1677130071, 0, 0, 0, -351390145, 0, 0, 0, 1913087877, 0, 0, 0, 83908371, 0, 0, 0, -1782625662, 0, 0, 0, -491226604, 0, 0, 0, 2075208622, 0, 0, 0, 213261112, 0, 0, 0, -1831694693, 0, 0, 0, -438977011, 0, 0, 0, 2094854071, 0, 0, 0, 198958881, 0, 0, 0, -2032938284, 0, 0, 0, -237706686, 0, 0, 0, 1759359992, 0, 0, 0, 534414190, 0, 0, 0, -2118248755, 0, 0, 0, -155638181, 0, 0, 0, 1873836001, 0, 0, 0, 414664567, 0, 0, 0, -2012718362, 0, 0, 0, -15766928, 0, 0, 0, 1711684554, 0, 0, 0, 285281116, 0, 0, 0, -1889165569, 0, 0, 0, -127750551, 0, 0, 0, 1634467795, 0, 0, 0, 376229701, 0, 0, 0, -1609899400, 0, 0, 0, -686959890, 0, 0, 0, 1308918612, 0, 0, 0, 956543938, 0, 0, 0, -1486412191, 0, 0, 0, -799009033, 0, 0, 0, 1231636301, 0, 0, 0, 1047427035, 0, 0, 0, -1362007478, 0, 0, 0, -640263460, 0, 0, 0, 1088359270, 0, 0, 0, 936918000, 0, 0, 0, -1447252397, 0, 0, 0, -558129467, 0, 0, 0, 1202900863, 0, 0, 0, 817233897, 0, 0, 0, -1111625188, 0, 0, 0, -893730166, 0, 0, 0, 1404277552, 0, 0, 0, 615818150, 0, 0, 0, -1160759803, 0, 0, 0, -841546093, 0, 0, 0, 1423857449, 0, 0, 0, 601450431, 0, 0, 0, -1285129682, 0, 0, 0, -1000256840, 0, 0, 0, 1567103746, 0, 0, 0, 711928724, 0, 0, 0, -1274298825, 0, 0, 0, -1022587231, 0, 0, 0, 1510334235, 0, 0, 0, 755167117, 0, 0, 0, 0, 0, 0, 0, 421212481, 0, 0, 0, 842424962, 0, 0, 0, 724390851, 0, 0, 0, 1684849924, 0, 0, 0, 2105013317, 0, 0, 0, 1448781702, 0, 0, 0, 1329698503, 0, 0, 0, -925267448, 0, 0, 0, -775767223, 0, 0, 0, -84940662, 0, 0, 0, -470492725, 0, 0, 0, -1397403892, 0, 0, 0, -1246855603, 0, 0, 0, -1635570290, 0, 0, 0, -2020074289, 0, 0, 0, 1254232657, 0, 0, 0, 1406739216, 0, 0, 0, 2029285587, 0, 0, 0, 1643069842, 0, 0, 0, 783210325, 0, 0, 0, 934667796, 0, 0, 0, 479770071, 0, 0, 0, 92505238, 0, 0, 0, -2112120743, 0, 0, 0, -1694455528, 0, 0, 0, -1339163941, 0, 0, 0, -1456026726, 0, 0, 0, -428384931, 0, 0, 0, -9671652, 0, 0, 0, -733921313, 0, 0, 0, -849736034, 0, 0, 0, -1786501982, 0, 0, 0, -1935731229, 0, 0, 0, -1481488864, 0, 0, 0, -1096190111, 0, 0, 0, -236396122, 0, 0, 0, -386674457, 0, 0, 0, -1008827612, 0, 0, 0, -624577947, 0, 0, 0, 1566420650, 0, 0, 0, 1145479147, 0, 0, 0, 1869335592, 0, 0, 0, 1987116393, 0, 0, 0, 959540142, 0, 0, 0, 539646703, 0, 0, 0, 185010476, 0, 0, 0, 303839341, 0, 0, 0, -549046541, 0, 0, 0, -966981710, 0, 0, 0, -311405455, 0, 0, 0, -194288336, 0, 0, 0, -1154812937, 0, 0, 0, -1573797194, 0, 0, 0, -1994616459, 0, 0, 0, -1878548428, 0, 0, 0, 396344571, 0, 0, 0, 243568058, 0, 0, 0, 631889529, 0, 0, 0, 1018359608, 0, 0, 0, 1945336319, 0, 0, 0, 1793607870, 0, 0, 0, 1103436669, 0, 0, 0, 1490954812, 0, 0, 0, -260485371, 0, 0, 0, -379421116, 0, 0, 0, -1034998393, 0, 0, 0, -615244602, 0, 0, 0, -1810527743, 0, 0, 0, -1928414400, 0, 0, 0, -1507596157, 0, 0, 0, -1086793278, 0, 0, 0, 950060301, 0, 0, 0, 565965900, 0, 0, 0, 177645455, 0, 0, 0, 328046286, 0, 0, 0, 1556873225, 0, 0, 0, 1171730760, 0, 0, 0, 1861902987, 0, 0, 0, 2011255754, 0, 0, 0, -1162125996, 0, 0, 0, -1549767659, 0, 0, 0, -2004009002, 0, 0, 0, -1852436841, 0, 0, 0, -556296112, 0, 0, 0, -942888687, 0, 0, 0, -320734510, 0, 0, 0, -168113261, 0, 0, 0, 1919080284, 0, 0, 0, 1803150877, 0, 0, 0, 1079293406, 0, 0, 0, 1498383519, 0, 0, 0, 370020952, 0, 0, 0, 253043481, 0, 0, 0, 607678682, 0, 0, 0, 1025720731, 0, 0, 0, 1711106983, 0, 0, 0, 2095471334, 0, 0, 0, 1472923941, 0, 0, 0, 1322268772, 0, 0, 0, 26324643, 0, 0, 0, 411738082, 0, 0, 0, 866634785, 0, 0, 0, 717028704, 0, 0, 0, -1390091857, 0, 0, 0, -1270886162, 0, 0, 0, -1626176723, 0, 0, 0, -2046184852, 0, 0, 0, -918018901, 0, 0, 0, -799861270, 0, 0, 0, -75610583, 0, 0, 0, -496666776, 0, 0, 0, 792689142, 0, 0, 0, 908347575, 0, 0, 0, 487136116, 0, 0, 0, 68299317, 0, 0, 0, 1263779058, 0, 0, 0, 1380486579, 0, 0, 0, 2036719216, 0, 0, 0, 1618931505, 0, 0, 0, -404294658, 0, 0, 0, -16923969, 0, 0, 0, -707751556, 0, 0, 0, -859070403, 0, 0, 0, -2088093958, 0, 0, 0, -1701771333, 0, 0, 0, -1313057672, 0, 0, 0, -1465424583, 0, 0, 0, 998479947, 0, 0, 0, 580430090, 0, 0, 0, 162921161, 0, 0, 0, 279890824, 0, 0, 0, 1609522511, 0, 0, 0, 1190423566, 0, 0, 0, 1842954189, 0, 0, 0, 1958874764, 0, 0, 0, -212200893, 0, 0, 0, -364829950, 0, 0, 0, -1049857855, 0, 0, 0, -663273088, 0, 0, 0, -1758013625, 0, 0, 0, -1909594618, 0, 0, 0, -1526680123, 0, 0, 0, -1139047292, 0, 0, 0, 1900120602, 0, 0, 0, 1750776667, 0, 0, 0, 1131931800, 0, 0, 0, 1517083097, 0, 0, 0, 355290910, 0, 0, 0, 204897887, 0, 0, 0, 656092572, 0, 0, 0, 1040194781, 0, 0, 0, -1181220846, 0, 0, 0, -1602014893, 0, 0, 0, -1951505776, 0, 0, 0, -1833610287, 0, 0, 0, -571161322, 0, 0, 0, -990907305, 0, 0, 0, -272455788, 0, 0, 0, -153512235, 0, 0, 0, -1375224599, 0, 0, 0, -1222865496, 0, 0, 0, -1674453397, 0, 0, 0, -2060783830, 0, 0, 0, -898926099, 0, 0, 0, -747616084, 0, 0, 0, -128115857, 0, 0, 0, -515495378, 0, 0, 0, 1725839073, 0, 0, 0, 2143618976, 0, 0, 0, 1424512099, 0, 0, 0, 1307796770, 0, 0, 0, 45282277, 0, 0, 0, 464110244, 0, 0, 0, 813994343, 0, 0, 0, 698327078, 0, 0, 0, -456806728, 0, 0, 0, -35741703, 0, 0, 0, -688665542, 0, 0, 0, -806814341, 0, 0, 0, -2136380484, 0, 0, 0, -1716364547, 0, 0, 0, -1298200258, 0, 0, 0, -1417398145, 0, 0, 0, 740041904, 0, 0, 0, 889656817, 0, 0, 0, 506086962, 0, 0, 0, 120682355, 0, 0, 0, 1215357364, 0, 0, 0, 1366020341, 0, 0, 0, 2051441462, 0, 0, 0, 1667084919, 0, 0, 0, -872753330, 0, 0, 0, -756947441, 0, 0, 0, -104024628, 0, 0, 0, -522746739, 0, 0, 0, -1349119414, 0, 0, 0, -1232264437, 0, 0, 0, -1650429752, 0, 0, 0, -2068102775, 0, 0, 0, 52649286, 0, 0, 0, 439905287, 0, 0, 0, 823476164, 0, 0, 0, 672009861, 0, 0, 0, 1733269570, 0, 0, 0, 2119477507, 0, 0, 0, 1434057408, 0, 0, 0, 1281543041, 0, 0, 0, -2126985953, 0, 0, 0, -1742474146, 0, 0, 0, -1290885219, 0, 0, 0, -1441425700, 0, 0, 0, -447479781, 0, 0, 0, -61918886, 0, 0, 0, -681418087, 0, 0, 0, -830909480, 0, 0, 0, 1239502615, 0, 0, 0, 1358593622, 0, 0, 0, 2077699477, 0, 0, 0, 1657543892, 0, 0, 0, 764250643, 0, 0, 0, 882293586, 0, 0, 0, 532408465, 0, 0, 0, 111204816, 0, 0, 0, 1585378284, 0, 0, 0, 1197851309, 0, 0, 0, 1816695150, 0, 0, 0, 1968414767, 0, 0, 0, 974272232, 0, 0, 0, 587794345, 0, 0, 0, 136598634, 0, 0, 0, 289367339, 0, 0, 0, -1767409180, 0, 0, 0, -1883486043, 0, 0, 0, -1533994138, 0, 0, 0, -1115018713, 0, 0, 0, -221528864, 0, 0, 0, -338653791, 0, 0, 0, -1057104286, 0, 0, 0, -639176925, 0, 0, 0, 347922877, 0, 0, 0, 229101820, 0, 0, 0, 646611775, 0, 0, 0, 1066513022, 0, 0, 0, 1892689081, 0, 0, 0, 1774917112, 0, 0, 0, 1122387515, 0, 0, 0, 1543337850, 0, 0, 0, -597333067, 0, 0, 0, -981574924, 0, 0, 0, -296548041, 0, 0, 0, -146261898, 0, 0, 0, -1207325007, 0, 0, 0, -1592614928, 0, 0, 0, -1975530445, 0, 0, 0, -1826292366, 0, 0, 0, 0, 0, 0, 0, 29518391, 0, 0, 0, 59036782, 0, 0, 0, 38190681, 0, 0, 0, 118073564, 0, 0, 0, 114017003, 0, 0, 0, 76381362, 0, 0, 0, 89069189, 0, 0, 0, 236147128, 0, 0, 0, 265370511, 0, 0, 0, 228034006, 0, 0, 0, 206958561, 0, 0, 0, 152762724, 0, 0, 0, 148411219, 0, 0, 0, 178138378, 0, 0, 0, 190596925, 0, 0, 0, 472294256, 0, 0, 0, 501532999, 0, 0, 0, 530741022, 0, 0, 0, 509615401, 0, 0, 0, 456068012, 0, 0, 0, 451764635, 0, 0, 0, 413917122, 0, 0, 0, 426358261, 0, 0, 0, 305525448, 0, 0, 0, 334993663, 0, 0, 0, 296822438, 0, 0, 0, 275991697, 0, 0, 0, 356276756, 0, 0, 0, 352202787, 0, 0, 0, 381193850, 0, 0, 0, 393929805, 0, 0, 0, 944588512, 0, 0, 0, 965684439, 0, 0, 0, 1003065998, 0, 0, 0, 973863097, 0, 0, 0, 1061482044, 0, 0, 0, 1049003019, 0, 0, 0, 1019230802, 0, 0, 0, 1023561829, 0, 0, 0, 912136024, 0, 0, 0, 933002607, 0, 0, 0, 903529270, 0, 0, 0, 874031361, 0, 0, 0, 827834244, 0, 0, 0, 815125939, 0, 0, 0, 852716522, 0, 0, 0, 856752605, 0, 0, 0, 611050896, 0, 0, 0, 631869351, 0, 0, 0, 669987326, 0, 0, 0, 640506825, 0, 0, 0, 593644876, 0, 0, 0, 580921211, 0, 0, 0, 551983394, 0, 0, 0, 556069653, 0, 0, 0, 712553512, 0, 0, 0, 733666847, 0, 0, 0, 704405574, 0, 0, 0, 675154545, 0, 0, 0, 762387700, 0, 0, 0, 749958851, 0, 0, 0, 787859610, 0, 0, 0, 792175277, 0, 0, 0, 1889177024, 0, 0, 0, 1901651959, 0, 0, 0, 1931368878, 0, 0, 0, 1927033753, 0, 0, 0, 2006131996, 0, 0, 0, 1985040171, 0, 0, 0, 1947726194, 0, 0, 0, 1976933189, 0, 0, 0, 2122964088, 0, 0, 0, 2135668303, 0, 0, 0, 2098006038, 0, 0, 0, 2093965857, 0, 0, 0, 2038461604, 0, 0, 0, 2017599123, 0, 0, 0, 2047123658, 0, 0, 0, 2076625661, 0, 0, 0, 1824272048, 0, 0, 0, 1836991623, 0, 0, 0, 1866005214, 0, 0, 0, 1861914857, 0, 0, 0, 1807058540, 0, 0, 0, 1786244187, 0, 0, 0, 1748062722, 0, 0, 0, 1777547317, 0, 0, 0, 1655668488, 0, 0, 0, 1668093247, 0, 0, 0, 1630251878, 0, 0, 0, 1625932113, 0, 0, 0, 1705433044, 0, 0, 0, 1684323811, 0, 0, 0, 1713505210, 0, 0, 0, 1742760333, 0, 0, 0, 1222101792, 0, 0, 0, 1226154263, 0, 0, 0, 1263738702, 0, 0, 0, 1251046777, 0, 0, 0, 1339974652, 0, 0, 0, 1310460363, 0, 0, 0, 1281013650, 0, 0, 0, 1301863845, 0, 0, 0, 1187289752, 0, 0, 0, 1191637167, 0, 0, 0, 1161842422, 0, 0, 0, 1149379777, 0, 0, 0, 1103966788, 0, 0, 0, 1074747507, 0, 0, 0, 1112139306, 0, 0, 0, 1133218845, 0, 0, 0, 1425107024, 0, 0, 0, 1429406311, 0, 0, 0, 1467333694, 0, 0, 0, 1454888457, 0, 0, 0, 1408811148, 0, 0, 0, 1379576507, 0, 0, 0, 1350309090, 0, 0, 0, 1371438805, 0, 0, 0, 1524775400, 0, 0, 0, 1528845279, 0, 0, 0, 1499917702, 0, 0, 0, 1487177649, 0, 0, 0, 1575719220, 0, 0, 0, 1546255107, 0, 0, 0, 1584350554, 0, 0, 0, 1605185389, 0, 0, 0, -516613248, 0, 0, 0, -520654409, 0, 0, 0, -491663378, 0, 0, 0, -478960167, 0, 0, 0, -432229540, 0, 0, 0, -402728597, 0, 0, 0, -440899790, 0, 0, 0, -461763323, 0, 0, 0, -282703304, 0, 0, 0, -287039473, 0, 0, 0, -324886954, 0, 0, 0, -312413087, 0, 0, 0, -399514908, 0, 0, 0, -370308909, 0, 0, 0, -341100918, 0, 0, 0, -362193731, 0, 0, 0, -49039120, 0, 0, 0, -53357881, 0, 0, 0, -23630690, 0, 0, 0, -11204951, 0, 0, 0, -98955220, 0, 0, 0, -69699045, 0, 0, 0, -107035582, 0, 0, 0, -128143755, 0, 0, 0, -218044088, 0, 0, 0, -222133377, 0, 0, 0, -259769050, 0, 0, 0, -247048431, 0, 0, 0, -200719980, 0, 0, 0, -171234397, 0, 0, 0, -141715974, 0, 0, 0, -162529331, 0, 0, 0, -646423200, 0, 0, 0, -658884777, 0, 0, 0, -620984050, 0, 0, 0, -616635591, 0, 0, 0, -562956868, 0, 0, 0, -541876341, 0, 0, 0, -571137582, 0, 0, 0, -600355867, 0, 0, 0, -680850216, 0, 0, 0, -693541137, 0, 0, 0, -722478922, 0, 0, 0, -718425471, 0, 0, 0, -798841852, 0, 0, 0, -777990605, 0, 0, 0, -739872662, 0, 0, 0, -769385891, 0, 0, 0, -983630320, 0, 0, 0, -996371417, 0, 0, 0, -958780802, 0, 0, 0, -954711991, 0, 0, 0, -1034463540, 0, 0, 0, -1013629701, 0, 0, 0, -1043103070, 0, 0, 0, -1072568171, 0, 0, 0, -884101208, 0, 0, 0, -896547425, 0, 0, 0, -926319674, 0, 0, 0, -922021391, 0, 0, 0, -867956876, 0, 0, 0, -846828221, 0, 0, 0, -809446630, 0, 0, 0, -838682323, 0, 0, 0, -1850763712, 0, 0, 0, -1871840137, 0, 0, 0, -1842658770, 0, 0, 0, -1813436391, 0, 0, 0, -1767489892, 0, 0, 0, -1755032405, 0, 0, 0, -1792873742, 0, 0, 0, -1797226299, 0, 0, 0, -1615017992, 0, 0, 0, -1635865137, 0, 0, 0, -1674046570, 0, 0, 0, -1644529247, 0, 0, 0, -1732939996, 0, 0, 0, -1720253165, 0, 0, 0, -1691239606, 0, 0, 0, -1695297155, 0, 0, 0, -1920387792, 0, 0, 0, -1941217529, 0, 0, 0, -1911692962, 0, 0, 0, -1882223767, 0, 0, 0, -1971282452, 0, 0, 0, -1958545445, 0, 0, 0, -1996207742, 0, 0, 0, -2000280651, 0, 0, 0, -2087033720, 0, 0, 0, -2108158273, 0, 0, 0, -2145472282, 0, 0, 0, -2116232495, 0, 0, 0, -2070688684, 0, 0, 0, -2058246557, 0, 0, 0, -2028529606, 0, 0, 0, -2032831987, 0, 0, 0, -1444753248, 0, 0, 0, -1474250089, 0, 0, 0, -1436154674, 0, 0, 0, -1415287047, 0, 0, 0, -1360299908, 0, 0, 0, -1356262837, 0, 0, 0, -1385190382, 0, 0, 0, -1397897691, 0, 0, 0, -1477345000, 0, 0, 0, -1506546897, 0, 0, 0, -1535814282, 0, 0, 0, -1514717375, 0, 0, 0, -1594349116, 0, 0, 0, -1590017037, 0, 0, 0, -1552089686, 0, 0, 0, -1564567651, 0, 0, 0, -1245416496, 0, 0, 0, -1274668569, 0, 0, 0, -1237276738, 0, 0, 0, -1216164471, 0, 0, 0, -1295131892, 0, 0, 0, -1290817221, 0, 0, 0, -1320611998, 0, 0, 0, -1333041835, 0, 0, 0, -1143528856, 0, 0, 0, -1173010337, 0, 0, 0, -1202457082, 0, 0, 0, -1181639631, 0, 0, 0, -1126266188, 0, 0, 0, -1122180989, 0, 0, 0, -1084596518, 0, 0, 0, -1097321235, 0, 0, 0, 0, 0, 0, 0, -1195612315, 0, 0, 0, -1442199413, 0, 0, 0, 313896942, 0, 0, 0, -1889364137, 0, 0, 0, 937357362, 0, 0, 0, 627793884, 0, 0, 0, -1646839623, 0, 0, 0, -978048785, 0, 0, 0, 2097696650, 0, 0, 0, 1874714724, 0, 0, 0, -687765759, 0, 0, 0, 1255587768, 0, 0, 0, -227878691, 0, 0, 0, -522225869, 0, 0, 0, 1482887254, 0, 0, 0, 1343838111, 0, 0, 0, -391827206, 0, 0, 0, -99573996, 0, 0, 0, 1118632049, 0, 0, 0, -545537848, 0, 0, 0, 1741137837, 0, 0, 0, 1970407491, 0, 0, 0, -842109146, 0, 0, 0, -1783791760, 0, 0, 0, 756094997, 0, 0, 0, 1067759611, 0, 0, 0, -2028416866, 0, 0, 0, 449832999, 0, 0, 0, -1569484990, 0, 0, 0, -1329192788, 0, 0, 0, 142231497, 0, 0, 0, -1607291074, 0, 0, 0, 412010587, 0, 0, 0, 171665333, 0, 0, 0, -1299775280, 0, 0, 0, 793786473, 0, 0, 0, -1746116852, 0, 0, 0, -2057703198, 0, 0, 0, 1038456711, 0, 0, 0, 1703315409, 0, 0, 0, -583343948, 0, 0, 0, -812691622, 0, 0, 0, 1999841343, 0, 0, 0, -354152314, 0, 0, 0, 1381529571, 0, 0, 0, 1089329165, 0, 0, 0, -128860312, 0, 0, 0, -265553759, 0, 0, 0, 1217896388, 0, 0, 0, 1512189994, 0, 0, 0, -492939441, 0, 0, 0, 2135519222, 0, 0, 0, -940242797, 0, 0, 0, -717183107, 0, 0, 0, 1845280792, 0, 0, 0, 899665998, 0, 0, 0, -1927039189, 0, 0, 0, -1617553211, 0, 0, 0, 657096608, 0, 0, 0, -1157806311, 0, 0, 0, 37822588, 0, 0, 0, 284462994, 0, 0, 0, -1471616777, 0, 0, 0, -1693165507, 0, 0, 0, 598228824, 0, 0, 0, 824021174, 0, 0, 0, -1985873965, 0, 0, 0, 343330666, 0, 0, 0, -1396004849, 0, 0, 0, -1098971167, 0, 0, 0, 113467524, 0, 0, 0, 1587572946, 0, 0, 0, -434366537, 0, 0, 0, -190203815, 0, 0, 0, 1276501820, 0, 0, 0, -775755899, 0, 0, 0, 1769898208, 0, 0, 0, 2076913422, 0, 0, 0, -1015592853, 0, 0, 0, -888336478, 0, 0, 0, 1941006535, 0, 0, 0, 1627703081, 0, 0, 0, -642211764, 0, 0, 0, 1148164341, 0, 0, 0, -53215344, 0, 0, 0, -295284610, 0, 0, 0, 1457141531, 0, 0, 0, 247015245, 0, 0, 0, -1241169880, 0, 0, 0, -1531908154, 0, 0, 0, 470583459, 0, 0, 0, -2116308966, 0, 0, 0, 963106687, 0, 0, 0, 735213713, 0, 0, 0, -1821499404, 0, 0, 0, 992409347, 0, 0, 0, -2087022490, 0, 0, 0, -1859174520, 0, 0, 0, 697522413, 0, 0, 0, -1270587308, 0, 0, 0, 217581361, 0, 0, 0, 508405983, 0, 0, 0, -1494102086, 0, 0, 0, -23928852, 0, 0, 0, 1177467017, 0, 0, 0, 1419450215, 0, 0, 0, -332959742, 0, 0, 0, 1911572667, 0, 0, 0, -917753890, 0, 0, 0, -604405712, 0, 0, 0, 1665525589, 0, 0, 0, 1799331996, 0, 0, 0, -746338311, 0, 0, 0, -1053399017, 0, 0, 0, 2039091058, 0, 0, 0, -463652917, 0, 0, 0, 1558270126, 0, 0, 0, 1314193216, 0, 0, 0, -152528859, 0, 0, 0, -1366587277, 0, 0, 0, 372764438, 0, 0, 0, 75645176, 0, 0, 0, -1136777315, 0, 0, 0, 568925988, 0, 0, 0, -1722451903, 0, 0, 0, -1948198993, 0, 0, 0, 861712586, 0, 0, 0, -312887749, 0, 0, 0, 1441124702, 0, 0, 0, 1196457648, 0, 0, 0, -1304107, 0, 0, 0, 1648042348, 0, 0, 0, -628668919, 0, 0, 0, -936187417, 0, 0, 0, 1888390786, 0, 0, 0, 686661332, 0, 0, 0, -1873675855, 0, 0, 0, -2098964897, 0, 0, 0, 978858298, 0, 0, 0, -1483798141, 0, 0, 0, 523464422, 0, 0, 0, 226935048, 0, 0, 0, -1254447507, 0, 0, 0, -1119821404, 0, 0, 0, 100435649, 0, 0, 0, 390670639, 0, 0, 0, -1342878134, 0, 0, 0, 841119475, 0, 0, 0, -1969352298, 0, 0, 0, -1741963656, 0, 0, 0, 546822429, 0, 0, 0, 2029308235, 0, 0, 0, -1068978642, 0, 0, 0, -755170880, 0, 0, 0, 1782671013, 0, 0, 0, -141140452, 0, 0, 0, 1328167289, 0, 0, 0, 1570739863, 0, 0, 0, -450629134, 0, 0, 0, 1298864389, 0, 0, 0, -170426784, 0, 0, 0, -412954226, 0, 0, 0, 1608431339, 0, 0, 0, -1039561134, 0, 0, 0, 2058742071, 0, 0, 0, 1744848601, 0, 0, 0, -792976964, 0, 0, 0, -1998638614, 0, 0, 0, 811816591, 0, 0, 0, 584513889, 0, 0, 0, -1704288764, 0, 0, 0, 129869501, 0, 0, 0, -1090403880, 0, 0, 0, -1380684234, 0, 0, 0, 352848211, 0, 0, 0, 494030490, 0, 0, 0, -1513215489, 0, 0, 0, -1216641519, 0, 0, 0, 264757620, 0, 0, 0, -1844389427, 0, 0, 0, 715964072, 0, 0, 0, 941166918, 0, 0, 0, -2136639965, 0, 0, 0, -658086283, 0, 0, 0, 1618608400, 0, 0, 0, 1926213374, 0, 0, 0, -898381413, 0, 0, 0, 1470427426, 0, 0, 0, -283601337, 0, 0, 0, -38979159, 0, 0, 0, 1158766284, 0, 0, 0, 1984818694, 0, 0, 0, -823031453, 0, 0, 0, -599513459, 0, 0, 0, 1693991400, 0, 0, 0, -114329263, 0, 0, 0, 1100160564, 0, 0, 0, 1395044826, 0, 0, 0, -342174017, 0, 0, 0, -1275476247, 0, 0, 0, 189112716, 0, 0, 0, 435162722, 0, 0, 0, -1588827897, 0, 0, 0, 1016811966, 0, 0, 0, -2077804837, 0, 0, 0, -1768777419, 0, 0, 0, 774831696, 0, 0, 0, 643086745, 0, 0, 0, -1628905732, 0, 0, 0, -1940033262, 0, 0, 0, 887166583, 0, 0, 0, -1456066866, 0, 0, 0, 294275499, 0, 0, 0, 54519365, 0, 0, 0, -1149009632, 0, 0, 0, -471821962, 0, 0, 0, 1532818963, 0, 0, 0, 1240029693, 0, 0, 0, -246071656, 0, 0, 0, 1820460577, 0, 0, 0, -734109372, 0, 0, 0, -963916118, 0, 0, 0, 2117577167, 0, 0, 0, -696303304, 0, 0, 0, 1858283101, 0, 0, 0, 2088143283, 0, 0, 0, -993333546, 0, 0, 0, 1495127663, 0, 0, 0, -509497078, 0, 0, 0, -216785180, 0, 0, 0, 1269332353, 0, 0, 0, 332098007, 0, 0, 0, -1418260814, 0, 0, 0, -1178427044, 0, 0, 0, 25085497, 0, 0, 0, -1666580864, 0, 0, 0, 605395429, 0, 0, 0, 916469259, 0, 0, 0, -1910746770, 0, 0, 0, -2040129881, 0, 0, 0, 1054503362, 0, 0, 0, 745528876, 0, 0, 0, -1798063799, 0, 0, 0, 151290352, 0, 0, 0, -1313282411, 0, 0, 0, -1559410309, 0, 0, 0, 464596510, 0, 0, 0, 1137851976, 0, 0, 0, -76654291, 0, 0, 0, -371460413, 0, 0, 0, 1365741990, 0, 0, 0, -860837601, 0, 0, 0, 1946996346, 0, 0, 0, 1723425172, 0, 0, 0, -570095887, 0, 0, 0, 0, 0, 0, 0, -1775237257, 0, 0, 0, 744558318, 0, 0, 0, -1169094247, 0, 0, 0, 432303367, 0, 0, 0, -1879807376, 0, 0, 0, 900031465, 0, 0, 0, -1550490466, 0, 0, 0, 847829774, 0, 0, 0, -1531388807, 0, 0, 0, 518641120, 0, 0, 0, -1998990697, 0, 0, 0, 726447625, 0, 0, 0, -1115901570, 0, 0, 0, 120436967, 0, 0, 0, -1860321392, 0, 0, 0, 1678817053, 0, 0, 0, -232738710, 0, 0, 0, 1215412723, 0, 0, 0, -566116732, 0, 0, 0, 2111101466, 0, 0, 0, -337322643, 0, 0, 0, 1370871028, 0, 0, 0, -947530877, 0, 0, 0, 1452829715, 0, 0, 0, -1062704284, 0, 0, 0, 2063164157, 0, 0, 0, -322345590, 0, 0, 0, 1331429652, 0, 0, 0, -647231901, 0, 0, 0, 1664946170, 0, 0, 0, -183695219, 0, 0, 0, -937398725, 0, 0, 0, 1578133836, 0, 0, 0, -465477419, 0, 0, 0, 1920034722, 0, 0, 0, -773586116, 0, 0, 0, 1205077067, 0, 0, 0, -41611822, 0, 0, 0, 1807026853, 0, 0, 0, -89606859, 0, 0, 0, 1821946434, 0, 0, 0, -691422245, 0, 0, 0, 1090108588, 0, 0, 0, -479406030, 0, 0, 0, 1969020741, 0, 0, 0, -821176612, 0, 0, 0, 1497223595, 0, 0, 0, -1406084826, 0, 0, 0, 973135441, 0, 0, 0, -2142119992, 0, 0, 0, 375509183, 0, 0, 0, -1242254303, 0, 0, 0, 600093526, 0, 0, 0, -1718240561, 0, 0, 0, 262520248, 0, 0, 0, -1632107992, 0, 0, 0, 143131999, 0, 0, 0, -1294398266, 0, 0, 0, 619252657, 0, 0, 0, -2021888209, 0, 0, 0, 290220120, 0, 0, 0, -1424137791, 0, 0, 0, 1026385590, 0, 0, 0, -1874731914, 0, 0, 0, 108124929, 0, 0, 0, -1138699624, 0, 0, 0, 705746415, 0, 0, 0, -1987726991, 0, 0, 0, 532002310, 0, 0, 0, -1511735393, 0, 0, 0, 869578984, 0, 0, 0, -1563883656, 0, 0, 0, 888733711, 0, 0, 0, -1901590122, 0, 0, 0, 412618465, 0, 0, 0, -1156748673, 0, 0, 0, 759000328, 0, 0, 0, -1754504047, 0, 0, 0, 22832102, 0, 0, 0, -195990677, 0, 0, 0, 1650551836, 0, 0, 0, -667916923, 0, 0, 0, 1308648178, 0, 0, 0, -309000596, 0, 0, 0, 2074411291, 0, 0, 0, -1040971646, 0, 0, 0, 1472466933, 0, 0, 0, -958812059, 0, 0, 0, 1357494034, 0, 0, 0, -356991349, 0, 0, 0, 2089335292, 0, 0, 0, -551690910, 0, 0, 0, 1227741717, 0, 0, 0, -209923188, 0, 0, 0, 1699534075, 0, 0, 0, 1482797645, 0, 0, 0, -833505990, 0, 0, 0, 1946205347, 0, 0, 0, -500122668, 0, 0, 0, 1101389642, 0, 0, 0, -678045635, 0, 0, 0, 1841615268, 0, 0, 0, -67840301, 0, 0, 0, 1793681731, 0, 0, 0, -52859340, 0, 0, 0, 1183344557, 0, 0, 0, -793222950, 0, 0, 0, 1932330052, 0, 0, 0, -451083469, 0, 0, 0, 1598818986, 0, 0, 0, -914616867, 0, 0, 0, 1014039888, 0, 0, 0, -1438580185, 0, 0, 0, 269487038, 0, 0, 0, -2044719927, 0, 0, 0, 632645719, 0, 0, 0, -1283100896, 0, 0, 0, 164914873, 0, 0, 0, -1612422706, 0, 0, 0, 251256414, 0, 0, 0, -1731602135, 0, 0, 0, 580440240, 0, 0, 0, -1264003129, 0, 0, 0, 389919577, 0, 0, 0, -2129808338, 0, 0, 0, 995933623, 0, 0, 0, -1385383232, 0, 0, 0, 545503469, 0, 0, 0, -1229733990, 0, 0, 0, 216184323, 0, 0, 0, -1697468044, 0, 0, 0, 961009130, 0, 0, 0, -1351101795, 0, 0, 0, 354867972, 0, 0, 0, -2095653773, 0, 0, 0, 302736355, 0, 0, 0, -2076482412, 0, 0, 0, 1047162125, 0, 0, 0, -1470469510, 0, 0, 0, 198119140, 0, 0, 0, -1644230253, 0, 0, 0, 665714698, 0, 0, 0, -1315043459, 0, 0, 0, 1150488560, 0, 0, 0, -761067385, 0, 0, 0, 1760690462, 0, 0, 0, -20838807, 0, 0, 0, 1566008055, 0, 0, 0, -882416256, 0, 0, 0, 1899392025, 0, 0, 0, -419009682, 0, 0, 0, 1981535486, 0, 0, 0, -533998711, 0, 0, 0, 1518000656, 0, 0, 0, -867508889, 0, 0, 0, 1876933113, 0, 0, 0, -101728626, 0, 0, 0, 1136572183, 0, 0, 0, -712069024, 0, 0, 0, -391915818, 0, 0, 0, 2123616673, 0, 0, 0, -993863624, 0, 0, 0, 1391648591, 0, 0, 0, -244859951, 0, 0, 0, 1733803174, 0, 0, 0, -586762945, 0, 0, 0, 1261875784, 0, 0, 0, -634712616, 0, 0, 0, 1276840623, 0, 0, 0, -162921674, 0, 0, 0, 1618609217, 0, 0, 0, -1007722273, 0, 0, 0, 1440704424, 0, 0, 0, -275878351, 0, 0, 0, 2042521926, 0, 0, 0, -1934401077, 0, 0, 0, 444819132, 0, 0, 0, -1596821723, 0, 0, 0, 920807506, 0, 0, 0, -1787360052, 0, 0, 0, 54987707, 0, 0, 0, -1189739998, 0, 0, 0, 791020885, 0, 0, 0, -1103381819, 0, 0, 0, 671858098, 0, 0, 0, -1839549397, 0, 0, 0, 74101596, 0, 0, 0, -1476405310, 0, 0, 0, 835702965, 0, 0, 0, -1952523988, 0, 0, 0, 497999451, 0, 0, 0, -1329437541, 0, 0, 0, 653419500, 0, 0, 0, -1667011979, 0, 0, 0, 177433858, 0, 0, 0, -1459222116, 0, 0, 0, 1060507371, 0, 0, 0, -2056845454, 0, 0, 0, 324468741, 0, 0, 0, -2109030507, 0, 0, 0, 343587042, 0, 0, 0, -1372868229, 0, 0, 0, 941340172, 0, 0, 0, -1685138798, 0, 0, 0, 230610405, 0, 0, 0, -1209017220, 0, 0, 0, 568318731, 0, 0, 0, -724380794, 0, 0, 0, 1122161905, 0, 0, 0, -122430104, 0, 0, 0, 1854134815, 0, 0, 0, -854147455, 0, 0, 0, 1529264630, 0, 0, 0, -512249745, 0, 0, 0, 2001188632, 0, 0, 0, -430307192, 0, 0, 0, 1885999103, 0, 0, 0, -902101402, 0, 0, 0, 1544225041, 0, 0, 0, -6396529, 0, 0, 0, 1773036280, 0, 0, 0, -738235551, 0, 0, 0, 1171221526, 0, 0, 0, 2028079776, 0, 0, 0, -288223785, 0, 0, 0, 1417872462, 0, 0, 0, -1028455623, 0, 0, 0, 1629906855, 0, 0, 0, -149528368, 0, 0, 0, 1296525641, 0, 0, 0, -612929986, 0, 0, 0, 1248514478, 0, 0, 0, -598026535, 0, 0, 0, 1712054080, 0, 0, 0, -264513481, 0, 0, 0, 1403960489, 0, 0, 0, -979452962, 0, 0, 0, 2144318023, 0, 0, 0, -369117904, 0, 0, 0, 485670333, 0, 0, 0, -1966949686, 0, 0, 0, 814986067, 0, 0, 0, -1499220956, 0, 0, 0, 87478458, 0, 0, 0, -1828268083, 0, 0, 0, 693624404, 0, 0, 0, -1083713245, 0, 0, 0, 779773619, 0, 0, 0, -1203084860, 0, 0, 0, 35350621, 0, 0, 0, -1809092822, 0, 0, 0, 935201716, 0, 0, 0, -1584526141, 0, 0, 0, 467600730, 0, 0, 0, -1913716179, 0, 0, 0, 0, 0, 0, 0, 1093737241, 0, 0, 0, -2107492814, 0, 0, 0, -1017959125, 0, 0, 0, 80047204, 0, 0, 0, 1173649277, 0, 0, 0, -2035852714, 0, 0, 0, -946454193, 0, 0, 0, 143317448, 0, 0, 0, 1237041873, 0, 0, 0, -1964445702, 0, 0, 0, -874908445, 0, 0, 0, 206550444, 0, 0, 0, 1300147893, 0, 0, 0, -1909619810, 0, 0, 0, -820209529, 0, 0, 0, 1360183882, 0, 0, 0, 270784851, 0, 0, 0, -747572104, 0, 0, 0, -1841172639, 0, 0, 0, 1440198190, 0, 0, 0, 350663991, 0, 0, 0, -675964900, 0, 0, 0, -1769700603, 0, 0, 0, 1503140738, 0, 0, 0, 413728923, 0, 0, 0, -604361296, 0, 0, 0, -1697958231, 0, 0, 0, 1566406630, 0, 0, 0, 476867839, 0, 0, 0, -549502508, 0, 0, 0, -1643226419, 0, 0, 0, -1574665067, 0, 0, 0, -485122164, 0, 0, 0, 541504167, 0, 0, 0, 1635232190, 0, 0, 0, -1495144207, 0, 0, 0, -405736472, 0, 0, 0, 612622019, 0, 0, 0, 1706214874, 0, 0, 0, -1431413411, 0, 0, 0, -341883324, 0, 0, 0, 684485487, 0, 0, 0, 1778217078, 0, 0, 0, -1368706759, 0, 0, 0, -279303648, 0, 0, 0, 738789131, 0, 0, 0, 1832393746, 0, 0, 0, -214546721, 0, 0, 0, -1308140090, 0, 0, 0, 1901359341, 0, 0, 0, 811953140, 0, 0, 0, -135058757, 0, 0, 0, -1228787294, 0, 0, 0, 1972444297, 0, 0, 0, 882902928, 0, 0, 0, -71524585, 0, 0, 0, -1165130738, 0, 0, 0, 2044635429, 0, 0, 0, 955232828, 0, 0, 0, -8785037, 0, 0, 0, -1102518166, 0, 0, 0, 2098971969, 0, 0, 0, 1009442392, 0, 0, 0, 89094640, 0, 0, 0, 1149133545, 0, 0, 0, -2027073598, 0, 0, 0, -971221797, 0, 0, 0, 25826708, 0, 0, 0, 1086000781, 0, 0, 0, -2081938522, 0, 0, 0, -1025951553, 0, 0, 0, 231055416, 0, 0, 0, 1291107105, 0, 0, 0, -1884842486, 0, 0, 0, -828994285, 0, 0, 0, 151047260, 0, 0, 0, 1211225925, 0, 0, 0, -1956447634, 0, 0, 0, -900472457, 0, 0, 0, 1415429050, 0, 0, 0, 359440547, 0, 0, 0, -700478072, 0, 0, 0, -1760651631, 0, 0, 0, 1352194014, 0, 0, 0, 296340679, 0, 0, 0, -755310100, 0, 0, 0, -1815348491, 0, 0, 0, 1557619314, 0, 0, 0, 501643627, 0, 0, 0, -558541760, 0, 0, 0, -1618718887, 0, 0, 0, 1477578262, 0, 0, 0, 421729551, 0, 0, 0, -630179804, 0, 0, 0, -1690229955, 0, 0, 0, -1486095003, 0, 0, 0, -430250372, 0, 0, 0, 621398871, 0, 0, 0, 1681444942, 0, 0, 0, -1548840703, 0, 0, 0, -492860904, 0, 0, 0, 567060275, 0, 0, 0, 1627241514, 0, 0, 0, -1344199507, 0, 0, 0, -288342092, 0, 0, 0, 763564703, 0, 0, 0, 1823607174, 0, 0, 0, -1423685431, 0, 0, 0, -367701040, 0, 0, 0, 692485883, 0, 0, 0, 1752655330, 0, 0, 0, -159826129, 0, 0, 0, -1220008906, 0, 0, 0, 1947928861, 0, 0, 0, 891949572, 0, 0, 0, -222538933, 0, 0, 0, -1282586542, 0, 0, 0, 1893623161, 0, 0, 0, 837779040, 0, 0, 0, -17570073, 0, 0, 0, -1077740034, 0, 0, 0, 2089930965, 0, 0, 0, 1033948108, 0, 0, 0, -97088893, 0, 0, 0, -1157131878, 0, 0, 0, 2018819249, 0, 0, 0, 962963368, 0, 0, 0, 1268286267, 0, 0, 0, 178886690, 0, 0, 0, -906316535, 0, 0, 0, -1999917552, 0, 0, 0, 1331556191, 0, 0, 0, 242021446, 0, 0, 0, -851453587, 0, 0, 0, -1945189772, 0, 0, 0, 1125276403, 0, 0, 0, 35865066, 0, 0, 0, -1049596735, 0, 0, 0, -2143193128, 0, 0, 0, 1205286551, 0, 0, 0, 115748238, 0, 0, 0, -977993563, 0, 0, 0, -2071716932, 0, 0, 0, 445268337, 0, 0, 0, 1539005032, 0, 0, 0, -1729595581, 0, 0, 0, -640062374, 0, 0, 0, 508505365, 0, 0, 0, 1602106892, 0, 0, 0, -1674765529, 0, 0, 0, -585367490, 0, 0, 0, 302028985, 0, 0, 0, 1395753888, 0, 0, 0, -1872580981, 0, 0, 0, -783043182, 0, 0, 0, 382072029, 0, 0, 0, 1475669956, 0, 0, 0, -1800944913, 0, 0, 0, -711534090, 0, 0, 0, -373553234, 0, 0, 0, -1467147081, 0, 0, 0, 1809723804, 0, 0, 0, 720317061, 0, 0, 0, -310809654, 0, 0, 0, -1404538669, 0, 0, 0, 1864064504, 0, 0, 0, 774522593, 0, 0, 0, -516497818, 0, 0, 0, -1610103425, 0, 0, 0, 1666508884, 0, 0, 0, 577106765, 0, 0, 0, -437014014, 0, 0, 0, -1530746597, 0, 0, 0, 1737589808, 0, 0, 0, 648060713, 0, 0, 0, -1196505628, 0, 0, 0, -106963203, 0, 0, 0, 986510294, 0, 0, 0, 2080237775, 0, 0, 0, -1133794944, 0, 0, 0, -44387687, 0, 0, 0, 1040818098, 0, 0, 0, 2134410411, 0, 0, 0, -1339810772, 0, 0, 0, -250280139, 0, 0, 0, 843459102, 0, 0, 0, 1937191175, 0, 0, 0, -1260294072, 0, 0, 0, -170890415, 0, 0, 0, 914572922, 0, 0, 0, 2008178019, 0, 0, 0, 1322777291, 0, 0, 0, 266789330, 0, 0, 0, -860500743, 0, 0, 0, -1920673824, 0, 0, 0, 1242732207, 0, 0, 0, 186879414, 0, 0, 0, -932142947, 0, 0, 0, -1992180860, 0, 0, 0, 1180508931, 0, 0, 0, 124532762, 0, 0, 0, -1002498767, 0, 0, 0, -2062676440, 0, 0, 0, 1117278055, 0, 0, 0, 61428862, 0, 0, 0, -1057326763, 0, 0, 0, -2117377460, 0, 0, 0, 533018753, 0, 0, 0, 1593058200, 0, 0, 0, -1649996109, 0, 0, 0, -594143830, 0, 0, 0, 453006565, 0, 0, 0, 1513181180, 0, 0, 0, -1721605417, 0, 0, 0, -665617970, 0, 0, 0, 391110985, 0, 0, 0, 1451162192, 0, 0, 0, -1792157829, 0, 0, 0, -736310174, 0, 0, 0, 327847213, 0, 0, 0, 1388025396, 0, 0, 0, -1847018721, 0, 0, 0, -791044090, 0, 0, 0, -319586722, 0, 0, 0, -1379769017, 0, 0, 0, 1855015020, 0, 0, 0, 799036277, 0, 0, 0, -399109574, 0, 0, 0, -1459156701, 0, 0, 0, 1783899144, 0, 0, 0, 728055569, 0, 0, 0, -461789290, 0, 0, 0, -1521959793, 0, 0, 0, 1713082788, 0, 0, 0, 657099453, 0, 0, 0, -524497934, 0, 0, 0, -1584541461, 0, 0, 0, 1658781120, 0, 0, 0, 602924761, 0, 0, 0, -1109279724, 0, 0, 0, -53434611, 0, 0, 0, 1065585190, 0, 0, 0, 2125631807, 0, 0, 0, -1188769680, 0, 0, 0, -132789399, 0, 0, 0, 994502210, 0, 0, 0, 2054683995, 0, 0, 0, -1251252772, 0, 0, 0, -195395899, 0, 0, 0, 923358190, 0, 0, 0, 1983400183, 0, 0, 0, -1313994312, 0, 0, 0, -258010463, 0, 0, 0, 869023626, 0, 0, 0, 1929192595, 0, 0, 0, 0, 0, 0, 0, 929743361, 0, 0, 0, 1859421187, 0, 0, 0, 1505641986, 0, 0, 0, -592967417, 0, 0, 0, -339555578, 0, 0, 0, -1300460284, 0, 0, 0, -2062135547, 0, 0, 0, -1202646258, 0, 0, 0, -1891905265, 0, 0, 0, -695888115, 0, 0, 0, -504408820, 0, 0, 0, 1694046729, 0, 0, 0, 1402198024, 0, 0, 0, 170761738, 0, 0, 0, 1028086795, 0, 0, 0, 1889740316, 0, 0, 0, 1204413469, 0, 0, 0, 511156767, 0, 0, 0, 689791006, 0, 0, 0, -1408553189, 0, 0, 0, -1688081126, 0, 0, 0, -1025529064, 0, 0, 0, -172660455, 0, 0, 0, -923650798, 0, 0, 0, -6752493, 0, 0, 0, -1507413743, 0, 0, 0, -1857260784, 0, 0, 0, 341457941, 0, 0, 0, 590413332, 0, 0, 0, 2056173590, 0, 0, 0, 1306819095, 0, 0, 0, -532263624, 0, 0, 0, -684945607, 0, 0, 0, -1902982853, 0, 0, 0, -1174926534, 0, 0, 0, 1022247999, 0, 0, 0, 193234494, 0, 0, 0, 1379582012, 0, 0, 0, 1699742269, 0, 0, 0, 1477926454, 0, 0, 0, 1870502967, 0, 0, 0, 918805045, 0, 0, 0, 27858996, 0, 0, 0, -2067835087, 0, 0, 0, -1277848272, 0, 0, 0, -362032334, 0, 0, 0, -587132621, 0, 0, 0, -1864013020, 0, 0, 0, -1483757275, 0, 0, 0, -30281945, 0, 0, 0, -916771546, 0, 0, 0, 1280139811, 0, 0, 0, 2066194466, 0, 0, 0, 580511264, 0, 0, 0, 368256033, 0, 0, 0, 682915882, 0, 0, 0, 534690347, 0, 0, 0, 1180761129, 0, 0, 0, 1896496680, 0, 0, 0, -199462611, 0, 0, 0, -1015631060, 0, 0, 0, -1698106066, 0, 0, 0, -1381877969, 0, 0, 0, -1064461712, 0, 0, 0, -135833487, 0, 0, 0, -1369891213, 0, 0, 0, -1724654478, 0, 0, 0, 472224631, 0, 0, 0, 726618486, 0, 0, 0, 1928402804, 0, 0, 0, 1167840629, 0, 0, 0, 2027719038, 0, 0, 0, 1337346943, 0, 0, 0, 369626493, 0, 0, 0, 560123772, 0, 0, 0, -1535868807, 0, 0, 0, -1826733448, 0, 0, 0, -895482758, 0, 0, 0, -37042565, 0, 0, 0, -1339114388, 0, 0, 0, -2025554323, 0, 0, 0, -554026897, 0, 0, 0, -376374674, 0, 0, 0, 1820767595, 0, 0, 0, 1542223722, 0, 0, 0, 38941032, 0, 0, 0, 892924777, 0, 0, 0, 142585698, 0, 0, 0, 1058368867, 0, 0, 0, 1722493793, 0, 0, 0, 1371662688, 0, 0, 0, -724064667, 0, 0, 0, -474127260, 0, 0, 0, -1174199706, 0, 0, 0, -1922441113, 0, 0, 0, 550229832, 0, 0, 0, 396432713, 0, 0, 0, 1310675787, 0, 0, 0, 2037748042, 0, 0, 0, -60563889, 0, 0, 0, -888595378, 0, 0, 0, -1833477556, 0, 0, 0, -1512204211, 0, 0, 0, -1734687674, 0, 0, 0, -1343224249, 0, 0, 0, -162643899, 0, 0, 0, -1054571964, 0, 0, 0, 1144180033, 0, 0, 0, 1935150912, 0, 0, 0, 719735106, 0, 0, 0, 495749955, 0, 0, 0, 1349054804, 0, 0, 0, 1728197461, 0, 0, 0, 1052538199, 0, 0, 0, 165066582, 0, 0, 0, -1933510573, 0, 0, 0, -1146471854, 0, 0, 0, -501973936, 0, 0, 0, -713114031, 0, 0, 0, -398859686, 0, 0, 0, -548200357, 0, 0, 0, -2031262119, 0, 0, 0, -1316510632, 0, 0, 0, 881978205, 0, 0, 0, 66791772, 0, 0, 0, 1514499934, 0, 0, 0, 1831841119, 0, 0, 0, -2145700383, 0, 0, 0, -1217267744, 0, 0, 0, -288378398, 0, 0, 0, -643468317, 0, 0, 0, 1555250406, 0, 0, 0, 1809448679, 0, 0, 0, 845658341, 0, 0, 0, 84769508, 0, 0, 0, 944383727, 0, 0, 0, 253813998, 0, 0, 0, 1453236972, 0, 0, 0, 1643405549, 0, 0, 0, -454938648, 0, 0, 0, -746000919, 0, 0, 0, -1976128533, 0, 0, 0, -1118017046, 0, 0, 0, -256371715, 0, 0, 0, -942484996, 0, 0, 0, -1637050370, 0, 0, 0, -1459202561, 0, 0, 0, 739252986, 0, 0, 0, 461035771, 0, 0, 0, 1120182009, 0, 0, 0, 1974361336, 0, 0, 0, 1223229683, 0, 0, 0, 2139341554, 0, 0, 0, 641565936, 0, 0, 0, 290932465, 0, 0, 0, -1807676940, 0, 0, 0, -1557410827, 0, 0, 0, -90862089, 0, 0, 0, -838905866, 0, 0, 0, 1616738521, 0, 0, 0, 1463270104, 0, 0, 0, 243924186, 0, 0, 0, 971194075, 0, 0, 0, -1124765218, 0, 0, 0, -1952468001, 0, 0, 0, -769526307, 0, 0, 0, -448055332, 0, 0, 0, -670274601, 0, 0, 0, -278484522, 0, 0, 0, -1227296812, 0, 0, 0, -2119029291, 0, 0, 0, 77882064, 0, 0, 0, 869179601, 0, 0, 0, 1785784019, 0, 0, 0, 1561994450, 0, 0, 0, 285105861, 0, 0, 0, 664050884, 0, 0, 0, 2116737734, 0, 0, 0, 1228937415, 0, 0, 0, -866756670, 0, 0, 0, -79915581, 0, 0, 0, -1568484415, 0, 0, 0, -1779953216, 0, 0, 0, -1464906293, 0, 0, 0, -1614442550, 0, 0, 0, -964965944, 0, 0, 0, -250541111, 0, 0, 0, 1946633420, 0, 0, 0, 1131251405, 0, 0, 0, 450085071, 0, 0, 0, 767099598, 0, 0, 0, 1083617169, 0, 0, 0, 2013031824, 0, 0, 0, 776088466, 0, 0, 0, 422111635, 0, 0, 0, -1673615722, 0, 0, 0, -1420532585, 0, 0, 0, -219536747, 0, 0, 0, -981409644, 0, 0, 0, -121127777, 0, 0, 0, -810713442, 0, 0, 0, -1777125220, 0, 0, 0, -1585841507, 0, 0, 0, 611300760, 0, 0, 0, 319125401, 0, 0, 0, 1253781915, 0, 0, 0, 2110911386, 0, 0, 0, 808814989, 0, 0, 0, 123685772, 0, 0, 0, 1591807374, 0, 0, 0, 1770770319, 0, 0, 0, -325222262, 0, 0, 0, -604552565, 0, 0, 0, -2109143927, 0, 0, 0, -1255946616, 0, 0, 0, -2006672765, 0, 0, 0, -1089578878, 0, 0, 0, -424665472, 0, 0, 0, -774185855, 0, 0, 0, 1422693252, 0, 0, 0, 1671844229, 0, 0, 0, 974657415, 0, 0, 0, 225629574, 0, 0, 0, -1596923223, 0, 0, 0, -1749409624, 0, 0, 0, -838572374, 0, 0, 0, -110189397, 0, 0, 0, 2088299438, 0, 0, 0, 1259481519, 0, 0, 0, 313290669, 0, 0, 0, 633777580, 0, 0, 0, 411169191, 0, 0, 0, 803943334, 0, 0, 0, 1985312164, 0, 0, 0, 1094694821, 0, 0, 0, -1003882336, 0, 0, 0, -213697887, 0, 0, 0, -1426228061, 0, 0, 0, -1650999646, 0, 0, 0, -797719371, 0, 0, 0, -417790284, 0, 0, 0, -1096335178, 0, 0, 0, -1983020361, 0, 0, 0, 215731634, 0, 0, 0, 1001459635, 0, 0, 0, 1645169073, 0, 0, 0, 1432718256, 0, 0, 0, 1747113915, 0, 0, 0, 1598559674, 0, 0, 0, 116806584, 0, 0, 0, 832344505, 0, 0, 0, -1265967428, 0, 0, 0, -2082464579, 0, 0, 0, -631350593, 0, 0, 0, -315320130, 0, 0, 0, 0, 0, 0, 0, 1701297336, 0, 0, 0, -1949824598, 0, 0, 0, -290474734, 0, 0, 0, 1469538959, 0, 0, 0, 854646327, 0, 0, 0, -597726427, 0, 0, 0, -1187457123, 0, 0, 0, -282544955, 0, 0, 0, -1974531971, 0, 0, 0, 1692450159, 0, 0, 0, 25625047, 0, 0, 0, -1195387318, 0, 0, 0, -573019406, 0, 0, 0, 863494112, 0, 0, 0, 1443914584, 0, 0, 0, -1621681840, 0, 0, 0, -97475096, 0, 0, 0, 345968890, 0, 0, 0, 1912122434, 0, 0, 0, -926909473, 0, 0, 0, -1381513369, 0, 0, 0, 1124627061, 0, 0, 0, 644861645, 0, 0, 0, 1887415701, 0, 0, 0, 353898797, 0, 0, 0, -71850945, 0, 0, 0, -1630529401, 0, 0, 0, 669568794, 0, 0, 0, 1116697506, 0, 0, 0, -1407138128, 0, 0, 0, -918062584, 0, 0, 0, 1051669152, 0, 0, 0, 1539870232, 0, 0, 0, -1251525878, 0, 0, 0, -805271630, 0, 0, 0, 1765298223, 0, 0, 0, 207613079, 0, 0, 0, -487564923, 0, 0, 0, -2020088515, 0, 0, 0, -779647387, 0, 0, 0, -1260373283, 0, 0, 0, 1515163599, 0, 0, 0, 1059599223, 0, 0, 0, -2045713174, 0, 0, 0, -478717870, 0, 0, 0, 232320320, 0, 0, 0, 1757368824, 0, 0, 0, -1577571344, 0, 0, 0, -996174008, 0, 0, 0, 707797594, 0, 0, 0, 1331142370, 0, 0, 0, -160478849, 0, 0, 0, -1828129337, 0, 0, 0, 2108113109, 0, 0, 0, 415300717, 0, 0, 0, 1322295093, 0, 0, 0, 733422477, 0, 0, 0, -988244321, 0, 0, 0, -1602278873, 0, 0, 0, 424148410, 0, 0, 0, 2082488578, 0, 0, 0, -1836059632, 0, 0, 0, -135771992, 0, 0, 0, 1029182619, 0, 0, 0, 1480566819, 0, 0, 0, -1232069327, 0, 0, 0, -738745975, 0, 0, 0, 1791981076, 0, 0, 0, 262720172, 0, 0, 0, -519602242, 0, 0, 0, -2074033402, 0, 0, 0, -764370850, 0, 0, 0, -1223222042, 0, 0, 0, 1505274356, 0, 0, 0, 1021252940, 0, 0, 0, -2048408879, 0, 0, 0, -528449943, 0, 0, 0, 238013307, 0, 0, 0, 1799911363, 0, 0, 0, -1576071733, 0, 0, 0, -949440141, 0, 0, 0, 700908641, 0, 0, 0, 1285601497, 0, 0, 0, -174559420, 0, 0, 0, -1862282244, 0, 0, 0, 2119198446, 0, 0, 0, 456645206, 0, 0, 0, 1294448910, 0, 0, 0, 675284406, 0, 0, 0, -957370204, 0, 0, 0, -1551365092, 0, 0, 0, 447798145, 0, 0, 0, 2144823097, 0, 0, 0, -1854352853, 0, 0, 0, -199266669, 0, 0, 0, 66528827, 0, 0, 0, 1720752771, 0, 0, 0, -2009124975, 0, 0, 0, -312962263, 0, 0, 0, 1415595188, 0, 0, 0, 822605836, 0, 0, 0, -542618338, 0, 0, 0, -1160777306, 0, 0, 0, -320892162, 0, 0, 0, -1984418234, 0, 0, 0, 1729600340, 0, 0, 0, 40904684, 0, 0, 0, -1152847759, 0, 0, 0, -567325495, 0, 0, 0, 813758939, 0, 0, 0, 1441219939, 0, 0, 0, -1667219605, 0, 0, 0, -104365101, 0, 0, 0, 392705729, 0, 0, 0, 1913621113, 0, 0, 0, -885563932, 0, 0, 0, -1370431140, 0, 0, 0, 1090475086, 0, 0, 0, 630778102, 0, 0, 0, 1938328494, 0, 0, 0, 384775958, 0, 0, 0, -129990140, 0, 0, 0, -1658372420, 0, 0, 0, 606071073, 0, 0, 0, 1098405273, 0, 0, 0, -1344806773, 0, 0, 0, -894411725, 0, 0, 0, 1001806317, 0, 0, 0, 1590814037, 0, 0, 0, -1333899193, 0, 0, 0, -719721217, 0, 0, 0, 1814117218, 0, 0, 0, 155617242, 0, 0, 0, -404147512, 0, 0, 0, -2104586640, 0, 0, 0, -727782104, 0, 0, 0, -1309060720, 0, 0, 0, 1599530114, 0, 0, 0, 976312378, 0, 0, 0, -2096525401, 0, 0, 0, -428985569, 0, 0, 0, 146900493, 0, 0, 0, 1839610549, 0, 0, 0, -1528741699, 0, 0, 0, -1048118267, 0, 0, 0, 791234839, 0, 0, 0, 1246688687, 0, 0, 0, -210361806, 0, 0, 0, -1777230198, 0, 0, 0, 2025728920, 0, 0, 0, 500799264, 0, 0, 0, 1271526520, 0, 0, 0, 783173824, 0, 0, 0, -1073611310, 0, 0, 0, -1520025238, 0, 0, 0, 475961079, 0, 0, 0, 2033789519, 0, 0, 0, -1751736483, 0, 0, 0, -219077659, 0, 0, 0, 85551949, 0, 0, 0, 1618925557, 0, 0, 0, -1898880281, 0, 0, 0, -340337057, 0, 0, 0, 1385040322, 0, 0, 0, 938063226, 0, 0, 0, -649723800, 0, 0, 0, -1138639664, 0, 0, 0, -365830264, 0, 0, 0, -1890163920, 0, 0, 0, 1643763234, 0, 0, 0, 77490842, 0, 0, 0, -1113146105, 0, 0, 0, -658439745, 0, 0, 0, 913224877, 0, 0, 0, 1393100821, 0, 0, 0, -1706135011, 0, 0, 0, -14037339, 0, 0, 0, 294026167, 0, 0, 0, 1960953615, 0, 0, 0, -841412462, 0, 0, 0, -1463899094, 0, 0, 0, 1175525688, 0, 0, 0, 594978176, 0, 0, 0, 1969669848, 0, 0, 0, 268532320, 0, 0, 0, -22098062, 0, 0, 0, -1681296438, 0, 0, 0, 586261591, 0, 0, 0, 1201019119, 0, 0, 0, -1455837699, 0, 0, 0, -866250427, 0, 0, 0, 116280694, 0, 0, 0, 1669984718, 0, 0, 0, -1926871844, 0, 0, 0, -398329756, 0, 0, 0, 1366896633, 0, 0, 0, 874419009, 0, 0, 0, -625924525, 0, 0, 0, -1076454677, 0, 0, 0, -372835917, 0, 0, 0, -1935588085, 0, 0, 0, 1645146137, 0, 0, 0, 124341409, 0, 0, 0, -1101948100, 0, 0, 0, -617207932, 0, 0, 0, 899256982, 0, 0, 0, 1358835246, 0, 0, 0, -1715907546, 0, 0, 0, -52500322, 0, 0, 0, 309419404, 0, 0, 0, 1997988148, 0, 0, 0, -835832151, 0, 0, 0, -1421243887, 0, 0, 0, 1172717315, 0, 0, 0, 545358779, 0, 0, 0, 1989271779, 0, 0, 0, 334912603, 0, 0, 0, -44439223, 0, 0, 0, -1740745231, 0, 0, 0, 554074732, 0, 0, 0, 1147223764, 0, 0, 0, -1429304378, 0, 0, 0, -810993794, 0, 0, 0, 943816662, 0, 0, 0, 1562821486, 0, 0, 0, -1282836868, 0, 0, 0, -688993596, 0, 0, 0, 1876303193, 0, 0, 0, 179413473, 0, 0, 0, -467790605, 0, 0, 0, -2122733493, 0, 0, 0, -680932589, 0, 0, 0, -1307674709, 0, 0, 0, 1554105017, 0, 0, 0, 969309697, 0, 0, 0, -2130794084, 0, 0, 0, -442952412, 0, 0, 0, 188129334, 0, 0, 0, 1850809486, 0, 0, 0, -1491704186, 0, 0, 0, -1032725954, 0, 0, 0, 752774956, 0, 0, 0, 1236915092, 0, 0, 0, -259980279, 0, 0, 0, -1780041551, 0, 0, 0, 2068385187, 0, 0, 0, 506376475, 0, 0, 0, 1212076611, 0, 0, 0, 760835835, 0, 0, 0, -1007232023, 0, 0, 0, -1500420271, 0, 0, 0, 531214540, 0, 0, 0, 2060323956, 0, 0, 0, -1805534874, 0, 0, 0, -251263522, 0, 0, 0], ["i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0], ALLOC_STATIC);
STRING_TABLE._deflateInit2__my_version=allocate([49,46,50,46,55,0] /* 1.2.7\00 */, "i8", ALLOC_STATIC);
_configuration_table=allocate([0, 0, 0, 0, 0, 0, 0, 0, 256, 0, 0, 0, 4, 0, 4, 0, 8, 0, 4, 0, 258, 0, 0, 0, 4, 0, 5, 0, 16, 0, 8, 0, 258, 0, 0, 0, 4, 0, 6, 0, 32, 0, 32, 0, 258, 0, 0, 0, 4, 0, 4, 0, 16, 0, 16, 0, 260, 0, 0, 0, 8, 0, 16, 0, 32, 0, 32, 0, 260, 0, 0, 0, 8, 0, 16, 0, 128, 0, 128, 0, 260, 0, 0, 0, 8, 0, 32, 0, 128, 0, 256, 0, 260, 0, 0, 0, 32, 0, 128, 0, 258, 0, 1024, 0, 260, 0, 0, 0, 32, 0, 258, 0, 258, 0, 4096, 0, 260, 0, 0, 0], ["i16",0,"i16",0,"i16",0,"i16",0,"*",0,0,0,"i16",0,"i16",0,"i16",0,"i16",0,"*",0,0,0,"i16",0,"i16",0,"i16",0,"i16",0,"*",0,0,0,"i16",0,"i16",0,"i16",0,"i16",0,"*",0,0,0,"i16",0,"i16",0,"i16",0,"i16",0,"*",0,0,0,"i16",0,"i16",0,"i16",0,"i16",0,"*",0,0,0,"i16",0,"i16",0,"i16",0,"i16",0,"*",0,0,0,"i16",0,"i16",0,"i16",0,"i16",0,"*",0,0,0,"i16",0,"i16",0,"i16",0,"i16",0,"*",0,0,0,"i16",0,"i16",0,"i16",0,"i16",0,"*",0,0,0], ALLOC_STATIC);
STRING_TABLE.__str29=allocate([105,110,118,97,108,105,100,32,100,105,115,116,97,110,99,101,32,116,111,111,32,102,97,114,32,98,97,99,107,0] /* invalid distance too */, "i8", ALLOC_STATIC);
STRING_TABLE.__str130=allocate([105,110,118,97,108,105,100,32,100,105,115,116,97,110,99,101,32,99,111,100,101,0] /* invalid distance cod */, "i8", ALLOC_STATIC);
STRING_TABLE.__str231=allocate([105,110,118,97,108,105,100,32,108,105,116,101,114,97,108,47,108,101,110,103,116,104,32,99,111,100,101,0] /* invalid literal/leng */, "i8", ALLOC_STATIC);
STRING_TABLE.__str34=allocate([49,46,50,46,55,0] /* 1.2.7\00 */, "i8", ALLOC_STATIC);
_inflate_order=allocate([16, 0, 17, 0, 18, 0, 0, 0, 8, 0, 7, 0, 9, 0, 6, 0, 10, 0, 5, 0, 11, 0, 4, 0, 12, 0, 3, 0, 13, 0, 2, 0, 14, 0, 1, 0, 15, 0], ["i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0], ALLOC_STATIC);
STRING_TABLE.__str135=allocate([105,110,99,111,114,114,101,99,116,32,104,101,97,100,101,114,32,99,104,101,99,107,0] /* incorrect header che */, "i8", ALLOC_STATIC);
STRING_TABLE.__str236=allocate([117,110,107,110,111,119,110,32,99,111,109,112,114,101,115,115,105,111,110,32,109,101,116,104,111,100,0] /* unknown compression  */, "i8", ALLOC_STATIC);
STRING_TABLE.__str337=allocate([105,110,118,97,108,105,100,32,119,105,110,100,111,119,32,115,105,122,101,0] /* invalid window size\ */, "i8", ALLOC_STATIC);
STRING_TABLE.__str438=allocate([117,110,107,110,111,119,110,32,104,101,97,100,101,114,32,102,108,97,103,115,32,115,101,116,0] /* unknown header flags */, "i8", ALLOC_STATIC);
STRING_TABLE.__str539=allocate([104,101,97,100,101,114,32,99,114,99,32,109,105,115,109,97,116,99,104,0] /* header crc mismatch\ */, "i8", ALLOC_STATIC);
STRING_TABLE.__str640=allocate([105,110,118,97,108,105,100,32,98,108,111,99,107,32,116,121,112,101,0] /* invalid block type\0 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str741=allocate([105,110,118,97,108,105,100,32,115,116,111,114,101,100,32,98,108,111,99,107,32,108,101,110,103,116,104,115,0] /* invalid stored block */, "i8", ALLOC_STATIC);
STRING_TABLE.__str842=allocate([116,111,111,32,109,97,110,121,32,108,101,110,103,116,104,32,111,114,32,100,105,115,116,97,110,99,101,32,115,121,109,98,111,108,115,0] /* too many length or d */, "i8", ALLOC_STATIC);
STRING_TABLE.__str943=allocate([105,110,118,97,108,105,100,32,99,111,100,101,32,108,101,110,103,116,104,115,32,115,101,116,0] /* invalid code lengths */, "i8", ALLOC_STATIC);
STRING_TABLE.__str1044=allocate([105,110,118,97,108,105,100,32,98,105,116,32,108,101,110,103,116,104,32,114,101,112,101,97,116,0] /* invalid bit length r */, "i8", ALLOC_STATIC);
STRING_TABLE.__str1145=allocate([105,110,118,97,108,105,100,32,99,111,100,101,32,45,45,32,109,105,115,115,105,110,103,32,101,110,100,45,111,102,45,98,108,111,99,107,0] /* invalid code -- miss */, "i8", ALLOC_STATIC);
STRING_TABLE.__str12=allocate([105,110,118,97,108,105,100,32,108,105,116,101,114,97,108,47,108,101,110,103,116,104,115,32,115,101,116,0] /* invalid literal/leng */, "i8", ALLOC_STATIC);
STRING_TABLE.__str13=allocate([105,110,118,97,108,105,100,32,100,105,115,116,97,110,99,101,115,32,115,101,116,0] /* invalid distances se */, "i8", ALLOC_STATIC);
STRING_TABLE.__str1446=allocate([105,110,118,97,108,105,100,32,108,105,116,101,114,97,108,47,108,101,110,103,116,104,32,99,111,100,101,0] /* invalid literal/leng */, "i8", ALLOC_STATIC);
STRING_TABLE.__str15=allocate([105,110,118,97,108,105,100,32,100,105,115,116,97,110,99,101,32,99,111,100,101,0] /* invalid distance cod */, "i8", ALLOC_STATIC);
STRING_TABLE.__str16=allocate([105,110,118,97,108,105,100,32,100,105,115,116,97,110,99,101,32,116,111,111,32,102,97,114,32,98,97,99,107,0] /* invalid distance too */, "i8", ALLOC_STATIC);
STRING_TABLE.__str17=allocate([105,110,99,111,114,114,101,99,116,32,100,97,116,97,32,99,104,101,99,107,0] /* incorrect data check */, "i8", ALLOC_STATIC);
STRING_TABLE.__str18=allocate([105,110,99,111,114,114,101,99,116,32,108,101,110,103,116,104,32,99,104,101,99,107,0] /* incorrect length che */, "i8", ALLOC_STATIC);
_fixedtables_lenfix47=allocate([96, 7, 0, 0, 0, 8, 80, 0, 0, 8, 16, 0, 20, 8, 115, 0, 18, 7, 31, 0, 0, 8, 112, 0, 0, 8, 48, 0, 0, 9, 192, 0, 16, 7, 10, 0, 0, 8, 96, 0, 0, 8, 32, 0, 0, 9, 160, 0, 0, 8, 0, 0, 0, 8, 128, 0, 0, 8, 64, 0, 0, 9, 224, 0, 16, 7, 6, 0, 0, 8, 88, 0, 0, 8, 24, 0, 0, 9, 144, 0, 19, 7, 59, 0, 0, 8, 120, 0, 0, 8, 56, 0, 0, 9, 208, 0, 17, 7, 17, 0, 0, 8, 104, 0, 0, 8, 40, 0, 0, 9, 176, 0, 0, 8, 8, 0, 0, 8, 136, 0, 0, 8, 72, 0, 0, 9, 240, 0, 16, 7, 4, 0, 0, 8, 84, 0, 0, 8, 20, 0, 21, 8, 227, 0, 19, 7, 43, 0, 0, 8, 116, 0, 0, 8, 52, 0, 0, 9, 200, 0, 17, 7, 13, 0, 0, 8, 100, 0, 0, 8, 36, 0, 0, 9, 168, 0, 0, 8, 4, 0, 0, 8, 132, 0, 0, 8, 68, 0, 0, 9, 232, 0, 16, 7, 8, 0, 0, 8, 92, 0, 0, 8, 28, 0, 0, 9, 152, 0, 20, 7, 83, 0, 0, 8, 124, 0, 0, 8, 60, 0, 0, 9, 216, 0, 18, 7, 23, 0, 0, 8, 108, 0, 0, 8, 44, 0, 0, 9, 184, 0, 0, 8, 12, 0, 0, 8, 140, 0, 0, 8, 76, 0, 0, 9, 248, 0, 16, 7, 3, 0, 0, 8, 82, 0, 0, 8, 18, 0, 21, 8, 163, 0, 19, 7, 35, 0, 0, 8, 114, 0, 0, 8, 50, 0, 0, 9, 196, 0, 17, 7, 11, 0, 0, 8, 98, 0, 0, 8, 34, 0, 0, 9, 164, 0, 0, 8, 2, 0, 0, 8, 130, 0, 0, 8, 66, 0, 0, 9, 228, 0, 16, 7, 7, 0, 0, 8, 90, 0, 0, 8, 26, 0, 0, 9, 148, 0, 20, 7, 67, 0, 0, 8, 122, 0, 0, 8, 58, 0, 0, 9, 212, 0, 18, 7, 19, 0, 0, 8, 106, 0, 0, 8, 42, 0, 0, 9, 180, 0, 0, 8, 10, 0, 0, 8, 138, 0, 0, 8, 74, 0, 0, 9, 244, 0, 16, 7, 5, 0, 0, 8, 86, 0, 0, 8, 22, 0, 64, 8, 0, 0, 19, 7, 51, 0, 0, 8, 118, 0, 0, 8, 54, 0, 0, 9, 204, 0, 17, 7, 15, 0, 0, 8, 102, 0, 0, 8, 38, 0, 0, 9, 172, 0, 0, 8, 6, 0, 0, 8, 134, 0, 0, 8, 70, 0, 0, 9, 236, 0, 16, 7, 9, 0, 0, 8, 94, 0, 0, 8, 30, 0, 0, 9, 156, 0, 20, 7, 99, 0, 0, 8, 126, 0, 0, 8, 62, 0, 0, 9, 220, 0, 18, 7, 27, 0, 0, 8, 110, 0, 0, 8, 46, 0, 0, 9, 188, 0, 0, 8, 14, 0, 0, 8, 142, 0, 0, 8, 78, 0, 0, 9, 252, 0, 96, 7, 0, 0, 0, 8, 81, 0, 0, 8, 17, 0, 21, 8, 131, 0, 18, 7, 31, 0, 0, 8, 113, 0, 0, 8, 49, 0, 0, 9, 194, 0, 16, 7, 10, 0, 0, 8, 97, 0, 0, 8, 33, 0, 0, 9, 162, 0, 0, 8, 1, 0, 0, 8, 129, 0, 0, 8, 65, 0, 0, 9, 226, 0, 16, 7, 6, 0, 0, 8, 89, 0, 0, 8, 25, 0, 0, 9, 146, 0, 19, 7, 59, 0, 0, 8, 121, 0, 0, 8, 57, 0, 0, 9, 210, 0, 17, 7, 17, 0, 0, 8, 105, 0, 0, 8, 41, 0, 0, 9, 178, 0, 0, 8, 9, 0, 0, 8, 137, 0, 0, 8, 73, 0, 0, 9, 242, 0, 16, 7, 4, 0, 0, 8, 85, 0, 0, 8, 21, 0, 16, 8, 258, 0, 19, 7, 43, 0, 0, 8, 117, 0, 0, 8, 53, 0, 0, 9, 202, 0, 17, 7, 13, 0, 0, 8, 101, 0, 0, 8, 37, 0, 0, 9, 170, 0, 0, 8, 5, 0, 0, 8, 133, 0, 0, 8, 69, 0, 0, 9, 234, 0, 16, 7, 8, 0, 0, 8, 93, 0, 0, 8, 29, 0, 0, 9, 154, 0, 20, 7, 83, 0, 0, 8, 125, 0, 0, 8, 61, 0, 0, 9, 218, 0, 18, 7, 23, 0, 0, 8, 109, 0, 0, 8, 45, 0, 0, 9, 186, 0, 0, 8, 13, 0, 0, 8, 141, 0, 0, 8, 77, 0, 0, 9, 250, 0, 16, 7, 3, 0, 0, 8, 83, 0, 0, 8, 19, 0, 21, 8, 195, 0, 19, 7, 35, 0, 0, 8, 115, 0, 0, 8, 51, 0, 0, 9, 198, 0, 17, 7, 11, 0, 0, 8, 99, 0, 0, 8, 35, 0, 0, 9, 166, 0, 0, 8, 3, 0, 0, 8, 131, 0, 0, 8, 67, 0, 0, 9, 230, 0, 16, 7, 7, 0, 0, 8, 91, 0, 0, 8, 27, 0, 0, 9, 150, 0, 20, 7, 67, 0, 0, 8, 123, 0, 0, 8, 59, 0, 0, 9, 214, 0, 18, 7, 19, 0, 0, 8, 107, 0, 0, 8, 43, 0, 0, 9, 182, 0, 0, 8, 11, 0, 0, 8, 139, 0, 0, 8, 75, 0, 0, 9, 246, 0, 16, 7, 5, 0, 0, 8, 87, 0, 0, 8, 23, 0, 64, 8, 0, 0, 19, 7, 51, 0, 0, 8, 119, 0, 0, 8, 55, 0, 0, 9, 206, 0, 17, 7, 15, 0, 0, 8, 103, 0, 0, 8, 39, 0, 0, 9, 174, 0, 0, 8, 7, 0, 0, 8, 135, 0, 0, 8, 71, 0, 0, 9, 238, 0, 16, 7, 9, 0, 0, 8, 95, 0, 0, 8, 31, 0, 0, 9, 158, 0, 20, 7, 99, 0, 0, 8, 127, 0, 0, 8, 63, 0, 0, 9, 222, 0, 18, 7, 27, 0, 0, 8, 111, 0, 0, 8, 47, 0, 0, 9, 190, 0, 0, 8, 15, 0, 0, 8, 143, 0, 0, 8, 79, 0, 0, 9, 254, 0, 96, 7, 0, 0, 0, 8, 80, 0, 0, 8, 16, 0, 20, 8, 115, 0, 18, 7, 31, 0, 0, 8, 112, 0, 0, 8, 48, 0, 0, 9, 193, 0, 16, 7, 10, 0, 0, 8, 96, 0, 0, 8, 32, 0, 0, 9, 161, 0, 0, 8, 0, 0, 0, 8, 128, 0, 0, 8, 64, 0, 0, 9, 225, 0, 16, 7, 6, 0, 0, 8, 88, 0, 0, 8, 24, 0, 0, 9, 145, 0, 19, 7, 59, 0, 0, 8, 120, 0, 0, 8, 56, 0, 0, 9, 209, 0, 17, 7, 17, 0, 0, 8, 104, 0, 0, 8, 40, 0, 0, 9, 177, 0, 0, 8, 8, 0, 0, 8, 136, 0, 0, 8, 72, 0, 0, 9, 241, 0, 16, 7, 4, 0, 0, 8, 84, 0, 0, 8, 20, 0, 21, 8, 227, 0, 19, 7, 43, 0, 0, 8, 116, 0, 0, 8, 52, 0, 0, 9, 201, 0, 17, 7, 13, 0, 0, 8, 100, 0, 0, 8, 36, 0, 0, 9, 169, 0, 0, 8, 4, 0, 0, 8, 132, 0, 0, 8, 68, 0, 0, 9, 233, 0, 16, 7, 8, 0, 0, 8, 92, 0, 0, 8, 28, 0, 0, 9, 153, 0, 20, 7, 83, 0, 0, 8, 124, 0, 0, 8, 60, 0, 0, 9, 217, 0, 18, 7, 23, 0, 0, 8, 108, 0, 0, 8, 44, 0, 0, 9, 185, 0, 0, 8, 12, 0, 0, 8, 140, 0, 0, 8, 76, 0, 0, 9, 249, 0, 16, 7, 3, 0, 0, 8, 82, 0, 0, 8, 18, 0, 21, 8, 163, 0, 19, 7, 35, 0, 0, 8, 114, 0, 0, 8, 50, 0, 0, 9, 197, 0, 17, 7, 11, 0, 0, 8, 98, 0, 0, 8, 34, 0, 0, 9, 165, 0, 0, 8, 2, 0, 0, 8, 130, 0, 0, 8, 66, 0, 0, 9, 229, 0, 16, 7, 7, 0, 0, 8, 90, 0, 0, 8, 26, 0, 0, 9, 149, 0, 20, 7, 67, 0, 0, 8, 122, 0, 0, 8, 58, 0, 0, 9, 213, 0, 18, 7, 19, 0, 0, 8, 106, 0, 0, 8, 42, 0, 0, 9, 181, 0, 0, 8, 10, 0, 0, 8, 138, 0, 0, 8, 74, 0, 0, 9, 245, 0, 16, 7, 5, 0, 0, 8, 86, 0, 0, 8, 22, 0, 64, 8, 0, 0, 19, 7, 51, 0, 0, 8, 118, 0, 0, 8, 54, 0, 0, 9, 205, 0, 17, 7, 15, 0, 0, 8, 102, 0, 0, 8, 38, 0, 0, 9, 173, 0, 0, 8, 6, 0, 0, 8, 134, 0, 0, 8, 70, 0, 0, 9, 237, 0, 16, 7, 9, 0, 0, 8, 94, 0, 0, 8, 30, 0, 0, 9, 157, 0, 20, 7, 99, 0, 0, 8, 126, 0, 0, 8, 62, 0, 0, 9, 221, 0, 18, 7, 27, 0, 0, 8, 110, 0, 0, 8, 46, 0, 0, 9, 189, 0, 0, 8, 14, 0, 0, 8, 142, 0, 0, 8, 78, 0, 0, 9, 253, 0, 96, 7, 0, 0, 0, 8, 81, 0, 0, 8, 17, 0, 21, 8, 131, 0, 18, 7, 31, 0, 0, 8, 113, 0, 0, 8, 49, 0, 0, 9, 195, 0, 16, 7, 10, 0, 0, 8, 97, 0, 0, 8, 33, 0, 0, 9, 163, 0, 0, 8, 1, 0, 0, 8, 129, 0, 0, 8, 65, 0, 0, 9, 227, 0, 16, 7, 6, 0, 0, 8, 89, 0, 0, 8, 25, 0, 0, 9, 147, 0, 19, 7, 59, 0, 0, 8, 121, 0, 0, 8, 57, 0, 0, 9, 211, 0, 17, 7, 17, 0, 0, 8, 105, 0, 0, 8, 41, 0, 0, 9, 179, 0, 0, 8, 9, 0, 0, 8, 137, 0, 0, 8, 73, 0, 0, 9, 243, 0, 16, 7, 4, 0, 0, 8, 85, 0, 0, 8, 21, 0, 16, 8, 258, 0, 19, 7, 43, 0, 0, 8, 117, 0, 0, 8, 53, 0, 0, 9, 203, 0, 17, 7, 13, 0, 0, 8, 101, 0, 0, 8, 37, 0, 0, 9, 171, 0, 0, 8, 5, 0, 0, 8, 133, 0, 0, 8, 69, 0, 0, 9, 235, 0, 16, 7, 8, 0, 0, 8, 93, 0, 0, 8, 29, 0, 0, 9, 155, 0, 20, 7, 83, 0, 0, 8, 125, 0, 0, 8, 61, 0, 0, 9, 219, 0, 18, 7, 23, 0, 0, 8, 109, 0, 0, 8, 45, 0, 0, 9, 187, 0, 0, 8, 13, 0, 0, 8, 141, 0, 0, 8, 77, 0, 0, 9, 251, 0, 16, 7, 3, 0, 0, 8, 83, 0, 0, 8, 19, 0, 21, 8, 195, 0, 19, 7, 35, 0, 0, 8, 115, 0, 0, 8, 51, 0, 0, 9, 199, 0, 17, 7, 11, 0, 0, 8, 99, 0, 0, 8, 35, 0, 0, 9, 167, 0, 0, 8, 3, 0, 0, 8, 131, 0, 0, 8, 67, 0, 0, 9, 231, 0, 16, 7, 7, 0, 0, 8, 91, 0, 0, 8, 27, 0, 0, 9, 151, 0, 20, 7, 67, 0, 0, 8, 123, 0, 0, 8, 59, 0, 0, 9, 215, 0, 18, 7, 19, 0, 0, 8, 107, 0, 0, 8, 43, 0, 0, 9, 183, 0, 0, 8, 11, 0, 0, 8, 139, 0, 0, 8, 75, 0, 0, 9, 247, 0, 16, 7, 5, 0, 0, 8, 87, 0, 0, 8, 23, 0, 64, 8, 0, 0, 19, 7, 51, 0, 0, 8, 119, 0, 0, 8, 55, 0, 0, 9, 207, 0, 17, 7, 15, 0, 0, 8, 103, 0, 0, 8, 39, 0, 0, 9, 175, 0, 0, 8, 7, 0, 0, 8, 135, 0, 0, 8, 71, 0, 0, 9, 239, 0, 16, 7, 9, 0, 0, 8, 95, 0, 0, 8, 31, 0, 0, 9, 159, 0, 20, 7, 99, 0, 0, 8, 127, 0, 0, 8, 63, 0, 0, 9, 223, 0, 18, 7, 27, 0, 0, 8, 111, 0, 0, 8, 47, 0, 0, 9, 191, 0, 0, 8, 15, 0, 0, 8, 143, 0, 0, 8, 79, 0, 0, 9, 255, 0], ["i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0], ALLOC_STATIC);
_fixedtables_distfix48=allocate([16, 5, 1, 0, 23, 5, 257, 0, 19, 5, 17, 0, 27, 5, 4097, 0, 17, 5, 5, 0, 25, 5, 1025, 0, 21, 5, 65, 0, 29, 5, 16385, 0, 16, 5, 3, 0, 24, 5, 513, 0, 20, 5, 33, 0, 28, 5, 8193, 0, 18, 5, 9, 0, 26, 5, 2049, 0, 22, 5, 129, 0, 64, 5, 0, 0, 16, 5, 2, 0, 23, 5, 385, 0, 19, 5, 25, 0, 27, 5, 6145, 0, 17, 5, 7, 0, 25, 5, 1537, 0, 21, 5, 97, 0, 29, 5, 24577, 0, 16, 5, 4, 0, 24, 5, 769, 0, 20, 5, 49, 0, 28, 5, 12289, 0, 18, 5, 13, 0, 26, 5, 3073, 0, 22, 5, 193, 0, 64, 5, 0, 0], ["i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0,"i8","i8","i16",0], ALLOC_STATIC);
_inflate_table_lbase=allocate([3, 0, 4, 0, 5, 0, 6, 0, 7, 0, 8, 0, 9, 0, 10, 0, 11, 0, 13, 0, 15, 0, 17, 0, 19, 0, 23, 0, 27, 0, 31, 0, 35, 0, 43, 0, 51, 0, 59, 0, 67, 0, 83, 0, 99, 0, 115, 0, 131, 0, 163, 0, 195, 0, 227, 0, 258, 0, 0, 0, 0, 0], ["i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0], ALLOC_STATIC);
_inflate_table_lext=allocate([16, 0, 16, 0, 16, 0, 16, 0, 16, 0, 16, 0, 16, 0, 16, 0, 17, 0, 17, 0, 17, 0, 17, 0, 18, 0, 18, 0, 18, 0, 18, 0, 19, 0, 19, 0, 19, 0, 19, 0, 20, 0, 20, 0, 20, 0, 20, 0, 21, 0, 21, 0, 21, 0, 21, 0, 16, 0, 78, 0, 68, 0], ["i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0], ALLOC_STATIC);
_inflate_table_dbase=allocate([1, 0, 2, 0, 3, 0, 4, 0, 5, 0, 7, 0, 9, 0, 13, 0, 17, 0, 25, 0, 33, 0, 49, 0, 65, 0, 97, 0, 129, 0, 193, 0, 257, 0, 385, 0, 513, 0, 769, 0, 1025, 0, 1537, 0, 2049, 0, 3073, 0, 4097, 0, 6145, 0, 8193, 0, 12289, 0, 16385, 0, 24577, 0, 0, 0, 0, 0], ["i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0], ALLOC_STATIC);
_inflate_table_dext=allocate([16, 0, 16, 0, 16, 0, 16, 0, 17, 0, 17, 0, 18, 0, 18, 0, 19, 0, 19, 0, 20, 0, 20, 0, 21, 0, 21, 0, 22, 0, 22, 0, 23, 0, 23, 0, 24, 0, 24, 0, 25, 0, 25, 0, 26, 0, 26, 0, 27, 0, 27, 0, 28, 0, 28, 0, 29, 0, 29, 0, 64, 0, 64, 0], ["i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0], ALLOC_STATIC);
STRING_TABLE.__dist_code=allocate([0,1,2,3,4,4,5,5,6,6,6,6,7,7,7,7,8,8,8,8,8,8,8,8,9,9,9,9,9,9,9,9,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,0,0,16,17,18,18,19,19,20,20,20,20,21,21,21,21,22,22,22,22,22,22,22,22,23,23,23,23,23,23,23,23,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,25,25,25,25,25,25,25,25,25,25,25,25,25,25,25,25,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29] /* \00\01\02\03\04\04\0 */, "i8", ALLOC_STATIC);
STRING_TABLE.__length_code=allocate([0,1,2,3,4,5,6,7,8,8,9,9,10,10,11,11,12,12,12,12,13,13,13,13,14,14,14,14,15,15,15,15,16,16,16,16,16,16,16,16,17,17,17,17,17,17,17,17,18,18,18,18,18,18,18,18,19,19,19,19,19,19,19,19,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,21,21,21,21,21,21,21,21,21,21,21,21,21,21,21,21,22,22,22,22,22,22,22,22,22,22,22,22,22,22,22,22,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,25,25,25,25,25,25,25,25,25,25,25,25,25,25,25,25,25,25,25,25,25,25,25,25,25,25,25,25,25,25,25,25,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,28] /* \00\01\02\03\04\05\0 */, "i8", ALLOC_STATIC);
_static_l_desc=allocate([0, 0, 0, 0, 0, 0, 0, 0, 257, 0, 0, 0, 286, 0, 0, 0, 15, 0, 0, 0], ["*",0,0,0,"*",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0], ALLOC_STATIC);
_static_d_desc=allocate([0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 30, 0, 0, 0, 15, 0, 0, 0], ["*",0,0,0,"*",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0], ALLOC_STATIC);
_static_bl_desc=allocate([0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 19, 0, 0, 0, 7, 0, 0, 0], ["*",0,0,0,"*",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0], ALLOC_STATIC);
_static_ltree=allocate([12, 0, 8, 0, 140, 0, 8, 0, 76, 0, 8, 0, 204, 0, 8, 0, 44, 0, 8, 0, 172, 0, 8, 0, 108, 0, 8, 0, 236, 0, 8, 0, 28, 0, 8, 0, 156, 0, 8, 0, 92, 0, 8, 0, 220, 0, 8, 0, 60, 0, 8, 0, 188, 0, 8, 0, 124, 0, 8, 0, 252, 0, 8, 0, 2, 0, 8, 0, 130, 0, 8, 0, 66, 0, 8, 0, 194, 0, 8, 0, 34, 0, 8, 0, 162, 0, 8, 0, 98, 0, 8, 0, 226, 0, 8, 0, 18, 0, 8, 0, 146, 0, 8, 0, 82, 0, 8, 0, 210, 0, 8, 0, 50, 0, 8, 0, 178, 0, 8, 0, 114, 0, 8, 0, 242, 0, 8, 0, 10, 0, 8, 0, 138, 0, 8, 0, 74, 0, 8, 0, 202, 0, 8, 0, 42, 0, 8, 0, 170, 0, 8, 0, 106, 0, 8, 0, 234, 0, 8, 0, 26, 0, 8, 0, 154, 0, 8, 0, 90, 0, 8, 0, 218, 0, 8, 0, 58, 0, 8, 0, 186, 0, 8, 0, 122, 0, 8, 0, 250, 0, 8, 0, 6, 0, 8, 0, 134, 0, 8, 0, 70, 0, 8, 0, 198, 0, 8, 0, 38, 0, 8, 0, 166, 0, 8, 0, 102, 0, 8, 0, 230, 0, 8, 0, 22, 0, 8, 0, 150, 0, 8, 0, 86, 0, 8, 0, 214, 0, 8, 0, 54, 0, 8, 0, 182, 0, 8, 0, 118, 0, 8, 0, 246, 0, 8, 0, 14, 0, 8, 0, 142, 0, 8, 0, 78, 0, 8, 0, 206, 0, 8, 0, 46, 0, 8, 0, 174, 0, 8, 0, 110, 0, 8, 0, 238, 0, 8, 0, 30, 0, 8, 0, 158, 0, 8, 0, 94, 0, 8, 0, 222, 0, 8, 0, 62, 0, 8, 0, 190, 0, 8, 0, 126, 0, 8, 0, 254, 0, 8, 0, 1, 0, 8, 0, 129, 0, 8, 0, 65, 0, 8, 0, 193, 0, 8, 0, 33, 0, 8, 0, 161, 0, 8, 0, 97, 0, 8, 0, 225, 0, 8, 0, 17, 0, 8, 0, 145, 0, 8, 0, 81, 0, 8, 0, 209, 0, 8, 0, 49, 0, 8, 0, 177, 0, 8, 0, 113, 0, 8, 0, 241, 0, 8, 0, 9, 0, 8, 0, 137, 0, 8, 0, 73, 0, 8, 0, 201, 0, 8, 0, 41, 0, 8, 0, 169, 0, 8, 0, 105, 0, 8, 0, 233, 0, 8, 0, 25, 0, 8, 0, 153, 0, 8, 0, 89, 0, 8, 0, 217, 0, 8, 0, 57, 0, 8, 0, 185, 0, 8, 0, 121, 0, 8, 0, 249, 0, 8, 0, 5, 0, 8, 0, 133, 0, 8, 0, 69, 0, 8, 0, 197, 0, 8, 0, 37, 0, 8, 0, 165, 0, 8, 0, 101, 0, 8, 0, 229, 0, 8, 0, 21, 0, 8, 0, 149, 0, 8, 0, 85, 0, 8, 0, 213, 0, 8, 0, 53, 0, 8, 0, 181, 0, 8, 0, 117, 0, 8, 0, 245, 0, 8, 0, 13, 0, 8, 0, 141, 0, 8, 0, 77, 0, 8, 0, 205, 0, 8, 0, 45, 0, 8, 0, 173, 0, 8, 0, 109, 0, 8, 0, 237, 0, 8, 0, 29, 0, 8, 0, 157, 0, 8, 0, 93, 0, 8, 0, 221, 0, 8, 0, 61, 0, 8, 0, 189, 0, 8, 0, 125, 0, 8, 0, 253, 0, 8, 0, 19, 0, 9, 0, 275, 0, 9, 0, 147, 0, 9, 0, 403, 0, 9, 0, 83, 0, 9, 0, 339, 0, 9, 0, 211, 0, 9, 0, 467, 0, 9, 0, 51, 0, 9, 0, 307, 0, 9, 0, 179, 0, 9, 0, 435, 0, 9, 0, 115, 0, 9, 0, 371, 0, 9, 0, 243, 0, 9, 0, 499, 0, 9, 0, 11, 0, 9, 0, 267, 0, 9, 0, 139, 0, 9, 0, 395, 0, 9, 0, 75, 0, 9, 0, 331, 0, 9, 0, 203, 0, 9, 0, 459, 0, 9, 0, 43, 0, 9, 0, 299, 0, 9, 0, 171, 0, 9, 0, 427, 0, 9, 0, 107, 0, 9, 0, 363, 0, 9, 0, 235, 0, 9, 0, 491, 0, 9, 0, 27, 0, 9, 0, 283, 0, 9, 0, 155, 0, 9, 0, 411, 0, 9, 0, 91, 0, 9, 0, 347, 0, 9, 0, 219, 0, 9, 0, 475, 0, 9, 0, 59, 0, 9, 0, 315, 0, 9, 0, 187, 0, 9, 0, 443, 0, 9, 0, 123, 0, 9, 0, 379, 0, 9, 0, 251, 0, 9, 0, 507, 0, 9, 0, 7, 0, 9, 0, 263, 0, 9, 0, 135, 0, 9, 0, 391, 0, 9, 0, 71, 0, 9, 0, 327, 0, 9, 0, 199, 0, 9, 0, 455, 0, 9, 0, 39, 0, 9, 0, 295, 0, 9, 0, 167, 0, 9, 0, 423, 0, 9, 0, 103, 0, 9, 0, 359, 0, 9, 0, 231, 0, 9, 0, 487, 0, 9, 0, 23, 0, 9, 0, 279, 0, 9, 0, 151, 0, 9, 0, 407, 0, 9, 0, 87, 0, 9, 0, 343, 0, 9, 0, 215, 0, 9, 0, 471, 0, 9, 0, 55, 0, 9, 0, 311, 0, 9, 0, 183, 0, 9, 0, 439, 0, 9, 0, 119, 0, 9, 0, 375, 0, 9, 0, 247, 0, 9, 0, 503, 0, 9, 0, 15, 0, 9, 0, 271, 0, 9, 0, 143, 0, 9, 0, 399, 0, 9, 0, 79, 0, 9, 0, 335, 0, 9, 0, 207, 0, 9, 0, 463, 0, 9, 0, 47, 0, 9, 0, 303, 0, 9, 0, 175, 0, 9, 0, 431, 0, 9, 0, 111, 0, 9, 0, 367, 0, 9, 0, 239, 0, 9, 0, 495, 0, 9, 0, 31, 0, 9, 0, 287, 0, 9, 0, 159, 0, 9, 0, 415, 0, 9, 0, 95, 0, 9, 0, 351, 0, 9, 0, 223, 0, 9, 0, 479, 0, 9, 0, 63, 0, 9, 0, 319, 0, 9, 0, 191, 0, 9, 0, 447, 0, 9, 0, 127, 0, 9, 0, 383, 0, 9, 0, 255, 0, 9, 0, 511, 0, 9, 0, 0, 0, 7, 0, 64, 0, 7, 0, 32, 0, 7, 0, 96, 0, 7, 0, 16, 0, 7, 0, 80, 0, 7, 0, 48, 0, 7, 0, 112, 0, 7, 0, 8, 0, 7, 0, 72, 0, 7, 0, 40, 0, 7, 0, 104, 0, 7, 0, 24, 0, 7, 0, 88, 0, 7, 0, 56, 0, 7, 0, 120, 0, 7, 0, 4, 0, 7, 0, 68, 0, 7, 0, 36, 0, 7, 0, 100, 0, 7, 0, 20, 0, 7, 0, 84, 0, 7, 0, 52, 0, 7, 0, 116, 0, 7, 0, 3, 0, 8, 0, 131, 0, 8, 0, 67, 0, 8, 0, 195, 0, 8, 0, 35, 0, 8, 0, 163, 0, 8, 0, 99, 0, 8, 0, 227, 0, 8, 0], ["i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0], ALLOC_STATIC);
_static_dtree=allocate([0, 0, 5, 0, 16, 0, 5, 0, 8, 0, 5, 0, 24, 0, 5, 0, 4, 0, 5, 0, 20, 0, 5, 0, 12, 0, 5, 0, 28, 0, 5, 0, 2, 0, 5, 0, 18, 0, 5, 0, 10, 0, 5, 0, 26, 0, 5, 0, 6, 0, 5, 0, 22, 0, 5, 0, 14, 0, 5, 0, 30, 0, 5, 0, 1, 0, 5, 0, 17, 0, 5, 0, 9, 0, 5, 0, 25, 0, 5, 0, 5, 0, 5, 0, 21, 0, 5, 0, 13, 0, 5, 0, 29, 0, 5, 0, 3, 0, 5, 0, 19, 0, 5, 0, 11, 0, 5, 0, 27, 0, 5, 0, 7, 0, 5, 0, 23, 0, 5, 0], ["i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0], ALLOC_STATIC);
_extra_lbits=allocate([0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 1, 0, 0, 0, 1, 0, 0, 0, 1, 0, 0, 0, 2, 0, 0, 0, 2, 0, 0, 0, 2, 0, 0, 0, 2, 0, 0, 0, 3, 0, 0, 0, 3, 0, 0, 0, 3, 0, 0, 0, 3, 0, 0, 0, 4, 0, 0, 0, 4, 0, 0, 0, 4, 0, 0, 0, 4, 0, 0, 0, 5, 0, 0, 0, 5, 0, 0, 0, 5, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0], ["i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0], ALLOC_STATIC);
_base_length=allocate([0, 0, 0, 0, 1, 0, 0, 0, 2, 0, 0, 0, 3, 0, 0, 0, 4, 0, 0, 0, 5, 0, 0, 0, 6, 0, 0, 0, 7, 0, 0, 0, 8, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 14, 0, 0, 0, 16, 0, 0, 0, 20, 0, 0, 0, 24, 0, 0, 0, 28, 0, 0, 0, 32, 0, 0, 0, 40, 0, 0, 0, 48, 0, 0, 0, 56, 0, 0, 0, 64, 0, 0, 0, 80, 0, 0, 0, 96, 0, 0, 0, 112, 0, 0, 0, 128, 0, 0, 0, 160, 0, 0, 0, 192, 0, 0, 0, 224, 0, 0, 0, 0, 0, 0, 0], ["i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0], ALLOC_STATIC);
_extra_dbits=allocate([0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 1, 0, 0, 0, 2, 0, 0, 0, 2, 0, 0, 0, 3, 0, 0, 0, 3, 0, 0, 0, 4, 0, 0, 0, 4, 0, 0, 0, 5, 0, 0, 0, 5, 0, 0, 0, 6, 0, 0, 0, 6, 0, 0, 0, 7, 0, 0, 0, 7, 0, 0, 0, 8, 0, 0, 0, 8, 0, 0, 0, 9, 0, 0, 0, 9, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 11, 0, 0, 0, 11, 0, 0, 0, 12, 0, 0, 0, 12, 0, 0, 0, 13, 0, 0, 0, 13, 0, 0, 0], ["i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0], ALLOC_STATIC);
_base_dist=allocate([0, 0, 0, 0, 1, 0, 0, 0, 2, 0, 0, 0, 3, 0, 0, 0, 4, 0, 0, 0, 6, 0, 0, 0, 8, 0, 0, 0, 12, 0, 0, 0, 16, 0, 0, 0, 24, 0, 0, 0, 32, 0, 0, 0, 48, 0, 0, 0, 64, 0, 0, 0, 96, 0, 0, 0, 128, 0, 0, 0, 192, 0, 0, 0, 256, 0, 0, 0, 384, 0, 0, 0, 512, 0, 0, 0, 768, 0, 0, 0, 1024, 0, 0, 0, 1536, 0, 0, 0, 2048, 0, 0, 0, 3072, 0, 0, 0, 4096, 0, 0, 0, 6144, 0, 0, 0, 8192, 0, 0, 0, 12288, 0, 0, 0, 16384, 0, 0, 0, 24576, 0, 0, 0], ["i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0], ALLOC_STATIC);
STRING_TABLE._bl_order=allocate([16,17,18,0,8,7,9,6,10,5,11,4,12,3,13,2,14,1,15] /* \10\11\12\00\08\07\0 */, "i8", ALLOC_STATIC);
_extra_blbits=allocate([0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 3, 0, 0, 0, 7, 0, 0, 0], ["i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0], ALLOC_STATIC);
STRING_TABLE.__str75=allocate([110,101,101,100,32,100,105,99,116,105,111,110,97,114,121,0] /* need dictionary\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str176=allocate([115,116,114,101,97,109,32,101,110,100,0] /* stream end\00 */, "i8", ALLOC_STATIC);
__str277=allocate(1, "i8", ALLOC_STATIC);
STRING_TABLE.__str378=allocate([102,105,108,101,32,101,114,114,111,114,0] /* file error\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str479=allocate([115,116,114,101,97,109,32,101,114,114,111,114,0] /* stream error\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str580=allocate([100,97,116,97,32,101,114,114,111,114,0] /* data error\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str681=allocate([105,110,115,117,102,102,105,99,105,101,110,116,32,109,101,109,111,114,121,0] /* insufficient memory\ */, "i8", ALLOC_STATIC);
STRING_TABLE.__str782=allocate([98,117,102,102,101,114,32,101,114,114,111,114,0] /* buffer error\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str883=allocate([105,110,99,111,109,112,97,116,105,98,108,101,32,118,101,114,115,105,111,110,0] /* incompatible version */, "i8", ALLOC_STATIC);
_z_errmsg=allocate(40, "i8", ALLOC_STATIC);
STRING_TABLE.__str91=allocate([84,111,111,32,109,97,110,121,32,98,121,116,101,115,32,102,111,114,32,80,78,71,32,115,105,103,110,97,116,117,114,101,0] /* Too many bytes for P */, "i8", ALLOC_STATIC);
STRING_TABLE._png_sig_cmp_png_signature=allocate([137,80,78,71,13,10,26,10] /* \89PNG\0D\0A\1A\0A */, "i8", ALLOC_STATIC);
STRING_TABLE.__str192=allocate([80,111,116,101,110,116,105,97,108,32,111,118,101,114,102,108,111,119,32,105,110,32,112,110,103,95,122,97,108,108,111,99,40,41,0] /* Potential overflow i */, "i8", ALLOC_STATIC);
STRING_TABLE.__str596=allocate([49,46,52,46,49,50,0] /* 1.4.12\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str798=allocate([73,103,110,111,114,105,110,103,32,97,116,116,101,109,112,116,32,116,111,32,115,101,116,32,110,101,103,97,116,105,118,101,32,99,104,114,111,109,97,116,105,99,105,116,121,32,118,97,108,117,101,0] /* Ignoring attempt to  */, "i8", ALLOC_STATIC);
STRING_TABLE.__str899=allocate([73,103,110,111,114,105,110,103,32,97,116,116,101,109,112,116,32,116,111,32,115,101,116,32,99,104,114,111,109,97,116,105,99,105,116,121,32,118,97,108,117,101,32,101,120,99,101,101,100,105,110,103,32,50,49,52,55,52,46,56,51,0] /* Ignoring attempt to  */, "i8", ALLOC_STATIC);
STRING_TABLE.__str9100=allocate([73,110,118,97,108,105,100,32,99,72,82,77,32,119,104,105,116,101,32,112,111,105,110,116,0] /* Invalid cHRM white p */, "i8", ALLOC_STATIC);
STRING_TABLE.__str10101=allocate([73,110,118,97,108,105,100,32,99,72,82,77,32,114,101,100,32,112,111,105,110,116,0] /* Invalid cHRM red poi */, "i8", ALLOC_STATIC);
STRING_TABLE.__str11102=allocate([73,110,118,97,108,105,100,32,99,72,82,77,32,103,114,101,101,110,32,112,111,105,110,116,0] /* Invalid cHRM green p */, "i8", ALLOC_STATIC);
STRING_TABLE.__str12103=allocate([73,110,118,97,108,105,100,32,99,72,82,77,32,98,108,117,101,32,112,111,105,110,116,0] /* Invalid cHRM blue po */, "i8", ALLOC_STATIC);
STRING_TABLE.__str13104=allocate([73,103,110,111,114,105,110,103,32,97,116,116,101,109,112,116,32,116,111,32,115,101,116,32,99,72,82,77,32,82,71,66,32,116,114,105,97,110,103,108,101,32,119,105,116,104,32,122,101,114,111,32,97,114,101,97,0] /* Ignoring attempt to  */, "i8", ALLOC_STATIC);
STRING_TABLE.__str14105=allocate([73,109,97,103,101,32,119,105,100,116,104,32,105,115,32,122,101,114,111,32,105,110,32,73,72,68,82,0] /* Image width is zero  */, "i8", ALLOC_STATIC);
STRING_TABLE.__str15106=allocate([73,109,97,103,101,32,104,101,105,103,104,116,32,105,115,32,122,101,114,111,32,105,110,32,73,72,68,82,0] /* Image height is zero */, "i8", ALLOC_STATIC);
STRING_TABLE.__str16107=allocate([73,109,97,103,101,32,119,105,100,116,104,32,101,120,99,101,101,100,115,32,117,115,101,114,32,108,105,109,105,116,32,105,110,32,73,72,68,82,0] /* Image width exceeds  */, "i8", ALLOC_STATIC);
STRING_TABLE.__str17108=allocate([73,109,97,103,101,32,104,101,105,103,104,116,32,101,120,99,101,101,100,115,32,117,115,101,114,32,108,105,109,105,116,32,105,110,32,73,72,68,82,0] /* Image height exceeds */, "i8", ALLOC_STATIC);
STRING_TABLE.__str18109=allocate([73,110,118,97,108,105,100,32,105,109,97,103,101,32,119,105,100,116,104,32,105,110,32,73,72,68,82,0] /* Invalid image width  */, "i8", ALLOC_STATIC);
STRING_TABLE.__str19110=allocate([73,110,118,97,108,105,100,32,105,109,97,103,101,32,104,101,105,103,104,116,32,105,110,32,73,72,68,82,0] /* Invalid image height */, "i8", ALLOC_STATIC);
STRING_TABLE.__str20111=allocate([87,105,100,116,104,32,105,115,32,116,111,111,32,108,97,114,103,101,32,102,111,114,32,108,105,98,112,110,103,32,116,111,32,112,114,111,99,101,115,115,32,112,105,120,101,108,115,0] /* Width is too large f */, "i8", ALLOC_STATIC);
STRING_TABLE.__str21=allocate([73,110,118,97,108,105,100,32,98,105,116,32,100,101,112,116,104,32,105,110,32,73,72,68,82,0] /* Invalid bit depth in */, "i8", ALLOC_STATIC);
STRING_TABLE.__str22=allocate([73,110,118,97,108,105,100,32,99,111,108,111,114,32,116,121,112,101,32,105,110,32,73,72,68,82,0] /* Invalid color type i */, "i8", ALLOC_STATIC);
STRING_TABLE.__str23=allocate([73,110,118,97,108,105,100,32,99,111,108,111,114,32,116,121,112,101,47,98,105,116,32,100,101,112,116,104,32,99,111,109,98,105,110,97,116,105,111,110,32,105,110,32,73,72,68,82,0] /* Invalid color type/b */, "i8", ALLOC_STATIC);
STRING_TABLE.__str24=allocate([85,110,107,110,111,119,110,32,105,110,116,101,114,108,97,99,101,32,109,101,116,104,111,100,32,105,110,32,73,72,68,82,0] /* Unknown interlace me */, "i8", ALLOC_STATIC);
STRING_TABLE.__str25=allocate([85,110,107,110,111,119,110,32,99,111,109,112,114,101,115,115,105,111,110,32,109,101,116,104,111,100,32,105,110,32,73,72,68,82,0] /* Unknown compression  */, "i8", ALLOC_STATIC);
STRING_TABLE.__str26=allocate([77,78,71,32,102,101,97,116,117,114,101,115,32,97,114,101,32,110,111,116,32,97,108,108,111,119,101,100,32,105,110,32,97,32,80,78,71,32,100,97,116,97,115,116,114,101,97,109,0] /* MNG features are not */, "i8", ALLOC_STATIC);
STRING_TABLE.__str27=allocate([85,110,107,110,111,119,110,32,102,105,108,116,101,114,32,109,101,116,104,111,100,32,105,110,32,73,72,68,82,0] /* Unknown filter metho */, "i8", ALLOC_STATIC);
STRING_TABLE.__str28=allocate([73,110,118,97,108,105,100,32,102,105,108,116,101,114,32,109,101,116,104,111,100,32,105,110,32,73,72,68,82,0] /* Invalid filter metho */, "i8", ALLOC_STATIC);
STRING_TABLE.__str29112=allocate([73,110,118,97,108,105,100,32,73,72,68,82,32,100,97,116,97,0] /* Invalid IHDR data\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str113=allocate([108,105,98,112,110,103,32,119,97,114,110,105,110,103,58,32,37,115,0] /* libpng warning: %s\0 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str1114=allocate([10,0] /* \0A\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str2115=allocate([108,105,98,112,110,103,32,101,114,114,111,114,58,32,37,115,0] /* libpng error: %s\00 */, "i8", ALLOC_STATIC);
STRING_TABLE._png_digit=allocate([48,49,50,51,52,53,54,55,56,57,65,66,67,68,69,70] /* 0123456789ABCDEF */, "i8", ALLOC_STATIC);
STRING_TABLE.__str120=allocate([79,117,116,32,111,102,32,77,101,109,111,114,121,0] /* Out of Memory\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str148=allocate([65,112,112,108,105,99,97,116,105,111,110,32,119,97,115,32,99,111,109,112,105,108,101,100,32,119,105,116,104,32,112,110,103,46,104,32,102,114,111,109,32,108,105,98,112,110,103,45,37,46,50,48,115,0] /* Application was comp */, "i8", ALLOC_STATIC);
STRING_TABLE.__str1149=allocate([65,112,112,108,105,99,97,116,105,111,110,32,32,105,115,32,32,114,117,110,110,105,110,103,32,119,105,116,104,32,112,110,103,46,99,32,102,114,111,109,32,108,105,98,112,110,103,45,37,46,50,48,115,0] /* Application  is  run */, "i8", ALLOC_STATIC);
STRING_TABLE.__str2150=allocate([73,110,99,111,109,112,97,116,105,98,108,101,32,108,105,98,112,110,103,32,118,101,114,115,105,111,110,32,105,110,32,97,112,112,108,105,99,97,116,105,111,110,32,97,110,100,32,108,105,98,114,97,114,121,0] /* Incompatible libpng  */, "i8", ALLOC_STATIC);
STRING_TABLE.__str3151=allocate([49,46,50,46,53,0] /* 1.2.5\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str4152=allocate([122,108,105,98,32,109,101,109,111,114,121,32,101,114,114,111,114,0] /* zlib memory error\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str5153=allocate([122,108,105,98,32,118,101,114,115,105,111,110,32,101,114,114,111,114,0] /* zlib version error\0 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str6154=allocate([85,110,107,110,111,119,110,32,122,108,105,98,32,101,114,114,111,114,0] /* Unknown zlib error\0 */, "i8", ALLOC_STATIC);
STRING_TABLE._png_read_info_png_IHDR=allocate([73,72,68,82,0] /* IHDR\00 */, "i8", ALLOC_STATIC);
STRING_TABLE._png_read_info_png_IDAT=allocate([73,68,65,84,0] /* IDAT\00 */, "i8", ALLOC_STATIC);
STRING_TABLE._png_read_info_png_IEND=allocate([73,69,78,68,0] /* IEND\00 */, "i8", ALLOC_STATIC);
STRING_TABLE._png_read_info_png_PLTE=allocate([80,76,84,69,0] /* PLTE\00 */, "i8", ALLOC_STATIC);
STRING_TABLE._png_read_info_png_bKGD=allocate([98,75,71,68,0] /* bKGD\00 */, "i8", ALLOC_STATIC);
STRING_TABLE._png_read_info_png_cHRM=allocate([99,72,82,77,0] /* cHRM\00 */, "i8", ALLOC_STATIC);
STRING_TABLE._png_read_info_png_gAMA=allocate([103,65,77,65,0] /* gAMA\00 */, "i8", ALLOC_STATIC);
STRING_TABLE._png_read_info_png_hIST=allocate([104,73,83,84,0] /* hIST\00 */, "i8", ALLOC_STATIC);
STRING_TABLE._png_read_info_png_iCCP=allocate([105,67,67,80,0] /* iCCP\00 */, "i8", ALLOC_STATIC);
STRING_TABLE._png_read_info_png_iTXt=allocate([105,84,88,116,0] /* iTXt\00 */, "i8", ALLOC_STATIC);
STRING_TABLE._png_read_info_png_oFFs=allocate([111,70,70,115,0] /* oFFs\00 */, "i8", ALLOC_STATIC);
STRING_TABLE._png_read_info_png_pCAL=allocate([112,67,65,76,0] /* pCAL\00 */, "i8", ALLOC_STATIC);
STRING_TABLE._png_read_info_png_pHYs=allocate([112,72,89,115,0] /* pHYs\00 */, "i8", ALLOC_STATIC);
STRING_TABLE._png_read_info_png_sBIT=allocate([115,66,73,84,0] /* sBIT\00 */, "i8", ALLOC_STATIC);
STRING_TABLE._png_read_info_png_sCAL=allocate([115,67,65,76,0] /* sCAL\00 */, "i8", ALLOC_STATIC);
STRING_TABLE._png_read_info_png_sPLT=allocate([115,80,76,84,0] /* sPLT\00 */, "i8", ALLOC_STATIC);
STRING_TABLE._png_read_info_png_sRGB=allocate([115,82,71,66,0] /* sRGB\00 */, "i8", ALLOC_STATIC);
STRING_TABLE._png_read_info_png_tEXt=allocate([116,69,88,116,0] /* tEXt\00 */, "i8", ALLOC_STATIC);
STRING_TABLE._png_read_info_png_tIME=allocate([116,73,77,69,0] /* tIME\00 */, "i8", ALLOC_STATIC);
STRING_TABLE._png_read_info_png_tRNS=allocate([116,82,78,83,0] /* tRNS\00 */, "i8", ALLOC_STATIC);
STRING_TABLE._png_read_info_png_zTXt=allocate([122,84,88,116,0] /* zTXt\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str7155=allocate([77,105,115,115,105,110,103,32,73,72,68,82,32,98,101,102,111,114,101,32,73,68,65,84,0] /* Missing IHDR before  */, "i8", ALLOC_STATIC);
STRING_TABLE.__str8156=allocate([77,105,115,115,105,110,103,32,80,76,84,69,32,98,101,102,111,114,101,32,73,68,65,84,0] /* Missing PLTE before  */, "i8", ALLOC_STATIC);
STRING_TABLE.__str9157=allocate([73,103,110,111,114,105,110,103,32,101,120,116,114,97,32,112,110,103,95,114,101,97,100,95,117,112,100,97,116,101,95,105,110,102,111,40,41,32,99,97,108,108,59,32,114,111,119,32,98,117,102,102,101,114,32,110,111,116,32,114,101,97,108,108,111,99,97,116,101,100,0] /* Ignoring extra png_r */, "i8", ALLOC_STATIC);
STRING_TABLE._png_read_row_png_IDAT=allocate([73,68,65,84,0] /* IDAT\00 */, "i8", ALLOC_STATIC);
_png_read_row_png_pass_dsp_mask=allocate([255, 0, 0, 0, 15, 0, 0, 0, 255, 0, 0, 0, 51, 0, 0, 0, 255, 0, 0, 0, 85, 0, 0, 0, 255, 0, 0, 0], ["i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0], ALLOC_STATIC);
_png_read_row_png_pass_mask=allocate([128, 0, 0, 0, 8, 0, 0, 0, 136, 0, 0, 0, 34, 0, 0, 0, 170, 0, 0, 0, 85, 0, 0, 0, 255, 0, 0, 0], ["i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0], ALLOC_STATIC);
STRING_TABLE.__str10158=allocate([73,110,118,97,108,105,100,32,97,116,116,101,109,112,116,32,116,111,32,114,101,97,100,32,114,111,119,32,100,97,116,97,0] /* Invalid attempt to r */, "i8", ALLOC_STATIC);
STRING_TABLE.__str11159=allocate([78,111,116,32,101,110,111,117,103,104,32,105,109,97,103,101,32,100,97,116,97,0] /* Not enough image dat */, "i8", ALLOC_STATIC);
STRING_TABLE.__str12160=allocate([69,120,116,114,97,32,99,111,109,112,114,101,115,115,101,100,32,100,97,116,97,0] /* Extra compressed dat */, "i8", ALLOC_STATIC);
STRING_TABLE.__str13161=allocate([68,101,99,111,109,112,114,101,115,115,105,111,110,32,101,114,114,111,114,0] /* Decompression error\ */, "i8", ALLOC_STATIC);
STRING_TABLE.__str164=allocate([67,97,108,108,32,116,111,32,78,85,76,76,32,114,101,97,100,32,102,117,110,99,116,105,111,110,0] /* Call to NULL read fu */, "i8", ALLOC_STATIC);
STRING_TABLE.__str1165=allocate([82,101,97,100,32,69,114,114,111,114,0] /* Read Error\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str2166=allocate([73,116,39,115,32,97,110,32,101,114,114,111,114,32,116,111,32,115,101,116,32,98,111,116,104,32,114,101,97,100,95,100,97,116,97,95,102,110,32,97,110,100,32,119,114,105,116,101,95,100,97,116,97,95,102,110,32,105,110,32,116,104,101,32,0] /* It's an error to set */, "i8", ALLOC_STATIC);
STRING_TABLE.__str3167=allocate([115,97,109,101,32,115,116,114,117,99,116,117,114,101,46,32,32,82,101,115,101,116,116,105,110,103,32,119,114,105,116,101,95,100,97,116,97,95,102,110,32,116,111,32,78,85,76,76,0] /* same structure.  Res */, "i8", ALLOC_STATIC);
STRING_TABLE.__str4174=allocate([105,110,118,97,108,105,100,32,98,97,99,107,103,114,111,117,110,100,32,103,97,109,109,97,32,116,121,112,101,0] /* invalid background g */, "i8", ALLOC_STATIC);
STRING_TABLE.__str5175=allocate([78,85,76,76,32,114,111,119,32,98,117,102,102,101,114,32,102,111,114,32,114,111,119,32,37,108,100,44,32,112,97,115,115,32,37,100,0] /* NULL row buffer for  */, "i8", ALLOC_STATIC);
STRING_TABLE.__str6176=allocate([112,110,103,95,100,111,95,114,103,98,95,116,111,95,103,114,97,121,32,102,111,117,110,100,32,110,111,110,103,114,97,121,32,112,105,120,101,108,0] /* png_do_rgb_to_gray f */, "i8", ALLOC_STATIC);
STRING_TABLE.__str7177=allocate([112,110,103,95,100,111,95,113,117,97,110,116,105,122,101,32,114,101,116,117,114,110,101,100,32,114,111,119,98,121,116,101,115,61,48,0] /* png_do_quantize retu */, "i8", ALLOC_STATIC);
_png_gamma_shift=allocate([16, 0, 0, 0, 33, 0, 0, 0, 66, 0, 0, 0, 132, 0, 0, 0, 272, 0, 0, 0, 584, 0, 0, 0, 1360, 0, 0, 0, 4080, 0, 0, 0, 0, 0, 0, 0], ["i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0], ALLOC_STATIC);
STRING_TABLE.__str193=allocate([80,78,71,32,117,110,115,105,103,110,101,100,32,105,110,116,101,103,101,114,32,111,117,116,32,111,102,32,114,97,110,103,101,0] /* PNG unsigned integer */, "i8", ALLOC_STATIC);
STRING_TABLE.__str1194=allocate([78,111,116,32,97,32,80,78,71,32,102,105,108,101,0] /* Not a PNG file\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str2195=allocate([80,78,71,32,102,105,108,101,32,99,111,114,114,117,112,116,101,100,32,98,121,32,65,83,67,73,73,32,99,111,110,118,101,114,115,105,111,110,0] /* PNG file corrupted b */, "i8", ALLOC_STATIC);
STRING_TABLE.__str3196=allocate([67,82,67,32,101,114,114,111,114,0] /* CRC error\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str4197=allocate([105,110,118,97,108,105,100,32,99,104,117,110,107,108,101,110,103,116,104,0] /* invalid chunklength\ */, "i8", ALLOC_STATIC);
STRING_TABLE.__str5198=allocate([69,120,99,101,101,100,101,100,32,115,105,122,101,32,108,105,109,105,116,32,119,104,105,108,101,32,101,120,112,97,110,100,105,110,103,32,99,104,117,110,107,0] /* Exceeded size limit  */, "i8", ALLOC_STATIC);
STRING_TABLE.__str6199=allocate([112,110,103,95,105,110,102,108,97,116,101,32,108,111,103,105,99,32,101,114,114,111,114,0] /* png_inflate logic er */, "i8", ALLOC_STATIC);
STRING_TABLE.__str7200=allocate([78,111,116,32,101,110,111,117,103,104,32,109,101,109,111,114,121,32,116,111,32,100,101,99,111,109,112,114,101,115,115,32,99,104,117,110,107,0] /* Not enough memory to */, "i8", ALLOC_STATIC);
STRING_TABLE.__str8201=allocate([85,110,107,110,111,119,110,32,122,84,88,116,32,99,111,109,112,114,101,115,115,105,111,110,32,116,121,112,101,32,37,100,0] /* Unknown zTXt compres */, "i8", ALLOC_STATIC);
STRING_TABLE.__str9202=allocate([79,117,116,32,111,102,32,112,108,97,99,101,32,73,72,68,82,0] /* Out of place IHDR\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str10203=allocate([73,110,118,97,108,105,100,32,73,72,68,82,32,99,104,117,110,107,0] /* Invalid IHDR chunk\0 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str11204=allocate([77,105,115,115,105,110,103,32,73,72,68,82,32,98,101,102,111,114,101,32,80,76,84,69,0] /* Missing IHDR before  */, "i8", ALLOC_STATIC);
STRING_TABLE.__str12205=allocate([73,110,118,97,108,105,100,32,80,76,84,69,32,97,102,116,101,114,32,73,68,65,84,0] /* Invalid PLTE after I */, "i8", ALLOC_STATIC);
STRING_TABLE.__str13206=allocate([68,117,112,108,105,99,97,116,101,32,80,76,84,69,32,99,104,117,110,107,0] /* Duplicate PLTE chunk */, "i8", ALLOC_STATIC);
STRING_TABLE.__str14207=allocate([73,103,110,111,114,105,110,103,32,80,76,84,69,32,99,104,117,110,107,32,105,110,32,103,114,97,121,115,99,97,108,101,32,80,78,71,0] /* Ignoring PLTE chunk  */, "i8", ALLOC_STATIC);
STRING_TABLE.__str15208=allocate([73,110,118,97,108,105,100,32,112,97,108,101,116,116,101,32,99,104,117,110,107,0] /* Invalid palette chun */, "i8", ALLOC_STATIC);
STRING_TABLE.__str16209=allocate([84,114,117,110,99,97,116,105,110,103,32,105,110,99,111,114,114,101,99,116,32,116,82,78,83,32,99,104,117,110,107,32,108,101,110,103,116,104,0] /* Truncating incorrect */, "i8", ALLOC_STATIC);
STRING_TABLE.__str17210=allocate([84,114,117,110,99,97,116,105,110,103,32,105,110,99,111,114,114,101,99,116,32,105,110,102,111,32,116,82,78,83,32,99,104,117,110,107,32,108,101,110,103,116,104,0] /* Truncating incorrect */, "i8", ALLOC_STATIC);
STRING_TABLE.__str18211=allocate([78,111,32,105,109,97,103,101,32,105,110,32,102,105,108,101,0] /* No image in file\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str19212=allocate([73,110,99,111,114,114,101,99,116,32,73,69,78,68,32,99,104,117,110,107,32,108,101,110,103,116,104,0] /* Incorrect IEND chunk */, "i8", ALLOC_STATIC);
STRING_TABLE.__str20213=allocate([77,105,115,115,105,110,103,32,73,72,68,82,32,98,101,102,111,114,101,32,103,65,77,65,0] /* Missing IHDR before  */, "i8", ALLOC_STATIC);
STRING_TABLE.__str21214=allocate([73,110,118,97,108,105,100,32,103,65,77,65,32,97,102,116,101,114,32,73,68,65,84,0] /* Invalid gAMA after I */, "i8", ALLOC_STATIC);
STRING_TABLE.__str22215=allocate([79,117,116,32,111,102,32,112,108,97,99,101,32,103,65,77,65,32,99,104,117,110,107,0] /* Out of place gAMA ch */, "i8", ALLOC_STATIC);
STRING_TABLE.__str23216=allocate([68,117,112,108,105,99,97,116,101,32,103,65,77,65,32,99,104,117,110,107,0] /* Duplicate gAMA chunk */, "i8", ALLOC_STATIC);
STRING_TABLE.__str24217=allocate([73,110,99,111,114,114,101,99,116,32,103,65,77,65,32,99,104,117,110,107,32,108,101,110,103,116,104,0] /* Incorrect gAMA chunk */, "i8", ALLOC_STATIC);
STRING_TABLE.__str25218=allocate([73,103,110,111,114,105,110,103,32,103,65,77,65,32,99,104,117,110,107,32,119,105,116,104,32,103,97,109,109,97,61,48,0] /* Ignoring gAMA chunk  */, "i8", ALLOC_STATIC);
STRING_TABLE.__str26219=allocate([73,103,110,111,114,105,110,103,32,105,110,99,111,114,114,101,99,116,32,103,65,77,65,32,118,97,108,117,101,32,119,104,101,110,32,115,82,71,66,32,105,115,32,97,108,115,111,32,112,114,101,115,101,110,116,0] /* Ignoring incorrect g */, "i8", ALLOC_STATIC);
STRING_TABLE.__str27220=allocate([103,97,109,109,97,32,61,32,40,37,100,47,49,48,48,48,48,48,41,0] /* gamma = (%d/100000)\ */, "i8", ALLOC_STATIC);
STRING_TABLE.__str28221=allocate([77,105,115,115,105,110,103,32,73,72,68,82,32,98,101,102,111,114,101,32,115,66,73,84,0] /* Missing IHDR before  */, "i8", ALLOC_STATIC);
STRING_TABLE.__str29222=allocate([73,110,118,97,108,105,100,32,115,66,73,84,32,97,102,116,101,114,32,73,68,65,84,0] /* Invalid sBIT after I */, "i8", ALLOC_STATIC);
STRING_TABLE.__str30=allocate([79,117,116,32,111,102,32,112,108,97,99,101,32,115,66,73,84,32,99,104,117,110,107,0] /* Out of place sBIT ch */, "i8", ALLOC_STATIC);
STRING_TABLE.__str31=allocate([68,117,112,108,105,99,97,116,101,32,115,66,73,84,32,99,104,117,110,107,0] /* Duplicate sBIT chunk */, "i8", ALLOC_STATIC);
STRING_TABLE.__str32=allocate([73,110,99,111,114,114,101,99,116,32,115,66,73,84,32,99,104,117,110,107,32,108,101,110,103,116,104,0] /* Incorrect sBIT chunk */, "i8", ALLOC_STATIC);
STRING_TABLE.__str33=allocate([77,105,115,115,105,110,103,32,73,72,68,82,32,98,101,102,111,114,101,32,99,72,82,77,0] /* Missing IHDR before  */, "i8", ALLOC_STATIC);
STRING_TABLE.__str34223=allocate([73,110,118,97,108,105,100,32,99,72,82,77,32,97,102,116,101,114,32,73,68,65,84,0] /* Invalid cHRM after I */, "i8", ALLOC_STATIC);
STRING_TABLE.__str35=allocate([77,105,115,115,105,110,103,32,80,76,84,69,32,98,101,102,111,114,101,32,99,72,82,77,0] /* Missing PLTE before  */, "i8", ALLOC_STATIC);
STRING_TABLE.__str36=allocate([68,117,112,108,105,99,97,116,101,32,99,72,82,77,32,99,104,117,110,107,0] /* Duplicate cHRM chunk */, "i8", ALLOC_STATIC);
STRING_TABLE.__str37=allocate([73,110,99,111,114,114,101,99,116,32,99,72,82,77,32,99,104,117,110,107,32,108,101,110,103,116,104,0] /* Incorrect cHRM chunk */, "i8", ALLOC_STATIC);
STRING_TABLE.__str38=allocate([73,103,110,111,114,105,110,103,32,105,110,99,111,114,114,101,99,116,32,99,72,82,77,32,118,97,108,117,101,32,119,104,101,110,32,115,82,71,66,32,105,115,32,97,108,115,111,32,112,114,101,115,101,110,116,0] /* Ignoring incorrect c */, "i8", ALLOC_STATIC);
STRING_TABLE.__str39=allocate([119,120,61,37,102,44,32,119,121,61,37,102,44,32,114,120,61,37,102,44,32,114,121,61,37,102,10,0] /* wx=%f, wy=%f, rx=%f, */, "i8", ALLOC_STATIC);
STRING_TABLE.__str40=allocate([103,120,61,37,102,44,32,103,121,61,37,102,44,32,98,120,61,37,102,44,32,98,121,61,37,102,10,0] /* gx=%f, gy=%f, bx=%f, */, "i8", ALLOC_STATIC);
STRING_TABLE.__str41=allocate([77,105,115,115,105,110,103,32,73,72,68,82,32,98,101,102,111,114,101,32,115,82,71,66,0] /* Missing IHDR before  */, "i8", ALLOC_STATIC);
STRING_TABLE.__str42=allocate([73,110,118,97,108,105,100,32,115,82,71,66,32,97,102,116,101,114,32,73,68,65,84,0] /* Invalid sRGB after I */, "i8", ALLOC_STATIC);
STRING_TABLE.__str43=allocate([79,117,116,32,111,102,32,112,108,97,99,101,32,115,82,71,66,32,99,104,117,110,107,0] /* Out of place sRGB ch */, "i8", ALLOC_STATIC);
STRING_TABLE.__str44=allocate([68,117,112,108,105,99,97,116,101,32,115,82,71,66,32,99,104,117,110,107,0] /* Duplicate sRGB chunk */, "i8", ALLOC_STATIC);
STRING_TABLE.__str45=allocate([73,110,99,111,114,114,101,99,116,32,115,82,71,66,32,99,104,117,110,107,32,108,101,110,103,116,104,0] /* Incorrect sRGB chunk */, "i8", ALLOC_STATIC);
STRING_TABLE.__str46=allocate([85,110,107,110,111,119,110,32,115,82,71,66,32,105,110,116,101,110,116,0] /* Unknown sRGB intent\ */, "i8", ALLOC_STATIC);
STRING_TABLE.__str47=allocate([105,110,99,111,114,114,101,99,116,32,103,97,109,109,97,61,40,37,100,47,49,48,48,48,48,48,41,10,0] /* incorrect gamma=(%d/ */, "i8", ALLOC_STATIC);
STRING_TABLE.__str48=allocate([77,105,115,115,105,110,103,32,73,72,68,82,32,98,101,102,111,114,101,32,105,67,67,80,0] /* Missing IHDR before  */, "i8", ALLOC_STATIC);
STRING_TABLE.__str49=allocate([73,110,118,97,108,105,100,32,105,67,67,80,32,97,102,116,101,114,32,73,68,65,84,0] /* Invalid iCCP after I */, "i8", ALLOC_STATIC);
STRING_TABLE.__str50=allocate([79,117,116,32,111,102,32,112,108,97,99,101,32,105,67,67,80,32,99,104,117,110,107,0] /* Out of place iCCP ch */, "i8", ALLOC_STATIC);
STRING_TABLE.__str51=allocate([68,117,112,108,105,99,97,116,101,32,105,67,67,80,32,99,104,117,110,107,0] /* Duplicate iCCP chunk */, "i8", ALLOC_STATIC);
STRING_TABLE.__str52=allocate([77,97,108,102,111,114,109,101,100,32,105,67,67,80,32,99,104,117,110,107,0] /* Malformed iCCP chunk */, "i8", ALLOC_STATIC);
STRING_TABLE.__str53=allocate([73,103,110,111,114,105,110,103,32,110,111,110,122,101,114,111,32,99,111,109,112,114,101,115,115,105,111,110,32,116,121,112,101,32,105,110,32,105,67,67,80,32,99,104,117,110,107,0] /* Ignoring nonzero com */, "i8", ALLOC_STATIC);
STRING_TABLE.__str54=allocate([80,114,111,102,105,108,101,32,115,105,122,101,32,102,105,101,108,100,32,109,105,115,115,105,110,103,32,102,114,111,109,32,105,67,67,80,32,99,104,117,110,107,0] /* Profile size field m */, "i8", ALLOC_STATIC);
STRING_TABLE.__str55=allocate([73,103,110,111,114,105,110,103,32,116,114,117,110,99,97,116,101,100,32,105,67,67,80,32,112,114,111,102,105,108,101,0] /* Ignoring truncated i */, "i8", ALLOC_STATIC);
STRING_TABLE.__str56=allocate([100,101,99,108,97,114,101,100,32,112,114,111,102,105,108,101,32,115,105,122,101,32,61,32,37,108,117,0] /* declared profile siz */, "i8", ALLOC_STATIC);
STRING_TABLE.__str57=allocate([97,99,116,117,97,108,32,112,114,111,102,105,108,101,32,108,101,110,103,116,104,32,61,32,37,108,117,0] /* actual profile lengt */, "i8", ALLOC_STATIC);
STRING_TABLE.__str58=allocate([78,111,32,115,112,97,99,101,32,105,110,32,99,104,117,110,107,32,99,97,99,104,101,32,102,111,114,32,115,80,76,84,0] /* No space in chunk ca */, "i8", ALLOC_STATIC);
STRING_TABLE.__str59=allocate([77,105,115,115,105,110,103,32,73,72,68,82,32,98,101,102,111,114,101,32,115,80,76,84,0] /* Missing IHDR before  */, "i8", ALLOC_STATIC);
STRING_TABLE.__str60=allocate([73,110,118,97,108,105,100,32,115,80,76,84,32,97,102,116,101,114,32,73,68,65,84,0] /* Invalid sPLT after I */, "i8", ALLOC_STATIC);
STRING_TABLE.__str61=allocate([109,97,108,102,111,114,109,101,100,32,115,80,76,84,32,99,104,117,110,107,0] /* malformed sPLT chunk */, "i8", ALLOC_STATIC);
STRING_TABLE.__str62=allocate([115,80,76,84,32,99,104,117,110,107,32,104,97,115,32,98,97,100,32,108,101,110,103,116,104,0] /* sPLT chunk has bad l */, "i8", ALLOC_STATIC);
STRING_TABLE.__str63=allocate([115,80,76,84,32,99,104,117,110,107,32,116,111,111,32,108,111,110,103,0] /* sPLT chunk too long\ */, "i8", ALLOC_STATIC);
STRING_TABLE.__str64=allocate([115,80,76,84,32,99,104,117,110,107,32,114,101,113,117,105,114,101,115,32,116,111,111,32,109,117,99,104,32,109,101,109,111,114,121,0] /* sPLT chunk requires  */, "i8", ALLOC_STATIC);
STRING_TABLE.__str65=allocate([77,105,115,115,105,110,103,32,73,72,68,82,32,98,101,102,111,114,101,32,116,82,78,83,0] /* Missing IHDR before  */, "i8", ALLOC_STATIC);
STRING_TABLE.__str66=allocate([73,110,118,97,108,105,100,32,116,82,78,83,32,97,102,116,101,114,32,73,68,65,84,0] /* Invalid tRNS after I */, "i8", ALLOC_STATIC);
STRING_TABLE.__str67=allocate([68,117,112,108,105,99,97,116,101,32,116,82,78,83,32,99,104,117,110,107,0] /* Duplicate tRNS chunk */, "i8", ALLOC_STATIC);
STRING_TABLE.__str68=allocate([73,110,99,111,114,114,101,99,116,32,116,82,78,83,32,99,104,117,110,107,32,108,101,110,103,116,104,0] /* Incorrect tRNS chunk */, "i8", ALLOC_STATIC);
STRING_TABLE.__str69=allocate([77,105,115,115,105,110,103,32,80,76,84,69,32,98,101,102,111,114,101,32,116,82,78,83,0] /* Missing PLTE before  */, "i8", ALLOC_STATIC);
STRING_TABLE.__str70=allocate([90,101,114,111,32,108,101,110,103,116,104,32,116,82,78,83,32,99,104,117,110,107,0] /* Zero length tRNS chu */, "i8", ALLOC_STATIC);
STRING_TABLE.__str71=allocate([116,82,78,83,32,99,104,117,110,107,32,110,111,116,32,97,108,108,111,119,101,100,32,119,105,116,104,32,97,108,112,104,97,32,99,104,97,110,110,101,108,0] /* tRNS chunk not allow */, "i8", ALLOC_STATIC);
STRING_TABLE.__str72=allocate([77,105,115,115,105,110,103,32,73,72,68,82,32,98,101,102,111,114,101,32,98,75,71,68,0] /* Missing IHDR before  */, "i8", ALLOC_STATIC);
STRING_TABLE.__str73=allocate([73,110,118,97,108,105,100,32,98,75,71,68,32,97,102,116,101,114,32,73,68,65,84,0] /* Invalid bKGD after I */, "i8", ALLOC_STATIC);
STRING_TABLE.__str74224=allocate([77,105,115,115,105,110,103,32,80,76,84,69,32,98,101,102,111,114,101,32,98,75,71,68,0] /* Missing PLTE before  */, "i8", ALLOC_STATIC);
STRING_TABLE.__str75225=allocate([68,117,112,108,105,99,97,116,101,32,98,75,71,68,32,99,104,117,110,107,0] /* Duplicate bKGD chunk */, "i8", ALLOC_STATIC);
STRING_TABLE.__str76=allocate([73,110,99,111,114,114,101,99,116,32,98,75,71,68,32,99,104,117,110,107,32,108,101,110,103,116,104,0] /* Incorrect bKGD chunk */, "i8", ALLOC_STATIC);
STRING_TABLE.__str77=allocate([73,110,99,111,114,114,101,99,116,32,98,75,71,68,32,99,104,117,110,107,32,105,110,100,101,120,32,118,97,108,117,101,0] /* Incorrect bKGD chunk */, "i8", ALLOC_STATIC);
STRING_TABLE.__str78=allocate([77,105,115,115,105,110,103,32,73,72,68,82,32,98,101,102,111,114,101,32,104,73,83,84,0] /* Missing IHDR before  */, "i8", ALLOC_STATIC);
STRING_TABLE.__str79=allocate([73,110,118,97,108,105,100,32,104,73,83,84,32,97,102,116,101,114,32,73,68,65,84,0] /* Invalid hIST after I */, "i8", ALLOC_STATIC);
STRING_TABLE.__str80=allocate([77,105,115,115,105,110,103,32,80,76,84,69,32,98,101,102,111,114,101,32,104,73,83,84,0] /* Missing PLTE before  */, "i8", ALLOC_STATIC);
STRING_TABLE.__str81=allocate([68,117,112,108,105,99,97,116,101,32,104,73,83,84,32,99,104,117,110,107,0] /* Duplicate hIST chunk */, "i8", ALLOC_STATIC);
STRING_TABLE.__str82=allocate([73,110,99,111,114,114,101,99,116,32,104,73,83,84,32,99,104,117,110,107,32,108,101,110,103,116,104,0] /* Incorrect hIST chunk */, "i8", ALLOC_STATIC);
STRING_TABLE.__str83=allocate([77,105,115,115,105,110,103,32,73,72,68,82,32,98,101,102,111,114,101,32,112,72,89,115,0] /* Missing IHDR before  */, "i8", ALLOC_STATIC);
STRING_TABLE.__str84=allocate([73,110,118,97,108,105,100,32,112,72,89,115,32,97,102,116,101,114,32,73,68,65,84,0] /* Invalid pHYs after I */, "i8", ALLOC_STATIC);
STRING_TABLE.__str85=allocate([68,117,112,108,105,99,97,116,101,32,112,72,89,115,32,99,104,117,110,107,0] /* Duplicate pHYs chunk */, "i8", ALLOC_STATIC);
STRING_TABLE.__str86=allocate([73,110,99,111,114,114,101,99,116,32,112,72,89,115,32,99,104,117,110,107,32,108,101,110,103,116,104,0] /* Incorrect pHYs chunk */, "i8", ALLOC_STATIC);
STRING_TABLE.__str87=allocate([77,105,115,115,105,110,103,32,73,72,68,82,32,98,101,102,111,114,101,32,111,70,70,115,0] /* Missing IHDR before  */, "i8", ALLOC_STATIC);
STRING_TABLE.__str88=allocate([73,110,118,97,108,105,100,32,111,70,70,115,32,97,102,116,101,114,32,73,68,65,84,0] /* Invalid oFFs after I */, "i8", ALLOC_STATIC);
STRING_TABLE.__str89=allocate([68,117,112,108,105,99,97,116,101,32,111,70,70,115,32,99,104,117,110,107,0] /* Duplicate oFFs chunk */, "i8", ALLOC_STATIC);
STRING_TABLE.__str90=allocate([73,110,99,111,114,114,101,99,116,32,111,70,70,115,32,99,104,117,110,107,32,108,101,110,103,116,104,0] /* Incorrect oFFs chunk */, "i8", ALLOC_STATIC);
STRING_TABLE.__str91226=allocate([77,105,115,115,105,110,103,32,73,72,68,82,32,98,101,102,111,114,101,32,112,67,65,76,0] /* Missing IHDR before  */, "i8", ALLOC_STATIC);
STRING_TABLE.__str92=allocate([73,110,118,97,108,105,100,32,112,67,65,76,32,97,102,116,101,114,32,73,68,65,84,0] /* Invalid pCAL after I */, "i8", ALLOC_STATIC);
STRING_TABLE.__str93=allocate([68,117,112,108,105,99,97,116,101,32,112,67,65,76,32,99,104,117,110,107,0] /* Duplicate pCAL chunk */, "i8", ALLOC_STATIC);
STRING_TABLE.__str94=allocate([78,111,32,109,101,109,111,114,121,32,102,111,114,32,112,67,65,76,32,112,117,114,112,111,115,101,0] /* No memory for pCAL p */, "i8", ALLOC_STATIC);
STRING_TABLE.__str95=allocate([73,110,118,97,108,105,100,32,112,67,65,76,32,100,97,116,97,0] /* Invalid pCAL data\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str96=allocate([73,110,118,97,108,105,100,32,112,67,65,76,32,112,97,114,97,109,101,116,101,114,115,32,102,111,114,32,101,113,117,97,116,105,111,110,32,116,121,112,101,0] /* Invalid pCAL paramet */, "i8", ALLOC_STATIC);
STRING_TABLE.__str97=allocate([85,110,114,101,99,111,103,110,105,122,101,100,32,101,113,117,97,116,105,111,110,32,116,121,112,101,32,102,111,114,32,112,67,65,76,32,99,104,117,110,107,0] /* Unrecognized equatio */, "i8", ALLOC_STATIC);
STRING_TABLE.__str98=allocate([78,111,32,109,101,109,111,114,121,32,102,111,114,32,112,67,65,76,32,112,97,114,97,109,115,0] /* No memory for pCAL p */, "i8", ALLOC_STATIC);
STRING_TABLE.__str99=allocate([77,105,115,115,105,110,103,32,73,72,68,82,32,98,101,102,111,114,101,32,115,67,65,76,0] /* Missing IHDR before  */, "i8", ALLOC_STATIC);
STRING_TABLE.__str100=allocate([73,110,118,97,108,105,100,32,115,67,65,76,32,97,102,116,101,114,32,73,68,65,84,0] /* Invalid sCAL after I */, "i8", ALLOC_STATIC);
STRING_TABLE.__str101=allocate([68,117,112,108,105,99,97,116,101,32,115,67,65,76,32,99,104,117,110,107,0] /* Duplicate sCAL chunk */, "i8", ALLOC_STATIC);
STRING_TABLE.__str102=allocate([115,67,65,76,32,99,104,117,110,107,32,116,111,111,32,115,104,111,114,116,0] /* sCAL chunk too short */, "i8", ALLOC_STATIC);
STRING_TABLE.__str103=allocate([79,117,116,32,111,102,32,109,101,109,111,114,121,32,119,104,105,108,101,32,112,114,111,99,101,115,115,105,110,103,32,115,67,65,76,32,99,104,117,110,107,0] /* Out of memory while  */, "i8", ALLOC_STATIC);
STRING_TABLE.__str104=allocate([109,97,108,102,111,114,109,101,100,32,119,105,100,116,104,32,115,116,114,105,110,103,32,105,110,32,115,67,65,76,32,99,104,117,110,107,0] /* malformed width stri */, "i8", ALLOC_STATIC);
STRING_TABLE.__str105=allocate([84,114,117,110,99,97,116,101,100,32,115,67,65,76,32,99,104,117,110,107,0] /* Truncated sCAL chunk */, "i8", ALLOC_STATIC);
STRING_TABLE.__str106=allocate([109,97,108,102,111,114,109,101,100,32,104,101,105,103,104,116,32,115,116,114,105,110,103,32,105,110,32,115,67,65,76,32,99,104,117,110,107,0] /* malformed height str */, "i8", ALLOC_STATIC);
STRING_TABLE.__str107=allocate([73,110,118,97,108,105,100,32,115,67,65,76,32,100,97,116,97,0] /* Invalid sCAL data\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str108=allocate([79,117,116,32,111,102,32,112,108,97,99,101,32,116,73,77,69,32,99,104,117,110,107,0] /* Out of place tIME ch */, "i8", ALLOC_STATIC);
STRING_TABLE.__str109=allocate([68,117,112,108,105,99,97,116,101,32,116,73,77,69,32,99,104,117,110,107,0] /* Duplicate tIME chunk */, "i8", ALLOC_STATIC);
STRING_TABLE.__str110=allocate([73,110,99,111,114,114,101,99,116,32,116,73,77,69,32,99,104,117,110,107,32,108,101,110,103,116,104,0] /* Incorrect tIME chunk */, "i8", ALLOC_STATIC);
STRING_TABLE.__str111=allocate([78,111,32,115,112,97,99,101,32,105,110,32,99,104,117,110,107,32,99,97,99,104,101,32,102,111,114,32,116,69,88,116,0] /* No space in chunk ca */, "i8", ALLOC_STATIC);
STRING_TABLE.__str112=allocate([77,105,115,115,105,110,103,32,73,72,68,82,32,98,101,102,111,114,101,32,116,69,88,116,0] /* Missing IHDR before  */, "i8", ALLOC_STATIC);
STRING_TABLE.__str113227=allocate([78,111,32,109,101,109,111,114,121,32,116,111,32,112,114,111,99,101,115,115,32,116,101,120,116,32,99,104,117,110,107,0] /* No memory to process */, "i8", ALLOC_STATIC);
STRING_TABLE.__str114=allocate([78,111,116,32,101,110,111,117,103,104,32,109,101,109,111,114,121,32,116,111,32,112,114,111,99,101,115,115,32,116,101,120,116,32,99,104,117,110,107,0] /* Not enough memory to */, "i8", ALLOC_STATIC);
STRING_TABLE.__str115228=allocate([73,110,115,117,102,102,105,99,105,101,110,116,32,109,101,109,111,114,121,32,116,111,32,112,114,111,99,101,115,115,32,116,101,120,116,32,99,104,117,110,107,0] /* Insufficient memory  */, "i8", ALLOC_STATIC);
STRING_TABLE.__str116=allocate([78,111,32,115,112,97,99,101,32,105,110,32,99,104,117,110,107,32,99,97,99,104,101,32,102,111,114,32,122,84,88,116,0] /* No space in chunk ca */, "i8", ALLOC_STATIC);
STRING_TABLE.__str117=allocate([77,105,115,115,105,110,103,32,73,72,68,82,32,98,101,102,111,114,101,32,122,84,88,116,0] /* Missing IHDR before  */, "i8", ALLOC_STATIC);
STRING_TABLE.__str118=allocate([79,117,116,32,111,102,32,109,101,109,111,114,121,32,112,114,111,99,101,115,115,105,110,103,32,122,84,88,116,32,99,104,117,110,107,0] /* Out of memory proces */, "i8", ALLOC_STATIC);
STRING_TABLE.__str119=allocate([84,114,117,110,99,97,116,101,100,32,122,84,88,116,32,99,104,117,110,107,0] /* Truncated zTXt chunk */, "i8", ALLOC_STATIC);
STRING_TABLE.__str120229=allocate([85,110,107,110,111,119,110,32,99,111,109,112,114,101,115,115,105,111,110,32,116,121,112,101,32,105,110,32,122,84,88,116,32,99,104,117,110,107,0] /* Unknown compression  */, "i8", ALLOC_STATIC);
STRING_TABLE.__str121230=allocate([78,111,116,32,101,110,111,117,103,104,32,109,101,109,111,114,121,32,116,111,32,112,114,111,99,101,115,115,32,122,84,88,116,32,99,104,117,110,107,0] /* Not enough memory to */, "i8", ALLOC_STATIC);
STRING_TABLE.__str122=allocate([73,110,115,117,102,102,105,99,105,101,110,116,32,109,101,109,111,114,121,32,116,111,32,115,116,111,114,101,32,122,84,88,116,32,99,104,117,110,107,0] /* Insufficient memory  */, "i8", ALLOC_STATIC);
STRING_TABLE.__str123=allocate([78,111,32,115,112,97,99,101,32,105,110,32,99,104,117,110,107,32,99,97,99,104,101,32,102,111,114,32,105,84,88,116,0] /* No space in chunk ca */, "i8", ALLOC_STATIC);
STRING_TABLE.__str124=allocate([77,105,115,115,105,110,103,32,73,72,68,82,32,98,101,102,111,114,101,32,105,84,88,116,0] /* Missing IHDR before  */, "i8", ALLOC_STATIC);
STRING_TABLE.__str125=allocate([78,111,32,109,101,109,111,114,121,32,116,111,32,112,114,111,99,101,115,115,32,105,84,88,116,32,99,104,117,110,107,0] /* No memory to process */, "i8", ALLOC_STATIC);
STRING_TABLE.__str126=allocate([84,114,117,110,99,97,116,101,100,32,105,84,88,116,32,99,104,117,110,107,0] /* Truncated iTXt chunk */, "i8", ALLOC_STATIC);
STRING_TABLE.__str127=allocate([77,97,108,102,111,114,109,101,100,32,105,84,88,116,32,99,104,117,110,107,0] /* Malformed iTXt chunk */, "i8", ALLOC_STATIC);
STRING_TABLE.__str128=allocate([78,111,116,32,101,110,111,117,103,104,32,109,101,109,111,114,121,32,116,111,32,112,114,111,99,101,115,115,32,105,84,88,116,32,99,104,117,110,107,0] /* Not enough memory to */, "i8", ALLOC_STATIC);
STRING_TABLE.__str129=allocate([73,110,115,117,102,102,105,99,105,101,110,116,32,109,101,109,111,114,121,32,116,111,32,115,116,111,114,101,32,105,84,88,116,32,99,104,117,110,107,0] /* Insufficient memory  */, "i8", ALLOC_STATIC);
STRING_TABLE.__str130231=allocate([78,111,32,115,112,97,99,101,32,105,110,32,99,104,117,110,107,32,99,97,99,104,101,32,102,111,114,32,117,110,107,110,111,119,110,32,99,104,117,110,107,0] /* No space in chunk ca */, "i8", ALLOC_STATIC);
STRING_TABLE._png_handle_unknown_png_IDAT=allocate([73,68,65,84,0] /* IDAT\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str131=allocate([117,110,107,110,111,119,110,32,99,114,105,116,105,99,97,108,32,99,104,117,110,107,0] /* unknown critical chu */, "i8", ALLOC_STATIC);
STRING_TABLE.__str132=allocate([101,114,114,111,114,32,105,110,32,117,115,101,114,32,99,104,117,110,107,0] /* error in user chunk\ */, "i8", ALLOC_STATIC);
STRING_TABLE.__str133232=allocate([105,110,118,97,108,105,100,32,99,104,117,110,107,32,116,121,112,101,0] /* invalid chunk type\0 */, "i8", ALLOC_STATIC);
_png_do_read_interlace_png_pass_inc=allocate([8, 0, 0, 0, 8, 0, 0, 0, 4, 0, 0, 0, 4, 0, 0, 0, 2, 0, 0, 0, 2, 0, 0, 0, 1, 0, 0, 0], ["i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0], ALLOC_STATIC);
STRING_TABLE.__str134=allocate([73,103,110,111,114,105,110,103,32,98,97,100,32,97,100,97,112,116,105,118,101,32,102,105,108,116,101,114,32,116,121,112,101,0] /* Ignoring bad adaptiv */, "i8", ALLOC_STATIC);
_png_read_finish_row_png_pass_start=allocate([0, 0, 0, 0, 4, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0], ["i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0], ALLOC_STATIC);
_png_read_finish_row_png_pass_inc=allocate([8, 0, 0, 0, 8, 0, 0, 0, 4, 0, 0, 0, 4, 0, 0, 0, 2, 0, 0, 0, 2, 0, 0, 0, 1, 0, 0, 0], ["i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0], ALLOC_STATIC);
_png_read_finish_row_png_pass_ystart=allocate([0, 0, 0, 0, 0, 0, 0, 0, 4, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0], ["i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0], ALLOC_STATIC);
_png_read_finish_row_png_pass_yinc=allocate([8, 0, 0, 0, 8, 0, 0, 0, 8, 0, 0, 0, 4, 0, 0, 0, 4, 0, 0, 0, 2, 0, 0, 0, 2, 0, 0, 0], ["i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0], ALLOC_STATIC);
STRING_TABLE._png_read_finish_row_png_IDAT=allocate([73,68,65,84,0] /* IDAT\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str135233=allocate([78,111,116,32,101,110,111,117,103,104,32,105,109,97,103,101,32,100,97,116,97,0] /* Not enough image dat */, "i8", ALLOC_STATIC);
STRING_TABLE.__str136=allocate([69,120,116,114,97,32,99,111,109,112,114,101,115,115,101,100,32,100,97,116,97,0] /* Extra compressed dat */, "i8", ALLOC_STATIC);
STRING_TABLE.__str137=allocate([68,101,99,111,109,112,114,101,115,115,105,111,110,32,69,114,114,111,114,0] /* Decompression Error\ */, "i8", ALLOC_STATIC);
STRING_TABLE.__str138=allocate([69,120,116,114,97,32,99,111,109,112,114,101,115,115,105,111,110,32,100,97,116,97,0] /* Extra compression da */, "i8", ALLOC_STATIC);
_png_read_start_row_png_pass_start=allocate([0, 0, 0, 0, 4, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0], ["i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0], ALLOC_STATIC);
_png_read_start_row_png_pass_inc=allocate([8, 0, 0, 0, 8, 0, 0, 0, 4, 0, 0, 0, 4, 0, 0, 0, 2, 0, 0, 0, 2, 0, 0, 0, 1, 0, 0, 0], ["i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0], ALLOC_STATIC);
_png_read_start_row_png_pass_ystart=allocate([0, 0, 0, 0, 0, 0, 0, 0, 4, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0], ["i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0], ALLOC_STATIC);
_png_read_start_row_png_pass_yinc=allocate([8, 0, 0, 0, 8, 0, 0, 0, 8, 0, 0, 0, 4, 0, 0, 0, 4, 0, 0, 0, 2, 0, 0, 0, 2, 0, 0, 0], ["i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0,"i32",0,0,0], ALLOC_STATIC);
STRING_TABLE.__str139=allocate([82,111,119,32,104,97,115,32,116,111,111,32,109,97,110,121,32,98,121,116,101,115,32,116,111,32,97,108,108,111,99,97,116,101,32,105,110,32,109,101,109,111,114,121,0] /* Row has too many byt */, "i8", ALLOC_STATIC);
STRING_TABLE.__str140=allocate([66,117,102,102,101,114,32,101,114,114,111,114,32,105,110,32,99,111,109,112,114,101,115,115,101,100,32,100,97,116,97,115,116,114,101,97,109,32,105,110,32,37,115,32,99,104,117,110,107,0] /* Buffer error in comp */, "i8", ALLOC_STATIC);
STRING_TABLE.__str141=allocate([68,97,116,97,32,101,114,114,111,114,32,105,110,32,99,111,109,112,114,101,115,115,101,100,32,100,97,116,97,115,116,114,101,97,109,32,105,110,32,37,115,32,99,104,117,110,107,0] /* Data error in compre */, "i8", ALLOC_STATIC);
STRING_TABLE.__str142=allocate([73,110,99,111,109,112,108,101,116,101,32,99,111,109,112,114,101,115,115,101,100,32,100,97,116,97,115,116,114,101,97,109,32,105,110,32,37,115,32,99,104,117,110,107,0] /* Incomplete compresse */, "i8", ALLOC_STATIC);
STRING_TABLE.__str298=allocate([76,105,109,105,116,105,110,103,32,103,97,109,109,97,32,116,111,32,50,49,52,55,52,46,56,51,0] /* Limiting gamma to 21 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str1299=allocate([83,101,116,116,105,110,103,32,103,97,109,109,97,61,48,0] /* Setting gamma=0\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str2300=allocate([83,101,116,116,105,110,103,32,110,101,103,97,116,105,118,101,32,103,97,109,109,97,32,116,111,32,122,101,114,111,0] /* Setting negative gam */, "i8", ALLOC_STATIC);
STRING_TABLE.__str3301=allocate([73,110,118,97,108,105,100,32,112,97,108,101,116,116,101,32,115,105,122,101,44,32,104,73,83,84,32,97,108,108,111,99,97,116,105,111,110,32,115,107,105,112,112,101,100,0] /* Invalid palette size */, "i8", ALLOC_STATIC);
STRING_TABLE.__str4302=allocate([73,110,115,117,102,102,105,99,105,101,110,116,32,109,101,109,111,114,121,32,102,111,114,32,104,73,83,84,32,99,104,117,110,107,32,100,97,116,97,0] /* Insufficient memory  */, "i8", ALLOC_STATIC);
STRING_TABLE.__str5303=allocate([73,110,115,117,102,102,105,99,105,101,110,116,32,109,101,109,111,114,121,32,102,111,114,32,112,67,65,76,32,112,117,114,112,111,115,101,0] /* Insufficient memory  */, "i8", ALLOC_STATIC);
STRING_TABLE.__str6304=allocate([73,110,115,117,102,102,105,99,105,101,110,116,32,109,101,109,111,114,121,32,102,111,114,32,112,67,65,76,32,117,110,105,116,115,0] /* Insufficient memory  */, "i8", ALLOC_STATIC);
STRING_TABLE.__str7305=allocate([73,110,115,117,102,102,105,99,105,101,110,116,32,109,101,109,111,114,121,32,102,111,114,32,112,67,65,76,32,112,97,114,97,109,115,0] /* Insufficient memory  */, "i8", ALLOC_STATIC);
STRING_TABLE.__str8306=allocate([73,110,115,117,102,102,105,99,105,101,110,116,32,109,101,109,111,114,121,32,102,111,114,32,112,67,65,76,32,112,97,114,97,109,101,116,101,114,0] /* Insufficient memory  */, "i8", ALLOC_STATIC);
STRING_TABLE.__str9307=allocate([73,110,118,97,108,105,100,32,112,97,108,101,116,116,101,32,108,101,110,103,116,104,0] /* Invalid palette leng */, "i8", ALLOC_STATIC);
STRING_TABLE.__str10308=allocate([73,110,115,117,102,102,105,99,105,101,110,116,32,109,101,109,111,114,121,32,116,111,32,112,114,111,99,101,115,115,32,105,67,67,80,32,99,104,117,110,107,0] /* Insufficient memory  */, "i8", ALLOC_STATIC);
STRING_TABLE.__str11309=allocate([73,110,115,117,102,102,105,99,105,101,110,116,32,109,101,109,111,114,121,32,116,111,32,112,114,111,99,101,115,115,32,105,67,67,80,32,112,114,111,102,105,108,101,0] /* Insufficient memory  */, "i8", ALLOC_STATIC);
STRING_TABLE.__str13311=allocate([116,101,120,116,32,99,111,109,112,114,101,115,115,105,111,110,32,109,111,100,101,32,105,115,32,111,117,116,32,111,102,32,114,97,110,103,101,0] /* text compression mod */, "i8", ALLOC_STATIC);
STRING_TABLE.__str14312=allocate([116,82,78,83,32,99,104,117,110,107,32,104,97,115,32,111,117,116,45,111,102,45,114,97,110,103,101,32,115,97,109,112,108,101,115,32,102,111,114,32,98,105,116,95,100,101,112,116,104,0] /* tRNS chunk has out-o */, "i8", ALLOC_STATIC);
STRING_TABLE.__str15313=allocate([78,111,32,109,101,109,111,114,121,32,102,111,114,32,115,80,76,84,32,112,97,108,101,116,116,101,115,0] /* No memory for sPLT p */, "i8", ALLOC_STATIC);
STRING_TABLE.__str16314=allocate([79,117,116,32,111,102,32,109,101,109,111,114,121,32,119,104,105,108,101,32,112,114,111,99,101,115,115,105,110,103,32,115,80,76,84,32,99,104,117,110,107,0] /* Out of memory while  */, "i8", ALLOC_STATIC);
STRING_TABLE.__str17315=allocate([79,117,116,32,111,102,32,109,101,109,111,114,121,32,119,104,105,108,101,32,112,114,111,99,101,115,115,105,110,103,32,117,110,107,110,111,119,110,32,99,104,117,110,107,0] /* Out of memory while  */, "i8", ALLOC_STATIC);
STRING_TABLE._onebppswaptable=allocate([0,128,64,192,32,160,96,224,16,144,80,208,48,176,112,240,8,136,72,200,40,168,104,232,24,152,88,216,56,184,120,248,4,132,68,196,36,164,100,228,20,148,84,212,52,180,116,244,12,140,76,204,44,172,108,236,28,156,92,220,60,188,124,252,2,130,66,194,34,162,98,226,18,146,82,210,50,178,114,242,10,138,74,202,42,170,106,234,26,154,90,218,58,186,122,250,6,134,70,198,38,166,102,230,22,150,86,214,54,182,118,246,14,142,78,206,46,174,110,238,30,158,94,222,62,190,126,254,1,129,65,193,33,161,97,225,17,145,81,209,49,177,113,241,9,137,73,201,41,169,105,233,25,153,89,217,57,185,121,249,5,133,69,197,37,165,101,229,21,149,85,213,53,181,117,245,13,141,77,205,45,173,109,237,29,157,93,221,61,189,125,253,3,131,67,195,35,163,99,227,19,147,83,211,51,179,115,243,11,139,75,203,43,171,107,235,27,155,91,219,59,187,123,251,7,135,71,199,39,167,103,231,23,151,87,215,55,183,119,247,15,143,79,207,47,175,111,239,31,159,95,223,63,191,127,255] /* \00\80@\C0 \A0`\E0\1 */, "i8", ALLOC_STATIC);
STRING_TABLE._twobppswaptable=allocate([0,64,128,192,16,80,144,208,32,96,160,224,48,112,176,240,4,68,132,196,20,84,148,212,36,100,164,228,52,116,180,244,8,72,136,200,24,88,152,216,40,104,168,232,56,120,184,248,12,76,140,204,28,92,156,220,44,108,172,236,60,124,188,252,1,65,129,193,17,81,145,209,33,97,161,225,49,113,177,241,5,69,133,197,21,85,149,213,37,101,165,229,53,117,181,245,9,73,137,201,25,89,153,217,41,105,169,233,57,121,185,249,13,77,141,205,29,93,157,221,45,109,173,237,61,125,189,253,2,66,130,194,18,82,146,210,34,98,162,226,50,114,178,242,6,70,134,198,22,86,150,214,38,102,166,230,54,118,182,246,10,74,138,202,26,90,154,218,42,106,170,234,58,122,186,250,14,78,142,206,30,94,158,222,46,110,174,238,62,126,190,254,3,67,131,195,19,83,147,211,35,99,163,227,51,115,179,243,7,71,135,199,23,87,151,215,39,103,167,231,55,119,183,247,11,75,139,203,27,91,155,219,43,107,171,235,59,123,187,251,15,79,143,207,31,95,159,223,47,111,175,239,63,127,191,255] /* \00@\80\C0\10P\90\D0 */, "i8", ALLOC_STATIC);
STRING_TABLE._fourbppswaptable=allocate([0,16,32,48,64,80,96,112,128,144,160,176,192,208,224,240,1,17,33,49,65,81,97,113,129,145,161,177,193,209,225,241,2,18,34,50,66,82,98,114,130,146,162,178,194,210,226,242,3,19,35,51,67,83,99,115,131,147,163,179,195,211,227,243,4,20,36,52,68,84,100,116,132,148,164,180,196,212,228,244,5,21,37,53,69,85,101,117,133,149,165,181,197,213,229,245,6,22,38,54,70,86,102,118,134,150,166,182,198,214,230,246,7,23,39,55,71,87,103,119,135,151,167,183,199,215,231,247,8,24,40,56,72,88,104,120,136,152,168,184,200,216,232,248,9,25,41,57,73,89,105,121,137,153,169,185,201,217,233,249,10,26,42,58,74,90,106,122,138,154,170,186,202,218,234,250,11,27,43,59,75,91,107,123,139,155,171,187,203,219,235,251,12,28,44,60,76,92,108,124,140,156,172,188,204,220,236,252,13,29,45,61,77,93,109,125,141,157,173,189,205,221,237,253,14,30,46,62,78,94,110,126,142,158,174,190,206,222,238,254,15,31,47,63,79,95,111,127,143,159,175,191,207,223,239,255] /* \00\10 0@P`p\80\90\A */, "i8", ALLOC_STATIC);
STRING_TABLE.__str510=allocate([82,101,99,116,0] /* Rect\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str1511=allocate([84,121,112,101,0] /* Type\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str2512=allocate([65,110,110,111,116,0] /* Annot\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str3513=allocate([83,117,98,116,121,112,101,0] /* Subtype\00 */, "i8", ALLOC_STATIC);
_HPDF_ANNOT_TYPE_NAMES=allocate(56, "i8", ALLOC_STATIC);
STRING_TABLE.__str6516=allocate([66,111,114,100,101,114,0] /* Border\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str7517=allocate([83,0] /* S\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str12522=allocate([68,101,115,116,0] /* Dest\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str13523=allocate([65,0] /* A\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str14524=allocate([65,99,116,105,111,110,0] /* Action\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str15525=allocate([85,82,73,0] /* URI\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str16526=allocate([72,0] /* H\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str17527=allocate([78,0] /* N\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str18528=allocate([79,0] /* O\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str19529=allocate([80,0] /* P\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str20530=allocate([67,111,110,116,101,110,116,115,0] /* Contents\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str21531=allocate([51,68,32,77,111,100,101,108,0] /* 3D Model\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str22532=allocate([51,68,65,0] /* 3DA\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str23533=allocate([80,86,0] /* PV\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str24534=allocate([84,66,0] /* TB\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str25535=allocate([51,68,68,0] /* 3DD\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str26536=allocate([65,80,0] /* AP\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str27537=allocate([78,97,109,101,0] /* Name\00 */, "i8", ALLOC_STATIC);
_HPDF_ANNOT_ICON_NAMES_NAMES=allocate(28, "i8", ALLOC_STATIC);
STRING_TABLE.__str28538=allocate([79,112,101,110,0] /* Open\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str29539=allocate([67,111,109,109,101,110,116,0] /* Comment\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str30540=allocate([75,101,121,0] /* Key\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str31541=allocate([78,111,116,101,0] /* Note\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str32542=allocate([72,101,108,112,0] /* Help\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str33543=allocate([78,101,119,80,97,114,97,103,114,97,112,104,0] /* NewParagraph\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str34544=allocate([80,97,114,97,103,114,97,112,104,0] /* Paragraph\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str35545=allocate([73,110,115,101,114,116,0] /* Insert\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str36546=allocate([84,101,120,116,0] /* Text\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str37547=allocate([76,105,110,107,0] /* Link\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str38548=allocate([83,111,117,110,100,0] /* Sound\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str39549=allocate([70,114,101,101,84,101,120,116,0] /* FreeText\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str40550=allocate([83,116,97,109,112,0] /* Stamp\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str41551=allocate([83,113,117,97,114,101,0] /* Square\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str42552=allocate([67,105,114,99,108,101,0] /* Circle\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str43553=allocate([83,116,114,105,107,101,79,117,116,0] /* StrikeOut\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str44554=allocate([72,105,103,104,108,105,103,104,116,0] /* Highlight\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str45555=allocate([85,110,100,101,114,108,105,110,101,0] /* Underline\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str46556=allocate([73,110,107,0] /* Ink\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str47557=allocate([70,105,108,101,65,116,116,97,99,104,109,101,110,116,0] /* FileAttachment\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str48558=allocate([80,111,112,117,112,0] /* Popup\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str49559=allocate([51,68,0] /* 3D\00 */, "i8", ALLOC_STATIC);
_llvm_used=allocate([262, 0, 0, 0, 264, 0, 0, 0, 266, 0, 0, 0, 268, 0, 0, 0, 270, 0, 0, 0, 272, 0, 0, 0, 274, 0, 0, 0, 276, 0, 0, 0, 278, 0, 0, 0, 280, 0, 0, 0, 282, 0, 0, 0, 284, 0, 0, 0, 286, 0, 0, 0, 288, 0, 0, 0, 290, 0, 0, 0, 292, 0, 0, 0, 294, 0, 0, 0, 296, 0, 0, 0, 298, 0, 0, 0, 300, 0, 0, 0, 302, 0, 0, 0, 304, 0, 0, 0, 306, 0, 0, 0, 308, 0, 0, 0, 310, 0, 0, 0, 312, 0, 0, 0, 314, 0, 0, 0, 316, 0, 0, 0, 318, 0, 0, 0, 320, 0, 0, 0, 322, 0, 0, 0, 324, 0, 0, 0, 326, 0, 0, 0, 328, 0, 0, 0, 330, 0, 0, 0, 332, 0, 0, 0, 334, 0, 0, 0, 336, 0, 0, 0, 338, 0, 0, 0, 340, 0, 0, 0, 342, 0, 0, 0, 344, 0, 0, 0, 346, 0, 0, 0, 348, 0, 0, 0, 350, 0, 0, 0, 352, 0, 0, 0, 354, 0, 0, 0, 356, 0, 0, 0, 358, 0, 0, 0, 360, 0, 0, 0, 362, 0, 0, 0, 364, 0, 0, 0, 366, 0, 0, 0, 368, 0, 0, 0, 370, 0, 0, 0, 372, 0, 0, 0, 374, 0, 0, 0, 376, 0, 0, 0, 378, 0, 0, 0, 380, 0, 0, 0, 382, 0, 0, 0, 384, 0, 0, 0, 386, 0, 0, 0, 388, 0, 0, 0, 390, 0, 0, 0, 392, 0, 0, 0, 394, 0, 0, 0, 396, 0, 0, 0, 398, 0, 0, 0, 400, 0, 0, 0, 402, 0, 0, 0, 404, 0, 0, 0, 406, 0, 0, 0, 408, 0, 0, 0, 410, 0, 0, 0, 412, 0, 0, 0, 414, 0, 0, 0, 416, 0, 0, 0, 418, 0, 0, 0, 420, 0, 0, 0, 422, 0, 0, 0, 424, 0, 0, 0, 426, 0, 0, 0, 428, 0, 0, 0, 430, 0, 0, 0, 432, 0, 0, 0, 434, 0, 0, 0, 436, 0, 0, 0, 438, 0, 0, 0, 440, 0, 0, 0, 442, 0, 0, 0, 444, 0, 0, 0, 446, 0, 0, 0, 448, 0, 0, 0, 450, 0, 0, 0, 452, 0, 0, 0, 454, 0, 0, 0, 456, 0, 0, 0, 458, 0, 0, 0, 460, 0, 0, 0, 462, 0, 0, 0, 464, 0, 0, 0, 466, 0, 0, 0, 468, 0, 0, 0, 470, 0, 0, 0, 472, 0, 0, 0, 474, 0, 0, 0, 476, 0, 0, 0, 478, 0, 0, 0, 480, 0, 0, 0, 482, 0, 0, 0, 484, 0, 0, 0, 486, 0, 0, 0, 488, 0, 0, 0, 490, 0, 0, 0, 492, 0, 0, 0, 494, 0, 0, 0, 496, 0, 0, 0, 498, 0, 0, 0, 500, 0, 0, 0, 502, 0, 0, 0, 504, 0, 0, 0, 506, 0, 0, 0, 508, 0, 0, 0, 510, 0, 0, 0, 512, 0, 0, 0, 514, 0, 0, 0, 516, 0, 0, 0, 518, 0, 0, 0, 520, 0, 0, 0, 522, 0, 0, 0, 524, 0, 0, 0, 526, 0, 0, 0, 528, 0, 0, 0, 530, 0, 0, 0, 532, 0, 0, 0, 534, 0, 0, 0, 536, 0, 0, 0, 538, 0, 0, 0, 540, 0, 0, 0, 542, 0, 0, 0, 544, 0, 0, 0, 546, 0, 0, 0, 548, 0, 0, 0, 550, 0, 0, 0, 552, 0, 0, 0, 554, 0, 0, 0, 556, 0, 0, 0, 558, 0, 0, 0, 560, 0, 0, 0, 562, 0, 0, 0, 564, 0, 0, 0, 566, 0, 0, 0, 568, 0, 0, 0, 570, 0, 0, 0, 572, 0, 0, 0, 574, 0, 0, 0, 576, 0, 0, 0, 578, 0, 0, 0, 580, 0, 0, 0, 582, 0, 0, 0, 584, 0, 0, 0, 586, 0, 0, 0, 588, 0, 0, 0, 590, 0, 0, 0, 592, 0, 0, 0, 594, 0, 0, 0, 596, 0, 0, 0, 598, 0, 0, 0, 600, 0, 0, 0, 602, 0, 0, 0, 604, 0, 0, 0, 606, 0, 0, 0, 608, 0, 0, 0, 610, 0, 0, 0, 612, 0, 0, 0, 614, 0, 0, 0, 616, 0, 0, 0, 618, 0, 0, 0, 620, 0, 0, 0, 622, 0, 0, 0, 624, 0, 0, 0, 626, 0, 0, 0, 628, 0, 0, 0, 630, 0, 0, 0, 632, 0, 0, 0, 634, 0, 0, 0, 636, 0, 0, 0, 638, 0, 0, 0, 640, 0, 0, 0, 642, 0, 0, 0, 644, 0, 0, 0, 646, 0, 0, 0, 648, 0, 0, 0, 650, 0, 0, 0, 652, 0, 0, 0, 654, 0, 0, 0, 656, 0, 0, 0, 658, 0, 0, 0, 660, 0, 0, 0, 662, 0, 0, 0, 664, 0, 0, 0, 666, 0, 0, 0, 668, 0, 0, 0, 670, 0, 0, 0, 672, 0, 0, 0, 674, 0, 0, 0, 676, 0, 0, 0, 678, 0, 0, 0, 680, 0, 0, 0, 682, 0, 0, 0, 684, 0, 0, 0, 686, 0, 0, 0, 688, 0, 0, 0, 690, 0, 0, 0, 692, 0, 0, 0, 694, 0, 0, 0, 696, 0, 0, 0, 698, 0, 0, 0], ["*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0,"*",0,0,0], ALLOC_STATIC);
STRING_TABLE.__str560=allocate([91,32,0] /* [ \00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str569=allocate([60,62,0] /* __\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str570=allocate([116,114,117,101,0] /* true\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str1571=allocate([102,97,108,115,101,0] /* false\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str574=allocate([84,121,112,101,0] /* Type\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str1575=allocate([67,97,116,97,108,111,103,0] /* Catalog\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str2576=allocate([80,97,103,101,115,0] /* Pages\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str3577=allocate([80,97,103,101,76,97,121,111,117,116,0] /* PageLayout\00 */, "i8", ALLOC_STATIC);
_HPDF_PAGE_LAYOUT_NAMES=allocate(20, "i8", ALLOC_STATIC);
STRING_TABLE.__str4578=allocate([80,97,103,101,77,111,100,101,0] /* PageMode\00 */, "i8", ALLOC_STATIC);
_HPDF_PAGE_MODE_NAMES=allocate(28, "i8", ALLOC_STATIC);
STRING_TABLE.__str5579=allocate([79,112,101,110,65,99,116,105,111,110,0] /* OpenAction\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str6580=allocate([80,97,103,101,76,97,98,101,108,115,0] /* PageLabels\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str7581=allocate([78,117,109,115,0] /* Nums\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str8582=allocate([86,105,101,119,101,114,80,114,101,102,101,114,101,110,99,101,115,0] /* ViewerPreferences\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str9583=allocate([72,105,100,101,84,111,111,108,98,97,114,0] /* HideToolbar\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str10584=allocate([72,105,100,101,77,101,110,117,98,97,114,0] /* HideMenubar\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str11585=allocate([72,105,100,101,87,105,110,100,111,119,85,73,0] /* HideWindowUI\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str12586=allocate([70,105,116,87,105,110,100,111,119,0] /* FitWindow\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str13587=allocate([67,101,110,116,101,114,87,105,110,100,111,119,0] /* CenterWindow\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str14588=allocate([85,115,101,78,111,110,101,0] /* UseNone\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str15589=allocate([85,115,101,79,117,116,108,105,110,101,115,0] /* UseOutlines\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str16590=allocate([85,115,101,84,104,117,109,98,115,0] /* UseThumbs\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str17591=allocate([70,117,108,108,83,99,114,101,101,110,0] /* FullScreen\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str18592=allocate([85,115,101,79,67,0] /* UseOC\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str19593=allocate([85,115,101,65,116,116,97,99,104,109,101,110,116,115,0] /* UseAttachments\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str20594=allocate([83,105,110,103,108,101,80,97,103,101,0] /* SinglePage\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str21595=allocate([79,110,101,67,111,108,117,109,110,0] /* OneColumn\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str22596=allocate([84,119,111,67,111,108,117,109,110,76,101,102,116,0] /* TwoColumnLeft\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str23597=allocate([84,119,111,67,111,108,117,109,110,82,105,103,104,116,0] /* TwoColumnRight\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str598=allocate([88,89,90,0] /* XYZ\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str1599=allocate([70,105,116,0] /* Fit\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str2600=allocate([70,105,116,72,0] /* FitH\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str3601=allocate([70,105,116,86,0] /* FitV\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str4602=allocate([70,105,116,82,0] /* FitR\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str5603=allocate([70,105,116,66,0] /* FitB\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str6604=allocate([70,105,116,66,72,0] /* FitBH\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str7605=allocate([70,105,116,66,86,0] /* FitBV\00 */, "i8", ALLOC_STATIC);
_HPDF_DESTINATION_TYPE_NAMES=allocate(36, "i8", ALLOC_STATIC);
STRING_TABLE.__str607=allocate([76,101,110,103,116,104,0] /* Length\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str1608=allocate([60,60,10,0] /* __\0A\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str2609=allocate([70,105,108,116,101,114,0] /* Filter\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str3610=allocate([70,108,97,116,101,68,101,99,111,100,101,0] /* FlateDecode\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str4611=allocate([68,67,84,68,101,99,111,100,101,0] /* DCTDecode\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str5612=allocate([10,0] /* \0A\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str6613=allocate([62,62,0] /* __\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str7614=allocate([10,115,116,114,101,97,109,10,0] /* \0Astream\0A\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str8615=allocate([10,101,110,100,115,116,114,101,97,109,0] /* \0Aendstream\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str630=allocate([50,46,50,46,48,0] /* 2.2.0\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str1631=allocate([72,97,114,117,32,70,114,101,101,32,80,68,70,32,76,105,98,114,97,114,121,32,0] /* Haru Free PDF Librar */, "i8", ALLOC_STATIC);
STRING_TABLE.__str2632=allocate([69,110,99,114,121,112,116,0] /* Encrypt\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str3633=allocate([73,68,0] /* ID\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str4634=allocate([70,111,110,116,83,112,101,99,105,102,105,99,0] /* FontSpecific\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str5635=allocate([83,116,97,110,100,97,114,100,69,110,99,111,100,105,110,103,0] /* StandardEncoding\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str6636=allocate([79,117,116,108,105,110,101,115,0] /* Outlines\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str7637=allocate([72,80,68,70,65,65,0] /* HPDFAA\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str8638=allocate([82,111,111,116,0] /* Root\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str9639=allocate([73,110,102,111,0] /* Info\00 */, "i8", ALLOC_STATIC);
_HPDF_VERSION_STR=allocate(24, "i8", ALLOC_STATIC);
STRING_TABLE.__str10640=allocate([37,80,68,70,45,49,46,50,10,37,183,190,173,170,10,0] /* %PDF-1.2\0A%\B7\BE\A */, "i8", ALLOC_STATIC);
STRING_TABLE.__str11641=allocate([37,80,68,70,45,49,46,51,10,37,183,190,173,170,10,0] /* %PDF-1.3\0A%\B7\BE\A */, "i8", ALLOC_STATIC);
STRING_TABLE.__str12642=allocate([37,80,68,70,45,49,46,52,10,37,183,190,173,170,10,0] /* %PDF-1.4\0A%\B7\BE\A */, "i8", ALLOC_STATIC);
STRING_TABLE.__str13643=allocate([37,80,68,70,45,49,46,53,10,37,183,190,173,170,10,0] /* %PDF-1.5\0A%\B7\BE\A */, "i8", ALLOC_STATIC);
STRING_TABLE.__str14644=allocate([37,80,68,70,45,49,46,54,10,37,183,190,173,170,10,0] /* %PDF-1.6\0A%\B7\BE\A */, "i8", ALLOC_STATIC);
STRING_TABLE.__str15645=allocate([37,80,68,70,45,49,46,55,10,37,183,190,173,170,10,0] /* %PDF-1.7\0A%\B7\BE\A */, "i8", ALLOC_STATIC);
STRING_TABLE.__str647=allocate([95,70,73,76,69,95,78,65,77,69,0] /* _FILE_NAME\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str649=allocate([83,116,97,110,100,97,114,100,69,110,99,111,100,105,110,103,0] /* StandardEncoding\00 */, "i8", ALLOC_STATIC);
_HPDF_UNICODE_MAP_STANDARD=allocate([32, 0, 33, 0, 34, 0, 35, 0, 36, 0, 37, 0, 38, 0, 8217, 0, 40, 0, 41, 0, 42, 0, 43, 0, 44, 0, 45, 0, 46, 0, 47, 0, 48, 0, 49, 0, 50, 0, 51, 0, 52, 0, 53, 0, 54, 0, 55, 0, 56, 0, 57, 0, 58, 0, 59, 0, 60, 0, 61, 0, 62, 0, 63, 0, 64, 0, 65, 0, 66, 0, 67, 0, 68, 0, 69, 0, 70, 0, 71, 0, 72, 0, 73, 0, 74, 0, 75, 0, 76, 0, 77, 0, 78, 0, 79, 0, 80, 0, 81, 0, 82, 0, 83, 0, 84, 0, 85, 0, 86, 0, 87, 0, 88, 0, 89, 0, 90, 0, 91, 0, 92, 0, 93, 0, 94, 0, 95, 0, 8216, 0, 97, 0, 98, 0, 99, 0, 100, 0, 101, 0, 102, 0, 103, 0, 104, 0, 105, 0, 106, 0, 107, 0, 108, 0, 109, 0, 110, 0, 111, 0, 112, 0, 113, 0, 114, 0, 115, 0, 116, 0, 117, 0, 118, 0, 119, 0, 120, 0, 121, 0, 122, 0, 123, 0, 124, 0, 125, 0, 126, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 209, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 161, 0, 162, 0, 163, 0, 8260, 0, 165, 0, 402, 0, 167, 0, 164, 0, 39, 0, 8220, 0, 171, 0, 8249, 0, 8250, 0, -1279, 0, -1278, 0, 0, 0, 8211, 0, 8224, 0, 8225, 0, 183, 0, 0, 0, 182, 0, 8226, 0, 8218, 0, 8222, 0, 8221, 0, 187, 0, 8230, 0, 8240, 0, 0, 0, 191, 0, 0, 0, 96, 0, 180, 0, 710, 0, 732, 0, 175, 0, 728, 0, 729, 0, 168, 0, 0, 0, 730, 0, 184, 0, 0, 0, 733, 0, 731, 0, 711, 0, 8212, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 198, 0, 0, 0, 170, 0, 0, 0, 0, 0, 0, 0, 0, 0, 321, 0, 216, 0, 338, 0, 186, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 230, 0, 0, 0, 0, 0, 0, 0, 305, 0, 0, 0, 0, 0, 322, 0, 248, 0, 339, 0, 223, 0, 0, 0, 0, 0, 0, 0, 0, 0], ["i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0], ALLOC_STATIC);
STRING_TABLE.__str1650=allocate([87,105,110,65,110,115,105,69,110,99,111,100,105,110,103,0] /* WinAnsiEncoding\00 */, "i8", ALLOC_STATIC);
_HPDF_UNICODE_MAP_WIN_ANSI=allocate([32, 0, 33, 0, 34, 0, 35, 0, 36, 0, 37, 0, 38, 0, 39, 0, 40, 0, 41, 0, 42, 0, 43, 0, 44, 0, 45, 0, 46, 0, 47, 0, 48, 0, 49, 0, 50, 0, 51, 0, 52, 0, 53, 0, 54, 0, 55, 0, 56, 0, 57, 0, 58, 0, 59, 0, 60, 0, 61, 0, 62, 0, 63, 0, 64, 0, 65, 0, 66, 0, 67, 0, 68, 0, 69, 0, 70, 0, 71, 0, 72, 0, 73, 0, 74, 0, 75, 0, 76, 0, 77, 0, 78, 0, 79, 0, 80, 0, 81, 0, 82, 0, 83, 0, 84, 0, 85, 0, 86, 0, 87, 0, 88, 0, 89, 0, 90, 0, 91, 0, 92, 0, 93, 0, 94, 0, 95, 0, 96, 0, 97, 0, 98, 0, 99, 0, 100, 0, 101, 0, 102, 0, 103, 0, 104, 0, 105, 0, 106, 0, 107, 0, 108, 0, 109, 0, 110, 0, 111, 0, 112, 0, 113, 0, 114, 0, 115, 0, 116, 0, 117, 0, 118, 0, 119, 0, 120, 0, 121, 0, 122, 0, 123, 0, 124, 0, 125, 0, 126, 0, 0, 0, 8364, 0, 0, 0, 8218, 0, 402, 0, 8222, 0, 8230, 0, 8224, 0, 8225, 0, 710, 0, 8240, 0, 352, 0, 8249, 0, 338, 0, 0, 0, 381, 0, 0, 0, 0, 0, 8216, 0, 8217, 0, 8220, 0, 8221, 0, 8226, 0, 8211, 0, 8212, 0, 732, 0, 8482, 0, 353, 0, 8250, 0, 339, 0, 0, 0, 382, 0, 376, 0, 0, 0, 161, 0, 162, 0, 163, 0, 164, 0, 165, 0, 166, 0, 167, 0, 168, 0, 169, 0, 170, 0, 171, 0, 172, 0, 0, 0, 174, 0, 175, 0, 730, 0, 177, 0, 178, 0, 179, 0, 180, 0, 181, 0, 182, 0, 183, 0, 184, 0, 185, 0, 186, 0, 187, 0, 188, 0, 189, 0, 190, 0, 191, 0, 192, 0, 193, 0, 194, 0, 195, 0, 196, 0, 197, 0, 198, 0, 199, 0, 200, 0, 201, 0, 202, 0, 203, 0, 204, 0, 205, 0, 206, 0, 207, 0, 208, 0, 209, 0, 210, 0, 211, 0, 212, 0, 213, 0, 214, 0, 215, 0, 216, 0, 217, 0, 218, 0, 219, 0, 220, 0, 221, 0, 222, 0, 223, 0, 224, 0, 225, 0, 226, 0, 227, 0, 228, 0, 229, 0, 230, 0, 231, 0, 232, 0, 233, 0, 234, 0, 235, 0, 236, 0, 237, 0, 238, 0, 239, 0, 240, 0, 241, 0, 242, 0, 243, 0, 244, 0, 245, 0, 246, 0, 247, 0, 248, 0, 249, 0, 250, 0, 251, 0, 252, 0, 253, 0, 254, 0, 255, 0], ["i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0], ALLOC_STATIC);
STRING_TABLE.__str2651=allocate([77,97,99,82,111,109,97,110,69,110,99,111,100,105,110,103,0] /* MacRomanEncoding\00 */, "i8", ALLOC_STATIC);
_HPDF_UNICODE_MAP_MAC_ROMAN=allocate([32, 0, 33, 0, 34, 0, 35, 0, 36, 0, 37, 0, 38, 0, 39, 0, 40, 0, 41, 0, 42, 0, 43, 0, 44, 0, 45, 0, 46, 0, 47, 0, 48, 0, 49, 0, 50, 0, 51, 0, 52, 0, 53, 0, 54, 0, 55, 0, 56, 0, 57, 0, 58, 0, 59, 0, 60, 0, 61, 0, 62, 0, 63, 0, 64, 0, 65, 0, 66, 0, 67, 0, 68, 0, 69, 0, 70, 0, 71, 0, 72, 0, 73, 0, 74, 0, 75, 0, 76, 0, 77, 0, 78, 0, 79, 0, 80, 0, 81, 0, 82, 0, 83, 0, 84, 0, 85, 0, 86, 0, 87, 0, 88, 0, 89, 0, 90, 0, 91, 0, 92, 0, 93, 0, 94, 0, 95, 0, 96, 0, 97, 0, 98, 0, 99, 0, 100, 0, 101, 0, 102, 0, 103, 0, 104, 0, 105, 0, 106, 0, 107, 0, 108, 0, 109, 0, 110, 0, 111, 0, 112, 0, 113, 0, 114, 0, 115, 0, 116, 0, 117, 0, 118, 0, 119, 0, 120, 0, 121, 0, 122, 0, 123, 0, 124, 0, 125, 0, 126, 0, 0, 0, 196, 0, 197, 0, 199, 0, 201, 0, 0, 0, 214, 0, 220, 0, 225, 0, 224, 0, 226, 0, 228, 0, 227, 0, 229, 0, 231, 0, 233, 0, 232, 0, 234, 0, 235, 0, 237, 0, 236, 0, 238, 0, 239, 0, 241, 0, 243, 0, 242, 0, 244, 0, 246, 0, 245, 0, 250, 0, 249, 0, 251, 0, 252, 0, 8224, 0, 176, 0, 162, 0, 163, 0, 167, 0, 8226, 0, 182, 0, 223, 0, 174, 0, 169, 0, 8482, 0, 180, 0, 168, 0, 0, 0, 198, 0, 216, 0, 0, 0, 177, 0, 0, 0, 0, 0, 165, 0, 181, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 170, 0, 186, 0, 0, 0, 230, 0, 248, 0, 191, 0, 161, 0, 172, 0, 0, 0, 402, 0, 0, 0, 0, 0, 171, 0, 187, 0, 8230, 0, 32, 0, 192, 0, 195, 0, 213, 0, 338, 0, 339, 0, 8211, 0, 8212, 0, 8220, 0, 8221, 0, 8216, 0, 8217, 0, 247, 0, 0, 0, 255, 0, 376, 0, 8260, 0, 164, 0, 8249, 0, 8250, 0, -1279, 0, -1278, 0, 8225, 0, 183, 0, 8218, 0, 8222, 0, 8240, 0, 194, 0, 202, 0, 193, 0, 203, 0, 200, 0, 205, 0, 206, 0, 207, 0, 204, 0, 211, 0, 212, 0, 0, 0, 210, 0, 218, 0, 219, 0, 217, 0, 305, 0, 710, 0, 732, 0, 175, 0, 728, 0, 729, 0, 730, 0, 184, 0, 733, 0, 731, 0, 711, 0], ["i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0], ALLOC_STATIC);
STRING_TABLE.__str3652=allocate([70,111,110,116,83,112,101,99,105,102,105,99,0] /* FontSpecific\00 */, "i8", ALLOC_STATIC);
_HPDF_UNICODE_MAP_FONT_SPECIFIC=allocate([32, 0, 33, 0, 34, 0, 35, 0, 36, 0, 37, 0, 38, 0, 39, 0, 40, 0, 41, 0, 42, 0, 43, 0, 44, 0, 45, 0, 46, 0, 47, 0, 48, 0, 49, 0, 50, 0, 51, 0, 52, 0, 53, 0, 54, 0, 55, 0, 56, 0, 57, 0, 58, 0, 59, 0, 60, 0, 61, 0, 62, 0, 63, 0, 64, 0, 65, 0, 66, 0, 67, 0, 68, 0, 69, 0, 70, 0, 71, 0, 72, 0, 73, 0, 74, 0, 75, 0, 76, 0, 77, 0, 78, 0, 79, 0, 80, 0, 81, 0, 82, 0, 83, 0, 84, 0, 85, 0, 86, 0, 87, 0, 88, 0, 89, 0, 90, 0, 91, 0, 92, 0, 93, 0, 94, 0, 95, 0, 96, 0, 97, 0, 98, 0, 99, 0, 100, 0, 101, 0, 102, 0, 103, 0, 104, 0, 105, 0, 106, 0, 107, 0, 108, 0, 109, 0, 110, 0, 111, 0, 112, 0, 113, 0, 114, 0, 115, 0, 116, 0, 117, 0, 118, 0, 119, 0, 120, 0, 121, 0, 122, 0, 123, 0, 124, 0, 125, 0, 126, 0, 127, 0, 128, 0, 129, 0, 130, 0, 131, 0, 132, 0, 133, 0, 134, 0, 135, 0, 136, 0, 137, 0, 138, 0, 139, 0, 140, 0, 141, 0, 142, 0, 143, 0, 144, 0, 145, 0, 146, 0, 147, 0, 148, 0, 149, 0, 150, 0, 151, 0, 152, 0, 153, 0, 154, 0, 155, 0, 156, 0, 157, 0, 158, 0, 159, 0, 160, 0, 161, 0, 162, 0, 163, 0, 164, 0, 165, 0, 166, 0, 167, 0, 168, 0, 169, 0, 170, 0, 171, 0, 172, 0, 173, 0, 174, 0, 175, 0, 176, 0, 177, 0, 178, 0, 179, 0, 180, 0, 181, 0, 182, 0, 183, 0, 184, 0, 185, 0, 186, 0, 187, 0, 188, 0, 189, 0, 190, 0, 191, 0, 192, 0, 193, 0, 194, 0, 195, 0, 196, 0, 197, 0, 198, 0, 199, 0, 200, 0, 201, 0, 202, 0, 203, 0, 204, 0, 205, 0, 206, 0, 207, 0, 208, 0, 209, 0, 210, 0, 211, 0, 212, 0, 213, 0, 214, 0, 215, 0, 216, 0, 217, 0, 218, 0, 219, 0, 220, 0, 221, 0, 222, 0, 223, 0, 224, 0, 225, 0, 226, 0, 227, 0, 228, 0, 229, 0, 230, 0, 231, 0, 232, 0, 233, 0, 234, 0, 235, 0, 236, 0, 237, 0, 238, 0, 239, 0, 240, 0, 241, 0, 242, 0, 243, 0, 244, 0, 245, 0, 246, 0, 247, 0, 248, 0, 249, 0, 250, 0, 251, 0, 252, 0, 253, 0, 254, 0, 255, 0], ["i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0], ALLOC_STATIC);
_HPDF_BUILTIN_ENCODINGS=allocate([0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 4, 0, 0, 0, 0, 0, 0, 0], ["*",0,0,0,"i32",0,0,0,"*",0,0,0,"*",0,0,0,"i32",0,0,0,"*",0,0,0,"*",0,0,0,"i32",0,0,0,"*",0,0,0,"*",0,0,0,"i32",0,0,0,"*",0,0,0,"*",0,0,0,"i32",0,0,0,"*",0,0,0,"*",0,0,0,"i32",0,0,0,"*",0,0,0,"*",0,0,0,"i32",0,0,0,"*",0,0,0,"*",0,0,0,"i32",0,0,0,"*",0,0,0,"*",0,0,0,"i32",0,0,0,"*",0,0,0,"*",0,0,0,"i32",0,0,0,"*",0,0,0,"*",0,0,0,"i32",0,0,0,"*",0,0,0,"*",0,0,0,"i32",0,0,0,"*",0,0,0,"*",0,0,0,"i32",0,0,0,"*",0,0,0,"*",0,0,0,"i32",0,0,0,"*",0,0,0,"*",0,0,0,"i32",0,0,0,"*",0,0,0,"*",0,0,0,"i32",0,0,0,"*",0,0,0,"*",0,0,0,"i32",0,0,0,"*",0,0,0,"*",0,0,0,"i32",0,0,0,"*",0,0,0,"*",0,0,0,"i32",0,0,0,"*",0,0,0,"*",0,0,0,"i32",0,0,0,"*",0,0,0,"*",0,0,0,"i32",0,0,0,"*",0,0,0,"*",0,0,0,"i32",0,0,0,"*",0,0,0,"*",0,0,0,"i32",0,0,0,"*",0,0,0,"*",0,0,0,"i32",0,0,0,"*",0,0,0,"*",0,0,0,"i32",0,0,0,"*",0,0,0,"*",0,0,0,"i32",0,0,0,"*",0,0,0,"*",0,0,0,"i32",0,0,0,"*",0,0,0,"*",0,0,0,"i32",0,0,0,"*",0,0,0,"*",0,0,0,"i32",0,0,0,"*",0,0,0], ALLOC_STATIC);
_HPDF_UNICODE_GRYPH_NAME_MAP=allocate([0, 0, 0, 0, 0, 0, 0, 0, 32, 0, 0, 0, 0, 0, 0, 0, 33, 0, 0, 0, 0, 0, 0, 0, 34, 0, 0, 0, 0, 0, 0, 0, 35, 0, 0, 0, 0, 0, 0, 0, 36, 0, 0, 0, 0, 0, 0, 0, 37, 0, 0, 0, 0, 0, 0, 0, 38, 0, 0, 0, 0, 0, 0, 0, 39, 0, 0, 0, 0, 0, 0, 0, 40, 0, 0, 0, 0, 0, 0, 0, 41, 0, 0, 0, 0, 0, 0, 0, 42, 0, 0, 0, 0, 0, 0, 0, 43, 0, 0, 0, 0, 0, 0, 0, 44, 0, 0, 0, 0, 0, 0, 0, 45, 0, 0, 0, 0, 0, 0, 0, 46, 0, 0, 0, 0, 0, 0, 0, 47, 0, 0, 0, 0, 0, 0, 0, 48, 0, 0, 0, 0, 0, 0, 0, 49, 0, 0, 0, 0, 0, 0, 0, 50, 0, 0, 0, 0, 0, 0, 0, 51, 0, 0, 0, 0, 0, 0, 0, 52, 0, 0, 0, 0, 0, 0, 0, 53, 0, 0, 0, 0, 0, 0, 0, 54, 0, 0, 0, 0, 0, 0, 0, 55, 0, 0, 0, 0, 0, 0, 0, 56, 0, 0, 0, 0, 0, 0, 0, 57, 0, 0, 0, 0, 0, 0, 0, 58, 0, 0, 0, 0, 0, 0, 0, 59, 0, 0, 0, 0, 0, 0, 0, 60, 0, 0, 0, 0, 0, 0, 0, 61, 0, 0, 0, 0, 0, 0, 0, 62, 0, 0, 0, 0, 0, 0, 0, 63, 0, 0, 0, 0, 0, 0, 0, 64, 0, 0, 0, 0, 0, 0, 0, 65, 0, 0, 0, 0, 0, 0, 0, 66, 0, 0, 0, 0, 0, 0, 0, 67, 0, 0, 0, 0, 0, 0, 0, 68, 0, 0, 0, 0, 0, 0, 0, 69, 0, 0, 0, 0, 0, 0, 0, 70, 0, 0, 0, 0, 0, 0, 0, 71, 0, 0, 0, 0, 0, 0, 0, 72, 0, 0, 0, 0, 0, 0, 0, 73, 0, 0, 0, 0, 0, 0, 0, 74, 0, 0, 0, 0, 0, 0, 0, 75, 0, 0, 0, 0, 0, 0, 0, 76, 0, 0, 0, 0, 0, 0, 0, 77, 0, 0, 0, 0, 0, 0, 0, 78, 0, 0, 0, 0, 0, 0, 0, 79, 0, 0, 0, 0, 0, 0, 0, 80, 0, 0, 0, 0, 0, 0, 0, 81, 0, 0, 0, 0, 0, 0, 0, 82, 0, 0, 0, 0, 0, 0, 0, 83, 0, 0, 0, 0, 0, 0, 0, 84, 0, 0, 0, 0, 0, 0, 0, 85, 0, 0, 0, 0, 0, 0, 0, 86, 0, 0, 0, 0, 0, 0, 0, 87, 0, 0, 0, 0, 0, 0, 0, 88, 0, 0, 0, 0, 0, 0, 0, 89, 0, 0, 0, 0, 0, 0, 0, 90, 0, 0, 0, 0, 0, 0, 0, 91, 0, 0, 0, 0, 0, 0, 0, 92, 0, 0, 0, 0, 0, 0, 0, 93, 0, 0, 0, 0, 0, 0, 0, 94, 0, 0, 0, 0, 0, 0, 0, 95, 0, 0, 0, 0, 0, 0, 0, 96, 0, 0, 0, 0, 0, 0, 0, 97, 0, 0, 0, 0, 0, 0, 0, 98, 0, 0, 0, 0, 0, 0, 0, 99, 0, 0, 0, 0, 0, 0, 0, 100, 0, 0, 0, 0, 0, 0, 0, 101, 0, 0, 0, 0, 0, 0, 0, 102, 0, 0, 0, 0, 0, 0, 0, 103, 0, 0, 0, 0, 0, 0, 0, 104, 0, 0, 0, 0, 0, 0, 0, 105, 0, 0, 0, 0, 0, 0, 0, 106, 0, 0, 0, 0, 0, 0, 0, 107, 0, 0, 0, 0, 0, 0, 0, 108, 0, 0, 0, 0, 0, 0, 0, 109, 0, 0, 0, 0, 0, 0, 0, 110, 0, 0, 0, 0, 0, 0, 0, 111, 0, 0, 0, 0, 0, 0, 0, 112, 0, 0, 0, 0, 0, 0, 0, 113, 0, 0, 0, 0, 0, 0, 0, 114, 0, 0, 0, 0, 0, 0, 0, 115, 0, 0, 0, 0, 0, 0, 0, 116, 0, 0, 0, 0, 0, 0, 0, 117, 0, 0, 0, 0, 0, 0, 0, 118, 0, 0, 0, 0, 0, 0, 0, 119, 0, 0, 0, 0, 0, 0, 0, 120, 0, 0, 0, 0, 0, 0, 0, 121, 0, 0, 0, 0, 0, 0, 0, 122, 0, 0, 0, 0, 0, 0, 0, 123, 0, 0, 0, 0, 0, 0, 0, 124, 0, 0, 0, 0, 0, 0, 0, 125, 0, 0, 0, 0, 0, 0, 0, 126, 0, 0, 0, 0, 0, 0, 0, 160, 0, 0, 0, 0, 0, 0, 0, 161, 0, 0, 0, 0, 0, 0, 0, 162, 0, 0, 0, 0, 0, 0, 0, 163, 0, 0, 0, 0, 0, 0, 0, 164, 0, 0, 0, 0, 0, 0, 0, 165, 0, 0, 0, 0, 0, 0, 0, 166, 0, 0, 0, 0, 0, 0, 0, 167, 0, 0, 0, 0, 0, 0, 0, 168, 0, 0, 0, 0, 0, 0, 0, 169, 0, 0, 0, 0, 0, 0, 0, 170, 0, 0, 0, 0, 0, 0, 0, 171, 0, 0, 0, 0, 0, 0, 0, 172, 0, 0, 0, 0, 0, 0, 0, 173, 0, 0, 0, 0, 0, 0, 0, 174, 0, 0, 0, 0, 0, 0, 0, 175, 0, 0, 0, 0, 0, 0, 0, 176, 0, 0, 0, 0, 0, 0, 0, 177, 0, 0, 0, 0, 0, 0, 0, 178, 0, 0, 0, 0, 0, 0, 0, 179, 0, 0, 0, 0, 0, 0, 0, 180, 0, 0, 0, 0, 0, 0, 0, 181, 0, 0, 0, 0, 0, 0, 0, 182, 0, 0, 0, 0, 0, 0, 0, 183, 0, 0, 0, 0, 0, 0, 0, 184, 0, 0, 0, 0, 0, 0, 0, 185, 0, 0, 0, 0, 0, 0, 0, 186, 0, 0, 0, 0, 0, 0, 0, 187, 0, 0, 0, 0, 0, 0, 0, 188, 0, 0, 0, 0, 0, 0, 0, 189, 0, 0, 0, 0, 0, 0, 0, 190, 0, 0, 0, 0, 0, 0, 0, 191, 0, 0, 0, 0, 0, 0, 0, 192, 0, 0, 0, 0, 0, 0, 0, 193, 0, 0, 0, 0, 0, 0, 0, 194, 0, 0, 0, 0, 0, 0, 0, 195, 0, 0, 0, 0, 0, 0, 0, 196, 0, 0, 0, 0, 0, 0, 0, 197, 0, 0, 0, 0, 0, 0, 0, 198, 0, 0, 0, 0, 0, 0, 0, 199, 0, 0, 0, 0, 0, 0, 0, 200, 0, 0, 0, 0, 0, 0, 0, 201, 0, 0, 0, 0, 0, 0, 0, 202, 0, 0, 0, 0, 0, 0, 0, 203, 0, 0, 0, 0, 0, 0, 0, 204, 0, 0, 0, 0, 0, 0, 0, 205, 0, 0, 0, 0, 0, 0, 0, 206, 0, 0, 0, 0, 0, 0, 0, 207, 0, 0, 0, 0, 0, 0, 0, 208, 0, 0, 0, 0, 0, 0, 0, 209, 0, 0, 0, 0, 0, 0, 0, 210, 0, 0, 0, 0, 0, 0, 0, 211, 0, 0, 0, 0, 0, 0, 0, 212, 0, 0, 0, 0, 0, 0, 0, 213, 0, 0, 0, 0, 0, 0, 0, 214, 0, 0, 0, 0, 0, 0, 0, 215, 0, 0, 0, 0, 0, 0, 0, 216, 0, 0, 0, 0, 0, 0, 0, 217, 0, 0, 0, 0, 0, 0, 0, 218, 0, 0, 0, 0, 0, 0, 0, 219, 0, 0, 0, 0, 0, 0, 0, 220, 0, 0, 0, 0, 0, 0, 0, 221, 0, 0, 0, 0, 0, 0, 0, 222, 0, 0, 0, 0, 0, 0, 0, 223, 0, 0, 0, 0, 0, 0, 0, 224, 0, 0, 0, 0, 0, 0, 0, 225, 0, 0, 0, 0, 0, 0, 0, 226, 0, 0, 0, 0, 0, 0, 0, 227, 0, 0, 0, 0, 0, 0, 0, 228, 0, 0, 0, 0, 0, 0, 0, 229, 0, 0, 0, 0, 0, 0, 0, 230, 0, 0, 0, 0, 0, 0, 0, 231, 0, 0, 0, 0, 0, 0, 0, 232, 0, 0, 0, 0, 0, 0, 0, 233, 0, 0, 0, 0, 0, 0, 0, 234, 0, 0, 0, 0, 0, 0, 0, 235, 0, 0, 0, 0, 0, 0, 0, 236, 0, 0, 0, 0, 0, 0, 0, 237, 0, 0, 0, 0, 0, 0, 0, 238, 0, 0, 0, 0, 0, 0, 0, 239, 0, 0, 0, 0, 0, 0, 0, 240, 0, 0, 0, 0, 0, 0, 0, 241, 0, 0, 0, 0, 0, 0, 0, 242, 0, 0, 0, 0, 0, 0, 0, 243, 0, 0, 0, 0, 0, 0, 0, 244, 0, 0, 0, 0, 0, 0, 0, 245, 0, 0, 0, 0, 0, 0, 0, 246, 0, 0, 0, 0, 0, 0, 0, 247, 0, 0, 0, 0, 0, 0, 0, 248, 0, 0, 0, 0, 0, 0, 0, 249, 0, 0, 0, 0, 0, 0, 0, 250, 0, 0, 0, 0, 0, 0, 0, 251, 0, 0, 0, 0, 0, 0, 0, 252, 0, 0, 0, 0, 0, 0, 0, 253, 0, 0, 0, 0, 0, 0, 0, 254, 0, 0, 0, 0, 0, 0, 0, 255, 0, 0, 0, 0, 0, 0, 0, 256, 0, 0, 0, 0, 0, 0, 0, 257, 0, 0, 0, 0, 0, 0, 0, 258, 0, 0, 0, 0, 0, 0, 0, 259, 0, 0, 0, 0, 0, 0, 0, 260, 0, 0, 0, 0, 0, 0, 0, 261, 0, 0, 0, 0, 0, 0, 0, 262, 0, 0, 0, 0, 0, 0, 0, 263, 0, 0, 0, 0, 0, 0, 0, 264, 0, 0, 0, 0, 0, 0, 0, 265, 0, 0, 0, 0, 0, 0, 0, 266, 0, 0, 0, 0, 0, 0, 0, 267, 0, 0, 0, 0, 0, 0, 0, 268, 0, 0, 0, 0, 0, 0, 0, 269, 0, 0, 0, 0, 0, 0, 0, 270, 0, 0, 0, 0, 0, 0, 0, 271, 0, 0, 0, 0, 0, 0, 0, 272, 0, 0, 0, 0, 0, 0, 0, 273, 0, 0, 0, 0, 0, 0, 0, 274, 0, 0, 0, 0, 0, 0, 0, 275, 0, 0, 0, 0, 0, 0, 0, 276, 0, 0, 0, 0, 0, 0, 0, 277, 0, 0, 0, 0, 0, 0, 0, 278, 0, 0, 0, 0, 0, 0, 0, 279, 0, 0, 0, 0, 0, 0, 0, 280, 0, 0, 0, 0, 0, 0, 0, 281, 0, 0, 0, 0, 0, 0, 0, 282, 0, 0, 0, 0, 0, 0, 0, 283, 0, 0, 0, 0, 0, 0, 0, 284, 0, 0, 0, 0, 0, 0, 0, 285, 0, 0, 0, 0, 0, 0, 0, 286, 0, 0, 0, 0, 0, 0, 0, 287, 0, 0, 0, 0, 0, 0, 0, 288, 0, 0, 0, 0, 0, 0, 0, 289, 0, 0, 0, 0, 0, 0, 0, 290, 0, 0, 0, 0, 0, 0, 0, 291, 0, 0, 0, 0, 0, 0, 0, 292, 0, 0, 0, 0, 0, 0, 0, 293, 0, 0, 0, 0, 0, 0, 0, 294, 0, 0, 0, 0, 0, 0, 0, 295, 0, 0, 0, 0, 0, 0, 0, 296, 0, 0, 0, 0, 0, 0, 0, 297, 0, 0, 0, 0, 0, 0, 0, 298, 0, 0, 0, 0, 0, 0, 0, 299, 0, 0, 0, 0, 0, 0, 0, 300, 0, 0, 0, 0, 0, 0, 0, 301, 0, 0, 0, 0, 0, 0, 0, 302, 0, 0, 0, 0, 0, 0, 0, 303, 0, 0, 0, 0, 0, 0, 0, 304, 0, 0, 0, 0, 0, 0, 0, 305, 0, 0, 0, 0, 0, 0, 0, 306, 0, 0, 0, 0, 0, 0, 0, 307, 0, 0, 0, 0, 0, 0, 0, 308, 0, 0, 0, 0, 0, 0, 0, 309, 0, 0, 0, 0, 0, 0, 0, 310, 0, 0, 0, 0, 0, 0, 0, 311, 0, 0, 0, 0, 0, 0, 0, 312, 0, 0, 0, 0, 0, 0, 0, 313, 0, 0, 0, 0, 0, 0, 0, 314, 0, 0, 0, 0, 0, 0, 0, 315, 0, 0, 0, 0, 0, 0, 0, 316, 0, 0, 0, 0, 0, 0, 0, 317, 0, 0, 0, 0, 0, 0, 0, 318, 0, 0, 0, 0, 0, 0, 0, 319, 0, 0, 0, 0, 0, 0, 0, 320, 0, 0, 0, 0, 0, 0, 0, 321, 0, 0, 0, 0, 0, 0, 0, 322, 0, 0, 0, 0, 0, 0, 0, 323, 0, 0, 0, 0, 0, 0, 0, 324, 0, 0, 0, 0, 0, 0, 0, 325, 0, 0, 0, 0, 0, 0, 0, 326, 0, 0, 0, 0, 0, 0, 0, 327, 0, 0, 0, 0, 0, 0, 0, 328, 0, 0, 0, 0, 0, 0, 0, 329, 0, 0, 0, 0, 0, 0, 0, 330, 0, 0, 0, 0, 0, 0, 0, 331, 0, 0, 0, 0, 0, 0, 0, 332, 0, 0, 0, 0, 0, 0, 0, 333, 0, 0, 0, 0, 0, 0, 0, 334, 0, 0, 0, 0, 0, 0, 0, 335, 0, 0, 0, 0, 0, 0, 0, 336, 0, 0, 0, 0, 0, 0, 0, 337, 0, 0, 0, 0, 0, 0, 0, 338, 0, 0, 0, 0, 0, 0, 0, 339, 0, 0, 0, 0, 0, 0, 0, 340, 0, 0, 0, 0, 0, 0, 0, 341, 0, 0, 0, 0, 0, 0, 0, 342, 0, 0, 0, 0, 0, 0, 0, 343, 0, 0, 0, 0, 0, 0, 0, 344, 0, 0, 0, 0, 0, 0, 0, 345, 0, 0, 0, 0, 0, 0, 0, 346, 0, 0, 0, 0, 0, 0, 0, 347, 0, 0, 0, 0, 0, 0, 0, 348, 0, 0, 0, 0, 0, 0, 0, 349, 0, 0, 0, 0, 0, 0, 0, 350, 0, 0, 0, 0, 0, 0, 0, 351, 0, 0, 0, 0, 0, 0, 0, 352, 0, 0, 0, 0, 0, 0, 0, 353, 0, 0, 0, 0, 0, 0, 0, 354, 0, 0, 0, 0, 0, 0, 0, 355, 0, 0, 0, 0, 0, 0, 0, 356, 0, 0, 0, 0, 0, 0, 0, 357, 0, 0, 0, 0, 0, 0, 0, 358, 0, 0, 0, 0, 0, 0, 0, 359, 0, 0, 0, 0, 0, 0, 0, 360, 0, 0, 0, 0, 0, 0, 0, 361, 0, 0, 0, 0, 0, 0, 0, 362, 0, 0, 0, 0, 0, 0, 0, 363, 0, 0, 0, 0, 0, 0, 0, 364, 0, 0, 0, 0, 0, 0, 0, 365, 0, 0, 0, 0, 0, 0, 0, 366, 0, 0, 0, 0, 0, 0, 0, 367, 0, 0, 0, 0, 0, 0, 0, 368, 0, 0, 0, 0, 0, 0, 0, 369, 0, 0, 0, 0, 0, 0, 0, 370, 0, 0, 0, 0, 0, 0, 0, 371, 0, 0, 0, 0, 0, 0, 0, 372, 0, 0, 0, 0, 0, 0, 0, 373, 0, 0, 0, 0, 0, 0, 0, 374, 0, 0, 0, 0, 0, 0, 0, 375, 0, 0, 0, 0, 0, 0, 0, 376, 0, 0, 0, 0, 0, 0, 0, 377, 0, 0, 0, 0, 0, 0, 0, 378, 0, 0, 0, 0, 0, 0, 0, 379, 0, 0, 0, 0, 0, 0, 0, 380, 0, 0, 0, 0, 0, 0, 0, 381, 0, 0, 0, 0, 0, 0, 0, 382, 0, 0, 0, 0, 0, 0, 0, 383, 0, 0, 0, 0, 0, 0, 0, 402, 0, 0, 0, 0, 0, 0, 0, 416, 0, 0, 0, 0, 0, 0, 0, 417, 0, 0, 0, 0, 0, 0, 0, 431, 0, 0, 0, 0, 0, 0, 0, 432, 0, 0, 0, 0, 0, 0, 0, 486, 0, 0, 0, 0, 0, 0, 0, 487, 0, 0, 0, 0, 0, 0, 0, 506, 0, 0, 0, 0, 0, 0, 0, 507, 0, 0, 0, 0, 0, 0, 0, 508, 0, 0, 0, 0, 0, 0, 0, 509, 0, 0, 0, 0, 0, 0, 0, 510, 0, 0, 0, 0, 0, 0, 0, 511, 0, 0, 0, 0, 0, 0, 0, 536, 0, 0, 0, 0, 0, 0, 0, 537, 0, 0, 0, 0, 0, 0, 0, 538, 0, 0, 0, 0, 0, 0, 0, 539, 0, 0, 0, 0, 0, 0, 0, 700, 0, 0, 0, 0, 0, 0, 0, 701, 0, 0, 0, 0, 0, 0, 0, 710, 0, 0, 0, 0, 0, 0, 0, 711, 0, 0, 0, 0, 0, 0, 0, 713, 0, 0, 0, 0, 0, 0, 0, 728, 0, 0, 0, 0, 0, 0, 0, 729, 0, 0, 0, 0, 0, 0, 0, 730, 0, 0, 0, 0, 0, 0, 0, 731, 0, 0, 0, 0, 0, 0, 0, 732, 0, 0, 0, 0, 0, 0, 0, 733, 0, 0, 0, 0, 0, 0, 0, 768, 0, 0, 0, 0, 0, 0, 0, 769, 0, 0, 0, 0, 0, 0, 0, 771, 0, 0, 0, 0, 0, 0, 0, 777, 0, 0, 0, 0, 0, 0, 0, 803, 0, 0, 0, 0, 0, 0, 0, 900, 0, 0, 0, 0, 0, 0, 0, 901, 0, 0, 0, 0, 0, 0, 0, 902, 0, 0, 0, 0, 0, 0, 0, 903, 0, 0, 0, 0, 0, 0, 0, 904, 0, 0, 0, 0, 0, 0, 0, 905, 0, 0, 0, 0, 0, 0, 0, 906, 0, 0, 0, 0, 0, 0, 0, 908, 0, 0, 0, 0, 0, 0, 0, 910, 0, 0, 0, 0, 0, 0, 0, 911, 0, 0, 0, 0, 0, 0, 0, 912, 0, 0, 0, 0, 0, 0, 0, 913, 0, 0, 0, 0, 0, 0, 0, 914, 0, 0, 0, 0, 0, 0, 0, 915, 0, 0, 0, 0, 0, 0, 0, 916, 0, 0, 0, 0, 0, 0, 0, 917, 0, 0, 0, 0, 0, 0, 0, 918, 0, 0, 0, 0, 0, 0, 0, 919, 0, 0, 0, 0, 0, 0, 0, 920, 0, 0, 0, 0, 0, 0, 0, 921, 0, 0, 0, 0, 0, 0, 0, 922, 0, 0, 0, 0, 0, 0, 0, 923, 0, 0, 0, 0, 0, 0, 0, 924, 0, 0, 0, 0, 0, 0, 0, 925, 0, 0, 0, 0, 0, 0, 0, 926, 0, 0, 0, 0, 0, 0, 0, 927, 0, 0, 0, 0, 0, 0, 0, 928, 0, 0, 0, 0, 0, 0, 0, 929, 0, 0, 0, 0, 0, 0, 0, 931, 0, 0, 0, 0, 0, 0, 0, 932, 0, 0, 0, 0, 0, 0, 0, 933, 0, 0, 0, 0, 0, 0, 0, 934, 0, 0, 0, 0, 0, 0, 0, 935, 0, 0, 0, 0, 0, 0, 0, 936, 0, 0, 0, 0, 0, 0, 0, 937, 0, 0, 0, 0, 0, 0, 0, 938, 0, 0, 0, 0, 0, 0, 0, 939, 0, 0, 0, 0, 0, 0, 0, 940, 0, 0, 0, 0, 0, 0, 0, 941, 0, 0, 0, 0, 0, 0, 0, 942, 0, 0, 0, 0, 0, 0, 0, 943, 0, 0, 0, 0, 0, 0, 0, 944, 0, 0, 0, 0, 0, 0, 0, 945, 0, 0, 0, 0, 0, 0, 0, 946, 0, 0, 0, 0, 0, 0, 0, 947, 0, 0, 0, 0, 0, 0, 0, 948, 0, 0, 0, 0, 0, 0, 0, 949, 0, 0, 0, 0, 0, 0, 0, 950, 0, 0, 0, 0, 0, 0, 0, 951, 0, 0, 0, 0, 0, 0, 0, 952, 0, 0, 0, 0, 0, 0, 0, 953, 0, 0, 0, 0, 0, 0, 0, 954, 0, 0, 0, 0, 0, 0, 0, 955, 0, 0, 0, 0, 0, 0, 0, 956, 0, 0, 0, 0, 0, 0, 0, 957, 0, 0, 0, 0, 0, 0, 0, 958, 0, 0, 0, 0, 0, 0, 0, 959, 0, 0, 0, 0, 0, 0, 0, 960, 0, 0, 0, 0, 0, 0, 0, 961, 0, 0, 0, 0, 0, 0, 0, 962, 0, 0, 0, 0, 0, 0, 0, 963, 0, 0, 0, 0, 0, 0, 0, 964, 0, 0, 0, 0, 0, 0, 0, 965, 0, 0, 0, 0, 0, 0, 0, 966, 0, 0, 0, 0, 0, 0, 0, 967, 0, 0, 0, 0, 0, 0, 0, 968, 0, 0, 0, 0, 0, 0, 0, 969, 0, 0, 0, 0, 0, 0, 0, 970, 0, 0, 0, 0, 0, 0, 0, 971, 0, 0, 0, 0, 0, 0, 0, 972, 0, 0, 0, 0, 0, 0, 0, 973, 0, 0, 0, 0, 0, 0, 0, 974, 0, 0, 0, 0, 0, 0, 0, 977, 0, 0, 0, 0, 0, 0, 0, 978, 0, 0, 0, 0, 0, 0, 0, 981, 0, 0, 0, 0, 0, 0, 0, 982, 0, 0, 0, 0, 0, 0, 0, 1025, 0, 0, 0, 0, 0, 0, 0, 1026, 0, 0, 0, 0, 0, 0, 0, 1027, 0, 0, 0, 0, 0, 0, 0, 1028, 0, 0, 0, 0, 0, 0, 0, 1029, 0, 0, 0, 0, 0, 0, 0, 1030, 0, 0, 0, 0, 0, 0, 0, 1031, 0, 0, 0, 0, 0, 0, 0, 1032, 0, 0, 0, 0, 0, 0, 0, 1033, 0, 0, 0, 0, 0, 0, 0, 1034, 0, 0, 0, 0, 0, 0, 0, 1035, 0, 0, 0, 0, 0, 0, 0, 1036, 0, 0, 0, 0, 0, 0, 0, 1038, 0, 0, 0, 0, 0, 0, 0, 1039, 0, 0, 0, 0, 0, 0, 0, 1040, 0, 0, 0, 0, 0, 0, 0, 1041, 0, 0, 0, 0, 0, 0, 0, 1042, 0, 0, 0, 0, 0, 0, 0, 1043, 0, 0, 0, 0, 0, 0, 0, 1044, 0, 0, 0, 0, 0, 0, 0, 1045, 0, 0, 0, 0, 0, 0, 0, 1046, 0, 0, 0, 0, 0, 0, 0, 1047, 0, 0, 0, 0, 0, 0, 0, 1048, 0, 0, 0, 0, 0, 0, 0, 1049, 0, 0, 0, 0, 0, 0, 0, 1050, 0, 0, 0, 0, 0, 0, 0, 1051, 0, 0, 0, 0, 0, 0, 0, 1052, 0, 0, 0, 0, 0, 0, 0, 1053, 0, 0, 0, 0, 0, 0, 0, 1054, 0, 0, 0, 0, 0, 0, 0, 1055, 0, 0, 0, 0, 0, 0, 0, 1056, 0, 0, 0, 0, 0, 0, 0, 1057, 0, 0, 0, 0, 0, 0, 0, 1058, 0, 0, 0, 0, 0, 0, 0, 1059, 0, 0, 0, 0, 0, 0, 0, 1060, 0, 0, 0, 0, 0, 0, 0, 1061, 0, 0, 0, 0, 0, 0, 0, 1062, 0, 0, 0, 0, 0, 0, 0, 1063, 0, 0, 0, 0, 0, 0, 0, 1064, 0, 0, 0, 0, 0, 0, 0, 1065, 0, 0, 0, 0, 0, 0, 0, 1066, 0, 0, 0, 0, 0, 0, 0, 1067, 0, 0, 0, 0, 0, 0, 0, 1068, 0, 0, 0, 0, 0, 0, 0, 1069, 0, 0, 0, 0, 0, 0, 0, 1070, 0, 0, 0, 0, 0, 0, 0, 1071, 0, 0, 0, 0, 0, 0, 0, 1072, 0, 0, 0, 0, 0, 0, 0, 1073, 0, 0, 0, 0, 0, 0, 0, 1074, 0, 0, 0, 0, 0, 0, 0, 1075, 0, 0, 0, 0, 0, 0, 0, 1076, 0, 0, 0, 0, 0, 0, 0, 1077, 0, 0, 0, 0, 0, 0, 0, 1078, 0, 0, 0, 0, 0, 0, 0, 1079, 0, 0, 0, 0, 0, 0, 0, 1080, 0, 0, 0, 0, 0, 0, 0, 1081, 0, 0, 0, 0, 0, 0, 0, 1082, 0, 0, 0, 0, 0, 0, 0, 1083, 0, 0, 0, 0, 0, 0, 0, 1084, 0, 0, 0, 0, 0, 0, 0, 1085, 0, 0, 0, 0, 0, 0, 0, 1086, 0, 0, 0, 0, 0, 0, 0, 1087, 0, 0, 0, 0, 0, 0, 0, 1088, 0, 0, 0, 0, 0, 0, 0, 1089, 0, 0, 0, 0, 0, 0, 0, 1090, 0, 0, 0, 0, 0, 0, 0, 1091, 0, 0, 0, 0, 0, 0, 0, 1092, 0, 0, 0, 0, 0, 0, 0, 1093, 0, 0, 0, 0, 0, 0, 0, 1094, 0, 0, 0, 0, 0, 0, 0, 1095, 0, 0, 0, 0, 0, 0, 0, 1096, 0, 0, 0, 0, 0, 0, 0, 1097, 0, 0, 0, 0, 0, 0, 0, 1098, 0, 0, 0, 0, 0, 0, 0, 1099, 0, 0, 0, 0, 0, 0, 0, 1100, 0, 0, 0, 0, 0, 0, 0, 1101, 0, 0, 0, 0, 0, 0, 0, 1102, 0, 0, 0, 0, 0, 0, 0, 1103, 0, 0, 0, 0, 0, 0, 0, 1105, 0, 0, 0, 0, 0, 0, 0, 1106, 0, 0, 0, 0, 0, 0, 0, 1107, 0, 0, 0, 0, 0, 0, 0, 1108, 0, 0, 0, 0, 0, 0, 0, 1109, 0, 0, 0, 0, 0, 0, 0, 1110, 0, 0, 0, 0, 0, 0, 0, 1111, 0, 0, 0, 0, 0, 0, 0, 1112, 0, 0, 0, 0, 0, 0, 0, 1113, 0, 0, 0, 0, 0, 0, 0, 1114, 0, 0, 0, 0, 0, 0, 0, 1115, 0, 0, 0, 0, 0, 0, 0, 1116, 0, 0, 0, 0, 0, 0, 0, 1118, 0, 0, 0, 0, 0, 0, 0, 1119, 0, 0, 0, 0, 0, 0, 0, 1122, 0, 0, 0, 0, 0, 0, 0, 1123, 0, 0, 0, 0, 0, 0, 0, 1138, 0, 0, 0, 0, 0, 0, 0, 1139, 0, 0, 0, 0, 0, 0, 0, 1140, 0, 0, 0, 0, 0, 0, 0, 1141, 0, 0, 0, 0, 0, 0, 0, 1168, 0, 0, 0, 0, 0, 0, 0, 1169, 0, 0, 0, 0, 0, 0, 0, 1241, 0, 0, 0, 0, 0, 0, 0, 1456, 0, 0, 0, 0, 0, 0, 0, 1457, 0, 0, 0, 0, 0, 0, 0, 1458, 0, 0, 0, 0, 0, 0, 0, 1459, 0, 0, 0, 0, 0, 0, 0, 1460, 0, 0, 0, 0, 0, 0, 0, 1461, 0, 0, 0, 0, 0, 0, 0, 1462, 0, 0, 0, 0, 0, 0, 0, 1463, 0, 0, 0, 0, 0, 0, 0, 1464, 0, 0, 0, 0, 0, 0, 0, 1465, 0, 0, 0, 0, 0, 0, 0, 1467, 0, 0, 0, 0, 0, 0, 0, 1468, 0, 0, 0, 0, 0, 0, 0, 1469, 0, 0, 0, 0, 0, 0, 0, 1470, 0, 0, 0, 0, 0, 0, 0, 1471, 0, 0, 0, 0, 0, 0, 0, 1472, 0, 0, 0, 0, 0, 0, 0, 1473, 0, 0, 0, 0, 0, 0, 0, 1474, 0, 0, 0, 0, 0, 0, 0, 1475, 0, 0, 0, 0, 0, 0, 0, 1488, 0, 0, 0, 0, 0, 0, 0, 1489, 0, 0, 0, 0, 0, 0, 0, 1490, 0, 0, 0, 0, 0, 0, 0, 1491, 0, 0, 0, 0, 0, 0, 0, 1492, 0, 0, 0, 0, 0, 0, 0, 1493, 0, 0, 0, 0, 0, 0, 0, 1494, 0, 0, 0, 0, 0, 0, 0, 1495, 0, 0, 0, 0, 0, 0, 0, 1496, 0, 0, 0, 0, 0, 0, 0, 1497, 0, 0, 0, 0, 0, 0, 0, 1498, 0, 0, 0, 0, 0, 0, 0, 1499, 0, 0, 0, 0, 0, 0, 0, 1500, 0, 0, 0, 0, 0, 0, 0, 1501, 0, 0, 0, 0, 0, 0, 0, 1502, 0, 0, 0, 0, 0, 0, 0, 1503, 0, 0, 0, 0, 0, 0, 0, 1504, 0, 0, 0, 0, 0, 0, 0, 1505, 0, 0, 0, 0, 0, 0, 0, 1506, 0, 0, 0, 0, 0, 0, 0, 1507, 0, 0, 0, 0, 0, 0, 0, 1508, 0, 0, 0, 0, 0, 0, 0, 1509, 0, 0, 0, 0, 0, 0, 0, 1510, 0, 0, 0, 0, 0, 0, 0, 1511, 0, 0, 0, 0, 0, 0, 0, 1512, 0, 0, 0, 0, 0, 0, 0, 1513, 0, 0, 0, 0, 0, 0, 0, 1514, 0, 0, 0, 0, 0, 0, 0, 1520, 0, 0, 0, 0, 0, 0, 0, 1521, 0, 0, 0, 0, 0, 0, 0, 1522, 0, 0, 0, 0, 0, 0, 0, 1548, 0, 0, 0, 0, 0, 0, 0, 1563, 0, 0, 0, 0, 0, 0, 0, 1567, 0, 0, 0, 0, 0, 0, 0, 1569, 0, 0, 0, 0, 0, 0, 0, 1570, 0, 0, 0, 0, 0, 0, 0, 1571, 0, 0, 0, 0, 0, 0, 0, 1572, 0, 0, 0, 0, 0, 0, 0, 1573, 0, 0, 0, 0, 0, 0, 0, 1574, 0, 0, 0, 0, 0, 0, 0, 1575, 0, 0, 0, 0, 0, 0, 0, 1576, 0, 0, 0, 0, 0, 0, 0, 1577, 0, 0, 0, 0, 0, 0, 0, 1578, 0, 0, 0, 0, 0, 0, 0, 1579, 0, 0, 0, 0, 0, 0, 0, 1580, 0, 0, 0, 0, 0, 0, 0, 1581, 0, 0, 0, 0, 0, 0, 0, 1582, 0, 0, 0, 0, 0, 0, 0, 1583, 0, 0, 0, 0, 0, 0, 0, 1584, 0, 0, 0, 0, 0, 0, 0, 1585, 0, 0, 0, 0, 0, 0, 0, 1586, 0, 0, 0, 0, 0, 0, 0, 1587, 0, 0, 0, 0, 0, 0, 0, 1588, 0, 0, 0, 0, 0, 0, 0, 1589, 0, 0, 0, 0, 0, 0, 0, 1590, 0, 0, 0, 0, 0, 0, 0, 1591, 0, 0, 0, 0, 0, 0, 0, 1592, 0, 0, 0, 0, 0, 0, 0, 1593, 0, 0, 0, 0, 0, 0, 0, 1594, 0, 0, 0, 0, 0, 0, 0, 1600, 0, 0, 0, 0, 0, 0, 0, 1601, 0, 0, 0, 0, 0, 0, 0, 1602, 0, 0, 0, 0, 0, 0, 0, 1603, 0, 0, 0, 0, 0, 0, 0, 1604, 0, 0, 0, 0, 0, 0, 0, 1605, 0, 0, 0, 0, 0, 0, 0, 1606, 0, 0, 0, 0, 0, 0, 0, 1607, 0, 0, 0, 0, 0, 0, 0, 1608, 0, 0, 0, 0, 0, 0, 0, 1609, 0, 0, 0, 0, 0, 0, 0, 1610, 0, 0, 0, 0, 0, 0, 0, 1611, 0, 0, 0, 0, 0, 0, 0, 1612, 0, 0, 0, 0, 0, 0, 0, 1613, 0, 0, 0, 0, 0, 0, 0, 1614, 0, 0, 0, 0, 0, 0, 0, 1615, 0, 0, 0, 0, 0, 0, 0, 1616, 0, 0, 0, 0, 0, 0, 0, 1617, 0, 0, 0, 0, 0, 0, 0, 1618, 0, 0, 0, 0, 0, 0, 0, 1632, 0, 0, 0, 0, 0, 0, 0, 1633, 0, 0, 0, 0, 0, 0, 0, 1634, 0, 0, 0, 0, 0, 0, 0, 1635, 0, 0, 0, 0, 0, 0, 0, 1636, 0, 0, 0, 0, 0, 0, 0, 1637, 0, 0, 0, 0, 0, 0, 0, 1638, 0, 0, 0, 0, 0, 0, 0, 1639, 0, 0, 0, 0, 0, 0, 0, 1640, 0, 0, 0, 0, 0, 0, 0, 1641, 0, 0, 0, 0, 0, 0, 0, 1642, 0, 0, 0, 0, 0, 0, 0, 1645, 0, 0, 0, 0, 0, 0, 0, 1657, 0, 0, 0, 0, 0, 0, 0, 1662, 0, 0, 0, 0, 0, 0, 0, 1670, 0, 0, 0, 0, 0, 0, 0, 1672, 0, 0, 0, 0, 0, 0, 0, 1681, 0, 0, 0, 0, 0, 0, 0, 1688, 0, 0, 0, 0, 0, 0, 0, 1700, 0, 0, 0, 0, 0, 0, 0, 1711, 0, 0, 0, 0, 0, 0, 0, 1722, 0, 0, 0, 0, 0, 0, 0, 1746, 0, 0, 0, 0, 0, 0, 0, 1749, 0, 0, 0, 0, 0, 0, 0, 7808, 0, 0, 0, 0, 0, 0, 0, 7809, 0, 0, 0, 0, 0, 0, 0, 7810, 0, 0, 0, 0, 0, 0, 0, 7811, 0, 0, 0, 0, 0, 0, 0, 7812, 0, 0, 0, 0, 0, 0, 0, 7813, 0, 0, 0, 0, 0, 0, 0, 7922, 0, 0, 0, 0, 0, 0, 0, 7923, 0, 0, 0, 0, 0, 0, 0, 8204, 0, 0, 0, 0, 0, 0, 0, 8205, 0, 0, 0, 0, 0, 0, 0, 8206, 0, 0, 0, 0, 0, 0, 0, 8207, 0, 0, 0, 0, 0, 0, 0, 8210, 0, 0, 0, 0, 0, 0, 0, 8211, 0, 0, 0, 0, 0, 0, 0, 8212, 0, 0, 0, 0, 0, 0, 0, 8213, 0, 0, 0, 0, 0, 0, 0, 8215, 0, 0, 0, 0, 0, 0, 0, 8216, 0, 0, 0, 0, 0, 0, 0, 8217, 0, 0, 0, 0, 0, 0, 0, 8218, 0, 0, 0, 0, 0, 0, 0, 8219, 0, 0, 0, 0, 0, 0, 0, 8220, 0, 0, 0, 0, 0, 0, 0, 8221, 0, 0, 0, 0, 0, 0, 0, 8222, 0, 0, 0, 0, 0, 0, 0, 8224, 0, 0, 0, 0, 0, 0, 0, 8225, 0, 0, 0, 0, 0, 0, 0, 8226, 0, 0, 0, 0, 0, 0, 0, 8228, 0, 0, 0, 0, 0, 0, 0, 8229, 0, 0, 0, 0, 0, 0, 0, 8230, 0, 0, 0, 0, 0, 0, 0, 8236, 0, 0, 0, 0, 0, 0, 0, 8237, 0, 0, 0, 0, 0, 0, 0, 8238, 0, 0, 0, 0, 0, 0, 0, 8240, 0, 0, 0, 0, 0, 0, 0, 8242, 0, 0, 0, 0, 0, 0, 0, 8243, 0, 0, 0, 0, 0, 0, 0, 8249, 0, 0, 0, 0, 0, 0, 0, 8250, 0, 0, 0, 0, 0, 0, 0, 8252, 0, 0, 0, 0, 0, 0, 0, 8260, 0, 0, 0, 0, 0, 0, 0, 8304, 0, 0, 0, 0, 0, 0, 0, 8308, 0, 0, 0, 0, 0, 0, 0, 8309, 0, 0, 0, 0, 0, 0, 0, 8310, 0, 0, 0, 0, 0, 0, 0, 8311, 0, 0, 0, 0, 0, 0, 0, 8312, 0, 0, 0, 0, 0, 0, 0, 8313, 0, 0, 0, 0, 0, 0, 0, 8317, 0, 0, 0, 0, 0, 0, 0, 8318, 0, 0, 0, 0, 0, 0, 0, 8319, 0, 0, 0, 0, 0, 0, 0, 8320, 0, 0, 0, 0, 0, 0, 0, 8321, 0, 0, 0, 0, 0, 0, 0, 8322, 0, 0, 0, 0, 0, 0, 0, 8323, 0, 0, 0, 0, 0, 0, 0, 8324, 0, 0, 0, 0, 0, 0, 0, 8325, 0, 0, 0, 0, 0, 0, 0, 8326, 0, 0, 0, 0, 0, 0, 0, 8327, 0, 0, 0, 0, 0, 0, 0, 8328, 0, 0, 0, 0, 0, 0, 0, 8329, 0, 0, 0, 0, 0, 0, 0, 8333, 0, 0, 0, 0, 0, 0, 0, 8334, 0, 0, 0, 0, 0, 0, 0, 8353, 0, 0, 0, 0, 0, 0, 0, 8355, 0, 0, 0, 0, 0, 0, 0, 8356, 0, 0, 0, 0, 0, 0, 0, 8359, 0, 0, 0, 0, 0, 0, 0, 8362, 0, 0, 0, 0, 0, 0, 0, 8363, 0, 0, 0, 0, 0, 0, 0, 8364, 0, 0, 0, 0, 0, 0, 0, 8453, 0, 0, 0, 0, 0, 0, 0, 8465, 0, 0, 0, 0, 0, 0, 0, 8467, 0, 0, 0, 0, 0, 0, 0, 8470, 0, 0, 0, 0, 0, 0, 0, 8472, 0, 0, 0, 0, 0, 0, 0, 8476, 0, 0, 0, 0, 0, 0, 0, 8478, 0, 0, 0, 0, 0, 0, 0, 8482, 0, 0, 0, 0, 0, 0, 0, 8486, 0, 0, 0, 0, 0, 0, 0, 8494, 0, 0, 0, 0, 0, 0, 0, 8501, 0, 0, 0, 0, 0, 0, 0, 8531, 0, 0, 0, 0, 0, 0, 0, 8532, 0, 0, 0, 0, 0, 0, 0, 8539, 0, 0, 0, 0, 0, 0, 0, 8540, 0, 0, 0, 0, 0, 0, 0, 8541, 0, 0, 0, 0, 0, 0, 0, 8542, 0, 0, 0, 0, 0, 0, 0, 8592, 0, 0, 0, 0, 0, 0, 0, 8593, 0, 0, 0, 0, 0, 0, 0, 8594, 0, 0, 0, 0, 0, 0, 0, 8595, 0, 0, 0, 0, 0, 0, 0, 8596, 0, 0, 0, 0, 0, 0, 0, 8597, 0, 0, 0, 0, 0, 0, 0, 8616, 0, 0, 0, 0, 0, 0, 0, 8629, 0, 0, 0, 0, 0, 0, 0, 8656, 0, 0, 0, 0, 0, 0, 0, 8657, 0, 0, 0, 0, 0, 0, 0, 8658, 0, 0, 0, 0, 0, 0, 0, 8659, 0, 0, 0, 0, 0, 0, 0, 8660, 0, 0, 0, 0, 0, 0, 0, 8704, 0, 0, 0, 0, 0, 0, 0, 8706, 0, 0, 0, 0, 0, 0, 0, 8707, 0, 0, 0, 0, 0, 0, 0, 8709, 0, 0, 0, 0, 0, 0, 0, 8710, 0, 0, 0, 0, 0, 0, 0, 8711, 0, 0, 0, 0, 0, 0, 0, 8712, 0, 0, 0, 0, 0, 0, 0, 8713, 0, 0, 0, 0, 0, 0, 0, 8715, 0, 0, 0, 0, 0, 0, 0, 8719, 0, 0, 0, 0, 0, 0, 0, 8721, 0, 0, 0, 0, 0, 0, 0, 8722, 0, 0, 0, 0, 0, 0, 0, 8725, 0, 0, 0, 0, 0, 0, 0, 8727, 0, 0, 0, 0, 0, 0, 0, 8729, 0, 0, 0, 0, 0, 0, 0, 8730, 0, 0, 0, 0, 0, 0, 0, 8733, 0, 0, 0, 0, 0, 0, 0, 8734, 0, 0, 0, 0, 0, 0, 0, 8735, 0, 0, 0, 0, 0, 0, 0, 8736, 0, 0, 0, 0, 0, 0, 0, 8743, 0, 0, 0, 0, 0, 0, 0, 8744, 0, 0, 0, 0, 0, 0, 0, 8745, 0, 0, 0, 0, 0, 0, 0, 8746, 0, 0, 0, 0, 0, 0, 0, 8747, 0, 0, 0, 0, 0, 0, 0, 8756, 0, 0, 0, 0, 0, 0, 0, 8764, 0, 0, 0, 0, 0, 0, 0, 8773, 0, 0, 0, 0, 0, 0, 0, 8776, 0, 0, 0, 0, 0, 0, 0, 8800, 0, 0, 0, 0, 0, 0, 0, 8801, 0, 0, 0, 0, 0, 0, 0, 8804, 0, 0, 0, 0, 0, 0, 0, 8805, 0, 0, 0, 0, 0, 0, 0, 8834, 0, 0, 0, 0, 0, 0, 0, 8835, 0, 0, 0, 0, 0, 0, 0, 8836, 0, 0, 0, 0, 0, 0, 0, 8838, 0, 0, 0, 0, 0, 0, 0, 8839, 0, 0, 0, 0, 0, 0, 0, 8853, 0, 0, 0, 0, 0, 0, 0, 8855, 0, 0, 0, 0, 0, 0, 0, 8869, 0, 0, 0, 0, 0, 0, 0, 8901, 0, 0, 0, 0, 0, 0, 0, 8962, 0, 0, 0, 0, 0, 0, 0, 8976, 0, 0, 0, 0, 0, 0, 0, 8992, 0, 0, 0, 0, 0, 0, 0, 8993, 0, 0, 0, 0, 0, 0, 0, 9001, 0, 0, 0, 0, 0, 0, 0, 9002, 0, 0, 0, 0, 0, 0, 0, 9472, 0, 0, 0, 0, 0, 0, 0, 9474, 0, 0, 0, 0, 0, 0, 0, 9484, 0, 0, 0, 0, 0, 0, 0, 9488, 0, 0, 0, 0, 0, 0, 0, 9492, 0, 0, 0, 0, 0, 0, 0, 9496, 0, 0, 0, 0, 0, 0, 0, 9500, 0, 0, 0, 0, 0, 0, 0, 9508, 0, 0, 0, 0, 0, 0, 0, 9516, 0, 0, 0, 0, 0, 0, 0, 9524, 0, 0, 0, 0, 0, 0, 0, 9532, 0, 0, 0, 0, 0, 0, 0, 9552, 0, 0, 0, 0, 0, 0, 0, 9553, 0, 0, 0, 0, 0, 0, 0, 9554, 0, 0, 0, 0, 0, 0, 0, 9555, 0, 0, 0, 0, 0, 0, 0, 9556, 0, 0, 0, 0, 0, 0, 0, 9557, 0, 0, 0, 0, 0, 0, 0, 9558, 0, 0, 0, 0, 0, 0, 0, 9559, 0, 0, 0, 0, 0, 0, 0, 9560, 0, 0, 0, 0, 0, 0, 0, 9561, 0, 0, 0, 0, 0, 0, 0, 9562, 0, 0, 0, 0, 0, 0, 0, 9563, 0, 0, 0, 0, 0, 0, 0, 9564, 0, 0, 0, 0, 0, 0, 0, 9565, 0, 0, 0, 0, 0, 0, 0, 9566, 0, 0, 0, 0, 0, 0, 0, 9567, 0, 0, 0, 0, 0, 0, 0, 9568, 0, 0, 0, 0, 0, 0, 0, 9569, 0, 0, 0, 0, 0, 0, 0, 9570, 0, 0, 0, 0, 0, 0, 0, 9571, 0, 0, 0, 0, 0, 0, 0, 9572, 0, 0, 0, 0, 0, 0, 0, 9573, 0, 0, 0, 0, 0, 0, 0, 9574, 0, 0, 0, 0, 0, 0, 0, 9575, 0, 0, 0, 0, 0, 0, 0, 9576, 0, 0, 0, 0, 0, 0, 0, 9577, 0, 0, 0, 0, 0, 0, 0, 9578, 0, 0, 0, 0, 0, 0, 0, 9579, 0, 0, 0, 0, 0, 0, 0, 9580, 0, 0, 0, 0, 0, 0, 0, 9600, 0, 0, 0, 0, 0, 0, 0, 9604, 0, 0, 0, 0, 0, 0, 0, 9608, 0, 0, 0, 0, 0, 0, 0, 9612, 0, 0, 0, 0, 0, 0, 0, 9616, 0, 0, 0, 0, 0, 0, 0, 9617, 0, 0, 0, 0, 0, 0, 0, 9618, 0, 0, 0, 0, 0, 0, 0, 9619, 0, 0, 0, 0, 0, 0, 0, 9632, 0, 0, 0, 0, 0, 0, 0, 9633, 0, 0, 0, 0, 0, 0, 0, 9642, 0, 0, 0, 0, 0, 0, 0, 9643, 0, 0, 0, 0, 0, 0, 0, 9644, 0, 0, 0, 0, 0, 0, 0, 9650, 0, 0, 0, 0, 0, 0, 0, 9658, 0, 0, 0, 0, 0, 0, 0, 9660, 0, 0, 0, 0, 0, 0, 0, 9668, 0, 0, 0, 0, 0, 0, 0, 9674, 0, 0, 0, 0, 0, 0, 0, 9675, 0, 0, 0, 0, 0, 0, 0, 9679, 0, 0, 0, 0, 0, 0, 0, 9688, 0, 0, 0, 0, 0, 0, 0, 9689, 0, 0, 0, 0, 0, 0, 0, 9702, 0, 0, 0, 0, 0, 0, 0, 9786, 0, 0, 0, 0, 0, 0, 0, 9787, 0, 0, 0, 0, 0, 0, 0, 9788, 0, 0, 0, 0, 0, 0, 0, 9792, 0, 0, 0, 0, 0, 0, 0, 9794, 0, 0, 0, 0, 0, 0, 0, 9824, 0, 0, 0, 0, 0, 0, 0, 9827, 0, 0, 0, 0, 0, 0, 0, 9829, 0, 0, 0, 0, 0, 0, 0, 9830, 0, 0, 0, 0, 0, 0, 0, 9834, 0, 0, 0, 0, 0, 0, 0, 9835, 0, 0, 0, 0, 0, 0, 0, -2370, 0, 0, 0, 0, 0, 0, 0, -2369, 0, 0, 0, 0, 0, 0, 0, -2368, 0, 0, 0, 0, 0, 0, 0, -2367, 0, 0, 0, 0, 0, 0, 0, -2366, 0, 0, 0, 0, 0, 0, 0, -2365, 0, 0, 0, 0, 0, 0, 0, -2364, 0, 0, 0, 0, 0, 0, 0, -2363, 0, 0, 0, 0, 0, 0, 0, -2362, 0, 0, 0, 0, 0, 0, 0, -2361, 0, 0, 0, 0, 0, 0, 0, -2360, 0, 0, 0, 0, 0, 0, 0, -2359, 0, 0, 0, 0, 0, 0, 0, -2358, 0, 0, 0, 0, 0, 0, 0, -2357, 0, 0, 0, 0, 0, 0, 0, -2356, 0, 0, 0, 0, 0, 0, 0, -2355, 0, 0, 0, 0, 0, 0, 0, -2354, 0, 0, 0, 0, 0, 0, 0, -2353, 0, 0, 0, 0, 0, 0, 0, -2352, 0, 0, 0, 0, 0, 0, 0, -2351, 0, 0, 0, 0, 0, 0, 0, -2350, 0, 0, 0, 0, 0, 0, 0, -2349, 0, 0, 0, 0, 0, 0, 0, -2348, 0, 0, 0, 0, 0, 0, 0, -2347, 0, 0, 0, 0, 0, 0, 0, -2346, 0, 0, 0, 0, 0, 0, 0, -2345, 0, 0, 0, 0, 0, 0, 0, -2344, 0, 0, 0, 0, 0, 0, 0, -2343, 0, 0, 0, 0, 0, 0, 0, -2342, 0, 0, 0, 0, 0, 0, 0, -2341, 0, 0, 0, 0, 0, 0, 0, -2340, 0, 0, 0, 0, 0, 0, 0, -2339, 0, 0, 0, 0, 0, 0, 0, -2338, 0, 0, 0, 0, 0, 0, 0, -2337, 0, 0, 0, 0, 0, 0, 0, -2336, 0, 0, 0, 0, 0, 0, 0, -2335, 0, 0, 0, 0, 0, 0, 0, -2334, 0, 0, 0, 0, 0, 0, 0, -2333, 0, 0, 0, 0, 0, 0, 0, -2332, 0, 0, 0, 0, 0, 0, 0, -2331, 0, 0, 0, 0, 0, 0, 0, -2330, 0, 0, 0, 0, 0, 0, 0, -2329, 0, 0, 0, 0, 0, 0, 0, -2328, 0, 0, 0, 0, 0, 0, 0, -2327, 0, 0, 0, 0, 0, 0, 0, -2326, 0, 0, 0, 0, 0, 0, 0, -2325, 0, 0, 0, 0, 0, 0, 0, -2324, 0, 0, 0, 0, 0, 0, 0, -2323, 0, 0, 0, 0, 0, 0, 0, -2322, 0, 0, 0, 0, 0, 0, 0, -2321, 0, 0, 0, 0, 0, 0, 0, -2320, 0, 0, 0, 0, 0, 0, 0, -2319, 0, 0, 0, 0, 0, 0, 0, -2318, 0, 0, 0, 0, 0, 0, 0, -2317, 0, 0, 0, 0, 0, 0, 0, -2316, 0, 0, 0, 0, 0, 0, 0, -2315, 0, 0, 0, 0, 0, 0, 0, -2314, 0, 0, 0, 0, 0, 0, 0, -2313, 0, 0, 0, 0, 0, 0, 0, -2312, 0, 0, 0, 0, 0, 0, 0, -2311, 0, 0, 0, 0, 0, 0, 0, -2310, 0, 0, 0, 0, 0, 0, 0, -2309, 0, 0, 0, 0, 0, 0, 0, -2308, 0, 0, 0, 0, 0, 0, 0, -2307, 0, 0, 0, 0, 0, 0, 0, -2306, 0, 0, 0, 0, 0, 0, 0, -2305, 0, 0, 0, 0, 0, 0, 0, -2271, 0, 0, 0, 0, 0, 0, 0, -2268, 0, 0, 0, 0, 0, 0, 0, -2266, 0, 0, 0, 0, 0, 0, 0, -2256, 0, 0, 0, 0, 0, 0, 0, -2255, 0, 0, 0, 0, 0, 0, 0, -2254, 0, 0, 0, 0, 0, 0, 0, -2253, 0, 0, 0, 0, 0, 0, 0, -2252, 0, 0, 0, 0, 0, 0, 0, -2251, 0, 0, 0, 0, 0, 0, 0, -2250, 0, 0, 0, 0, 0, 0, 0, -2249, 0, 0, 0, 0, 0, 0, 0, -2248, 0, 0, 0, 0, 0, 0, 0, -2247, 0, 0, 0, 0, 0, 0, 0, -2241, 0, 0, 0, 0, 0, 0, 0, -2208, 0, 0, 0, 0, 0, 0, 0, -2207, 0, 0, 0, 0, 0, 0, 0, -2206, 0, 0, 0, 0, 0, 0, 0, -2205, 0, 0, 0, 0, 0, 0, 0, -2204, 0, 0, 0, 0, 0, 0, 0, -2203, 0, 0, 0, 0, 0, 0, 0, -2202, 0, 0, 0, 0, 0, 0, 0, -2201, 0, 0, 0, 0, 0, 0, 0, -2200, 0, 0, 0, 0, 0, 0, 0, -2199, 0, 0, 0, 0, 0, 0, 0, -2198, 0, 0, 0, 0, 0, 0, 0, -2197, 0, 0, 0, 0, 0, 0, 0, -2196, 0, 0, 0, 0, 0, 0, 0, -2195, 0, 0, 0, 0, 0, 0, 0, -2194, 0, 0, 0, 0, 0, 0, 0, -2193, 0, 0, 0, 0, 0, 0, 0, -2192, 0, 0, 0, 0, 0, 0, 0, -2191, 0, 0, 0, 0, 0, 0, 0, -2190, 0, 0, 0, 0, 0, 0, 0, -2189, 0, 0, 0, 0, 0, 0, 0, -2188, 0, 0, 0, 0, 0, 0, 0, -2187, 0, 0, 0, 0, 0, 0, 0, -2186, 0, 0, 0, 0, 0, 0, 0, -2185, 0, 0, 0, 0, 0, 0, 0, -2184, 0, 0, 0, 0, 0, 0, 0, -2183, 0, 0, 0, 0, 0, 0, 0, -2182, 0, 0, 0, 0, 0, 0, 0, -2143, 0, 0, 0, 0, 0, 0, 0, -2142, 0, 0, 0, 0, 0, 0, 0, -2136, 0, 0, 0, 0, 0, 0, 0, -2129, 0, 0, 0, 0, 0, 0, 0, -2124, 0, 0, 0, 0, 0, 0, 0, -2120, 0, 0, 0, 0, 0, 0, 0, -2113, 0, 0, 0, 0, 0, 0, 0, -2080, 0, 0, 0, 0, 0, 0, 0, -2079, 0, 0, 0, 0, 0, 0, 0, -2078, 0, 0, 0, 0, 0, 0, 0, -2077, 0, 0, 0, 0, 0, 0, 0, -2076, 0, 0, 0, 0, 0, 0, 0, -2075, 0, 0, 0, 0, 0, 0, 0, -2074, 0, 0, 0, 0, 0, 0, 0, -2073, 0, 0, 0, 0, 0, 0, 0, -2072, 0, 0, 0, 0, 0, 0, 0, -2071, 0, 0, 0, 0, 0, 0, 0, -2070, 0, 0, 0, 0, 0, 0, 0, -2069, 0, 0, 0, 0, 0, 0, 0, -2068, 0, 0, 0, 0, 0, 0, 0, -2067, 0, 0, 0, 0, 0, 0, 0, -2066, 0, 0, 0, 0, 0, 0, 0, -2065, 0, 0, 0, 0, 0, 0, 0, -2064, 0, 0, 0, 0, 0, 0, 0, -2063, 0, 0, 0, 0, 0, 0, 0, -2062, 0, 0, 0, 0, 0, 0, 0, -2061, 0, 0, 0, 0, 0, 0, 0, -2060, 0, 0, 0, 0, 0, 0, 0, -2059, 0, 0, 0, 0, 0, 0, 0, -2058, 0, 0, 0, 0, 0, 0, 0, -2056, 0, 0, 0, 0, 0, 0, 0, -2055, 0, 0, 0, 0, 0, 0, 0, -2054, 0, 0, 0, 0, 0, 0, 0, -2053, 0, 0, 0, 0, 0, 0, 0, -2052, 0, 0, 0, 0, 0, 0, 0, -2051, 0, 0, 0, 0, 0, 0, 0, -2050, 0, 0, 0, 0, 0, 0, 0, -2049, 0, 0, 0, 0, 0, 0, 0, -1819, 0, 0, 0, 0, 0, 0, 0, -1818, 0, 0, 0, 0, 0, 0, 0, -1817, 0, 0, 0, 0, 0, 0, 0, -1816, 0, 0, 0, 0, 0, 0, 0, -1815, 0, 0, 0, 0, 0, 0, 0, -1814, 0, 0, 0, 0, 0, 0, 0, -1813, 0, 0, 0, 0, 0, 0, 0, -1812, 0, 0, 0, 0, 0, 0, 0, -1811, 0, 0, 0, 0, 0, 0, 0, -1810, 0, 0, 0, 0, 0, 0, 0, -1809, 0, 0, 0, 0, 0, 0, 0, -1808, 0, 0, 0, 0, 0, 0, 0, -1807, 0, 0, 0, 0, 0, 0, 0, -1806, 0, 0, 0, 0, 0, 0, 0, -1805, 0, 0, 0, 0, 0, 0, 0, -1804, 0, 0, 0, 0, 0, 0, 0, -1803, 0, 0, 0, 0, 0, 0, 0, -1802, 0, 0, 0, 0, 0, 0, 0, -1801, 0, 0, 0, 0, 0, 0, 0, -1800, 0, 0, 0, 0, 0, 0, 0, -1799, 0, 0, 0, 0, 0, 0, 0, -1798, 0, 0, 0, 0, 0, 0, 0, -1797, 0, 0, 0, 0, 0, 0, 0, -1796, 0, 0, 0, 0, 0, 0, 0, -1795, 0, 0, 0, 0, 0, 0, 0, -1794, 0, 0, 0, 0, 0, 0, 0, -1280, 0, 0, 0, 0, 0, 0, 0, -1279, 0, 0, 0, 0, 0, 0, 0, -1278, 0, 0, 0, 0, 0, 0, 0, -1277, 0, 0, 0, 0, 0, 0, 0, -1276, 0, 0, 0, 0, 0, 0, 0, -1249, 0, 0, 0, 0, 0, 0, 0, -1238, 0, 0, 0, 0, 0, 0, 0, -1237, 0, 0, 0, 0, 0, 0, 0, -1227, 0, 0, 0, 0, 0, 0, 0, -1205, 0, 0, 0, 0, 0, 0, 0, -1, 0, 0, 0, 0, 0, 0, 0], ["i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0,"i16",0,0,0,"*",0,0,0], ALLOC_STATIC);
STRING_TABLE.__str4653=allocate([47,69,110,99,111,100,105,110,103,32,60,60,10,47,84,121,112,101,32,47,69,110,99,111,100,105,110,103,10,47,66,97,115,101,69,110,99,111,100,105,110,103,32,0] /* /Encoding __\0A/Type */, "i8", ALLOC_STATIC);
STRING_TABLE.__str5654=allocate([47,69,110,99,111,100,105,110,103,32,0] /* /Encoding \00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str6655=allocate([10,0] /* \0A\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str7656=allocate([47,68,105,102,102,101,114,101,110,99,101,115,32,91,0] /* /Differences [\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str8657=allocate([93,10,62,62,10,0] /* ]\0A__\0A\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str9658=allocate([46,110,111,116,100,101,102,0] /* .notdef\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str10659=allocate([115,112,97,99,101,0] /* space\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str11660=allocate([101,120,99,108,97,109,0] /* exclam\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str12661=allocate([113,117,111,116,101,100,98,108,0] /* quotedbl\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str13662=allocate([110,117,109,98,101,114,115,105,103,110,0] /* numbersign\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str14663=allocate([100,111,108,108,97,114,0] /* dollar\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str15664=allocate([112,101,114,99,101,110,116,0] /* percent\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str16665=allocate([97,109,112,101,114,115,97,110,100,0] /* ampersand\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str17666=allocate([113,117,111,116,101,115,105,110,103,108,101,0] /* quotesingle\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str18667=allocate([112,97,114,101,110,108,101,102,116,0] /* parenleft\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str19668=allocate([112,97,114,101,110,114,105,103,104,116,0] /* parenright\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str20669=allocate([97,115,116,101,114,105,115,107,0] /* asterisk\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str21670=allocate([112,108,117,115,0] /* plus\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str22671=allocate([99,111,109,109,97,0] /* comma\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str23672=allocate([104,121,112,104,101,110,0] /* hyphen\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str24673=allocate([112,101,114,105,111,100,0] /* period\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str25674=allocate([115,108,97,115,104,0] /* slash\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str26675=allocate([122,101,114,111,0] /* zero\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str27676=allocate([111,110,101,0] /* one\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str28677=allocate([116,119,111,0] /* two\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str29678=allocate([116,104,114,101,101,0] /* three\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str30679=allocate([102,111,117,114,0] /* four\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str31680=allocate([102,105,118,101,0] /* five\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str32681=allocate([115,105,120,0] /* six\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str33682=allocate([115,101,118,101,110,0] /* seven\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str34683=allocate([101,105,103,104,116,0] /* eight\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str35684=allocate([110,105,110,101,0] /* nine\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str36685=allocate([99,111,108,111,110,0] /* colon\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str37686=allocate([115,101,109,105,99,111,108,111,110,0] /* semicolon\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str38687=allocate([108,101,115,115,0] /* less\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str39688=allocate([101,113,117,97,108,0] /* equal\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str40689=allocate([103,114,101,97,116,101,114,0] /* greater\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str41690=allocate([113,117,101,115,116,105,111,110,0] /* question\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str42691=allocate([97,116,0] /* at\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str43692=allocate([65,0] /* A\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str44693=allocate([66,0] /* B\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str45694=allocate([67,0] /* C\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str46695=allocate([68,0] /* D\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str47696=allocate([69,0] /* E\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str48697=allocate([70,0] /* F\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str49698=allocate([71,0] /* G\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str50699=allocate([72,0] /* H\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str51700=allocate([73,0] /* I\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str52701=allocate([74,0] /* J\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str53702=allocate([75,0] /* K\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str54703=allocate([76,0] /* L\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str55704=allocate([77,0] /* M\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str56705=allocate([78,0] /* N\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str57706=allocate([79,0] /* O\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str58707=allocate([80,0] /* P\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str59708=allocate([81,0] /* Q\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str60709=allocate([82,0] /* R\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str61710=allocate([83,0] /* S\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str62711=allocate([84,0] /* T\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str63712=allocate([85,0] /* U\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str64713=allocate([86,0] /* V\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str65714=allocate([87,0] /* W\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str66715=allocate([88,0] /* X\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str67716=allocate([89,0] /* Y\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str68717=allocate([90,0] /* Z\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str69718=allocate([98,114,97,99,107,101,116,108,101,102,116,0] /* bracketleft\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str70719=allocate([98,97,99,107,115,108,97,115,104,0] /* backslash\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str71720=allocate([98,114,97,99,107,101,116,114,105,103,104,116,0] /* bracketright\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str72721=allocate([97,115,99,105,105,99,105,114,99,117,109,0] /* asciicircum\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str73722=allocate([117,110,100,101,114,115,99,111,114,101,0] /* underscore\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str74723=allocate([103,114,97,118,101,0] /* grave\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str75724=allocate([97,0] /* a\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str76725=allocate([98,0] /* b\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str77726=allocate([99,0] /* c\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str78727=allocate([100,0] /* d\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str79728=allocate([101,0] /* e\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str80729=allocate([102,0] /* f\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str81730=allocate([103,0] /* g\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str82731=allocate([104,0] /* h\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str83732=allocate([105,0] /* i\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str84733=allocate([106,0] /* j\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str85734=allocate([107,0] /* k\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str86735=allocate([108,0] /* l\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str87736=allocate([109,0] /* m\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str88737=allocate([110,0] /* n\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str89738=allocate([111,0] /* o\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str90739=allocate([112,0] /* p\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str91740=allocate([113,0] /* q\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str92741=allocate([114,0] /* r\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str93742=allocate([115,0] /* s\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str94743=allocate([116,0] /* t\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str95744=allocate([117,0] /* u\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str96745=allocate([118,0] /* v\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str97746=allocate([119,0] /* w\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str98747=allocate([120,0] /* x\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str99748=allocate([121,0] /* y\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str100749=allocate([122,0] /* z\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str101750=allocate([98,114,97,99,101,108,101,102,116,0] /* braceleft\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str102751=allocate([98,97,114,0] /* bar\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str103752=allocate([98,114,97,99,101,114,105,103,104,116,0] /* braceright\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str104753=allocate([97,115,99,105,105,116,105,108,100,101,0] /* asciitilde\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str105754=allocate([101,120,99,108,97,109,100,111,119,110,0] /* exclamdown\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str106755=allocate([99,101,110,116,0] /* cent\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str107756=allocate([115,116,101,114,108,105,110,103,0] /* sterling\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str108757=allocate([99,117,114,114,101,110,99,121,0] /* currency\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str109758=allocate([121,101,110,0] /* yen\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str110759=allocate([98,114,111,107,101,110,98,97,114,0] /* brokenbar\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str111760=allocate([115,101,99,116,105,111,110,0] /* section\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str112761=allocate([100,105,101,114,101,115,105,115,0] /* dieresis\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str113762=allocate([99,111,112,121,114,105,103,104,116,0] /* copyright\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str114763=allocate([111,114,100,102,101,109,105,110,105,110,101,0] /* ordfeminine\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str115764=allocate([103,117,105,108,108,101,109,111,116,108,101,102,116,0] /* guillemotleft\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str116765=allocate([108,111,103,105,99,97,108,110,111,116,0] /* logicalnot\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str117766=allocate([114,101,103,105,115,116,101,114,101,100,0] /* registered\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str118767=allocate([109,97,99,114,111,110,0] /* macron\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str119768=allocate([100,101,103,114,101,101,0] /* degree\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str120769=allocate([112,108,117,115,109,105,110,117,115,0] /* plusminus\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str121770=allocate([116,119,111,115,117,112,101,114,105,111,114,0] /* twosuperior\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str122771=allocate([116,104,114,101,101,115,117,112,101,114,105,111,114,0] /* threesuperior\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str123772=allocate([97,99,117,116,101,0] /* acute\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str124773=allocate([109,117,0] /* mu\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str125774=allocate([112,97,114,97,103,114,97,112,104,0] /* paragraph\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str126775=allocate([112,101,114,105,111,100,99,101,110,116,101,114,101,100,0] /* periodcentered\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str127776=allocate([99,101,100,105,108,108,97,0] /* cedilla\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str128777=allocate([111,110,101,115,117,112,101,114,105,111,114,0] /* onesuperior\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str129778=allocate([111,114,100,109,97,115,99,117,108,105,110,101,0] /* ordmasculine\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str130779=allocate([103,117,105,108,108,101,109,111,116,114,105,103,104,116,0] /* guillemotright\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str131780=allocate([111,110,101,113,117,97,114,116,101,114,0] /* onequarter\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str132781=allocate([111,110,101,104,97,108,102,0] /* onehalf\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str133782=allocate([116,104,114,101,101,113,117,97,114,116,101,114,115,0] /* threequarters\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str134783=allocate([113,117,101,115,116,105,111,110,100,111,119,110,0] /* questiondown\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str135784=allocate([65,103,114,97,118,101,0] /* Agrave\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str136785=allocate([65,97,99,117,116,101,0] /* Aacute\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str137786=allocate([65,99,105,114,99,117,109,102,108,101,120,0] /* Acircumflex\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str138787=allocate([65,116,105,108,100,101,0] /* Atilde\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str139788=allocate([65,100,105,101,114,101,115,105,115,0] /* Adieresis\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str140789=allocate([65,114,105,110,103,0] /* Aring\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str141790=allocate([65,69,0] /* AE\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str142791=allocate([67,99,101,100,105,108,108,97,0] /* Ccedilla\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str143=allocate([69,103,114,97,118,101,0] /* Egrave\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str144=allocate([69,97,99,117,116,101,0] /* Eacute\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str145=allocate([69,99,105,114,99,117,109,102,108,101,120,0] /* Ecircumflex\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str146=allocate([69,100,105,101,114,101,115,105,115,0] /* Edieresis\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str147=allocate([73,103,114,97,118,101,0] /* Igrave\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str148792=allocate([73,97,99,117,116,101,0] /* Iacute\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str149=allocate([73,99,105,114,99,117,109,102,108,101,120,0] /* Icircumflex\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str150=allocate([73,100,105,101,114,101,115,105,115,0] /* Idieresis\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str151=allocate([69,116,104,0] /* Eth\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str152=allocate([78,116,105,108,100,101,0] /* Ntilde\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str153=allocate([79,103,114,97,118,101,0] /* Ograve\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str154=allocate([79,97,99,117,116,101,0] /* Oacute\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str155=allocate([79,99,105,114,99,117,109,102,108,101,120,0] /* Ocircumflex\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str156=allocate([79,116,105,108,100,101,0] /* Otilde\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str157=allocate([79,100,105,101,114,101,115,105,115,0] /* Odieresis\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str158=allocate([109,117,108,116,105,112,108,121,0] /* multiply\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str159=allocate([79,115,108,97,115,104,0] /* Oslash\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str160=allocate([85,103,114,97,118,101,0] /* Ugrave\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str161=allocate([85,97,99,117,116,101,0] /* Uacute\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str162=allocate([85,99,105,114,99,117,109,102,108,101,120,0] /* Ucircumflex\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str163=allocate([85,100,105,101,114,101,115,105,115,0] /* Udieresis\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str164793=allocate([89,97,99,117,116,101,0] /* Yacute\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str165=allocate([84,104,111,114,110,0] /* Thorn\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str166=allocate([103,101,114,109,97,110,100,98,108,115,0] /* germandbls\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str167=allocate([97,103,114,97,118,101,0] /* agrave\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str168=allocate([97,97,99,117,116,101,0] /* aacute\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str169=allocate([97,99,105,114,99,117,109,102,108,101,120,0] /* acircumflex\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str170794=allocate([97,116,105,108,100,101,0] /* atilde\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str171=allocate([97,100,105,101,114,101,115,105,115,0] /* adieresis\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str172=allocate([97,114,105,110,103,0] /* aring\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str173=allocate([97,101,0] /* ae\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str174=allocate([99,99,101,100,105,108,108,97,0] /* ccedilla\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str175=allocate([101,103,114,97,118,101,0] /* egrave\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str176795=allocate([101,97,99,117,116,101,0] /* eacute\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str177=allocate([101,99,105,114,99,117,109,102,108,101,120,0] /* ecircumflex\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str178=allocate([101,100,105,101,114,101,115,105,115,0] /* edieresis\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str179=allocate([105,103,114,97,118,101,0] /* igrave\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str180=allocate([105,97,99,117,116,101,0] /* iacute\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str181=allocate([105,99,105,114,99,117,109,102,108,101,120,0] /* icircumflex\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str182=allocate([105,100,105,101,114,101,115,105,115,0] /* idieresis\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str183=allocate([101,116,104,0] /* eth\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str184=allocate([110,116,105,108,100,101,0] /* ntilde\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str185=allocate([111,103,114,97,118,101,0] /* ograve\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str186=allocate([111,97,99,117,116,101,0] /* oacute\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str187=allocate([111,99,105,114,99,117,109,102,108,101,120,0] /* ocircumflex\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str188=allocate([111,116,105,108,100,101,0] /* otilde\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str189=allocate([111,100,105,101,114,101,115,105,115,0] /* odieresis\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str190=allocate([100,105,118,105,100,101,0] /* divide\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str191=allocate([111,115,108,97,115,104,0] /* oslash\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str192796=allocate([117,103,114,97,118,101,0] /* ugrave\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str193797=allocate([117,97,99,117,116,101,0] /* uacute\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str194=allocate([117,99,105,114,99,117,109,102,108,101,120,0] /* ucircumflex\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str195=allocate([117,100,105,101,114,101,115,105,115,0] /* udieresis\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str196=allocate([121,97,99,117,116,101,0] /* yacute\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str197=allocate([116,104,111,114,110,0] /* thorn\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str198=allocate([121,100,105,101,114,101,115,105,115,0] /* ydieresis\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str199=allocate([65,109,97,99,114,111,110,0] /* Amacron\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str200=allocate([97,109,97,99,114,111,110,0] /* amacron\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str201=allocate([65,98,114,101,118,101,0] /* Abreve\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str202=allocate([97,98,114,101,118,101,0] /* abreve\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str203=allocate([65,111,103,111,110,101,107,0] /* Aogonek\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str204=allocate([97,111,103,111,110,101,107,0] /* aogonek\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str205=allocate([67,97,99,117,116,101,0] /* Cacute\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str206=allocate([99,97,99,117,116,101,0] /* cacute\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str207=allocate([67,99,105,114,99,117,109,102,108,101,120,0] /* Ccircumflex\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str208=allocate([99,99,105,114,99,117,109,102,108,101,120,0] /* ccircumflex\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str209=allocate([67,100,111,116,97,99,99,101,110,116,0] /* Cdotaccent\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str210798=allocate([99,100,111,116,97,99,99,101,110,116,0] /* cdotaccent\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str211=allocate([67,99,97,114,111,110,0] /* Ccaron\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str212=allocate([99,99,97,114,111,110,0] /* ccaron\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str213=allocate([68,99,97,114,111,110,0] /* Dcaron\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str214=allocate([100,99,97,114,111,110,0] /* dcaron\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str215=allocate([68,99,114,111,97,116,0] /* Dcroat\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str216799=allocate([100,99,114,111,97,116,0] /* dcroat\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str217=allocate([69,109,97,99,114,111,110,0] /* Emacron\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str218=allocate([101,109,97,99,114,111,110,0] /* emacron\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str219=allocate([69,98,114,101,118,101,0] /* Ebreve\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str220=allocate([101,98,114,101,118,101,0] /* ebreve\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str221=allocate([69,100,111,116,97,99,99,101,110,116,0] /* Edotaccent\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str222800=allocate([101,100,111,116,97,99,99,101,110,116,0] /* edotaccent\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str223=allocate([69,111,103,111,110,101,107,0] /* Eogonek\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str224=allocate([101,111,103,111,110,101,107,0] /* eogonek\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str225=allocate([69,99,97,114,111,110,0] /* Ecaron\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str226=allocate([101,99,97,114,111,110,0] /* ecaron\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str227=allocate([71,99,105,114,99,117,109,102,108,101,120,0] /* Gcircumflex\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str228=allocate([103,99,105,114,99,117,109,102,108,101,120,0] /* gcircumflex\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str229=allocate([71,98,114,101,118,101,0] /* Gbreve\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str230=allocate([103,98,114,101,118,101,0] /* gbreve\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str231801=allocate([71,100,111,116,97,99,99,101,110,116,0] /* Gdotaccent\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str232=allocate([103,100,111,116,97,99,99,101,110,116,0] /* gdotaccent\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str233=allocate([71,99,111,109,109,97,97,99,99,101,110,116,0] /* Gcommaaccent\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str234=allocate([103,99,111,109,109,97,97,99,99,101,110,116,0] /* gcommaaccent\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str235=allocate([72,99,105,114,99,117,109,102,108,101,120,0] /* Hcircumflex\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str236802=allocate([104,99,105,114,99,117,109,102,108,101,120,0] /* hcircumflex\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str237=allocate([72,98,97,114,0] /* Hbar\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str238=allocate([104,98,97,114,0] /* hbar\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str239=allocate([73,116,105,108,100,101,0] /* Itilde\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str240=allocate([105,116,105,108,100,101,0] /* itilde\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str241=allocate([73,109,97,99,114,111,110,0] /* Imacron\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str242=allocate([105,109,97,99,114,111,110,0] /* imacron\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str243=allocate([73,98,114,101,118,101,0] /* Ibreve\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str244=allocate([105,98,114,101,118,101,0] /* ibreve\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str245=allocate([73,111,103,111,110,101,107,0] /* Iogonek\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str246=allocate([105,111,103,111,110,101,107,0] /* iogonek\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str247=allocate([73,100,111,116,97,99,99,101,110,116,0] /* Idotaccent\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str248=allocate([100,111,116,108,101,115,115,105,0] /* dotlessi\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str249=allocate([73,74,0] /* IJ\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str250=allocate([105,106,0] /* ij\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str251=allocate([74,99,105,114,99,117,109,102,108,101,120,0] /* Jcircumflex\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str252=allocate([106,99,105,114,99,117,109,102,108,101,120,0] /* jcircumflex\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str253=allocate([75,99,111,109,109,97,97,99,99,101,110,116,0] /* Kcommaaccent\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str254=allocate([107,99,111,109,109,97,97,99,99,101,110,116,0] /* kcommaaccent\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str255=allocate([107,103,114,101,101,110,108,97,110,100,105,99,0] /* kgreenlandic\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str256=allocate([76,97,99,117,116,101,0] /* Lacute\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str257=allocate([108,97,99,117,116,101,0] /* lacute\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str258=allocate([76,99,111,109,109,97,97,99,99,101,110,116,0] /* Lcommaaccent\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str259=allocate([108,99,111,109,109,97,97,99,99,101,110,116,0] /* lcommaaccent\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str260=allocate([76,99,97,114,111,110,0] /* Lcaron\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str261=allocate([108,99,97,114,111,110,0] /* lcaron\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str262=allocate([76,100,111,116,0] /* Ldot\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str263=allocate([108,100,111,116,0] /* ldot\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str264=allocate([76,115,108,97,115,104,0] /* Lslash\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str265=allocate([108,115,108,97,115,104,0] /* lslash\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str266=allocate([78,97,99,117,116,101,0] /* Nacute\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str267=allocate([110,97,99,117,116,101,0] /* nacute\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str268=allocate([78,99,111,109,109,97,97,99,99,101,110,116,0] /* Ncommaaccent\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str269=allocate([110,99,111,109,109,97,97,99,99,101,110,116,0] /* ncommaaccent\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str270=allocate([78,99,97,114,111,110,0] /* Ncaron\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str271=allocate([110,99,97,114,111,110,0] /* ncaron\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str272=allocate([110,97,112,111,115,116,114,111,112,104,101,0] /* napostrophe\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str273=allocate([69,110,103,0] /* Eng\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str274=allocate([101,110,103,0] /* eng\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str275=allocate([79,109,97,99,114,111,110,0] /* Omacron\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str276=allocate([111,109,97,99,114,111,110,0] /* omacron\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str277803=allocate([79,98,114,101,118,101,0] /* Obreve\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str278=allocate([111,98,114,101,118,101,0] /* obreve\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str279=allocate([79,104,117,110,103,97,114,117,109,108,97,117,116,0] /* Ohungarumlaut\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str280=allocate([111,104,117,110,103,97,114,117,109,108,97,117,116,0] /* ohungarumlaut\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str281=allocate([79,69,0] /* OE\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str282=allocate([111,101,0] /* oe\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str283=allocate([82,97,99,117,116,101,0] /* Racute\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str284=allocate([114,97,99,117,116,101,0] /* racute\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str285=allocate([82,99,111,109,109,97,97,99,99,101,110,116,0] /* Rcommaaccent\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str286=allocate([114,99,111,109,109,97,97,99,99,101,110,116,0] /* rcommaaccent\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str287=allocate([82,99,97,114,111,110,0] /* Rcaron\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str288=allocate([114,99,97,114,111,110,0] /* rcaron\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str289=allocate([83,97,99,117,116,101,0] /* Sacute\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str290=allocate([115,97,99,117,116,101,0] /* sacute\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str291=allocate([83,99,105,114,99,117,109,102,108,101,120,0] /* Scircumflex\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str292=allocate([115,99,105,114,99,117,109,102,108,101,120,0] /* scircumflex\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str293804=allocate([83,99,101,100,105,108,108,97,0] /* Scedilla\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str294=allocate([115,99,101,100,105,108,108,97,0] /* scedilla\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str295=allocate([83,99,97,114,111,110,0] /* Scaron\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str296=allocate([115,99,97,114,111,110,0] /* scaron\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str297=allocate([84,99,111,109,109,97,97,99,99,101,110,116,0] /* Tcommaaccent\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str298805=allocate([116,99,111,109,109,97,97,99,99,101,110,116,0] /* tcommaaccent\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str299=allocate([84,99,97,114,111,110,0] /* Tcaron\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str300=allocate([116,99,97,114,111,110,0] /* tcaron\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str301=allocate([84,98,97,114,0] /* Tbar\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str302=allocate([116,98,97,114,0] /* tbar\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str303=allocate([85,116,105,108,100,101,0] /* Utilde\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str304=allocate([117,116,105,108,100,101,0] /* utilde\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str305=allocate([85,109,97,99,114,111,110,0] /* Umacron\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str306=allocate([117,109,97,99,114,111,110,0] /* umacron\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str307=allocate([85,98,114,101,118,101,0] /* Ubreve\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str308=allocate([117,98,114,101,118,101,0] /* ubreve\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str309=allocate([85,114,105,110,103,0] /* Uring\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str310=allocate([117,114,105,110,103,0] /* uring\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str311806=allocate([85,104,117,110,103,97,114,117,109,108,97,117,116,0] /* Uhungarumlaut\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str312=allocate([117,104,117,110,103,97,114,117,109,108,97,117,116,0] /* uhungarumlaut\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str313=allocate([85,111,103,111,110,101,107,0] /* Uogonek\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str314=allocate([117,111,103,111,110,101,107,0] /* uogonek\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str315=allocate([87,99,105,114,99,117,109,102,108,101,120,0] /* Wcircumflex\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str316=allocate([119,99,105,114,99,117,109,102,108,101,120,0] /* wcircumflex\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str317807=allocate([89,99,105,114,99,117,109,102,108,101,120,0] /* Ycircumflex\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str318=allocate([121,99,105,114,99,117,109,102,108,101,120,0] /* ycircumflex\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str319=allocate([89,100,105,101,114,101,115,105,115,0] /* Ydieresis\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str320=allocate([90,97,99,117,116,101,0] /* Zacute\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str321=allocate([122,97,99,117,116,101,0] /* zacute\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str322=allocate([90,100,111,116,97,99,99,101,110,116,0] /* Zdotaccent\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str323808=allocate([122,100,111,116,97,99,99,101,110,116,0] /* zdotaccent\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str324=allocate([90,99,97,114,111,110,0] /* Zcaron\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str325=allocate([122,99,97,114,111,110,0] /* zcaron\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str326=allocate([108,111,110,103,115,0] /* longs\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str327=allocate([102,108,111,114,105,110,0] /* florin\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str328=allocate([79,104,111,114,110,0] /* Ohorn\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str329=allocate([111,104,111,114,110,0] /* ohorn\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str330=allocate([85,104,111,114,110,0] /* Uhorn\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str331=allocate([117,104,111,114,110,0] /* uhorn\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str332=allocate([71,99,97,114,111,110,0] /* Gcaron\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str333=allocate([103,99,97,114,111,110,0] /* gcaron\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str334=allocate([65,114,105,110,103,97,99,117,116,101,0] /* Aringacute\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str335=allocate([97,114,105,110,103,97,99,117,116,101,0] /* aringacute\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str336=allocate([65,69,97,99,117,116,101,0] /* AEacute\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str337809=allocate([97,101,97,99,117,116,101,0] /* aeacute\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str338=allocate([79,115,108,97,115,104,97,99,117,116,101,0] /* Oslashacute\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str339=allocate([111,115,108,97,115,104,97,99,117,116,101,0] /* oslashacute\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str340=allocate([83,99,111,109,109,97,97,99,99,101,110,116,0] /* Scommaaccent\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str341=allocate([115,99,111,109,109,97,97,99,99,101,110,116,0] /* scommaaccent\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str342=allocate([97,102,105,105,53,55,57,50,57,0] /* afii57929\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str343=allocate([97,102,105,105,54,52,57,51,55,0] /* afii64937\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str344=allocate([99,105,114,99,117,109,102,108,101,120,0] /* circumflex\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str345=allocate([99,97,114,111,110,0] /* caron\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str346=allocate([98,114,101,118,101,0] /* breve\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str347=allocate([100,111,116,97,99,99,101,110,116,0] /* dotaccent\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str348=allocate([114,105,110,103,0] /* ring\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str349=allocate([111,103,111,110,101,107,0] /* ogonek\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str350=allocate([116,105,108,100,101,0] /* tilde\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str351=allocate([104,117,110,103,97,114,117,109,108,97,117,116,0] /* hungarumlaut\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str352=allocate([103,114,97,118,101,99,111,109,98,0] /* gravecomb\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str353=allocate([97,99,117,116,101,99,111,109,98,0] /* acutecomb\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str354=allocate([116,105,108,100,101,99,111,109,98,0] /* tildecomb\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str355=allocate([104,111,111,107,97,98,111,118,101,99,111,109,98,0] /* hookabovecomb\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str356=allocate([100,111,116,98,101,108,111,119,99,111,109,98,0] /* dotbelowcomb\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str357=allocate([116,111,110,111,115,0] /* tonos\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str358=allocate([100,105,101,114,101,115,105,115,116,111,110,111,115,0] /* dieresistonos\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str359=allocate([65,108,112,104,97,116,111,110,111,115,0] /* Alphatonos\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str360=allocate([97,110,111,116,101,108,101,105,97,0] /* anoteleia\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str361=allocate([69,112,115,105,108,111,110,116,111,110,111,115,0] /* Epsilontonos\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str362=allocate([69,116,97,116,111,110,111,115,0] /* Etatonos\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str363=allocate([73,111,116,97,116,111,110,111,115,0] /* Iotatonos\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str364=allocate([79,109,105,99,114,111,110,116,111,110,111,115,0] /* Omicrontonos\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str365=allocate([85,112,115,105,108,111,110,116,111,110,111,115,0] /* Upsilontonos\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str366=allocate([79,109,101,103,97,116,111,110,111,115,0] /* Omegatonos\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str367=allocate([105,111,116,97,100,105,101,114,101,115,105,115,116,111,110,111,115,0] /* iotadieresistonos\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str368=allocate([65,108,112,104,97,0] /* Alpha\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str369=allocate([66,101,116,97,0] /* Beta\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str370=allocate([71,97,109,109,97,0] /* Gamma\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str371=allocate([68,101,108,116,97,0] /* Delta\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str372=allocate([69,112,115,105,108,111,110,0] /* Epsilon\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str373=allocate([90,101,116,97,0] /* Zeta\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str374=allocate([69,116,97,0] /* Eta\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str375=allocate([84,104,101,116,97,0] /* Theta\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str376=allocate([73,111,116,97,0] /* Iota\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str377=allocate([75,97,112,112,97,0] /* Kappa\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str378810=allocate([76,97,109,98,100,97,0] /* Lambda\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str379=allocate([77,117,0] /* Mu\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str380=allocate([78,117,0] /* Nu\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str381=allocate([88,105,0] /* Xi\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str382811=allocate([79,109,105,99,114,111,110,0] /* Omicron\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str383=allocate([80,105,0] /* Pi\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str384=allocate([82,104,111,0] /* Rho\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str385=allocate([83,105,103,109,97,0] /* Sigma\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str386812=allocate([84,97,117,0] /* Tau\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str387=allocate([85,112,115,105,108,111,110,0] /* Upsilon\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str388=allocate([80,104,105,0] /* Phi\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str389=allocate([67,104,105,0] /* Chi\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str390=allocate([80,115,105,0] /* Psi\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str391=allocate([79,109,101,103,97,0] /* Omega\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str392=allocate([73,111,116,97,100,105,101,114,101,115,105,115,0] /* Iotadieresis\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str393=allocate([85,112,115,105,108,111,110,100,105,101,114,101,115,105,115,0] /* Upsilondieresis\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str394813=allocate([97,108,112,104,97,116,111,110,111,115,0] /* alphatonos\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str395=allocate([101,112,115,105,108,111,110,116,111,110,111,115,0] /* epsilontonos\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str396=allocate([101,116,97,116,111,110,111,115,0] /* etatonos\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str397=allocate([105,111,116,97,116,111,110,111,115,0] /* iotatonos\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str398=allocate([117,112,115,105,108,111,110,100,105,101,114,101,115,105,115,116,111,110,111,115,0] /* upsilondieresistonos */, "i8", ALLOC_STATIC);
STRING_TABLE.__str399=allocate([97,108,112,104,97,0] /* alpha\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str400=allocate([98,101,116,97,0] /* beta\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str401=allocate([103,97,109,109,97,0] /* gamma\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str402=allocate([100,101,108,116,97,0] /* delta\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str403=allocate([101,112,115,105,108,111,110,0] /* epsilon\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str404=allocate([122,101,116,97,0] /* zeta\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str405=allocate([101,116,97,0] /* eta\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str406=allocate([116,104,101,116,97,0] /* theta\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str407=allocate([105,111,116,97,0] /* iota\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str408=allocate([107,97,112,112,97,0] /* kappa\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str409814=allocate([108,97,109,98,100,97,0] /* lambda\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str410=allocate([110,117,0] /* nu\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str411=allocate([120,105,0] /* xi\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str412=allocate([111,109,105,99,114,111,110,0] /* omicron\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str413=allocate([112,105,0] /* pi\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str414=allocate([114,104,111,0] /* rho\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str415=allocate([115,105,103,109,97,49,0] /* sigma1\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str416=allocate([115,105,103,109,97,0] /* sigma\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str417=allocate([116,97,117,0] /* tau\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str418=allocate([117,112,115,105,108,111,110,0] /* upsilon\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str419=allocate([112,104,105,0] /* phi\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str420=allocate([99,104,105,0] /* chi\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str421=allocate([112,115,105,0] /* psi\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str422=allocate([111,109,101,103,97,0] /* omega\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str423=allocate([105,111,116,97,100,105,101,114,101,115,105,115,0] /* iotadieresis\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str424815=allocate([117,112,115,105,108,111,110,100,105,101,114,101,115,105,115,0] /* upsilondieresis\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str425=allocate([111,109,105,99,114,111,110,116,111,110,111,115,0] /* omicrontonos\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str426=allocate([117,112,115,105,108,111,110,116,111,110,111,115,0] /* upsilontonos\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str427=allocate([111,109,101,103,97,116,111,110,111,115,0] /* omegatonos\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str428=allocate([116,104,101,116,97,49,0] /* theta1\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str429=allocate([85,112,115,105,108,111,110,49,0] /* Upsilon1\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str430=allocate([112,104,105,49,0] /* phi1\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str431=allocate([111,109,101,103,97,49,0] /* omega1\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str432=allocate([97,102,105,105,49,48,48,50,51,0] /* afii10023\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str433=allocate([97,102,105,105,49,48,48,53,49,0] /* afii10051\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str434=allocate([97,102,105,105,49,48,48,53,50,0] /* afii10052\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str435=allocate([97,102,105,105,49,48,48,53,51,0] /* afii10053\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str436=allocate([97,102,105,105,49,48,48,53,52,0] /* afii10054\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str437=allocate([97,102,105,105,49,48,48,53,53,0] /* afii10055\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str438816=allocate([97,102,105,105,49,48,48,53,54,0] /* afii10056\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str439=allocate([97,102,105,105,49,48,48,53,55,0] /* afii10057\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str440=allocate([97,102,105,105,49,48,48,53,56,0] /* afii10058\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str441=allocate([97,102,105,105,49,48,48,53,57,0] /* afii10059\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str442=allocate([97,102,105,105,49,48,48,54,48,0] /* afii10060\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str443=allocate([97,102,105,105,49,48,48,54,49,0] /* afii10061\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str444=allocate([97,102,105,105,49,48,48,54,50,0] /* afii10062\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str445=allocate([97,102,105,105,49,48,49,52,53,0] /* afii10145\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str446=allocate([97,102,105,105,49,48,48,49,55,0] /* afii10017\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str447=allocate([97,102,105,105,49,48,48,49,56,0] /* afii10018\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str448=allocate([97,102,105,105,49,48,48,49,57,0] /* afii10019\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str449=allocate([97,102,105,105,49,48,48,50,48,0] /* afii10020\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str450=allocate([97,102,105,105,49,48,48,50,49,0] /* afii10021\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str451=allocate([97,102,105,105,49,48,48,50,50,0] /* afii10022\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str452=allocate([97,102,105,105,49,48,48,50,52,0] /* afii10024\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str453=allocate([97,102,105,105,49,48,48,50,53,0] /* afii10025\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str454=allocate([97,102,105,105,49,48,48,50,54,0] /* afii10026\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str455=allocate([97,102,105,105,49,48,48,50,55,0] /* afii10027\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str456=allocate([97,102,105,105,49,48,48,50,56,0] /* afii10028\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str457=allocate([97,102,105,105,49,48,48,50,57,0] /* afii10029\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str458=allocate([97,102,105,105,49,48,48,51,48,0] /* afii10030\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str459=allocate([97,102,105,105,49,48,48,51,49,0] /* afii10031\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str460=allocate([97,102,105,105,49,48,48,51,50,0] /* afii10032\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str461=allocate([97,102,105,105,49,48,48,51,51,0] /* afii10033\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str462=allocate([97,102,105,105,49,48,48,51,52,0] /* afii10034\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str463=allocate([97,102,105,105,49,48,48,51,53,0] /* afii10035\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str464=allocate([97,102,105,105,49,48,48,51,54,0] /* afii10036\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str465=allocate([97,102,105,105,49,48,48,51,55,0] /* afii10037\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str466=allocate([97,102,105,105,49,48,48,51,56,0] /* afii10038\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str467=allocate([97,102,105,105,49,48,48,51,57,0] /* afii10039\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str468=allocate([97,102,105,105,49,48,48,52,48,0] /* afii10040\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str469=allocate([97,102,105,105,49,48,48,52,49,0] /* afii10041\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str470=allocate([97,102,105,105,49,48,48,52,50,0] /* afii10042\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str471=allocate([97,102,105,105,49,48,48,52,51,0] /* afii10043\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str472=allocate([97,102,105,105,49,48,48,52,52,0] /* afii10044\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str473=allocate([97,102,105,105,49,48,48,52,53,0] /* afii10045\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str474=allocate([97,102,105,105,49,48,48,52,54,0] /* afii10046\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str475=allocate([97,102,105,105,49,48,48,52,55,0] /* afii10047\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str476=allocate([97,102,105,105,49,48,48,52,56,0] /* afii10048\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str477=allocate([97,102,105,105,49,48,48,52,57,0] /* afii10049\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str478=allocate([97,102,105,105,49,48,48,54,53,0] /* afii10065\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str479817=allocate([97,102,105,105,49,48,48,54,54,0] /* afii10066\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str480=allocate([97,102,105,105,49,48,48,54,55,0] /* afii10067\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str481=allocate([97,102,105,105,49,48,48,54,56,0] /* afii10068\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str482=allocate([97,102,105,105,49,48,48,54,57,0] /* afii10069\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str483=allocate([97,102,105,105,49,48,48,55,48,0] /* afii10070\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str484=allocate([97,102,105,105,49,48,48,55,50,0] /* afii10072\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str485=allocate([97,102,105,105,49,48,48,55,51,0] /* afii10073\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str486=allocate([97,102,105,105,49,48,48,55,52,0] /* afii10074\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str487=allocate([97,102,105,105,49,48,48,55,53,0] /* afii10075\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str488=allocate([97,102,105,105,49,48,48,55,54,0] /* afii10076\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str489=allocate([97,102,105,105,49,48,48,55,55,0] /* afii10077\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str490=allocate([97,102,105,105,49,48,48,55,56,0] /* afii10078\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str491=allocate([97,102,105,105,49,48,48,55,57,0] /* afii10079\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str492=allocate([97,102,105,105,49,48,48,56,48,0] /* afii10080\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str493=allocate([97,102,105,105,49,48,48,56,49,0] /* afii10081\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str494=allocate([97,102,105,105,49,48,48,56,50,0] /* afii10082\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str495818=allocate([97,102,105,105,49,48,48,56,51,0] /* afii10083\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str496=allocate([97,102,105,105,49,48,48,56,52,0] /* afii10084\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str497=allocate([97,102,105,105,49,48,48,56,53,0] /* afii10085\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str498=allocate([97,102,105,105,49,48,48,56,54,0] /* afii10086\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str499=allocate([97,102,105,105,49,48,48,56,55,0] /* afii10087\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str500=allocate([97,102,105,105,49,48,48,56,56,0] /* afii10088\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str501=allocate([97,102,105,105,49,48,48,56,57,0] /* afii10089\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str502=allocate([97,102,105,105,49,48,48,57,48,0] /* afii10090\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str503=allocate([97,102,105,105,49,48,48,57,49,0] /* afii10091\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str504=allocate([97,102,105,105,49,48,48,57,50,0] /* afii10092\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str505=allocate([97,102,105,105,49,48,48,57,51,0] /* afii10093\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str506=allocate([97,102,105,105,49,48,48,57,52,0] /* afii10094\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str507=allocate([97,102,105,105,49,48,48,57,53,0] /* afii10095\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str508=allocate([97,102,105,105,49,48,48,57,54,0] /* afii10096\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str509=allocate([97,102,105,105,49,48,48,57,55,0] /* afii10097\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str510819=allocate([97,102,105,105,49,48,48,55,49,0] /* afii10071\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str511=allocate([97,102,105,105,49,48,48,57,57,0] /* afii10099\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str512=allocate([97,102,105,105,49,48,49,48,48,0] /* afii10100\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str513=allocate([97,102,105,105,49,48,49,48,49,0] /* afii10101\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str514=allocate([97,102,105,105,49,48,49,48,50,0] /* afii10102\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str515=allocate([97,102,105,105,49,48,49,48,51,0] /* afii10103\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str516=allocate([97,102,105,105,49,48,49,48,52,0] /* afii10104\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str517=allocate([97,102,105,105,49,48,49,48,53,0] /* afii10105\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str518=allocate([97,102,105,105,49,48,49,48,54,0] /* afii10106\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str519=allocate([97,102,105,105,49,48,49,48,55,0] /* afii10107\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str520=allocate([97,102,105,105,49,48,49,48,56,0] /* afii10108\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str521=allocate([97,102,105,105,49,48,49,48,57,0] /* afii10109\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str522=allocate([97,102,105,105,49,48,49,49,48,0] /* afii10110\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str523=allocate([97,102,105,105,49,48,49,57,51,0] /* afii10193\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str524=allocate([97,102,105,105,49,48,49,52,54,0] /* afii10146\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str525820=allocate([97,102,105,105,49,48,49,57,52,0] /* afii10194\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str526=allocate([97,102,105,105,49,48,49,52,55,0] /* afii10147\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str527=allocate([97,102,105,105,49,48,49,57,53,0] /* afii10195\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str528=allocate([97,102,105,105,49,48,49,52,56,0] /* afii10148\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str529=allocate([97,102,105,105,49,48,49,57,54,0] /* afii10196\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str530=allocate([97,102,105,105,49,48,48,53,48,0] /* afii10050\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str531=allocate([97,102,105,105,49,48,48,57,56,0] /* afii10098\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str532=allocate([97,102,105,105,49,48,56,52,54,0] /* afii10846\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str533=allocate([97,102,105,105,53,55,55,57,57,0] /* afii57799\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str534=allocate([97,102,105,105,53,55,56,48,49,0] /* afii57801\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str535=allocate([97,102,105,105,53,55,56,48,48,0] /* afii57800\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str536=allocate([97,102,105,105,53,55,56,48,50,0] /* afii57802\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str537=allocate([97,102,105,105,53,55,55,57,51,0] /* afii57793\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str538=allocate([97,102,105,105,53,55,55,57,52,0] /* afii57794\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str539821=allocate([97,102,105,105,53,55,55,57,53,0] /* afii57795\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str540=allocate([97,102,105,105,53,55,55,57,56,0] /* afii57798\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str541=allocate([97,102,105,105,53,55,55,57,55,0] /* afii57797\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str542=allocate([97,102,105,105,53,55,56,48,54,0] /* afii57806\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str543=allocate([97,102,105,105,53,55,55,57,54,0] /* afii57796\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str544=allocate([97,102,105,105,53,55,56,48,55,0] /* afii57807\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str545=allocate([97,102,105,105,53,55,56,51,57,0] /* afii57839\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str546=allocate([97,102,105,105,53,55,54,52,53,0] /* afii57645\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str547=allocate([97,102,105,105,53,55,56,52,49,0] /* afii57841\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str548=allocate([97,102,105,105,53,55,56,52,50,0] /* afii57842\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str549=allocate([97,102,105,105,53,55,56,48,52,0] /* afii57804\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str550=allocate([97,102,105,105,53,55,56,48,51,0] /* afii57803\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str551=allocate([97,102,105,105,53,55,54,53,56,0] /* afii57658\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str552=allocate([97,102,105,105,53,55,54,54,52,0] /* afii57664\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str553=allocate([97,102,105,105,53,55,54,54,53,0] /* afii57665\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str554=allocate([97,102,105,105,53,55,54,54,54,0] /* afii57666\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str555=allocate([97,102,105,105,53,55,54,54,55,0] /* afii57667\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str556=allocate([97,102,105,105,53,55,54,54,56,0] /* afii57668\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str557=allocate([97,102,105,105,53,55,54,54,57,0] /* afii57669\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str558=allocate([97,102,105,105,53,55,54,55,48,0] /* afii57670\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str559=allocate([97,102,105,105,53,55,54,55,49,0] /* afii57671\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str560822=allocate([97,102,105,105,53,55,54,55,50,0] /* afii57672\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str561=allocate([97,102,105,105,53,55,54,55,51,0] /* afii57673\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str562=allocate([97,102,105,105,53,55,54,55,52,0] /* afii57674\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str563=allocate([97,102,105,105,53,55,54,55,53,0] /* afii57675\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str564=allocate([97,102,105,105,53,55,54,55,54,0] /* afii57676\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str565=allocate([97,102,105,105,53,55,54,55,55,0] /* afii57677\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str566=allocate([97,102,105,105,53,55,54,55,56,0] /* afii57678\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str567=allocate([97,102,105,105,53,55,54,55,57,0] /* afii57679\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str568=allocate([97,102,105,105,53,55,54,56,48,0] /* afii57680\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str569823=allocate([97,102,105,105,53,55,54,56,49,0] /* afii57681\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str570824=allocate([97,102,105,105,53,55,54,56,50,0] /* afii57682\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str571=allocate([97,102,105,105,53,55,54,56,51,0] /* afii57683\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str572=allocate([97,102,105,105,53,55,54,56,52,0] /* afii57684\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str573=allocate([97,102,105,105,53,55,54,56,53,0] /* afii57685\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str574825=allocate([97,102,105,105,53,55,54,56,54,0] /* afii57686\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str575=allocate([97,102,105,105,53,55,54,56,55,0] /* afii57687\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str576=allocate([97,102,105,105,53,55,54,56,56,0] /* afii57688\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str577=allocate([97,102,105,105,53,55,54,56,57,0] /* afii57689\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str578=allocate([97,102,105,105,53,55,54,57,48,0] /* afii57690\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str579=allocate([97,102,105,105,53,55,55,49,54,0] /* afii57716\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str580826=allocate([97,102,105,105,53,55,55,49,55,0] /* afii57717\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str581=allocate([97,102,105,105,53,55,55,49,56,0] /* afii57718\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str582=allocate([97,102,105,105,53,55,51,56,56,0] /* afii57388\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str583=allocate([97,102,105,105,53,55,52,48,51,0] /* afii57403\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str584=allocate([97,102,105,105,53,55,52,48,55,0] /* afii57407\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str585=allocate([97,102,105,105,53,55,52,48,57,0] /* afii57409\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str586=allocate([97,102,105,105,53,55,52,49,48,0] /* afii57410\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str587=allocate([97,102,105,105,53,55,52,49,49,0] /* afii57411\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str588=allocate([97,102,105,105,53,55,52,49,50,0] /* afii57412\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str589=allocate([97,102,105,105,53,55,52,49,51,0] /* afii57413\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str590=allocate([97,102,105,105,53,55,52,49,52,0] /* afii57414\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str591=allocate([97,102,105,105,53,55,52,49,53,0] /* afii57415\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str592=allocate([97,102,105,105,53,55,52,49,54,0] /* afii57416\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str593=allocate([97,102,105,105,53,55,52,49,55,0] /* afii57417\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str594=allocate([97,102,105,105,53,55,52,49,56,0] /* afii57418\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str595=allocate([97,102,105,105,53,55,52,49,57,0] /* afii57419\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str596827=allocate([97,102,105,105,53,55,52,50,48,0] /* afii57420\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str597=allocate([97,102,105,105,53,55,52,50,49,0] /* afii57421\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str598828=allocate([97,102,105,105,53,55,52,50,50,0] /* afii57422\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str599=allocate([97,102,105,105,53,55,52,50,51,0] /* afii57423\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str600=allocate([97,102,105,105,53,55,52,50,52,0] /* afii57424\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str601=allocate([97,102,105,105,53,55,52,50,53,0] /* afii57425\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str602=allocate([97,102,105,105,53,55,52,50,54,0] /* afii57426\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str603=allocate([97,102,105,105,53,55,52,50,55,0] /* afii57427\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str604=allocate([97,102,105,105,53,55,52,50,56,0] /* afii57428\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str605=allocate([97,102,105,105,53,55,52,50,57,0] /* afii57429\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str606=allocate([97,102,105,105,53,55,52,51,48,0] /* afii57430\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str607829=allocate([97,102,105,105,53,55,52,51,49,0] /* afii57431\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str608=allocate([97,102,105,105,53,55,52,51,50,0] /* afii57432\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str609=allocate([97,102,105,105,53,55,52,51,51,0] /* afii57433\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str610=allocate([97,102,105,105,53,55,52,51,52,0] /* afii57434\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str611=allocate([97,102,105,105,53,55,52,52,48,0] /* afii57440\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str612=allocate([97,102,105,105,53,55,52,52,49,0] /* afii57441\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str613=allocate([97,102,105,105,53,55,52,52,50,0] /* afii57442\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str614=allocate([97,102,105,105,53,55,52,52,51,0] /* afii57443\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str615=allocate([97,102,105,105,53,55,52,52,52,0] /* afii57444\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str616=allocate([97,102,105,105,53,55,52,52,53,0] /* afii57445\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str617=allocate([97,102,105,105,53,55,52,52,54,0] /* afii57446\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str618=allocate([97,102,105,105,53,55,52,55,48,0] /* afii57470\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str619=allocate([97,102,105,105,53,55,52,52,56,0] /* afii57448\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str620=allocate([97,102,105,105,53,55,52,52,57,0] /* afii57449\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str621=allocate([97,102,105,105,53,55,52,53,48,0] /* afii57450\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str622=allocate([97,102,105,105,53,55,52,53,49,0] /* afii57451\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str623=allocate([97,102,105,105,53,55,52,53,50,0] /* afii57452\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str624=allocate([97,102,105,105,53,55,52,53,51,0] /* afii57453\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str625=allocate([97,102,105,105,53,55,52,53,52,0] /* afii57454\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str626830=allocate([97,102,105,105,53,55,52,53,53,0] /* afii57455\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str627=allocate([97,102,105,105,53,55,52,53,54,0] /* afii57456\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str628=allocate([97,102,105,105,53,55,52,53,55,0] /* afii57457\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str629=allocate([97,102,105,105,53,55,52,53,56,0] /* afii57458\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str630831=allocate([97,102,105,105,53,55,51,57,50,0] /* afii57392\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str631=allocate([97,102,105,105,53,55,51,57,51,0] /* afii57393\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str632=allocate([97,102,105,105,53,55,51,57,52,0] /* afii57394\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str633=allocate([97,102,105,105,53,55,51,57,53,0] /* afii57395\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str634=allocate([97,102,105,105,53,55,51,57,54,0] /* afii57396\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str635=allocate([97,102,105,105,53,55,51,57,55,0] /* afii57397\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str636=allocate([97,102,105,105,53,55,51,57,56,0] /* afii57398\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str637=allocate([97,102,105,105,53,55,51,57,57,0] /* afii57399\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str638=allocate([97,102,105,105,53,55,52,48,48,0] /* afii57400\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str639=allocate([97,102,105,105,53,55,52,48,49,0] /* afii57401\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str640832=allocate([97,102,105,105,53,55,51,56,49,0] /* afii57381\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str641=allocate([97,102,105,105,54,51,49,54,55,0] /* afii63167\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str642=allocate([97,102,105,105,53,55,53,49,49,0] /* afii57511\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str643=allocate([97,102,105,105,53,55,53,48,54,0] /* afii57506\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str644=allocate([97,102,105,105,53,55,53,48,55,0] /* afii57507\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str645=allocate([97,102,105,105,53,55,53,49,50,0] /* afii57512\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str646=allocate([97,102,105,105,53,55,53,49,51,0] /* afii57513\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str647833=allocate([97,102,105,105,53,55,53,48,56,0] /* afii57508\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str648=allocate([97,102,105,105,53,55,53,48,53,0] /* afii57505\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str649834=allocate([97,102,105,105,53,55,53,48,57,0] /* afii57509\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str650=allocate([97,102,105,105,53,55,53,49,52,0] /* afii57514\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str651=allocate([97,102,105,105,53,55,53,49,57,0] /* afii57519\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str652=allocate([97,102,105,105,53,55,53,51,52,0] /* afii57534\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str653=allocate([87,103,114,97,118,101,0] /* Wgrave\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str654=allocate([119,103,114,97,118,101,0] /* wgrave\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str655=allocate([87,97,99,117,116,101,0] /* Wacute\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str656=allocate([119,97,99,117,116,101,0] /* wacute\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str657=allocate([87,100,105,101,114,101,115,105,115,0] /* Wdieresis\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str658=allocate([119,100,105,101,114,101,115,105,115,0] /* wdieresis\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str659=allocate([89,103,114,97,118,101,0] /* Ygrave\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str660=allocate([121,103,114,97,118,101,0] /* ygrave\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str661=allocate([97,102,105,105,54,49,54,54,52,0] /* afii61664\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str662=allocate([97,102,105,105,51,48,49,0] /* afii301\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str663=allocate([97,102,105,105,50,57,57,0] /* afii299\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str664=allocate([97,102,105,105,51,48,48,0] /* afii300\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str665=allocate([102,105,103,117,114,101,100,97,115,104,0] /* figuredash\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str666=allocate([101,110,100,97,115,104,0] /* endash\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str667=allocate([101,109,100,97,115,104,0] /* emdash\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str668=allocate([97,102,105,105,48,48,50,48,56,0] /* afii00208\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str669=allocate([117,110,100,101,114,115,99,111,114,101,100,98,108,0] /* underscoredbl\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str670=allocate([113,117,111,116,101,108,101,102,116,0] /* quoteleft\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str671=allocate([113,117,111,116,101,114,105,103,104,116,0] /* quoteright\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str672=allocate([113,117,111,116,101,115,105,110,103,108,98,97,115,101,0] /* quotesinglbase\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str673=allocate([113,117,111,116,101,114,101,118,101,114,115,101,100,0] /* quotereversed\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str674=allocate([113,117,111,116,101,100,98,108,108,101,102,116,0] /* quotedblleft\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str675=allocate([113,117,111,116,101,100,98,108,114,105,103,104,116,0] /* quotedblright\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str676=allocate([113,117,111,116,101,100,98,108,98,97,115,101,0] /* quotedblbase\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str677=allocate([100,97,103,103,101,114,0] /* dagger\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str678=allocate([100,97,103,103,101,114,100,98,108,0] /* daggerdbl\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str679=allocate([98,117,108,108,101,116,0] /* bullet\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str680=allocate([111,110,101,100,111,116,101,110,108,101,97,100,101,114,0] /* onedotenleader\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str681835=allocate([116,119,111,100,111,116,101,110,108,101,97,100,101,114,0] /* twodotenleader\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str682=allocate([101,108,108,105,112,115,105,115,0] /* ellipsis\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str683=allocate([97,102,105,105,54,49,53,55,51,0] /* afii61573\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str684=allocate([97,102,105,105,54,49,53,55,52,0] /* afii61574\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str685=allocate([97,102,105,105,54,49,53,55,53,0] /* afii61575\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str686=allocate([112,101,114,116,104,111,117,115,97,110,100,0] /* perthousand\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str687=allocate([109,105,110,117,116,101,0] /* minute\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str688=allocate([115,101,99,111,110,100,0] /* second\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str689=allocate([103,117,105,108,115,105,110,103,108,108,101,102,116,0] /* guilsinglleft\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str690=allocate([103,117,105,108,115,105,110,103,108,114,105,103,104,116,0] /* guilsinglright\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str691=allocate([101,120,99,108,97,109,100,98,108,0] /* exclamdbl\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str692=allocate([102,114,97,99,116,105,111,110,0] /* fraction\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str693=allocate([122,101,114,111,115,117,112,101,114,105,111,114,0] /* zerosuperior\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str694=allocate([102,111,117,114,115,117,112,101,114,105,111,114,0] /* foursuperior\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str695=allocate([102,105,118,101,115,117,112,101,114,105,111,114,0] /* fivesuperior\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str696=allocate([115,105,120,115,117,112,101,114,105,111,114,0] /* sixsuperior\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str697836=allocate([115,101,118,101,110,115,117,112,101,114,105,111,114,0] /* sevensuperior\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str698=allocate([101,105,103,104,116,115,117,112,101,114,105,111,114,0] /* eightsuperior\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str699=allocate([110,105,110,101,115,117,112,101,114,105,111,114,0] /* ninesuperior\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str700=allocate([112,97,114,101,110,108,101,102,116,115,117,112,101,114,105,111,114,0] /* parenleftsuperior\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str701=allocate([112,97,114,101,110,114,105,103,104,116,115,117,112,101,114,105,111,114,0] /* parenrightsuperior\0 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str702=allocate([110,115,117,112,101,114,105,111,114,0] /* nsuperior\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str703=allocate([122,101,114,111,105,110,102,101,114,105,111,114,0] /* zeroinferior\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str704=allocate([111,110,101,105,110,102,101,114,105,111,114,0] /* oneinferior\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str705=allocate([116,119,111,105,110,102,101,114,105,111,114,0] /* twoinferior\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str706=allocate([116,104,114,101,101,105,110,102,101,114,105,111,114,0] /* threeinferior\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str707=allocate([102,111,117,114,105,110,102,101,114,105,111,114,0] /* fourinferior\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str708=allocate([102,105,118,101,105,110,102,101,114,105,111,114,0] /* fiveinferior\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str709=allocate([115,105,120,105,110,102,101,114,105,111,114,0] /* sixinferior\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str710=allocate([115,101,118,101,110,105,110,102,101,114,105,111,114,0] /* seveninferior\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str711=allocate([101,105,103,104,116,105,110,102,101,114,105,111,114,0] /* eightinferior\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str712=allocate([110,105,110,101,105,110,102,101,114,105,111,114,0] /* nineinferior\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str713=allocate([112,97,114,101,110,108,101,102,116,105,110,102,101,114,105,111,114,0] /* parenleftinferior\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str714=allocate([112,97,114,101,110,114,105,103,104,116,105,110,102,101,114,105,111,114,0] /* parenrightinferior\0 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str715=allocate([99,111,108,111,110,109,111,110,101,116,97,114,121,0] /* colonmonetary\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str716=allocate([102,114,97,110,99,0] /* franc\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str717=allocate([108,105,114,97,0] /* lira\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str718=allocate([112,101,115,101,116,97,0] /* peseta\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str719=allocate([97,102,105,105,53,55,54,51,54,0] /* afii57636\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str720=allocate([100,111,110,103,0] /* dong\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str721=allocate([69,117,114,111,0] /* Euro\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str722=allocate([97,102,105,105,54,49,50,52,56,0] /* afii61248\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str723=allocate([73,102,114,97,107,116,117,114,0] /* Ifraktur\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str724=allocate([97,102,105,105,54,49,50,56,57,0] /* afii61289\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str725=allocate([97,102,105,105,54,49,51,53,50,0] /* afii61352\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str726=allocate([119,101,105,101,114,115,116,114,97,115,115,0] /* weierstrass\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str727837=allocate([82,102,114,97,107,116,117,114,0] /* Rfraktur\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str728=allocate([112,114,101,115,99,114,105,112,116,105,111,110,0] /* prescription\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str729=allocate([116,114,97,100,101,109,97,114,107,0] /* trademark\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str730=allocate([101,115,116,105,109,97,116,101,100,0] /* estimated\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str731=allocate([97,108,101,112,104,0] /* aleph\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str732=allocate([111,110,101,116,104,105,114,100,0] /* onethird\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str733=allocate([116,119,111,116,104,105,114,100,115,0] /* twothirds\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str734=allocate([111,110,101,101,105,103,104,116,104,0] /* oneeighth\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str735=allocate([116,104,114,101,101,101,105,103,104,116,104,115,0] /* threeeighths\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str736=allocate([102,105,118,101,101,105,103,104,116,104,115,0] /* fiveeighths\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str737=allocate([115,101,118,101,110,101,105,103,104,116,104,115,0] /* seveneighths\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str738=allocate([97,114,114,111,119,108,101,102,116,0] /* arrowleft\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str739=allocate([97,114,114,111,119,117,112,0] /* arrowup\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str740=allocate([97,114,114,111,119,114,105,103,104,116,0] /* arrowright\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str741838=allocate([97,114,114,111,119,100,111,119,110,0] /* arrowdown\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str742=allocate([97,114,114,111,119,98,111,116,104,0] /* arrowboth\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str743=allocate([97,114,114,111,119,117,112,100,110,0] /* arrowupdn\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str744=allocate([97,114,114,111,119,117,112,100,110,98,115,101,0] /* arrowupdnbse\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str745=allocate([99,97,114,114,105,97,103,101,114,101,116,117,114,110,0] /* carriagereturn\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str746=allocate([97,114,114,111,119,100,98,108,108,101,102,116,0] /* arrowdblleft\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str747=allocate([97,114,114,111,119,100,98,108,117,112,0] /* arrowdblup\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str748=allocate([97,114,114,111,119,100,98,108,114,105,103,104,116,0] /* arrowdblright\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str749=allocate([97,114,114,111,119,100,98,108,100,111,119,110,0] /* arrowdbldown\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str750=allocate([97,114,114,111,119,100,98,108,98,111,116,104,0] /* arrowdblboth\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str751=allocate([117,110,105,118,101,114,115,97,108,0] /* universal\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str752=allocate([112,97,114,116,105,97,108,100,105,102,102,0] /* partialdiff\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str753=allocate([101,120,105,115,116,101,110,116,105,97,108,0] /* existential\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str754=allocate([101,109,112,116,121,115,101,116,0] /* emptyset\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str755=allocate([103,114,97,100,105,101,110,116,0] /* gradient\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str756=allocate([101,108,101,109,101,110,116,0] /* element\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str757=allocate([110,111,116,101,108,101,109,101,110,116,0] /* notelement\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str758=allocate([115,117,99,104,116,104,97,116,0] /* suchthat\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str759=allocate([112,114,111,100,117,99,116,0] /* product\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str760=allocate([115,117,109,109,97,116,105,111,110,0] /* summation\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str761=allocate([109,105,110,117,115,0] /* minus\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str762=allocate([97,115,116,101,114,105,115,107,109,97,116,104,0] /* asteriskmath\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str763=allocate([114,97,100,105,99,97,108,0] /* radical\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str764=allocate([112,114,111,112,111,114,116,105,111,110,97,108,0] /* proportional\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str765=allocate([105,110,102,105,110,105,116,121,0] /* infinity\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str766=allocate([111,114,116,104,111,103,111,110,97,108,0] /* orthogonal\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str767=allocate([97,110,103,108,101,0] /* angle\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str768=allocate([108,111,103,105,99,97,108,97,110,100,0] /* logicaland\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str769=allocate([108,111,103,105,99,97,108,111,114,0] /* logicalor\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str770=allocate([105,110,116,101,114,115,101,99,116,105,111,110,0] /* intersection\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str771=allocate([117,110,105,111,110,0] /* union\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str772=allocate([105,110,116,101,103,114,97,108,0] /* integral\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str773=allocate([116,104,101,114,101,102,111,114,101,0] /* therefore\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str774=allocate([115,105,109,105,108,97,114,0] /* similar\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str775=allocate([99,111,110,103,114,117,101,110,116,0] /* congruent\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str776=allocate([97,112,112,114,111,120,101,113,117,97,108,0] /* approxequal\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str777=allocate([110,111,116,101,113,117,97,108,0] /* notequal\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str778=allocate([101,113,117,105,118,97,108,101,110,99,101,0] /* equivalence\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str779=allocate([108,101,115,115,101,113,117,97,108,0] /* lessequal\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str780=allocate([103,114,101,97,116,101,114,101,113,117,97,108,0] /* greaterequal\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str781=allocate([112,114,111,112,101,114,115,117,98,115,101,116,0] /* propersubset\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str782839=allocate([112,114,111,112,101,114,115,117,112,101,114,115,101,116,0] /* propersuperset\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str783=allocate([110,111,116,115,117,98,115,101,116,0] /* notsubset\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str784=allocate([114,101,102,108,101,120,115,117,98,115,101,116,0] /* reflexsubset\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str785=allocate([114,101,102,108,101,120,115,117,112,101,114,115,101,116,0] /* reflexsuperset\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str786=allocate([99,105,114,99,108,101,112,108,117,115,0] /* circleplus\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str787=allocate([99,105,114,99,108,101,109,117,108,116,105,112,108,121,0] /* circlemultiply\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str788=allocate([112,101,114,112,101,110,100,105,99,117,108,97,114,0] /* perpendicular\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str789=allocate([100,111,116,109,97,116,104,0] /* dotmath\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str790=allocate([104,111,117,115,101,0] /* house\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str791=allocate([114,101,118,108,111,103,105,99,97,108,110,111,116,0] /* revlogicalnot\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str792=allocate([105,110,116,101,103,114,97,108,116,112,0] /* integraltp\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str793=allocate([105,110,116,101,103,114,97,108,98,116,0] /* integralbt\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str794=allocate([97,110,103,108,101,108,101,102,116,0] /* angleleft\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str795=allocate([97,110,103,108,101,114,105,103,104,116,0] /* angleright\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str796=allocate([83,70,49,48,48,48,48,48,0] /* SF100000\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str797=allocate([83,70,49,49,48,48,48,48,0] /* SF110000\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str798840=allocate([83,70,48,49,48,48,48,48,0] /* SF010000\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str799=allocate([83,70,48,51,48,48,48,48,0] /* SF030000\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str800=allocate([83,70,48,50,48,48,48,48,0] /* SF020000\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str801=allocate([83,70,48,52,48,48,48,48,0] /* SF040000\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str802=allocate([83,70,48,56,48,48,48,48,0] /* SF080000\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str803=allocate([83,70,48,57,48,48,48,48,0] /* SF090000\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str804=allocate([83,70,48,54,48,48,48,48,0] /* SF060000\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str805=allocate([83,70,48,55,48,48,48,48,0] /* SF070000\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str806=allocate([83,70,48,53,48,48,48,48,0] /* SF050000\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str807=allocate([83,70,52,51,48,48,48,48,0] /* SF430000\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str808=allocate([83,70,50,52,48,48,48,48,0] /* SF240000\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str809=allocate([83,70,53,49,48,48,48,48,0] /* SF510000\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str810=allocate([83,70,53,50,48,48,48,48,0] /* SF520000\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str811=allocate([83,70,51,57,48,48,48,48,0] /* SF390000\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str812=allocate([83,70,50,50,48,48,48,48,0] /* SF220000\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str813=allocate([83,70,50,49,48,48,48,48,0] /* SF210000\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str814=allocate([83,70,50,53,48,48,48,48,0] /* SF250000\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str815=allocate([83,70,53,48,48,48,48,48,0] /* SF500000\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str816=allocate([83,70,52,57,48,48,48,48,0] /* SF490000\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str817=allocate([83,70,51,56,48,48,48,48,0] /* SF380000\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str818=allocate([83,70,50,56,48,48,48,48,0] /* SF280000\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str819=allocate([83,70,50,55,48,48,48,48,0] /* SF270000\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str820=allocate([83,70,50,54,48,48,48,48,0] /* SF260000\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str821=allocate([83,70,51,54,48,48,48,48,0] /* SF360000\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str822=allocate([83,70,51,55,48,48,48,48,0] /* SF370000\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str823=allocate([83,70,52,50,48,48,48,48,0] /* SF420000\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str824=allocate([83,70,49,57,48,48,48,48,0] /* SF190000\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str825=allocate([83,70,50,48,48,48,48,48,0] /* SF200000\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str826=allocate([83,70,50,51,48,48,48,48,0] /* SF230000\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str827=allocate([83,70,52,55,48,48,48,48,0] /* SF470000\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str828841=allocate([83,70,52,56,48,48,48,48,0] /* SF480000\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str829=allocate([83,70,52,49,48,48,48,48,0] /* SF410000\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str830=allocate([83,70,52,53,48,48,48,48,0] /* SF450000\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str831=allocate([83,70,52,54,48,48,48,48,0] /* SF460000\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str832=allocate([83,70,52,48,48,48,48,48,0] /* SF400000\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str833=allocate([83,70,53,52,48,48,48,48,0] /* SF540000\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str834=allocate([83,70,53,51,48,48,48,48,0] /* SF530000\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str835=allocate([83,70,52,52,48,48,48,48,0] /* SF440000\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str836=allocate([117,112,98,108,111,99,107,0] /* upblock\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str837=allocate([100,110,98,108,111,99,107,0] /* dnblock\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str838=allocate([98,108,111,99,107,0] /* block\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str839=allocate([108,102,98,108,111,99,107,0] /* lfblock\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str840=allocate([114,116,98,108,111,99,107,0] /* rtblock\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str841=allocate([108,116,115,104,97,100,101,0] /* ltshade\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str842842=allocate([115,104,97,100,101,0] /* shade\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str843=allocate([100,107,115,104,97,100,101,0] /* dkshade\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str844=allocate([102,105,108,108,101,100,98,111,120,0] /* filledbox\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str845=allocate([72,50,50,48,55,51,0] /* H22073\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str846=allocate([72,49,56,53,52,51,0] /* H18543\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str847=allocate([72,49,56,53,53,49,0] /* H18551\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str848=allocate([102,105,108,108,101,100,114,101,99,116,0] /* filledrect\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str849=allocate([116,114,105,97,103,117,112,0] /* triagup\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str850=allocate([116,114,105,97,103,114,116,0] /* triagrt\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str851=allocate([116,114,105,97,103,100,110,0] /* triagdn\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str852=allocate([116,114,105,97,103,108,102,0] /* triaglf\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str853=allocate([108,111,122,101,110,103,101,0] /* lozenge\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str854=allocate([99,105,114,99,108,101,0] /* circle\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str855=allocate([72,49,56,53,51,51,0] /* H18533\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str856=allocate([105,110,118,98,117,108,108,101,116,0] /* invbullet\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str857=allocate([105,110,118,99,105,114,99,108,101,0] /* invcircle\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str858=allocate([111,112,101,110,98,117,108,108,101,116,0] /* openbullet\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str859=allocate([115,109,105,108,101,102,97,99,101,0] /* smileface\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str860=allocate([105,110,118,115,109,105,108,101,102,97,99,101,0] /* invsmileface\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str861=allocate([115,117,110,0] /* sun\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str862=allocate([102,101,109,97,108,101,0] /* female\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str863=allocate([109,97,108,101,0] /* male\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str864=allocate([115,112,97,100,101,0] /* spade\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str865=allocate([99,108,117,98,0] /* club\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str866=allocate([104,101,97,114,116,0] /* heart\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str867=allocate([100,105,97,109,111,110,100,0] /* diamond\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str868=allocate([109,117,115,105,99,97,108,110,111,116,101,0] /* musicalnote\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str869=allocate([109,117,115,105,99,97,108,110,111,116,101,100,98,108,0] /* musicalnotedbl\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str870=allocate([100,111,116,108,101,115,115,106,0] /* dotlessj\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str871=allocate([76,76,0] /* LL\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str872=allocate([108,108,0] /* ll\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str873=allocate([99,111,109,109,97,97,99,99,101,110,116,0] /* commaaccent\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str874=allocate([97,102,105,105,49,48,48,54,51,0] /* afii10063\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str875=allocate([97,102,105,105,49,48,48,54,52,0] /* afii10064\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str876=allocate([97,102,105,105,49,48,49,57,50,0] /* afii10192\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str877=allocate([97,102,105,105,49,48,56,51,49,0] /* afii10831\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str878=allocate([97,102,105,105,49,48,56,51,50,0] /* afii10832\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str879=allocate([65,99,117,116,101,0] /* Acute\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str880=allocate([67,97,114,111,110,0] /* Caron\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str881=allocate([68,105,101,114,101,115,105,115,0] /* Dieresis\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str882=allocate([68,105,101,114,101,115,105,115,65,99,117,116,101,0] /* DieresisAcute\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str883843=allocate([68,105,101,114,101,115,105,115,71,114,97,118,101,0] /* DieresisGrave\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str884=allocate([71,114,97,118,101,0] /* Grave\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str885=allocate([72,117,110,103,97,114,117,109,108,97,117,116,0] /* Hungarumlaut\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str886=allocate([77,97,99,114,111,110,0] /* Macron\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str887=allocate([99,121,114,66,114,101,118,101,0] /* cyrBreve\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str888=allocate([99,121,114,70,108,101,120,0] /* cyrFlex\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str889=allocate([100,98,108,71,114,97,118,101,0] /* dblGrave\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str890=allocate([99,121,114,98,114,101,118,101,0] /* cyrbreve\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str891=allocate([99,121,114,102,108,101,120,0] /* cyrflex\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str892=allocate([100,98,108,103,114,97,118,101,0] /* dblgrave\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str893=allocate([100,105,101,114,101,115,105,115,97,99,117,116,101,0] /* dieresisacute\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str894=allocate([100,105,101,114,101,115,105,115,103,114,97,118,101,0] /* dieresisgrave\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str895=allocate([99,111,112,121,114,105,103,104,116,115,101,114,105,102,0] /* copyrightserif\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str896=allocate([114,101,103,105,115,116,101,114,115,101,114,105,102,0] /* registerserif\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str897=allocate([116,114,97,100,101,109,97,114,107,115,101,114,105,102,0] /* trademarkserif\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str898=allocate([111,110,101,102,105,116,116,101,100,0] /* onefitted\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str899844=allocate([114,117,112,105,97,104,0] /* rupiah\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str900=allocate([116,104,114,101,101,113,117,97,114,116,101,114,115,101,109,100,97,115,104,0] /* threequartersemdash\ */, "i8", ALLOC_STATIC);
STRING_TABLE.__str901=allocate([99,101,110,116,105,110,102,101,114,105,111,114,0] /* centinferior\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str902=allocate([99,101,110,116,115,117,112,101,114,105,111,114,0] /* centsuperior\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str903=allocate([99,111,109,109,97,105,110,102,101,114,105,111,114,0] /* commainferior\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str904=allocate([99,111,109,109,97,115,117,112,101,114,105,111,114,0] /* commasuperior\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str905=allocate([100,111,108,108,97,114,105,110,102,101,114,105,111,114,0] /* dollarinferior\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str906=allocate([100,111,108,108,97,114,115,117,112,101,114,105,111,114,0] /* dollarsuperior\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str907=allocate([104,121,112,104,101,110,105,110,102,101,114,105,111,114,0] /* hypheninferior\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str908=allocate([104,121,112,104,101,110,115,117,112,101,114,105,111,114,0] /* hyphensuperior\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str909=allocate([112,101,114,105,111,100,105,110,102,101,114,105,111,114,0] /* periodinferior\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str910=allocate([112,101,114,105,111,100,115,117,112,101,114,105,111,114,0] /* periodsuperior\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str911=allocate([97,115,117,112,101,114,105,111,114,0] /* asuperior\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str912=allocate([98,115,117,112,101,114,105,111,114,0] /* bsuperior\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str913=allocate([100,115,117,112,101,114,105,111,114,0] /* dsuperior\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str914=allocate([101,115,117,112,101,114,105,111,114,0] /* esuperior\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str915=allocate([105,115,117,112,101,114,105,111,114,0] /* isuperior\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str916=allocate([108,115,117,112,101,114,105,111,114,0] /* lsuperior\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str917=allocate([109,115,117,112,101,114,105,111,114,0] /* msuperior\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str918=allocate([111,115,117,112,101,114,105,111,114,0] /* osuperior\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str919=allocate([114,115,117,112,101,114,105,111,114,0] /* rsuperior\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str920=allocate([115,115,117,112,101,114,105,111,114,0] /* ssuperior\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str921=allocate([116,115,117,112,101,114,105,111,114,0] /* tsuperior\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str922=allocate([66,114,101,118,101,115,109,97,108,108,0] /* Brevesmall\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str923=allocate([67,97,114,111,110,115,109,97,108,108,0] /* Caronsmall\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str924=allocate([67,105,114,99,117,109,102,108,101,120,115,109,97,108,108,0] /* Circumflexsmall\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str925=allocate([68,111,116,97,99,99,101,110,116,115,109,97,108,108,0] /* Dotaccentsmall\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str926=allocate([72,117,110,103,97,114,117,109,108,97,117,116,115,109,97,108,108,0] /* Hungarumlautsmall\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str927=allocate([76,115,108,97,115,104,115,109,97,108,108,0] /* Lslashsmall\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str928=allocate([79,69,115,109,97,108,108,0] /* OEsmall\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str929=allocate([79,103,111,110,101,107,115,109,97,108,108,0] /* Ogoneksmall\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str930=allocate([82,105,110,103,115,109,97,108,108,0] /* Ringsmall\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str931=allocate([83,99,97,114,111,110,115,109,97,108,108,0] /* Scaronsmall\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str932=allocate([84,105,108,100,101,115,109,97,108,108,0] /* Tildesmall\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str933=allocate([90,99,97,114,111,110,115,109,97,108,108,0] /* Zcaronsmall\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str934=allocate([101,120,99,108,97,109,115,109,97,108,108,0] /* exclamsmall\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str935=allocate([100,111,108,108,97,114,111,108,100,115,116,121,108,101,0] /* dollaroldstyle\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str936=allocate([97,109,112,101,114,115,97,110,100,115,109,97,108,108,0] /* ampersandsmall\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str937=allocate([122,101,114,111,111,108,100,115,116,121,108,101,0] /* zerooldstyle\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str938=allocate([111,110,101,111,108,100,115,116,121,108,101,0] /* oneoldstyle\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str939=allocate([116,119,111,111,108,100,115,116,121,108,101,0] /* twooldstyle\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str940=allocate([116,104,114,101,101,111,108,100,115,116,121,108,101,0] /* threeoldstyle\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str941=allocate([102,111,117,114,111,108,100,115,116,121,108,101,0] /* fouroldstyle\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str942=allocate([102,105,118,101,111,108,100,115,116,121,108,101,0] /* fiveoldstyle\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str943845=allocate([115,105,120,111,108,100,115,116,121,108,101,0] /* sixoldstyle\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str944=allocate([115,101,118,101,110,111,108,100,115,116,121,108,101,0] /* sevenoldstyle\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str945=allocate([101,105,103,104,116,111,108,100,115,116,121,108,101,0] /* eightoldstyle\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str946=allocate([110,105,110,101,111,108,100,115,116,121,108,101,0] /* nineoldstyle\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str947=allocate([113,117,101,115,116,105,111,110,115,109,97,108,108,0] /* questionsmall\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str948=allocate([71,114,97,118,101,115,109,97,108,108,0] /* Gravesmall\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str949=allocate([65,115,109,97,108,108,0] /* Asmall\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str950=allocate([66,115,109,97,108,108,0] /* Bsmall\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str951=allocate([67,115,109,97,108,108,0] /* Csmall\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str952=allocate([68,115,109,97,108,108,0] /* Dsmall\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str953=allocate([69,115,109,97,108,108,0] /* Esmall\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str954=allocate([70,115,109,97,108,108,0] /* Fsmall\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str955=allocate([71,115,109,97,108,108,0] /* Gsmall\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str956=allocate([72,115,109,97,108,108,0] /* Hsmall\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str957=allocate([73,115,109,97,108,108,0] /* Ismall\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str958=allocate([74,115,109,97,108,108,0] /* Jsmall\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str959=allocate([75,115,109,97,108,108,0] /* Ksmall\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str960=allocate([76,115,109,97,108,108,0] /* Lsmall\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str961=allocate([77,115,109,97,108,108,0] /* Msmall\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str962=allocate([78,115,109,97,108,108,0] /* Nsmall\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str963=allocate([79,115,109,97,108,108,0] /* Osmall\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str964=allocate([80,115,109,97,108,108,0] /* Psmall\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str965=allocate([81,115,109,97,108,108,0] /* Qsmall\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str966=allocate([82,115,109,97,108,108,0] /* Rsmall\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str967=allocate([83,115,109,97,108,108,0] /* Ssmall\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str968=allocate([84,115,109,97,108,108,0] /* Tsmall\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str969=allocate([85,115,109,97,108,108,0] /* Usmall\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str970=allocate([86,115,109,97,108,108,0] /* Vsmall\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str971=allocate([87,115,109,97,108,108,0] /* Wsmall\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str972=allocate([88,115,109,97,108,108,0] /* Xsmall\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str973=allocate([89,115,109,97,108,108,0] /* Ysmall\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str974=allocate([90,115,109,97,108,108,0] /* Zsmall\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str975=allocate([101,120,99,108,97,109,100,111,119,110,115,109,97,108,108,0] /* exclamdownsmall\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str976=allocate([99,101,110,116,111,108,100,115,116,121,108,101,0] /* centoldstyle\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str977=allocate([68,105,101,114,101,115,105,115,115,109,97,108,108,0] /* Dieresissmall\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str978=allocate([77,97,99,114,111,110,115,109,97,108,108,0] /* Macronsmall\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str979=allocate([65,99,117,116,101,115,109,97,108,108,0] /* Acutesmall\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str980=allocate([67,101,100,105,108,108,97,115,109,97,108,108,0] /* Cedillasmall\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str981=allocate([113,117,101,115,116,105,111,110,100,111,119,110,115,109,97,108,108,0] /* questiondownsmall\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str982=allocate([65,103,114,97,118,101,115,109,97,108,108,0] /* Agravesmall\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str983=allocate([65,97,99,117,116,101,115,109,97,108,108,0] /* Aacutesmall\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str984=allocate([65,99,105,114,99,117,109,102,108,101,120,115,109,97,108,108,0] /* Acircumflexsmall\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str985=allocate([65,116,105,108,100,101,115,109,97,108,108,0] /* Atildesmall\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str986846=allocate([65,100,105,101,114,101,115,105,115,115,109,97,108,108,0] /* Adieresissmall\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str987=allocate([65,114,105,110,103,115,109,97,108,108,0] /* Aringsmall\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str988=allocate([65,69,115,109,97,108,108,0] /* AEsmall\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str989=allocate([67,99,101,100,105,108,108,97,115,109,97,108,108,0] /* Ccedillasmall\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str990=allocate([69,103,114,97,118,101,115,109,97,108,108,0] /* Egravesmall\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str991=allocate([69,97,99,117,116,101,115,109,97,108,108,0] /* Eacutesmall\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str992=allocate([69,99,105,114,99,117,109,102,108,101,120,115,109,97,108,108,0] /* Ecircumflexsmall\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str993=allocate([69,100,105,101,114,101,115,105,115,115,109,97,108,108,0] /* Edieresissmall\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str994=allocate([73,103,114,97,118,101,115,109,97,108,108,0] /* Igravesmall\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str995=allocate([73,97,99,117,116,101,115,109,97,108,108,0] /* Iacutesmall\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str996=allocate([73,99,105,114,99,117,109,102,108,101,120,115,109,97,108,108,0] /* Icircumflexsmall\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str997=allocate([73,100,105,101,114,101,115,105,115,115,109,97,108,108,0] /* Idieresissmall\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str998=allocate([69,116,104,115,109,97,108,108,0] /* Ethsmall\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str999=allocate([78,116,105,108,100,101,115,109,97,108,108,0] /* Ntildesmall\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str1000=allocate([79,103,114,97,118,101,115,109,97,108,108,0] /* Ogravesmall\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str1001=allocate([79,97,99,117,116,101,115,109,97,108,108,0] /* Oacutesmall\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str1002=allocate([79,99,105,114,99,117,109,102,108,101,120,115,109,97,108,108,0] /* Ocircumflexsmall\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str1003=allocate([79,116,105,108,100,101,115,109,97,108,108,0] /* Otildesmall\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str1004=allocate([79,100,105,101,114,101,115,105,115,115,109,97,108,108,0] /* Odieresissmall\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str1005=allocate([79,115,108,97,115,104,115,109,97,108,108,0] /* Oslashsmall\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str1006=allocate([85,103,114,97,118,101,115,109,97,108,108,0] /* Ugravesmall\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str1007=allocate([85,97,99,117,116,101,115,109,97,108,108,0] /* Uacutesmall\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str1008=allocate([85,99,105,114,99,117,109,102,108,101,120,115,109,97,108,108,0] /* Ucircumflexsmall\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str1009=allocate([85,100,105,101,114,101,115,105,115,115,109,97,108,108,0] /* Udieresissmall\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str1010=allocate([89,97,99,117,116,101,115,109,97,108,108,0] /* Yacutesmall\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str1011=allocate([84,104,111,114,110,115,109,97,108,108,0] /* Thornsmall\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str1012=allocate([89,100,105,101,114,101,115,105,115,115,109,97,108,108,0] /* Ydieresissmall\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str1013=allocate([114,97,100,105,99,97,108,101,120,0] /* radicalex\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str1014=allocate([97,114,114,111,119,118,101,114,116,101,120,0] /* arrowvertex\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str1015=allocate([97,114,114,111,119,104,111,114,105,122,101,120,0] /* arrowhorizex\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str1016=allocate([114,101,103,105,115,116,101,114,115,97,110,115,0] /* registersans\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str1017=allocate([99,111,112,121,114,105,103,104,116,115,97,110,115,0] /* copyrightsans\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str1018=allocate([116,114,97,100,101,109,97,114,107,115,97,110,115,0] /* trademarksans\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str1019=allocate([112,97,114,101,110,108,101,102,116,116,112,0] /* parenlefttp\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str1020=allocate([112,97,114,101,110,108,101,102,116,101,120,0] /* parenleftex\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str1021=allocate([112,97,114,101,110,108,101,102,116,98,116,0] /* parenleftbt\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str1022=allocate([98,114,97,99,107,101,116,108,101,102,116,116,112,0] /* bracketlefttp\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str1023=allocate([98,114,97,99,107,101,116,108,101,102,116,101,120,0] /* bracketleftex\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str1024=allocate([98,114,97,99,107,101,116,108,101,102,116,98,116,0] /* bracketleftbt\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str1025=allocate([98,114,97,99,101,108,101,102,116,116,112,0] /* bracelefttp\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str1026=allocate([98,114,97,99,101,108,101,102,116,109,105,100,0] /* braceleftmid\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str1027=allocate([98,114,97,99,101,108,101,102,116,98,116,0] /* braceleftbt\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str1028=allocate([98,114,97,99,101,101,120,0] /* braceex\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str1029=allocate([105,110,116,101,103,114,97,108,101,120,0] /* integralex\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str1030=allocate([112,97,114,101,110,114,105,103,104,116,116,112,0] /* parenrighttp\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str1031=allocate([112,97,114,101,110,114,105,103,104,116,101,120,0] /* parenrightex\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str1032=allocate([112,97,114,101,110,114,105,103,104,116,98,116,0] /* parenrightbt\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str1033=allocate([98,114,97,99,107,101,116,114,105,103,104,116,116,112,0] /* bracketrighttp\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str1034=allocate([98,114,97,99,107,101,116,114,105,103,104,116,101,120,0] /* bracketrightex\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str1035=allocate([98,114,97,99,107,101,116,114,105,103,104,116,98,116,0] /* bracketrightbt\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str1036=allocate([98,114,97,99,101,114,105,103,104,116,116,112,0] /* bracerighttp\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str1037=allocate([98,114,97,99,101,114,105,103,104,116,109,105,100,0] /* bracerightmid\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str1038=allocate([98,114,97,99,101,114,105,103,104,116,98,116,0] /* bracerightbt\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str1039=allocate([102,102,0] /* ff\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str1040=allocate([102,105,0] /* fi\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str1041=allocate([102,108,0] /* fl\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str1042=allocate([102,102,105,0] /* ffi\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str1043=allocate([102,102,108,0] /* ffl\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str1044847=allocate([97,102,105,105,53,55,55,48,53,0] /* afii57705\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str1045=allocate([97,102,105,105,53,55,54,57,52,0] /* afii57694\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str1046=allocate([97,102,105,105,53,55,54,57,53,0] /* afii57695\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str1047=allocate([97,102,105,105,53,55,55,50,51,0] /* afii57723\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str1048=allocate([97,102,105,105,53,55,55,48,48,0] /* afii57700\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str1049=allocate([73,83,79,56,56,53,57,45,50,0] /* ISO8859-2\00 */, "i8", ALLOC_STATIC);
_HPDF_UNICODE_MAP_ISO8859_2=allocate([32, 0, 33, 0, 34, 0, 35, 0, 36, 0, 37, 0, 38, 0, 39, 0, 40, 0, 41, 0, 42, 0, 43, 0, 44, 0, 45, 0, 46, 0, 47, 0, 48, 0, 49, 0, 50, 0, 51, 0, 52, 0, 53, 0, 54, 0, 55, 0, 56, 0, 57, 0, 58, 0, 59, 0, 60, 0, 61, 0, 62, 0, 63, 0, 64, 0, 65, 0, 66, 0, 67, 0, 68, 0, 69, 0, 70, 0, 71, 0, 72, 0, 73, 0, 74, 0, 75, 0, 76, 0, 77, 0, 78, 0, 79, 0, 80, 0, 81, 0, 82, 0, 83, 0, 84, 0, 85, 0, 86, 0, 87, 0, 88, 0, 89, 0, 90, 0, 91, 0, 92, 0, 93, 0, 94, 0, 95, 0, 96, 0, 97, 0, 98, 0, 99, 0, 100, 0, 101, 0, 102, 0, 103, 0, 104, 0, 105, 0, 106, 0, 107, 0, 108, 0, 109, 0, 110, 0, 111, 0, 112, 0, 113, 0, 114, 0, 115, 0, 116, 0, 117, 0, 118, 0, 119, 0, 120, 0, 121, 0, 122, 0, 123, 0, 124, 0, 125, 0, 126, 0, 127, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 160, 0, 260, 0, 728, 0, 321, 0, 164, 0, 317, 0, 346, 0, 167, 0, 168, 0, 352, 0, 350, 0, 356, 0, 377, 0, 173, 0, 381, 0, 379, 0, 176, 0, 261, 0, 731, 0, 322, 0, 180, 0, 318, 0, 347, 0, 711, 0, 184, 0, 353, 0, 351, 0, 357, 0, 378, 0, 733, 0, 382, 0, 380, 0, 340, 0, 193, 0, 194, 0, 258, 0, 196, 0, 313, 0, 262, 0, 199, 0, 268, 0, 201, 0, 280, 0, 203, 0, 282, 0, 205, 0, 206, 0, 270, 0, 272, 0, 323, 0, 327, 0, 211, 0, 212, 0, 336, 0, 214, 0, 215, 0, 344, 0, 366, 0, 218, 0, 368, 0, 220, 0, 221, 0, 354, 0, 223, 0, 341, 0, 225, 0, 226, 0, 259, 0, 228, 0, 314, 0, 263, 0, 231, 0, 269, 0, 233, 0, 281, 0, 235, 0, 283, 0, 237, 0, 238, 0, 271, 0, 273, 0, 324, 0, 328, 0, 243, 0, 244, 0, 337, 0, 246, 0, 247, 0, 345, 0, 367, 0, 250, 0, 369, 0, 252, 0, 253, 0, 355, 0, 729, 0], ["i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0], ALLOC_STATIC);
STRING_TABLE.__str1050=allocate([73,83,79,56,56,53,57,45,51,0] /* ISO8859-3\00 */, "i8", ALLOC_STATIC);
_HPDF_UNICODE_MAP_ISO8859_3=allocate([32, 0, 33, 0, 34, 0, 35, 0, 36, 0, 37, 0, 38, 0, 39, 0, 40, 0, 41, 0, 42, 0, 43, 0, 44, 0, 45, 0, 46, 0, 47, 0, 48, 0, 49, 0, 50, 0, 51, 0, 52, 0, 53, 0, 54, 0, 55, 0, 56, 0, 57, 0, 58, 0, 59, 0, 60, 0, 61, 0, 62, 0, 63, 0, 64, 0, 65, 0, 66, 0, 67, 0, 68, 0, 69, 0, 70, 0, 71, 0, 72, 0, 73, 0, 74, 0, 75, 0, 76, 0, 77, 0, 78, 0, 79, 0, 80, 0, 81, 0, 82, 0, 83, 0, 84, 0, 85, 0, 86, 0, 87, 0, 88, 0, 89, 0, 90, 0, 91, 0, 92, 0, 93, 0, 94, 0, 95, 0, 96, 0, 97, 0, 98, 0, 99, 0, 100, 0, 101, 0, 102, 0, 103, 0, 104, 0, 105, 0, 106, 0, 107, 0, 108, 0, 109, 0, 110, 0, 111, 0, 112, 0, 113, 0, 114, 0, 115, 0, 116, 0, 117, 0, 118, 0, 119, 0, 120, 0, 121, 0, 122, 0, 123, 0, 124, 0, 125, 0, 126, 0, 127, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 160, 0, 294, 0, 728, 0, 163, 0, 164, 0, 0, 0, 292, 0, 167, 0, 168, 0, 304, 0, 350, 0, 286, 0, 308, 0, 173, 0, 0, 0, 379, 0, 176, 0, 295, 0, 178, 0, 179, 0, 180, 0, 181, 0, 293, 0, 183, 0, 184, 0, 305, 0, 351, 0, 287, 0, 309, 0, 189, 0, 0, 0, 380, 0, 192, 0, 193, 0, 194, 0, 0, 0, 196, 0, 266, 0, 264, 0, 199, 0, 200, 0, 201, 0, 202, 0, 203, 0, 204, 0, 205, 0, 206, 0, 207, 0, 0, 0, 209, 0, 210, 0, 211, 0, 212, 0, 288, 0, 214, 0, 215, 0, 284, 0, 217, 0, 218, 0, 219, 0, 220, 0, 364, 0, 348, 0, 223, 0, 224, 0, 225, 0, 226, 0, 0, 0, 228, 0, 267, 0, 265, 0, 231, 0, 232, 0, 233, 0, 234, 0, 235, 0, 236, 0, 237, 0, 238, 0, 239, 0, 0, 0, 241, 0, 242, 0, 243, 0, 244, 0, 289, 0, 246, 0, 247, 0, 285, 0, 249, 0, 250, 0, 251, 0, 252, 0, 365, 0, 349, 0, 729, 0], ["i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0], ALLOC_STATIC);
STRING_TABLE.__str1051=allocate([73,83,79,56,56,53,57,45,52,0] /* ISO8859-4\00 */, "i8", ALLOC_STATIC);
_HPDF_UNICODE_MAP_ISO8859_4=allocate([32, 0, 33, 0, 34, 0, 35, 0, 36, 0, 37, 0, 38, 0, 39, 0, 40, 0, 41, 0, 42, 0, 43, 0, 44, 0, 45, 0, 46, 0, 47, 0, 48, 0, 49, 0, 50, 0, 51, 0, 52, 0, 53, 0, 54, 0, 55, 0, 56, 0, 57, 0, 58, 0, 59, 0, 60, 0, 61, 0, 62, 0, 63, 0, 64, 0, 65, 0, 66, 0, 67, 0, 68, 0, 69, 0, 70, 0, 71, 0, 72, 0, 73, 0, 74, 0, 75, 0, 76, 0, 77, 0, 78, 0, 79, 0, 80, 0, 81, 0, 82, 0, 83, 0, 84, 0, 85, 0, 86, 0, 87, 0, 88, 0, 89, 0, 90, 0, 91, 0, 92, 0, 93, 0, 94, 0, 95, 0, 96, 0, 97, 0, 98, 0, 99, 0, 100, 0, 101, 0, 102, 0, 103, 0, 104, 0, 105, 0, 106, 0, 107, 0, 108, 0, 109, 0, 110, 0, 111, 0, 112, 0, 113, 0, 114, 0, 115, 0, 116, 0, 117, 0, 118, 0, 119, 0, 120, 0, 121, 0, 122, 0, 123, 0, 124, 0, 125, 0, 126, 0, 127, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 160, 0, 260, 0, 312, 0, 342, 0, 164, 0, 296, 0, 315, 0, 167, 0, 168, 0, 352, 0, 274, 0, 290, 0, 358, 0, 173, 0, 381, 0, 175, 0, 176, 0, 261, 0, 731, 0, 343, 0, 180, 0, 297, 0, 316, 0, 711, 0, 184, 0, 353, 0, 275, 0, 291, 0, 359, 0, 330, 0, 382, 0, 331, 0, 256, 0, 193, 0, 194, 0, 195, 0, 196, 0, 197, 0, 198, 0, 302, 0, 268, 0, 201, 0, 280, 0, 203, 0, 278, 0, 205, 0, 206, 0, 298, 0, 272, 0, 325, 0, 332, 0, 310, 0, 212, 0, 213, 0, 214, 0, 215, 0, 216, 0, 370, 0, 218, 0, 219, 0, 220, 0, 360, 0, 362, 0, 223, 0, 257, 0, 225, 0, 226, 0, 227, 0, 228, 0, 229, 0, 230, 0, 303, 0, 269, 0, 233, 0, 281, 0, 235, 0, 279, 0, 237, 0, 238, 0, 299, 0, 273, 0, 326, 0, 333, 0, 311, 0, 244, 0, 245, 0, 246, 0, 247, 0, 248, 0, 371, 0, 250, 0, 251, 0, 252, 0, 361, 0, 363, 0, 729, 0], ["i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0], ALLOC_STATIC);
STRING_TABLE.__str1052=allocate([73,83,79,56,56,53,57,45,53,0] /* ISO8859-5\00 */, "i8", ALLOC_STATIC);
_HPDF_UNICODE_MAP_ISO8859_5=allocate([32, 0, 33, 0, 34, 0, 35, 0, 36, 0, 37, 0, 38, 0, 39, 0, 40, 0, 41, 0, 42, 0, 43, 0, 44, 0, 45, 0, 46, 0, 47, 0, 48, 0, 49, 0, 50, 0, 51, 0, 52, 0, 53, 0, 54, 0, 55, 0, 56, 0, 57, 0, 58, 0, 59, 0, 60, 0, 61, 0, 62, 0, 63, 0, 64, 0, 65, 0, 66, 0, 67, 0, 68, 0, 69, 0, 70, 0, 71, 0, 72, 0, 73, 0, 74, 0, 75, 0, 76, 0, 77, 0, 78, 0, 79, 0, 80, 0, 81, 0, 82, 0, 83, 0, 84, 0, 85, 0, 86, 0, 87, 0, 88, 0, 89, 0, 90, 0, 91, 0, 92, 0, 93, 0, 94, 0, 95, 0, 96, 0, 97, 0, 98, 0, 99, 0, 100, 0, 101, 0, 102, 0, 103, 0, 104, 0, 105, 0, 106, 0, 107, 0, 108, 0, 109, 0, 110, 0, 111, 0, 112, 0, 113, 0, 114, 0, 115, 0, 116, 0, 117, 0, 118, 0, 119, 0, 120, 0, 121, 0, 122, 0, 123, 0, 124, 0, 125, 0, 126, 0, 127, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 160, 0, 1025, 0, 1026, 0, 1027, 0, 1028, 0, 1029, 0, 1030, 0, 1031, 0, 1032, 0, 1033, 0, 1034, 0, 1035, 0, 1036, 0, 173, 0, 1038, 0, 1039, 0, 1040, 0, 1041, 0, 1042, 0, 1043, 0, 1044, 0, 1045, 0, 1046, 0, 1047, 0, 1048, 0, 1049, 0, 1050, 0, 1051, 0, 1052, 0, 1053, 0, 1054, 0, 1055, 0, 1056, 0, 1057, 0, 1058, 0, 1059, 0, 1060, 0, 1061, 0, 1062, 0, 1063, 0, 1064, 0, 1065, 0, 1066, 0, 1067, 0, 1068, 0, 1069, 0, 1070, 0, 1071, 0, 1072, 0, 1073, 0, 1074, 0, 1075, 0, 1076, 0, 1077, 0, 1078, 0, 1079, 0, 1080, 0, 1081, 0, 1082, 0, 1083, 0, 1084, 0, 1085, 0, 1086, 0, 1087, 0, 1088, 0, 1089, 0, 1090, 0, 1091, 0, 1092, 0, 1093, 0, 1094, 0, 1095, 0, 1096, 0, 1097, 0, 1098, 0, 1099, 0, 1100, 0, 1101, 0, 1102, 0, 1103, 0, 8470, 0, 1105, 0, 1106, 0, 1107, 0, 1108, 0, 1109, 0, 1110, 0, 1111, 0, 1112, 0, 1113, 0, 1114, 0, 1115, 0, 1116, 0, 167, 0, 1118, 0, 1119, 0], ["i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0], ALLOC_STATIC);
STRING_TABLE.__str1053=allocate([73,83,79,56,56,53,57,45,54,0] /* ISO8859-6\00 */, "i8", ALLOC_STATIC);
_HPDF_UNICODE_MAP_ISO8859_6=allocate([32, 0, 33, 0, 34, 0, 35, 0, 36, 0, 37, 0, 38, 0, 39, 0, 40, 0, 41, 0, 42, 0, 43, 0, 44, 0, 45, 0, 46, 0, 47, 0, 48, 0, 49, 0, 50, 0, 51, 0, 52, 0, 53, 0, 54, 0, 55, 0, 56, 0, 57, 0, 58, 0, 59, 0, 60, 0, 61, 0, 62, 0, 63, 0, 64, 0, 65, 0, 66, 0, 67, 0, 68, 0, 69, 0, 70, 0, 71, 0, 72, 0, 73, 0, 74, 0, 75, 0, 76, 0, 77, 0, 78, 0, 79, 0, 80, 0, 81, 0, 82, 0, 83, 0, 84, 0, 85, 0, 86, 0, 87, 0, 88, 0, 89, 0, 90, 0, 91, 0, 92, 0, 93, 0, 94, 0, 95, 0, 96, 0, 97, 0, 98, 0, 99, 0, 100, 0, 101, 0, 102, 0, 103, 0, 104, 0, 105, 0, 106, 0, 107, 0, 108, 0, 109, 0, 110, 0, 111, 0, 112, 0, 113, 0, 114, 0, 115, 0, 116, 0, 117, 0, 118, 0, 119, 0, 120, 0, 121, 0, 122, 0, 123, 0, 124, 0, 125, 0, 126, 0, 127, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 160, 0, 0, 0, 0, 0, 0, 0, 164, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1548, 0, 173, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1563, 0, 0, 0, 0, 0, 0, 0, 1567, 0, 0, 0, 1569, 0, 1570, 0, 1571, 0, 1572, 0, 1573, 0, 1574, 0, 1575, 0, 1576, 0, 1577, 0, 1578, 0, 1579, 0, 1580, 0, 1581, 0, 1582, 0, 1583, 0, 1584, 0, 1585, 0, 1586, 0, 1587, 0, 1588, 0, 1589, 0, 1590, 0, 1591, 0, 1592, 0, 1593, 0, 1594, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1600, 0, 1601, 0, 1602, 0, 1603, 0, 1604, 0, 1605, 0, 1606, 0, 1607, 0, 1608, 0, 1609, 0, 1610, 0, 1611, 0, 1612, 0, 1613, 0, 1614, 0, 1615, 0, 1616, 0, 1617, 0, 1618, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], ["i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0], ALLOC_STATIC);
STRING_TABLE.__str1054=allocate([73,83,79,56,56,53,57,45,55,0] /* ISO8859-7\00 */, "i8", ALLOC_STATIC);
_HPDF_UNICODE_MAP_ISO8859_7=allocate([32, 0, 33, 0, 34, 0, 35, 0, 36, 0, 37, 0, 38, 0, 39, 0, 40, 0, 41, 0, 42, 0, 43, 0, 44, 0, 45, 0, 46, 0, 47, 0, 48, 0, 49, 0, 50, 0, 51, 0, 52, 0, 53, 0, 54, 0, 55, 0, 56, 0, 57, 0, 58, 0, 59, 0, 60, 0, 61, 0, 62, 0, 63, 0, 64, 0, 65, 0, 66, 0, 67, 0, 68, 0, 69, 0, 70, 0, 71, 0, 72, 0, 73, 0, 74, 0, 75, 0, 76, 0, 77, 0, 78, 0, 79, 0, 80, 0, 81, 0, 82, 0, 83, 0, 84, 0, 85, 0, 86, 0, 87, 0, 88, 0, 89, 0, 90, 0, 91, 0, 92, 0, 93, 0, 94, 0, 95, 0, 96, 0, 97, 0, 98, 0, 99, 0, 100, 0, 101, 0, 102, 0, 103, 0, 104, 0, 105, 0, 106, 0, 107, 0, 108, 0, 109, 0, 110, 0, 111, 0, 112, 0, 113, 0, 114, 0, 115, 0, 116, 0, 117, 0, 118, 0, 119, 0, 120, 0, 121, 0, 122, 0, 123, 0, 124, 0, 125, 0, 126, 0, 127, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 160, 0, 8216, 0, 8217, 0, 163, 0, 8364, 0, 8367, 0, 166, 0, 167, 0, 168, 0, 169, 0, 890, 0, 171, 0, 172, 0, 173, 0, 0, 0, 8213, 0, 176, 0, 177, 0, 178, 0, 179, 0, 900, 0, 901, 0, 902, 0, 183, 0, 904, 0, 905, 0, 906, 0, 187, 0, 908, 0, 189, 0, 910, 0, 911, 0, 912, 0, 913, 0, 914, 0, 915, 0, 916, 0, 917, 0, 918, 0, 919, 0, 920, 0, 921, 0, 922, 0, 923, 0, 924, 0, 925, 0, 926, 0, 927, 0, 928, 0, 929, 0, 0, 0, 931, 0, 932, 0, 933, 0, 934, 0, 935, 0, 936, 0, 937, 0, 938, 0, 939, 0, 940, 0, 941, 0, 942, 0, 943, 0, 944, 0, 945, 0, 946, 0, 947, 0, 948, 0, 949, 0, 950, 0, 951, 0, 952, 0, 953, 0, 954, 0, 955, 0, 956, 0, 957, 0, 958, 0, 959, 0, 960, 0, 961, 0, 962, 0, 963, 0, 964, 0, 965, 0, 966, 0, 967, 0, 968, 0, 969, 0, 970, 0, 971, 0, 972, 0, 973, 0, 974, 0, 0, 0], ["i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0], ALLOC_STATIC);
STRING_TABLE.__str1055=allocate([73,83,79,56,56,53,57,45,56,0] /* ISO8859-8\00 */, "i8", ALLOC_STATIC);
_HPDF_UNICODE_MAP_ISO8859_8=allocate([32, 0, 33, 0, 34, 0, 35, 0, 36, 0, 37, 0, 38, 0, 39, 0, 40, 0, 41, 0, 42, 0, 43, 0, 44, 0, 45, 0, 46, 0, 47, 0, 48, 0, 49, 0, 50, 0, 51, 0, 52, 0, 53, 0, 54, 0, 55, 0, 56, 0, 57, 0, 58, 0, 59, 0, 60, 0, 61, 0, 62, 0, 63, 0, 64, 0, 65, 0, 66, 0, 67, 0, 68, 0, 69, 0, 70, 0, 71, 0, 72, 0, 73, 0, 74, 0, 75, 0, 76, 0, 77, 0, 78, 0, 79, 0, 80, 0, 81, 0, 82, 0, 83, 0, 84, 0, 85, 0, 86, 0, 87, 0, 88, 0, 89, 0, 90, 0, 91, 0, 92, 0, 93, 0, 94, 0, 95, 0, 96, 0, 97, 0, 98, 0, 99, 0, 100, 0, 101, 0, 102, 0, 103, 0, 104, 0, 105, 0, 106, 0, 107, 0, 108, 0, 109, 0, 110, 0, 111, 0, 112, 0, 113, 0, 114, 0, 115, 0, 116, 0, 117, 0, 118, 0, 119, 0, 120, 0, 121, 0, 122, 0, 123, 0, 124, 0, 125, 0, 126, 0, 127, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 160, 0, 0, 0, 162, 0, 163, 0, 164, 0, 165, 0, 166, 0, 167, 0, 168, 0, 169, 0, 215, 0, 171, 0, 172, 0, 173, 0, 174, 0, 175, 0, 176, 0, 177, 0, 178, 0, 179, 0, 180, 0, 181, 0, 182, 0, 183, 0, 184, 0, 185, 0, 247, 0, 187, 0, 188, 0, 189, 0, 190, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 8215, 0, 1488, 0, 1489, 0, 1490, 0, 1491, 0, 1492, 0, 1493, 0, 1494, 0, 1495, 0, 1496, 0, 1497, 0, 1498, 0, 1499, 0, 1500, 0, 1501, 0, 1502, 0, 1503, 0, 1504, 0, 1505, 0, 1506, 0, 1507, 0, 1508, 0, 1509, 0, 1510, 0, 1511, 0, 1512, 0, 1513, 0, 1514, 0, 0, 0, 0, 0, 8206, 0, 8207, 0, 0, 0], ["i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0], ALLOC_STATIC);
STRING_TABLE.__str1056=allocate([73,83,79,56,56,53,57,45,57,0] /* ISO8859-9\00 */, "i8", ALLOC_STATIC);
_HPDF_UNICODE_MAP_ISO8859_9=allocate([32, 0, 33, 0, 34, 0, 35, 0, 36, 0, 37, 0, 38, 0, 39, 0, 40, 0, 41, 0, 42, 0, 43, 0, 44, 0, 45, 0, 46, 0, 47, 0, 48, 0, 49, 0, 50, 0, 51, 0, 52, 0, 53, 0, 54, 0, 55, 0, 56, 0, 57, 0, 58, 0, 59, 0, 60, 0, 61, 0, 62, 0, 63, 0, 64, 0, 65, 0, 66, 0, 67, 0, 68, 0, 69, 0, 70, 0, 71, 0, 72, 0, 73, 0, 74, 0, 75, 0, 76, 0, 77, 0, 78, 0, 79, 0, 80, 0, 81, 0, 82, 0, 83, 0, 84, 0, 85, 0, 86, 0, 87, 0, 88, 0, 89, 0, 90, 0, 91, 0, 92, 0, 93, 0, 94, 0, 95, 0, 96, 0, 97, 0, 98, 0, 99, 0, 100, 0, 101, 0, 102, 0, 103, 0, 104, 0, 105, 0, 106, 0, 107, 0, 108, 0, 109, 0, 110, 0, 111, 0, 112, 0, 113, 0, 114, 0, 115, 0, 116, 0, 117, 0, 118, 0, 119, 0, 120, 0, 121, 0, 122, 0, 123, 0, 124, 0, 125, 0, 126, 0, 127, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 160, 0, 161, 0, 162, 0, 163, 0, 164, 0, 165, 0, 166, 0, 167, 0, 168, 0, 169, 0, 170, 0, 171, 0, 172, 0, 173, 0, 174, 0, 175, 0, 176, 0, 177, 0, 178, 0, 179, 0, 180, 0, 181, 0, 182, 0, 183, 0, 184, 0, 185, 0, 186, 0, 187, 0, 188, 0, 189, 0, 190, 0, 191, 0, 192, 0, 193, 0, 194, 0, 195, 0, 196, 0, 197, 0, 198, 0, 199, 0, 200, 0, 201, 0, 202, 0, 203, 0, 204, 0, 205, 0, 206, 0, 207, 0, 286, 0, 209, 0, 210, 0, 211, 0, 212, 0, 213, 0, 214, 0, 215, 0, 216, 0, 217, 0, 218, 0, 219, 0, 220, 0, 304, 0, 350, 0, 223, 0, 224, 0, 225, 0, 226, 0, 227, 0, 228, 0, 229, 0, 230, 0, 231, 0, 232, 0, 233, 0, 234, 0, 235, 0, 236, 0, 237, 0, 238, 0, 239, 0, 287, 0, 241, 0, 242, 0, 243, 0, 244, 0, 245, 0, 246, 0, 247, 0, 248, 0, 249, 0, 250, 0, 251, 0, 252, 0, 305, 0, 351, 0, 255, 0], ["i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0], ALLOC_STATIC);
STRING_TABLE.__str1057=allocate([73,83,79,56,56,53,57,45,49,48,0] /* ISO8859-10\00 */, "i8", ALLOC_STATIC);
_HPDF_UNICODE_MAP_ISO8859_10=allocate([32, 0, 33, 0, 34, 0, 35, 0, 36, 0, 37, 0, 38, 0, 39, 0, 40, 0, 41, 0, 42, 0, 43, 0, 44, 0, 45, 0, 46, 0, 47, 0, 48, 0, 49, 0, 50, 0, 51, 0, 52, 0, 53, 0, 54, 0, 55, 0, 56, 0, 57, 0, 58, 0, 59, 0, 60, 0, 61, 0, 62, 0, 63, 0, 64, 0, 65, 0, 66, 0, 67, 0, 68, 0, 69, 0, 70, 0, 71, 0, 72, 0, 73, 0, 74, 0, 75, 0, 76, 0, 77, 0, 78, 0, 79, 0, 80, 0, 81, 0, 82, 0, 83, 0, 84, 0, 85, 0, 86, 0, 87, 0, 88, 0, 89, 0, 90, 0, 91, 0, 92, 0, 93, 0, 94, 0, 95, 0, 96, 0, 97, 0, 98, 0, 99, 0, 100, 0, 101, 0, 102, 0, 103, 0, 104, 0, 105, 0, 106, 0, 107, 0, 108, 0, 109, 0, 110, 0, 111, 0, 112, 0, 113, 0, 114, 0, 115, 0, 116, 0, 117, 0, 118, 0, 119, 0, 120, 0, 121, 0, 122, 0, 123, 0, 124, 0, 125, 0, 126, 0, 127, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 160, 0, 260, 0, 274, 0, 290, 0, 298, 0, 296, 0, 310, 0, 167, 0, 315, 0, 272, 0, 352, 0, 358, 0, 381, 0, 173, 0, 362, 0, 330, 0, 176, 0, 261, 0, 275, 0, 291, 0, 299, 0, 297, 0, 311, 0, 183, 0, 316, 0, 273, 0, 353, 0, 359, 0, 382, 0, 8213, 0, 363, 0, 331, 0, 256, 0, 193, 0, 194, 0, 195, 0, 196, 0, 197, 0, 198, 0, 302, 0, 268, 0, 201, 0, 280, 0, 203, 0, 278, 0, 205, 0, 206, 0, 207, 0, 208, 0, 325, 0, 332, 0, 211, 0, 212, 0, 213, 0, 214, 0, 360, 0, 216, 0, 370, 0, 218, 0, 219, 0, 220, 0, 221, 0, 222, 0, 223, 0, 257, 0, 225, 0, 226, 0, 227, 0, 228, 0, 229, 0, 230, 0, 303, 0, 269, 0, 233, 0, 281, 0, 235, 0, 279, 0, 237, 0, 238, 0, 239, 0, 240, 0, 326, 0, 333, 0, 243, 0, 244, 0, 245, 0, 246, 0, 361, 0, 248, 0, 371, 0, 250, 0, 251, 0, 252, 0, 253, 0, 254, 0, 312, 0], ["i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0], ALLOC_STATIC);
STRING_TABLE.__str1058=allocate([73,83,79,56,56,53,57,45,49,49,0] /* ISO8859-11\00 */, "i8", ALLOC_STATIC);
_HPDF_UNICODE_MAP_ISO8859_11=allocate([32, 0, 33, 0, 34, 0, 35, 0, 36, 0, 37, 0, 38, 0, 39, 0, 40, 0, 41, 0, 42, 0, 43, 0, 44, 0, 45, 0, 46, 0, 47, 0, 48, 0, 49, 0, 50, 0, 51, 0, 52, 0, 53, 0, 54, 0, 55, 0, 56, 0, 57, 0, 58, 0, 59, 0, 60, 0, 61, 0, 62, 0, 63, 0, 64, 0, 65, 0, 66, 0, 67, 0, 68, 0, 69, 0, 70, 0, 71, 0, 72, 0, 73, 0, 74, 0, 75, 0, 76, 0, 77, 0, 78, 0, 79, 0, 80, 0, 81, 0, 82, 0, 83, 0, 84, 0, 85, 0, 86, 0, 87, 0, 88, 0, 89, 0, 90, 0, 91, 0, 92, 0, 93, 0, 94, 0, 95, 0, 96, 0, 97, 0, 98, 0, 99, 0, 100, 0, 101, 0, 102, 0, 103, 0, 104, 0, 105, 0, 106, 0, 107, 0, 108, 0, 109, 0, 110, 0, 111, 0, 112, 0, 113, 0, 114, 0, 115, 0, 116, 0, 117, 0, 118, 0, 119, 0, 120, 0, 121, 0, 122, 0, 123, 0, 124, 0, 125, 0, 126, 0, 127, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 160, 0, 3585, 0, 3586, 0, 3587, 0, 3588, 0, 3589, 0, 3590, 0, 3591, 0, 3592, 0, 3593, 0, 3594, 0, 3595, 0, 3596, 0, 3597, 0, 3598, 0, 3599, 0, 3600, 0, 3601, 0, 3602, 0, 3603, 0, 3604, 0, 3605, 0, 3606, 0, 3607, 0, 3608, 0, 3609, 0, 3610, 0, 3611, 0, 3612, 0, 3613, 0, 3614, 0, 3615, 0, 3616, 0, 3617, 0, 3618, 0, 3619, 0, 3620, 0, 3621, 0, 3622, 0, 3623, 0, 3624, 0, 3625, 0, 3626, 0, 3627, 0, 3628, 0, 3629, 0, 3630, 0, 3631, 0, 3632, 0, 3633, 0, 3634, 0, 3635, 0, 3636, 0, 3637, 0, 3638, 0, 3639, 0, 3640, 0, 3641, 0, 3642, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3647, 0, 3648, 0, 3649, 0, 3650, 0, 3651, 0, 3652, 0, 3653, 0, 3654, 0, 3655, 0, 3656, 0, 3657, 0, 3658, 0, 3659, 0, 3660, 0, 3661, 0, 3662, 0, 3663, 0, 3664, 0, 3665, 0, 3666, 0, 3667, 0, 3668, 0, 3669, 0, 3670, 0, 3671, 0, 3672, 0, 3673, 0, 3674, 0, 3675, 0, 0, 0, 0, 0, 0, 0, 0, 0], ["i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0], ALLOC_STATIC);
STRING_TABLE.__str1059=allocate([73,83,79,56,56,53,57,45,49,51,0] /* ISO8859-13\00 */, "i8", ALLOC_STATIC);
_HPDF_UNICODE_MAP_ISO8859_13=allocate([32, 0, 33, 0, 34, 0, 35, 0, 36, 0, 37, 0, 38, 0, 39, 0, 40, 0, 41, 0, 42, 0, 43, 0, 44, 0, 45, 0, 46, 0, 47, 0, 48, 0, 49, 0, 50, 0, 51, 0, 52, 0, 53, 0, 54, 0, 55, 0, 56, 0, 57, 0, 58, 0, 59, 0, 60, 0, 61, 0, 62, 0, 63, 0, 64, 0, 65, 0, 66, 0, 67, 0, 68, 0, 69, 0, 70, 0, 71, 0, 72, 0, 73, 0, 74, 0, 75, 0, 76, 0, 77, 0, 78, 0, 79, 0, 80, 0, 81, 0, 82, 0, 83, 0, 84, 0, 85, 0, 86, 0, 87, 0, 88, 0, 89, 0, 90, 0, 91, 0, 92, 0, 93, 0, 94, 0, 95, 0, 96, 0, 97, 0, 98, 0, 99, 0, 100, 0, 101, 0, 102, 0, 103, 0, 104, 0, 105, 0, 106, 0, 107, 0, 108, 0, 109, 0, 110, 0, 111, 0, 112, 0, 113, 0, 114, 0, 115, 0, 116, 0, 117, 0, 118, 0, 119, 0, 120, 0, 121, 0, 122, 0, 123, 0, 124, 0, 125, 0, 126, 0, 127, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 160, 0, 8221, 0, 162, 0, 163, 0, 164, 0, 8222, 0, 166, 0, 167, 0, 216, 0, 169, 0, 342, 0, 171, 0, 172, 0, 173, 0, 174, 0, 198, 0, 176, 0, 177, 0, 178, 0, 179, 0, 8220, 0, 181, 0, 182, 0, 183, 0, 248, 0, 185, 0, 343, 0, 187, 0, 188, 0, 189, 0, 190, 0, 230, 0, 260, 0, 302, 0, 256, 0, 262, 0, 196, 0, 197, 0, 280, 0, 274, 0, 268, 0, 201, 0, 377, 0, 278, 0, 290, 0, 310, 0, 298, 0, 315, 0, 352, 0, 323, 0, 325, 0, 211, 0, 332, 0, 213, 0, 214, 0, 215, 0, 370, 0, 321, 0, 346, 0, 362, 0, 220, 0, 379, 0, 381, 0, 223, 0, 261, 0, 303, 0, 257, 0, 263, 0, 228, 0, 229, 0, 281, 0, 275, 0, 269, 0, 233, 0, 378, 0, 279, 0, 291, 0, 311, 0, 299, 0, 316, 0, 353, 0, 324, 0, 326, 0, 243, 0, 333, 0, 245, 0, 246, 0, 247, 0, 371, 0, 322, 0, 347, 0, 363, 0, 252, 0, 380, 0, 382, 0, 8217, 0], ["i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0], ALLOC_STATIC);
STRING_TABLE.__str1060=allocate([73,83,79,56,56,53,57,45,49,52,0] /* ISO8859-14\00 */, "i8", ALLOC_STATIC);
_HPDF_UNICODE_MAP_ISO8859_14=allocate([32, 0, 33, 0, 34, 0, 35, 0, 36, 0, 37, 0, 38, 0, 39, 0, 40, 0, 41, 0, 42, 0, 43, 0, 44, 0, 45, 0, 46, 0, 47, 0, 48, 0, 49, 0, 50, 0, 51, 0, 52, 0, 53, 0, 54, 0, 55, 0, 56, 0, 57, 0, 58, 0, 59, 0, 60, 0, 61, 0, 62, 0, 63, 0, 64, 0, 65, 0, 66, 0, 67, 0, 68, 0, 69, 0, 70, 0, 71, 0, 72, 0, 73, 0, 74, 0, 75, 0, 76, 0, 77, 0, 78, 0, 79, 0, 80, 0, 81, 0, 82, 0, 83, 0, 84, 0, 85, 0, 86, 0, 87, 0, 88, 0, 89, 0, 90, 0, 91, 0, 92, 0, 93, 0, 94, 0, 95, 0, 96, 0, 97, 0, 98, 0, 99, 0, 100, 0, 101, 0, 102, 0, 103, 0, 104, 0, 105, 0, 106, 0, 107, 0, 108, 0, 109, 0, 110, 0, 111, 0, 112, 0, 113, 0, 114, 0, 115, 0, 116, 0, 117, 0, 118, 0, 119, 0, 120, 0, 121, 0, 122, 0, 123, 0, 124, 0, 125, 0, 126, 0, 127, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 160, 0, 7682, 0, 7683, 0, 163, 0, 266, 0, 267, 0, 7690, 0, 167, 0, 7808, 0, 169, 0, 7810, 0, 7691, 0, 7922, 0, 173, 0, 174, 0, 376, 0, 7710, 0, 7711, 0, 288, 0, 289, 0, 7744, 0, 7745, 0, 182, 0, 7766, 0, 7809, 0, 7767, 0, 7811, 0, 7776, 0, 7923, 0, 7812, 0, 7813, 0, 7777, 0, 192, 0, 193, 0, 194, 0, 195, 0, 196, 0, 197, 0, 198, 0, 199, 0, 200, 0, 201, 0, 202, 0, 203, 0, 204, 0, 205, 0, 206, 0, 207, 0, 372, 0, 209, 0, 210, 0, 211, 0, 212, 0, 213, 0, 214, 0, 7786, 0, 216, 0, 217, 0, 218, 0, 219, 0, 220, 0, 221, 0, 374, 0, 223, 0, 224, 0, 225, 0, 226, 0, 227, 0, 228, 0, 229, 0, 230, 0, 231, 0, 232, 0, 233, 0, 234, 0, 235, 0, 236, 0, 237, 0, 238, 0, 239, 0, 373, 0, 241, 0, 242, 0, 243, 0, 244, 0, 245, 0, 246, 0, 7787, 0, 248, 0, 249, 0, 250, 0, 251, 0, 252, 0, 253, 0, 375, 0, 255, 0], ["i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0], ALLOC_STATIC);
STRING_TABLE.__str1061=allocate([73,83,79,56,56,53,57,45,49,53,0] /* ISO8859-15\00 */, "i8", ALLOC_STATIC);
_HPDF_UNICODE_MAP_ISO8859_15=allocate([32, 0, 33, 0, 34, 0, 35, 0, 36, 0, 37, 0, 38, 0, 39, 0, 40, 0, 41, 0, 42, 0, 43, 0, 44, 0, 45, 0, 46, 0, 47, 0, 48, 0, 49, 0, 50, 0, 51, 0, 52, 0, 53, 0, 54, 0, 55, 0, 56, 0, 57, 0, 58, 0, 59, 0, 60, 0, 61, 0, 62, 0, 63, 0, 64, 0, 65, 0, 66, 0, 67, 0, 68, 0, 69, 0, 70, 0, 71, 0, 72, 0, 73, 0, 74, 0, 75, 0, 76, 0, 77, 0, 78, 0, 79, 0, 80, 0, 81, 0, 82, 0, 83, 0, 84, 0, 85, 0, 86, 0, 87, 0, 88, 0, 89, 0, 90, 0, 91, 0, 92, 0, 93, 0, 94, 0, 95, 0, 96, 0, 97, 0, 98, 0, 99, 0, 100, 0, 101, 0, 102, 0, 103, 0, 104, 0, 105, 0, 106, 0, 107, 0, 108, 0, 109, 0, 110, 0, 111, 0, 112, 0, 113, 0, 114, 0, 115, 0, 116, 0, 117, 0, 118, 0, 119, 0, 120, 0, 121, 0, 122, 0, 123, 0, 124, 0, 125, 0, 126, 0, 127, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 160, 0, 161, 0, 162, 0, 163, 0, 8364, 0, 165, 0, 352, 0, 167, 0, 353, 0, 169, 0, 170, 0, 171, 0, 172, 0, 173, 0, 174, 0, 175, 0, 176, 0, 177, 0, 178, 0, 179, 0, 381, 0, 181, 0, 182, 0, 183, 0, 382, 0, 185, 0, 186, 0, 187, 0, 338, 0, 339, 0, 376, 0, 191, 0, 192, 0, 193, 0, 194, 0, 195, 0, 196, 0, 197, 0, 198, 0, 199, 0, 200, 0, 201, 0, 202, 0, 203, 0, 204, 0, 205, 0, 206, 0, 207, 0, 208, 0, 209, 0, 210, 0, 211, 0, 212, 0, 213, 0, 214, 0, 215, 0, 216, 0, 217, 0, 218, 0, 219, 0, 220, 0, 221, 0, 222, 0, 223, 0, 224, 0, 225, 0, 226, 0, 227, 0, 228, 0, 229, 0, 230, 0, 231, 0, 232, 0, 233, 0, 234, 0, 235, 0, 236, 0, 237, 0, 238, 0, 239, 0, 240, 0, 241, 0, 242, 0, 243, 0, 244, 0, 245, 0, 246, 0, 247, 0, 248, 0, 249, 0, 250, 0, 251, 0, 252, 0, 253, 0, 254, 0, 255, 0], ["i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0], ALLOC_STATIC);
STRING_TABLE.__str1062=allocate([73,83,79,56,56,53,57,45,49,54,0] /* ISO8859-16\00 */, "i8", ALLOC_STATIC);
_HPDF_UNICODE_MAP_ISO8859_16=allocate([32, 0, 33, 0, 34, 0, 35, 0, 36, 0, 37, 0, 38, 0, 39, 0, 40, 0, 41, 0, 42, 0, 43, 0, 44, 0, 45, 0, 46, 0, 47, 0, 48, 0, 49, 0, 50, 0, 51, 0, 52, 0, 53, 0, 54, 0, 55, 0, 56, 0, 57, 0, 58, 0, 59, 0, 60, 0, 61, 0, 62, 0, 63, 0, 64, 0, 65, 0, 66, 0, 67, 0, 68, 0, 69, 0, 70, 0, 71, 0, 72, 0, 73, 0, 74, 0, 75, 0, 76, 0, 77, 0, 78, 0, 79, 0, 80, 0, 81, 0, 82, 0, 83, 0, 84, 0, 85, 0, 86, 0, 87, 0, 88, 0, 89, 0, 90, 0, 91, 0, 92, 0, 93, 0, 94, 0, 95, 0, 96, 0, 97, 0, 98, 0, 99, 0, 100, 0, 101, 0, 102, 0, 103, 0, 104, 0, 105, 0, 106, 0, 107, 0, 108, 0, 109, 0, 110, 0, 111, 0, 112, 0, 113, 0, 114, 0, 115, 0, 116, 0, 117, 0, 118, 0, 119, 0, 120, 0, 121, 0, 122, 0, 123, 0, 124, 0, 125, 0, 126, 0, 127, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 160, 0, 260, 0, 261, 0, 321, 0, 8364, 0, 8222, 0, 352, 0, 167, 0, 353, 0, 169, 0, 536, 0, 171, 0, 377, 0, 173, 0, 378, 0, 379, 0, 176, 0, 177, 0, 268, 0, 322, 0, 381, 0, 8221, 0, 182, 0, 183, 0, 382, 0, 269, 0, 537, 0, 187, 0, 338, 0, 339, 0, 376, 0, 380, 0, 192, 0, 193, 0, 194, 0, 258, 0, 196, 0, 262, 0, 198, 0, 199, 0, 200, 0, 201, 0, 202, 0, 203, 0, 204, 0, 205, 0, 206, 0, 207, 0, 272, 0, 323, 0, 210, 0, 211, 0, 212, 0, 336, 0, 214, 0, 346, 0, 368, 0, 217, 0, 218, 0, 219, 0, 220, 0, 280, 0, 538, 0, 223, 0, 224, 0, 225, 0, 226, 0, 259, 0, 228, 0, 263, 0, 230, 0, 231, 0, 232, 0, 233, 0, 234, 0, 235, 0, 236, 0, 237, 0, 238, 0, 239, 0, 273, 0, 324, 0, 242, 0, 243, 0, 244, 0, 337, 0, 246, 0, 347, 0, 369, 0, 249, 0, 250, 0, 251, 0, 252, 0, 281, 0, 539, 0, 255, 0], ["i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0], ALLOC_STATIC);
STRING_TABLE.__str1063=allocate([67,80,49,50,53,48,0] /* CP1250\00 */, "i8", ALLOC_STATIC);
_HPDF_UNICODE_MAP_CP1250=allocate([32, 0, 33, 0, 34, 0, 35, 0, 36, 0, 37, 0, 38, 0, 39, 0, 40, 0, 41, 0, 42, 0, 43, 0, 44, 0, 45, 0, 46, 0, 47, 0, 48, 0, 49, 0, 50, 0, 51, 0, 52, 0, 53, 0, 54, 0, 55, 0, 56, 0, 57, 0, 58, 0, 59, 0, 60, 0, 61, 0, 62, 0, 63, 0, 64, 0, 65, 0, 66, 0, 67, 0, 68, 0, 69, 0, 70, 0, 71, 0, 72, 0, 73, 0, 74, 0, 75, 0, 76, 0, 77, 0, 78, 0, 79, 0, 80, 0, 81, 0, 82, 0, 83, 0, 84, 0, 85, 0, 86, 0, 87, 0, 88, 0, 89, 0, 90, 0, 91, 0, 92, 0, 93, 0, 94, 0, 95, 0, 96, 0, 97, 0, 98, 0, 99, 0, 100, 0, 101, 0, 102, 0, 103, 0, 104, 0, 105, 0, 106, 0, 107, 0, 108, 0, 109, 0, 110, 0, 111, 0, 112, 0, 113, 0, 114, 0, 115, 0, 116, 0, 117, 0, 118, 0, 119, 0, 120, 0, 121, 0, 122, 0, 123, 0, 124, 0, 125, 0, 126, 0, 127, 0, 8364, 0, 0, 0, 8218, 0, 0, 0, 8222, 0, 8230, 0, 8224, 0, 8225, 0, 0, 0, 8240, 0, 352, 0, 8249, 0, 346, 0, 356, 0, 381, 0, 377, 0, 0, 0, 8216, 0, 8217, 0, 8220, 0, 8221, 0, 8226, 0, 8211, 0, 8212, 0, 0, 0, 8482, 0, 353, 0, 8250, 0, 347, 0, 357, 0, 382, 0, 378, 0, 160, 0, 711, 0, 728, 0, 321, 0, 164, 0, 260, 0, 166, 0, 167, 0, 168, 0, 169, 0, 350, 0, 171, 0, 172, 0, 173, 0, 174, 0, 379, 0, 176, 0, 177, 0, 731, 0, 322, 0, 180, 0, 181, 0, 182, 0, 183, 0, 184, 0, 261, 0, 351, 0, 187, 0, 317, 0, 733, 0, 318, 0, 380, 0, 340, 0, 193, 0, 194, 0, 258, 0, 196, 0, 313, 0, 262, 0, 199, 0, 268, 0, 201, 0, 280, 0, 203, 0, 282, 0, 205, 0, 206, 0, 270, 0, 272, 0, 323, 0, 327, 0, 211, 0, 212, 0, 336, 0, 214, 0, 215, 0, 344, 0, 366, 0, 218, 0, 368, 0, 220, 0, 221, 0, 354, 0, 223, 0, 341, 0, 225, 0, 226, 0, 259, 0, 228, 0, 314, 0, 263, 0, 231, 0, 269, 0, 233, 0, 281, 0, 235, 0, 283, 0, 237, 0, 238, 0, 271, 0, 273, 0, 324, 0, 328, 0, 243, 0, 244, 0, 337, 0, 246, 0, 247, 0, 345, 0, 367, 0, 250, 0, 369, 0, 252, 0, 253, 0, 355, 0, 729, 0], ["i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0], ALLOC_STATIC);
STRING_TABLE.__str1064=allocate([67,80,49,50,53,49,0] /* CP1251\00 */, "i8", ALLOC_STATIC);
_HPDF_UNICODE_MAP_CP1251=allocate([32, 0, 33, 0, 34, 0, 35, 0, 36, 0, 37, 0, 38, 0, 39, 0, 40, 0, 41, 0, 42, 0, 43, 0, 44, 0, 45, 0, 46, 0, 47, 0, 48, 0, 49, 0, 50, 0, 51, 0, 52, 0, 53, 0, 54, 0, 55, 0, 56, 0, 57, 0, 58, 0, 59, 0, 60, 0, 61, 0, 62, 0, 63, 0, 64, 0, 65, 0, 66, 0, 67, 0, 68, 0, 69, 0, 70, 0, 71, 0, 72, 0, 73, 0, 74, 0, 75, 0, 76, 0, 77, 0, 78, 0, 79, 0, 80, 0, 81, 0, 82, 0, 83, 0, 84, 0, 85, 0, 86, 0, 87, 0, 88, 0, 89, 0, 90, 0, 91, 0, 92, 0, 93, 0, 94, 0, 95, 0, 96, 0, 97, 0, 98, 0, 99, 0, 100, 0, 101, 0, 102, 0, 103, 0, 104, 0, 105, 0, 106, 0, 107, 0, 108, 0, 109, 0, 110, 0, 111, 0, 112, 0, 113, 0, 114, 0, 115, 0, 116, 0, 117, 0, 118, 0, 119, 0, 120, 0, 121, 0, 122, 0, 123, 0, 124, 0, 125, 0, 126, 0, 127, 0, 1026, 0, 1027, 0, 8218, 0, 1107, 0, 8222, 0, 8230, 0, 8224, 0, 8225, 0, 8364, 0, 8240, 0, 1033, 0, 8249, 0, 1034, 0, 1036, 0, 1035, 0, 1039, 0, 1106, 0, 8216, 0, 8217, 0, 8220, 0, 8221, 0, 8226, 0, 8211, 0, 8212, 0, 0, 0, 8482, 0, 1113, 0, 8250, 0, 1114, 0, 1116, 0, 1115, 0, 1119, 0, 160, 0, 1038, 0, 1118, 0, 1032, 0, 164, 0, 1168, 0, 166, 0, 167, 0, 1025, 0, 169, 0, 1028, 0, 171, 0, 172, 0, 173, 0, 174, 0, 1031, 0, 176, 0, 177, 0, 1030, 0, 1110, 0, 1169, 0, 181, 0, 182, 0, 183, 0, 1105, 0, 8470, 0, 1108, 0, 187, 0, 1112, 0, 1029, 0, 1109, 0, 1111, 0, 1040, 0, 1041, 0, 1042, 0, 1043, 0, 1044, 0, 1045, 0, 1046, 0, 1047, 0, 1048, 0, 1049, 0, 1050, 0, 1051, 0, 1052, 0, 1053, 0, 1054, 0, 1055, 0, 1056, 0, 1057, 0, 1058, 0, 1059, 0, 1060, 0, 1061, 0, 1062, 0, 1063, 0, 1064, 0, 1065, 0, 1066, 0, 1067, 0, 1068, 0, 1069, 0, 1070, 0, 1071, 0, 1072, 0, 1073, 0, 1074, 0, 1075, 0, 1076, 0, 1077, 0, 1078, 0, 1079, 0, 1080, 0, 1081, 0, 1082, 0, 1083, 0, 1084, 0, 1085, 0, 1086, 0, 1087, 0, 1088, 0, 1089, 0, 1090, 0, 1091, 0, 1092, 0, 1093, 0, 1094, 0, 1095, 0, 1096, 0, 1097, 0, 1098, 0, 1099, 0, 1100, 0, 1101, 0, 1102, 0, 1103, 0], ["i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0], ALLOC_STATIC);
STRING_TABLE.__str1065=allocate([67,80,49,50,53,50,0] /* CP1252\00 */, "i8", ALLOC_STATIC);
_HPDF_UNICODE_MAP_CP1252=allocate([32, 0, 33, 0, 34, 0, 35, 0, 36, 0, 37, 0, 38, 0, 39, 0, 40, 0, 41, 0, 42, 0, 43, 0, 44, 0, 45, 0, 46, 0, 47, 0, 48, 0, 49, 0, 50, 0, 51, 0, 52, 0, 53, 0, 54, 0, 55, 0, 56, 0, 57, 0, 58, 0, 59, 0, 60, 0, 61, 0, 62, 0, 63, 0, 64, 0, 65, 0, 66, 0, 67, 0, 68, 0, 69, 0, 70, 0, 71, 0, 72, 0, 73, 0, 74, 0, 75, 0, 76, 0, 77, 0, 78, 0, 79, 0, 80, 0, 81, 0, 82, 0, 83, 0, 84, 0, 85, 0, 86, 0, 87, 0, 88, 0, 89, 0, 90, 0, 91, 0, 92, 0, 93, 0, 94, 0, 95, 0, 96, 0, 97, 0, 98, 0, 99, 0, 100, 0, 101, 0, 102, 0, 103, 0, 104, 0, 105, 0, 106, 0, 107, 0, 108, 0, 109, 0, 110, 0, 111, 0, 112, 0, 113, 0, 114, 0, 115, 0, 116, 0, 117, 0, 118, 0, 119, 0, 120, 0, 121, 0, 122, 0, 123, 0, 124, 0, 125, 0, 126, 0, 127, 0, 8364, 0, 0, 0, 8218, 0, 402, 0, 8222, 0, 8230, 0, 8224, 0, 8225, 0, 710, 0, 8240, 0, 352, 0, 8249, 0, 338, 0, 0, 0, 381, 0, 0, 0, 0, 0, 8216, 0, 8217, 0, 8220, 0, 8221, 0, 8226, 0, 8211, 0, 8212, 0, 732, 0, 8482, 0, 353, 0, 8250, 0, 339, 0, 0, 0, 382, 0, 376, 0, 160, 0, 161, 0, 162, 0, 163, 0, 164, 0, 165, 0, 166, 0, 167, 0, 168, 0, 169, 0, 170, 0, 171, 0, 172, 0, 173, 0, 174, 0, 175, 0, 176, 0, 177, 0, 178, 0, 179, 0, 180, 0, 181, 0, 182, 0, 183, 0, 184, 0, 185, 0, 186, 0, 187, 0, 188, 0, 189, 0, 190, 0, 191, 0, 192, 0, 193, 0, 194, 0, 195, 0, 196, 0, 197, 0, 198, 0, 199, 0, 200, 0, 201, 0, 202, 0, 203, 0, 204, 0, 205, 0, 206, 0, 207, 0, 208, 0, 209, 0, 210, 0, 211, 0, 212, 0, 213, 0, 214, 0, 215, 0, 216, 0, 217, 0, 218, 0, 219, 0, 220, 0, 221, 0, 222, 0, 223, 0, 224, 0, 225, 0, 226, 0, 227, 0, 228, 0, 229, 0, 230, 0, 231, 0, 232, 0, 233, 0, 234, 0, 235, 0, 236, 0, 237, 0, 238, 0, 239, 0, 240, 0, 241, 0, 242, 0, 243, 0, 244, 0, 245, 0, 246, 0, 247, 0, 248, 0, 249, 0, 250, 0, 251, 0, 252, 0, 253, 0, 254, 0, 255, 0], ["i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0], ALLOC_STATIC);
STRING_TABLE.__str1066=allocate([67,80,49,50,53,51,0] /* CP1253\00 */, "i8", ALLOC_STATIC);
_HPDF_UNICODE_MAP_CP1253=allocate([32, 0, 33, 0, 34, 0, 35, 0, 36, 0, 37, 0, 38, 0, 39, 0, 40, 0, 41, 0, 42, 0, 43, 0, 44, 0, 45, 0, 46, 0, 47, 0, 48, 0, 49, 0, 50, 0, 51, 0, 52, 0, 53, 0, 54, 0, 55, 0, 56, 0, 57, 0, 58, 0, 59, 0, 60, 0, 61, 0, 62, 0, 63, 0, 64, 0, 65, 0, 66, 0, 67, 0, 68, 0, 69, 0, 70, 0, 71, 0, 72, 0, 73, 0, 74, 0, 75, 0, 76, 0, 77, 0, 78, 0, 79, 0, 80, 0, 81, 0, 82, 0, 83, 0, 84, 0, 85, 0, 86, 0, 87, 0, 88, 0, 89, 0, 90, 0, 91, 0, 92, 0, 93, 0, 94, 0, 95, 0, 96, 0, 97, 0, 98, 0, 99, 0, 100, 0, 101, 0, 102, 0, 103, 0, 104, 0, 105, 0, 106, 0, 107, 0, 108, 0, 109, 0, 110, 0, 111, 0, 112, 0, 113, 0, 114, 0, 115, 0, 116, 0, 117, 0, 118, 0, 119, 0, 120, 0, 121, 0, 122, 0, 123, 0, 124, 0, 125, 0, 126, 0, 127, 0, 8364, 0, 0, 0, 8218, 0, 402, 0, 8222, 0, 8230, 0, 8224, 0, 8225, 0, 0, 0, 8240, 0, 0, 0, 8249, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 8216, 0, 8217, 0, 8220, 0, 8221, 0, 8226, 0, 8211, 0, 8212, 0, 0, 0, 8482, 0, 0, 0, 8250, 0, 0, 0, 0, 0, 0, 0, 0, 0, 160, 0, 901, 0, 902, 0, 163, 0, 164, 0, 165, 0, 166, 0, 167, 0, 168, 0, 169, 0, 0, 0, 171, 0, 172, 0, 173, 0, 174, 0, 8213, 0, 176, 0, 177, 0, 178, 0, 179, 0, 900, 0, 181, 0, 182, 0, 183, 0, 904, 0, 905, 0, 906, 0, 187, 0, 908, 0, 189, 0, 910, 0, 911, 0, 912, 0, 913, 0, 914, 0, 915, 0, 916, 0, 917, 0, 918, 0, 919, 0, 920, 0, 921, 0, 922, 0, 923, 0, 924, 0, 925, 0, 926, 0, 927, 0, 928, 0, 929, 0, 0, 0, 931, 0, 932, 0, 933, 0, 934, 0, 935, 0, 936, 0, 937, 0, 938, 0, 939, 0, 940, 0, 941, 0, 942, 0, 943, 0, 944, 0, 945, 0, 946, 0, 947, 0, 948, 0, 949, 0, 950, 0, 951, 0, 952, 0, 953, 0, 954, 0, 955, 0, 956, 0, 957, 0, 958, 0, 959, 0, 960, 0, 961, 0, 962, 0, 963, 0, 964, 0, 965, 0, 966, 0, 967, 0, 968, 0, 969, 0, 970, 0, 971, 0, 972, 0, 973, 0, 974, 0, 0, 0], ["i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0], ALLOC_STATIC);
STRING_TABLE.__str1067=allocate([67,80,49,50,53,52,0] /* CP1254\00 */, "i8", ALLOC_STATIC);
_HPDF_UNICODE_MAP_CP1254=allocate([32, 0, 33, 0, 34, 0, 35, 0, 36, 0, 37, 0, 38, 0, 39, 0, 40, 0, 41, 0, 42, 0, 43, 0, 44, 0, 45, 0, 46, 0, 47, 0, 48, 0, 49, 0, 50, 0, 51, 0, 52, 0, 53, 0, 54, 0, 55, 0, 56, 0, 57, 0, 58, 0, 59, 0, 60, 0, 61, 0, 62, 0, 63, 0, 64, 0, 65, 0, 66, 0, 67, 0, 68, 0, 69, 0, 70, 0, 71, 0, 72, 0, 73, 0, 74, 0, 75, 0, 76, 0, 77, 0, 78, 0, 79, 0, 80, 0, 81, 0, 82, 0, 83, 0, 84, 0, 85, 0, 86, 0, 87, 0, 88, 0, 89, 0, 90, 0, 91, 0, 92, 0, 93, 0, 94, 0, 95, 0, 96, 0, 97, 0, 98, 0, 99, 0, 100, 0, 101, 0, 102, 0, 103, 0, 104, 0, 105, 0, 106, 0, 107, 0, 108, 0, 109, 0, 110, 0, 111, 0, 112, 0, 113, 0, 114, 0, 115, 0, 116, 0, 117, 0, 118, 0, 119, 0, 120, 0, 121, 0, 122, 0, 123, 0, 124, 0, 125, 0, 126, 0, 127, 0, 8364, 0, 0, 0, 8218, 0, 402, 0, 8222, 0, 8230, 0, 8224, 0, 8225, 0, 710, 0, 8240, 0, 352, 0, 8249, 0, 338, 0, 0, 0, 0, 0, 0, 0, 0, 0, 8216, 0, 8217, 0, 8220, 0, 8221, 0, 8226, 0, 8211, 0, 8212, 0, 732, 0, 8482, 0, 353, 0, 8250, 0, 339, 0, 0, 0, 0, 0, 376, 0, 160, 0, 161, 0, 162, 0, 163, 0, 164, 0, 165, 0, 166, 0, 167, 0, 168, 0, 169, 0, 170, 0, 171, 0, 172, 0, 173, 0, 174, 0, 175, 0, 176, 0, 177, 0, 178, 0, 179, 0, 180, 0, 181, 0, 182, 0, 183, 0, 184, 0, 185, 0, 186, 0, 187, 0, 188, 0, 189, 0, 190, 0, 191, 0, 192, 0, 193, 0, 194, 0, 195, 0, 196, 0, 197, 0, 198, 0, 199, 0, 200, 0, 201, 0, 202, 0, 203, 0, 204, 0, 205, 0, 206, 0, 207, 0, 286, 0, 209, 0, 210, 0, 211, 0, 212, 0, 213, 0, 214, 0, 215, 0, 216, 0, 217, 0, 218, 0, 219, 0, 220, 0, 304, 0, 350, 0, 223, 0, 224, 0, 225, 0, 226, 0, 227, 0, 228, 0, 229, 0, 230, 0, 231, 0, 232, 0, 233, 0, 234, 0, 235, 0, 236, 0, 237, 0, 238, 0, 239, 0, 287, 0, 241, 0, 242, 0, 243, 0, 244, 0, 245, 0, 246, 0, 247, 0, 248, 0, 249, 0, 250, 0, 251, 0, 252, 0, 305, 0, 351, 0, 255, 0], ["i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0], ALLOC_STATIC);
STRING_TABLE.__str1068=allocate([67,80,49,50,53,53,0] /* CP1255\00 */, "i8", ALLOC_STATIC);
_HPDF_UNICODE_MAP_CP1255=allocate([32, 0, 33, 0, 34, 0, 35, 0, 36, 0, 37, 0, 38, 0, 39, 0, 40, 0, 41, 0, 42, 0, 43, 0, 44, 0, 45, 0, 46, 0, 47, 0, 48, 0, 49, 0, 50, 0, 51, 0, 52, 0, 53, 0, 54, 0, 55, 0, 56, 0, 57, 0, 58, 0, 59, 0, 60, 0, 61, 0, 62, 0, 63, 0, 64, 0, 65, 0, 66, 0, 67, 0, 68, 0, 69, 0, 70, 0, 71, 0, 72, 0, 73, 0, 74, 0, 75, 0, 76, 0, 77, 0, 78, 0, 79, 0, 80, 0, 81, 0, 82, 0, 83, 0, 84, 0, 85, 0, 86, 0, 87, 0, 88, 0, 89, 0, 90, 0, 91, 0, 92, 0, 93, 0, 94, 0, 95, 0, 96, 0, 97, 0, 98, 0, 99, 0, 100, 0, 101, 0, 102, 0, 103, 0, 104, 0, 105, 0, 106, 0, 107, 0, 108, 0, 109, 0, 110, 0, 111, 0, 112, 0, 113, 0, 114, 0, 115, 0, 116, 0, 117, 0, 118, 0, 119, 0, 120, 0, 121, 0, 122, 0, 123, 0, 124, 0, 125, 0, 126, 0, 127, 0, 8364, 0, 0, 0, 8218, 0, 402, 0, 8222, 0, 8230, 0, 8224, 0, 8225, 0, 710, 0, 8240, 0, 0, 0, 8249, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 8216, 0, 8217, 0, 8220, 0, 8221, 0, 8226, 0, 8211, 0, 8212, 0, 732, 0, 8482, 0, 0, 0, 8250, 0, 0, 0, 0, 0, 0, 0, 0, 0, 160, 0, 161, 0, 162, 0, 163, 0, 8362, 0, 165, 0, 166, 0, 167, 0, 168, 0, 169, 0, 215, 0, 171, 0, 172, 0, 173, 0, 174, 0, 175, 0, 176, 0, 177, 0, 178, 0, 179, 0, 180, 0, 181, 0, 182, 0, 183, 0, 184, 0, 185, 0, 247, 0, 187, 0, 188, 0, 189, 0, 190, 0, 191, 0, 1456, 0, 1457, 0, 1458, 0, 1459, 0, 1460, 0, 1461, 0, 1462, 0, 1463, 0, 1464, 0, 1465, 0, 0, 0, 1467, 0, 1468, 0, 1469, 0, 1470, 0, 1471, 0, 1472, 0, 1473, 0, 1474, 0, 1475, 0, 1520, 0, 1521, 0, 1522, 0, 1523, 0, 1524, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1488, 0, 1489, 0, 1490, 0, 1491, 0, 1492, 0, 1493, 0, 1494, 0, 1495, 0, 1496, 0, 1497, 0, 1498, 0, 1499, 0, 1500, 0, 1501, 0, 1502, 0, 1503, 0, 1504, 0, 1505, 0, 1506, 0, 1507, 0, 1508, 0, 1509, 0, 1510, 0, 1511, 0, 1512, 0, 1513, 0, 1514, 0, 0, 0, 0, 0, 8206, 0, 8207, 0, 0, 0], ["i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0], ALLOC_STATIC);
STRING_TABLE.__str1069=allocate([67,80,49,50,53,54,0] /* CP1256\00 */, "i8", ALLOC_STATIC);
_HPDF_UNICODE_MAP_CP1256=allocate([32, 0, 33, 0, 34, 0, 35, 0, 36, 0, 37, 0, 38, 0, 39, 0, 40, 0, 41, 0, 42, 0, 43, 0, 44, 0, 45, 0, 46, 0, 47, 0, 48, 0, 49, 0, 50, 0, 51, 0, 52, 0, 53, 0, 54, 0, 55, 0, 56, 0, 57, 0, 58, 0, 59, 0, 60, 0, 61, 0, 62, 0, 63, 0, 64, 0, 65, 0, 66, 0, 67, 0, 68, 0, 69, 0, 70, 0, 71, 0, 72, 0, 73, 0, 74, 0, 75, 0, 76, 0, 77, 0, 78, 0, 79, 0, 80, 0, 81, 0, 82, 0, 83, 0, 84, 0, 85, 0, 86, 0, 87, 0, 88, 0, 89, 0, 90, 0, 91, 0, 92, 0, 93, 0, 94, 0, 95, 0, 96, 0, 97, 0, 98, 0, 99, 0, 100, 0, 101, 0, 102, 0, 103, 0, 104, 0, 105, 0, 106, 0, 107, 0, 108, 0, 109, 0, 110, 0, 111, 0, 112, 0, 113, 0, 114, 0, 115, 0, 116, 0, 117, 0, 118, 0, 119, 0, 120, 0, 121, 0, 122, 0, 123, 0, 124, 0, 125, 0, 126, 0, 127, 0, 8364, 0, 1662, 0, 8218, 0, 402, 0, 8222, 0, 8230, 0, 8224, 0, 8225, 0, 710, 0, 8240, 0, 1657, 0, 8249, 0, 338, 0, 1670, 0, 1688, 0, 1672, 0, 1711, 0, 8216, 0, 8217, 0, 8220, 0, 8221, 0, 8226, 0, 8211, 0, 8212, 0, 1705, 0, 8482, 0, 1681, 0, 8250, 0, 339, 0, 8204, 0, 8205, 0, 1722, 0, 160, 0, 1548, 0, 162, 0, 163, 0, 164, 0, 165, 0, 166, 0, 167, 0, 168, 0, 169, 0, 1726, 0, 171, 0, 172, 0, 173, 0, 174, 0, 175, 0, 176, 0, 177, 0, 178, 0, 179, 0, 180, 0, 181, 0, 182, 0, 183, 0, 184, 0, 185, 0, 1563, 0, 187, 0, 188, 0, 189, 0, 190, 0, 1567, 0, 1729, 0, 1569, 0, 1570, 0, 1571, 0, 1572, 0, 1573, 0, 1574, 0, 1575, 0, 1576, 0, 1577, 0, 1578, 0, 1579, 0, 1580, 0, 1581, 0, 1582, 0, 1583, 0, 1584, 0, 1585, 0, 1586, 0, 1587, 0, 1588, 0, 1589, 0, 1590, 0, 215, 0, 1591, 0, 1592, 0, 1593, 0, 1594, 0, 1600, 0, 1601, 0, 1602, 0, 1603, 0, 224, 0, 1604, 0, 226, 0, 1605, 0, 1606, 0, 1607, 0, 1608, 0, 231, 0, 232, 0, 233, 0, 234, 0, 235, 0, 1609, 0, 1610, 0, 238, 0, 239, 0, 1611, 0, 1612, 0, 1613, 0, 1614, 0, 244, 0, 1615, 0, 1616, 0, 247, 0, 1617, 0, 249, 0, 1618, 0, 251, 0, 252, 0, 8206, 0, 8207, 0, 1746, 0], ["i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0], ALLOC_STATIC);
STRING_TABLE.__str1070=allocate([67,80,49,50,53,55,0] /* CP1257\00 */, "i8", ALLOC_STATIC);
_HPDF_UNICODE_MAP_CP1257=allocate([32, 0, 33, 0, 34, 0, 35, 0, 36, 0, 37, 0, 38, 0, 39, 0, 40, 0, 41, 0, 42, 0, 43, 0, 44, 0, 45, 0, 46, 0, 47, 0, 48, 0, 49, 0, 50, 0, 51, 0, 52, 0, 53, 0, 54, 0, 55, 0, 56, 0, 57, 0, 58, 0, 59, 0, 60, 0, 61, 0, 62, 0, 63, 0, 64, 0, 65, 0, 66, 0, 67, 0, 68, 0, 69, 0, 70, 0, 71, 0, 72, 0, 73, 0, 74, 0, 75, 0, 76, 0, 77, 0, 78, 0, 79, 0, 80, 0, 81, 0, 82, 0, 83, 0, 84, 0, 85, 0, 86, 0, 87, 0, 88, 0, 89, 0, 90, 0, 91, 0, 92, 0, 93, 0, 94, 0, 95, 0, 96, 0, 97, 0, 98, 0, 99, 0, 100, 0, 101, 0, 102, 0, 103, 0, 104, 0, 105, 0, 106, 0, 107, 0, 108, 0, 109, 0, 110, 0, 111, 0, 112, 0, 113, 0, 114, 0, 115, 0, 116, 0, 117, 0, 118, 0, 119, 0, 120, 0, 121, 0, 122, 0, 123, 0, 124, 0, 125, 0, 126, 0, 127, 0, 8364, 0, 0, 0, 8218, 0, 0, 0, 8222, 0, 8230, 0, 8224, 0, 8225, 0, 0, 0, 8240, 0, 0, 0, 8249, 0, 0, 0, 168, 0, 711, 0, 184, 0, 0, 0, 8216, 0, 8217, 0, 8220, 0, 8221, 0, 8226, 0, 8211, 0, 8212, 0, 0, 0, 8482, 0, 0, 0, 8250, 0, 0, 0, 175, 0, 731, 0, 0, 0, 160, 0, 0, 0, 162, 0, 163, 0, 164, 0, 0, 0, 166, 0, 167, 0, 216, 0, 169, 0, 342, 0, 171, 0, 172, 0, 173, 0, 174, 0, 198, 0, 176, 0, 177, 0, 178, 0, 179, 0, 180, 0, 181, 0, 182, 0, 183, 0, 248, 0, 185, 0, 343, 0, 187, 0, 188, 0, 189, 0, 190, 0, 230, 0, 260, 0, 302, 0, 256, 0, 262, 0, 196, 0, 197, 0, 280, 0, 274, 0, 268, 0, 201, 0, 377, 0, 278, 0, 290, 0, 310, 0, 298, 0, 315, 0, 352, 0, 323, 0, 325, 0, 211, 0, 332, 0, 213, 0, 214, 0, 215, 0, 370, 0, 321, 0, 346, 0, 362, 0, 220, 0, 379, 0, 381, 0, 223, 0, 261, 0, 303, 0, 257, 0, 263, 0, 228, 0, 229, 0, 281, 0, 275, 0, 269, 0, 233, 0, 378, 0, 279, 0, 291, 0, 311, 0, 299, 0, 316, 0, 353, 0, 324, 0, 326, 0, 243, 0, 333, 0, 245, 0, 246, 0, 247, 0, 371, 0, 322, 0, 347, 0, 363, 0, 252, 0, 380, 0, 382, 0, 729, 0], ["i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0], ALLOC_STATIC);
STRING_TABLE.__str1071=allocate([67,80,49,50,53,56,0] /* CP1258\00 */, "i8", ALLOC_STATIC);
_HPDF_UNICODE_MAP_CP1258=allocate([32, 0, 33, 0, 34, 0, 35, 0, 36, 0, 37, 0, 38, 0, 39, 0, 40, 0, 41, 0, 42, 0, 43, 0, 44, 0, 45, 0, 46, 0, 47, 0, 48, 0, 49, 0, 50, 0, 51, 0, 52, 0, 53, 0, 54, 0, 55, 0, 56, 0, 57, 0, 58, 0, 59, 0, 60, 0, 61, 0, 62, 0, 63, 0, 64, 0, 65, 0, 66, 0, 67, 0, 68, 0, 69, 0, 70, 0, 71, 0, 72, 0, 73, 0, 74, 0, 75, 0, 76, 0, 77, 0, 78, 0, 79, 0, 80, 0, 81, 0, 82, 0, 83, 0, 84, 0, 85, 0, 86, 0, 87, 0, 88, 0, 89, 0, 90, 0, 91, 0, 92, 0, 93, 0, 94, 0, 95, 0, 96, 0, 97, 0, 98, 0, 99, 0, 100, 0, 101, 0, 102, 0, 103, 0, 104, 0, 105, 0, 106, 0, 107, 0, 108, 0, 109, 0, 110, 0, 111, 0, 112, 0, 113, 0, 114, 0, 115, 0, 116, 0, 117, 0, 118, 0, 119, 0, 120, 0, 121, 0, 122, 0, 123, 0, 124, 0, 125, 0, 126, 0, 127, 0, 8364, 0, 0, 0, 8218, 0, 402, 0, 8222, 0, 8230, 0, 8224, 0, 8225, 0, 710, 0, 8240, 0, 0, 0, 8249, 0, 338, 0, 0, 0, 0, 0, 0, 0, 0, 0, 8216, 0, 8217, 0, 8220, 0, 8221, 0, 8226, 0, 8211, 0, 8212, 0, 732, 0, 8482, 0, 0, 0, 8250, 0, 339, 0, 0, 0, 0, 0, 376, 0, 160, 0, 161, 0, 162, 0, 163, 0, 164, 0, 165, 0, 166, 0, 167, 0, 168, 0, 169, 0, 170, 0, 171, 0, 172, 0, 173, 0, 174, 0, 175, 0, 176, 0, 177, 0, 178, 0, 179, 0, 180, 0, 181, 0, 182, 0, 183, 0, 184, 0, 185, 0, 186, 0, 187, 0, 188, 0, 189, 0, 190, 0, 191, 0, 192, 0, 193, 0, 194, 0, 258, 0, 196, 0, 197, 0, 198, 0, 199, 0, 200, 0, 201, 0, 202, 0, 203, 0, 768, 0, 205, 0, 206, 0, 207, 0, 272, 0, 209, 0, 777, 0, 211, 0, 212, 0, 416, 0, 214, 0, 215, 0, 216, 0, 217, 0, 218, 0, 219, 0, 220, 0, 431, 0, 771, 0, 223, 0, 224, 0, 225, 0, 226, 0, 259, 0, 228, 0, 229, 0, 230, 0, 231, 0, 232, 0, 233, 0, 234, 0, 235, 0, 769, 0, 237, 0, 238, 0, 239, 0, 273, 0, 241, 0, 803, 0, 243, 0, 244, 0, 417, 0, 246, 0, 247, 0, 248, 0, 249, 0, 250, 0, 251, 0, 252, 0, 432, 0, 8363, 0, 255, 0], ["i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0], ALLOC_STATIC);
STRING_TABLE.__str1072=allocate([75,79,73,56,45,82,0] /* KOI8-R\00 */, "i8", ALLOC_STATIC);
_HPDF_UNICODE_MAP_KOI8_R=allocate([32, 0, 33, 0, 34, 0, 35, 0, 36, 0, 37, 0, 38, 0, 39, 0, 40, 0, 41, 0, 42, 0, 43, 0, 44, 0, 45, 0, 46, 0, 47, 0, 48, 0, 49, 0, 50, 0, 51, 0, 52, 0, 53, 0, 54, 0, 55, 0, 56, 0, 57, 0, 58, 0, 59, 0, 60, 0, 61, 0, 62, 0, 63, 0, 64, 0, 65, 0, 66, 0, 67, 0, 68, 0, 69, 0, 70, 0, 71, 0, 72, 0, 73, 0, 74, 0, 75, 0, 76, 0, 77, 0, 78, 0, 79, 0, 80, 0, 81, 0, 82, 0, 83, 0, 84, 0, 85, 0, 86, 0, 87, 0, 88, 0, 89, 0, 90, 0, 91, 0, 92, 0, 93, 0, 94, 0, 95, 0, 96, 0, 97, 0, 98, 0, 99, 0, 100, 0, 101, 0, 102, 0, 103, 0, 104, 0, 105, 0, 106, 0, 107, 0, 108, 0, 109, 0, 110, 0, 111, 0, 112, 0, 113, 0, 114, 0, 115, 0, 116, 0, 117, 0, 118, 0, 119, 0, 120, 0, 121, 0, 122, 0, 123, 0, 124, 0, 125, 0, 126, 0, 127, 0, 9472, 0, 9474, 0, 9484, 0, 9488, 0, 9492, 0, 9496, 0, 9500, 0, 9508, 0, 9516, 0, 9524, 0, 9532, 0, 9600, 0, 9604, 0, 9608, 0, 9612, 0, 9616, 0, 9617, 0, 9618, 0, 9619, 0, 8992, 0, 9632, 0, 8729, 0, 8730, 0, 8776, 0, 8804, 0, 8805, 0, 160, 0, 8993, 0, 176, 0, 178, 0, 183, 0, 247, 0, 9552, 0, 9553, 0, 9554, 0, 1105, 0, 9555, 0, 9556, 0, 9557, 0, 9558, 0, 9559, 0, 9560, 0, 9561, 0, 9562, 0, 9563, 0, 9564, 0, 9565, 0, 9566, 0, 9567, 0, 9568, 0, 9569, 0, 1025, 0, 9570, 0, 9571, 0, 9572, 0, 9573, 0, 9574, 0, 9575, 0, 9576, 0, 9577, 0, 9578, 0, 9579, 0, 9580, 0, 169, 0, 1102, 0, 1072, 0, 1073, 0, 1094, 0, 1076, 0, 1077, 0, 1092, 0, 1075, 0, 1093, 0, 1080, 0, 1081, 0, 1082, 0, 1083, 0, 1084, 0, 1085, 0, 1086, 0, 1087, 0, 1103, 0, 1088, 0, 1089, 0, 1090, 0, 1091, 0, 1078, 0, 1074, 0, 1100, 0, 1099, 0, 1079, 0, 1096, 0, 1101, 0, 1097, 0, 1095, 0, 1098, 0, 1070, 0, 1040, 0, 1041, 0, 1062, 0, 1044, 0, 1045, 0, 1060, 0, 1043, 0, 1061, 0, 1048, 0, 1049, 0, 1050, 0, 1051, 0, 1052, 0, 1053, 0, 1054, 0, 1055, 0, 1071, 0, 1056, 0, 1057, 0, 1058, 0, 1059, 0, 1046, 0, 1042, 0, 1068, 0, 1067, 0, 1047, 0, 1064, 0, 1069, 0, 1065, 0, 1063, 0, 1066, 0], ["i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0], ALLOC_STATIC);
STRING_TABLE.__str1073=allocate([71,66,75,45,69,85,67,45,72,0] /* GBK-EUC-H\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str11074=allocate([71,66,75,45,69,85,67,45,86,0] /* GBK-EUC-V\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str21075=allocate([71,66,45,69,85,67,45,72,0] /* GB-EUC-H\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str31076=allocate([71,66,45,69,85,67,45,86,0] /* GB-EUC-V\00 */, "i8", ALLOC_STATIC);
_CMAP_ARRAY_GB_EUC_H=allocate([32, 0, 32, 0, 7716, 0, 33, 0, 126, 0, 814, 0, -24159, 0, -24066, 0, 96, 0, -23887, 0, -23838, 0, 190, 0, -23835, 0, -23826, 0, 240, 0, -23823, 0, -23812, 0, 250, 0, -23647, 0, -23554, 0, 262, 0, -23391, 0, -23309, 0, 356, 0, -23135, 0, -23050, 0, 439, 0, -22879, 0, -22856, 0, 525, 0, -22847, 0, -22795, 0, 549, 0, -22623, 0, -22591, 0, 602, 0, -22575, 0, -22543, 0, 635, 0, -22367, 0, -22336, 0, 668, 0, -22331, 0, -22294, 0, 700, 0, -22108, 0, -22033, 0, 738, 0, -21855, 0, -21762, 0, 814, 0, -21599, 0, -21568, 0, 908, 0, -20319, 0, -20226, 0, 940, 0, -20063, 0, -19970, 0, 1034, 0, -19807, 0, -19714, 0, 1128, 0, -19551, 0, -19458, 0, 1222, 0, -19295, 0, -19202, 0, 1316, 0, -19039, 0, -18946, 0, 1410, 0, -18783, 0, -18690, 0, 1504, 0, -18527, 0, -18434, 0, 1598, 0, -18271, 0, -18178, 0, 1692, 0, -18015, 0, -17922, 0, 1786, 0, -17759, 0, -17666, 0, 1880, 0, -17503, 0, -17410, 0, 1974, 0, -17247, 0, -17154, 0, 2068, 0, -16991, 0, -16898, 0, 2162, 0, -16735, 0, -16642, 0, 2256, 0, -16479, 0, -16386, 0, 2350, 0, -16223, 0, -16130, 0, 2444, 0, -15967, 0, -15874, 0, 2538, 0, -15711, 0, -15618, 0, 2632, 0, -15455, 0, -15362, 0, 2726, 0, -15199, 0, -15106, 0, 2820, 0, -14943, 0, -14850, 0, 2914, 0, -14687, 0, -14594, 0, 3008, 0, -14431, 0, -14338, 0, 3102, 0, -14175, 0, -14082, 0, 3196, 0, -13919, 0, -13826, 0, 3290, 0, -13663, 0, -13570, 0, 3384, 0, -13407, 0, -13314, 0, 3478, 0, -13151, 0, -13058, 0, 3572, 0, -12895, 0, -12802, 0, 3666, 0, -12639, 0, -12546, 0, 3760, 0, -12383, 0, -12290, 0, 3854, 0, -12127, 0, -12034, 0, 3948, 0, -11871, 0, -11778, 0, 4042, 0, -11615, 0, -11522, 0, 4136, 0, -11359, 0, -11266, 0, 4230, 0, -11103, 0, -11010, 0, 4324, 0, -10847, 0, -10754, 0, 4418, 0, -10591, 0, -10498, 0, 4512, 0, -10335, 0, -10247, 0, 4606, 0, -10079, 0, -9986, 0, 4695, 0, -9823, 0, -9730, 0, 4789, 0, -9567, 0, -9474, 0, 4883, 0, -9311, 0, -9218, 0, 4977, 0, -9055, 0, -8962, 0, 5071, 0, -8799, 0, -8706, 0, 5165, 0, -8543, 0, -8450, 0, 5259, 0, -8287, 0, -8194, 0, 5353, 0, -8031, 0, -7938, 0, 5447, 0, -7775, 0, -7682, 0, 5541, 0, -7519, 0, -7426, 0, 5635, 0, -7263, 0, -7170, 0, 5729, 0, -7007, 0, -6914, 0, 5823, 0, -6751, 0, -6658, 0, 5917, 0, -6495, 0, -6402, 0, 6011, 0, -6239, 0, -6146, 0, 6105, 0, -5983, 0, -5890, 0, 6199, 0, -5727, 0, -5634, 0, 6293, 0, -5471, 0, -5378, 0, 6387, 0, -5215, 0, -5122, 0, 6481, 0, -4959, 0, -4866, 0, 6575, 0, -4703, 0, -4610, 0, 6669, 0, -4447, 0, -4354, 0, 6763, 0, -4191, 0, -4098, 0, 6857, 0, -3935, 0, -3842, 0, 6951, 0, -3679, 0, -3586, 0, 7045, 0, -3423, 0, -3330, 0, 7139, 0, -3167, 0, -3074, 0, 7233, 0, -2911, 0, -2818, 0, 7327, 0, -2655, 0, -2562, 0, 7421, 0, -2399, 0, -2306, 0, 7515, 0, -2143, 0, -2050, 0, 7609, 0, -1, 0, -1, 0, 0, 0], ["i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0], ALLOC_STATIC);
_CMAP_ARRAY_GB_EUC_V=allocate([-24158, 0, -24158, 0, 575, 0, -24157, 0, -24157, 0, 574, 0, -24150, 0, -24150, 0, 598, 0, -24149, 0, -24148, 0, 7704, 0, -24147, 0, -24147, 0, 599, 0, -24142, 0, -24129, 0, 582, 0, -24066, 0, -24066, 0, 7706, 0, -23647, 0, -23647, 0, 578, 0, -23640, 0, -23639, 0, 580, 0, -23636, 0, -23636, 0, 573, 0, -23634, 0, -23634, 0, 7707, 0, -23622, 0, -23621, 0, 576, 0, -23619, 0, -23619, 0, 7708, 0, -23617, 0, -23617, 0, 579, 0, -23589, 0, -23589, 0, 7709, 0, -23587, 0, -23587, 0, 7710, 0, -23585, 0, -23585, 0, 600, 0, -23557, 0, -23557, 0, 596, 0, -23555, 0, -23555, 0, 597, 0, -23554, 0, -23554, 0, 7711, 0, -1, 0, -1, 0, 0, 0], ["i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0], ALLOC_STATIC);
_GB_EUC_NOTDEF_RANGE=allocate([0, 0, 31, 0, 7716, 0], ["i16",0,"i16",0,"i16",0], ALLOC_STATIC);
_EUC_CN_UNICODE_ARRAY=allocate([32, 0, 32, 0, 33, 0, 33, 0, 34, 0, 34, 0, 35, 0, 35, 0, 36, 0, 36, 0, 37, 0, 37, 0, 38, 0, 38, 0, 39, 0, 39, 0, 40, 0, 40, 0, 41, 0, 41, 0, 42, 0, 42, 0, 43, 0, 43, 0, 44, 0, 44, 0, 45, 0, 45, 0, 46, 0, 46, 0, 47, 0, 47, 0, 48, 0, 48, 0, 49, 0, 49, 0, 50, 0, 50, 0, 51, 0, 51, 0, 52, 0, 52, 0, 53, 0, 53, 0, 54, 0, 54, 0, 55, 0, 55, 0, 56, 0, 56, 0, 57, 0, 57, 0, 58, 0, 58, 0, 59, 0, 59, 0, 60, 0, 60, 0, 61, 0, 61, 0, 62, 0, 62, 0, 63, 0, 63, 0, 64, 0, 64, 0, 65, 0, 65, 0, 66, 0, 66, 0, 67, 0, 67, 0, 68, 0, 68, 0, 69, 0, 69, 0, 70, 0, 70, 0, 71, 0, 71, 0, 72, 0, 72, 0, 73, 0, 73, 0, 74, 0, 74, 0, 75, 0, 75, 0, 76, 0, 76, 0, 77, 0, 77, 0, 78, 0, 78, 0, 79, 0, 79, 0, 80, 0, 80, 0, 81, 0, 81, 0, 82, 0, 82, 0, 83, 0, 83, 0, 84, 0, 84, 0, 85, 0, 85, 0, 86, 0, 86, 0, 87, 0, 87, 0, 88, 0, 88, 0, 89, 0, 89, 0, 90, 0, 90, 0, 91, 0, 91, 0, 92, 0, 92, 0, 93, 0, 93, 0, 94, 0, 94, 0, 95, 0, 95, 0, 96, 0, 96, 0, 97, 0, 97, 0, 98, 0, 98, 0, 99, 0, 99, 0, 100, 0, 100, 0, 101, 0, 101, 0, 102, 0, 102, 0, 103, 0, 103, 0, 104, 0, 104, 0, 105, 0, 105, 0, 106, 0, 106, 0, 107, 0, 107, 0, 108, 0, 108, 0, 109, 0, 109, 0, 110, 0, 110, 0, 111, 0, 111, 0, 112, 0, 112, 0, 113, 0, 113, 0, 114, 0, 114, 0, 115, 0, 115, 0, 116, 0, 116, 0, 117, 0, 117, 0, 118, 0, 118, 0, 119, 0, 119, 0, 120, 0, 120, 0, 121, 0, 121, 0, 122, 0, 122, 0, 123, 0, 123, 0, 124, 0, 124, 0, 125, 0, 125, 0, 126, 0, 126, 0, -24159, 0, 12288, 0, -24158, 0, 12289, 0, -24157, 0, 12290, 0, -24156, 0, 183, 0, -24155, 0, 713, 0, -24154, 0, 711, 0, -24153, 0, 168, 0, -24152, 0, 12291, 0, -24151, 0, 12293, 0, -24150, 0, 8212, 0, -24149, 0, -162, 0, -24148, 0, 8214, 0, -24147, 0, 8230, 0, -24146, 0, 8216, 0, -24145, 0, 8217, 0, -24144, 0, 8220, 0, -24143, 0, 8221, 0, -24142, 0, 12308, 0, -24141, 0, 12309, 0, -24140, 0, 12296, 0, -24139, 0, 12297, 0, -24138, 0, 12298, 0, -24137, 0, 12299, 0, -24136, 0, 12300, 0, -24135, 0, 12301, 0, -24134, 0, 12302, 0, -24133, 0, 12303, 0, -24132, 0, 12310, 0, -24131, 0, 12311, 0, -24130, 0, 12304, 0, -24129, 0, 12305, 0, -24128, 0, 177, 0, -24127, 0, 215, 0, -24126, 0, 247, 0, -24125, 0, 8758, 0, -24124, 0, 8743, 0, -24123, 0, 8744, 0, -24122, 0, 8721, 0, -24121, 0, 8719, 0, -24120, 0, 8746, 0, -24119, 0, 8745, 0, -24118, 0, 8712, 0, -24117, 0, 8759, 0, -24116, 0, 8730, 0, -24115, 0, 8869, 0, -24114, 0, 8741, 0, -24113, 0, 8736, 0, -24112, 0, 8978, 0, -24111, 0, 8857, 0, -24110, 0, 8747, 0, -24109, 0, 8750, 0, -24108, 0, 8801, 0, -24107, 0, 8780, 0, -24106, 0, 8776, 0, -24105, 0, 8765, 0, -24104, 0, 8733, 0, -24103, 0, 8800, 0, -24102, 0, 8814, 0, -24101, 0, 8815, 0, -24100, 0, 8804, 0, -24099, 0, 8805, 0, -24098, 0, 8734, 0, -24097, 0, 8757, 0, -24096, 0, 8756, 0, -24095, 0, 9794, 0, -24094, 0, 9792, 0, -24093, 0, 176, 0, -24092, 0, 8242, 0, -24091, 0, 8243, 0, -24090, 0, 8451, 0, -24089, 0, -252, 0, -24088, 0, 164, 0, -24087, 0, -32, 0, -24086, 0, -31, 0, -24085, 0, 8240, 0, -24084, 0, 167, 0, -24083, 0, 8470, 0, -24082, 0, 9734, 0, -24081, 0, 9733, 0, -24080, 0, 9675, 0, -24079, 0, 9679, 0, -24078, 0, 9678, 0, -24077, 0, 9671, 0, -24076, 0, 9670, 0, -24075, 0, 9633, 0, -24074, 0, 9632, 0, -24073, 0, 9651, 0, -24072, 0, 9650, 0, -24071, 0, 8251, 0, -24070, 0, 8594, 0, -24069, 0, 8592, 0, -24068, 0, 8593, 0, -24067, 0, 8595, 0, -24066, 0, 12307, 0, -23887, 0, 9352, 0, -23886, 0, 9353, 0, -23885, 0, 9354, 0, -23884, 0, 9355, 0, -23883, 0, 9356, 0, -23882, 0, 9357, 0, -23881, 0, 9358, 0, -23880, 0, 9359, 0, -23879, 0, 9360, 0, -23878, 0, 9361, 0, -23877, 0, 9362, 0, -23876, 0, 9363, 0, -23875, 0, 9364, 0, -23874, 0, 9365, 0, -23873, 0, 9366, 0, -23872, 0, 9367, 0, -23871, 0, 9368, 0, -23870, 0, 9369, 0, -23869, 0, 9370, 0, -23868, 0, 9371, 0, -23867, 0, 9332, 0, -23866, 0, 9333, 0, -23865, 0, 9334, 0, -23864, 0, 9335, 0, -23863, 0, 9336, 0, -23862, 0, 9337, 0, -23861, 0, 9338, 0, -23860, 0, 9339, 0, -23859, 0, 9340, 0, -23858, 0, 9341, 0, -23857, 0, 9342, 0, -23856, 0, 9343, 0, -23855, 0, 9344, 0, -23854, 0, 9345, 0, -23853, 0, 9346, 0, -23852, 0, 9347, 0, -23851, 0, 9348, 0, -23850, 0, 9349, 0, -23849, 0, 9350, 0, -23848, 0, 9351, 0, -23847, 0, 9312, 0, -23846, 0, 9313, 0, -23845, 0, 9314, 0, -23844, 0, 9315, 0, -23843, 0, 9316, 0, -23842, 0, 9317, 0, -23841, 0, 9318, 0, -23840, 0, 9319, 0, -23839, 0, 9320, 0, -23838, 0, 9321, 0, -23835, 0, 12832, 0, -23834, 0, 12833, 0, -23833, 0, 12834, 0, -23832, 0, 12835, 0, -23831, 0, 12836, 0, -23830, 0, 12837, 0, -23829, 0, 12838, 0, -23828, 0, 12839, 0, -23827, 0, 12840, 0, -23826, 0, 12841, 0, -23823, 0, 8544, 0, -23822, 0, 8545, 0, -23821, 0, 8546, 0, -23820, 0, 8547, 0, -23819, 0, 8548, 0, -23818, 0, 8549, 0, -23817, 0, 8550, 0, -23816, 0, 8551, 0, -23815, 0, 8552, 0, -23814, 0, 8553, 0, -23813, 0, 8554, 0, -23812, 0, 8555, 0, -23647, 0, -255, 0, -23646, 0, -254, 0, -23645, 0, -253, 0, -23644, 0, -27, 0, -23643, 0, -251, 0, -23642, 0, -250, 0, -23641, 0, -249, 0, -23640, 0, -248, 0, -23639, 0, -247, 0, -23638, 0, -246, 0, -23637, 0, -245, 0, -23636, 0, -244, 0, -23635, 0, -243, 0, -23634, 0, -242, 0, -23633, 0, -241, 0, -23632, 0, -240, 0, -23631, 0, -239, 0, -23630, 0, -238, 0, -23629, 0, -237, 0, -23628, 0, -236, 0, -23627, 0, -235, 0, -23626, 0, -234, 0, -23625, 0, -233, 0, -23624, 0, -232, 0, -23623, 0, -231, 0, -23622, 0, -230, 0, -23621, 0, -229, 0, -23620, 0, -228, 0, -23619, 0, -227, 0, -23618, 0, -226, 0, -23617, 0, -225, 0, -23616, 0, -224, 0, -23615, 0, -223, 0, -23614, 0, -222, 0, -23613, 0, -221, 0, -23612, 0, -220, 0, -23611, 0, -219, 0, -23610, 0, -218, 0, -23609, 0, -217, 0, -23608, 0, -216, 0, -23607, 0, -215, 0, -23606, 0, -214, 0, -23605, 0, -213, 0, -23604, 0, -212, 0, -23603, 0, -211, 0, -23602, 0, -210, 0, -23601, 0, -209, 0, -23600, 0, -208, 0, -23599, 0, -207, 0, -23598, 0, -206, 0, -23597, 0, -205, 0, -23596, 0, -204, 0, -23595, 0, -203, 0, -23594, 0, -202, 0, -23593, 0, -201, 0, -23592, 0, -200, 0, -23591, 0, -199, 0, -23590, 0, -198, 0, -23589, 0, -197, 0, -23588, 0, -196, 0, -23587, 0, -195, 0, -23586, 0, -194, 0, -23585, 0, -193, 0, -23584, 0, -192, 0, -23583, 0, -191, 0, -23582, 0, -190, 0, -23581, 0, -189, 0, -23580, 0, -188, 0, -23579, 0, -187, 0, -23578, 0, -186, 0, -23577, 0, -185, 0, -23576, 0, -184, 0, -23575, 0, -183, 0, -23574, 0, -182, 0, -23573, 0, -181, 0, -23572, 0, -180, 0, -23571, 0, -179, 0, -23570, 0, -178, 0, -23569, 0, -177, 0, -23568, 0, -176, 0, -23567, 0, -175, 0, -23566, 0, -174, 0, -23565, 0, -173, 0, -23564, 0, -172, 0, -23563, 0, -171, 0, -23562, 0, -170, 0, -23561, 0, -169, 0, -23560, 0, -168, 0, -23559, 0, -167, 0, -23558, 0, -166, 0, -23557, 0, -165, 0, -23556, 0, -164, 0, -23555, 0, -163, 0, -23554, 0, -29, 0, -23391, 0, 12353, 0, -23390, 0, 12354, 0, -23389, 0, 12355, 0, -23388, 0, 12356, 0, -23387, 0, 12357, 0, -23386, 0, 12358, 0, -23385, 0, 12359, 0, -23384, 0, 12360, 0, -23383, 0, 12361, 0, -23382, 0, 12362, 0, -23381, 0, 12363, 0, -23380, 0, 12364, 0, -23379, 0, 12365, 0, -23378, 0, 12366, 0, -23377, 0, 12367, 0, -23376, 0, 12368, 0, -23375, 0, 12369, 0, -23374, 0, 12370, 0, -23373, 0, 12371, 0, -23372, 0, 12372, 0, -23371, 0, 12373, 0, -23370, 0, 12374, 0, -23369, 0, 12375, 0, -23368, 0, 12376, 0, -23367, 0, 12377, 0, -23366, 0, 12378, 0, -23365, 0, 12379, 0, -23364, 0, 12380, 0, -23363, 0, 12381, 0, -23362, 0, 12382, 0, -23361, 0, 12383, 0, -23360, 0, 12384, 0, -23359, 0, 12385, 0, -23358, 0, 12386, 0, -23357, 0, 12387, 0, -23356, 0, 12388, 0, -23355, 0, 12389, 0, -23354, 0, 12390, 0, -23353, 0, 12391, 0, -23352, 0, 12392, 0, -23351, 0, 12393, 0, -23350, 0, 12394, 0, -23349, 0, 12395, 0, -23348, 0, 12396, 0, -23347, 0, 12397, 0, -23346, 0, 12398, 0, -23345, 0, 12399, 0, -23344, 0, 12400, 0, -23343, 0, 12401, 0, -23342, 0, 12402, 0, -23341, 0, 12403, 0, -23340, 0, 12404, 0, -23339, 0, 12405, 0, -23338, 0, 12406, 0, -23337, 0, 12407, 0, -23336, 0, 12408, 0, -23335, 0, 12409, 0, -23334, 0, 12410, 0, -23333, 0, 12411, 0, -23332, 0, 12412, 0, -23331, 0, 12413, 0, -23330, 0, 12414, 0, -23329, 0, 12415, 0, -23328, 0, 12416, 0, -23327, 0, 12417, 0, -23326, 0, 12418, 0, -23325, 0, 12419, 0, -23324, 0, 12420, 0, -23323, 0, 12421, 0, -23322, 0, 12422, 0, -23321, 0, 12423, 0, -23320, 0, 12424, 0, -23319, 0, 12425, 0, -23318, 0, 12426, 0, -23317, 0, 12427, 0, -23316, 0, 12428, 0, -23315, 0, 12429, 0, -23314, 0, 12430, 0, -23313, 0, 12431, 0, -23312, 0, 12432, 0, -23311, 0, 12433, 0, -23310, 0, 12434, 0, -23309, 0, 12435, 0, -23135, 0, 12449, 0, -23134, 0, 12450, 0, -23133, 0, 12451, 0, -23132, 0, 12452, 0, -23131, 0, 12453, 0, -23130, 0, 12454, 0, -23129, 0, 12455, 0, -23128, 0, 12456, 0, -23127, 0, 12457, 0, -23126, 0, 12458, 0, -23125, 0, 12459, 0, -23124, 0, 12460, 0, -23123, 0, 12461, 0, -23122, 0, 12462, 0, -23121, 0, 12463, 0, -23120, 0, 12464, 0, -23119, 0, 12465, 0, -23118, 0, 12466, 0, -23117, 0, 12467, 0, -23116, 0, 12468, 0, -23115, 0, 12469, 0, -23114, 0, 12470, 0, -23113, 0, 12471, 0, -23112, 0, 12472, 0, -23111, 0, 12473, 0, -23110, 0, 12474, 0, -23109, 0, 12475, 0, -23108, 0, 12476, 0, -23107, 0, 12477, 0, -23106, 0, 12478, 0, -23105, 0, 12479, 0, -23104, 0, 12480, 0, -23103, 0, 12481, 0, -23102, 0, 12482, 0, -23101, 0, 12483, 0, -23100, 0, 12484, 0, -23099, 0, 12485, 0, -23098, 0, 12486, 0, -23097, 0, 12487, 0, -23096, 0, 12488, 0, -23095, 0, 12489, 0, -23094, 0, 12490, 0, -23093, 0, 12491, 0, -23092, 0, 12492, 0, -23091, 0, 12493, 0, -23090, 0, 12494, 0, -23089, 0, 12495, 0, -23088, 0, 12496, 0, -23087, 0, 12497, 0, -23086, 0, 12498, 0, -23085, 0, 12499, 0, -23084, 0, 12500, 0, -23083, 0, 12501, 0, -23082, 0, 12502, 0, -23081, 0, 12503, 0, -23080, 0, 12504, 0, -23079, 0, 12505, 0, -23078, 0, 12506, 0, -23077, 0, 12507, 0, -23076, 0, 12508, 0, -23075, 0, 12509, 0, -23074, 0, 12510, 0, -23073, 0, 12511, 0, -23072, 0, 12512, 0, -23071, 0, 12513, 0, -23070, 0, 12514, 0, -23069, 0, 12515, 0, -23068, 0, 12516, 0, -23067, 0, 12517, 0, -23066, 0, 12518, 0, -23065, 0, 12519, 0, -23064, 0, 12520, 0, -23063, 0, 12521, 0, -23062, 0, 12522, 0, -23061, 0, 12523, 0, -23060, 0, 12524, 0, -23059, 0, 12525, 0, -23058, 0, 12526, 0, -23057, 0, 12527, 0, -23056, 0, 12528, 0, -23055, 0, 12529, 0, -23054, 0, 12530, 0, -23053, 0, 12531, 0, -23052, 0, 12532, 0, -23051, 0, 12533, 0, -23050, 0, 12534, 0, -22879, 0, 913, 0, -22878, 0, 914, 0, -22877, 0, 915, 0, -22876, 0, 916, 0, -22875, 0, 917, 0, -22874, 0, 918, 0, -22873, 0, 919, 0, -22872, 0, 920, 0, -22871, 0, 921, 0, -22870, 0, 922, 0, -22869, 0, 923, 0, -22868, 0, 924, 0, -22867, 0, 925, 0, -22866, 0, 926, 0, -22865, 0, 927, 0, -22864, 0, 928, 0, -22863, 0, 929, 0, -22862, 0, 931, 0, -22861, 0, 932, 0, -22860, 0, 933, 0, -22859, 0, 934, 0, -22858, 0, 935, 0, -22857, 0, 936, 0, -22856, 0, 937, 0, -22847, 0, 945, 0, -22846, 0, 946, 0, -22845, 0, 947, 0, -22844, 0, 948, 0, -22843, 0, 949, 0, -22842, 0, 950, 0, -22841, 0, 951, 0, -22840, 0, 952, 0, -22839, 0, 953, 0, -22838, 0, 954, 0, -22837, 0, 955, 0, -22836, 0, 956, 0, -22835, 0, 957, 0, -22834, 0, 958, 0, -22833, 0, 959, 0, -22832, 0, 960, 0, -22831, 0, 961, 0, -22830, 0, 963, 0, -22829, 0, 964, 0, -22828, 0, 965, 0, -22827, 0, 966, 0, -22826, 0, 967, 0, -22825, 0, 968, 0, -22824, 0, 969, 0, -22823, 0, -6259, 0, -22822, 0, -6258, 0, -22821, 0, -6257, 0, -22820, 0, -6256, 0, -22819, 0, -6255, 0, -22818, 0, -6254, 0, -22817, 0, -6253, 0, -22816, 0, -459, 0, -22815, 0, -458, 0, -22814, 0, -455, 0, -22813, 0, -454, 0, -22812, 0, -449, 0, -22811, 0, -448, 0, -22810, 0, -451, 0, -22809, 0, -450, 0, -22808, 0, -447, 0, -22807, 0, -446, 0, -22806, 0, -445, 0, -22805, 0, -444, 0, -22804, 0, -6252, 0, -22803, 0, -6251, 0, -22802, 0, -453, 0, -22801, 0, -452, 0, -22800, 0, -457, 0, -22799, 0, -456, 0, -22798, 0, -463, 0, -22797, 0, -6250, 0, -22796, 0, -461, 0, -22795, 0, -460, 0, -22623, 0, 1040, 0, -22622, 0, 1041, 0, -22621, 0, 1042, 0, -22620, 0, 1043, 0, -22619, 0, 1044, 0, -22618, 0, 1045, 0, -22617, 0, 1025, 0, -22616, 0, 1046, 0, -22615, 0, 1047, 0, -22614, 0, 1048, 0, -22613, 0, 1049, 0, -22612, 0, 1050, 0, -22611, 0, 1051, 0, -22610, 0, 1052, 0, -22609, 0, 1053, 0, -22608, 0, 1054, 0, -22607, 0, 1055, 0, -22606, 0, 1056, 0, -22605, 0, 1057, 0, -22604, 0, 1058, 0, -22603, 0, 1059, 0, -22602, 0, 1060, 0, -22601, 0, 1061, 0, -22600, 0, 1062, 0, -22599, 0, 1063, 0, -22598, 0, 1064, 0, -22597, 0, 1065, 0, -22596, 0, 1066, 0, -22595, 0, 1067, 0, -22594, 0, 1068, 0, -22593, 0, 1069, 0, -22592, 0, 1070, 0, -22591, 0, 1071, 0, -22575, 0, 1072, 0, -22574, 0, 1073, 0, -22573, 0, 1074, 0, -22572, 0, 1075, 0, -22571, 0, 1076, 0, -22570, 0, 1077, 0, -22569, 0, 1105, 0, -22568, 0, 1078, 0, -22567, 0, 1079, 0, -22566, 0, 1080, 0, -22565, 0, 1081, 0, -22564, 0, 1082, 0, -22563, 0, 1083, 0, -22562, 0, 1084, 0, -22561, 0, 1085, 0, -22560, 0, 1086, 0, -22559, 0, 1087, 0, -22558, 0, 1088, 0, -22557, 0, 1089, 0, -22556, 0, 1090, 0, -22555, 0, 1091, 0, -22554, 0, 1092, 0, -22553, 0, 1093, 0, -22552, 0, 1094, 0, -22551, 0, 1095, 0, -22550, 0, 1096, 0, -22549, 0, 1097, 0, -22548, 0, 1098, 0, -22547, 0, 1099, 0, -22546, 0, 1100, 0, -22545, 0, 1101, 0, -22544, 0, 1102, 0, -22543, 0, 1103, 0, -22367, 0, 257, 0, -22366, 0, 225, 0, -22365, 0, 462, 0, -22364, 0, 224, 0, -22363, 0, 275, 0, -22362, 0, 233, 0, -22361, 0, 283, 0, -22360, 0, 232, 0, -22359, 0, 299, 0, -22358, 0, 237, 0, -22357, 0, 464, 0, -22356, 0, 236, 0, -22355, 0, 333, 0, -22354, 0, 243, 0, -22353, 0, 466, 0, -22352, 0, 242, 0, -22351, 0, 363, 0, -22350, 0, 250, 0, -22349, 0, 468, 0, -22348, 0, 249, 0, -22347, 0, 470, 0, -22346, 0, 472, 0, -22345, 0, 474, 0, -22344, 0, 476, 0, -22343, 0, 252, 0, -22342, 0, 234, 0, -22341, 0, 593, 0, -22340, 0, 7743, 0, -22339, 0, 324, 0, -22338, 0, 328, 0, -22337, 0, -6200, 0, -22336, 0, 609, 0, -22331, 0, 12549, 0, -22330, 0, 12550, 0, -22329, 0, 12551, 0, -22328, 0, 12552, 0, -22327, 0, 12553, 0, -22326, 0, 12554, 0, -22325, 0, 12555, 0, -22324, 0, 12556, 0, -22323, 0, 12557, 0, -22322, 0, 12558, 0, -22321, 0, 12559, 0, -22320, 0, 12560, 0, -22319, 0, 12561, 0, -22318, 0, 12562, 0, -22317, 0, 12563, 0, -22316, 0, 12564, 0, -22315, 0, 12565, 0, -22314, 0, 12566, 0, -22313, 0, 12567, 0, -22312, 0, 12568, 0, -22311, 0, 12569, 0, -22310, 0, 12570, 0, -22309, 0, 12571, 0, -22308, 0, 12572, 0, -22307, 0, 12573, 0, -22306, 0, 12574, 0, -22305, 0, 12575, 0, -22304, 0, 12576, 0, -22303, 0, 12577, 0, -22302, 0, 12578, 0, -22301, 0, 12579, 0, -22300, 0, 12580, 0, -22299, 0, 12581, 0, -22298, 0, 12582, 0, -22297, 0, 12583, 0, -22296, 0, 12584, 0, -22295, 0, 12585, 0, -22294, 0, -6195, 0, -22108, 0, 9472, 0, -22107, 0, 9473, 0, -22106, 0, 9474, 0, -22105, 0, 9475, 0, -22104, 0, 9476, 0, -22103, 0, 9477, 0, -22102, 0, 9478, 0, -22101, 0, 9479, 0, -22100, 0, 9480, 0, -22099, 0, 9481, 0, -22098, 0, 9482, 0, -22097, 0, 9483, 0, -22096, 0, 9484, 0, -22095, 0, 9485, 0, -22094, 0, 9486, 0, -22093, 0, 9487, 0, -22092, 0, 9488, 0, -22091, 0, 9489, 0, -22090, 0, 9490, 0, -22089, 0, 9491, 0, -22088, 0, 9492, 0, -22087, 0, 9493, 0, -22086, 0, 9494, 0, -22085, 0, 9495, 0, -22084, 0, 9496, 0, -22083, 0, 9497, 0, -22082, 0, 9498, 0, -22081, 0, 9499, 0, -22080, 0, 9500, 0, -22079, 0, 9501, 0, -22078, 0, 9502, 0, -22077, 0, 9503, 0, -22076, 0, 9504, 0, -22075, 0, 9505, 0, -22074, 0, 9506, 0, -22073, 0, 9507, 0, -22072, 0, 9508, 0, -22071, 0, 9509, 0, -22070, 0, 9510, 0, -22069, 0, 9511, 0, -22068, 0, 9512, 0, -22067, 0, 9513, 0, -22066, 0, 9514, 0, -22065, 0, 9515, 0, -22064, 0, 9516, 0, -22063, 0, 9517, 0, -22062, 0, 9518, 0, -22061, 0, 9519, 0, -22060, 0, 9520, 0, -22059, 0, 9521, 0, -22058, 0, 9522, 0, -22057, 0, 9523, 0, -22056, 0, 9524, 0, -22055, 0, 9525, 0, -22054, 0, 9526, 0, -22053, 0, 9527, 0, -22052, 0, 9528, 0, -22051, 0, 9529, 0, -22050, 0, 9530, 0, -22049, 0, 9531, 0, -22048, 0, 9532, 0, -22047, 0, 9533, 0, -22046, 0, 9534, 0, -22045, 0, 9535, 0, -22044, 0, 9536, 0, -22043, 0, 9537, 0, -22042, 0, 9538, 0, -22041, 0, 9539, 0, -22040, 0, 9540, 0, -22039, 0, 9541, 0, -22038, 0, 9542, 0, -22037, 0, 9543, 0, -22036, 0, 9544, 0, -22035, 0, 9545, 0, -22034, 0, 9546, 0, -22033, 0, 9547, 0, -21855, 0, 33, 0, -21854, 0, 34, 0, -21853, 0, 35, 0, -21852, 0, 36, 0, -21851, 0, 37, 0, -21850, 0, 38, 0, -21849, 0, 39, 0, -21848, 0, 40, 0, -21847, 0, 41, 0, -21846, 0, 42, 0, -21845, 0, 43, 0, -21844, 0, 44, 0, -21843, 0, 45, 0, -21842, 0, 46, 0, -21841, 0, 47, 0, -21840, 0, 48, 0, -21839, 0, 49, 0, -21838, 0, 50, 0, -21837, 0, 51, 0, -21836, 0, 52, 0, -21835, 0, 53, 0, -21834, 0, 54, 0, -21833, 0, 55, 0, -21832, 0, 56, 0, -21831, 0, 57, 0, -21830, 0, 58, 0, -21829, 0, 59, 0, -21828, 0, 60, 0, -21827, 0, 61, 0, -21826, 0, 62, 0, -21825, 0, 63, 0, -21824, 0, 64, 0, -21823, 0, 65, 0, -21822, 0, 66, 0, -21821, 0, 67, 0, -21820, 0, 68, 0, -21819, 0, 69, 0, -21818, 0, 70, 0, -21817, 0, 71, 0, -21816, 0, 72, 0, -21815, 0, 73, 0, -21814, 0, 74, 0, -21813, 0, 75, 0, -21812, 0, 76, 0, -21811, 0, 77, 0, -21810, 0, 78, 0, -21809, 0, 79, 0, -21808, 0, 80, 0, -21807, 0, 81, 0, -21806, 0, 82, 0, -21805, 0, 83, 0, -21804, 0, 84, 0, -21803, 0, 85, 0, -21802, 0, 86, 0, -21801, 0, 87, 0, -21800, 0, 88, 0, -21799, 0, 89, 0, -21798, 0, 90, 0, -21797, 0, 91, 0, -21796, 0, 92, 0, -21795, 0, 93, 0, -21794, 0, 94, 0, -21793, 0, 95, 0, -21792, 0, 96, 0, -21791, 0, 97, 0, -21790, 0, 98, 0, -21789, 0, 99, 0, -21788, 0, 100, 0, -21787, 0, 101, 0, -21786, 0, 102, 0, -21785, 0, 103, 0, -21784, 0, 104, 0, -21783, 0, 105, 0, -21782, 0, 106, 0, -21781, 0, 107, 0, -21780, 0, 108, 0, -21779, 0, 109, 0, -21778, 0, 110, 0, -21777, 0, 111, 0, -21776, 0, 112, 0, -21775, 0, 113, 0, -21774, 0, 114, 0, -21773, 0, 115, 0, -21772, 0, 116, 0, -21771, 0, 117, 0, -21770, 0, 118, 0, -21769, 0, 119, 0, -21768, 0, 120, 0, -21767, 0, 121, 0, -21766, 0, 122, 0, -21765, 0, 123, 0, -21764, 0, 124, 0, -21763, 0, 125, 0, -21762, 0, 126, 0, -21599, 0, -8098, 0, -21598, 0, -8097, 0, -21597, 0, -8096, 0, -21596, 0, -8095, 0, -21595, 0, -8094, 0, -21594, 0, -8093, 0, -21593, 0, -8092, 0, -21592, 0, -8091, 0, -21591, 0, -8090, 0, -21590, 0, -8089, 0, -21589, 0, -8088, 0, -21588, 0, -8087, 0, -21587, 0, -8086, 0, -21586, 0, -8085, 0, -21585, 0, -8084, 0, -21584, 0, -8083, 0, -21583, 0, -8082, 0, -21582, 0, -8081, 0, -21581, 0, -8080, 0, -21580, 0, -8079, 0, -21579, 0, -8078, 0, -21578, 0, -8077, 0, -21577, 0, -8076, 0, -21576, 0, -8075, 0, -21575, 0, -8074, 0, -21574, 0, -8073, 0, -21573, 0, -8072, 0, -21572, 0, -8071, 0, -21571, 0, -8070, 0, -21570, 0, -8069, 0, -21569, 0, -8068, 0, -21568, 0, -8067, 0, -20319, 0, 21834, 0, -20318, 0, -27073, 0, -20317, 0, 22467, 0, -20316, 0, 25384, 0, -20315, 0, 21710, 0, -20314, 0, 21769, 0, -20313, 0, 21696, 0, -20312, 0, 30353, 0, -20311, 0, 30284, 0, -20310, 0, -31428, 0, -20309, 0, 30702, 0, -20308, 0, -32130, 0, -20307, 0, 30861, 0, -20306, 0, 29233, 0, -20305, 0, -26984, 0, -20304, 0, -26739, 0, -20303, 0, 27688, 0, -20302, 0, 23433, 0, -20301, 0, 20474, 0, -20300, 0, 25353, 0, -20299, 0, 26263, 0, -20298, 0, 23736, 0, -20297, 0, -32518, 0, -20296, 0, 26696, 0, -20295, 0, -32594, 0, -20294, 0, 26114, 0, -20293, 0, 30414, 0, -20292, 0, 20985, 0, -20291, 0, 25942, 0, -20290, 0, 29100, 0, -20289, 0, 32753, 0, -20288, 0, -30588, 0, -20287, 0, 20658, 0, -20286, 0, 22885, 0, -20285, 0, 25034, 0, -20284, 0, 28595, 0, -20283, 0, -32083, 0, -20282, 0, 25420, 0, -20281, 0, 25170, 0, -20280, 0, 21485, 0, -20279, 0, 21543, 0, -20278, 0, 31494, 0, -20277, 0, 20843, 0, -20276, 0, 30116, 0, -20275, 0, 24052, 0, -20274, 0, 25300, 0, -20273, 0, -29237, 0, -20272, 0, -26762, 0, -20271, 0, 25226, 0, -20270, 0, -32743, 0, -20269, 0, 22365, 0, -20268, 0, -26824, 0, -20267, 0, 32610, 0, -20266, 0, 29240, 0, -20265, 0, 30333, 0, -20264, 0, 26575, 0, -20263, 0, 30334, 0, -20262, 0, 25670, 0, -20261, 0, 20336, 0, -20260, 0, -29403, 0, -20259, 0, 25308, 0, -20258, 0, 31255, 0, -20257, 0, 26001, 0, -20256, 0, 29677, 0, -20255, 0, 25644, 0, -20254, 0, 25203, 0, -20253, 0, -32212, 0, -20252, 0, -26495, 0, -20251, 0, 26495, 0, -20250, 0, 29256, 0, -20249, 0, 25198, 0, -20248, 0, 25292, 0, -20247, 0, 20276, 0, -20246, 0, 29923, 0, -20245, 0, 21322, 0, -20244, 0, 21150, 0, -20243, 0, 32458, 0, -20242, 0, -28506, 0, -20241, 0, 24110, 0, -20240, 0, 26758, 0, -20239, 0, 27036, 0, -20238, 0, -32384, 0, -20237, 0, 32465, 0, -20236, 0, 26834, 0, -20235, 0, 30917, 0, -20234, 0, -31092, 0, -20233, 0, -27311, 0, -20232, 0, 20621, 0, -20231, 0, -29660, 0, -20230, 0, -32034, 0, -20229, 0, -32546, 0, -20228, 0, 21253, 0, -20227, 0, -30446, 0, -20226, 0, 21093, 0, -20063, 0, -31356, 0, -20062, 0, -26887, 0, -20061, 0, 20445, 0, -20060, 0, 22561, 0, -20059, 0, -26255, 0, -20058, 0, 23453, 0, -20057, 0, 25265, 0, -20056, 0, 25253, 0, -20055, 0, 26292, 0, -20054, 0, -29575, 0, -20053, 0, -25459, 0, -20052, 0, 29190, 0, -20051, 0, 26479, 0, -20050, 0, 30865, 0, -20049, 0, 24754, 0, -20048, 0, 21329, 0, -20047, 0, 21271, 0, -20046, 0, -28792, 0, -20045, 0, -32564, 0, -20044, 0, -29411, 0, -20043, 0, -27487, 0, -20042, 0, 20493, 0, -20041, 0, 29384, 0, -20040, 0, 22791, 0, -20039, 0, 24811, 0, -20038, 0, 28953, 0, -20037, 0, -30549, 0, -20036, 0, 22868, 0, -20035, 0, -32017, 0, -20034, 0, 26412, 0, -20033, 0, 31528, 0, -20032, 0, 23849, 0, -20031, 0, 32503, 0, -20030, 0, 29997, 0, -20029, 0, 27893, 0, -20028, 0, -29082, 0, -20027, 0, -28680, 0, -20026, 0, -28612, 0, -20025, 0, -24773, 0, -20024, 0, 27604, 0, -20023, 0, -28391, 0, -20022, 0, 31508, 0, -20021, 0, 24444, 0, -20020, 0, 30887, 0, -20019, 0, -31530, 0, -20018, 0, -31427, 0, -20017, 0, 27605, 0, -20016, 0, 27609, 0, -20015, 0, 27606, 0, -20014, 0, 24065, 0, -20013, 0, 24199, 0, -20012, 0, 30201, 0, -20011, 0, -27155, 0, -20010, 0, 25949, 0, -20009, 0, 24330, 0, -20008, 0, 24517, 0, -20007, 0, -28769, 0, -20006, 0, 22721, 0, -20005, 0, -32318, 0, -20004, 0, -28545, 0, -20003, 0, -27045, 0, -20002, 0, -26707, 0, -20001, 0, -28743, 0, -20000, 0, 32534, 0, -19999, 0, -29396, 0, -19998, 0, 25153, 0, -19997, 0, 20415, 0, -19996, 0, 21464, 0, -19995, 0, 21342, 0, -19994, 0, -28760, 0, -19993, 0, -28759, 0, -19992, 0, -28757, 0, -19991, 0, -28595, 0, -19990, 0, 26631, 0, -19989, 0, 24426, 0, -19988, 0, -32360, 0, -19987, 0, -30616, 0, -19986, 0, -25386, 0, -19985, 0, 24971, 0, -19984, 0, 21035, 0, -19983, 0, 30250, 0, -19982, 0, 24428, 0, -19981, 0, 25996, 0, -19980, 0, 28626, 0, -19979, 0, 28392, 0, -19978, 0, 23486, 0, -19977, 0, 25672, 0, -19976, 0, 20853, 0, -19975, 0, 20912, 0, -19974, 0, 26564, 0, -19973, 0, 19993, 0, -19972, 0, 31177, 0, -19971, 0, -26244, 0, -19970, 0, 28851, 0, -19807, 0, 30149, 0, -19806, 0, 24182, 0, -19805, 0, 29627, 0, -19804, 0, -31776, 0, -19803, 0, 25773, 0, -19802, 0, 25320, 0, -19801, 0, -27467, 0, -19800, 0, 27874, 0, -19799, 0, 21338, 0, -19798, 0, 21187, 0, -19797, 0, 25615, 0, -19796, 0, -27454, 0, -19795, 0, 31636, 0, -19794, 0, 20271, 0, -19793, 0, 24091, 0, -19792, 0, -32202, 0, -19791, 0, -32490, 0, -19790, 0, -32374, 0, -19789, 0, 28196, 0, -19788, 0, 27850, 0, -19787, 0, -25997, 0, -19786, 0, 25429, 0, -19785, 0, 21340, 0, -19784, 0, 21754, 0, -19783, 0, -30619, 0, -19782, 0, 22496, 0, -19781, 0, 19981, 0, -19780, 0, 24067, 0, -19779, 0, 27493, 0, -19778, 0, 31807, 0, -19777, 0, -28440, 0, -19776, 0, 24598, 0, -19775, 0, 25830, 0, -19774, 0, 29468, 0, -19773, 0, -30527, 0, -19772, 0, 26448, 0, -19771, 0, 25165, 0, -19770, 0, -29406, 0, -19769, 0, 30572, 0, -19768, 0, -29143, 0, -19767, 0, -28217, 0, -19766, 0, 24425, 0, -19765, 0, -31780, 0, -19764, 0, -31455, 0, -19763, 0, -26352, 0, -19762, 0, 21442, 0, -19761, 0, -31083, 0, -19760, 0, 27531, 0, -19759, 0, 24813, 0, -19758, 0, 24808, 0, -19757, 0, 28799, 0, -19756, 0, -32051, 0, -19755, 0, -32207, 0, -19754, 0, 20179, 0, -19753, 0, 27815, 0, -19752, 0, -31281, 0, -19751, 0, 25805, 0, -19750, 0, 31961, 0, -19749, 0, 27133, 0, -19748, 0, 26361, 0, -19747, 0, -31927, 0, -19746, 0, 21397, 0, -19745, 0, 31574, 0, -19744, 0, 20391, 0, -19743, 0, 20876, 0, -19742, 0, 27979, 0, -19741, 0, 23618, 0, -19740, 0, -29075, 0, -19739, 0, 25554, 0, -19738, 0, 21449, 0, -19737, 0, -31956, 0, -19736, 0, -31946, 0, -19735, 0, 26597, 0, -19734, 0, 30900, 0, -19733, 0, 25661, 0, -19732, 0, 23519, 0, -19731, 0, 23700, 0, -19730, 0, 24046, 0, -19729, 0, -29721, 0, -19728, 0, 25286, 0, -19727, 0, 26612, 0, -19726, 0, -29574, 0, -19725, 0, 25600, 0, -19724, 0, 25530, 0, -19723, 0, -30903, 0, -19722, 0, -26229, 0, -19721, 0, -29673, 0, -19720, 0, 32544, 0, -19719, 0, -27406, 0, -19718, 0, 20135, 0, -19717, 0, -27120, 0, -19716, 0, -26460, 0, -19715, 0, 26124, 0, -19714, 0, 29462, 0, -19551, 0, 22330, 0, -19550, 0, 23581, 0, -19549, 0, 24120, 0, -19548, 0, -27265, 0, -19547, 0, 20607, 0, -19546, 0, -32608, 0, -19545, 0, 21378, 0, -19544, 0, 25950, 0, -19543, 0, 30021, 0, -19542, 0, 21809, 0, -19541, 0, 20513, 0, -19540, 0, -29307, 0, -19539, 0, 25220, 0, -19538, 0, -27490, 0, -19537, 0, 26397, 0, -19536, 0, 22066, 0, -19535, 0, 28526, 0, -19534, 0, 24034, 0, -19533, 0, 21557, 0, -19532, 0, 28818, 0, -19531, 0, -28826, 0, -19530, 0, 25199, 0, -19529, 0, 25764, 0, -19528, 0, 25507, 0, -19527, 0, 24443, 0, -19526, 0, 28552, 0, -19525, 0, -28428, 0, -19524, 0, -32285, 0, -19523, 0, -28752, 0, -19522, 0, 23576, 0, -19521, 0, 26216, 0, -19520, 0, 24561, 0, -19519, 0, 27785, 0, -19518, 0, -27064, 0, -19517, 0, -29311, 0, -19516, 0, -30612, 0, -19515, 0, 25745, 0, -19514, 0, 31216, 0, -19513, 0, 22478, 0, -19512, 0, 27225, 0, -19511, 0, 25104, 0, -19510, 0, 21576, 0, -19509, 0, 20056, 0, -19508, 0, 31243, 0, -19507, 0, 24809, 0, -19506, 0, 28548, 0, -19505, 0, -29734, 0, -19504, 0, 25215, 0, -19503, 0, -28642, 0, -19502, 0, -25973, 0, -19501, 0, 31204, 0, -19500, 0, 21507, 0, -19499, 0, 30196, 0, -19498, 0, 25345, 0, -19497, 0, 21273, 0, -19496, 0, 27744, 0, -19495, 0, -28705, 0, -19494, 0, 24347, 0, -19493, 0, -26000, 0, -19492, 0, -32709, 0, -19491, 0, -24705, 0, -19490, 0, 20360, 0, -19489, 0, 23610, 0, -19488, 0, -29340, 0, -19487, 0, 32709, 0, -19486, 0, 26021, 0, -19485, 0, 28861, 0, -19484, 0, 20805, 0, -19483, 0, 20914, 0, -19482, 0, -31125, 0, -19481, 0, 23815, 0, -19480, 0, 23456, 0, -19479, 0, 25277, 0, -19478, 0, -28308, 0, -19477, 0, 30068, 0, -19476, 0, -29172, 0, -19475, 0, 31264, 0, -19474, 0, 24833, 0, -19473, 0, 31609, 0, -19472, 0, 20167, 0, -19471, 0, 32504, 0, -19470, 0, 30597, 0, -19469, 0, 19985, 0, -19468, 0, -32275, 0, -19467, 0, 21021, 0, -19466, 0, 20986, 0, -19465, 0, 27249, 0, -19464, 0, 21416, 0, -19463, 0, -29049, 0, -19462, 0, -27388, 0, -19461, 0, -26929, 0, -19460, 0, 28353, 0, -19459, 0, -27036, 0, -19458, 0, 26970, 0, -19295, 0, 30784, 0, -19294, 0, 20648, 0, -19293, 0, 30679, 0, -19292, 0, 25616, 0, -19291, 0, -30234, 0, -19290, 0, 22788, 0, -19289, 0, 25571, 0, -19288, 0, 24029, 0, -19287, 0, 31359, 0, -19286, 0, 26941, 0, -19285, 0, 20256, 0, -19284, 0, -32199, 0, -19283, 0, 21912, 0, -19282, 0, 20018, 0, -19281, 0, 30126, 0, -19280, 0, 31383, 0, -19279, 0, 24162, 0, -19278, 0, 24202, 0, -19277, 0, -27153, 0, -19276, 0, 21019, 0, -19275, 0, 21561, 0, -19274, 0, 28810, 0, -19273, 0, 25462, 0, -19272, 0, -27356, 0, -19271, 0, 22402, 0, -19270, 0, 26149, 0, -19269, 0, 26943, 0, -19268, 0, -28281, 0, -19267, 0, 21767, 0, -19266, 0, 28147, 0, -19265, 0, 32431, 0, -19264, 0, -30686, 0, -19263, 0, 25139, 0, -19262, 0, 32496, 0, -19261, 0, 30133, 0, -19260, 0, -31960, 0, -19259, 0, 30913, 0, -19258, 0, -26932, 0, -19257, 0, -28770, 0, -19256, 0, 24904, 0, -19255, 0, 29943, 0, -19254, 0, -29747, 0, -19253, 0, 27492, 0, -19252, 0, 21050, 0, -19251, 0, -29360, 0, -19250, 0, 27425, 0, -19249, 0, -32662, 0, -19248, 0, -31631, 0, -19247, 0, 22257, 0, -19246, 0, 21254, 0, -19245, 0, 20174, 0, -19244, 0, 19995, 0, -19243, 0, 20945, 0, -19242, 0, 31895, 0, -19241, 0, -28277, 0, -19240, 0, 31751, 0, -19239, 0, 20419, 0, -19238, 0, -29057, 0, -19237, 0, 31713, 0, -19236, 0, 31388, 0, -19235, 0, 25703, 0, -19234, 0, 23828, 0, -19233, 0, 20652, 0, -19232, 0, -32506, 0, -19231, 0, 30209, 0, -19230, 0, 31929, 0, -19229, 0, 28140, 0, -19228, 0, 32736, 0, -19227, 0, 26449, 0, -19226, 0, 23384, 0, -19225, 0, 23544, 0, -19224, 0, 30923, 0, -19223, 0, 25774, 0, -19222, 0, 25619, 0, -19221, 0, 25514, 0, -19220, 0, 25387, 0, -19219, 0, -27367, 0, -19218, 0, 25645, 0, -19217, 0, -28738, 0, -19216, 0, 31572, 0, -19215, 0, 30249, 0, -19214, 0, 25171, 0, -19213, 0, 22823, 0, -19212, 0, 21574, 0, -19211, 0, 27513, 0, -19210, 0, 20643, 0, -19209, 0, 25140, 0, -19208, 0, 24102, 0, -19207, 0, 27526, 0, -19206, 0, 20195, 0, -19205, 0, -29385, 0, -19204, 0, -30581, 0, -19203, 0, 24453, 0, -19202, 0, -28626, 0, -19039, 0, 24608, 0, -19038, 0, -32707, 0, -19037, 0, 25285, 0, -19036, 0, 20025, 0, -19035, 0, 21333, 0, -19034, 0, -28424, 0, -19033, 0, 25528, 0, -19032, 0, -32570, 0, -19031, 0, 26086, 0, -19030, 0, 27694, 0, -19029, 0, 20294, 0, -19028, 0, 24814, 0, -19027, 0, 28129, 0, -19026, 0, -29730, 0, -19025, 0, 24377, 0, -19024, 0, -31029, 0, -19023, 0, 24403, 0, -19022, 0, 25377, 0, -19021, 0, 20826, 0, -19020, 0, -31903, 0, -19019, 0, 26723, 0, -19018, 0, 20992, 0, -19017, 0, 25443, 0, -19016, 0, -29112, 0, -19015, 0, 20498, 0, -19014, 0, 23707, 0, -19013, 0, 31095, 0, -19012, 0, 23548, 0, -19011, 0, 21040, 0, -19010, 0, 31291, 0, -19009, 0, 24764, 0, -19008, 0, -28589, 0, -19007, 0, 30423, 0, -19006, 0, 24503, 0, -19005, 0, 24471, 0, -19004, 0, 30340, 0, -19003, 0, -29076, 0, -19002, 0, 28783, 0, -19001, 0, 30331, 0, -19000, 0, 31561, 0, -18999, 0, 30634, 0, -18998, 0, 20979, 0, -18997, 0, -28525, 0, -18996, 0, 22564, 0, -18995, 0, 20302, 0, -18994, 0, 28404, 0, -18993, 0, -28694, 0, -18992, 0, 25932, 0, -18991, 0, 31515, 0, -18990, 0, 29380, 0, -18989, 0, 28068, 0, -18988, 0, 32735, 0, -18987, 0, 23265, 0, -18986, 0, 25269, 0, -18985, 0, 24213, 0, -18984, 0, 22320, 0, -18983, 0, -31614, 0, -18982, 0, 31532, 0, -18981, 0, 24093, 0, -18980, 0, 24351, 0, -18979, 0, -28654, 0, -18978, 0, 32532, 0, -18977, 0, -26464, 0, -18976, 0, 25474, 0, -18975, 0, 28359, 0, -18974, 0, 30872, 0, -18973, 0, 28857, 0, -18972, 0, 20856, 0, -18971, 0, -26789, 0, -18970, 0, 22443, 0, -18969, 0, 30005, 0, -18968, 0, 20291, 0, -18967, 0, 30008, 0, -18966, 0, 24215, 0, -18965, 0, 24806, 0, -18964, 0, 22880, 0, -18963, 0, 28096, 0, -18962, 0, 27583, 0, -18961, 0, 30857, 0, -18960, 0, 21500, 0, -18959, 0, -26923, 0, -18958, 0, 20939, 0, -18957, 0, 20993, 0, -18956, 0, 25481, 0, -18955, 0, 21514, 0, -18954, 0, -27501, 0, -18953, 0, -29693, 0, -18952, 0, -29236, 0, -18951, 0, 29241, 0, -18950, 0, 30879, 0, -18949, 0, -30858, 0, -18948, 0, -28691, 0, -18947, 0, -29683, 0, -18946, 0, 21472, 0, -18783, 0, 19969, 0, -18782, 0, 30447, 0, -18781, 0, 21486, 0, -18780, 0, -27511, 0, -18779, 0, -26506, 0, -18778, 0, -24818, 0, -18777, 0, -27347, 0, -18776, 0, 23450, 0, -18775, 0, -29790, 0, -18774, 0, 20002, 0, -18773, 0, 19996, 0, -18772, 0, 20908, 0, -18771, 0, -31645, 0, -18770, 0, 25026, 0, -18769, 0, 21160, 0, -18768, 0, 26635, 0, -18767, 0, 20375, 0, -18766, 0, 24683, 0, -18765, 0, 20923, 0, -18764, 0, 27934, 0, -18763, 0, 20828, 0, -18762, 0, 25238, 0, -18761, 0, 26007, 0, -18760, 0, -27039, 0, -18759, 0, -29626, 0, -18758, 0, -28649, 0, -18757, 0, 30168, 0, -18756, 0, -28419, 0, -18755, 0, 30563, 0, -18754, 0, 27602, 0, -18753, 0, 29322, 0, -18752, 0, 29420, 0, -18751, 0, -29701, 0, -18750, 0, 22581, 0, -18749, 0, 30585, 0, -18748, 0, -29364, 0, -18747, 0, 26460, 0, -18746, 0, -27328, 0, -18745, 0, -32614, 0, -18744, 0, 24230, 0, -18743, 0, 28193, 0, -18742, 0, 22930, 0, -18741, 0, 31471, 0, -18740, 0, 30701, 0, -18739, 0, -27333, 0, -18738, 0, 27573, 0, -18737, 0, 26029, 0, -18736, 0, 32526, 0, -18735, 0, 22534, 0, -18734, 0, 20817, 0, -18733, 0, -27105, 0, -18732, 0, 23545, 0, -18731, 0, 22697, 0, -18730, 0, 21544, 0, -18729, 0, -29070, 0, -18728, 0, 25958, 0, -18727, 0, -26497, 0, -18726, 0, 22244, 0, -18725, 0, -27491, 0, -18724, 0, 30462, 0, -18723, 0, -28607, 0, -18722, 0, 25479, 0, -18721, 0, 21702, 0, -18720, 0, 22810, 0, -18719, 0, 22842, 0, -18718, 0, 22427, 0, -18717, 0, -29006, 0, -18716, 0, 26421, 0, -18715, 0, -29190, 0, -18714, 0, -32203, 0, -18713, 0, 21057, 0, -18712, 0, 24816, 0, -18711, 0, 22549, 0, -18710, 0, -30978, 0, -18709, 0, 23784, 0, -18708, 0, -25019, 0, -18707, 0, 20420, 0, -18706, 0, -26467, 0, -18705, 0, -29767, 0, -18704, 0, 23077, 0, -18703, 0, 24694, 0, -18702, 0, 21380, 0, -18701, 0, 25212, 0, -18700, 0, -28593, 0, -18699, 0, -28414, 0, -18698, 0, -26241, 0, -18697, 0, 24681, 0, -18696, 0, -32756, 0, -18695, 0, 20799, 0, -18694, 0, -32717, 0, -18693, 0, 23572, 0, -18692, 0, -26251, 0, -18691, 0, 27953, 0, -18690, 0, 20108, 0, -18527, 0, -29392, 0, -18526, 0, 21457, 0, -18525, 0, 32602, 0, -18524, 0, 31567, 0, -18523, 0, 20240, 0, -18522, 0, 20047, 0, -18521, 0, -27136, 0, -18520, 0, 27861, 0, -18519, 0, 29648, 0, -18518, 0, -31255, 0, -18517, 0, 24070, 0, -18516, 0, 30058, 0, -18515, 0, 32763, 0, -18514, 0, 27146, 0, -18513, 0, 30718, 0, -18512, 0, -27502, 0, -18511, 0, 32321, 0, -18510, 0, 20961, 0, -18509, 0, 28902, 0, -18508, 0, 21453, 0, -18507, 0, -28716, 0, -18506, 0, -31997, 0, -18505, 0, -29399, 0, -18504, 0, 29359, 0, -18503, 0, -26259, 0, -18502, 0, 27867, 0, -18501, 0, 22346, 0, -18500, 0, -32077, 0, -18499, 0, 26041, 0, -18498, 0, -32598, 0, -18497, 0, 25151, 0, -18496, 0, -27086, 0, -18495, 0, 22952, 0, -18494, 0, 20223, 0, -18493, 0, -29761, 0, -18492, 0, 32442, 0, -18491, 0, 25918, 0, -18490, 0, -31758, 0, -18489, 0, -26786, 0, -18488, 0, 21857, 0, -18487, 0, -26402, 0, -18486, 0, -32603, 0, -18485, 0, 21290, 0, -18484, 0, -29699, 0, -18483, 0, 21536, 0, -18482, 0, -32582, 0, -18481, 0, 24223, 0, -18480, 0, 27832, 0, -18479, 0, -29383, 0, -18478, 0, -32084, 0, -18477, 0, -28326, 0, -18476, 0, 21545, 0, -18475, 0, 27675, 0, -18474, 0, 20998, 0, -18473, 0, 32439, 0, -18472, 0, 22367, 0, -18471, 0, 28954, 0, -18470, 0, 27774, 0, -18469, 0, 31881, 0, -18468, 0, 22859, 0, -18467, 0, 20221, 0, -18466, 0, 24575, 0, -18465, 0, 24868, 0, -18464, 0, 31914, 0, -18463, 0, 20016, 0, -18462, 0, 23553, 0, -18461, 0, 26539, 0, -18460, 0, -30974, 0, -18459, 0, 23792, 0, -18458, 0, -27381, 0, -18457, 0, -26418, 0, -18456, 0, 30127, 0, -18455, 0, 28925, 0, -18454, 0, -28638, 0, -18453, 0, 20911, 0, -18452, 0, 32541, 0, -18451, 0, -29763, 0, -18450, 0, 22857, 0, -18449, 0, 20964, 0, -18448, 0, 20315, 0, -18447, 0, 21542, 0, -18446, 0, 22827, 0, -18445, 0, 25975, 0, -18444, 0, -32604, 0, -18443, 0, 23413, 0, -18442, 0, 25206, 0, -18441, 0, 25282, 0, -18440, 0, -28784, 0, -18439, 0, 24133, 0, -18438, 0, 27679, 0, -18437, 0, 31526, 0, -18436, 0, 20239, 0, -18435, 0, 20440, 0, -18434, 0, 26381, 0, -18271, 0, 28014, 0, -18270, 0, 28074, 0, -18269, 0, 31119, 0, -18268, 0, -30543, 0, -18267, 0, 24343, 0, -18266, 0, 29995, 0, -18265, 0, 25242, 0, -18264, 0, -28795, 0, -18263, 0, 20463, 0, -18262, 0, -28196, 0, -18261, 0, 26023, 0, -18260, 0, -32465, 0, -18259, 0, -32431, 0, -18258, 0, 24220, 0, -18257, 0, -32432, 0, -18256, 0, -29324, 0, -18255, 0, 21103, 0, -18254, 0, -30330, 0, -18253, 0, -29365, 0, -18252, 0, 22797, 0, -18251, 0, 20613, 0, -18250, 0, 20184, 0, -18249, 0, -27108, 0, -18248, 0, 29238, 0, -18247, 0, -32391, 0, -18246, 0, -29409, 0, -18245, 0, 23500, 0, -18244, 0, -29789, 0, -18243, 0, -27068, 0, -18242, 0, 22919, 0, -18241, 0, 32538, 0, -18240, 0, 21648, 0, -18239, 0, 22134, 0, -18238, 0, 22030, 0, -18237, 0, -29723, 0, -18236, 0, 25913, 0, -18235, 0, 27010, 0, -18234, 0, -27495, 0, -18233, 0, 30422, 0, -18232, 0, 28297, 0, -18231, 0, 24178, 0, -18230, 0, 29976, 0, -18229, 0, 26438, 0, -18228, 0, 26577, 0, -18227, 0, 31487, 0, -18226, 0, -32611, 0, -18225, 0, -29322, 0, -18224, 0, 24863, 0, -18223, 0, 31174, 0, -18222, 0, 25954, 0, -18221, 0, -29341, 0, -18220, 0, 20872, 0, -18219, 0, 21018, 0, -18218, 0, -27486, 0, -18217, 0, 32568, 0, -18216, 0, -32613, 0, -18215, 0, 32434, 0, -18214, 0, 23703, 0, -18213, 0, 28207, 0, -18212, 0, 26464, 0, -18211, 0, 31705, 0, -18210, 0, 30347, 0, -18209, 0, -25896, 0, -18208, 0, -32369, 0, -18207, 0, 32660, 0, -18206, 0, 31957, 0, -18205, 0, 25630, 0, -18204, 0, -27312, 0, -18203, 0, 31295, 0, -18202, 0, 21578, 0, -18201, 0, 21733, 0, -18200, 0, 27468, 0, -18199, 0, 25601, 0, -18198, 0, 25096, 0, -18197, 0, -25027, 0, -18196, 0, -32525, 0, -18195, 0, 30105, 0, -18194, 0, 21106, 0, -18193, 0, -26775, 0, -18192, 0, -31653, 0, -18191, 0, 26684, 0, -18190, 0, -31004, 0, -18189, 0, -27135, 0, -18188, 0, -26988, 0, -18187, 0, -27412, 0, -18186, 0, 20010, 0, -18185, 0, 21508, 0, -18184, 0, 32473, 0, -18183, 0, 26681, 0, -18182, 0, -29217, 0, -18181, 0, -32747, 0, -18180, 0, 26356, 0, -18179, 0, 24218, 0, -18178, 0, 32697, 0, -18015, 0, 22466, 0, -18014, 0, -32705, 0, -18013, 0, 26775, 0, -18012, 0, 24037, 0, -18011, 0, 25915, 0, -18010, 0, 21151, 0, -18009, 0, 24685, 0, -18008, 0, -24678, 0, -18007, 0, 20379, 0, -18006, 0, -29012, 0, -18005, 0, 20844, 0, -18004, 0, 23467, 0, -18003, 0, 24339, 0, -18002, 0, 24041, 0, -18001, 0, 27742, 0, -18000, 0, 25329, 0, -17999, 0, -29407, 0, -17998, 0, 20849, 0, -17997, 0, -27479, 0, -17996, 0, 21246, 0, -17995, 0, 27807, 0, -17994, 0, -32033, 0, -17993, 0, 29399, 0, -17992, 0, 22434, 0, -17991, 0, 26500, 0, -17990, 0, -29395, 0, -17989, 0, 22815, 0, -17988, 0, -28772, 0, -17987, 0, -31801, 0, -17986, 0, 21653, 0, -17985, 0, 31629, 0, -17984, 0, 20272, 0, -17983, 0, 27837, 0, -17982, 0, 23396, 0, -17981, 0, 22993, 0, -17980, 0, -24813, 0, -17979, 0, 21476, 0, -17978, 0, -31030, 0, -17977, 0, -25944, 0, -17976, 0, -29641, 0, -17975, 0, -32607, 0, -17974, 0, 25925, 0, -17973, 0, -26498, 0, -17972, 0, 22266, 0, -17971, 0, -26937, 0, -17970, 0, 21038, 0, -17969, 0, 29916, 0, -17968, 0, 21072, 0, -17967, 0, 23521, 0, -17966, 0, 25346, 0, -17965, 0, -30462, 0, -17964, 0, 20054, 0, -17963, 0, 25296, 0, -17962, 0, 24618, 0, -17961, 0, 26874, 0, -17960, 0, 20851, 0, -17959, 0, 23448, 0, -17958, 0, 20896, 0, -17957, 0, -30270, 0, -17956, 0, 31649, 0, -17955, 0, -26234, 0, -17954, 0, 32592, 0, -17953, 0, 24815, 0, -17952, 0, 28748, 0, -17951, 0, -29393, 0, -17950, 0, 20809, 0, -17949, 0, 24191, 0, -17948, 0, -28645, 0, -17947, 0, 29808, 0, -17946, 0, -30268, 0, -17945, 0, 22317, 0, -17944, 0, 30789, 0, -17943, 0, 24402, 0, -17942, 0, -24673, 0, -17941, 0, -27142, 0, -17940, 0, -28824, 0, -17939, 0, -25796, 0, -17938, 0, -29727, 0, -17937, 0, 30328, 0, -17936, 0, 26690, 0, -17935, 0, 26588, 0, -17934, 0, -29206, 0, -17933, 0, -29387, 0, -17932, 0, 21053, 0, -17931, 0, -28790, 0, -17930, 0, 28378, 0, -17929, 0, 26829, 0, -17928, 0, -27387, 0, -17927, 0, -28435, 0, -17926, 0, 22269, 0, -17925, 0, 26524, 0, -17924, 0, -30471, 0, -17923, 0, -28729, 0, -17922, 0, 21704, 0, -17759, 0, -25928, 0, -17758, 0, 23401, 0, -17757, 0, 28023, 0, -17756, 0, 27686, 0, -17755, 0, 20133, 0, -17754, 0, 23475, 0, -17753, 0, -25977, 0, -17752, 0, -28317, 0, -17751, 0, 25000, 0, -17750, 0, -28497, 0, -17749, 0, -26647, 0, -17748, 0, 21547, 0, -17747, 0, 28085, 0, -17746, 0, 23506, 0, -17745, 0, 20989, 0, -17744, 0, 21898, 0, -17743, 0, 32597, 0, -17742, 0, 32752, 0, -17741, 0, 25788, 0, -17740, 0, 25421, 0, -17739, 0, 26097, 0, -17738, 0, 25022, 0, -17737, 0, 24717, 0, -17736, 0, 28938, 0, -17735, 0, 27735, 0, -17734, 0, 27721, 0, -17733, 0, 22831, 0, -17732, 0, 26477, 0, -17731, 0, -32214, 0, -17730, 0, 22741, 0, -17729, 0, 22158, 0, -17728, 0, -29590, 0, -17727, 0, 27627, 0, -17726, 0, -28451, 0, -17725, 0, 22909, 0, -17724, 0, -32745, 0, -17723, 0, 21495, 0, -17722, 0, 28009, 0, -17721, 0, 21621, 0, -17720, 0, 21917, 0, -17719, 0, -31881, 0, -17718, 0, -31793, 0, -17717, 0, 26680, 0, -17716, 0, 31166, 0, -17715, 0, 21644, 0, -17714, 0, 20309, 0, -17713, 0, 21512, 0, -17712, 0, 30418, 0, -17711, 0, -29559, 0, -17710, 0, -27134, 0, -17709, 0, 27827, 0, -17708, 0, 28088, 0, -17707, 0, -29333, 0, -17706, 0, -30448, 0, -17705, 0, -24988, 0, -17704, 0, -29382, 0, -17703, 0, 22079, 0, -17702, 0, -24879, 0, -17701, 0, 30165, 0, -17700, 0, 24456, 0, -17699, 0, 29408, 0, -17698, 0, 24680, 0, -17697, 0, 21756, 0, -17696, 0, 20136, 0, -17695, 0, 27178, 0, -17694, 0, -30623, 0, -17693, 0, 24658, 0, -17692, 0, -28816, 0, -17691, 0, 21700, 0, -17690, 0, 28888, 0, -17689, 0, -31111, 0, -17688, 0, -25025, 0, -17687, 0, 27946, 0, -17686, 0, 23439, 0, -17685, 0, 24344, 0, -17684, 0, 32418, 0, -17683, 0, 21897, 0, -17682, 0, 20399, 0, -17681, 0, 29492, 0, -17680, 0, 21564, 0, -17679, 0, 21402, 0, -17678, 0, 20505, 0, -17677, 0, 21518, 0, -17676, 0, 21628, 0, -17675, 0, 20046, 0, -17674, 0, 24573, 0, -17673, 0, 29786, 0, -17672, 0, 22774, 0, -17671, 0, -31637, 0, -17670, 0, -32543, 0, -17669, 0, -30860, 0, -17668, 0, 29392, 0, -17667, 0, 31946, 0, -17666, 0, 28246, 0, -17503, 0, 24359, 0, -17502, 0, -31154, 0, -17501, 0, 21804, 0, -17500, 0, 25252, 0, -17499, 0, 20114, 0, -17498, 0, 27818, 0, -17497, 0, 25143, 0, -17496, 0, -32079, 0, -17495, 0, 21719, 0, -17494, 0, 21326, 0, -17493, 0, 29502, 0, -17492, 0, 28369, 0, -17491, 0, 30011, 0, -17490, 0, 21010, 0, -17489, 0, 21270, 0, -17488, 0, -29731, 0, -17487, 0, 27088, 0, -17486, 0, 24458, 0, -17485, 0, 24576, 0, -17484, 0, 28142, 0, -17483, 0, 22351, 0, -17482, 0, 27426, 0, -17481, 0, 29615, 0, -17480, 0, 26707, 0, -17479, 0, -28712, 0, -17478, 0, 32531, 0, -17477, 0, 25442, 0, -17476, 0, 24739, 0, -17475, 0, 21796, 0, -17474, 0, 30186, 0, -17473, 0, -29598, 0, -17472, 0, 28949, 0, -17471, 0, 28067, 0, -17470, 0, 23462, 0, -17469, 0, 24187, 0, -17468, 0, -31918, 0, -17467, 0, 24908, 0, -17466, 0, -24892, 0, -17465, 0, 30970, 0, -17464, 0, -30889, 0, -17463, 0, 31783, 0, -17462, 0, 30343, 0, -17461, 0, 20976, 0, -17460, 0, 24822, 0, -17459, 0, 29004, 0, -17458, 0, 26179, 0, -17457, 0, 24140, 0, -17456, 0, 24653, 0, -17455, 0, -29682, 0, -17454, 0, 28784, 0, -17453, 0, 25381, 0, -17452, 0, -28791, 0, -17451, 0, 24509, 0, -17450, 0, 24674, 0, -17449, 0, -31020, 0, -17448, 0, 22238, 0, -17447, 0, 27585, 0, -17446, 0, 24724, 0, -17445, 0, 24935, 0, -17444, 0, 21321, 0, -17443, 0, 24800, 0, -17442, 0, 26214, 0, -17441, 0, -29377, 0, -17440, 0, 31229, 0, -17439, 0, 20250, 0, -17438, 0, 28905, 0, -17437, 0, 27719, 0, -17436, 0, -29773, 0, -17435, 0, -29710, 0, -17434, 0, 32472, 0, -17433, 0, -31900, 0, -17432, 0, 26127, 0, -17431, 0, 23130, 0, -17430, 0, -25790, 0, -17429, 0, 27985, 0, -17428, 0, 28151, 0, -17427, 0, -29631, 0, -17426, 0, 27963, 0, -17425, 0, 20249, 0, -17424, 0, 28779, 0, -17423, 0, -31817, 0, -17422, 0, 25110, 0, -17421, 0, 24785, 0, -17420, 0, -26867, 0, -17419, 0, -29401, 0, -17418, 0, 31096, 0, -17417, 0, 20987, 0, -17416, 0, 22334, 0, -17415, 0, 22522, 0, -17414, 0, 26426, 0, -17413, 0, 30072, 0, -17412, 0, 31293, 0, -17411, 0, 31215, 0, -17410, 0, 31637, 0, -17247, 0, -32628, 0, -17246, 0, -26267, 0, -17245, 0, -28679, 0, -17244, 0, 28608, 0, -17243, 0, -29787, 0, -17242, 0, -25055, 0, -17241, 0, 23020, 0, -17240, 0, 32489, 0, -17239, 0, 32521, 0, -17238, 0, 21513, 0, -17237, 0, 26497, 0, -17236, 0, 26840, 0, -17235, 0, -28783, 0, -17234, 0, 31821, 0, -17233, 0, -26938, 0, -17232, 0, 21450, 0, -17231, 0, 24613, 0, -17230, 0, 30142, 0, -17229, 0, 27762, 0, -17228, 0, 21363, 0, -17227, 0, 23241, 0, -17226, 0, 32423, 0, -17225, 0, 25380, 0, -17224, 0, 20960, 0, -17223, 0, -32502, 0, -17222, 0, 24049, 0, -17221, 0, -31521, 0, -17220, 0, 25216, 0, -17219, 0, 20864, 0, -17218, 0, 23395, 0, -17217, 0, 20238, 0, -17216, 0, 31085, 0, -17215, 0, 21058, 0, -17214, 0, 24760, 0, -17213, 0, 27982, 0, -17212, 0, 23492, 0, -17211, 0, 23490, 0, -17210, 0, -29791, 0, -17209, 0, -29776, 0, -17208, 0, 26082, 0, -17207, 0, 24524, 0, -17206, 0, -27067, 0, -17205, 0, 22931, 0, -17204, 0, 32487, 0, -17203, 0, 32426, 0, -17202, 0, 22025, 0, -17201, 0, 26551, 0, -17200, 0, 22841, 0, -17199, 0, 20339, 0, -17198, 0, 23478, 0, -17197, 0, 21152, 0, -17196, 0, -31910, 0, -17195, 0, -26486, 0, -17194, 0, -29378, 0, -17193, 0, 30002, 0, -17192, 0, -27458, 0, -17191, 0, 20551, 0, -17190, 0, 31292, 0, -17189, 0, 20215, 0, -17188, 0, 26550, 0, -17187, 0, -25986, 0, -17186, 0, 23233, 0, -17185, 0, 27516, 0, -17184, 0, 30417, 0, -17183, 0, 22362, 0, -17182, 0, 23574, 0, -17181, 0, 31546, 0, -17180, 0, -27148, 0, -17179, 0, 29006, 0, -17178, 0, 20860, 0, -17177, 0, -32599, 0, -17176, 0, -32144, 0, -17175, 0, 22904, 0, -17174, 0, 32516, 0, -17173, 0, -31961, 0, -17172, 0, 26816, 0, -17171, 0, 26604, 0, -17170, 0, 30897, 0, -17169, 0, 30839, 0, -17168, 0, 25315, 0, -17167, 0, 25441, 0, -17166, 0, 31616, 0, -17165, 0, 20461, 0, -17164, 0, 21098, 0, -17163, 0, 20943, 0, -17162, 0, -31920, 0, -17161, 0, 27099, 0, -17160, 0, -28044, 0, -17159, 0, -29195, 0, -17158, 0, -29391, 0, -17157, 0, -30271, 0, -17156, 0, -27346, 0, -17155, 0, 31661, 0, -17154, 0, 20214, 0, -16991, 0, 20581, 0, -16990, 0, -32208, 0, -16989, 0, 21073, 0, -16988, 0, -26257, 0, -16987, 0, 28176, 0, -16986, 0, 28293, 0, -16985, 0, 28071, 0, -16984, 0, 24314, 0, -16983, 0, 20725, 0, -16982, 0, 23004, 0, -16981, 0, 23558, 0, -16980, 0, 27974, 0, -16979, 0, 27743, 0, -16978, 0, 30086, 0, -16977, 0, -31605, 0, -16976, 0, 26728, 0, -16975, 0, 22870, 0, -16974, 0, -29774, 0, -16973, 0, 21280, 0, -16972, 0, -28303, 0, -16971, 0, -27059, 0, -16970, 0, -31415, 0, -16969, 0, 26898, 0, -16968, 0, 30977, 0, -16967, 0, 28966, 0, -16966, 0, -32522, 0, -16965, 0, 20132, 0, -16964, 0, -28470, 0, -16963, 0, 27975, 0, -16962, 0, -25980, 0, -16961, 0, 23047, 0, -16960, 0, 22204, 0, -16959, 0, 25605, 0, -16958, 0, -27408, 0, -16957, 0, 30699, 0, -16956, 0, 20389, 0, -16955, 0, -32486, 0, -16954, 0, 29409, 0, -16953, 0, -30254, 0, -16952, 0, -26246, 0, -16951, 0, 32564, 0, -16950, 0, 32478, 0, -16949, 0, 21119, 0, -16948, 0, 25945, 0, -16947, 0, -28299, 0, -16946, 0, -28801, 0, -16945, 0, -28797, 0, -16944, 0, 21483, 0, -16943, 0, 31382, 0, -16942, 0, 25581, 0, -16941, 0, 25509, 0, -16940, 0, 30342, 0, -16939, 0, 31224, 0, -16938, 0, -30633, 0, -16937, 0, -27082, 0, -16936, 0, 25130, 0, -16935, 0, 21163, 0, -16934, 0, -32126, 0, -16933, 0, 26708, 0, -16932, 0, 26480, 0, -16931, 0, 25463, 0, -16930, 0, 30571, 0, -16929, 0, 31469, 0, -16928, 0, 27905, 0, -16927, 0, 32467, 0, -16926, 0, -30237, 0, -16925, 0, 22992, 0, -16924, 0, 25106, 0, -16923, 0, -31287, 0, -16922, 0, -32091, 0, -16921, 0, 30028, 0, -16920, 0, 20511, 0, -16919, 0, 20171, 0, -16918, 0, 30117, 0, -16917, 0, -29717, 0, -16916, 0, 23626, 0, -16915, 0, 24062, 0, -16914, 0, 31563, 0, -16913, 0, 26020, 0, -16912, 0, -28207, 0, -16911, 0, 20170, 0, -16910, 0, 27941, 0, -16909, 0, -30369, 0, -16908, 0, 32039, 0, -16907, 0, -27354, 0, -16906, 0, 20165, 0, -16905, 0, -29656, 0, -16904, 0, -28709, 0, -16903, 0, -26765, 0, -16902, 0, 26187, 0, -16901, 0, 31105, 0, -16900, 0, -28719, 0, -16899, 0, 28908, 0, -16898, 0, 28024, 0, -16735, 0, 23613, 0, -16734, 0, 21170, 0, -16733, 0, -31930, 0, -16732, 0, 20834, 0, -16731, 0, -31986, 0, -16730, 0, 30555, 0, -16729, 0, 26230, 0, -16728, 0, -25416, 0, -16727, 0, 20140, 0, -16726, 0, 24778, 0, -16725, 0, 31934, 0, -16724, 0, 31923, 0, -16723, 0, 32463, 0, -16722, 0, 20117, 0, -16721, 0, -29850, 0, -16720, 0, 26223, 0, -16719, 0, -26488, 0, -16718, 0, -26791, 0, -16717, 0, 22659, 0, -16716, 0, 25964, 0, -16715, 0, -27300, 0, -16714, 0, 24452, 0, -16713, 0, 30153, 0, -16712, 0, -26794, 0, -16711, 0, 31455, 0, -16710, 0, 31454, 0, -16709, 0, 20928, 0, -16708, 0, 28847, 0, -16707, 0, 31384, 0, -16706, 0, 25578, 0, -16705, 0, 31350, 0, -16704, 0, 32416, 0, -16703, 0, 29590, 0, -16702, 0, -26643, 0, -16701, 0, 20037, 0, -16700, 0, 28792, 0, -16699, 0, 20061, 0, -16698, 0, -28334, 0, -16697, 0, 21417, 0, -16696, 0, 25937, 0, -16695, 0, 26087, 0, -16694, 0, -32260, 0, -16693, 0, -32251, 0, -16692, 0, 21646, 0, -16691, 0, 23601, 0, -16690, 0, 30106, 0, -16689, 0, -26720, 0, -16688, 0, 25304, 0, -16687, 0, 29401, 0, -16686, 0, 30141, 0, -16685, 0, 23621, 0, -16684, 0, -25991, 0, -16683, 0, -31798, 0, -16682, 0, 23616, 0, -16681, 0, 21632, 0, -16680, 0, 30697, 0, -16679, 0, 20030, 0, -16678, 0, 27822, 0, -16677, 0, -32678, 0, -16676, 0, 25298, 0, -16675, 0, 25454, 0, -16674, 0, 24040, 0, -16673, 0, 20855, 0, -16672, 0, -29219, 0, -16671, 0, -29154, 0, -16670, 0, -27345, 0, -16669, 0, 20465, 0, -16668, 0, 21477, 0, -16667, 0, 24807, 0, -16666, 0, 28844, 0, -16665, 0, 21095, 0, -16664, 0, 25424, 0, -16663, 0, -25021, 0, -16662, 0, 23071, 0, -16661, 0, 20518, 0, -16660, 0, 30519, 0, -16659, 0, 21367, 0, -16658, 0, 32482, 0, -16657, 0, 25733, 0, -16656, 0, 25899, 0, -16655, 0, 25225, 0, -16654, 0, 25496, 0, -16653, 0, 20500, 0, -16652, 0, 29237, 0, -16651, 0, -30263, 0, -16650, 0, 20915, 0, -16649, 0, -29760, 0, -16648, 0, 32477, 0, -16647, 0, 22343, 0, -16646, 0, -31796, 0, -16645, 0, -27481, 0, -16644, 0, 20891, 0, -16643, 0, 21531, 0, -16642, 0, 23803, 0, -16479, 0, 20426, 0, -16478, 0, 31459, 0, -16477, 0, 27994, 0, -16476, 0, -28447, 0, -16475, 0, -25969, 0, -16474, 0, 21888, 0, -16473, 0, 21654, 0, -16472, 0, 21345, 0, -16471, 0, 21679, 0, -16470, 0, 24320, 0, -16469, 0, 25577, 0, -16468, 0, 26999, 0, -16467, 0, 20975, 0, -16466, 0, 24936, 0, -16465, 0, 21002, 0, -16464, 0, 22570, 0, -16463, 0, 21208, 0, -16462, 0, 22350, 0, -16461, 0, 30733, 0, -16460, 0, 30475, 0, -16459, 0, 24247, 0, -16458, 0, 24951, 0, -16457, 0, 31968, 0, -16456, 0, 25179, 0, -16455, 0, 25239, 0, -16454, 0, 20130, 0, -16453, 0, 28821, 0, -16452, 0, -32765, 0, -16451, 0, 25335, 0, -16450, 0, 28900, 0, -16449, 0, -26784, 0, -16448, 0, 22391, 0, -16447, 0, -32037, 0, -16446, 0, 26607, 0, -16445, 0, 26869, 0, -16444, 0, 30933, 0, -16443, 0, -26473, 0, -16442, 0, 31185, 0, -16441, 0, 22771, 0, -16440, 0, 21683, 0, -16439, 0, 21487, 0, -16438, 0, 28212, 0, -16437, 0, 20811, 0, -16436, 0, 21051, 0, -16435, 0, 23458, 0, -16434, 0, -29698, 0, -16433, 0, -32593, 0, -16432, 0, 21827, 0, -16431, 0, 22438, 0, -16430, 0, 24691, 0, -16429, 0, 22353, 0, -16428, 0, 21549, 0, -16427, 0, 31354, 0, -16426, 0, 24656, 0, -16425, 0, 23380, 0, -16424, 0, 25511, 0, -16423, 0, 25248, 0, -16422, 0, 21475, 0, -16421, 0, 25187, 0, -16420, 0, 23495, 0, -16419, 0, 26543, 0, -16418, 0, 21741, 0, -16417, 0, 31391, 0, -16416, 0, -32026, 0, -16415, 0, -28297, 0, -16414, 0, 24211, 0, -16413, 0, -30492, 0, -16412, 0, 22840, 0, -16411, 0, 22446, 0, -16410, 0, 25358, 0, -16409, 0, -29208, 0, -16408, 0, -32529, 0, -16407, 0, 22359, 0, -16406, 0, 31607, 0, -16405, 0, 20393, 0, -16404, 0, 24555, 0, -16403, 0, 23485, 0, -16402, 0, 27454, 0, -16401, 0, 21281, 0, -16400, 0, 31568, 0, -16399, 0, 29378, 0, -16398, 0, 26694, 0, -16397, 0, 30719, 0, -16396, 0, 30518, 0, -16395, 0, 26103, 0, -16394, 0, 20917, 0, -16393, 0, 20111, 0, -16392, 0, 30420, 0, -16391, 0, 23743, 0, -16390, 0, 31397, 0, -16389, 0, -31627, 0, -16388, 0, 22862, 0, -16387, 0, -25791, 0, -16386, 0, 20608, 0, -16223, 0, -26232, 0, -16222, 0, 24871, 0, -16221, 0, 28291, 0, -16220, 0, 22372, 0, -16219, 0, 26118, 0, -16218, 0, 25414, 0, -16217, 0, 22256, 0, -16216, 0, 25324, 0, -16215, 0, 25193, 0, -16214, 0, 24275, 0, -16213, 0, -27116, 0, -16212, 0, 22403, 0, -16211, 0, 25289, 0, -16210, 0, 21895, 0, -16209, 0, -30943, 0, -16208, 0, -32438, 0, -16207, 0, -28765, 0, -16206, 0, 21862, 0, -16205, 0, -31823, 0, -16204, 0, 26469, 0, -16203, 0, -29354, 0, -16202, 0, -31523, 0, -16201, 0, 23146, 0, -16200, 0, 26639, 0, -16199, 0, 25318, 0, -16198, 0, 31726, 0, -16197, 0, -27119, 0, -16196, 0, 20848, 0, -16195, 0, 28572, 0, -16194, 0, -29648, 0, -16193, 0, 25597, 0, -16192, 0, -30264, 0, -16191, 0, 25042, 0, -16190, 0, 32518, 0, -16189, 0, 28866, 0, -16188, 0, 28389, 0, -16187, 0, 29701, 0, -16186, 0, 27028, 0, -16185, 0, 29436, 0, -16184, 0, 24266, 0, -16183, 0, -28466, 0, -16182, 0, 26391, 0, -16181, 0, 28010, 0, -16180, 0, 25438, 0, -16179, 0, 21171, 0, -16178, 0, 29282, 0, -16177, 0, -32767, 0, -16176, 0, 20332, 0, -16175, 0, 23013, 0, -16174, 0, -28310, 0, -16173, 0, 28889, 0, -16172, 0, 28061, 0, -16171, 0, 21202, 0, -16170, 0, 20048, 0, -16169, 0, -26889, 0, -16168, 0, -27283, 0, -16167, 0, -31362, 0, -16166, 0, 30922, 0, -16165, 0, 32047, 0, -16164, 0, 20769, 0, -16163, 0, 22418, 0, -16162, 0, 25794, 0, -16161, 0, -32629, 0, -16160, 0, 31867, 0, -16159, 0, 27882, 0, -16158, 0, 26865, 0, -16157, 0, 26974, 0, -16156, 0, 20919, 0, -16155, 0, 21400, 0, -16154, 0, 26792, 0, -16153, 0, 29313, 0, -16152, 0, -24882, 0, -16151, 0, 31729, 0, -16150, 0, 29432, 0, -16149, 0, 31163, 0, -16148, 0, 28435, 0, -16147, 0, 29702, 0, -16146, 0, 26446, 0, -16145, 0, -28212, 0, -16144, 0, -25436, 0, -16143, 0, 31036, 0, -16142, 0, -31863, 0, -16141, 0, -31916, 0, -16140, 0, 21519, 0, -16139, 0, 26647, 0, -16138, 0, 20029, 0, -16137, 0, 21385, 0, -16136, 0, 21169, 0, -16135, 0, 30782, 0, -16134, 0, 21382, 0, -16133, 0, 21033, 0, -16132, 0, 20616, 0, -16131, 0, 20363, 0, -16130, 0, 20432, 0, -15967, 0, 30178, 0, -15966, 0, 31435, 0, -15965, 0, 31890, 0, -15964, 0, 27813, 0, -15963, 0, -26954, 0, -15962, 0, 21147, 0, -15961, 0, 29827, 0, -15960, 0, 21737, 0, -15959, 0, 20457, 0, -15958, 0, -32684, 0, -15957, 0, -31822, 0, -15956, 0, -28706, 0, -15955, 0, -27280, 0, -15954, 0, 24265, 0, -15953, 0, 24604, 0, -15952, 0, 28063, 0, -15951, 0, 24088, 0, -15950, 0, 25947, 0, -15949, 0, -32456, 0, -15948, 0, -27394, 0, -15947, 0, 24651, 0, -15946, 0, 28860, 0, -15945, 0, 32451, 0, -15944, 0, 31918, 0, -15943, 0, -1671, 0, -15942, 0, 26753, 0, -15941, 0, 31921, 0, -15940, 0, -32145, 0, -15939, 0, 20004, 0, -15938, 0, -28794, 0, -15937, 0, -28209, 0, -15936, 0, 26238, 0, -15935, 0, 20142, 0, -15934, 0, -29691, 0, -15933, 0, 25769, 0, -15932, 0, -32694, 0, -15931, 0, 20698, 0, -15930, 0, 30103, 0, -15929, 0, 29134, 0, -15928, 0, 23525, 0, -15927, 0, -28739, 0, -15926, 0, 28518, 0, -15925, 0, 20102, 0, -15924, 0, 25730, 0, -15923, 0, -27293, 0, -15922, 0, 24278, 0, -15921, 0, 26009, 0, -15920, 0, 21015, 0, -15919, 0, -30526, 0, -15918, 0, 28872, 0, -15917, 0, 21155, 0, -15916, 0, 29454, 0, -15915, 0, 29747, 0, -15914, 0, 26519, 0, -15913, 0, 30967, 0, -15912, 0, -26858, 0, -15911, 0, 20020, 0, -15910, 0, -28485, 0, -15909, 0, -25378, 0, -15908, 0, 28107, 0, -15907, 0, 20955, 0, -15906, 0, -29375, 0, -15905, 0, 21533, 0, -15904, 0, 25294, 0, -15903, 0, 29618, 0, -15902, 0, -31759, 0, -15901, 0, -26890, 0, -15900, 0, -24700, 0, -15899, 0, -27453, 0, -15898, 0, 20278, 0, -15897, 0, 32666, 0, -15896, 0, 20940, 0, -15895, 0, 28789, 0, -15894, 0, -27019, 0, -15893, 0, 23725, 0, -15892, 0, -26490, 0, -15891, 0, 21478, 0, -15890, 0, 20196, 0, -15889, 0, 28316, 0, -15888, 0, 29705, 0, -15887, 0, 27060, 0, -15886, 0, 30827, 0, -15885, 0, -26225, 0, -15884, 0, 30041, 0, -15883, 0, 21016, 0, -15882, 0, 30244, 0, -15881, 0, 27969, 0, -15880, 0, 26611, 0, -15879, 0, 20845, 0, -15878, 0, -24679, 0, -15877, 0, -32693, 0, -15876, 0, 21657, 0, -15875, 0, 31548, 0, -15874, 0, 31423, 0, -15711, 0, -27002, 0, -15710, 0, 22404, 0, -15709, 0, 25314, 0, -15708, 0, -27065, 0, -15707, 0, 27004, 0, -15706, 0, 23044, 0, -15705, 0, 25602, 0, -15704, 0, 31699, 0, -15703, 0, 28431, 0, -15702, 0, -27061, 0, -15701, 0, -32090, 0, -15700, 0, 21346, 0, -15699, 0, -26491, 0, -15698, 0, 24208, 0, -15697, 0, 28809, 0, -15696, 0, 25523, 0, -15695, 0, 21348, 0, -15694, 0, -31153, 0, -15693, 0, -25471, 0, -15692, 0, -24941, 0, -15691, 0, 30860, 0, -15690, 0, -26830, 0, -15689, 0, -29201, 0, -15688, 0, -29374, 0, -15687, 0, -24961, 0, -15686, 0, 28510, 0, -15685, 0, 31108, 0, -15684, 0, 24405, 0, -15683, 0, -27066, 0, -15682, 0, 25134, 0, -15681, 0, -25996, 0, -15680, 0, 21525, 0, -15679, 0, -27427, 0, -15678, 0, 20387, 0, -15677, 0, 26053, 0, -15676, 0, 23653, 0, -15675, 0, 23649, 0, -15674, 0, 32533, 0, -15673, 0, -31151, 0, -15672, 0, 27695, 0, -15671, 0, 24459, 0, -15670, 0, 29575, 0, -15669, 0, 28388, 0, -15668, 0, 32511, 0, -15667, 0, 23782, 0, -15666, 0, 25371, 0, -15665, 0, 23402, 0, -15664, 0, 28390, 0, -15663, 0, 21365, 0, -15662, 0, 20081, 0, -15661, 0, 25504, 0, -15660, 0, 30053, 0, -15659, 0, 25249, 0, -15658, 0, -28818, 0, -15657, 0, 20262, 0, -15656, 0, 20177, 0, -15655, 0, 27814, 0, -15654, 0, 32438, 0, -15653, 0, -29766, 0, -15652, 0, -31715, 0, -15651, 0, -30790, 0, -15650, 0, 32599, 0, -15649, 0, -28613, 0, -15648, 0, -27357, 0, -15647, 0, 31657, 0, -15646, 0, -25951, 0, -15645, 0, -30472, 0, -15644, 0, -31683, 0, -15643, 0, 27931, 0, -15642, 0, -25978, 0, -15641, 0, 32476, 0, -15640, 0, 22920, 0, -15639, 0, -24901, 0, -15638, 0, 29595, 0, -15637, 0, 30721, 0, -15636, 0, -31102, 0, -15635, 0, -26004, 0, -15634, 0, -25982, 0, -15633, 0, 22043, 0, -15632, 0, 21527, 0, -15631, 0, 22475, 0, -15630, 0, 20080, 0, -15629, 0, -24922, 0, -15628, 0, 21334, 0, -15627, 0, -28728, 0, -15626, 0, -32503, 0, -15625, 0, 30610, 0, -15624, 0, -26222, 0, -15623, 0, -30994, 0, -15622, 0, 28385, 0, -15621, 0, -31469, 0, -15620, 0, 26364, 0, -15619, 0, 24930, 0, -15618, 0, 28459, 0, -15455, 0, -29655, 0, -15454, 0, -32110, 0, -15453, 0, -31957, 0, -15452, 0, 30450, 0, -15451, 0, 27667, 0, -15450, 0, 24537, 0, -15449, 0, -31811, 0, -15448, 0, 29483, 0, -15447, 0, -31995, 0, -15446, 0, -27366, 0, -15445, 0, 27611, 0, -15444, 0, 30683, 0, -15443, 0, -27450, 0, -15442, 0, 21359, 0, -15441, 0, -31998, 0, -15440, 0, 20882, 0, -15439, 0, 24125, 0, -15438, 0, -29556, 0, -15437, 0, -29384, 0, -15436, 0, 20040, 0, -15435, 0, 29611, 0, -15434, 0, 26522, 0, -15433, 0, 26757, 0, -15432, 0, -28298, 0, -15431, 0, -26871, 0, -15430, 0, 29028, 0, -15429, 0, 27809, 0, -15428, 0, 30473, 0, -15427, 0, 23186, 0, -15426, 0, -27327, 0, -15425, 0, 27599, 0, -15424, 0, 32654, 0, -15423, 0, 26151, 0, -15422, 0, 23504, 0, -15421, 0, 22969, 0, -15420, 0, 23194, 0, -15419, 0, -27160, 0, -15418, 0, -27145, 0, -15417, 0, 20204, 0, -15416, 0, -31732, 0, -15415, 0, -31591, 0, -15414, 0, 27308, 0, -15413, 0, 30431, 0, -15412, 0, -27344, 0, -15411, 0, 29467, 0, -15410, 0, 26790, 0, -15409, 0, 23391, 0, -15408, 0, 30511, 0, -15407, 0, -28262, 0, -15406, 0, -26783, 0, -15405, 0, 31964, 0, -15404, 0, -28681, 0, -15403, 0, -29668, 0, -15402, 0, 24357, 0, -15401, 0, 31859, 0, -15400, 0, 31192, 0, -15399, 0, -30267, 0, -15398, 0, 27852, 0, -15397, 0, -30948, 0, -15396, 0, 23494, 0, -15395, 0, 24130, 0, -15394, 0, 26825, 0, -15393, 0, 30496, 0, -15392, 0, 32501, 0, -15391, 0, 20885, 0, -15390, 0, 20813, 0, -15389, 0, 21193, 0, -15388, 0, 23081, 0, -15387, 0, 32517, 0, -15386, 0, -26782, 0, -15385, 0, -32041, 0, -15384, 0, 25551, 0, -15383, 0, 30596, 0, -15382, 0, -31280, 0, -15381, 0, 31186, 0, -15380, 0, 28218, 0, -15379, 0, 24217, 0, -15378, 0, 22937, 0, -15377, 0, -31471, 0, -15376, 0, 28781, 0, -15375, 0, 27665, 0, -15374, 0, 25279, 0, -15373, 0, 30399, 0, -15372, 0, 25935, 0, -15371, 0, 24751, 0, -15370, 0, -27139, 0, -15369, 0, 26126, 0, -15368, 0, -30817, 0, -15367, 0, -25053, 0, -15366, 0, -27411, 0, -15365, 0, 21517, 0, -15364, 0, 21629, 0, -15363, 0, -29652, 0, -15362, 0, 25720, 0, -15199, 0, 25721, 0, -15198, 0, -31215, 0, -15197, 0, 27169, 0, -15196, 0, -32356, 0, -15195, 0, 30952, 0, -15194, 0, 25705, 0, -15193, 0, -25772, 0, -15192, 0, 25273, 0, -15191, 0, 26411, 0, -15190, 0, -31829, 0, -15189, 0, 22696, 0, -15188, 0, -24872, 0, -15187, 0, 27819, 0, -15186, 0, 28448, 0, -15185, 0, 23518, 0, -15184, 0, -27060, 0, -15183, 0, -29685, 0, -15182, 0, 29279, 0, -15181, 0, 26576, 0, -15180, 0, 25287, 0, -15179, 0, 29281, 0, -15178, 0, 20137, 0, -15177, 0, 22982, 0, -15176, 0, 27597, 0, -15175, 0, 22675, 0, -15174, 0, 26286, 0, -15173, 0, 24149, 0, -15172, 0, 21215, 0, -15171, 0, 24917, 0, -15170, 0, 26408, 0, -15169, 0, 30446, 0, -15168, 0, 30566, 0, -15167, 0, 29287, 0, -15166, 0, 31302, 0, -15165, 0, 25343, 0, -15164, 0, 21738, 0, -15163, 0, 21584, 0, -15162, 0, -27488, 0, -15161, 0, -28509, 0, -15160, 0, 23068, 0, -15159, 0, 32435, 0, -15158, 0, 27670, 0, -15157, 0, 20035, 0, -15156, 0, 22902, 0, -15155, 0, -32752, 0, -15154, 0, 22856, 0, -15153, 0, 21335, 0, -15152, 0, 30007, 0, -15151, 0, -26946, 0, -15150, 0, 22218, 0, -15149, 0, 25376, 0, -15148, 0, -32495, 0, -15147, 0, 24700, 0, -15146, 0, -27143, 0, -15145, 0, 28118, 0, -15144, 0, 21602, 0, -15143, 0, -26239, 0, -15142, 0, 20869, 0, -15141, 0, 23273, 0, -15140, 0, -32515, 0, -15139, 0, 22958, 0, -15138, 0, -26861, 0, -15137, 0, 20522, 0, -15136, 0, 27877, 0, -15135, 0, 23612, 0, -15134, 0, 25311, 0, -15133, 0, 20320, 0, -15132, 0, 21311, 0, -15131, 0, -32389, 0, -15130, 0, -28666, 0, -15129, 0, 28346, 0, -15128, 0, -31445, 0, -15127, 0, 25288, 0, -15126, 0, 24180, 0, -15125, 0, 30910, 0, -15124, 0, 25781, 0, -15123, 0, 25467, 0, -15122, 0, 24565, 0, -15121, 0, 23064, 0, -15120, 0, -28289, 0, -15119, 0, -25057, 0, -15118, 0, 23615, 0, -15117, 0, 25423, 0, -15116, 0, -32702, 0, -15115, 0, 23421, 0, -15114, 0, 21870, 0, -15113, 0, -27318, 0, -15112, 0, -27315, 0, -15111, 0, 28037, 0, -15110, 0, 24744, 0, -15109, 0, 26592, 0, -15108, 0, 29406, 0, -15107, 0, 20957, 0, -15106, 0, 23425, 0, -14943, 0, 25319, 0, -14942, 0, 27870, 0, -14941, 0, 29275, 0, -14940, 0, 25197, 0, -14939, 0, -27474, 0, -14938, 0, 32445, 0, -14937, 0, -32493, 0, -14936, 0, 27987, 0, -14935, 0, 20892, 0, -14934, 0, 24324, 0, -14933, 0, 22900, 0, -14932, 0, 21162, 0, -14931, 0, 24594, 0, -14930, 0, 22899, 0, -14929, 0, 26262, 0, -14928, 0, -31152, 0, -14927, 0, 30111, 0, -14926, 0, 25386, 0, -14925, 0, 25062, 0, -14924, 0, 31983, 0, -14923, 0, -29702, 0, -14922, 0, 21734, 0, -14921, 0, 27431, 0, -14920, 0, -25051, 0, -14919, 0, 27572, 0, -14918, 0, -31275, 0, -14917, 0, 21589, 0, -14916, 0, 20598, 0, -14915, 0, 27812, 0, -14914, 0, 21866, 0, -14913, 0, -29260, 0, -14912, 0, 29228, 0, -14911, 0, 24085, 0, -14910, 0, 24597, 0, -14909, 0, 29750, 0, -14908, 0, 25293, 0, -14907, 0, 25490, 0, -14906, 0, 29260, 0, -14905, 0, 24472, 0, -14904, 0, 28227, 0, -14903, 0, 27966, 0, -14902, 0, 25856, 0, -14901, 0, 28504, 0, -14900, 0, 30424, 0, -14899, 0, 30928, 0, -14898, 0, 30460, 0, -14897, 0, 30036, 0, -14896, 0, 21028, 0, -14895, 0, 21467, 0, -14894, 0, 20051, 0, -14893, 0, 24222, 0, -14892, 0, 26049, 0, -14891, 0, -32726, 0, -14890, 0, -32554, 0, -14889, 0, 25243, 0, -14888, 0, 21638, 0, -14887, 0, 21032, 0, -14886, 0, 28846, 0, -14885, 0, -30579, 0, -14884, 0, -29231, 0, -14883, 0, 27873, 0, -14882, 0, 21624, 0, -14881, 0, -32550, 0, -14880, 0, 22521, 0, -14879, 0, -30476, 0, -14878, 0, -29356, 0, -14877, 0, -27030, 0, -14876, 0, -28339, 0, -14875, 0, 20329, 0, -14874, 0, 27803, 0, -14873, 0, 21943, 0, -14872, 0, 30406, 0, -14871, 0, 30768, 0, -14870, 0, 25256, 0, -14869, 0, 28921, 0, -14868, 0, 28558, 0, -14867, 0, 24429, 0, -14866, 0, -31508, 0, -14865, 0, 26842, 0, -14864, 0, 30844, 0, -14863, 0, 31735, 0, -14862, 0, -32344, 0, -14861, 0, 26379, 0, -14860, 0, -25009, 0, -14859, 0, 25447, 0, -14858, 0, 30896, 0, -14857, 0, 22383, 0, -14856, 0, 30738, 0, -14855, 0, -26823, 0, -14854, 0, 25209, 0, -14853, 0, 25259, 0, -14852, 0, 21128, 0, -14851, 0, 29749, 0, -14850, 0, 27607, 0, -14687, 0, 21860, 0, -14686, 0, -32450, 0, -14685, 0, 30130, 0, -14684, 0, 30382, 0, -14683, 0, 21305, 0, -14682, 0, 30174, 0, -14681, 0, 20731, 0, -14680, 0, 23617, 0, -14679, 0, -29844, 0, -14678, 0, 31687, 0, -14677, 0, 20559, 0, -14676, 0, 29255, 0, -14675, 0, -25961, 0, -14674, 0, -26408, 0, -14673, 0, 28418, 0, -14672, 0, 29922, 0, -14671, 0, 31080, 0, -14670, 0, 25735, 0, -14669, 0, 30629, 0, -14668, 0, 25340, 0, -14667, 0, -26479, 0, -14666, 0, -29397, 0, -14665, 0, 21697, 0, -14664, 0, -32680, 0, -14663, 0, 20050, 0, -14662, 0, 22378, 0, -14661, 0, -32007, 0, -14660, 0, -31731, 0, -14659, 0, 24179, 0, -14658, 0, 20973, 0, -14657, 0, 29942, 0, -14656, 0, -29756, 0, -14655, 0, 23631, 0, -14654, 0, 22369, 0, -14653, 0, 27900, 0, -14652, 0, -26489, 0, -14651, 0, 23110, 0, -14650, 0, 30772, 0, -14649, 0, -25788, 0, -14648, 0, -28693, 0, -14647, 0, 31893, 0, -14646, 0, 21078, 0, -14645, 0, 25169, 0, -14644, 0, -27398, 0, -14643, 0, 20166, 0, -14642, 0, -31866, 0, -14641, 0, -31647, 0, -14640, 0, -31767, 0, -14639, 0, -31566, 0, -14638, 0, 22484, 0, -14637, 0, 26420, 0, -14636, 0, 22275, 0, -14635, 0, 26222, 0, -14634, 0, 28006, 0, -14633, 0, -29647, 0, -14632, 0, 26333, 0, -14631, 0, 28689, 0, -14630, 0, 26399, 0, -14629, 0, 27450, 0, -14628, 0, 26646, 0, -14627, 0, 25114, 0, -14626, 0, 22971, 0, -14625, 0, 19971, 0, -14624, 0, 20932, 0, -14623, 0, 28422, 0, -14622, 0, 26578, 0, -14621, 0, 27791, 0, -14620, 0, 20854, 0, -14619, 0, 26827, 0, -14618, 0, 22855, 0, -14617, 0, 27495, 0, -14616, 0, 30054, 0, -14615, 0, 23822, 0, -14614, 0, -32496, 0, -14613, 0, -24752, 0, -14612, 0, 26071, 0, -14611, 0, 31048, 0, -14610, 0, 31041, 0, -14609, 0, -25967, 0, -14608, 0, -29321, 0, -14607, 0, 23682, 0, -14606, 0, 20062, 0, -14605, 0, 20225, 0, -14604, 0, 21551, 0, -14603, 0, 22865, 0, -14602, 0, 30732, 0, -14601, 0, 22120, 0, -14600, 0, 27668, 0, -14599, 0, -28732, 0, -14598, 0, 24323, 0, -14597, 0, 27773, 0, -14596, 0, 27875, 0, -14595, 0, -29781, 0, -14594, 0, 25488, 0, -14431, 0, 24688, 0, -14430, 0, 27965, 0, -14429, 0, 29301, 0, -14428, 0, 25190, 0, -14427, 0, -27506, 0, -14426, 0, -27451, 0, -14425, 0, 21315, 0, -14424, 0, -28735, 0, -14423, 0, 31614, 0, -14422, 0, 20191, 0, -14421, 0, -29658, 0, -14420, 0, 20094, 0, -14419, 0, -24876, 0, -14418, 0, -27471, 0, -14417, 0, -27469, 0, -14416, 0, 21069, 0, -14415, 0, 28508, 0, -14414, 0, -28573, 0, -14413, 0, 27973, 0, -14412, 0, -29644, 0, -14411, 0, 22545, 0, -14410, 0, 23884, 0, -14409, 0, 27424, 0, -14408, 0, 27465, 0, -14407, 0, 26538, 0, -14406, 0, 21595, 0, -14405, 0, -32428, 0, -14404, 0, 32652, 0, -14403, 0, 22681, 0, -14402, 0, -31433, 0, -14401, 0, 24378, 0, -14400, 0, 25250, 0, -14399, 0, 27207, 0, -14398, 0, -27335, 0, -14397, 0, 25970, 0, -14396, 0, 24708, 0, -14395, 0, 26725, 0, -14394, 0, 30631, 0, -14393, 0, 20052, 0, -14392, 0, 20392, 0, -14391, 0, 24039, 0, -14390, 0, -26728, 0, -14389, 0, 25772, 0, -14388, 0, 32728, 0, -14387, 0, 23789, 0, -14386, 0, 20431, 0, -14385, 0, 31373, 0, -14384, 0, 20999, 0, -14383, 0, -31996, 0, -14382, 0, 19988, 0, -14381, 0, 24623, 0, -14380, 0, 31363, 0, -14379, 0, -27482, 0, -14378, 0, 20405, 0, -14377, 0, 20146, 0, -14376, 0, 31206, 0, -14375, 0, 29748, 0, -14374, 0, 21220, 0, -14373, 0, -32071, 0, -14372, 0, 25810, 0, -14371, 0, 31165, 0, -14370, 0, 23517, 0, -14369, 0, 27777, 0, -14368, 0, -26798, 0, -14367, 0, -28805, 0, -14366, 0, 27682, 0, -14365, 0, 20542, 0, -14364, 0, 21375, 0, -14363, 0, 28165, 0, -14362, 0, 25806, 0, -14361, 0, 26228, 0, -14360, 0, 27696, 0, -14359, 0, 24773, 0, -14358, 0, -26505, 0, -14357, 0, -29705, 0, -14356, 0, 24198, 0, -14355, 0, 29756, 0, -14354, 0, 31351, 0, -14353, 0, 31179, 0, -14352, 0, 19992, 0, -14351, 0, -28495, 0, -14350, 0, 29699, 0, -14349, 0, 27714, 0, -14348, 0, 22234, 0, -14347, 0, -28341, 0, -14346, 0, 27845, 0, -14345, 0, -29301, 0, -14344, 0, 21306, 0, -14343, 0, -31034, 0, -14342, 0, 26354, 0, -14341, 0, -29009, 0, -14340, 0, 23624, 0, -14339, 0, -25999, 0, -14338, 0, 28192, 0, -14175, 0, 21462, 0, -14174, 0, 23094, 0, -14173, 0, -24693, 0, -14172, 0, -29277, 0, -14171, 0, 21435, 0, -14170, 0, 22280, 0, -14169, 0, -26457, 0, -14168, 0, 26435, 0, -14167, 0, -28261, 0, -14166, 0, 27849, 0, -14165, 0, 20840, 0, -14164, 0, 30154, 0, -14163, 0, 25331, 0, -14162, 0, 29356, 0, -14161, 0, 21048, 0, -14160, 0, 21149, 0, -14159, 0, 32570, 0, -14158, 0, 28820, 0, -14157, 0, 30264, 0, -14156, 0, 21364, 0, -14155, 0, -25014, 0, -14154, 0, 27063, 0, -14153, 0, 30830, 0, -14152, 0, -26944, 0, -14151, 0, -30503, 0, -14150, 0, 32676, 0, -14149, 0, 28982, 0, -14148, 0, 29123, 0, -14147, 0, 20873, 0, -14146, 0, 26579, 0, -14145, 0, 29924, 0, -14144, 0, 22756, 0, -14143, 0, 25880, 0, -14142, 0, 22199, 0, -14141, 0, -29783, 0, -14140, 0, -26250, 0, -14139, 0, 25200, 0, -14138, 0, 32469, 0, -14137, 0, 24825, 0, -14136, 0, 28909, 0, -14135, 0, 22764, 0, -14134, 0, 20161, 0, -14133, 0, 20154, 0, -14132, 0, 24525, 0, -14131, 0, -26649, 0, -14130, 0, 20219, 0, -14129, 0, -29788, 0, -14128, 0, 20995, 0, -14127, 0, 22922, 0, -14126, 0, 32427, 0, -14125, 0, 25172, 0, -14124, 0, 20173, 0, -14123, 0, 26085, 0, -14122, 0, 25102, 0, -14121, 0, -31944, 0, -14120, 0, -31543, 0, -14119, 0, -31901, 0, -14118, 0, -30835, 0, -14117, 0, 29076, 0, -14116, 0, 28342, 0, -14115, 0, 23481, 0, -14114, 0, 32466, 0, -14113, 0, 20887, 0, -14112, 0, 25545, 0, -14111, 0, 26580, 0, -14110, 0, -32631, 0, -14109, 0, -31943, 0, -14108, 0, -30699, 0, -14107, 0, 20754, 0, -14106, 0, 23418, 0, -14105, 0, 22914, 0, -14104, 0, -28751, 0, -14103, 0, 20083, 0, -14102, 0, 27741, 0, -14101, 0, 20837, 0, -14100, 0, -30427, 0, -14099, 0, -28817, 0, -14098, 0, -27090, 0, -14097, 0, -31414, 0, -14096, 0, 29790, 0, -14095, 0, -27376, 0, -14094, 0, -27152, 0, -14093, 0, 28070, 0, -14092, 0, -32027, 0, -14091, 0, 24369, 0, -14090, 0, 25746, 0, -14089, 0, 27922, 0, -14088, 0, -31704, 0, -14087, 0, -32402, 0, -14086, 0, -25405, 0, -14085, 0, 22622, 0, -14084, 0, -29349, 0, -14083, 0, 19977, 0, -14082, 0, 21441, 0, -13919, 0, 20254, 0, -13918, 0, 25955, 0, -13917, 0, 26705, 0, -13916, 0, 21971, 0, -13915, 0, 20007, 0, -13914, 0, 25620, 0, -13913, 0, -25958, 0, -13912, 0, 25195, 0, -13911, 0, 23234, 0, -13910, 0, 29791, 0, -13909, 0, -32142, 0, -13908, 0, 28073, 0, -13907, 0, 26862, 0, -13906, 0, 20711, 0, -13905, 0, -31858, 0, -13904, 0, 30722, 0, -13903, 0, 26432, 0, -13902, 0, 21049, 0, -13901, 0, 27801, 0, -13900, 0, 32433, 0, -13899, 0, 20667, 0, -13898, 0, 21861, 0, -13897, 0, 29022, 0, -13896, 0, 31579, 0, -13895, 0, 26194, 0, -13894, 0, 29642, 0, -13893, 0, -32021, 0, -13892, 0, 26441, 0, -13891, 0, 23665, 0, -13890, 0, 21024, 0, -13889, 0, 29053, 0, -13888, 0, -30613, 0, -13887, 0, -27158, 0, -13886, 0, -27051, 0, -13885, 0, 25797, 0, -13884, 0, -29343, 0, -13883, 0, -32333, 0, -13882, 0, 21892, 0, -13881, 0, 27733, 0, -13880, 0, 25159, 0, -13879, 0, 32558, 0, -13878, 0, 22674, 0, -13877, 0, 20260, 0, -13876, 0, 21830, 0, -13875, 0, -29361, 0, -13874, 0, 26188, 0, -13873, 0, 19978, 0, -13872, 0, 23578, 0, -13871, 0, -30477, 0, -13870, 0, 26786, 0, -13869, 0, 25422, 0, -13868, 0, 31245, 0, -13867, 0, 28903, 0, -13866, 0, -32115, 0, -13865, 0, 21242, 0, -13864, 0, -26634, 0, -13863, 0, 23569, 0, -13862, 0, 21736, 0, -13861, 0, -28491, 0, -13860, 0, 32461, 0, -13859, 0, 22882, 0, -13858, 0, -29366, 0, -13857, 0, -31033, 0, -13856, 0, -32244, 0, -13855, 0, -32243, 0, -13854, 0, -29338, 0, -13853, 0, 25668, 0, -13852, 0, 23556, 0, -13851, 0, 24913, 0, -13850, 0, 28041, 0, -13849, 0, 31038, 0, -13848, 0, -29762, 0, -13847, 0, 30775, 0, -13846, 0, 30003, 0, -13845, 0, 21627, 0, -13844, 0, 20280, 0, -13843, 0, -29013, 0, -13842, 0, 28145, 0, -13841, 0, 23072, 0, -13840, 0, 32453, 0, -13839, 0, 31070, 0, -13838, 0, 27784, 0, -13837, 0, 23457, 0, -13836, 0, 23158, 0, -13835, 0, 29978, 0, -13834, 0, -32578, 0, -13833, 0, 24910, 0, -13832, 0, 28183, 0, -13831, 0, 22768, 0, -13830, 0, 29983, 0, -13829, 0, 29989, 0, -13828, 0, 29298, 0, -13827, 0, 21319, 0, -13826, 0, 32499, 0, -13663, 0, 30465, 0, -13662, 0, 30427, 0, -13661, 0, 21097, 0, -13660, 0, -32548, 0, -13659, 0, 22307, 0, -13658, 0, 24072, 0, -13657, 0, 22833, 0, -13656, 0, 29422, 0, -13655, 0, 26045, 0, -13654, 0, 28287, 0, -13653, 0, -29737, 0, -13652, 0, 23608, 0, -13651, 0, -31119, 0, -13650, 0, 21313, 0, -13649, 0, 30707, 0, -13648, 0, 25342, 0, -13647, 0, 26102, 0, -13646, 0, 20160, 0, -13645, 0, -26401, 0, -13644, 0, -31104, 0, -13643, 0, 23454, 0, -13642, 0, -29754, 0, -13641, 0, 21490, 0, -13640, 0, 30690, 0, -13639, 0, 20351, 0, -13638, 0, 23630, 0, -13637, 0, -25994, 0, -13636, 0, 22987, 0, -13635, 0, 24335, 0, -13634, 0, 31034, 0, -13633, 0, 22763, 0, -13632, 0, 19990, 0, -13631, 0, 26623, 0, -13630, 0, 20107, 0, -13629, 0, 25325, 0, -13628, 0, -30061, 0, -13627, 0, -28643, 0, -13626, 0, 21183, 0, -13625, 0, 26159, 0, -13624, 0, 21980, 0, -13623, 0, 22124, 0, -13622, 0, -28670, 0, -13621, 0, 20181, 0, -13620, 0, 20365, 0, -13619, 0, -28214, 0, -13618, 0, -26256, 0, -13617, 0, 27663, 0, -13616, 0, 24066, 0, -13615, 0, 24643, 0, -13614, 0, 23460, 0, -13613, 0, -30266, 0, -13612, 0, -29739, 0, -13611, 0, 25910, 0, -13610, 0, 25163, 0, -13609, 0, -26218, 0, -13608, 0, 23432, 0, -13607, 0, 23551, 0, -13606, 0, 25480, 0, -13605, 0, 21806, 0, -13604, 0, 21463, 0, -13603, 0, 30246, 0, -13602, 0, 20861, 0, -13601, 0, -31444, 0, -13600, 0, 26530, 0, -13599, 0, 26803, 0, -13598, 0, 27530, 0, -13597, 0, 25234, 0, -13596, 0, -28781, 0, -13595, 0, 21460, 0, -13594, 0, -32238, 0, -13593, 0, 28113, 0, -13592, 0, 30095, 0, -13591, 0, 20070, 0, -13590, 0, -29362, 0, -13589, 0, 23408, 0, -13588, 0, 29087, 0, -13587, 0, -31313, 0, -13586, 0, 26257, 0, -13585, 0, 26329, 0, -13584, 0, 32626, 0, -13583, 0, -30976, 0, -13582, 0, -24883, 0, -13581, 0, -24800, 0, -13580, 0, 23646, 0, -13579, 0, 26415, 0, -13578, 0, -28688, 0, -13577, 0, 26641, 0, -13576, 0, 26463, 0, -13575, 0, 25101, 0, -13574, 0, 31446, 0, -13573, 0, 22661, 0, -13572, 0, 24246, 0, -13571, 0, 25968, 0, -13570, 0, 28465, 0, -13407, 0, 24661, 0, -13406, 0, 21047, 0, -13405, 0, -32755, 0, -13404, 0, 25684, 0, -13403, 0, -30608, 0, -13402, 0, 29993, 0, -13401, 0, 24069, 0, -13400, 0, 26643, 0, -13399, 0, 25332, 0, -13398, 0, -26852, 0, -13397, 0, 21452, 0, -13396, 0, 29245, 0, -13395, 0, -29695, 0, -13394, 0, 27700, 0, -13393, 0, 30561, 0, -13392, 0, 31246, 0, -13391, 0, 21550, 0, -13390, 0, 30636, 0, -13389, 0, -26502, 0, -13388, 0, -32228, 0, -13387, 0, -29708, 0, -13386, 0, 30805, 0, -13385, 0, 26388, 0, -13384, 0, 28865, 0, -13383, 0, 26031, 0, -13382, 0, 25749, 0, -13381, 0, 22070, 0, -13380, 0, 24605, 0, -13379, 0, 31169, 0, -13378, 0, 21496, 0, -13377, 0, 19997, 0, -13376, 0, 27515, 0, -13375, 0, -32634, 0, -13374, 0, 23546, 0, -13373, 0, 21987, 0, -13372, 0, 22235, 0, -13371, 0, 20282, 0, -13370, 0, 20284, 0, -13369, 0, -26254, 0, -13368, 0, 24051, 0, -13367, 0, 26494, 0, -13366, 0, -32712, 0, -13365, 0, 24578, 0, -13364, 0, -26494, 0, -13363, 0, -28671, 0, -13362, 0, 23435, 0, -13361, 0, -29764, 0, -13360, 0, -29707, 0, -13359, 0, 25628, 0, -13358, 0, -32168, 0, -13357, 0, 25822, 0, -13356, 0, 22013, 0, -13355, 0, -32049, 0, -13354, 0, -28315, 0, -13353, 0, 20439, 0, -13352, 0, 32032, 0, -13351, 0, -28641, 0, -13350, 0, 31903, 0, -13349, 0, 20723, 0, -13348, 0, 22609, 0, -13347, 0, 28335, 0, -13346, 0, 23487, 0, -13345, 0, -29751, 0, -13344, 0, -32637, 0, -13343, 0, -28296, 0, -13342, 0, -31588, 0, -13341, 0, 31639, 0, -13340, 0, -31107, 0, -13339, 0, -26997, 0, -13338, 0, -26993, 0, -13337, 0, 32485, 0, -13336, 0, -25901, 0, -13335, 0, 30862, 0, -13334, 0, 23681, 0, -13333, 0, 31319, 0, -13332, 0, -28606, 0, -13331, 0, -26969, 0, -13330, 0, 31071, 0, -13329, 0, 23385, 0, -13328, 0, 25439, 0, -13327, 0, 31499, 0, -13326, 0, -31535, 0, -13325, 0, 26797, 0, -13324, 0, 21766, 0, -13323, 0, 32553, 0, -13322, 0, 29712, 0, -13321, 0, 32034, 0, -13320, 0, -27391, 0, -13319, 0, 25152, 0, -13318, 0, 22604, 0, -13317, 0, 20182, 0, -13316, 0, 23427, 0, -13315, 0, 22905, 0, -13314, 0, 22612, 0, -13151, 0, 29549, 0, -13150, 0, 25374, 0, -13149, 0, -29109, 0, -13148, 0, -29169, 0, -13147, 0, -32562, 0, -13146, 0, -32044, 0, -13145, 0, 25260, 0, -13144, 0, 21488, 0, -13143, 0, 27888, 0, -13142, 0, -28322, 0, -13141, 0, 22826, 0, -13140, 0, 24577, 0, -13139, 0, 27760, 0, -13138, 0, 22349, 0, -13137, 0, 25674, 0, -13136, 0, -29398, 0, -13135, 0, 30251, 0, -13134, 0, 28393, 0, -13133, 0, 22363, 0, -13132, 0, 27264, 0, -13131, 0, 30192, 0, -13130, 0, 28525, 0, -13129, 0, -29651, 0, -13128, 0, -29688, 0, -13127, 0, 22374, 0, -13126, 0, 27631, 0, -13125, 0, -30574, 0, -13124, 0, 30899, 0, -13123, 0, 25506, 0, -13122, 0, 21497, 0, -13121, 0, 28845, 0, -13120, 0, 27748, 0, -13119, 0, 22616, 0, -13118, 0, 25642, 0, -13117, 0, 22530, 0, -13116, 0, 26848, 0, -13115, 0, -32357, 0, -13114, 0, 21776, 0, -13113, 0, 31958, 0, -13112, 0, 20504, 0, -13111, 0, -28998, 0, -13110, 0, 28108, 0, -13109, 0, -29281, 0, -13108, 0, 28907, 0, -13107, 0, 25487, 0, -13106, 0, 28059, 0, -13105, 0, 28372, 0, -13104, 0, 32486, 0, -13103, 0, -31740, 0, -13102, 0, 26691, 0, -13101, 0, -28669, 0, -13100, 0, 28120, 0, -13099, 0, -27018, 0, -13098, 0, -29784, 0, -13097, 0, 22871, 0, -13096, 0, 29305, 0, -13095, 0, -31260, 0, -13094, 0, -32386, 0, -13093, 0, 30140, 0, -13092, 0, -30070, 0, -13091, 0, 26799, 0, -13090, 0, 21076, 0, -13089, 0, -29150, 0, -13088, 0, -27375, 0, -13087, 0, 25552, 0, -13086, 0, -26472, 0, -13085, 0, -29116, 0, -13084, 0, 21884, 0, -13083, 0, 20307, 0, -13082, 0, 26367, 0, -13081, 0, 22159, 0, -13080, 0, 24789, 0, -13079, 0, 28053, 0, -13078, 0, 21059, 0, -13077, 0, 23625, 0, -13076, 0, 22825, 0, -13075, 0, 28155, 0, -13074, 0, 22635, 0, -13073, 0, 30000, 0, -13072, 0, 29980, 0, -13071, 0, 24684, 0, -13070, 0, -32236, 0, -13069, 0, -32442, 0, -13068, 0, 25361, 0, -13067, 0, 26465, 0, -13066, 0, -28702, 0, -13065, 0, 30522, 0, -13064, 0, -29197, 0, -13063, 0, -29388, 0, -13062, 0, -27455, 0, -13061, 0, 24086, 0, -13060, 0, 21381, 0, -13059, 0, 21548, 0, -13058, 0, 28867, 0, -12895, 0, 27712, 0, -12894, 0, 24311, 0, -12893, 0, 20572, 0, -12892, 0, 20141, 0, -12891, 0, 24237, 0, -12890, 0, 25402, 0, -12889, 0, -32185, 0, -12888, 0, -28646, 0, -12887, 0, 26704, 0, -12886, 0, -28306, 0, -12885, 0, 30643, 0, -12884, 0, 21516, 0, -12883, 0, -27428, 0, -12882, 0, 24420, 0, -12881, 0, 31461, 0, -12880, 0, 26742, 0, -12879, 0, 25413, 0, -12878, 0, 31570, 0, -12877, 0, 32479, 0, -12876, 0, 30171, 0, -12875, 0, 20599, 0, -12874, 0, 25237, 0, -12873, 0, 22836, 0, -12872, 0, -28657, 0, -12871, 0, 20984, 0, -12870, 0, 31171, 0, -12869, 0, 31361, 0, -12868, 0, 22270, 0, -12867, 0, 24466, 0, -12866, 0, -28652, 0, -12865, 0, 28034, 0, -12864, 0, 23648, 0, -12863, 0, 22303, 0, -12862, 0, 21520, 0, -12861, 0, 20820, 0, -12860, 0, 28237, 0, -12859, 0, 22242, 0, -12858, 0, 25512, 0, -12857, 0, -26477, 0, -12856, 0, -32385, 0, -12855, 0, -30955, 0, -12854, 0, -30422, 0, -12853, 0, -28672, 0, -12852, 0, 21534, 0, -12851, 0, 23663, 0, -12850, 0, -32320, 0, -12849, 0, 25302, 0, -12848, 0, 25176, 0, -12847, 0, -32463, 0, -12846, 0, -25035, 0, -12845, 0, -27072, 0, -12844, 0, -26002, 0, -12843, 0, -25988, 0, -12842, 0, 26925, 0, -12841, 0, 22949, 0, -12840, 0, 25299, 0, -12839, 0, 21822, 0, -12838, 0, 25366, 0, -12837, 0, 21703, 0, -12836, 0, -31015, 0, -12835, 0, 27964, 0, -12834, 0, 23043, 0, -12833, 0, 29926, 0, -12832, 0, -30564, 0, -12831, 0, 27498, 0, -12830, 0, 22806, 0, -12829, 0, -29620, 0, -12828, 0, 24367, 0, -12827, 0, 28286, 0, -12826, 0, 29609, 0, -12825, 0, -26499, 0, -12824, 0, 20024, 0, -12823, 0, 28919, 0, -12822, 0, 23436, 0, -12821, 0, 30871, 0, -12820, 0, 25405, 0, -12819, 0, 26202, 0, -12818, 0, 30358, 0, -12817, 0, 24779, 0, -12816, 0, 23451, 0, -12815, 0, 23113, 0, -12814, 0, 19975, 0, -12813, 0, -32427, 0, -12812, 0, 27754, 0, -12811, 0, 29579, 0, -12810, 0, 20129, 0, -12809, 0, 26505, 0, -12808, 0, 32593, 0, -12807, 0, 24448, 0, -12806, 0, 26106, 0, -12805, 0, 26395, 0, -12804, 0, 24536, 0, -12803, 0, 22916, 0, -12802, 0, 23041, 0, -12639, 0, 24013, 0, -12638, 0, 24494, 0, -12637, 0, 21361, 0, -12636, 0, -26650, 0, -12635, 0, -28707, 0, -12634, 0, 26693, 0, -12633, 0, 22260, 0, -12632, 0, 21807, 0, -12631, 0, 24799, 0, -12630, 0, 20026, 0, -12629, 0, 28493, 0, -12628, 0, 32500, 0, -12627, 0, -32057, 0, -12626, 0, -31730, 0, -12625, 0, 22996, 0, -12624, 0, 20255, 0, -12623, 0, 20266, 0, -12622, 0, 23614, 0, -12621, 0, 32428, 0, -12620, 0, 26410, 0, -12619, 0, -31462, 0, -12618, 0, 21619, 0, -12617, 0, 30031, 0, -12616, 0, -32573, 0, -12615, 0, 21890, 0, -12614, 0, -25777, 0, -12613, 0, 20301, 0, -12612, 0, 28205, 0, -12611, 0, -29677, 0, -12610, 0, 23561, 0, -12609, 0, 24944, 0, -12608, 0, 21355, 0, -12607, 0, 30239, 0, -12606, 0, 28201, 0, -12605, 0, -31094, 0, -12604, 0, 25991, 0, -12603, 0, -27141, 0, -12602, 0, 32441, 0, -12601, 0, 21563, 0, -12600, 0, 31283, 0, -12599, 0, 32010, 0, -12598, 0, -27154, 0, -12597, 0, 21985, 0, -12596, 0, 32705, 0, -12595, 0, 29934, 0, -12594, 0, 25373, 0, -12593, 0, -30953, 0, -12592, 0, 28065, 0, -12591, 0, 31389, 0, -12590, 0, 25105, 0, -12589, 0, 26017, 0, -12588, 0, 21351, 0, -12587, 0, 25569, 0, -12586, 0, 27779, 0, -12585, 0, 24043, 0, -12584, 0, 21596, 0, -12583, 0, -27480, 0, -12582, 0, 20044, 0, -12581, 0, 27745, 0, -12580, 0, -29716, 0, -12579, 0, 23627, 0, -12578, 0, 26080, 0, -12577, 0, -32100, 0, -12576, 0, 26791, 0, -12575, 0, 21566, 0, -12574, 0, 21556, 0, -12573, 0, 27595, 0, -12572, 0, 27494, 0, -12571, 0, 20116, 0, -12570, 0, 25410, 0, -12569, 0, 21320, 0, -12568, 0, -32226, 0, -12567, 0, 20237, 0, -12566, 0, 20398, 0, -12565, 0, 22366, 0, -12564, 0, 25098, 0, -12563, 0, -26882, 0, -12562, 0, 26212, 0, -12561, 0, 29289, 0, -12560, 0, 21247, 0, -12559, 0, 21153, 0, -12558, 0, 24735, 0, -12557, 0, -29713, 0, -12556, 0, 26132, 0, -12555, 0, 29081, 0, -12554, 0, 26512, 0, -12553, 0, -30337, 0, -12552, 0, 30802, 0, -12551, 0, 30717, 0, -12550, 0, 26224, 0, -12549, 0, 22075, 0, -12548, 0, 21560, 0, -12547, 0, -27359, 0, -12546, 0, 29306, 0, -12383, 0, 31232, 0, -12382, 0, 24687, 0, -12381, 0, 24076, 0, -12380, 0, 24713, 0, -12379, 0, -32355, 0, -12378, 0, 22805, 0, -12377, 0, 24796, 0, -12376, 0, 29060, 0, -12375, 0, 28911, 0, -12374, 0, 28330, 0, -12373, 0, 27728, 0, -12372, 0, 29312, 0, -12371, 0, 27268, 0, -12370, 0, -30547, 0, -12369, 0, 24109, 0, -12368, 0, 20064, 0, -12367, 0, 23219, 0, -12366, 0, 21916, 0, -12365, 0, -27421, 0, -12364, 0, 27927, 0, -12363, 0, 31995, 0, -12362, 0, -26983, 0, -12361, 0, 25103, 0, -12360, 0, 32454, 0, -12359, 0, 30606, 0, -12358, 0, -31106, 0, -12357, 0, 21283, 0, -12356, 0, -26850, 0, -12355, 0, -28778, 0, -12354, 0, 26247, 0, -12353, 0, 23777, 0, -12352, 0, 20384, 0, -12351, 0, 29421, 0, -12350, 0, 19979, 0, -12349, 0, 21414, 0, -12348, 0, 22799, 0, -12347, 0, 21523, 0, -12346, 0, 25472, 0, -12345, 0, -27352, 0, -12344, 0, 20808, 0, -12343, 0, 20185, 0, -12342, 0, -25444, 0, -12341, 0, 32420, 0, -12340, 0, 21688, 0, -12339, 0, -29404, 0, -12338, 0, -30636, 0, -12337, 0, -32201, 0, -12336, 0, -27150, 0, -12335, 0, 28046, 0, -12334, 0, 24358, 0, -12333, 0, 23244, 0, -12332, 0, 26174, 0, -12331, 0, -27031, 0, -12330, 0, 29616, 0, -12329, 0, 29486, 0, -12328, 0, 21439, 0, -12327, 0, -32390, 0, -12326, 0, -26235, 0, -12325, 0, 32673, 0, -12324, 0, 23466, 0, -12323, 0, -27017, 0, -12322, 0, -27056, 0, -12321, 0, 32447, 0, -12320, 0, 30456, 0, -12319, 0, 21410, 0, -12318, 0, -27274, 0, -12317, 0, -26215, 0, -12316, 0, 31665, 0, -12315, 0, -30396, 0, -12314, 0, 28248, 0, -12313, 0, 20065, 0, -12312, 0, 32724, 0, -12311, 0, 31077, 0, -12310, 0, -29722, 0, -12309, 0, 24819, 0, -12308, 0, 21709, 0, -12307, 0, 20139, 0, -12306, 0, -26503, 0, -12305, 0, 24055, 0, -12304, 0, 27233, 0, -12303, 0, 20687, 0, -12302, 0, 21521, 0, -12301, 0, -29599, 0, -12300, 0, -31705, 0, -12299, 0, 30813, 0, -12298, 0, -26876, 0, -12297, 0, 21066, 0, -12296, 0, 21742, 0, -12295, 0, 22179, 0, -12294, 0, -27392, 0, -12293, 0, 28040, 0, -12292, 0, 23477, 0, -12291, 0, 28102, 0, -12290, 0, 26195, 0, -12127, 0, 23567, 0, -12126, 0, 23389, 0, -12125, 0, 26657, 0, -12124, 0, -32618, 0, -12123, 0, 21880, 0, -12122, 0, 31505, 0, -12121, 0, 25928, 0, -12120, 0, 26964, 0, -12119, 0, 20123, 0, -12118, 0, 27463, 0, -12117, 0, -30898, 0, -12116, 0, -26741, 0, -12115, 0, 21327, 0, -12114, 0, 25375, 0, -12113, 0, 25658, 0, -12112, 0, -28502, 0, -12111, 0, 26012, 0, -12110, 0, -32575, 0, -12109, 0, -29680, 0, -12108, 0, 20889, 0, -12107, 0, 26800, 0, -12106, 0, 21368, 0, -12105, 0, -30727, 0, -12104, 0, 25032, 0, -12103, 0, 27844, 0, -12102, 0, 27899, 0, -12101, 0, -29662, 0, -12100, 0, 23633, 0, -12099, 0, -31318, 0, -12098, 0, -32081, 0, -12097, 0, -27380, 0, -12096, 0, 27427, 0, -12095, 0, -28773, 0, -12094, 0, 26032, 0, -12093, 0, 24571, 0, -12092, 0, 24515, 0, -12091, 0, 20449, 0, -12090, 0, -30651, 0, -12089, 0, 26143, 0, -12088, 0, -32411, 0, -12087, 0, 29481, 0, -12086, 0, 24826, 0, -12085, 0, 20852, 0, -12084, 0, 21009, 0, -12083, 0, 22411, 0, -12082, 0, 24418, 0, -12081, 0, -28510, 0, -12080, 0, -30644, 0, -12079, 0, -28270, 0, -12078, 0, 24184, 0, -12077, 0, 26447, 0, -12076, 0, 24615, 0, -12075, 0, 22995, 0, -12074, 0, 20804, 0, -12073, 0, 20982, 0, -12072, 0, -32520, 0, -12071, 0, 21256, 0, -12070, 0, 27769, 0, -12069, 0, -26940, 0, -12068, 0, 29066, 0, -12067, 0, 20241, 0, -12066, 0, 20462, 0, -12065, 0, 32670, 0, -12064, 0, 26429, 0, -12063, 0, 21957, 0, -12062, 0, -27384, 0, -12061, 0, 31168, 0, -12060, 0, -30570, 0, -12059, 0, 32483, 0, -12058, 0, 22687, 0, -12057, 0, 25100, 0, -12056, 0, -26880, 0, -12055, 0, -31142, 0, -12054, 0, 22040, 0, -12053, 0, -26501, 0, -12052, 0, 24464, 0, -12051, 0, -29768, 0, -12050, 0, -31548, 0, -12049, 0, -28329, 0, -12048, 0, 21465, 0, -12047, 0, 26093, 0, -12046, 0, 24207, 0, -12045, 0, 30044, 0, -12044, 0, 24676, 0, -12043, 0, 32110, 0, -12042, 0, 23167, 0, -12041, 0, 32490, 0, -12040, 0, 32493, 0, -12039, 0, -28823, 0, -12038, 0, 21927, 0, -12037, 0, 23459, 0, -12036, 0, 24748, 0, -12035, 0, 26059, 0, -12034, 0, 29572, 0, -11871, 0, -28663, 0, -11870, 0, 30307, 0, -11869, 0, 30505, 0, -11868, 0, 32474, 0, -11867, 0, -26764, 0, -11866, 0, -31333, 0, -11865, 0, 23398, 0, -11864, 0, 31348, 0, -11863, 0, -26902, 0, -11862, 0, -30656, 0, -11861, 0, 21195, 0, -11860, 0, 29071, 0, -11859, 0, 24490, 0, -11858, 0, 26092, 0, -11857, 0, -29726, 0, -11856, 0, 23547, 0, -11855, 0, -26001, 0, -11854, 0, 24033, 0, -11853, 0, 27529, 0, -11852, 0, 27739, 0, -11851, 0, -29779, 0, -11850, 0, -29777, 0, -11849, 0, -28662, 0, -11848, 0, -28731, 0, -11847, 0, 21387, 0, -11846, 0, 25276, 0, -11845, 0, -25050, 0, -11844, 0, -25043, 0, -11843, 0, 21568, 0, -11842, 0, 20011, 0, -11841, 0, -32067, 0, -11840, 0, 29273, 0, -11839, 0, -31076, 0, -11838, 0, 23830, 0, -11837, 0, -30631, 0, -11836, 0, 28079, 0, -11835, 0, -26939, 0, -11834, 0, 21713, 0, -11833, 0, 20122, 0, -11832, 0, -29770, 0, -11831, 0, 28937, 0, -11830, 0, 21693, 0, -11829, 0, -27127, 0, -11828, 0, 28895, 0, -11827, 0, 28153, 0, -11826, 0, 30416, 0, -11825, 0, 20005, 0, -11824, 0, 30740, 0, -11823, 0, -30958, 0, -11822, 0, 23721, 0, -11821, 0, 24310, 0, -11820, 0, -30208, 0, -11819, 0, -26468, 0, -11818, 0, -27122, 0, -11817, 0, 28814, 0, -11816, 0, 27839, 0, -11815, 0, 22852, 0, -11814, 0, 25513, 0, -11813, 0, 30524, 0, -11812, 0, -30643, 0, -11811, 0, 28436, 0, -11810, 0, -32141, 0, -11809, 0, 22576, 0, -11808, 0, 29141, 0, -11807, 0, 21388, 0, -11806, 0, 30746, 0, -11805, 0, -26943, 0, -11804, 0, 21761, 0, -11803, 0, 24422, 0, -11802, 0, 28976, 0, -11801, 0, 23476, 0, -11800, 0, -29670, 0, -11799, 0, -25972, 0, -11798, 0, 27523, 0, -11797, 0, 22830, 0, -11796, 0, -25041, 0, -11795, 0, 31207, 0, -11794, 0, 26472, 0, -11793, 0, 25196, 0, -11792, 0, 20335, 0, -11791, 0, 30113, 0, -11790, 0, 32650, 0, -11789, 0, 27915, 0, -11788, 0, -27085, 0, -11787, 0, 27687, 0, -11786, 0, 20208, 0, -11785, 0, 30162, 0, -11784, 0, 20859, 0, -11783, 0, 26679, 0, -11782, 0, 28478, 0, -11781, 0, -28544, 0, -11780, 0, -32400, 0, -11779, 0, 22934, 0, -11778, 0, 29814, 0, -11615, 0, 25671, 0, -11614, 0, 23591, 0, -11613, 0, -28571, 0, -11612, 0, 31377, 0, -11611, 0, -29661, 0, -11610, 0, 23002, 0, -11609, 0, 21676, 0, -11608, 0, -32256, 0, -11607, 0, -31889, 0, -11606, 0, -30335, 0, -11605, 0, -32768, 0, -11604, 0, 26928, 0, -11603, 0, 22094, 0, -11602, 0, -32714, 0, -11601, 0, 29239, 0, -11600, 0, -28210, 0, -11599, 0, 20918, 0, -11598, 0, 20063, 0, -11597, 0, -26507, 0, -11596, 0, 25494, 0, -11595, 0, 19994, 0, -11594, 0, 21494, 0, -11593, 0, 26355, 0, -11592, 0, -32437, 0, -11591, 0, 22812, 0, -11590, 0, 28082, 0, -11589, 0, 19968, 0, -11588, 0, 22777, 0, -11587, 0, 21307, 0, -11586, 0, 25558, 0, -11585, 0, -27407, 0, -11584, 0, 20381, 0, -11583, 0, 20234, 0, -11582, 0, -30621, 0, -11581, 0, -26480, 0, -11580, 0, 22839, 0, -11579, 0, -28585, 0, -11578, 0, 31227, 0, -11577, 0, 20202, 0, -11576, 0, -32528, 0, -11575, 0, 30097, 0, -11574, 0, 27778, 0, -11573, 0, 23452, 0, -11572, 0, 23016, 0, -11571, 0, 24413, 0, -11570, 0, 26885, 0, -11569, 0, -31103, 0, -11568, 0, 20506, 0, -11567, 0, 24050, 0, -11566, 0, 20057, 0, -11565, 0, 30691, 0, -11564, 0, 20197, 0, -11563, 0, -32134, 0, -11562, 0, 25233, 0, -11561, 0, 26131, 0, -11560, 0, -28527, 0, -11559, 0, 23673, 0, -11558, 0, 20159, 0, -11557, 0, 24441, 0, -11556, 0, -32314, 0, -11555, 0, -28616, 0, -11554, 0, -32636, 0, -11553, 0, 30123, 0, -11552, 0, 20134, 0, -11551, 0, -30508, 0, -11550, 0, 24847, 0, -11549, 0, 27589, 0, -11548, 0, 24518, 0, -11547, 0, 20041, 0, -11546, 0, 30410, 0, -11545, 0, 28322, 0, -11544, 0, -29725, 0, -11543, 0, -29778, 0, -11542, 0, -29686, 0, -11541, 0, -29743, 0, -11540, 0, 24322, 0, -11539, 0, 32764, 0, -11538, 0, 32716, 0, -11537, 0, 32462, 0, -11536, 0, -31947, 0, -11535, 0, -31893, 0, -11534, 0, 22240, 0, -11533, 0, 27575, 0, -11532, 0, -26637, 0, -11531, 0, -27084, 0, -11530, 0, 23035, 0, -11529, 0, 21535, 0, -11528, 0, -27402, 0, -11527, 0, 28139, 0, -11526, 0, 23493, 0, -11525, 0, -26258, 0, -11524, 0, 23609, 0, -11523, 0, 24341, 0, -11522, 0, -26992, 0, -11359, 0, 21360, 0, -11358, 0, -32015, 0, -11357, 0, 27185, 0, -11356, 0, 23156, 0, -11355, 0, -24976, 0, -11354, 0, 24212, 0, -11353, 0, 32552, 0, -11352, 0, -31815, 0, -11351, 0, -31708, 0, -11350, 0, -31707, 0, -11349, 0, -31897, 0, -11348, 0, -30905, 0, -11347, 0, -28722, 0, -11346, 0, -29342, 0, -11345, 0, 30408, 0, -11344, 0, 24433, 0, -11343, 0, -26474, 0, -11342, 0, 30828, 0, -11341, 0, 26144, 0, -11340, 0, 21727, 0, -11339, 0, 25317, 0, -11338, 0, 20323, 0, -11337, 0, -32317, 0, -11336, 0, 30152, 0, -11335, 0, 24248, 0, -11334, 0, -26931, 0, -11333, 0, -29174, 0, -11332, 0, -30983, 0, -11331, 0, 21647, 0, -11330, 0, 27891, 0, -11329, 0, 28044, 0, -11328, 0, 27704, 0, -11327, 0, 24703, 0, -11326, 0, 21191, 0, -11325, 0, 29992, 0, -11324, 0, 24189, 0, -11323, 0, 20248, 0, -11322, 0, 24736, 0, -11321, 0, 24551, 0, -11320, 0, 23588, 0, -11319, 0, 30001, 0, -11318, 0, -28498, 0, -11317, 0, -27456, 0, -11316, 0, 29369, 0, -11315, 0, 27833, 0, -11314, 0, 28216, 0, -11313, 0, -28343, 0, -11312, 0, 26377, 0, -11311, 0, 21451, 0, -11310, 0, 21491, 0, -11309, 0, 20305, 0, -11308, 0, -28215, 0, -11307, 0, -29711, 0, -11306, 0, 21448, 0, -11305, 0, 24188, 0, -11304, 0, -28734, 0, -11303, 0, 28132, 0, -11302, 0, 20110, 0, -11301, 0, 30402, 0, -11300, 0, 27014, 0, -11299, 0, -31138, 0, -11298, 0, 24858, 0, -11297, 0, -32250, 0, -11296, 0, 20313, 0, -11295, 0, 20446, 0, -11294, 0, -28610, 0, -11293, 0, -25476, 0, -11292, 0, 24841, 0, -11291, 0, 28189, 0, -11290, 0, 28180, 0, -11289, 0, -27003, 0, -11288, 0, 20104, 0, -11287, 0, 23089, 0, -11286, 0, -26904, 0, -11285, 0, 19982, 0, -11284, 0, 23679, 0, -11283, 0, 31161, 0, -11282, 0, 23431, 0, -11281, 0, -29715, 0, -11280, 0, 32701, 0, -11279, 0, 29577, 0, -11278, 0, 22495, 0, -11277, 0, -32117, 0, -11276, 0, -28479, 0, -11275, 0, 21505, 0, -11274, 0, -28601, 0, -11273, 0, 21947, 0, -11272, 0, 23786, 0, -11271, 0, 24481, 0, -11270, 0, 24840, 0, -11269, 0, 27442, 0, -11268, 0, 29425, 0, -11267, 0, -32590, 0, -11266, 0, -30071, 0, -11103, 0, 28020, 0, -11102, 0, 23507, 0, -11101, 0, -30507, 0, -11100, 0, -26492, 0, -11099, 0, -29589, 0, -11098, 0, -26003, 0, -11097, 0, -25037, 0, -11096, 0, 28170, 0, -11095, 0, 20900, 0, -11094, 0, 20803, 0, -11093, 0, 22435, 0, -11092, 0, -30591, 0, -11091, 0, 21407, 0, -11090, 0, 25588, 0, -11089, 0, -28779, 0, -11088, 0, 22253, 0, -11087, 0, 21592, 0, -11086, 0, 22278, 0, -11085, 0, 29503, 0, -11084, 0, 28304, 0, -11083, 0, 32536, 0, -11082, 0, -28708, 0, -11081, 0, -32047, 0, -11080, 0, 24895, 0, -11079, 0, 24616, 0, -11078, 0, -27038, 0, -11077, 0, 26352, 0, -11076, 0, 32422, 0, -11075, 0, -29302, 0, -11074, 0, -29245, 0, -11073, 0, -27483, 0, -11072, 0, 23731, 0, -11071, 0, 31908, 0, -11070, 0, 26376, 0, -11069, 0, 24742, 0, -11068, 0, -27131, 0, -11067, 0, -32744, 0, -11066, 0, 20113, 0, -11065, 0, -28441, 0, -11064, 0, 21248, 0, -11063, 0, -27032, 0, -11062, 0, 20801, 0, -11061, 0, -28720, 0, -11060, 0, -31372, 0, -11059, 0, -28323, 0, -11058, 0, 26197, 0, -11057, 0, -26635, 0, -11056, 0, 23381, 0, -11055, 0, 21277, 0, -11054, 0, 30776, 0, -11053, 0, 26434, 0, -11052, 0, 26685, 0, -11051, 0, 21705, 0, -11050, 0, 28798, 0, -11049, 0, 23472, 0, -11048, 0, -28803, 0, -11047, 0, 20877, 0, -11046, 0, 22312, 0, -11045, 0, 21681, 0, -11044, 0, 25874, 0, -11043, 0, 26242, 0, -11042, 0, -29346, 0, -11041, 0, -29373, 0, -11040, 0, -32497, 0, -11039, 0, -31636, 0, -11038, 0, -28563, 0, -11037, 0, 31967, 0, -11036, 0, 20991, 0, -11035, 0, -31237, 0, -11034, 0, 26531, 0, -11033, 0, 26089, 0, -11032, 0, 28577, 0, -11031, 0, -31068, 0, -11030, 0, -29055, 0, -11029, 0, 22122, 0, -11028, 0, -28640, 0, -11027, 0, 30338, 0, -11026, 0, 28790, 0, -11025, 0, 29157, 0, -11024, 0, -29405, 0, -11023, 0, 25321, 0, -11022, 0, 21017, 0, -11021, 0, 27901, 0, -11020, 0, -29380, 0, -11019, 0, 24590, 0, -11018, 0, 22686, 0, -11017, 0, 24974, 0, -11016, 0, 26366, 0, -11015, 0, -29344, 0, -11014, 0, 25166, 0, -11013, 0, 21939, 0, -11012, 0, 28195, 0, -11011, 0, 26413, 0, -11010, 0, -28825, 0, -10847, 0, -27423, 0, -10846, 0, -27144, 0, -10845, 0, 30504, 0, -10844, 0, 26629, 0, -10843, 0, 27048, 0, -10842, 0, 21643, 0, -10841, 0, 20045, 0, -10840, 0, 28856, 0, -10839, 0, -29752, 0, -10838, 0, 25688, 0, -10837, 0, 25995, 0, -10836, 0, 23429, 0, -10835, 0, 31364, 0, -10834, 0, 20538, 0, -10833, 0, 23528, 0, -10832, 0, 30651, 0, -10831, 0, 27617, 0, -10830, 0, -30087, 0, -10829, 0, 31896, 0, -10828, 0, 27838, 0, -10827, 0, 30415, 0, -10826, 0, 26025, 0, -10825, 0, -28777, 0, -10824, 0, 23853, 0, -10823, 0, 23637, 0, -10822, 0, -31176, 0, -10821, 0, 26632, 0, -10820, 0, 21344, 0, -10819, 0, 25112, 0, -10818, 0, 31449, 0, -10817, 0, 28251, 0, -10816, 0, 32509, 0, -10815, 0, 27167, 0, -10814, 0, 31456, 0, -10813, 0, 24432, 0, -10812, 0, 28467, 0, -10811, 0, 24352, 0, -10810, 0, 25484, 0, -10809, 0, 28072, 0, -10808, 0, 26454, 0, -10807, 0, 19976, 0, -10806, 0, 24080, 0, -10805, 0, -29402, 0, -10804, 0, 20183, 0, -10803, 0, -32576, 0, -10802, 0, 30260, 0, -10801, 0, -26980, 0, -10800, 0, 25307, 0, -10799, 0, 26157, 0, -10798, 0, 25214, 0, -10797, 0, 27836, 0, -10796, 0, -29323, 0, -10795, 0, 29031, 0, -10794, 0, 32617, 0, -10793, 0, 20806, 0, -10792, 0, -32633, 0, -10791, 0, 21484, 0, -10790, 0, -28562, 0, -10789, 0, 25240, 0, -10788, 0, 21746, 0, -10787, 0, -30992, 0, -10786, 0, -28775, 0, -10785, 0, -32763, 0, -10784, 0, -27369, 0, -10783, 0, -31465, 0, -10782, 0, -28711, 0, -10781, 0, 27993, 0, -10780, 0, 29645, 0, -10779, 0, 26015, 0, -10778, 0, 30495, 0, -10777, 0, 29956, 0, -10776, 0, 30759, 0, -10775, 0, -32261, 0, -10774, 0, -29410, 0, -10773, 0, -27512, 0, -10772, 0, 20390, 0, -10771, 0, 26517, 0, -10770, 0, 30137, 0, -10769, 0, -29750, 0, -10768, 0, -26873, 0, -10767, 0, 25391, 0, -10766, 0, -27321, 0, -10765, 0, -27083, 0, -10764, 0, -31560, 0, -10763, 0, 25379, 0, -10762, 0, 30529, 0, -10761, 0, 24449, 0, -10760, 0, 29424, 0, -10759, 0, 20105, 0, -10758, 0, 24596, 0, -10757, 0, 25972, 0, -10756, 0, 25327, 0, -10755, 0, 27491, 0, -10754, 0, 25919, 0, -10591, 0, 24103, 0, -10590, 0, 30151, 0, -10589, 0, -28463, 0, -10588, 0, -29759, 0, -10587, 0, -32099, 0, -10586, 0, 26525, 0, -10585, 0, 25903, 0, -10584, 0, 21553, 0, -10583, 0, -30952, 0, -10582, 0, 30693, 0, -10581, 0, -32606, 0, -10580, 0, -32510, 0, -10579, 0, 27713, 0, -10578, 0, 20043, 0, -10577, 0, 32455, 0, -10576, 0, -32692, 0, -10575, 0, 30452, 0, -10574, 0, 26893, 0, -10573, 0, 27542, 0, -10572, 0, 25191, 0, -10571, 0, 20540, 0, -10570, 0, 20356, 0, -10569, 0, 22336, 0, -10568, 0, 25351, 0, -10567, 0, 27490, 0, -10566, 0, -29250, 0, -10565, 0, 21482, 0, -10564, 0, 26088, 0, -10563, 0, 32440, 0, -10562, 0, 24535, 0, -10561, 0, 25370, 0, -10560, 0, 25527, 0, -10559, 0, -32269, 0, -10558, 0, -32268, 0, -10557, 0, 32622, 0, -10556, 0, 24092, 0, -10555, 0, 23769, 0, -10554, 0, 21046, 0, -10553, 0, 26234, 0, -10552, 0, 31209, 0, -10551, 0, 31258, 0, -10550, 0, -29400, 0, -10549, 0, 28825, 0, -10548, 0, 30164, 0, -10547, 0, 28382, 0, -10546, 0, 27835, 0, -10545, 0, 31378, 0, -10544, 0, 20013, 0, -10543, 0, 30405, 0, -10542, 0, 24544, 0, -10541, 0, -27489, 0, -10540, 0, -30601, 0, -10539, 0, 32456, 0, -10538, 0, 31181, 0, -10537, 0, -32577, 0, -10536, 0, -28211, 0, -10535, 0, 20210, 0, -10534, 0, 20247, 0, -10533, 0, -32225, 0, -10532, 0, 21608, 0, -10531, 0, 24030, 0, -10530, 0, 27954, 0, -10529, 0, -29748, 0, -10528, 0, 31909, 0, -10527, 0, -28812, 0, -10526, 0, -32616, 0, -10525, 0, 24090, 0, -10524, 0, 21650, 0, -10523, 0, 30385, 0, -10522, 0, 23449, 0, -10521, 0, 26172, 0, -10520, 0, -25948, 0, -10519, 0, 29664, 0, -10518, 0, 26666, 0, -10517, 0, -31013, 0, -10516, 0, 26417, 0, -10515, 0, 29482, 0, -10514, 0, -29704, 0, -10513, 0, -29733, 0, -10512, 0, -28656, 0, -10511, 0, 31481, 0, -10510, 0, 28891, 0, -10509, 0, 29038, 0, -10508, 0, 25284, 0, -10507, 0, 30633, 0, -10506, 0, 22065, 0, -10505, 0, 20027, 0, -10504, 0, -31657, 0, -10503, 0, 26609, 0, -10502, 0, 21161, 0, -10501, 0, -31040, 0, -10500, 0, -29394, 0, -10499, 0, -27400, 0, -10498, 0, 31569, 0, -10335, 0, 20303, 0, -10334, 0, 27880, 0, -10333, 0, 31069, 0, -10332, 0, -25989, 0, -10331, 0, 25235, 0, -10330, 0, 29226, 0, -10329, 0, 25341, 0, -10328, 0, 19987, 0, -10327, 0, 30742, 0, -10326, 0, -28820, 0, -10325, 0, 25776, 0, -10324, 0, -29350, 0, -10323, 0, 31686, 0, -10322, 0, 26729, 0, -10321, 0, 24196, 0, -10320, 0, -30523, 0, -10319, 0, 22918, 0, -10318, 0, 25758, 0, -10317, 0, 22766, 0, -10316, 0, 29366, 0, -10315, 0, 26894, 0, -10314, 0, -27355, 0, -10313, 0, -28675, 0, -10312, 0, -29352, 0, -10311, 0, 22368, 0, -10310, 0, 32512, 0, -10309, 0, -29690, 0, -10308, 0, 20934, 0, -10307, 0, 25417, 0, -10306, 0, 25305, 0, -10305, 0, 21331, 0, -10304, 0, 26700, 0, -10303, 0, 29730, 0, -10302, 0, -31999, 0, -10301, 0, -28340, 0, -10300, 0, 21828, 0, -10299, 0, 30528, 0, -10298, 0, 28796, 0, -10297, 0, 27978, 0, -10296, 0, 20857, 0, -10295, 0, 21672, 0, -10294, 0, -29372, 0, -10293, 0, 23039, 0, -10292, 0, 28363, 0, -10291, 0, 28100, 0, -10290, 0, 23388, 0, -10289, 0, 32043, 0, -10288, 0, 20180, 0, -10287, 0, 31869, 0, -10286, 0, 28371, 0, -10285, 0, 23376, 0, -10284, 0, -32278, 0, -10283, 0, 28173, 0, -10282, 0, 23383, 0, -10281, 0, -25853, 0, -10280, 0, 26837, 0, -10279, 0, -29142, 0, -10278, 0, 23447, 0, -10277, 0, 32508, 0, -10276, 0, 24635, 0, -10275, 0, 32437, 0, -10274, 0, -28487, 0, -10273, 0, -29328, 0, -10272, 0, 22863, 0, -10271, 0, 25549, 0, -10270, 0, 31199, 0, -10269, 0, -29261, 0, -10268, 0, 21330, 0, -10267, 0, 26063, 0, -10266, 0, 31062, 0, -10265, 0, -29755, 0, -10264, 0, -27077, 0, -10263, 0, 32452, 0, -10262, 0, -27461, 0, -10261, 0, 32386, 0, -10260, 0, 22068, 0, -10259, 0, -28279, 0, -10258, 0, 26368, 0, -10257, 0, 32618, 0, -10256, 0, 23562, 0, -10255, 0, -28555, 0, -10254, 0, 26152, 0, -10253, 0, 24038, 0, -10252, 0, 20304, 0, -10251, 0, 26590, 0, -10250, 0, 20570, 0, -10249, 0, 20316, 0, -10248, 0, 22352, 0, -10247, 0, 24231, 0, -10079, 0, 20109, 0, -10078, 0, 19980, 0, -10077, 0, -1524, 0, -10076, 0, 19984, 0, -10075, 0, 24319, 0, -10074, 0, 21317, 0, -10073, 0, 19989, 0, -10072, 0, 20120, 0, -10071, 0, 19998, 0, -10070, 0, -25806, 0, -10069, 0, 23404, 0, -10068, 0, 22121, 0, -10067, 0, 20008, 0, -10066, 0, 31162, 0, -10065, 0, 20031, 0, -10064, 0, 21269, 0, -10063, 0, 20039, 0, -10062, 0, 22829, 0, -10061, 0, 29243, 0, -10060, 0, 21358, 0, -10059, 0, 27664, 0, -10058, 0, 22239, 0, -10057, 0, -32540, 0, -10056, 0, -26217, 0, -10055, 0, 27603, 0, -10054, 0, 30590, 0, -10053, 0, -24809, 0, -10052, 0, 20022, 0, -10051, 0, 20127, 0, -10050, 0, -24816, 0, -10049, 0, 20060, 0, -10048, 0, 20073, 0, -10047, 0, 20115, 0, -10046, 0, -32120, 0, -10045, 0, 23387, 0, -10044, 0, 21868, 0, -10043, 0, 22031, 0, -10042, 0, 20164, 0, -10041, 0, 21389, 0, -10040, 0, 21405, 0, -10039, 0, 21411, 0, -10038, 0, 21413, 0, -10037, 0, 21422, 0, -10036, 0, -26779, 0, -10035, 0, -29347, 0, -10034, 0, 21274, 0, -10033, 0, 21493, 0, -10032, 0, 21286, 0, -10031, 0, 21294, 0, -10030, 0, 21310, 0, -10029, 0, -29348, 0, -10028, 0, 21350, 0, -10027, 0, 21347, 0, -10026, 0, 20994, 0, -10025, 0, 21000, 0, -10024, 0, 21006, 0, -10023, 0, 21037, 0, -10022, 0, 21043, 0, -10021, 0, 21055, 0, -10020, 0, 21056, 0, -10019, 0, 21068, 0, -10018, 0, 21086, 0, -10017, 0, 21089, 0, -10016, 0, 21084, 0, -10015, 0, -31569, 0, -10014, 0, 21117, 0, -10013, 0, 21122, 0, -10012, 0, 21121, 0, -10011, 0, 21136, 0, -10010, 0, 21139, 0, -10009, 0, 20866, 0, -10008, 0, 32596, 0, -10007, 0, 20155, 0, -10006, 0, 20163, 0, -10005, 0, 20169, 0, -10004, 0, 20162, 0, -10003, 0, 20200, 0, -10002, 0, 20193, 0, -10001, 0, 20203, 0, -10000, 0, 20190, 0, -9999, 0, 20251, 0, -9998, 0, 20211, 0, -9997, 0, 20258, 0, -9996, 0, 20324, 0, -9995, 0, 20213, 0, -9994, 0, 20261, 0, -9993, 0, 20263, 0, -9992, 0, 20233, 0, -9991, 0, 20267, 0, -9990, 0, 20318, 0, -9989, 0, 20327, 0, -9988, 0, 25912, 0, -9987, 0, 20314, 0, -9986, 0, 20317, 0, -9823, 0, 20319, 0, -9822, 0, 20311, 0, -9821, 0, 20274, 0, -9820, 0, 20285, 0, -9819, 0, 20342, 0, -9818, 0, 20340, 0, -9817, 0, 20369, 0, -9816, 0, 20361, 0, -9815, 0, 20355, 0, -9814, 0, 20367, 0, -9813, 0, 20350, 0, -9812, 0, 20347, 0, -9811, 0, 20394, 0, -9810, 0, 20348, 0, -9809, 0, 20396, 0, -9808, 0, 20372, 0, -9807, 0, 20454, 0, -9806, 0, 20456, 0, -9805, 0, 20458, 0, -9804, 0, 20421, 0, -9803, 0, 20442, 0, -9802, 0, 20451, 0, -9801, 0, 20444, 0, -9800, 0, 20433, 0, -9799, 0, 20447, 0, -9798, 0, 20472, 0, -9797, 0, 20521, 0, -9796, 0, 20556, 0, -9795, 0, 20467, 0, -9794, 0, 20524, 0, -9793, 0, 20495, 0, -9792, 0, 20526, 0, -9791, 0, 20525, 0, -9790, 0, 20478, 0, -9789, 0, 20508, 0, -9788, 0, 20492, 0, -9787, 0, 20517, 0, -9786, 0, 20520, 0, -9785, 0, 20606, 0, -9784, 0, 20547, 0, -9783, 0, 20565, 0, -9782, 0, 20552, 0, -9781, 0, 20558, 0, -9780, 0, 20588, 0, -9779, 0, 20603, 0, -9778, 0, 20645, 0, -9777, 0, 20647, 0, -9776, 0, 20649, 0, -9775, 0, 20666, 0, -9774, 0, 20694, 0, -9773, 0, 20742, 0, -9772, 0, 20717, 0, -9771, 0, 20716, 0, -9770, 0, 20710, 0, -9769, 0, 20718, 0, -9768, 0, 20743, 0, -9767, 0, 20747, 0, -9766, 0, 20189, 0, -9765, 0, 27709, 0, -9764, 0, 20312, 0, -9763, 0, 20325, 0, -9762, 0, 20430, 0, -9761, 0, -24672, 0, -9760, 0, 27718, 0, -9759, 0, 31860, 0, -9758, 0, 20846, 0, -9757, 0, 24061, 0, -9756, 0, -24887, 0, -9755, 0, -26216, 0, -9754, 0, 20865, 0, -9753, 0, 22804, 0, -9752, 0, 21241, 0, -9751, 0, 21261, 0, -9750, 0, -30201, 0, -9749, 0, 21264, 0, -9748, 0, 20971, 0, -9747, 0, 22809, 0, -9746, 0, 20821, 0, -9745, 0, 20128, 0, -9744, 0, 20822, 0, -9743, 0, 20147, 0, -9742, 0, -30610, 0, -9741, 0, -30556, 0, -9740, 0, 20149, 0, -9739, 0, -32492, 0, -9738, 0, -30510, 0, -9737, 0, 31104, 0, -9736, 0, 23348, 0, -9735, 0, -30717, 0, -9734, 0, 32696, 0, -9733, 0, 20907, 0, -9732, 0, 20913, 0, -9731, 0, 20925, 0, -9730, 0, 20924, 0, -9567, 0, 20935, 0, -9566, 0, 20886, 0, -9565, 0, 20898, 0, -9564, 0, 20901, 0, -9563, 0, -29792, 0, -9562, 0, -29786, 0, -9561, 0, -29785, 0, -9560, 0, -29782, 0, -9559, 0, -29772, 0, -9558, 0, -29771, 0, -9557, 0, -29769, 0, -9556, 0, -29758, 0, -9555, 0, -29757, 0, -9554, 0, -29749, 0, -9553, 0, -29745, 0, -9552, 0, -29746, 0, -9551, 0, -29742, 0, -9550, 0, -29741, 0, -9549, 0, -29740, 0, -9548, 0, -29738, 0, -9547, 0, -29736, 0, -9546, 0, -29735, 0, -9545, 0, -29732, 0, -9544, 0, -29729, 0, -9543, 0, -29728, 0, -9542, 0, -29724, 0, -9541, 0, -29720, 0, -9540, 0, -29719, 0, -9539, 0, -29714, 0, -9538, 0, -29712, 0, -9537, 0, -29709, 0, -9536, 0, -29706, 0, -9535, 0, -29703, 0, -9534, 0, -29700, 0, -9533, 0, -29697, 0, -9532, 0, -29696, 0, -9531, 0, -29694, 0, -9530, 0, -29692, 0, -9529, 0, -29689, 0, -9528, 0, -29684, 0, -9527, 0, -29681, 0, -9526, 0, -29679, 0, -9525, 0, -29678, 0, -9524, 0, -29676, 0, -9523, 0, -29675, 0, -9522, 0, -29674, 0, -9521, 0, -29671, 0, -9520, 0, -29669, 0, -9519, 0, -29672, 0, -9518, 0, -29667, 0, -9517, 0, -29665, 0, -9516, 0, -29664, 0, -9515, 0, -29663, 0, -9514, 0, -29659, 0, -9513, 0, -29657, 0, -9512, 0, -29654, 0, -9511, 0, -29653, 0, -9510, 0, -29650, 0, -9509, 0, -29649, 0, -9508, 0, -29646, 0, -9507, 0, -29645, 0, -9506, 0, -29643, 0, -9505, 0, -29642, 0, -9504, 0, 21353, 0, -9503, 0, 21370, 0, -9502, 0, -27107, 0, -9501, 0, -27102, 0, -9500, 0, -27103, 0, -9499, 0, -27087, 0, -9498, 0, -27094, 0, -9497, 0, -27075, 0, -9496, 0, -27076, 0, -9495, 0, -27070, 0, -9494, 0, -27063, 0, -9493, 0, -27052, 0, -9492, 0, -27041, 0, -9491, 0, -27033, 0, -9490, 0, -27028, 0, -9489, 0, -27022, 0, -9488, 0, -27020, 0, -9487, 0, -27000, 0, -9486, 0, -26995, 0, -9485, 0, -26985, 0, -9484, 0, -26960, 0, -9483, 0, -28521, 0, -9482, 0, -28517, 0, -9481, 0, -28515, 0, -9480, 0, -28519, 0, -9479, 0, -28500, 0, -9478, 0, -28511, 0, -9477, 0, -28492, 0, -9476, 0, -28493, 0, -9475, 0, -28490, 0, -9474, 0, -28486, 0, -9311, 0, -28488, 0, -9310, 0, -28496, 0, -9309, 0, -28465, 0, -9308, 0, -28475, 0, -9307, 0, -28482, 0, -9306, 0, -28464, 0, -9305, 0, -28476, 0, -9304, 0, -28473, 0, -9303, 0, -28461, 0, -9302, 0, -28442, 0, -9301, 0, -28446, 0, -9300, 0, -28452, 0, -9299, 0, -28457, 0, -9298, 0, -28453, 0, -9297, 0, -28437, 0, -9296, 0, -28433, 0, -9295, 0, -28418, 0, -9294, 0, -28412, 0, -9293, 0, -28382, 0, -9292, 0, -28386, 0, -9291, 0, -28381, 0, -9290, 0, -28367, 0, -9289, 0, -28369, 0, -9288, 0, -28359, 0, -9287, 0, -28349, 0, -9286, 0, -28346, 0, -9285, 0, 21005, 0, -9284, 0, 22850, 0, -9283, 0, 21154, 0, -9282, 0, 21164, 0, -9281, 0, 21165, 0, -9280, 0, 21182, 0, -9279, 0, 21759, 0, -9278, 0, 21200, 0, -9277, 0, 21206, 0, -9276, 0, 21232, 0, -9275, 0, 21471, 0, -9274, 0, 29166, 0, -9273, 0, 30669, 0, -9272, 0, 24308, 0, -9271, 0, 20981, 0, -9270, 0, 20988, 0, -9269, 0, -25809, 0, -9268, 0, 21430, 0, -9267, 0, 24321, 0, -9266, 0, 30042, 0, -9265, 0, 24047, 0, -9264, 0, 22348, 0, -9263, 0, 22441, 0, -9262, 0, 22433, 0, -9261, 0, 22654, 0, -9260, 0, 22716, 0, -9259, 0, 22725, 0, -9258, 0, 22737, 0, -9257, 0, 22313, 0, -9256, 0, 22316, 0, -9255, 0, 22314, 0, -9254, 0, 22323, 0, -9253, 0, 22329, 0, -9252, 0, 22318, 0, -9251, 0, 22319, 0, -9250, 0, 22364, 0, -9249, 0, 22331, 0, -9248, 0, 22338, 0, -9247, 0, 22377, 0, -9246, 0, 22405, 0, -9245, 0, 22379, 0, -9244, 0, 22406, 0, -9243, 0, 22396, 0, -9242, 0, 22395, 0, -9241, 0, 22376, 0, -9240, 0, 22381, 0, -9239, 0, 22390, 0, -9238, 0, 22387, 0, -9237, 0, 22445, 0, -9236, 0, 22436, 0, -9235, 0, 22412, 0, -9234, 0, 22450, 0, -9233, 0, 22479, 0, -9232, 0, 22439, 0, -9231, 0, 22452, 0, -9230, 0, 22419, 0, -9229, 0, 22432, 0, -9228, 0, 22485, 0, -9227, 0, 22488, 0, -9226, 0, 22490, 0, -9225, 0, 22489, 0, -9224, 0, 22482, 0, -9223, 0, 22456, 0, -9222, 0, 22516, 0, -9221, 0, 22511, 0, -9220, 0, 22520, 0, -9219, 0, 22500, 0, -9218, 0, 22493, 0, -9055, 0, 22539, 0, -9054, 0, 22541, 0, -9053, 0, 22525, 0, -9052, 0, 22509, 0, -9051, 0, 22528, 0, -9050, 0, 22558, 0, -9049, 0, 22553, 0, -9048, 0, 22596, 0, -9047, 0, 22560, 0, -9046, 0, 22629, 0, -9045, 0, 22636, 0, -9044, 0, 22657, 0, -9043, 0, 22665, 0, -9042, 0, 22682, 0, -9041, 0, 22656, 0, -9040, 0, -26200, 0, -9039, 0, -24807, 0, -9038, 0, 25087, 0, -9037, 0, -32135, 0, -9036, 0, -32131, 0, -9035, 0, -32129, 0, -9034, 0, -32113, 0, -9033, 0, -32118, 0, -9032, 0, -32088, 0, -9031, 0, -32124, 0, -9030, 0, -32114, 0, -9029, 0, -32111, 0, -9028, 0, -32105, 0, -9027, 0, -32103, 0, -9026, 0, -32085, 0, -9025, 0, -32072, 0, -9024, 0, -32066, 0, -9023, 0, -32080, 0, -9022, 0, -32056, 0, -9021, 0, -32054, 0, -9020, 0, -32029, 0, -9019, 0, -32104, 0, -9018, 0, -32073, 0, -9017, 0, -32082, 0, -9016, 0, -32053, 0, -9015, 0, -32052, 0, -9014, 0, -32063, 0, -9013, 0, -32087, 0, -9012, 0, -32076, 0, -9011, 0, -32095, 0, -9010, 0, -32086, 0, -9009, 0, -32097, 0, -9008, 0, -32060, 0, -9007, 0, -32050, 0, -9006, 0, -32092, 0, -9005, 0, -32031, 0, -9004, 0, -31991, 0, -9003, 0, -32009, 0, -9002, 0, -32028, 0, -9001, 0, -31985, 0, -9000, 0, -31993, 0, -8999, 0, -32036, 0, -8998, 0, -32012, 0, -8997, 0, -32046, 0, -8996, 0, -32040, 0, -8995, 0, -31988, 0, -8994, 0, -32005, 0, -8993, 0, -32045, 0, -8992, 0, -31983, 0, -8991, 0, -31974, 0, -8990, 0, -31994, 0, -8989, 0, -31980, 0, -8988, 0, -31979, 0, -8987, 0, -32032, 0, -8986, 0, -32043, 0, -8985, 0, -31972, 0, -8984, 0, -31919, 0, -8983, 0, -31909, 0, -8982, 0, -31908, 0, -8981, 0, -31992, 0, -8980, 0, -31854, 0, -8979, 0, -31940, 0, -8978, 0, -31948, 0, -8977, 0, -31951, 0, -8976, 0, -31845, 0, -8975, 0, -31906, 0, -8974, 0, -31953, 0, -8973, 0, -31921, 0, -8972, 0, -31929, 0, -8971, 0, -31933, 0, -8970, 0, -31905, 0, -8969, 0, -31936, 0, -8968, 0, -31977, 0, -8967, 0, -31904, 0, -8966, 0, -31955, 0, -8965, 0, -31942, 0, -8964, 0, -31949, 0, -8963, 0, -31898, 0, -8962, 0, -31899, 0, -8799, 0, -31896, 0, -8798, 0, -31973, 0, -8797, 0, -31895, 0, -8796, 0, -31892, 0, -8795, 0, -31894, 0, -8794, 0, -31891, 0, -8793, 0, -31890, 0, -8792, 0, -31824, 0, -8791, 0, -31880, 0, -8790, 0, -31821, 0, -8789, 0, -31820, 0, -8788, 0, -31840, 0, -8787, 0, -31830, 0, -8786, 0, -31853, 0, -8785, 0, -31844, 0, -8784, 0, -31867, 0, -8783, 0, -31876, 0, -8782, 0, -31818, 0, -8781, 0, -31831, 0, -8780, 0, -31875, 0, -8779, 0, -31816, 0, -8778, 0, -31877, 0, -8777, 0, -31848, 0, -8776, 0, -31842, 0, -8775, 0, -31832, 0, -8774, 0, -31814, 0, -8773, 0, -31812, 0, -8772, 0, -31807, 0, -8771, 0, -31743, 0, -8770, 0, -31771, 0, -8769, 0, -31784, 0, -8768, 0, 22535, 0, -8767, 0, -31720, 0, -8766, 0, -31733, 0, -8765, 0, -31779, 0, -8764, 0, -31747, 0, -8763, 0, -31786, 0, -8762, 0, -31716, 0, -8761, 0, -31688, 0, -8760, 0, -31727, 0, -8759, 0, -31738, 0, -8758, 0, -31788, 0, -8757, 0, -31777, 0, -8756, 0, -31729, 0, -8755, 0, -31741, 0, -8754, 0, -31752, 0, -8753, 0, -31751, 0, -8752, 0, -31766, 0, -8751, 0, -31803, 0, -8750, 0, -31808, 0, -8749, 0, -31706, 0, -8748, 0, -31760, 0, -8747, 0, -31775, 0, -8746, 0, -31652, 0, -8745, 0, -31663, 0, -8744, 0, -31654, 0, -8743, 0, -31655, 0, -8742, 0, -31629, 0, -8741, 0, -31609, 0, -8740, 0, -31608, 0, -8739, 0, -31622, 0, -8738, 0, -31607, 0, -8737, 0, -31624, 0, -8736, 0, -31684, 0, -8735, 0, -31674, 0, -8734, 0, -31639, 0, -8733, 0, -31626, 0, -8732, 0, -31604, 0, -8731, 0, -31602, 0, -8730, 0, -31695, 0, -8729, 0, -31635, 0, -8728, 0, -31551, 0, -8727, 0, -31539, 0, -8726, 0, -31536, 0, -8725, 0, -31514, 0, -8724, 0, -31555, 0, -8723, 0, -31533, 0, -8722, 0, -31542, 0, -8721, 0, -31553, 0, -8720, 0, -31558, 0, -8719, 0, -31520, 0, -8718, 0, -31583, 0, -8717, 0, -31559, 0, -8716, 0, -31564, 0, -8715, 0, -31593, 0, -8714, 0, -31515, 0, -8713, 0, -31517, 0, -8712, 0, -31476, 0, -8711, 0, 29965, 0, -8710, 0, -31432, 0, -8709, 0, -31504, 0, -8708, 0, -31431, 0, -8707, 0, -31457, 0, -8706, 0, -31430, 0, -8543, 0, -31402, 0, -8542, 0, -31429, 0, -8541, 0, -31489, 0, -8540, 0, -31492, 0, -8539, 0, -31399, 0, -8538, 0, -31416, 0, -8537, 0, -31384, 0, -8536, 0, -31388, 0, -8535, 0, -31394, 0, -8534, 0, -31366, 0, -8533, 0, 30626, 0, -8532, 0, -31421, 0, -8531, 0, -31374, 0, -8530, 0, -31365, 0, -8529, 0, -31324, 0, -8528, 0, -31320, 0, -8527, 0, -31353, 0, -8526, 0, -31345, 0, -8525, 0, -31367, 0, -8524, 0, -31314, 0, -8523, 0, -31332, 0, -8522, 0, -31355, 0, -8521, 0, -31303, 0, -8520, 0, -31305, 0, -8519, 0, -31312, 0, -8518, 0, -31277, 0, -8517, 0, -31295, 0, -8516, 0, -31268, 0, -8515, 0, -31233, 0, -8514, 0, -31193, 0, -8513, 0, -31227, 0, -8512, 0, -31191, 0, -8511, 0, -31210, 0, -8510, 0, -31172, 0, -8509, 0, 24318, 0, -8508, 0, 24328, 0, -8507, 0, 22844, 0, -8506, 0, 22849, 0, -8505, 0, -32713, 0, -8504, 0, 22869, 0, -8503, 0, 22874, 0, -8502, 0, 22872, 0, -8501, 0, 21263, 0, -8500, 0, 23586, 0, -8499, 0, 23589, 0, -8498, 0, 23596, 0, -8497, 0, 23604, 0, -8496, 0, 25164, 0, -8495, 0, 25194, 0, -8494, 0, 25247, 0, -8493, 0, 25275, 0, -8492, 0, 25290, 0, -8491, 0, 25306, 0, -8490, 0, 25303, 0, -8489, 0, 25326, 0, -8488, 0, 25378, 0, -8487, 0, 25334, 0, -8486, 0, 25401, 0, -8485, 0, 25419, 0, -8484, 0, 25411, 0, -8483, 0, 25517, 0, -8482, 0, 25590, 0, -8481, 0, 25457, 0, -8480, 0, 25466, 0, -8479, 0, 25486, 0, -8478, 0, 25524, 0, -8477, 0, 25453, 0, -8476, 0, 25516, 0, -8475, 0, 25482, 0, -8474, 0, 25449, 0, -8473, 0, 25518, 0, -8472, 0, 25532, 0, -8471, 0, 25586, 0, -8470, 0, 25592, 0, -8469, 0, 25568, 0, -8468, 0, 25599, 0, -8467, 0, 25540, 0, -8466, 0, 25566, 0, -8465, 0, 25550, 0, -8464, 0, 25682, 0, -8463, 0, 25542, 0, -8462, 0, 25534, 0, -8461, 0, 25669, 0, -8460, 0, 25665, 0, -8459, 0, 25611, 0, -8458, 0, 25627, 0, -8457, 0, 25632, 0, -8456, 0, 25612, 0, -8455, 0, 25638, 0, -8454, 0, 25633, 0, -8453, 0, 25694, 0, -8452, 0, 25732, 0, -8451, 0, 25709, 0, -8450, 0, 25750, 0, -8287, 0, 25722, 0, -8286, 0, 25783, 0, -8285, 0, 25784, 0, -8284, 0, 25753, 0, -8283, 0, 25786, 0, -8282, 0, 25792, 0, -8281, 0, 25808, 0, -8280, 0, 25815, 0, -8279, 0, 25828, 0, -8278, 0, 25826, 0, -8277, 0, 25865, 0, -8276, 0, 25893, 0, -8275, 0, 25902, 0, -8274, 0, 24331, 0, -8273, 0, 24530, 0, -8272, 0, 29977, 0, -8271, 0, 24337, 0, -8270, 0, 21343, 0, -8269, 0, 21489, 0, -8268, 0, 21501, 0, -8267, 0, 21481, 0, -8266, 0, 21480, 0, -8265, 0, 21499, 0, -8264, 0, 21522, 0, -8263, 0, 21526, 0, -8262, 0, 21510, 0, -8261, 0, 21579, 0, -8260, 0, 21586, 0, -8259, 0, 21587, 0, -8258, 0, 21588, 0, -8257, 0, 21590, 0, -8256, 0, 21571, 0, -8255, 0, 21537, 0, -8254, 0, 21591, 0, -8253, 0, 21593, 0, -8252, 0, 21539, 0, -8251, 0, 21554, 0, -8250, 0, 21634, 0, -8249, 0, 21652, 0, -8248, 0, 21623, 0, -8247, 0, 21617, 0, -8246, 0, 21604, 0, -8245, 0, 21658, 0, -8244, 0, 21659, 0, -8243, 0, 21636, 0, -8242, 0, 21622, 0, -8241, 0, 21606, 0, -8240, 0, 21661, 0, -8239, 0, 21712, 0, -8238, 0, 21677, 0, -8237, 0, 21698, 0, -8236, 0, 21684, 0, -8235, 0, 21714, 0, -8234, 0, 21671, 0, -8233, 0, 21670, 0, -8232, 0, 21715, 0, -8231, 0, 21716, 0, -8230, 0, 21618, 0, -8229, 0, 21667, 0, -8228, 0, 21717, 0, -8227, 0, 21691, 0, -8226, 0, 21695, 0, -8225, 0, 21708, 0, -8224, 0, 21721, 0, -8223, 0, 21722, 0, -8222, 0, 21724, 0, -8221, 0, 21673, 0, -8220, 0, 21674, 0, -8219, 0, 21668, 0, -8218, 0, 21725, 0, -8217, 0, 21711, 0, -8216, 0, 21726, 0, -8215, 0, 21787, 0, -8214, 0, 21735, 0, -8213, 0, 21792, 0, -8212, 0, 21757, 0, -8211, 0, 21780, 0, -8210, 0, 21747, 0, -8209, 0, 21794, 0, -8208, 0, 21795, 0, -8207, 0, 21775, 0, -8206, 0, 21777, 0, -8205, 0, 21799, 0, -8204, 0, 21802, 0, -8203, 0, 21863, 0, -8202, 0, 21903, 0, -8201, 0, 21941, 0, -8200, 0, 21833, 0, -8199, 0, 21869, 0, -8198, 0, 21825, 0, -8197, 0, 21845, 0, -8196, 0, 21823, 0, -8195, 0, 21840, 0, -8194, 0, 21820, 0, -8031, 0, 21815, 0, -8030, 0, 21846, 0, -8029, 0, 21877, 0, -8028, 0, 21878, 0, -8027, 0, 21879, 0, -8026, 0, 21811, 0, -8025, 0, 21808, 0, -8024, 0, 21852, 0, -8023, 0, 21899, 0, -8022, 0, 21970, 0, -8021, 0, 21891, 0, -8020, 0, 21937, 0, -8019, 0, 21945, 0, -8018, 0, 21896, 0, -8017, 0, 21889, 0, -8016, 0, 21919, 0, -8015, 0, 21886, 0, -8014, 0, 21974, 0, -8013, 0, 21905, 0, -8012, 0, 21883, 0, -8011, 0, 21983, 0, -8010, 0, 21949, 0, -8009, 0, 21950, 0, -8008, 0, 21908, 0, -8007, 0, 21913, 0, -8006, 0, 21994, 0, -8005, 0, 22007, 0, -8004, 0, 21961, 0, -8003, 0, 22047, 0, -8002, 0, 21969, 0, -8001, 0, 21995, 0, -8000, 0, 21996, 0, -7999, 0, 21972, 0, -7998, 0, 21990, 0, -7997, 0, 21981, 0, -7996, 0, 21956, 0, -7995, 0, 21999, 0, -7994, 0, 21989, 0, -7993, 0, 22002, 0, -7992, 0, 22003, 0, -7991, 0, 21964, 0, -7990, 0, 21965, 0, -7989, 0, 21992, 0, -7988, 0, 22005, 0, -7987, 0, 21988, 0, -7986, 0, -28780, 0, -7985, 0, 22046, 0, -7984, 0, 22024, 0, -7983, 0, 22028, 0, -7982, 0, 22017, 0, -7981, 0, 22052, 0, -7980, 0, 22051, 0, -7979, 0, 22014, 0, -7978, 0, 22016, 0, -7977, 0, 22055, 0, -7976, 0, 22061, 0, -7975, 0, 22104, 0, -7974, 0, 22073, 0, -7973, 0, 22103, 0, -7972, 0, 22060, 0, -7971, 0, 22093, 0, -7970, 0, 22114, 0, -7969, 0, 22105, 0, -7968, 0, 22108, 0, -7967, 0, 22092, 0, -7966, 0, 22100, 0, -7965, 0, 22150, 0, -7964, 0, 22116, 0, -7963, 0, 22129, 0, -7962, 0, 22123, 0, -7961, 0, 22139, 0, -7960, 0, 22140, 0, -7959, 0, 22149, 0, -7958, 0, 22163, 0, -7957, 0, 22191, 0, -7956, 0, 22228, 0, -7955, 0, 22231, 0, -7954, 0, 22237, 0, -7953, 0, 22241, 0, -7952, 0, 22261, 0, -7951, 0, 22251, 0, -7950, 0, 22265, 0, -7949, 0, 22271, 0, -7948, 0, 22276, 0, -7947, 0, 22282, 0, -7946, 0, 22281, 0, -7945, 0, 22300, 0, -7944, 0, 24079, 0, -7943, 0, 24089, 0, -7942, 0, 24084, 0, -7941, 0, 24081, 0, -7940, 0, 24113, 0, -7939, 0, 24123, 0, -7938, 0, 24124, 0, -7775, 0, 24119, 0, -7774, 0, 24132, 0, -7773, 0, 24148, 0, -7772, 0, 24155, 0, -7771, 0, 24158, 0, -7770, 0, 24161, 0, -7769, 0, 23692, 0, -7768, 0, 23674, 0, -7767, 0, 23693, 0, -7766, 0, 23696, 0, -7765, 0, 23702, 0, -7764, 0, 23688, 0, -7763, 0, 23704, 0, -7762, 0, 23705, 0, -7761, 0, 23697, 0, -7760, 0, 23706, 0, -7759, 0, 23708, 0, -7758, 0, 23733, 0, -7757, 0, 23714, 0, -7756, 0, 23741, 0, -7755, 0, 23724, 0, -7754, 0, 23723, 0, -7753, 0, 23729, 0, -7752, 0, 23715, 0, -7751, 0, 23745, 0, -7750, 0, 23735, 0, -7749, 0, 23748, 0, -7748, 0, 23762, 0, -7747, 0, 23780, 0, -7746, 0, 23755, 0, -7745, 0, 23781, 0, -7744, 0, 23810, 0, -7743, 0, 23811, 0, -7742, 0, 23847, 0, -7741, 0, 23846, 0, -7740, 0, 23854, 0, -7739, 0, 23844, 0, -7738, 0, 23838, 0, -7737, 0, 23814, 0, -7736, 0, 23835, 0, -7735, 0, 23896, 0, -7734, 0, 23870, 0, -7733, 0, 23860, 0, -7732, 0, 23869, 0, -7731, 0, 23916, 0, -7730, 0, 23899, 0, -7729, 0, 23919, 0, -7728, 0, 23901, 0, -7727, 0, 23915, 0, -7726, 0, 23883, 0, -7725, 0, 23882, 0, -7724, 0, 23913, 0, -7723, 0, 23924, 0, -7722, 0, 23938, 0, -7721, 0, 23961, 0, -7720, 0, 23965, 0, -7719, 0, -29581, 0, -7718, 0, 23991, 0, -7717, 0, 24005, 0, -7716, 0, 24435, 0, -7715, 0, 24439, 0, -7714, 0, 24450, 0, -7713, 0, 24455, 0, -7712, 0, 24457, 0, -7711, 0, 24460, 0, -7710, 0, 24469, 0, -7709, 0, 24473, 0, -7708, 0, 24476, 0, -7707, 0, 24488, 0, -7706, 0, 24493, 0, -7705, 0, 24501, 0, -7704, 0, 24508, 0, -7703, 0, -30622, 0, -7702, 0, 24417, 0, -7701, 0, 29357, 0, -7700, 0, 29360, 0, -7699, 0, 29364, 0, -7698, 0, 29367, 0, -7697, 0, 29368, 0, -7696, 0, 29379, 0, -7695, 0, 29377, 0, -7694, 0, 29390, 0, -7693, 0, 29389, 0, -7692, 0, 29394, 0, -7691, 0, 29416, 0, -7690, 0, 29423, 0, -7689, 0, 29417, 0, -7688, 0, 29426, 0, -7687, 0, 29428, 0, -7686, 0, 29431, 0, -7685, 0, 29441, 0, -7684, 0, 29427, 0, -7683, 0, 29443, 0, -7682, 0, 29434, 0, -7519, 0, 29435, 0, -7518, 0, 29463, 0, -7517, 0, 29459, 0, -7516, 0, 29473, 0, -7515, 0, 29450, 0, -7514, 0, 29470, 0, -7513, 0, 29469, 0, -7512, 0, 29461, 0, -7511, 0, 29474, 0, -7510, 0, 29497, 0, -7509, 0, 29477, 0, -7508, 0, 29484, 0, -7507, 0, 29496, 0, -7506, 0, 29489, 0, -7505, 0, 29520, 0, -7504, 0, 29517, 0, -7503, 0, 29527, 0, -7502, 0, 29536, 0, -7501, 0, 29548, 0, -7500, 0, 29551, 0, -7499, 0, 29566, 0, -7498, 0, -32229, 0, -7497, 0, 22821, 0, -7496, 0, -26393, 0, -7495, 0, 22820, 0, -7494, 0, 22786, 0, -7493, 0, -26269, 0, -7492, 0, -26265, 0, -7491, 0, -26264, 0, -7490, 0, -26263, 0, -7489, 0, -26262, 0, -7488, 0, -26261, 0, -7487, 0, -26260, 0, -7486, 0, -26252, 0, -7485, 0, -26249, 0, -7484, 0, -26243, 0, -7483, 0, -26240, 0, -7482, 0, -26236, 0, -7481, 0, -26233, 0, -7480, 0, -26230, 0, -7479, 0, -26227, 0, -7478, 0, -26224, 0, -7477, 0, -26223, 0, -7476, 0, -26221, 0, -7475, 0, -26220, 0, -7474, 0, -26219, 0, -7473, 0, 24192, 0, -7472, 0, 24209, 0, -7471, 0, 24203, 0, -7470, 0, 24214, 0, -7469, 0, 24229, 0, -7468, 0, 24224, 0, -7467, 0, 24249, 0, -7466, 0, 24245, 0, -7465, 0, 24254, 0, -7464, 0, 24243, 0, -7463, 0, -29357, 0, -7462, 0, 24274, 0, -7461, 0, 24273, 0, -7460, 0, 24283, 0, -7459, 0, 24296, 0, -7458, 0, 24298, 0, -7457, 0, -32326, 0, -7456, 0, 24516, 0, -7455, 0, 24521, 0, -7454, 0, 24534, 0, -7453, 0, 24527, 0, -7452, 0, 24579, 0, -7451, 0, 24558, 0, -7450, 0, 24580, 0, -7449, 0, 24545, 0, -7448, 0, 24548, 0, -7447, 0, 24574, 0, -7446, 0, 24581, 0, -7445, 0, 24582, 0, -7444, 0, 24554, 0, -7443, 0, 24557, 0, -7442, 0, 24568, 0, -7441, 0, 24601, 0, -7440, 0, 24629, 0, -7439, 0, 24614, 0, -7438, 0, 24603, 0, -7437, 0, 24591, 0, -7436, 0, 24589, 0, -7435, 0, 24617, 0, -7434, 0, 24619, 0, -7433, 0, 24586, 0, -7432, 0, 24639, 0, -7431, 0, 24609, 0, -7430, 0, 24696, 0, -7429, 0, 24697, 0, -7428, 0, 24699, 0, -7427, 0, 24698, 0, -7426, 0, 24642, 0, -7263, 0, 24682, 0, -7262, 0, 24701, 0, -7261, 0, 24726, 0, -7260, 0, 24730, 0, -7259, 0, 24749, 0, -7258, 0, 24733, 0, -7257, 0, 24707, 0, -7256, 0, 24722, 0, -7255, 0, 24716, 0, -7254, 0, 24731, 0, -7253, 0, 24812, 0, -7252, 0, 24763, 0, -7251, 0, 24753, 0, -7250, 0, 24797, 0, -7249, 0, 24792, 0, -7248, 0, 24774, 0, -7247, 0, 24794, 0, -7246, 0, 24756, 0, -7245, 0, 24864, 0, -7244, 0, 24870, 0, -7243, 0, 24853, 0, -7242, 0, 24867, 0, -7241, 0, 24820, 0, -7240, 0, 24832, 0, -7239, 0, 24846, 0, -7238, 0, 24875, 0, -7237, 0, 24906, 0, -7236, 0, 24949, 0, -7235, 0, 25004, 0, -7234, 0, 24980, 0, -7233, 0, 24999, 0, -7232, 0, 25015, 0, -7231, 0, 25044, 0, -7230, 0, 25077, 0, -7229, 0, 24541, 0, -7228, 0, -26957, 0, -7227, 0, -27159, 0, -7226, 0, -27157, 0, -7225, 0, -27151, 0, -7224, 0, -27149, 0, -7223, 0, -27147, 0, -7222, 0, -27146, 0, -7221, 0, -27140, 0, -7220, 0, -27138, 0, -7219, 0, -27133, 0, -7218, 0, -27132, 0, -7217, 0, -27130, 0, -7216, 0, -27128, 0, -7215, 0, -27126, 0, -7214, 0, -27125, 0, -7213, 0, -27124, 0, -7212, 0, -27123, 0, -7211, 0, -27121, 0, -7210, 0, -27118, 0, -7209, 0, -27115, 0, -7208, 0, -27114, 0, -7207, 0, -27113, 0, -7206, 0, -27111, 0, -7205, 0, -27110, 0, -7204, 0, 20012, 0, -7203, 0, 29247, 0, -7202, 0, 25109, 0, -7201, 0, 27701, 0, -7200, 0, 27732, 0, -7199, 0, 27740, 0, -7198, 0, 27722, 0, -7197, 0, 27811, 0, -7196, 0, 27781, 0, -7195, 0, 27792, 0, -7194, 0, 27796, 0, -7193, 0, 27788, 0, -7192, 0, 27752, 0, -7191, 0, 27753, 0, -7190, 0, 27764, 0, -7189, 0, 27766, 0, -7188, 0, 27782, 0, -7187, 0, 27817, 0, -7186, 0, 27856, 0, -7185, 0, 27860, 0, -7184, 0, 27821, 0, -7183, 0, 27895, 0, -7182, 0, 27896, 0, -7181, 0, 27889, 0, -7180, 0, 27863, 0, -7179, 0, 27826, 0, -7178, 0, 27872, 0, -7177, 0, 27862, 0, -7176, 0, 27898, 0, -7175, 0, 27883, 0, -7174, 0, 27886, 0, -7173, 0, 27825, 0, -7172, 0, 27859, 0, -7171, 0, 27887, 0, -7170, 0, 27902, 0, -7007, 0, 27961, 0, -7006, 0, 27943, 0, -7005, 0, 27916, 0, -7004, 0, 27971, 0, -7003, 0, 27976, 0, -7002, 0, 27911, 0, -7001, 0, 27908, 0, -7000, 0, 27929, 0, -6999, 0, 27918, 0, -6998, 0, 27947, 0, -6997, 0, 27981, 0, -6996, 0, 27950, 0, -6995, 0, 27957, 0, -6994, 0, 27930, 0, -6993, 0, 27983, 0, -6992, 0, 27986, 0, -6991, 0, 27988, 0, -6990, 0, 27955, 0, -6989, 0, 28049, 0, -6988, 0, 28015, 0, -6987, 0, 28062, 0, -6986, 0, 28064, 0, -6985, 0, 27998, 0, -6984, 0, 28051, 0, -6983, 0, 28052, 0, -6982, 0, 27996, 0, -6981, 0, 28000, 0, -6980, 0, 28028, 0, -6979, 0, 28003, 0, -6978, 0, 28186, 0, -6977, 0, 28103, 0, -6976, 0, 28101, 0, -6975, 0, 28126, 0, -6974, 0, 28174, 0, -6973, 0, 28095, 0, -6972, 0, 28128, 0, -6971, 0, 28177, 0, -6970, 0, 28134, 0, -6969, 0, 28125, 0, -6968, 0, 28121, 0, -6967, 0, 28182, 0, -6966, 0, 28075, 0, -6965, 0, 28172, 0, -6964, 0, 28078, 0, -6963, 0, 28203, 0, -6962, 0, 28270, 0, -6961, 0, 28238, 0, -6960, 0, 28267, 0, -6959, 0, 28338, 0, -6958, 0, 28255, 0, -6957, 0, 28294, 0, -6956, 0, 28243, 0, -6955, 0, 28244, 0, -6954, 0, 28210, 0, -6953, 0, 28197, 0, -6952, 0, 28228, 0, -6951, 0, 28383, 0, -6950, 0, 28337, 0, -6949, 0, 28312, 0, -6948, 0, 28384, 0, -6947, 0, 28461, 0, -6946, 0, 28386, 0, -6945, 0, 28325, 0, -6944, 0, 28327, 0, -6943, 0, 28349, 0, -6942, 0, 28347, 0, -6941, 0, 28343, 0, -6940, 0, 28375, 0, -6939, 0, 28340, 0, -6938, 0, 28367, 0, -6937, 0, 28303, 0, -6936, 0, 28354, 0, -6935, 0, 28319, 0, -6934, 0, 28514, 0, -6933, 0, 28486, 0, -6932, 0, 28487, 0, -6931, 0, 28452, 0, -6930, 0, 28437, 0, -6929, 0, 28409, 0, -6928, 0, 28463, 0, -6927, 0, 28470, 0, -6926, 0, 28491, 0, -6925, 0, 28532, 0, -6924, 0, 28458, 0, -6923, 0, 28425, 0, -6922, 0, 28457, 0, -6921, 0, 28553, 0, -6920, 0, 28557, 0, -6919, 0, 28556, 0, -6918, 0, 28536, 0, -6917, 0, 28530, 0, -6916, 0, 28540, 0, -6915, 0, 28538, 0, -6914, 0, 28625, 0, -6751, 0, 28617, 0, -6750, 0, 28583, 0, -6749, 0, 28601, 0, -6748, 0, 28598, 0, -6747, 0, 28610, 0, -6746, 0, 28641, 0, -6745, 0, 28654, 0, -6744, 0, 28638, 0, -6743, 0, 28640, 0, -6742, 0, 28655, 0, -6741, 0, 28698, 0, -6740, 0, 28707, 0, -6739, 0, 28699, 0, -6738, 0, 28729, 0, -6737, 0, 28725, 0, -6736, 0, 28751, 0, -6735, 0, 28766, 0, -6734, 0, 23424, 0, -6733, 0, 23428, 0, -6732, 0, 23445, 0, -6731, 0, 23443, 0, -6730, 0, 23461, 0, -6729, 0, 23480, 0, -6728, 0, 29999, 0, -6727, 0, -25954, 0, -6726, 0, 25652, 0, -6725, 0, 23524, 0, -6724, 0, 23534, 0, -6723, 0, -30416, 0, -6722, 0, 23536, 0, -6721, 0, -29113, 0, -6720, 0, -29945, 0, -6719, 0, -28746, 0, -6718, 0, -28717, 0, -6717, 0, -28715, 0, -6716, 0, -28699, 0, -6715, 0, -28690, 0, -6714, 0, -28700, 0, -6713, 0, -28695, 0, -6712, 0, -28698, 0, -6711, 0, -28685, 0, -6710, 0, -28696, 0, -6709, 0, -28667, 0, -6708, 0, -28668, 0, -6707, 0, -28661, 0, -6706, 0, -28634, 0, -6705, 0, -28655, 0, -6704, 0, -28659, 0, -6703, 0, -28650, 0, -6702, 0, -28639, 0, -6701, 0, -28619, 0, -6700, 0, -28618, 0, -6699, 0, -28627, 0, -6698, 0, -28625, 0, -6697, 0, -28604, 0, -6696, 0, -28591, 0, -6695, 0, -28590, 0, -6694, 0, -28592, 0, -6693, 0, -28568, 0, -6692, 0, -28584, 0, -6691, 0, -28574, 0, -6690, 0, -28581, 0, -6689, 0, 26297, 0, -6688, 0, -28556, 0, -6687, 0, -28547, 0, -6686, 0, -28542, 0, -6685, 0, -28536, 0, -6684, 0, -28541, 0, -6683, 0, -28533, 0, -6682, 0, 24400, 0, -6681, 0, 24407, 0, -6680, 0, 24406, 0, -6679, 0, 24408, 0, -6678, 0, 23611, 0, -6677, 0, 21675, 0, -6676, 0, 23632, 0, -6675, 0, 23641, 0, -6674, 0, 23409, 0, -6673, 0, 23651, 0, -6672, 0, 23654, 0, -6671, 0, 32700, 0, -6670, 0, 24362, 0, -6669, 0, 24361, 0, -6668, 0, 24365, 0, -6667, 0, -32140, 0, -6666, 0, 24380, 0, -6665, 0, -25797, 0, -6664, 0, 23662, 0, -6663, 0, 22913, 0, -6662, 0, 22915, 0, -6661, 0, 22925, 0, -6660, 0, 22953, 0, -6659, 0, 22954, 0, -6658, 0, 22947, 0, -6495, 0, 22935, 0, -6494, 0, 22986, 0, -6493, 0, 22955, 0, -6492, 0, 22942, 0, -6491, 0, 22948, 0, -6490, 0, 22994, 0, -6489, 0, 22962, 0, -6488, 0, 22959, 0, -6487, 0, 22999, 0, -6486, 0, 22974, 0, -6485, 0, 23045, 0, -6484, 0, 23046, 0, -6483, 0, 23005, 0, -6482, 0, 23048, 0, -6481, 0, 23011, 0, -6480, 0, 23000, 0, -6479, 0, 23033, 0, -6478, 0, 23052, 0, -6477, 0, 23049, 0, -6476, 0, 23090, 0, -6475, 0, 23092, 0, -6474, 0, 23057, 0, -6473, 0, 23075, 0, -6472, 0, 23059, 0, -6471, 0, 23104, 0, -6470, 0, 23143, 0, -6469, 0, 23114, 0, -6468, 0, 23125, 0, -6467, 0, 23100, 0, -6466, 0, 23138, 0, -6465, 0, 23157, 0, -6464, 0, -32532, 0, -6463, 0, 23210, 0, -6462, 0, 23195, 0, -6461, 0, 23159, 0, -6460, 0, 23162, 0, -6459, 0, 23230, 0, -6458, 0, 23275, 0, -6457, 0, 23218, 0, -6456, 0, 23250, 0, -6455, 0, 23252, 0, -6454, 0, 23224, 0, -6453, 0, 23264, 0, -6452, 0, 23267, 0, -6451, 0, 23281, 0, -6450, 0, 23254, 0, -6449, 0, 23270, 0, -6448, 0, 23256, 0, -6447, 0, 23260, 0, -6446, 0, 23305, 0, -6445, 0, 23319, 0, -6444, 0, 23318, 0, -6443, 0, 23346, 0, -6442, 0, 23351, 0, -6441, 0, 23360, 0, -6440, 0, 23573, 0, -6439, 0, 23580, 0, -6438, 0, 23386, 0, -6437, 0, 23397, 0, -6436, 0, 23411, 0, -6435, 0, 23377, 0, -6434, 0, 23379, 0, -6433, 0, 23394, 0, -6432, 0, -25995, 0, -6431, 0, -25993, 0, -6430, 0, -25992, 0, -6429, 0, -25990, 0, -6428, 0, -25985, 0, -6427, 0, -25987, 0, -6426, 0, -25984, 0, -6425, 0, -25983, 0, -6424, 0, -25979, 0, -6423, 0, -25976, 0, -6422, 0, -25974, 0, -6421, 0, -25968, 0, -6420, 0, -25966, 0, -6419, 0, -25965, 0, -6418, 0, -25962, 0, -6417, 0, -25960, 0, -6416, 0, -25957, 0, -6415, 0, -25956, 0, -6414, 0, -25955, 0, -6413, 0, -25953, 0, -6412, 0, -25952, 0, -6411, 0, -25950, 0, -6410, 0, -25949, 0, -6409, 0, -25947, 0, -6408, 0, -25945, 0, -6407, 0, 32415, 0, -6406, 0, 32417, 0, -6405, 0, 32419, 0, -6404, 0, 32421, 0, -6403, 0, 32424, 0, -6402, 0, 32425, 0, -6239, 0, 32429, 0, -6238, 0, 32432, 0, -6237, 0, 32446, 0, -6236, 0, 32448, 0, -6235, 0, 32449, 0, -6234, 0, 32450, 0, -6233, 0, 32457, 0, -6232, 0, 32459, 0, -6231, 0, 32460, 0, -6230, 0, 32464, 0, -6229, 0, 32468, 0, -6228, 0, 32471, 0, -6227, 0, 32475, 0, -6226, 0, 32480, 0, -6225, 0, 32481, 0, -6224, 0, 32488, 0, -6223, 0, 32491, 0, -6222, 0, 32494, 0, -6221, 0, 32495, 0, -6220, 0, 32497, 0, -6219, 0, 32498, 0, -6218, 0, 32525, 0, -6217, 0, 32502, 0, -6216, 0, 32506, 0, -6215, 0, 32507, 0, -6214, 0, 32510, 0, -6213, 0, 32513, 0, -6212, 0, 32514, 0, -6211, 0, 32515, 0, -6210, 0, 32519, 0, -6209, 0, 32520, 0, -6208, 0, 32523, 0, -6207, 0, 32524, 0, -6206, 0, 32527, 0, -6205, 0, 32529, 0, -6204, 0, 32530, 0, -6203, 0, 32535, 0, -6202, 0, 32537, 0, -6201, 0, 32540, 0, -6200, 0, 32539, 0, -6199, 0, 32543, 0, -6198, 0, 32545, 0, -6197, 0, 32546, 0, -6196, 0, 32547, 0, -6195, 0, 32548, 0, -6194, 0, 32549, 0, -6193, 0, 32550, 0, -6192, 0, 32551, 0, -6191, 0, 32554, 0, -6190, 0, 32555, 0, -6189, 0, 32556, 0, -6188, 0, 32557, 0, -6187, 0, 32559, 0, -6186, 0, 32560, 0, -6185, 0, 32561, 0, -6184, 0, 32562, 0, -6183, 0, 32563, 0, -6182, 0, 32565, 0, -6181, 0, 24186, 0, -6180, 0, 30079, 0, -6179, 0, 24027, 0, -6178, 0, 30014, 0, -6177, 0, -28523, 0, -6176, 0, 29582, 0, -6175, 0, 29585, 0, -6174, 0, 29614, 0, -6173, 0, 29602, 0, -6172, 0, 29599, 0, -6171, 0, 29647, 0, -6170, 0, 29634, 0, -6169, 0, 29649, 0, -6168, 0, 29623, 0, -6167, 0, 29619, 0, -6166, 0, 29632, 0, -6165, 0, 29641, 0, -6164, 0, 29640, 0, -6163, 0, 29669, 0, -6162, 0, 29657, 0, -6161, 0, -26500, 0, -6160, 0, 29706, 0, -6159, 0, 29673, 0, -6158, 0, 29671, 0, -6157, 0, 29662, 0, -6156, 0, 29626, 0, -6155, 0, 29682, 0, -6154, 0, 29711, 0, -6153, 0, 29738, 0, -6152, 0, 29787, 0, -6151, 0, 29734, 0, -6150, 0, 29733, 0, -6149, 0, 29736, 0, -6148, 0, 29744, 0, -6147, 0, 29742, 0, -6146, 0, 29740, 0, -5983, 0, 29723, 0, -5982, 0, 29722, 0, -5981, 0, 29761, 0, -5980, 0, 29788, 0, -5979, 0, 29783, 0, -5978, 0, 29781, 0, -5977, 0, 29785, 0, -5976, 0, 29815, 0, -5975, 0, 29805, 0, -5974, 0, 29822, 0, -5973, 0, 29852, 0, -5972, 0, 29838, 0, -5971, 0, 29824, 0, -5970, 0, 29825, 0, -5969, 0, 29831, 0, -5968, 0, 29835, 0, -5967, 0, 29854, 0, -5966, 0, 29864, 0, -5965, 0, 29865, 0, -5964, 0, 29840, 0, -5963, 0, 29863, 0, -5962, 0, 29906, 0, -5961, 0, 29882, 0, -5960, 0, -26646, 0, -5959, 0, -26645, 0, -5958, 0, -26644, 0, -5957, 0, 26444, 0, -5956, 0, 26451, 0, -5955, 0, 26462, 0, -5954, 0, 26440, 0, -5953, 0, 26473, 0, -5952, 0, 26533, 0, -5951, 0, 26503, 0, -5950, 0, 26474, 0, -5949, 0, 26483, 0, -5948, 0, 26520, 0, -5947, 0, 26535, 0, -5946, 0, 26485, 0, -5945, 0, 26536, 0, -5944, 0, 26526, 0, -5943, 0, 26541, 0, -5942, 0, 26507, 0, -5941, 0, 26487, 0, -5940, 0, 26492, 0, -5939, 0, 26608, 0, -5938, 0, 26633, 0, -5937, 0, 26584, 0, -5936, 0, 26634, 0, -5935, 0, 26601, 0, -5934, 0, 26544, 0, -5933, 0, 26636, 0, -5932, 0, 26585, 0, -5931, 0, 26549, 0, -5930, 0, 26586, 0, -5929, 0, 26547, 0, -5928, 0, 26589, 0, -5927, 0, 26624, 0, -5926, 0, 26563, 0, -5925, 0, 26552, 0, -5924, 0, 26594, 0, -5923, 0, 26638, 0, -5922, 0, 26561, 0, -5921, 0, 26621, 0, -5920, 0, 26674, 0, -5919, 0, 26675, 0, -5918, 0, 26720, 0, -5917, 0, 26721, 0, -5916, 0, 26702, 0, -5915, 0, 26722, 0, -5914, 0, 26692, 0, -5913, 0, 26724, 0, -5912, 0, 26755, 0, -5911, 0, 26653, 0, -5910, 0, 26709, 0, -5909, 0, 26726, 0, -5908, 0, 26689, 0, -5907, 0, 26727, 0, -5906, 0, 26688, 0, -5905, 0, 26686, 0, -5904, 0, 26698, 0, -5903, 0, 26697, 0, -5902, 0, 26665, 0, -5901, 0, 26805, 0, -5900, 0, 26767, 0, -5899, 0, 26740, 0, -5898, 0, 26743, 0, -5897, 0, 26771, 0, -5896, 0, 26731, 0, -5895, 0, 26818, 0, -5894, 0, 26990, 0, -5893, 0, 26876, 0, -5892, 0, 26911, 0, -5891, 0, 26912, 0, -5890, 0, 26873, 0, -5727, 0, 26916, 0, -5726, 0, 26864, 0, -5725, 0, 26891, 0, -5724, 0, 26881, 0, -5723, 0, 26967, 0, -5722, 0, 26851, 0, -5721, 0, 26896, 0, -5720, 0, 26993, 0, -5719, 0, 26937, 0, -5718, 0, 26976, 0, -5717, 0, 26946, 0, -5716, 0, 26973, 0, -5715, 0, 27012, 0, -5714, 0, 26987, 0, -5713, 0, 27008, 0, -5712, 0, 27032, 0, -5711, 0, 27000, 0, -5710, 0, 26932, 0, -5709, 0, 27084, 0, -5708, 0, 27015, 0, -5707, 0, 27016, 0, -5706, 0, 27086, 0, -5705, 0, 27017, 0, -5704, 0, 26982, 0, -5703, 0, 26979, 0, -5702, 0, 27001, 0, -5701, 0, 27035, 0, -5700, 0, 27047, 0, -5699, 0, 27067, 0, -5698, 0, 27051, 0, -5697, 0, 27053, 0, -5696, 0, 27092, 0, -5695, 0, 27057, 0, -5694, 0, 27073, 0, -5693, 0, 27082, 0, -5692, 0, 27103, 0, -5691, 0, 27029, 0, -5690, 0, 27104, 0, -5689, 0, 27021, 0, -5688, 0, 27135, 0, -5687, 0, 27183, 0, -5686, 0, 27117, 0, -5685, 0, 27159, 0, -5684, 0, 27160, 0, -5683, 0, 27237, 0, -5682, 0, 27122, 0, -5681, 0, 27204, 0, -5680, 0, 27198, 0, -5679, 0, 27296, 0, -5678, 0, 27216, 0, -5677, 0, 27227, 0, -5676, 0, 27189, 0, -5675, 0, 27278, 0, -5674, 0, 27257, 0, -5673, 0, 27197, 0, -5672, 0, 27176, 0, -5671, 0, 27224, 0, -5670, 0, 27260, 0, -5669, 0, 27281, 0, -5668, 0, 27280, 0, -5667, 0, 27305, 0, -5666, 0, 27287, 0, -5665, 0, 27307, 0, -5664, 0, 29495, 0, -5663, 0, 29522, 0, -5662, 0, 27521, 0, -5661, 0, 27522, 0, -5660, 0, 27527, 0, -5659, 0, 27524, 0, -5658, 0, 27538, 0, -5657, 0, 27539, 0, -5656, 0, 27533, 0, -5655, 0, 27546, 0, -5654, 0, 27547, 0, -5653, 0, 27553, 0, -5652, 0, 27562, 0, -5651, 0, -28821, 0, -5650, 0, -28819, 0, -5649, 0, -28815, 0, -5648, 0, -28814, 0, -5647, 0, -28813, 0, -5646, 0, -28811, 0, -5645, 0, -28810, 0, -5644, 0, -28808, 0, -5643, 0, -28809, 0, -5642, 0, -28807, 0, -5641, 0, -28806, 0, -5640, 0, -28804, 0, -5639, 0, -28802, 0, -5638, 0, -28799, 0, -5637, 0, -28798, 0, -5636, 0, -28796, 0, -5635, 0, -28793, 0, -5634, 0, -28789, 0, -5471, 0, -28787, 0, -5470, 0, -28786, 0, -5469, 0, -28785, 0, -5468, 0, -28776, 0, -5467, 0, -28774, 0, -5466, 0, -28978, 0, -5465, 0, 25099, 0, -5464, 0, 25111, 0, -5463, 0, 25115, 0, -5462, 0, 25119, 0, -5461, 0, 25122, 0, -5460, 0, 25121, 0, -5459, 0, 25125, 0, -5458, 0, 25124, 0, -5457, 0, 25132, 0, -5456, 0, -32281, 0, -5455, 0, 29935, 0, -5454, 0, 29940, 0, -5453, 0, 29951, 0, -5452, 0, 29967, 0, -5451, 0, 29969, 0, -5450, 0, 29971, 0, -5449, 0, 25908, 0, -5448, 0, 26094, 0, -5447, 0, 26095, 0, -5446, 0, 26096, 0, -5445, 0, 26122, 0, -5444, 0, 26137, 0, -5443, 0, 26482, 0, -5442, 0, 26115, 0, -5441, 0, 26133, 0, -5440, 0, 26112, 0, -5439, 0, 28805, 0, -5438, 0, 26359, 0, -5437, 0, 26141, 0, -5436, 0, 26164, 0, -5435, 0, 26161, 0, -5434, 0, 26166, 0, -5433, 0, 26165, 0, -5432, 0, -32762, 0, -5431, 0, 26207, 0, -5430, 0, 26196, 0, -5429, 0, 26177, 0, -5428, 0, 26191, 0, -5427, 0, 26198, 0, -5426, 0, 26209, 0, -5425, 0, 26199, 0, -5424, 0, 26231, 0, -5423, 0, 26244, 0, -5422, 0, 26252, 0, -5421, 0, 26279, 0, -5420, 0, 26269, 0, -5419, 0, 26302, 0, -5418, 0, 26331, 0, -5417, 0, 26332, 0, -5416, 0, 26342, 0, -5415, 0, 26345, 0, -5414, 0, -29390, 0, -5413, 0, -29389, 0, -5412, 0, -29386, 0, -5411, 0, -29381, 0, -5410, 0, -29379, 0, -5409, 0, -29376, 0, -5408, 0, -29371, 0, -5407, 0, -29370, 0, -5406, 0, -29368, 0, -5405, 0, -29367, 0, -5404, 0, -29369, 0, -5403, 0, -29363, 0, -5402, 0, -29355, 0, -5401, 0, -29351, 0, -5400, 0, -30265, 0, -5399, 0, -30262, 0, -5398, 0, -30261, 0, -5397, 0, -30260, 0, -5396, 0, -30258, 0, -5395, 0, -30257, 0, -5394, 0, -30256, 0, -5393, 0, -30255, 0, -5392, 0, 29294, 0, -5391, 0, 29343, 0, -5390, 0, 29277, 0, -5389, 0, 29286, 0, -5388, 0, 29295, 0, -5387, 0, 29310, 0, -5386, 0, 29311, 0, -5385, 0, 29316, 0, -5384, 0, 29323, 0, -5383, 0, 29325, 0, -5382, 0, 29327, 0, -5381, 0, 29330, 0, -5380, 0, 25352, 0, -5379, 0, 25394, 0, -5378, 0, 25520, 0, -5215, 0, 25663, 0, -5214, 0, 25816, 0, -5213, 0, -32764, 0, -5212, 0, 27626, 0, -5211, 0, 27635, 0, -5210, 0, 27645, 0, -5209, 0, 27637, 0, -5208, 0, 27641, 0, -5207, 0, 27653, 0, -5206, 0, 27655, 0, -5205, 0, 27654, 0, -5204, 0, 27661, 0, -5203, 0, 27669, 0, -5202, 0, 27672, 0, -5201, 0, 27673, 0, -5200, 0, 27674, 0, -5199, 0, 27681, 0, -5198, 0, 27689, 0, -5197, 0, 27684, 0, -5196, 0, 27690, 0, -5195, 0, 27698, 0, -5194, 0, 25909, 0, -5193, 0, 25941, 0, -5192, 0, 25963, 0, -5191, 0, 29261, 0, -5190, 0, 29266, 0, -5189, 0, 29270, 0, -5188, 0, 29232, 0, -5187, 0, -31134, 0, -5186, 0, 21014, 0, -5185, 0, -32609, 0, -5184, 0, -32612, 0, -5183, 0, -32621, 0, -5182, 0, -32580, 0, -5181, 0, 26378, 0, -5180, 0, -32579, 0, -5179, 0, -32591, 0, -5178, 0, -32597, 0, -5177, 0, -32595, 0, -5176, 0, -32588, 0, -5175, 0, -32585, 0, -5174, 0, -32537, 0, -5173, 0, -32536, 0, -5172, 0, -32535, 0, -5171, 0, -32534, 0, -5170, 0, -32549, 0, -5169, 0, -32574, 0, -5168, 0, -32572, 0, -5167, 0, -32551, 0, -5166, 0, -32563, 0, -5165, 0, -32553, 0, -5164, 0, 26384, 0, -5163, 0, -32547, 0, -5162, 0, -32533, 0, -5161, 0, -32527, 0, -5160, 0, -32524, 0, -5159, 0, -32531, 0, -5158, 0, -32499, 0, -5157, 0, -32498, 0, -5156, 0, -32526, 0, -5155, 0, -32516, 0, -5154, 0, 26389, 0, -5153, 0, -32494, 0, -5152, 0, -29606, 0, -5151, 0, -32458, 0, -5150, 0, -32482, 0, -5149, 0, -32468, 0, -5148, 0, -32488, 0, -5147, 0, -32462, 0, -5146, 0, -32440, 0, -5145, 0, -32436, 0, -5144, 0, -32429, 0, -5143, 0, -32396, 0, -5142, 0, -32423, 0, -5141, 0, -32422, 0, -5140, 0, -32399, 0, -5139, 0, -32416, 0, -5138, 0, -32407, 0, -5137, 0, -32388, 0, -5136, 0, -32387, 0, -5135, 0, -32403, 0, -5134, 0, -32409, 0, -5133, 0, 22605, 0, -5132, 0, 23221, 0, -5131, 0, -32376, 0, -5130, 0, -32382, 0, -5129, 0, -32367, 0, -5128, 0, 28373, 0, -5127, 0, -32349, 0, -5126, 0, -32342, 0, -5125, 0, -32308, 0, -5124, 0, 26406, 0, -5123, 0, -32310, 0, -5122, 0, -32325, 0, -4959, 0, -32319, 0, -4958, 0, -32346, 0, -4957, 0, 27428, 0, -4956, 0, 27447, 0, -4955, 0, 27449, 0, -4954, 0, 27459, 0, -4953, 0, 27462, 0, -4952, 0, 27481, 0, -4951, 0, -26415, 0, -4950, 0, -26414, 0, -4949, 0, -26413, 0, -4948, 0, -26411, 0, -4947, 0, -26407, 0, -4946, 0, -26406, 0, -4945, 0, 27571, 0, -4944, 0, 24384, 0, -4943, 0, 27586, 0, -4942, 0, -30221, 0, -4941, 0, 26000, 0, -4940, 0, -24751, 0, -4939, 0, 26003, 0, -4938, 0, 26044, 0, -4937, 0, 26054, 0, -4936, 0, 26052, 0, -4935, 0, 26051, 0, -4934, 0, 26060, 0, -4933, 0, 26062, 0, -4932, 0, 26066, 0, -4931, 0, 26070, 0, -4930, 0, 28800, 0, -4929, 0, 28828, 0, -4928, 0, 28822, 0, -4927, 0, 28829, 0, -4926, 0, 28859, 0, -4925, 0, 28864, 0, -4924, 0, 28855, 0, -4923, 0, 28843, 0, -4922, 0, 28849, 0, -4921, 0, 28904, 0, -4920, 0, 28874, 0, -4919, 0, 28944, 0, -4918, 0, 28947, 0, -4917, 0, 28950, 0, -4916, 0, 28975, 0, -4915, 0, 28977, 0, -4914, 0, 29043, 0, -4913, 0, 29020, 0, -4912, 0, 29032, 0, -4911, 0, 28997, 0, -4910, 0, 29042, 0, -4909, 0, 29002, 0, -4908, 0, 29048, 0, -4907, 0, 29050, 0, -4906, 0, 29080, 0, -4905, 0, 29107, 0, -4904, 0, 29109, 0, -4903, 0, 29096, 0, -4902, 0, 29088, 0, -4901, 0, 29152, 0, -4900, 0, 29140, 0, -4899, 0, 29159, 0, -4898, 0, 29177, 0, -4897, 0, 29213, 0, -4896, 0, 29224, 0, -4895, 0, 28780, 0, -4894, 0, 28952, 0, -4893, 0, 29030, 0, -4892, 0, 29113, 0, -4891, 0, 25150, 0, -4890, 0, 25149, 0, -4889, 0, 25155, 0, -4888, 0, 25160, 0, -4887, 0, 25161, 0, -4886, 0, 31035, 0, -4885, 0, 31040, 0, -4884, 0, 31046, 0, -4883, 0, 31049, 0, -4882, 0, 31067, 0, -4881, 0, 31068, 0, -4880, 0, 31059, 0, -4879, 0, 31066, 0, -4878, 0, 31074, 0, -4877, 0, 31063, 0, -4876, 0, 31072, 0, -4875, 0, 31087, 0, -4874, 0, 31079, 0, -4873, 0, 31098, 0, -4872, 0, 31109, 0, -4871, 0, 31114, 0, -4870, 0, 31130, 0, -4869, 0, 31143, 0, -4868, 0, 31155, 0, -4867, 0, 24529, 0, -4866, 0, 24528, 0, -4703, 0, 24636, 0, -4702, 0, 24669, 0, -4701, 0, 24666, 0, -4700, 0, 24679, 0, -4699, 0, 24641, 0, -4698, 0, 24665, 0, -4697, 0, 24675, 0, -4696, 0, 24747, 0, -4695, 0, 24838, 0, -4694, 0, 24845, 0, -4693, 0, 24925, 0, -4692, 0, 25001, 0, -4691, 0, 24989, 0, -4690, 0, 25035, 0, -4689, 0, 25041, 0, -4688, 0, 25094, 0, -4687, 0, -32640, 0, -4686, 0, -32641, 0, -4685, 0, 27795, 0, -4684, 0, 27894, 0, -4683, 0, 28156, 0, -4682, 0, 30710, 0, -4681, 0, 30712, 0, -4680, 0, 30720, 0, -4679, 0, 30729, 0, -4678, 0, 30743, 0, -4677, 0, 30744, 0, -4676, 0, 30737, 0, -4675, 0, 26027, 0, -4674, 0, 30765, 0, -4673, 0, 30748, 0, -4672, 0, 30749, 0, -4671, 0, 30777, 0, -4670, 0, 30778, 0, -4669, 0, 30779, 0, -4668, 0, 30751, 0, -4667, 0, 30780, 0, -4666, 0, 30757, 0, -4665, 0, 30764, 0, -4664, 0, 30755, 0, -4663, 0, 30761, 0, -4662, 0, 30798, 0, -4661, 0, 30829, 0, -4660, 0, 30806, 0, -4659, 0, 30807, 0, -4658, 0, 30758, 0, -4657, 0, 30800, 0, -4656, 0, 30791, 0, -4655, 0, 30796, 0, -4654, 0, 30826, 0, -4653, 0, 30875, 0, -4652, 0, 30867, 0, -4651, 0, 30874, 0, -4650, 0, 30855, 0, -4649, 0, 30876, 0, -4648, 0, 30881, 0, -4647, 0, 30883, 0, -4646, 0, 30898, 0, -4645, 0, 30905, 0, -4644, 0, 30885, 0, -4643, 0, 30932, 0, -4642, 0, 30937, 0, -4641, 0, 30921, 0, -4640, 0, 30956, 0, -4639, 0, 30962, 0, -4638, 0, 30981, 0, -4637, 0, 30964, 0, -4636, 0, 30995, 0, -4635, 0, 31012, 0, -4634, 0, 31006, 0, -4633, 0, 31028, 0, -4632, 0, -24677, 0, -4631, 0, -24839, 0, -4630, 0, -24837, 0, -4629, 0, -24836, 0, -4628, 0, 30449, 0, -4627, 0, 30468, 0, -4626, 0, 30477, 0, -4625, 0, 30457, 0, -4624, 0, 30471, 0, -4623, 0, 30472, 0, -4622, 0, 30490, 0, -4621, 0, 30498, 0, -4620, 0, 30489, 0, -4619, 0, 30509, 0, -4618, 0, 30502, 0, -4617, 0, 30517, 0, -4616, 0, 30520, 0, -4615, 0, 30544, 0, -4614, 0, 30545, 0, -4613, 0, 30535, 0, -4612, 0, 30531, 0, -4611, 0, 30554, 0, -4610, 0, 30568, 0, -4447, 0, 30562, 0, -4446, 0, 30565, 0, -4445, 0, 30591, 0, -4444, 0, 30605, 0, -4443, 0, 30589, 0, -4442, 0, 30592, 0, -4441, 0, 30604, 0, -4440, 0, 30609, 0, -4439, 0, 30623, 0, -4438, 0, 30624, 0, -4437, 0, 30640, 0, -4436, 0, 30645, 0, -4435, 0, 30653, 0, -4434, 0, 30010, 0, -4433, 0, 30016, 0, -4432, 0, 30030, 0, -4431, 0, 30027, 0, -4430, 0, 30024, 0, -4429, 0, 30043, 0, -4428, 0, 30066, 0, -4427, 0, 30073, 0, -4426, 0, 30083, 0, -4425, 0, 32600, 0, -4424, 0, 32609, 0, -4423, 0, 32607, 0, -4422, 0, -30136, 0, -4421, 0, 32616, 0, -4420, 0, 32628, 0, -4419, 0, 32625, 0, -4418, 0, 32633, 0, -4417, 0, 32641, 0, -4416, 0, 32638, 0, -4415, 0, 30413, 0, -4414, 0, 30437, 0, -4413, 0, -30670, 0, -4412, 0, -27515, 0, -4411, 0, -27514, 0, -4410, 0, -27513, 0, -4409, 0, -27509, 0, -4408, 0, -27510, 0, -4407, 0, -27508, 0, -4406, 0, -27507, 0, -4405, 0, -27505, 0, -4404, 0, -27504, 0, -4403, 0, -27500, 0, -4402, 0, -27497, 0, -4401, 0, -27499, 0, -4400, 0, -27494, 0, -4399, 0, -27493, 0, -4398, 0, -27492, 0, -4397, 0, -27485, 0, -4396, 0, -27484, 0, -4395, 0, -27477, 0, -4394, 0, -27478, 0, -4393, 0, -27475, 0, -4392, 0, -27476, 0, -4391, 0, -27473, 0, -4390, 0, -27472, 0, -4389, 0, -27470, 0, -4388, 0, -27468, 0, -4387, 0, -27466, 0, -4386, 0, -27465, 0, -4385, 0, -27464, 0, -4384, 0, -27463, 0, -4383, 0, -27462, 0, -4382, 0, -27460, 0, -4381, 0, -27459, 0, -4380, 0, -27457, 0, -4379, 0, -27452, 0, -4378, 0, -27448, 0, -4377, 0, -27447, 0, -4376, 0, -27446, 0, -4375, 0, -27445, 0, -4374, 0, -27444, 0, -4373, 0, -27443, 0, -4372, 0, -27442, 0, -4371, 0, -27440, 0, -4370, 0, -27439, 0, -4369, 0, -27438, 0, -4368, 0, -27435, 0, -4367, 0, -27434, 0, -4366, 0, -27433, 0, -4365, 0, -27431, 0, -4364, 0, -27432, 0, -4363, 0, -27429, 0, -4362, 0, -27426, 0, -4361, 0, -27425, 0, -4360, 0, -27424, 0, -4359, 0, -27422, 0, -4358, 0, -27420, 0, -4357, 0, -27419, 0, -4356, 0, -27417, 0, -4355, 0, -27416, 0, -4354, 0, -27414, 0, -4191, 0, -27415, 0, -4190, 0, -27413, 0, -4189, 0, -27410, 0, -4188, 0, -27409, 0, -4187, 0, -27405, 0, -4186, 0, -27404, 0, -4185, 0, -27403, 0, -4184, 0, -27401, 0, -4183, 0, -27399, 0, -4182, 0, -27396, 0, -4181, 0, -27395, 0, -4180, 0, -27393, 0, -4179, 0, -27389, 0, -4178, 0, -27390, 0, -4177, 0, -27386, 0, -4176, 0, -27385, 0, -4175, 0, -27383, 0, -4174, 0, -27382, 0, -4173, 0, -27379, 0, -4172, 0, -27378, 0, -4171, 0, -27377, 0, -4170, 0, -27374, 0, -4169, 0, -27373, 0, -4168, 0, -27372, 0, -4167, 0, -27371, 0, -4166, 0, -27370, 0, -4165, 0, -27368, 0, -4164, 0, -27365, 0, -4163, 0, -27363, 0, -4162, 0, -27362, 0, -4161, 0, -27361, 0, -4160, 0, -27358, 0, -4159, 0, -27350, 0, -4158, 0, -27349, 0, -4157, 0, -27351, 0, -4156, 0, -27348, 0, -4155, 0, -27343, 0, -4154, 0, -27342, 0, -4153, 0, -27340, 0, -4152, 0, -27338, 0, -4151, 0, -27337, 0, -4150, 0, -27336, 0, -4149, 0, -27332, 0, -4148, 0, -27330, 0, -4147, 0, -27329, 0, -4146, 0, -27326, 0, -4145, 0, -27339, 0, -4144, 0, -27324, 0, -4143, 0, -27323, 0, -4142, 0, -27322, 0, -4141, 0, -27319, 0, -4140, 0, -27316, 0, -4139, 0, -27314, 0, -4138, 0, -27313, 0, -4137, 0, -27310, 0, -4136, 0, -27309, 0, -4135, 0, -27308, 0, -4134, 0, -27306, 0, -4133, 0, -27305, 0, -4132, 0, -27304, 0, -4131, 0, -27303, 0, -4130, 0, -27301, 0, -4129, 0, -27298, 0, -4128, 0, -27297, 0, -4127, 0, -27299, 0, -4126, 0, -27295, 0, -4125, 0, -27294, 0, -4124, 0, -27292, 0, -4123, 0, -27291, 0, -4122, 0, -27290, 0, -4121, 0, -27289, 0, -4120, 0, -27288, 0, -4119, 0, -27287, 0, -4118, 0, -27286, 0, -4117, 0, -27285, 0, -4116, 0, -27284, 0, -4115, 0, -27281, 0, -4114, 0, -27279, 0, -4113, 0, -27278, 0, -4112, 0, -27277, 0, -4111, 0, -27334, 0, -4110, 0, 30695, 0, -4109, 0, 30700, 0, -4108, 0, -26935, 0, -4107, 0, 31189, 0, -4106, 0, 31213, 0, -4105, 0, 31203, 0, -4104, 0, 31211, 0, -4103, 0, 31238, 0, -4102, 0, 23879, 0, -4101, 0, 31235, 0, -4100, 0, 31234, 0, -4099, 0, 31262, 0, -4098, 0, 31252, 0, -3935, 0, 31289, 0, -3934, 0, 31287, 0, -3933, 0, 31313, 0, -3932, 0, -24881, 0, -3931, 0, -26203, 0, -3930, 0, 31344, 0, -3929, 0, 30344, 0, -3928, 0, 30350, 0, -3927, 0, 30355, 0, -3926, 0, 30361, 0, -3925, 0, 30372, 0, -3924, 0, 29918, 0, -3923, 0, 29920, 0, -3922, 0, 29996, 0, -3921, 0, -25056, 0, -3920, 0, -25054, 0, -3919, 0, -25048, 0, -3918, 0, -25047, 0, -3917, 0, -25046, 0, -3916, 0, -25045, 0, -3915, 0, -25044, 0, -3914, 0, -25038, 0, -3913, 0, -25039, 0, -3912, 0, -25034, 0, -3911, 0, -25032, 0, -3910, 0, -25033, 0, -3909, 0, -25031, 0, -3908, 0, -25030, 0, -3907, 0, -25026, 0, -3906, 0, -25023, 0, -3905, 0, -25022, 0, -3904, 0, -25020, 0, -3903, 0, -25018, 0, -3902, 0, -25017, 0, -3901, 0, -25016, 0, -3900, 0, -25015, 0, -3899, 0, -25013, 0, -3898, 0, -25012, 0, -3897, 0, -25010, 0, -3896, 0, -25007, 0, -3895, 0, -25003, 0, -3894, 0, -25001, 0, -3893, 0, -24998, 0, -3892, 0, -24997, 0, -3891, 0, -24996, 0, -3890, 0, -24994, 0, -3889, 0, -24989, 0, -3888, 0, -24986, 0, -3887, 0, -24985, 0, -3886, 0, -24984, 0, -3885, 0, -24983, 0, -3884, 0, -24982, 0, -3883, 0, -24981, 0, -3882, 0, -24980, 0, -3881, 0, -24975, 0, -3880, 0, -24979, 0, -3879, 0, -24973, 0, -3878, 0, 30098, 0, -3877, 0, 30100, 0, -3876, 0, 30102, 0, -3875, 0, 30112, 0, -3874, 0, 30109, 0, -3873, 0, 30124, 0, -3872, 0, 30115, 0, -3871, 0, 30131, 0, -3870, 0, 30132, 0, -3869, 0, 30136, 0, -3868, 0, 30148, 0, -3867, 0, 30129, 0, -3866, 0, 30128, 0, -3865, 0, 30147, 0, -3864, 0, 30146, 0, -3863, 0, 30166, 0, -3862, 0, 30157, 0, -3861, 0, 30179, 0, -3860, 0, 30184, 0, -3859, 0, 30182, 0, -3858, 0, 30180, 0, -3857, 0, 30187, 0, -3856, 0, 30183, 0, -3855, 0, 30211, 0, -3854, 0, 30193, 0, -3853, 0, 30204, 0, -3852, 0, 30207, 0, -3851, 0, 30224, 0, -3850, 0, 30208, 0, -3849, 0, 30213, 0, -3848, 0, 30220, 0, -3847, 0, 30231, 0, -3846, 0, 30218, 0, -3845, 0, 30245, 0, -3844, 0, 30232, 0, -3843, 0, 30229, 0, -3842, 0, 30233, 0, -3679, 0, 30235, 0, -3678, 0, 30268, 0, -3677, 0, 30242, 0, -3676, 0, 30240, 0, -3675, 0, 30272, 0, -3674, 0, 30253, 0, -3673, 0, 30256, 0, -3672, 0, 30271, 0, -3671, 0, 30261, 0, -3670, 0, 30275, 0, -3669, 0, 30270, 0, -3668, 0, 30259, 0, -3667, 0, 30285, 0, -3666, 0, 30302, 0, -3665, 0, 30292, 0, -3664, 0, 30300, 0, -3663, 0, 30294, 0, -3662, 0, 30315, 0, -3661, 0, 30319, 0, -3660, 0, 32714, 0, -3659, 0, 31462, 0, -3658, 0, 31352, 0, -3657, 0, 31353, 0, -3656, 0, 31360, 0, -3655, 0, 31366, 0, -3654, 0, 31368, 0, -3653, 0, 31381, 0, -3652, 0, 31398, 0, -3651, 0, 31392, 0, -3650, 0, 31404, 0, -3649, 0, 31400, 0, -3648, 0, 31405, 0, -3647, 0, 31411, 0, -3646, 0, -30620, 0, -3645, 0, -30615, 0, -3644, 0, -30606, 0, -3643, 0, -30595, 0, -3642, 0, -30593, 0, -3641, 0, -30590, 0, -3640, 0, -30558, 0, -3639, 0, -30522, 0, -3638, 0, -30537, 0, -3637, 0, -30532, 0, -3636, 0, -30519, 0, -3635, 0, -30494, 0, -3634, 0, -30514, 0, -3633, 0, -30493, 0, -3632, 0, -30491, 0, -3631, 0, -30479, 0, -3630, 0, -30438, 0, -3629, 0, -30468, 0, -3628, 0, -30488, 0, -3627, 0, -30466, 0, -3626, 0, -30480, 0, -3625, 0, -30431, 0, -3624, 0, -30439, 0, -3623, 0, -30445, 0, -3622, 0, -30437, 0, -3621, 0, -30454, 0, -3620, 0, -30412, 0, -3619, 0, -30421, 0, -3618, 0, -30410, 0, -3617, 0, -30399, 0, -3616, 0, -30362, 0, -3615, 0, -30341, 0, -3614, 0, 30091, 0, -3613, 0, -32539, 0, -3612, 0, 30386, 0, -3611, 0, 30388, 0, -3610, 0, 30684, 0, -3609, 0, -32750, 0, -3608, 0, -32748, 0, -3607, 0, -32746, 0, -3606, 0, -32740, 0, -3605, 0, -32736, 0, -3604, 0, -32734, 0, -3603, 0, -32731, 0, -3602, 0, -32730, 0, -3601, 0, -32729, 0, -3600, 0, -32727, 0, -3599, 0, -32728, 0, -3598, 0, -32719, 0, -3597, 0, -32757, 0, -3596, 0, -32715, 0, -3595, 0, -32701, 0, -3594, 0, -32698, 0, -3593, 0, -32691, 0, -3592, 0, -32686, 0, -3591, 0, -32663, 0, -3590, 0, -32655, 0, -3589, 0, -30333, 0, -3588, 0, -26504, 0, -3587, 0, -26496, 0, -3586, 0, -26493, 0, -3423, 0, -26487, 0, -3422, 0, -26484, 0, -3421, 0, -26483, 0, -3420, 0, -26481, 0, -3419, 0, -26476, 0, -3418, 0, -26470, 0, -3417, 0, -26469, 0, -3416, 0, -26466, 0, -3415, 0, -26465, 0, -3414, 0, -26463, 0, -3413, 0, -26462, 0, -3412, 0, -26459, 0, -3411, 0, -26458, 0, -3410, 0, -31155, 0, -3409, 0, -31148, 0, -3408, 0, -31124, 0, -3407, 0, -31122, 0, -3406, 0, -31105, 0, -3405, 0, -31110, 0, -3404, 0, -31108, 0, -3403, 0, -31109, 0, -3402, 0, -31064, 0, -3401, 0, -31091, 0, -3400, 0, -31093, 0, -3399, 0, -31060, 0, -3398, 0, -31075, 0, -3397, 0, -31065, 0, -3396, 0, -31069, 0, -3395, 0, -31062, 0, -3394, 0, -31085, 0, -3393, 0, -31063, 0, -3392, 0, -31050, 0, -3391, 0, -31036, 0, -3390, 0, -31051, 0, -3389, 0, -31026, 0, -3388, 0, -31056, 0, -3387, 0, -31046, 0, -3386, 0, -31055, 0, -3385, 0, -31057, 0, -3384, 0, -31031, 0, -3383, 0, -31025, 0, -3382, 0, -31052, 0, -3381, 0, -30999, 0, -3380, 0, -30991, 0, -3379, 0, -30990, 0, -3378, 0, -30995, 0, -3377, 0, -30989, 0, -3376, 0, -31024, 0, -3375, 0, -30957, 0, -3374, 0, -31010, 0, -3373, 0, -30988, 0, -3372, 0, -31009, 0, -3371, 0, -31016, 0, -3370, 0, -31023, 0, -3369, 0, -30973, 0, -3368, 0, -30969, 0, -3367, 0, -30984, 0, -3366, 0, -30968, 0, -3365, 0, -30966, 0, -3364, 0, -30963, 0, -3363, 0, -30967, 0, -3362, 0, -30941, 0, -3361, 0, -30917, 0, -3360, 0, -30946, 0, -3359, 0, -30939, 0, -3358, 0, -30930, 0, -3357, 0, -30950, 0, -3356, 0, -30914, 0, -3355, 0, -30904, 0, -3354, 0, -30924, 0, -3353, 0, -30927, 0, -3352, 0, -30935, 0, -3351, 0, -30921, 0, -3350, 0, -30913, 0, -3349, 0, -30846, 0, -3348, 0, -30942, 0, -3347, 0, -30851, 0, -3346, 0, -30850, 0, -3345, 0, -30853, 0, -3344, 0, -30880, 0, -3343, 0, -30864, 0, -3342, 0, -30900, 0, -3341, 0, -30866, 0, -3340, 0, -30837, 0, -3339, 0, -30893, 0, -3338, 0, -30877, 0, -3337, 0, -30852, 0, -3336, 0, -30876, 0, -3335, 0, -30887, 0, -3334, 0, -30875, 0, -3333, 0, -30829, 0, -3332, 0, -30801, 0, -3331, 0, -30808, 0, -3330, 0, -30766, 0, -3167, 0, -30778, 0, -3166, 0, -30840, 0, -3165, 0, -30843, 0, -3164, 0, -30803, 0, -3163, 0, -30825, 0, -3162, 0, -30845, 0, -3161, 0, -30805, 0, -3160, 0, -30747, 0, -3159, 0, -30804, 0, -3158, 0, -30795, 0, -3157, 0, -30797, 0, -3156, 0, -30773, 0, -3155, 0, -30765, 0, -3154, 0, -30787, 0, -3153, 0, -30767, 0, -3152, 0, -30784, 0, -3151, 0, -30774, 0, -3150, 0, -30757, 0, -3149, 0, -30742, 0, -3148, 0, -30752, 0, -3147, 0, -30738, 0, -3146, 0, -30698, 0, -3145, 0, -30701, 0, -3144, 0, -30722, 0, -3143, 0, -30710, 0, -3142, 0, -30693, 0, -3141, 0, -30687, 0, -3140, 0, -30663, 0, -3139, 0, -30660, 0, -3138, 0, 32566, 0, -3137, 0, 32578, 0, -3136, 0, 32580, 0, -3135, 0, 32581, 0, -3134, 0, -32240, 0, -3133, 0, 31482, 0, -3132, 0, 31485, 0, -3131, 0, 31496, 0, -3130, 0, 31491, 0, -3129, 0, 31492, 0, -3128, 0, 31509, 0, -3127, 0, 31498, 0, -3126, 0, 31531, 0, -3125, 0, 31503, 0, -3124, 0, 31559, 0, -3123, 0, 31544, 0, -3122, 0, 31530, 0, -3121, 0, 31513, 0, -3120, 0, 31534, 0, -3119, 0, 31537, 0, -3118, 0, 31520, 0, -3117, 0, 31525, 0, -3116, 0, 31524, 0, -3115, 0, 31539, 0, -3114, 0, 31550, 0, -3113, 0, 31518, 0, -3112, 0, 31576, 0, -3111, 0, 31578, 0, -3110, 0, 31557, 0, -3109, 0, 31605, 0, -3108, 0, 31564, 0, -3107, 0, 31581, 0, -3106, 0, 31584, 0, -3105, 0, 31598, 0, -3104, 0, 31611, 0, -3103, 0, 31586, 0, -3102, 0, 31602, 0, -3101, 0, 31601, 0, -3100, 0, 31632, 0, -3099, 0, 31654, 0, -3098, 0, 31655, 0, -3097, 0, 31672, 0, -3096, 0, 31660, 0, -3095, 0, 31645, 0, -3094, 0, 31656, 0, -3093, 0, 31621, 0, -3092, 0, 31658, 0, -3091, 0, 31644, 0, -3090, 0, 31650, 0, -3089, 0, 31659, 0, -3088, 0, 31668, 0, -3087, 0, 31697, 0, -3086, 0, 31681, 0, -3085, 0, 31692, 0, -3084, 0, 31709, 0, -3083, 0, 31706, 0, -3082, 0, 31717, 0, -3081, 0, 31718, 0, -3080, 0, 31722, 0, -3079, 0, 31756, 0, -3078, 0, 31742, 0, -3077, 0, 31740, 0, -3076, 0, 31759, 0, -3075, 0, 31766, 0, -3074, 0, 31755, 0, -2911, 0, 31775, 0, -2910, 0, 31786, 0, -2909, 0, 31782, 0, -2908, 0, 31800, 0, -2907, 0, 31809, 0, -2906, 0, 31808, 0, -2905, 0, -32258, 0, -2904, 0, -32255, 0, -2903, 0, -32254, 0, -2902, 0, -32252, 0, -2901, 0, -32276, 0, -2900, 0, -30652, 0, -2899, 0, -32223, 0, -2898, 0, -32222, 0, -2897, 0, -32221, 0, -2896, 0, -32211, 0, -2895, 0, -32209, 0, -2894, 0, -32216, 0, -2893, 0, -32213, 0, -2892, 0, -32200, 0, -2891, 0, -32197, 0, -2890, 0, -32205, 0, -2889, 0, -32204, 0, -2888, 0, -32194, 0, -2887, 0, -32188, 0, -2886, 0, -32183, 0, -2885, 0, -32181, 0, -2884, 0, -32177, 0, -2883, 0, -32166, 0, -2882, 0, -32161, 0, -2881, 0, -32152, 0, -2880, 0, -30594, 0, -2879, 0, -30587, 0, -2878, 0, -30584, 0, -2877, 0, -30504, 0, -2876, 0, -30497, 0, -2875, 0, -30370, 0, -2874, 0, 32669, 0, -2873, 0, 32671, 0, -2872, 0, 32679, 0, -2871, 0, 32687, 0, -2870, 0, 32688, 0, -2869, 0, 32690, 0, -2868, 0, 31868, 0, -2867, 0, 25929, 0, -2866, 0, 31889, 0, -2865, 0, 31901, 0, -2864, 0, 31900, 0, -2863, 0, 31902, 0, -2862, 0, 31906, 0, -2861, 0, 31922, 0, -2860, 0, 31932, 0, -2859, 0, 31933, 0, -2858, 0, 31937, 0, -2857, 0, 31943, 0, -2856, 0, 31948, 0, -2855, 0, 31949, 0, -2854, 0, 31944, 0, -2853, 0, 31941, 0, -2852, 0, 31959, 0, -2851, 0, 31976, 0, -2850, 0, -32146, 0, -2849, 0, 26280, 0, -2848, 0, 32703, 0, -2847, 0, 32718, 0, -2846, 0, 32725, 0, -2845, 0, 32741, 0, -2844, 0, 32737, 0, -2843, 0, 32742, 0, -2842, 0, 32745, 0, -2841, 0, 32750, 0, -2840, 0, 32755, 0, -2839, 0, 31992, 0, -2838, 0, 32119, 0, -2837, 0, 32166, 0, -2836, 0, 32174, 0, -2835, 0, 32327, 0, -2834, 0, 32411, 0, -2833, 0, -24904, 0, -2832, 0, -24908, 0, -2831, 0, -29325, 0, -2830, 0, -29308, 0, -2829, 0, -29292, 0, -2828, 0, -29295, 0, -2827, 0, -29263, 0, -2826, 0, -29337, 0, -2825, 0, -29331, 0, -2824, 0, -29625, 0, -2823, 0, -29623, 0, -2822, 0, -28342, 0, -2821, 0, -28336, 0, -2820, 0, -28338, 0, -2819, 0, -28337, 0, -2818, 0, -28316, 0, -2655, 0, -28318, 0, -2654, 0, -28319, 0, -2653, 0, -28304, 0, -2652, 0, -28311, 0, -2651, 0, -28305, 0, -2650, 0, -28291, 0, -2649, 0, -28290, 0, -2648, 0, -28302, 0, -2647, 0, -28300, 0, -2646, 0, -28295, 0, -2645, 0, -28276, 0, -2644, 0, -28283, 0, -2643, 0, -28272, 0, -2642, 0, -28275, 0, -2641, 0, -28271, 0, -2640, 0, -28254, 0, -2639, 0, -28253, 0, -2638, 0, -28246, 0, -2637, 0, -28243, 0, -2636, 0, -28242, 0, -2635, 0, -28241, 0, -2634, 0, -28235, 0, -2633, 0, -28236, 0, -2632, 0, -28230, 0, -2631, 0, -29611, 0, -2630, 0, -24962, 0, -2629, 0, -29256, 0, -2628, 0, -29205, 0, -2627, 0, -29179, 0, -2626, 0, -29095, 0, -2625, 0, -29079, 0, -2624, 0, -29259, 0, -2623, 0, -29249, 0, -2622, 0, -29252, 0, -2621, 0, -29254, 0, -2620, 0, -29244, 0, -2619, 0, -29226, 0, -2618, 0, -29225, 0, -2617, 0, -29222, 0, -2616, 0, -29218, 0, -2615, 0, -29234, 0, -2614, 0, -29233, 0, -2613, 0, -29221, 0, -2612, 0, -29242, 0, -2611, 0, -29204, 0, -2610, 0, -29193, 0, -2609, 0, -29192, 0, -2608, 0, -29213, 0, -2607, 0, -29191, 0, -2606, 0, -29189, 0, -2605, 0, -29212, 0, -2604, 0, -29175, 0, -2603, 0, -29187, 0, -2602, 0, -29164, 0, -2601, 0, -29155, 0, -2600, 0, -29153, 0, -2599, 0, -29140, 0, -2598, 0, -29138, 0, -2597, 0, -29149, 0, -2596, 0, -29137, 0, -2595, 0, -29126, 0, -2594, 0, -29120, 0, -2593, 0, -29127, 0, -2592, 0, -29131, 0, -2591, 0, -29123, 0, -2590, 0, -29135, 0, -2589, 0, -29111, 0, -2588, 0, -29119, 0, -2587, 0, -29118, 0, -2586, 0, -29103, 0, -2585, 0, -29102, 0, -2584, 0, -29110, 0, -2583, 0, -29072, 0, -2582, 0, -29066, 0, -2581, 0, -29060, 0, -2580, 0, -29073, 0, -2579, 0, -29068, 0, -2578, 0, -29051, 0, -2577, 0, -29041, 0, -2576, 0, -29036, 0, -2575, 0, -29040, 0, -2574, 0, -29028, 0, -2573, 0, -29026, 0, -2572, 0, -29576, 0, -2571, 0, -29566, 0, -2570, 0, -29558, 0, -2569, 0, -29563, 0, -2568, 0, -29544, 0, -2567, 0, -29548, 0, -2566, 0, 26011, 0, -2565, 0, -30250, 0, -2564, 0, -30242, 0, -2563, 0, -30246, 0, -2562, 0, -30244, 0, -2399, 0, -30235, 0, -2398, 0, -30229, 0, -2397, 0, -30225, 0, -2396, 0, -30146, 0, -2395, 0, -29914, 0, -2394, 0, -26797, 0, -2393, 0, -26903, 0, -2392, 0, -26893, 0, -2391, 0, -26897, 0, -2390, 0, -26874, 0, -2389, 0, -26879, 0, -2388, 0, -26872, 0, -2387, 0, -26865, 0, -2386, 0, -26866, 0, -2385, 0, -26838, 0, -2384, 0, -26835, 0, -2383, 0, -26832, 0, -2382, 0, -26818, 0, -2381, 0, -24704, 0, -2380, 0, -24701, 0, -2379, 0, -24699, 0, -2378, 0, -24698, 0, -2377, 0, -24697, 0, -2376, 0, -24696, 0, -2375, 0, -24695, 0, -2374, 0, -24694, 0, -2373, 0, -24692, 0, -2372, 0, -24834, 0, -2371, 0, -24821, 0, -2370, 0, -24819, 0, -2369, 0, -26951, 0, -2368, 0, -26948, 0, -2367, 0, -26947, 0, -2366, 0, -26930, 0, -2365, 0, -26926, 0, -2364, 0, 30655, 0, -2363, 0, -26912, 0, -2362, 0, -28018, 0, -2361, 0, -27986, 0, -2360, 0, -27960, 0, -2359, 0, -27842, 0, -2358, 0, -27798, 0, -2357, 0, -27702, 0, -2356, 0, -27761, 0, -2355, 0, -27586, 0, -2354, 0, -27541, 0, -2353, 0, -25473, 0, -2352, 0, -25470, 0, -2351, 0, -25467, 0, -2350, 0, -25466, 0, -2349, 0, -25465, 0, -2348, 0, -25464, 0, -2347, 0, 31267, 0, -2346, 0, -25461, 0, -2345, 0, -25458, 0, -2344, 0, -25456, 0, -2343, 0, -25455, 0, -2342, 0, -25454, 0, -2341, 0, -25452, 0, -2340, 0, -25451, 0, -2339, 0, -25446, 0, -2338, 0, -25445, 0, -2337, 0, -25442, 0, -2336, 0, -25441, 0, -2335, 0, -25440, 0, -2334, 0, -25439, 0, -2333, 0, -25438, 0, -2332, 0, -25437, 0, -2331, 0, -25435, 0, -2330, 0, -25434, 0, -2329, 0, -25433, 0, -2328, 0, -25432, 0, -2327, 0, -25431, 0, -2326, 0, -25429, 0, -2325, 0, -25427, 0, -2324, 0, -25426, 0, -2323, 0, -25424, 0, -2322, 0, -25423, 0, -2321, 0, -25422, 0, -2320, 0, -25421, 0, -2319, 0, -25420, 0, -2318, 0, -25419, 0, -2317, 0, -25418, 0, -2316, 0, -25417, 0, -2315, 0, -25414, 0, -2314, 0, -25413, 0, -2313, 0, -25412, 0, -2312, 0, -25411, 0, -2311, 0, -25404, 0, -2310, 0, -25403, 0, -2309, 0, -25402, 0, -2308, 0, -25401, 0, -2307, 0, -25398, 0, -2306, 0, -25397, 0, -2143, 0, -25396, 0, -2142, 0, -25395, 0, -2141, 0, -25394, 0, -2140, 0, -25393, 0, -2139, 0, -25392, 0, -2138, 0, -25389, 0, -2137, 0, -25388, 0, -2136, 0, -25387, 0, -2135, 0, -25385, 0, -2134, 0, -25384, 0, -2133, 0, -25383, 0, -2132, 0, -25380, 0, -2131, 0, -25379, 0, -2130, 0, -25377, 0, -2129, 0, -25374, 0, -2128, 0, -26756, 0, -2127, 0, -26747, 0, -2126, 0, -26735, 0, -2125, 0, -26734, 0, -2124, 0, -26732, 0, -2123, 0, -26705, 0, -2122, 0, -26709, 0, -2121, 0, -26717, 0, -2120, 0, -26702, 0, -2119, 0, -26700, 0, -2118, 0, -25935, 0, -2117, 0, -25936, 0, -2116, 0, -25929, 0, -2115, 0, -25000, 0, -2114, 0, -25930, 0, -2113, 0, -25926, 0, -2112, 0, -25924, 0, -2111, 0, -25919, 0, -2110, 0, -25920, 0, -2109, 0, -25915, 0, -2108, 0, -25918, 0, -2107, 0, -25909, 0, -2106, 0, -25908, 0, -2105, 0, -25903, 0, -2104, 0, -25787, 0, -2103, 0, -25789, 0, -2102, 0, -25785, 0, -2101, 0, -25783, 0, -2100, 0, -25784, 0, -2099, 0, -25779, 0, -2098, 0, -25775, 0, -2097, 0, -26392, 0, -2096, 0, -26355, 0, -2095, 0, -26322, 0, -2094, 0, -26283, 0, -2093, 0, -26284, 0, -2092, 0, -25889, 0, -2091, 0, -25887, 0, -2090, 0, -25882, 0, -2089, 0, -25873, 0, -2088, 0, -25877, 0, -2087, 0, -25861, 0, -2086, 0, -25875, 0, -2085, 0, -25863, 0, -2084, 0, -25848, 0, -2083, 0, -25841, 0, -2082, 0, -25837, 0, -2081, 0, -25825, 0, -2080, 0, -25821, 0, -2079, 0, -24899, 0, -2078, 0, -24898, 0, -2077, 0, 32315, 0, -2076, 0, -24958, 0, -2075, 0, -24953, 0, -2074, 0, -24952, 0, -2073, 0, -24949, 0, -2072, 0, -24942, 0, -2071, 0, -27690, 0, -2070, 0, -24931, 0, -2069, 0, -24929, 0, -2068, 0, -24869, 0, -2067, 0, -24868, 0, -2066, 0, -24867, 0, -2065, 0, -24864, 0, -2064, 0, -24865, 0, -2063, 0, -24862, 0, -2062, 0, -24855, 0, -2061, 0, -24857, 0, -2060, 0, -24859, 0, -2059, 0, -24854, 0, -2058, 0, -24849, 0, -2057, 0, -24798, 0, -2056, 0, -24788, 0, -2055, 0, -24785, 0, -2054, 0, -24775, 0, -2053, 0, -24777, 0, -2052, 0, -24771, 0, -2051, 0, -24770, 0, -1, 0, -1, 0], ["i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0], ALLOC_STATIC);
STRING_TABLE.__str41077=allocate([65,100,111,98,101,0] /* Adobe\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str51078=allocate([71,66,49,0] /* GB1\00 */, "i8", ALLOC_STATIC);
_GB_EUC_AddCodeSpaceRange_code_space_range1=allocate([0, 0, 128, 0, 0, 0], ["i16",0,"i16",0,"i16",0], ALLOC_STATIC);
_GB_EUC_AddCodeSpaceRange_code_space_range2=allocate([-24159, 0, -258, 0, 0, 0], ["i16",0,"i16",0,"i16",0], ALLOC_STATIC);
_CMAP_ARRAY_GBK_EUC_H=allocate([32, 0, 32, 0, 7716, 0, 33, 0, 126, 0, 814, 0, -32448, 0, -32392, 0, 10072, 0, -32391, 0, -32391, 0, 8281, 0, -32390, 0, -32386, 0, 10129, 0, -32384, 0, -32379, 0, 10134, 0, -32378, 0, -32378, 0, 8689, 0, -32377, 0, -32276, 0, 10140, 0, -32275, 0, -32275, 0, 8178, 0, -32274, 0, -32267, 0, 10242, 0, -32266, 0, -32266, 0, 8285, 0, -32265, 0, -32258, 0, 10250, 0, -32192, 0, -32174, 0, 10258, 0, -32173, 0, -32173, 0, 9884, 0, -32172, 0, -32159, 0, 10277, 0, -32158, 0, -32158, 0, 8629, 0, -32157, 0, -32141, 0, 10291, 0, -32140, 0, -32140, 0, 8908, 0, -32139, 0, -32135, 0, 10308, 0, -32134, 0, -32134, 0, 8214, 0, -32133, 0, -32132, 0, 10313, 0, -32131, 0, -32131, 0, 7778, 0, -32130, 0, -32130, 0, 10315, 0, -32128, 0, -32128, 0, 7968, 0, -32127, 0, -32126, 0, 10316, 0, -32125, 0, -32125, 0, 8319, 0, -32124, 0, -32113, 0, 10318, 0, -32112, 0, -32112, 0, 8284, 0, -32111, 0, -32092, 0, 10330, 0, -32091, 0, -32091, 0, 8596, 0, -32090, 0, -32057, 0, 10350, 0, -32056, 0, -32056, 0, 7781, 0, -32055, 0, -32055, 0, 8833, 0, -32054, 0, -32032, 0, 10384, 0, -32031, 0, -32031, 0, 8909, 0, -32030, 0, -32030, 0, 10407, 0, -32029, 0, -32029, 0, 8458, 0, -32028, 0, -32028, 0, 7742, 0, -32027, 0, -32020, 0, 10408, 0, -32019, 0, -32019, 0, 9855, 0, -32018, 0, -32015, 0, 10416, 0, -32014, 0, -32014, 0, 8750, 0, -32013, 0, -32010, 0, 10420, 0, -32009, 0, -32009, 0, 7830, 0, -32008, 0, -32008, 0, 8907, 0, -32007, 0, -32007, 0, 8812, 0, -32006, 0, -32006, 0, 10424, 0, -32005, 0, -32005, 0, 8471, 0, -32004, 0, -32002, 0, 10425, 0, -31936, 0, -31936, 0, 10428, 0, -31935, 0, -31935, 0, 8424, 0, -31934, 0, -31932, 0, 10429, 0, -31931, 0, -31931, 0, 8916, 0, -31930, 0, -31929, 0, 10432, 0, -31928, 0, -31928, 0, 8121, 0, -31927, 0, -31925, 0, 10434, 0, -31924, 0, -31924, 0, 8920, 0, -31923, 0, -31918, 0, 10437, 0, -31917, 0, -31917, 0, 8415, 0, -31916, 0, -31914, 0, 10443, 0, -31913, 0, -31913, 0, 8386, 0, -31912, 0, -31907, 0, 10446, 0, -31906, 0, -31906, 0, 8597, 0, -31905, 0, -31900, 0, 10452, 0, -31899, 0, -31899, 0, 8108, 0, -31898, 0, -31898, 0, 8915, 0, -31897, 0, -31887, 0, 10458, 0, -31886, 0, -31886, 0, 8065, 0, -31885, 0, -31881, 0, 10469, 0, -31880, 0, -31880, 0, 8720, 0, -31879, 0, -31879, 0, 10474, 0, -31878, 0, -31878, 0, 8911, 0, -31877, 0, -31877, 0, 10475, 0, -31876, 0, -31876, 0, 8723, 0, -31875, 0, -31875, 0, 10476, 0, -31874, 0, -31874, 0, 8164, 0, -31872, 0, -31872, 0, 8080, 0, -31871, 0, -31867, 0, 10477, 0, -31866, 0, -31866, 0, 8918, 0, -31865, 0, -31864, 0, 10482, 0, -31863, 0, -31863, 0, 8912, 0, -31862, 0, -31862, 0, 8910, 0, -31861, 0, -31860, 0, 10484, 0, -31859, 0, -31859, 0, 9857, 0, -31858, 0, -31853, 0, 10486, 0, -31852, 0, -31852, 0, 7798, 0, -31851, 0, -31843, 0, 10492, 0, -31842, 0, -31842, 0, 8753, 0, -31841, 0, -31835, 0, 10501, 0, -31834, 0, -31834, 0, 7827, 0, -31833, 0, -31830, 0, 10508, 0, -31829, 0, -31829, 0, 8914, 0, -31828, 0, -31827, 0, 10512, 0, -31826, 0, -31826, 0, 8919, 0, -31825, 0, -31825, 0, 8917, 0, -31824, 0, -31824, 0, 8913, 0, -31823, 0, -31815, 0, 10514, 0, -31814, 0, -31814, 0, 7909, 0, -31813, 0, -31800, 0, 10523, 0, -31799, 0, -31799, 0, 8229, 0, -31798, 0, -31755, 0, 10537, 0, -31754, 0, -31754, 0, 7887, 0, -31753, 0, -31746, 0, 10581, 0, -31680, 0, -31665, 0, 10589, 0, -31664, 0, -31664, 0, 8153, 0, -31663, 0, -31632, 0, 10605, 0, -31631, 0, -31631, 0, 8904, 0, -31630, 0, -31629, 0, 10637, 0, -31628, 0, -31628, 0, 8803, 0, -31627, 0, -31626, 0, 10639, 0, -31625, 0, -31625, 0, 9859, 0, -31624, 0, -31618, 0, 10641, 0, -31616, 0, -31615, 0, 10648, 0, -31614, 0, -31614, 0, 7959, 0, -31613, 0, -31603, 0, 10650, 0, -31602, 0, -31602, 0, 7979, 0, -31601, 0, -31599, 0, 10661, 0, -31598, 0, -31598, 0, 8906, 0, -31597, 0, -31597, 0, 7833, 0, -31596, 0, -31588, 0, 10664, 0, -31587, 0, -31587, 0, 8015, 0, -31586, 0, -31584, 0, 10673, 0, -31583, 0, -31583, 0, 8143, 0, -31582, 0, -31582, 0, 8246, 0, -31581, 0, -31581, 0, 7994, 0, -31580, 0, -31580, 0, 10676, 0, -31579, 0, -31579, 0, 8905, 0, -31578, 0, -31578, 0, 8089, 0, -31577, 0, -31576, 0, 10677, 0, -31575, 0, -31575, 0, 8053, 0, -31574, 0, -31548, 0, 10679, 0, -31547, 0, -31547, 0, 8126, 0, -31546, 0, -31534, 0, 10706, 0, -31533, 0, -31533, 0, 7885, 0, -31532, 0, -31532, 0, 10719, 0, -31531, 0, -31531, 0, 8617, 0, -31530, 0, -31530, 0, 10720, 0, -31529, 0, -31529, 0, 8678, 0, -31528, 0, -31528, 0, 10721, 0, -31527, 0, -31527, 0, 8487, 0, -31526, 0, -31526, 0, 8195, 0, -31525, 0, -31524, 0, 10722, 0, -31523, 0, -31523, 0, 8498, 0, -31522, 0, -31511, 0, 10724, 0, -31510, 0, -31510, 0, 8995, 0, -31509, 0, -31507, 0, 10736, 0, -31506, 0, -31506, 0, 8209, 0, -31505, 0, -31504, 0, 10739, 0, -31503, 0, -31503, 0, 8437, 0, -31502, 0, -31490, 0, 10741, 0, -31424, 0, -31408, 0, 10754, 0, -31407, 0, -31407, 0, 8901, 0, -31406, 0, -31406, 0, 8030, 0, -31405, 0, -31405, 0, 10771, 0, -31404, 0, -31404, 0, 8902, 0, -31403, 0, -31395, 0, 10772, 0, -31394, 0, -31394, 0, 8431, 0, -31393, 0, -31387, 0, 10781, 0, -31386, 0, -31386, 0, 8656, 0, -31385, 0, -31362, 0, 10788, 0, -31360, 0, -31354, 0, 10812, 0, -31353, 0, -31353, 0, 8897, 0, -31352, 0, -31350, 0, 10819, 0, -31349, 0, -31349, 0, 7780, 0, -31348, 0, -31343, 0, 10822, 0, -31342, 0, -31342, 0, 8697, 0, -31341, 0, -31339, 0, 10828, 0, -31338, 0, -31338, 0, 8208, 0, -31337, 0, -31337, 0, 10831, 0, -31336, 0, -31336, 0, 8898, 0, -31335, 0, -31327, 0, 10832, 0, -31326, 0, -31326, 0, 7770, 0, -31325, 0, -31311, 0, 10841, 0, -31310, 0, -31310, 0, 7842, 0, -31309, 0, -31234, 0, 10856, 0, -31168, 0, -31159, 0, 10932, 0, -31158, 0, -31158, 0, 9069, 0, -31157, 0, -31149, 0, 10942, 0, -31148, 0, -31148, 0, 8775, 0, -31147, 0, -31129, 0, 10951, 0, -31128, 0, -31128, 0, 9068, 0, -31127, 0, -31106, 0, 10970, 0, -31104, 0, -31083, 0, 10992, 0, -31082, 0, -31082, 0, 8604, 0, -31081, 0, -31080, 0, 11014, 0, -31079, 0, -31079, 0, 8393, 0, -31078, 0, -31072, 0, 11016, 0, -31071, 0, -31071, 0, 8688, 0, -31070, 0, -31031, 0, 11023, 0, -31030, 0, -31030, 0, 8459, 0, -31029, 0, -31029, 0, 11063, 0, -31028, 0, -31028, 0, 8414, 0, -31027, 0, -31027, 0, 11064, 0, -31026, 0, -31026, 0, 7850, 0, -31025, 0, -31024, 0, 11065, 0, -31023, 0, -31023, 0, 8748, 0, -31022, 0, -31013, 0, 11067, 0, -31012, 0, -31012, 0, 8408, 0, -31011, 0, -31011, 0, 8896, 0, -31010, 0, -31008, 0, 11077, 0, -31007, 0, -31007, 0, 8303, 0, -31006, 0, -31001, 0, 11080, 0, -31000, 0, -31000, 0, 8609, 0, -30999, 0, -30995, 0, 11086, 0, -30994, 0, -30994, 0, 9081, 0, -30993, 0, -30989, 0, 11091, 0, -30988, 0, -30988, 0, 9074, 0, -30987, 0, -30978, 0, 11096, 0, -30912, 0, -30912, 0, 8554, 0, -30911, 0, -30909, 0, 11106, 0, -30908, 0, -30908, 0, 9084, 0, -30907, 0, -30904, 0, 11109, 0, -30903, 0, -30903, 0, 8368, 0, -30902, 0, -30902, 0, 11113, 0, -30901, 0, -30901, 0, 9082, 0, -30900, 0, -30900, 0, 7796, 0, -30899, 0, -30898, 0, 11114, 0, -30897, 0, -30897, 0, 9079, 0, -30896, 0, -30890, 0, 11116, 0, -30889, 0, -30889, 0, 8012, 0, -30888, 0, -30887, 0, 11123, 0, -30886, 0, -30886, 0, 9080, 0, -30885, 0, -30885, 0, 8655, 0, -30884, 0, -30884, 0, 9064, 0, -30883, 0, -30883, 0, 11125, 0, -30882, 0, -30882, 0, 9073, 0, -30881, 0, -30881, 0, 11126, 0, -30880, 0, -30880, 0, 9065, 0, -30879, 0, -30875, 0, 11127, 0, -30874, 0, -30874, 0, 9844, 0, -30873, 0, -30855, 0, 11132, 0, -30854, 0, -30854, 0, 9071, 0, -30853, 0, -30852, 0, 11151, 0, -30851, 0, -30851, 0, 9072, 0, -30850, 0, -30850, 0, 11153, 0, -30848, 0, -30848, 0, 11154, 0, -30847, 0, -30847, 0, 9078, 0, -30846, 0, -30846, 0, 9075, 0, -30845, 0, -30843, 0, 11155, 0, -30842, 0, -30842, 0, 9087, 0, -30841, 0, -30841, 0, 11158, 0, -30840, 0, -30840, 0, 9076, 0, -30839, 0, -30839, 0, 11159, 0, -30838, 0, -30838, 0, 8373, 0, -30837, 0, -30836, 0, 11160, 0, -30835, 0, -30835, 0, 7899, 0, -30834, 0, -30834, 0, 9842, 0, -30833, 0, -30830, 0, 11162, 0, -30829, 0, -30829, 0, 9070, 0, -30828, 0, -30825, 0, 11166, 0, -30824, 0, -30824, 0, 8631, 0, -30823, 0, -30820, 0, 11170, 0, -30819, 0, -30819, 0, 9077, 0, -30818, 0, -30814, 0, 11174, 0, -30813, 0, -30813, 0, 9090, 0, -30812, 0, -30810, 0, 11179, 0, -30809, 0, -30809, 0, 8350, 0, -30808, 0, -30798, 0, 11182, 0, -30797, 0, -30797, 0, 9067, 0, -30796, 0, -30796, 0, 11193, 0, -30795, 0, -30795, 0, 8249, 0, -30794, 0, -30790, 0, 11194, 0, -30789, 0, -30789, 0, 9887, 0, -30788, 0, -30786, 0, 11199, 0, -30785, 0, -30785, 0, 9085, 0, -30784, 0, -30784, 0, 8693, 0, -30783, 0, -30783, 0, 11202, 0, -30782, 0, -30782, 0, 9089, 0, -30781, 0, -30775, 0, 11203, 0, -30774, 0, -30774, 0, 9083, 0, -30773, 0, -30773, 0, 9086, 0, -30772, 0, -30772, 0, 8652, 0, -30771, 0, -30770, 0, 11210, 0, -30769, 0, -30769, 0, 8923, 0, -30768, 0, -30767, 0, 11212, 0, -30766, 0, -30766, 0, 9066, 0, -30765, 0, -30765, 0, 9865, 0, -30764, 0, -30764, 0, 11214, 0, -30763, 0, -30763, 0, 9879, 0, -30762, 0, -30759, 0, 11215, 0, -30758, 0, -30758, 0, 8865, 0, -30757, 0, -30730, 0, 11219, 0, -30729, 0, -30729, 0, 9091, 0, -30728, 0, -30728, 0, 7997, 0, -30727, 0, -30727, 0, 11247, 0, -30726, 0, -30726, 0, 8591, 0, -30725, 0, -30722, 0, 11248, 0, -30656, 0, -30656, 0, 8774, 0, -30655, 0, -30655, 0, 8776, 0, -30654, 0, -30653, 0, 11252, 0, -30652, 0, -30652, 0, 8574, 0, -30651, 0, -30651, 0, 11254, 0, -30650, 0, -30650, 0, 8576, 0, -30649, 0, -30594, 0, 11255, 0, -30592, 0, -30535, 0, 11311, 0, -30534, 0, -30534, 0, 9002, 0, -30533, 0, -30517, 0, 11369, 0, -30516, 0, -30516, 0, 8843, 0, -30515, 0, -30509, 0, 11386, 0, -30508, 0, -30508, 0, 8069, 0, -30507, 0, -30506, 0, 11393, 0, -30505, 0, -30505, 0, 8997, 0, -30504, 0, -30498, 0, 11395, 0, -30497, 0, -30497, 0, 9004, 0, -30496, 0, -30492, 0, 11402, 0, -30491, 0, -30491, 0, 9006, 0, -30490, 0, -30479, 0, 11407, 0, -30478, 0, -30478, 0, 8709, 0, -30477, 0, -30477, 0, 7736, 0, -30476, 0, -30475, 0, 11419, 0, -30474, 0, -30474, 0, 7795, 0, -30473, 0, -30466, 0, 11421, 0, -30400, 0, -30390, 0, 11429, 0, -30389, 0, -30389, 0, 8163, 0, -30388, 0, -30388, 0, 9017, 0, -30387, 0, -30387, 0, 11440, 0, -30386, 0, -30386, 0, 9003, 0, -30385, 0, -30385, 0, 11441, 0, -30384, 0, -30384, 0, 9005, 0, -30383, 0, -30381, 0, 11442, 0, -30380, 0, -30380, 0, 8575, 0, -30379, 0, -30372, 0, 11445, 0, -30371, 0, -30371, 0, 8615, 0, -30370, 0, -30370, 0, 11453, 0, -30369, 0, -30369, 0, 9007, 0, -30368, 0, -30356, 0, 11454, 0, -30355, 0, -30355, 0, 7805, 0, -30354, 0, -30352, 0, 11467, 0, -30351, 0, -30351, 0, 8406, 0, -30350, 0, -30341, 0, 11470, 0, -30340, 0, -30340, 0, 7874, 0, -30339, 0, -30338, 0, 11480, 0, -30336, 0, -30326, 0, 11482, 0, -30325, 0, -30325, 0, 8882, 0, -30324, 0, -30312, 0, 11493, 0, -30311, 0, -30311, 0, 7903, 0, -30310, 0, -30307, 0, 11506, 0, -30306, 0, -30306, 0, 7929, 0, -30305, 0, -30299, 0, 11510, 0, -30298, 0, -30298, 0, 8409, 0, -30297, 0, -30297, 0, 11517, 0, -30296, 0, -30296, 0, 8157, 0, -30295, 0, -30290, 0, 11518, 0, -30289, 0, -30289, 0, 8551, 0, -30288, 0, -30279, 0, 11524, 0, -30278, 0, -30278, 0, 8685, 0, -30277, 0, -30275, 0, 11534, 0, -30274, 0, -30274, 0, 8199, 0, -30273, 0, -30273, 0, 8998, 0, -30272, 0, -30272, 0, 9001, 0, -30271, 0, -30269, 0, 11537, 0, -30268, 0, -30268, 0, 8018, 0, -30267, 0, -30267, 0, 8251, 0, -30266, 0, -30266, 0, 9000, 0, -30265, 0, -30265, 0, 11540, 0, -30264, 0, -30264, 0, 8999, 0, -30263, 0, -30259, 0, 11541, 0, -30258, 0, -30258, 0, 7723, 0, -30257, 0, -30256, 0, 11546, 0, -30255, 0, -30255, 0, 8878, 0, -30254, 0, -30249, 0, 11548, 0, -30248, 0, -30248, 0, 8009, 0, -30247, 0, -30246, 0, 11554, 0, -30245, 0, -30245, 0, 8504, 0, -30244, 0, -30221, 0, 11556, 0, -30220, 0, -30220, 0, 8321, 0, -30219, 0, -30210, 0, 11580, 0, -30144, 0, -30144, 0, 11590, 0, -30143, 0, -30143, 0, 8060, 0, -30142, 0, -30120, 0, 11591, 0, -30119, 0, -30119, 0, 9051, 0, -30118, 0, -30118, 0, 7902, 0, -30117, 0, -30117, 0, 11614, 0, -30116, 0, -30116, 0, 8098, 0, -30115, 0, -30115, 0, 11615, 0, -30114, 0, -30114, 0, 7930, 0, -30113, 0, -30088, 0, 11616, 0, -30087, 0, -30087, 0, 8877, 0, -30086, 0, -30082, 0, 11642, 0, -30080, 0, -29981, 0, 11647, 0, -29980, 0, -29980, 0, 8255, 0, -29979, 0, -29954, 0, 11747, 0, -29888, 0, -29885, 0, 11773, 0, -29884, 0, -29884, 0, 7950, 0, -29883, 0, -29880, 0, 11777, 0, -29879, 0, -29879, 0, 9209, 0, -29878, 0, -29831, 0, 11781, 0, -29830, 0, -29830, 0, 9212, 0, -29829, 0, -29826, 0, 11829, 0, -29824, 0, -29813, 0, 11833, 0, -29812, 0, -29812, 0, 8297, 0, -29811, 0, -29795, 0, 11845, 0, -29794, 0, -29794, 0, 9207, 0, -29793, 0, -29774, 0, 11862, 0, -29773, 0, -29773, 0, 9206, 0, -29772, 0, -29768, 0, 11882, 0, -29767, 0, -29767, 0, 9213, 0, -29766, 0, -29763, 0, 11887, 0, -29762, 0, -29762, 0, 9208, 0, -29761, 0, -29755, 0, 11891, 0, -29754, 0, -29754, 0, 9210, 0, -29753, 0, -29753, 0, 11898, 0, -29752, 0, -29752, 0, 9214, 0, -29751, 0, -29751, 0, 8104, 0, -29750, 0, -29741, 0, 11899, 0, -29740, 0, -29740, 0, 9217, 0, -29739, 0, -29733, 0, 11909, 0, -29732, 0, -29732, 0, 9215, 0, -29731, 0, -29724, 0, 11916, 0, -29723, 0, -29723, 0, 9216, 0, -29722, 0, -29718, 0, 11924, 0, -29717, 0, -29717, 0, 8737, 0, -29716, 0, -29713, 0, 11929, 0, -29712, 0, -29712, 0, 8482, 0, -29711, 0, -29698, 0, 11933, 0, -29632, 0, -29629, 0, 11947, 0, -29628, 0, -29628, 0, 9211, 0, -29627, 0, -29618, 0, 11951, 0, -29617, 0, -29617, 0, 8538, 0, -29616, 0, -29610, 0, 11961, 0, -29609, 0, -29609, 0, 8677, 0, -29608, 0, -29605, 0, 11968, 0, -29604, 0, -29604, 0, 8279, 0, -29603, 0, -29570, 0, 11972, 0, -29568, 0, -29558, 0, 12006, 0, -29557, 0, -29557, 0, 8421, 0, -29556, 0, -29556, 0, 12017, 0, -29555, 0, -29555, 0, 8495, 0, -29554, 0, -29554, 0, 8355, 0, -29553, 0, -29553, 0, 8481, 0, -29552, 0, -29552, 0, 12018, 0, -29551, 0, -29551, 0, 8660, 0, -29550, 0, -29550, 0, 8165, 0, -29549, 0, -29544, 0, 12019, 0, -29543, 0, -29543, 0, 7818, 0, -29542, 0, -29542, 0, 7735, 0, -29541, 0, -29535, 0, 12025, 0, -29534, 0, -29534, 0, 8094, 0, -29533, 0, -29533, 0, 8870, 0, -29532, 0, -29532, 0, 8680, 0, -29531, 0, -29531, 0, 12032, 0, -29530, 0, -29530, 0, 7898, 0, -29529, 0, -29529, 0, 7865, 0, -29528, 0, -29505, 0, 12033, 0, -29504, 0, -29504, 0, 9052, 0, -29503, 0, -29487, 0, 12057, 0, -29486, 0, -29486, 0, 8272, 0, -29485, 0, -29485, 0, 7783, 0, -29484, 0, -29484, 0, 12074, 0, -29483, 0, -29483, 0, 9204, 0, -29482, 0, -29480, 0, 12075, 0, -29479, 0, -29479, 0, 8510, 0, -29478, 0, -29448, 0, 12078, 0, -29447, 0, -29447, 0, 7958, 0, -29446, 0, -29442, 0, 12109, 0, -29376, 0, -29326, 0, 12114, 0, -29325, 0, -29325, 0, 9097, 0, -29324, 0, -29324, 0, 12165, 0, -29323, 0, -29323, 0, 7863, 0, -29322, 0, -29318, 0, 12166, 0, -29317, 0, -29317, 0, 8628, 0, -29316, 0, -29314, 0, 12171, 0, -29312, 0, -29305, 0, 12174, 0, -29304, 0, -29304, 0, 9103, 0, -29303, 0, -29298, 0, 12182, 0, -29297, 0, -29297, 0, 7962, 0, -29296, 0, -29283, 0, 12188, 0, -29282, 0, -29282, 0, 9099, 0, -29281, 0, -29256, 0, 12202, 0, -29255, 0, -29255, 0, 9098, 0, -29254, 0, -29215, 0, 12228, 0, -29214, 0, -29214, 0, 9105, 0, -29213, 0, -29213, 0, 12268, 0, -29212, 0, -29212, 0, 8817, 0, -29211, 0, -29210, 0, 12269, 0, -29209, 0, -29209, 0, 9096, 0, -29208, 0, -29194, 0, 12271, 0, -29193, 0, -29193, 0, 9102, 0, -29192, 0, -29187, 0, 12286, 0, -29186, 0, -29186, 0, 9101, 0, -29120, 0, -29115, 0, 12292, 0, -29114, 0, -29114, 0, 9100, 0, -29113, 0, -29099, 0, 12298, 0, -29098, 0, -29098, 0, 9104, 0, -29097, 0, -29097, 0, 12313, 0, -29096, 0, -29096, 0, 8243, 0, -29095, 0, -29095, 0, 12314, 0, -29094, 0, -29094, 0, 8764, 0, -29093, 0, -29081, 0, 12315, 0, -29080, 0, -29080, 0, 8169, 0, -29079, 0, -29075, 0, 12328, 0, -29074, 0, -29074, 0, 8277, 0, -29073, 0, -29073, 0, 12333, 0, -29072, 0, -29072, 0, 9106, 0, -29071, 0, -29058, 0, 12334, 0, -29056, 0, -29056, 0, 8996, 0, -29055, 0, -29030, 0, 12348, 0, -29029, 0, -29029, 0, 8515, 0, -29028, 0, -29026, 0, 12374, 0, -29025, 0, -29025, 0, 8489, 0, -29024, 0, -29021, 0, 12377, 0, -29020, 0, -29020, 0, 8823, 0, -29019, 0, -29018, 0, 12381, 0, -29017, 0, -29017, 0, 7847, 0, -29016, 0, -29013, 0, 12383, 0, -29012, 0, -29012, 0, 8837, 0, -29011, 0, -29011, 0, 12387, 0, -29010, 0, -29010, 0, 9092, 0, -29009, 0, -28996, 0, 12388, 0, -28995, 0, -28995, 0, 9095, 0, -28994, 0, -28994, 0, 9094, 0, -28993, 0, -28990, 0, 12402, 0, -28989, 0, -28989, 0, 8848, 0, -28988, 0, -28988, 0, 12406, 0, -28987, 0, -28987, 0, 7748, 0, -28986, 0, -28980, 0, 12407, 0, -28979, 0, -28979, 0, 7730, 0, -28978, 0, -28978, 0, 9093, 0, -28977, 0, -28971, 0, 12414, 0, -28970, 0, -28970, 0, 7955, 0, -28969, 0, -28969, 0, 8051, 0, -28968, 0, -28949, 0, 12421, 0, -28948, 0, -28948, 0, 8160, 0, -28947, 0, -28930, 0, 12441, 0, -28864, 0, -28847, 0, 12459, 0, -28846, 0, -28846, 0, 8327, 0, -28845, 0, -28845, 0, 7800, 0, -28844, 0, -28844, 0, 9134, 0, -28843, 0, -28843, 0, 7926, 0, -28842, 0, -28842, 0, 7985, 0, -28841, 0, -28836, 0, 12477, 0, -28835, 0, -28835, 0, 8261, 0, -28834, 0, -28829, 0, 12483, 0, -28828, 0, -28828, 0, 8568, 0, -28827, 0, -28802, 0, 12489, 0, -28800, 0, -28795, 0, 12515, 0, -28794, 0, -28794, 0, 9205, 0, -28793, 0, -28793, 0, 12521, 0, -28792, 0, -28792, 0, 8821, 0, -28791, 0, -28780, 0, 12522, 0, -28779, 0, -28779, 0, 9838, 0, -28778, 0, -28778, 0, 12534, 0, -28777, 0, -28777, 0, 7856, 0, -28776, 0, -28774, 0, 12535, 0, -28773, 0, -28773, 0, 8323, 0, -28772, 0, -28772, 0, 12538, 0, -28771, 0, -28771, 0, 8584, 0, -28770, 0, -28768, 0, 12539, 0, -28767, 0, -28767, 0, 9852, 0, -28766, 0, -28740, 0, 12542, 0, -28739, 0, -28739, 0, 8133, 0, -28738, 0, -28733, 0, 12569, 0, -28732, 0, -28732, 0, 7841, 0, -28731, 0, -28731, 0, 12575, 0, -28730, 0, -28730, 0, 9107, 0, -28729, 0, -28724, 0, 12576, 0, -28723, 0, -28723, 0, 7947, 0, -28722, 0, -28713, 0, 12582, 0, -28712, 0, -28712, 0, 7804, 0, -28711, 0, -28674, 0, 12592, 0, -28608, 0, -28546, 0, 12630, 0, -28544, 0, -28516, 0, 12693, 0, -28515, 0, -28515, 0, 9140, 0, -28514, 0, -28514, 0, 8318, 0, -28513, 0, -28487, 0, 12722, 0, -28486, 0, -28486, 0, 7907, 0, -28485, 0, -28481, 0, 12749, 0, -28480, 0, -28480, 0, 8341, 0, -28479, 0, -28479, 0, 9147, 0, -28478, 0, -28476, 0, 12754, 0, -28475, 0, -28475, 0, 9145, 0, -28474, 0, -28454, 0, 12757, 0, -28453, 0, -28453, 0, 7720, 0, -28452, 0, -28452, 0, 9149, 0, -28451, 0, -28436, 0, 12778, 0, -28435, 0, -28435, 0, 9141, 0, -28434, 0, -28433, 0, 12794, 0, -28432, 0, -28432, 0, 9146, 0, -28431, 0, -28426, 0, 12796, 0, -28425, 0, -28425, 0, 9139, 0, -28424, 0, -28418, 0, 12802, 0, -28352, 0, -28351, 0, 12809, 0, -28350, 0, -28350, 0, 8546, 0, -28349, 0, -28342, 0, 12811, 0, -28341, 0, -28341, 0, 7774, 0, -28340, 0, -28340, 0, 12819, 0, -28339, 0, -28339, 0, 7773, 0, -28338, 0, -28336, 0, 12820, 0, -28335, 0, -28335, 0, 9143, 0, -28334, 0, -28333, 0, 12823, 0, -28332, 0, -28332, 0, 7983, 0, -28331, 0, -28331, 0, 9439, 0, -28330, 0, -28328, 0, 12825, 0, -28327, 0, -28327, 0, 9138, 0, -28326, 0, -28326, 0, 8526, 0, -28325, 0, -28324, 0, 12828, 0, -28323, 0, -28323, 0, 8274, 0, -28322, 0, -28320, 0, 12830, 0, -28319, 0, -28319, 0, 9148, 0, -28318, 0, -28318, 0, 12833, 0, -28317, 0, -28317, 0, 8427, 0, -28316, 0, -28307, 0, 12834, 0, -28306, 0, -28306, 0, 8754, 0, -28305, 0, -28299, 0, 12844, 0, -28298, 0, -28298, 0, 7743, 0, -28297, 0, -28295, 0, 12851, 0, -28294, 0, -28294, 0, 8219, 0, -28293, 0, -28293, 0, 8380, 0, -28292, 0, -28292, 0, 9150, 0, -28291, 0, -28290, 0, 12854, 0, -28288, 0, -28285, 0, 12856, 0, -28284, 0, -28284, 0, 7854, 0, -28283, 0, -28276, 0, 12860, 0, -28275, 0, -28275, 0, 7931, 0, -28274, 0, -28272, 0, 12868, 0, -28271, 0, -28271, 0, 8329, 0, -28270, 0, -28270, 0, 12871, 0, -28269, 0, -28269, 0, 9137, 0, -28268, 0, -28266, 0, 12872, 0, -28265, 0, -28265, 0, 8644, 0, -28264, 0, -28262, 0, 12875, 0, -28261, 0, -28261, 0, 8724, 0, -28260, 0, -28248, 0, 12878, 0, -28247, 0, -28247, 0, 8158, 0, -28246, 0, -28246, 0, 8739, 0, -28245, 0, -28245, 0, 9142, 0, -28244, 0, -28231, 0, 12891, 0, -28230, 0, -28230, 0, 9868, 0, -28229, 0, -28229, 0, 9438, 0, -28228, 0, -28226, 0, 12905, 0, -28225, 0, -28225, 0, 9440, 0, -28224, 0, -28222, 0, 12908, 0, -28221, 0, -28221, 0, 9144, 0, -28220, 0, -28212, 0, 12911, 0, -28211, 0, -28211, 0, 7809, 0, -28210, 0, -28209, 0, 12920, 0, -28208, 0, -28208, 0, 8190, 0, -28207, 0, -28207, 0, 8017, 0, -28206, 0, -28206, 0, 8673, 0, -28205, 0, -28205, 0, 12922, 0, -28204, 0, -28204, 0, 9136, 0, -28203, 0, -28203, 0, 12923, 0, -28202, 0, -28202, 0, 8142, 0, -28201, 0, -28201, 0, 12924, 0, -28200, 0, -28200, 0, 8478, 0, -28199, 0, -28199, 0, 8225, 0, -28198, 0, -28194, 0, 12925, 0, -28193, 0, -28193, 0, 9441, 0, -28192, 0, -28191, 0, 12930, 0, -28190, 0, -28190, 0, 9379, 0, -28189, 0, -28183, 0, 12932, 0, -28182, 0, -28182, 0, 9380, 0, -28181, 0, -28177, 0, 12939, 0, -28176, 0, -28176, 0, 8819, 0, -28175, 0, -28175, 0, 12944, 0, -28174, 0, -28174, 0, 8624, 0, -28173, 0, -28162, 0, 12945, 0, -28096, 0, -28034, 0, 12957, 0, -28032, 0, -27979, 0, 13020, 0, -27978, 0, -27978, 0, 8657, 0, -27977, 0, -27955, 0, 13074, 0, -27954, 0, -27954, 0, 8476, 0, -27953, 0, -27953, 0, 13097, 0, -27952, 0, -27952, 0, 9053, 0, -27951, 0, -27949, 0, 13098, 0, -27948, 0, -27948, 0, 9858, 0, -27947, 0, -27938, 0, 13101, 0, -27937, 0, -27937, 0, 8461, 0, -27936, 0, -27936, 0, 8282, 0, -27935, 0, -27907, 0, 13111, 0, -27906, 0, -27906, 0, 8077, 0, -27840, 0, -27825, 0, 13140, 0, -27824, 0, -27824, 0, 8703, 0, -27823, 0, -27812, 0, 13156, 0, -27811, 0, -27811, 0, 8024, 0, -27810, 0, -27793, 0, 13168, 0, -27792, 0, -27792, 0, 8539, 0, -27791, 0, -27787, 0, 13186, 0, -27786, 0, -27786, 0, 7862, 0, -27785, 0, -27778, 0, 13191, 0, -27776, 0, -27765, 0, 13199, 0, -27764, 0, -27764, 0, 8411, 0, -27763, 0, -27748, 0, 13211, 0, -27747, 0, -27747, 0, 9056, 0, -27746, 0, -27740, 0, 13227, 0, -27739, 0, -27739, 0, 9057, 0, -27738, 0, -27738, 0, 13234, 0, -27737, 0, -27737, 0, 8256, 0, -27736, 0, -27725, 0, 13235, 0, -27724, 0, -27724, 0, 8846, 0, -27723, 0, -27721, 0, 13247, 0, -27720, 0, -27720, 0, 8159, 0, -27719, 0, -27718, 0, 13250, 0, -27717, 0, -27717, 0, 9054, 0, -27716, 0, -27716, 0, 13252, 0, -27715, 0, -27715, 0, 7786, 0, -27714, 0, -27707, 0, 13253, 0, -27706, 0, -27706, 0, 8194, 0, -27705, 0, -27698, 0, 13261, 0, -27697, 0, -27697, 0, 8339, 0, -27696, 0, -27690, 0, 13269, 0, -27689, 0, -27689, 0, 9055, 0, -27688, 0, -27686, 0, 13276, 0, -27685, 0, -27685, 0, 7852, 0, -27684, 0, -27684, 0, 7764, 0, -27683, 0, -27680, 0, 13279, 0, -27679, 0, -27679, 0, 7944, 0, -27678, 0, -27677, 0, 13283, 0, -27676, 0, -27676, 0, 8384, 0, -27675, 0, -27675, 0, 9058, 0, -27674, 0, -27672, 0, 13285, 0, -27671, 0, -27671, 0, 8544, 0, -27670, 0, -27670, 0, 13288, 0, -27669, 0, -27669, 0, 8605, 0, -27668, 0, -27668, 0, 8078, 0, -27667, 0, -27667, 0, 8749, 0, -27666, 0, -27666, 0, 13289, 0, -27665, 0, -27665, 0, 8263, 0, -27664, 0, -27664, 0, 13290, 0, -27663, 0, -27663, 0, 8802, 0, -27662, 0, -27661, 0, 13291, 0, -27660, 0, -27660, 0, 8039, 0, -27659, 0, -27659, 0, 7858, 0, -27658, 0, -27655, 0, 13293, 0, -27654, 0, -27654, 0, 7849, 0, -27653, 0, -27651, 0, 13297, 0, -27650, 0, -27650, 0, 8140, 0, -27584, 0, -27581, 0, 13300, 0, -27580, 0, -27580, 0, 8050, 0, -27579, 0, -27572, 0, 13304, 0, -27571, 0, -27571, 0, 8344, 0, -27570, 0, -27569, 0, 13312, 0, -27568, 0, -27568, 0, 7762, 0, -27567, 0, -27567, 0, 8356, 0, -27566, 0, -27566, 0, 7964, 0, -27565, 0, -27565, 0, 8847, 0, -27564, 0, -27564, 0, 13314, 0, -27563, 0, -27563, 0, 8173, 0, -27562, 0, -27561, 0, 13315, 0, -27560, 0, -27560, 0, 9061, 0, -27559, 0, -27558, 0, 13317, 0, -27557, 0, -27557, 0, 7725, 0, -27556, 0, -27556, 0, 8530, 0, -27555, 0, -27555, 0, 9062, 0, -27554, 0, -27554, 0, 13319, 0, -27553, 0, -27553, 0, 8442, 0, -27552, 0, -27549, 0, 13320, 0, -27548, 0, -27548, 0, 9059, 0, -27547, 0, -27547, 0, 13324, 0, -27546, 0, -27546, 0, 8346, 0, -27545, 0, -27539, 0, 13325, 0, -27538, 0, -27538, 0, 8252, 0, -27537, 0, -27535, 0, 13332, 0, -27534, 0, -27534, 0, 8182, 0, -27533, 0, -27533, 0, 13335, 0, -27532, 0, -27532, 0, 9060, 0, -27531, 0, -27531, 0, 13336, 0, -27530, 0, -27530, 0, 7785, 0, -27529, 0, -27529, 0, 13337, 0, -27528, 0, -27528, 0, 9063, 0, -27527, 0, -27527, 0, 13338, 0, -27526, 0, -27526, 0, 8477, 0, -27525, 0, -27522, 0, 13339, 0, -27520, 0, -27520, 0, 8793, 0, -27519, 0, -27519, 0, 8278, 0, -27518, 0, -27518, 0, 8547, 0, -27517, 0, -27514, 0, 13343, 0, -27513, 0, -27513, 0, 8105, 0, -27512, 0, -27512, 0, 8188, 0, -27511, 0, -27488, 0, 13347, 0, -27487, 0, -27487, 0, 7726, 0, -27486, 0, -27470, 0, 13371, 0, -27469, 0, -27469, 0, 7868, 0, -27468, 0, -27468, 0, 13388, 0, -27467, 0, -27467, 0, 8514, 0, -27466, 0, -27458, 0, 13389, 0, -27457, 0, -27457, 0, 8222, 0, -27456, 0, -27456, 0, 7747, 0, -27455, 0, -27445, 0, 13398, 0, -27444, 0, -27444, 0, 9428, 0, -27443, 0, -27433, 0, 13409, 0, -27432, 0, -27432, 0, 8815, 0, -27431, 0, -27425, 0, 13420, 0, -27424, 0, -27424, 0, 7895, 0, -27423, 0, -27394, 0, 13427, 0, -27328, 0, -27279, 0, 13457, 0, -27278, 0, -27278, 0, 8493, 0, -27277, 0, -27266, 0, 13507, 0, -27264, 0, -27262, 0, 13519, 0, -27261, 0, -27261, 0, 8859, 0, -27260, 0, -27235, 0, 13522, 0, -27234, 0, -27234, 0, 8790, 0, -27233, 0, -27233, 0, 9384, 0, -27232, 0, -27214, 0, 13548, 0, -27213, 0, -27213, 0, 7801, 0, -27212, 0, -27207, 0, 13567, 0, -27206, 0, -27206, 0, 8794, 0, -27205, 0, -27186, 0, 13573, 0, -27185, 0, -27185, 0, 9383, 0, -27184, 0, -27184, 0, 13593, 0, -27183, 0, -27183, 0, 9862, 0, -27182, 0, -27182, 0, 9382, 0, -27181, 0, -27181, 0, 13594, 0, -27180, 0, -27180, 0, 8654, 0, -27179, 0, -27168, 0, 13595, 0, -27167, 0, -27167, 0, 9385, 0, -27166, 0, -27162, 0, 13607, 0, -27161, 0, -27161, 0, 8167, 0, -27160, 0, -27152, 0, 13612, 0, -27151, 0, -27151, 0, 8466, 0, -27150, 0, -27145, 0, 13621, 0, -27144, 0, -27144, 0, 8508, 0, -27143, 0, -27139, 0, 13627, 0, -27138, 0, -27138, 0, 8028, 0, -27072, 0, -27051, 0, 13632, 0, -27050, 0, -27050, 0, 9412, 0, -27049, 0, -27013, 0, 13654, 0, -27012, 0, -27012, 0, 7884, 0, -27011, 0, -27010, 0, 13691, 0, -27008, 0, -26882, 0, 13693, 0, -26816, 0, -26778, 0, 13820, 0, -26777, 0, -26777, 0, 9322, 0, -26776, 0, -26773, 0, 13859, 0, -26772, 0, -26772, 0, 8565, 0, -26771, 0, -26771, 0, 13863, 0, -26770, 0, -26770, 0, 9325, 0, -26769, 0, -26754, 0, 13864, 0, -26752, 0, -26731, 0, 13880, 0, -26730, 0, -26730, 0, 9323, 0, -26729, 0, -26729, 0, 8799, 0, -26728, 0, -26724, 0, 13902, 0, -26723, 0, -26723, 0, 7886, 0, -26722, 0, -26718, 0, 13907, 0, -26717, 0, -26717, 0, 8818, 0, -26716, 0, -26690, 0, 13912, 0, -26689, 0, -26689, 0, 9331, 0, -26688, 0, -26643, 0, 13939, 0, -26642, 0, -26642, 0, 8702, 0, -26641, 0, -26634, 0, 13985, 0, -26633, 0, -26633, 0, 7934, 0, -26632, 0, -26626, 0, 13993, 0, -26560, 0, -26556, 0, 14000, 0, -26555, 0, -26555, 0, 9333, 0, -26554, 0, -26552, 0, 14005, 0, -26551, 0, -26551, 0, 8714, 0, -26550, 0, -26546, 0, 14008, 0, -26545, 0, -26545, 0, 8047, 0, -26544, 0, -26512, 0, 14013, 0, -26511, 0, -26511, 0, 9320, 0, -26510, 0, -26510, 0, 14046, 0, -26509, 0, -26509, 0, 8448, 0, -26508, 0, -26498, 0, 14047, 0, -26496, 0, -26496, 0, 14058, 0, -26495, 0, -26495, 0, 9334, 0, -26494, 0, -26486, 0, 14059, 0, -26485, 0, -26485, 0, 7975, 0, -26484, 0, -26484, 0, 8407, 0, -26483, 0, -26465, 0, 14068, 0, -26464, 0, -26464, 0, 9340, 0, -26463, 0, -26455, 0, 14087, 0, -26454, 0, -26454, 0, 8097, 0, -26453, 0, -26443, 0, 14096, 0, -26442, 0, -26442, 0, 8874, 0, -26441, 0, -26441, 0, 8197, 0, -26440, 0, -26439, 0, 14107, 0, -26438, 0, -26438, 0, 9324, 0, -26437, 0, -26426, 0, 14109, 0, -26425, 0, -26425, 0, 8254, 0, -26424, 0, -26422, 0, 14121, 0, -26421, 0, -26421, 0, 7756, 0, -26420, 0, -26417, 0, 14124, 0, -26416, 0, -26416, 0, 8506, 0, -26415, 0, -26414, 0, 14128, 0, -26413, 0, -26413, 0, 8708, 0, -26412, 0, -26398, 0, 14130, 0, -26397, 0, -26397, 0, 8387, 0, -26396, 0, -26396, 0, 8512, 0, -26395, 0, -26395, 0, 9335, 0, -26394, 0, -26386, 0, 14145, 0, -26385, 0, -26385, 0, 9332, 0, -26384, 0, -26383, 0, 14154, 0, -26382, 0, -26382, 0, 8413, 0, -26381, 0, -26370, 0, 14156, 0, -26304, 0, -26302, 0, 14168, 0, -26301, 0, -26301, 0, 8040, 0, -26300, 0, -26300, 0, 14171, 0, -26299, 0, -26299, 0, 8581, 0, -26298, 0, -26267, 0, 14172, 0, -26266, 0, -26266, 0, 9330, 0, -26265, 0, -26259, 0, 14204, 0, -26258, 0, -26258, 0, 7861, 0, -26257, 0, -26252, 0, 14211, 0, -26251, 0, -26251, 0, 9336, 0, -26250, 0, -26247, 0, 14217, 0, -26246, 0, -26246, 0, 8075, 0, -26245, 0, -26245, 0, 9348, 0, -26244, 0, -26242, 0, 14221, 0, -26240, 0, -26236, 0, 14224, 0, -26235, 0, -26235, 0, 9881, 0, -26234, 0, -26232, 0, 14229, 0, -26231, 0, -26231, 0, 9346, 0, -26230, 0, -26227, 0, 14232, 0, -26226, 0, -26226, 0, 8353, 0, -26225, 0, -26224, 0, 14236, 0, -26223, 0, -26223, 0, 8082, 0, -26222, 0, -26216, 0, 14238, 0, -26215, 0, -26215, 0, 7992, 0, -26214, 0, -26200, 0, 14245, 0, -26199, 0, -26199, 0, 9349, 0, -26198, 0, -26193, 0, 14260, 0, -26192, 0, -26192, 0, 9344, 0, -26191, 0, -26191, 0, 9326, 0, -26190, 0, -26190, 0, 14266, 0, -26189, 0, -26189, 0, 9339, 0, -26188, 0, -26188, 0, 9350, 0, -26187, 0, -26187, 0, 9329, 0, -26186, 0, -26180, 0, 14267, 0, -26179, 0, -26179, 0, 9347, 0, -26178, 0, -26178, 0, 9328, 0, -26177, 0, -26177, 0, 14274, 0, -26176, 0, -26176, 0, 9321, 0, -26175, 0, -26175, 0, 14275, 0, -26174, 0, -26174, 0, 9343, 0, -26173, 0, -26168, 0, 14276, 0, -26167, 0, -26167, 0, 9327, 0, -26166, 0, -26163, 0, 14282, 0, -26162, 0, -26162, 0, 9345, 0, -26161, 0, -26160, 0, 14286, 0, -26159, 0, -26159, 0, 8736, 0, -26158, 0, -26151, 0, 14288, 0, -26150, 0, -26150, 0, 8181, 0, -26149, 0, -26145, 0, 14296, 0, -26144, 0, -26144, 0, 8436, 0, -26143, 0, -26140, 0, 14301, 0, -26139, 0, -26139, 0, 9341, 0, -26138, 0, -26137, 0, 14305, 0, -26136, 0, -26136, 0, 9337, 0, -26135, 0, -26133, 0, 14307, 0, -26132, 0, -26132, 0, 9342, 0, -26131, 0, -26125, 0, 14310, 0, -26124, 0, -26124, 0, 9338, 0, -26123, 0, -26114, 0, 14317, 0, -26048, 0, -26039, 0, 14327, 0, -26038, 0, -26038, 0, 8419, 0, -26037, 0, -26026, 0, 14337, 0, -26025, 0, -26025, 0, 8365, 0, -26024, 0, -26012, 0, 14349, 0, -26011, 0, -26011, 0, 9419, 0, -26010, 0, -26010, 0, 14362, 0, -26009, 0, -26009, 0, 8019, 0, -26008, 0, -26000, 0, 14363, 0, -25999, 0, -25999, 0, 8537, 0, -25998, 0, -25995, 0, 14372, 0, -25994, 0, -25994, 0, 8211, 0, -25993, 0, -25993, 0, 7987, 0, -25992, 0, -25986, 0, 14376, 0, -25984, 0, -25977, 0, 14383, 0, -25976, 0, -25976, 0, 7772, 0, -25975, 0, -25973, 0, 14391, 0, -25972, 0, -25972, 0, 9352, 0, -25971, 0, -25968, 0, 14394, 0, -25967, 0, -25967, 0, 9351, 0, -25966, 0, -25962, 0, 14398, 0, -25961, 0, -25961, 0, 9354, 0, -25960, 0, -25959, 0, 14403, 0, -25958, 0, -25958, 0, 9353, 0, -25957, 0, -25957, 0, 9355, 0, -25956, 0, -25955, 0, 14405, 0, -25954, 0, -25954, 0, 8067, 0, -25953, 0, -25951, 0, 14407, 0, -25950, 0, -25950, 0, 8463, 0, -25949, 0, -25949, 0, 8155, 0, -25948, 0, -25943, 0, 14410, 0, -25942, 0, -25942, 0, 8367, 0, -25941, 0, -25905, 0, 14416, 0, -25904, 0, -25904, 0, 9408, 0, -25903, 0, -25899, 0, 14453, 0, -25898, 0, -25898, 0, 8813, 0, -25897, 0, -25895, 0, 14458, 0, -25894, 0, -25894, 0, 9409, 0, -25893, 0, -25887, 0, 14461, 0, -25886, 0, -25886, 0, 8394, 0, -25885, 0, -25885, 0, 14468, 0, -25884, 0, -25884, 0, 8423, 0, -25883, 0, -25883, 0, 9410, 0, -25882, 0, -25858, 0, 14469, 0, -25792, 0, -25730, 0, 14494, 0, -25728, 0, -25648, 0, 14557, 0, -25647, 0, -25647, 0, 9180, 0, -25646, 0, -25637, 0, 14638, 0, -25636, 0, -25636, 0, 9179, 0, -25635, 0, -25602, 0, 14648, 0, -25536, 0, -25518, 0, 14682, 0, -25517, 0, -25517, 0, 8286, 0, -25516, 0, -25512, 0, 14701, 0, -25511, 0, -25511, 0, 8772, 0, -25510, 0, -25510, 0, 9186, 0, -25509, 0, -25509, 0, 14706, 0, -25508, 0, -25508, 0, 8404, 0, -25507, 0, -25484, 0, 14707, 0, -25483, 0, -25483, 0, 8607, 0, -25482, 0, -25480, 0, 14731, 0, -25479, 0, -25479, 0, 7782, 0, -25478, 0, -25474, 0, 14734, 0, -25472, 0, -25467, 0, 14739, 0, -25466, 0, -25466, 0, 8035, 0, -25465, 0, -25444, 0, 14745, 0, -25443, 0, -25443, 0, 9181, 0, -25442, 0, -25430, 0, 14767, 0, -25429, 0, -25429, 0, 8555, 0, -25428, 0, -25399, 0, 14780, 0, -25398, 0, -25398, 0, 8885, 0, -25397, 0, -25394, 0, 14810, 0, -25393, 0, -25393, 0, 7974, 0, -25392, 0, -25371, 0, 14814, 0, -25370, 0, -25370, 0, 7779, 0, -25369, 0, -25369, 0, 8328, 0, -25368, 0, -25365, 0, 14836, 0, -25364, 0, -25364, 0, 7869, 0, -25363, 0, -25363, 0, 14840, 0, -25362, 0, -25362, 0, 9025, 0, -25361, 0, -25350, 0, 14841, 0, -25349, 0, -25349, 0, 8011, 0, -25348, 0, -25347, 0, 14853, 0, -25346, 0, -25346, 0, 8850, 0, -25280, 0, -25279, 0, 14855, 0, -25278, 0, -25278, 0, 8484, 0, -25277, 0, -25275, 0, 14857, 0, -25274, 0, -25274, 0, 8264, 0, -25273, 0, -25273, 0, 9184, 0, -25272, 0, -25268, 0, 14860, 0, -25267, 0, -25267, 0, 8311, 0, -25266, 0, -25266, 0, 14865, 0, -25265, 0, -25265, 0, 8762, 0, -25264, 0, -25248, 0, 14866, 0, -25247, 0, -25247, 0, 8369, 0, -25246, 0, -25241, 0, 14883, 0, -25240, 0, -25240, 0, 8001, 0, -25239, 0, -25239, 0, 8220, 0, -25238, 0, -25235, 0, 14889, 0, -25234, 0, -25234, 0, 8888, 0, -25233, 0, -25232, 0, 14893, 0, -25231, 0, -25231, 0, 8822, 0, -25230, 0, -25228, 0, 14895, 0, -25227, 0, -25227, 0, 8091, 0, -25226, 0, -25222, 0, 14898, 0, -25221, 0, -25221, 0, 8095, 0, -25220, 0, -25220, 0, 14903, 0, -25219, 0, -25219, 0, 9674, 0, -25218, 0, -25218, 0, 14904, 0, -25216, 0, -25207, 0, 14905, 0, -25206, 0, -25206, 0, 8382, 0, -25205, 0, -25204, 0, 14915, 0, -25203, 0, -25203, 0, 8116, 0, -25202, 0, -25200, 0, 14917, 0, -25199, 0, -25199, 0, 9175, 0, -25198, 0, -25192, 0, 14920, 0, -25191, 0, -25191, 0, 8453, 0, -25190, 0, -25184, 0, 14927, 0, -25183, 0, -25183, 0, 9185, 0, -25182, 0, -25182, 0, 8172, 0, -25181, 0, -25178, 0, 14934, 0, -25177, 0, -25177, 0, 9194, 0, -25176, 0, -25173, 0, 14938, 0, -25172, 0, -25172, 0, 9187, 0, -25171, 0, -25171, 0, 8462, 0, -25170, 0, -25167, 0, 14942, 0, -25166, 0, -25166, 0, 8102, 0, -25165, 0, -25165, 0, 8196, 0, -25164, 0, -25155, 0, 14946, 0, -25154, 0, -25154, 0, 8093, 0, -25153, 0, -25147, 0, 14956, 0, -25146, 0, -25146, 0, 9189, 0, -25145, 0, -25144, 0, 14963, 0, -25143, 0, -25143, 0, 8804, 0, -25142, 0, -25140, 0, 14965, 0, -25139, 0, -25139, 0, 9442, 0, -25138, 0, -25135, 0, 14968, 0, -25134, 0, -25134, 0, 9182, 0, -25133, 0, -25132, 0, 14972, 0, -25131, 0, -25131, 0, 7876, 0, -25130, 0, -25120, 0, 14974, 0, -25119, 0, -25119, 0, 8886, 0, -25118, 0, -25118, 0, 8361, 0, -25117, 0, -25104, 0, 14985, 0, -25103, 0, -25103, 0, 8491, 0, -25102, 0, -25101, 0, 14999, 0, -25100, 0, -25100, 0, 8357, 0, -25099, 0, -25098, 0, 15001, 0, -25097, 0, -25097, 0, 9867, 0, -25096, 0, -25095, 0, 15003, 0, -25094, 0, -25094, 0, 8054, 0, -25093, 0, -25092, 0, 15005, 0, -25091, 0, -25091, 0, 8557, 0, -25090, 0, -25090, 0, 15007, 0, -25024, 0, -25020, 0, 15008, 0, -25019, 0, -25019, 0, 8193, 0, -25018, 0, -25017, 0, 15013, 0, -25016, 0, -25016, 0, 8593, 0, -25015, 0, -25015, 0, 7760, 0, -25014, 0, -25007, 0, 15015, 0, -25006, 0, -25006, 0, 8092, 0, -25005, 0, -25005, 0, 15023, 0, -25004, 0, -25004, 0, 9178, 0, -25003, 0, -25003, 0, 15024, 0, -25002, 0, -25002, 0, 8275, 0, -25001, 0, -24996, 0, 15025, 0, -24995, 0, -24995, 0, 9193, 0, -24994, 0, -24994, 0, 9188, 0, -24993, 0, -24992, 0, 15031, 0, -24991, 0, -24991, 0, 8661, 0, -24990, 0, -24990, 0, 15033, 0, -24989, 0, -24989, 0, 9190, 0, -24988, 0, -24986, 0, 15034, 0, -24985, 0, -24985, 0, 9183, 0, -24984, 0, -24981, 0, 15037, 0, -24980, 0, -24980, 0, 7759, 0, -24979, 0, -24978, 0, 15041, 0, -24977, 0, -24977, 0, 9177, 0, -24976, 0, -24975, 0, 15043, 0, -24974, 0, -24974, 0, 8212, 0, -24973, 0, -24973, 0, 15045, 0, -24972, 0, -24972, 0, 9196, 0, -24971, 0, -24971, 0, 9195, 0, -24970, 0, -24966, 0, 15046, 0, -24965, 0, -24965, 0, 9176, 0, -24964, 0, -24964, 0, 9198, 0, -24963, 0, -24962, 0, 15051, 0, -24960, 0, -24956, 0, 15053, 0, -24955, 0, -24955, 0, 9870, 0, -24954, 0, -24954, 0, 15058, 0, -24953, 0, -24953, 0, 9197, 0, -24952, 0, -24944, 0, 15059, 0, -24943, 0, -24943, 0, 8186, 0, -24942, 0, -24939, 0, 15068, 0, -24938, 0, -24938, 0, 9174, 0, -24937, 0, -24937, 0, 9192, 0, -24936, 0, -24927, 0, 15072, 0, -24926, 0, -24926, 0, 8454, 0, -24925, 0, -24923, 0, 15082, 0, -24922, 0, -24922, 0, 8203, 0, -24921, 0, -24920, 0, 15085, 0, -24919, 0, -24919, 0, 8550, 0, -24918, 0, -24915, 0, 15087, 0, -24914, 0, -24914, 0, 9199, 0, -24913, 0, -24910, 0, 15091, 0, -24909, 0, -24909, 0, 8585, 0, -24908, 0, -24908, 0, 8280, 0, -24907, 0, -24906, 0, 15095, 0, -24905, 0, -24905, 0, 9191, 0, -24904, 0, -24844, 0, 15097, 0, -24843, 0, -24843, 0, 8611, 0, -24842, 0, -24834, 0, 15158, 0, -24768, 0, -24755, 0, 15167, 0, -24754, 0, -24754, 0, 8570, 0, -24753, 0, -24722, 0, 15181, 0, -24721, 0, -24721, 0, 8613, 0, -24720, 0, -24706, 0, 15213, 0, -24704, 0, -24687, 0, 15228, 0, -24686, 0, -24686, 0, 8226, 0, -24685, 0, -24681, 0, 15246, 0, -24680, 0, -24680, 0, 9430, 0, -24679, 0, -24667, 0, 15251, 0, -24666, 0, -24666, 0, 9018, 0, -24665, 0, -24664, 0, 15264, 0, -24663, 0, -24663, 0, 7918, 0, -24662, 0, -24661, 0, 15266, 0, -24660, 0, -24660, 0, 9429, 0, -24659, 0, -24632, 0, 15268, 0, -24631, 0, -24631, 0, 8744, 0, -24630, 0, -24628, 0, 15296, 0, -24627, 0, -24627, 0, 9431, 0, -24626, 0, -24608, 0, 15299, 0, -24607, 0, -24607, 0, 8444, 0, -24606, 0, -24598, 0, 15318, 0, -24597, 0, -24597, 0, 7815, 0, -24596, 0, -24595, 0, 15327, 0, -24594, 0, -24594, 0, 9432, 0, -24593, 0, -24589, 0, 15329, 0, -24588, 0, -24588, 0, 7866, 0, -24587, 0, -24580, 0, 15334, 0, -24579, 0, -24579, 0, 8473, 0, -24578, 0, -24578, 0, 15342, 0, -24512, 0, -24510, 0, 15343, 0, -24509, 0, -24509, 0, 8556, 0, -24508, 0, -24507, 0, 15346, 0, -24506, 0, -24506, 0, 9433, 0, -24505, 0, -24504, 0, 15348, 0, -24503, 0, -24503, 0, 8743, 0, -24502, 0, -24499, 0, 15350, 0, -24498, 0, -24498, 0, 7775, 0, -24497, 0, -24493, 0, 15354, 0, -24492, 0, -24492, 0, 8863, 0, -24491, 0, -24487, 0, 15359, 0, -24486, 0, -24486, 0, 8029, 0, -24485, 0, -24480, 0, 15364, 0, -24479, 0, -24479, 0, 8124, 0, -24478, 0, -24478, 0, 15370, 0, -24477, 0, -24477, 0, 9434, 0, -24476, 0, -24464, 0, 15371, 0, -24463, 0, -24463, 0, 8521, 0, -24462, 0, -24461, 0, 15384, 0, -24460, 0, -24460, 0, 8262, 0, -24459, 0, -24450, 0, 15386, 0, -24448, 0, -24448, 0, 8192, 0, -24447, 0, -24432, 0, 15396, 0, -24431, 0, -24431, 0, 8592, 0, -24430, 0, -24429, 0, 15412, 0, -24428, 0, -24428, 0, 8712, 0, -24427, 0, -24427, 0, 15414, 0, -24426, 0, -24426, 0, 7910, 0, -24425, 0, -24408, 0, 15415, 0, -24407, 0, -24407, 0, 9411, 0, -24406, 0, -24386, 0, 15433, 0, -24385, 0, -24385, 0, 8396, 0, -24384, 0, -24371, 0, 15454, 0, -24370, 0, -24370, 0, 9024, 0, -24369, 0, -24360, 0, 15468, 0, -24359, 0, -24359, 0, 7889, 0, -24358, 0, -24355, 0, 15478, 0, -24354, 0, -24354, 0, 8620, 0, -24353, 0, -24339, 0, 15482, 0, -24338, 0, -24338, 0, 8879, 0, -24337, 0, -24322, 0, 15497, 0, -24159, 0, -24066, 0, 96, 0, -23903, 0, -23894, 0, 9897, 0, -23887, 0, -23838, 0, 190, 0, -23835, 0, -23826, 0, 240, 0, -23823, 0, -23812, 0, 250, 0, -23647, 0, -23554, 0, 262, 0, -23391, 0, -23309, 0, 356, 0, -23135, 0, -23050, 0, 439, 0, -22879, 0, -22856, 0, 525, 0, -22847, 0, -22795, 0, 549, 0, -22623, 0, -22591, 0, 602, 0, -22575, 0, -22543, 0, 635, 0, -22464, 0, -22402, 0, 9907, 0, -22400, 0, -22379, 0, 9970, 0, -22367, 0, -22336, 0, 668, 0, -22331, 0, -22294, 0, 700, 0, -22208, 0, -22185, 0, 9992, 0, -22183, 0, -22182, 0, 10016, 0, -22180, 0, -22180, 0, 10018, 0, -22176, 0, -22146, 0, 10019, 0, -22144, 0, -22123, 0, 10050, 0, -22122, 0, -22122, 0, 7703, 0, -22108, 0, -22033, 0, 738, 0, -21952, 0, -21940, 0, 15513, 0, -21939, 0, -21939, 0, 8630, 0, -21938, 0, -21938, 0, 7741, 0, -21937, 0, -21904, 0, 15526, 0, -21903, 0, -21903, 0, 8757, 0, -21902, 0, -21902, 0, 15560, 0, -21901, 0, -21901, 0, 9111, 0, -21900, 0, -21898, 0, 15561, 0, -21897, 0, -21897, 0, 9109, 0, -21896, 0, -21895, 0, 15564, 0, -21894, 0, -21894, 0, 8767, 0, -21893, 0, -21893, 0, 8490, 0, -21892, 0, -21890, 0, 15566, 0, -21888, 0, -21863, 0, 15569, 0, -21862, 0, -21862, 0, 7890, 0, -21861, 0, -21861, 0, 15595, 0, -21860, 0, -21860, 0, 9110, 0, -21859, 0, -21859, 0, 9112, 0, -21858, 0, -21858, 0, 15596, 0, -21857, 0, -21857, 0, 8354, 0, -21856, 0, -21856, 0, 15597, 0, -21855, 0, -21762, 0, 814, 0, -21696, 0, -21696, 0, 8036, 0, -21695, 0, -21694, 0, 15598, 0, -21693, 0, -21693, 0, 8235, 0, -21692, 0, -21692, 0, 15600, 0, -21691, 0, -21691, 0, 9108, 0, -21690, 0, -21690, 0, 8505, 0, -21689, 0, -21689, 0, 15601, 0, -21688, 0, -21688, 0, 8543, 0, -21687, 0, -21687, 0, 8641, 0, -21686, 0, -21686, 0, 9114, 0, -21685, 0, -21684, 0, 15602, 0, -21683, 0, -21683, 0, 9113, 0, -21682, 0, -21634, 0, 15604, 0, -21632, 0, -21600, 0, 15653, 0, -21599, 0, -21568, 0, 908, 0, -21440, 0, -21435, 0, 15686, 0, -21434, 0, -21434, 0, 8640, 0, -21433, 0, -21392, 0, 15692, 0, -21391, 0, -21391, 0, 9312, 0, -21390, 0, -21381, 0, 15734, 0, -21380, 0, -21380, 0, 9308, 0, -21379, 0, -21378, 0, 15744, 0, -21376, 0, -21364, 0, 15746, 0, -21363, 0, -21363, 0, 8541, 0, -21362, 0, -21358, 0, 15759, 0, -21357, 0, -21357, 0, 8741, 0, -21356, 0, -21356, 0, 8298, 0, -21355, 0, -21344, 0, 15764, 0, -21184, 0, -21176, 0, 15776, 0, -21175, 0, -21175, 0, 9313, 0, -21174, 0, -21155, 0, 15785, 0, -21154, 0, -21154, 0, 9307, 0, -21153, 0, -21152, 0, 15805, 0, -21151, 0, -21151, 0, 9314, 0, -21150, 0, -21145, 0, 15807, 0, -21144, 0, -21144, 0, 8020, 0, -21143, 0, -21133, 0, 15813, 0, -21132, 0, -21132, 0, 9311, 0, -21131, 0, -21122, 0, 15824, 0, -21120, 0, -21119, 0, 15834, 0, -21118, 0, -21118, 0, 8428, 0, -21117, 0, -21114, 0, 15836, 0, -21113, 0, -21113, 0, 9309, 0, -21112, 0, -21110, 0, 15840, 0, -21109, 0, -21109, 0, 9315, 0, -21108, 0, -21104, 0, 15843, 0, -21103, 0, -21103, 0, 9316, 0, -21102, 0, -21088, 0, 15848, 0, -20928, 0, -20909, 0, 15863, 0, -20908, 0, -20908, 0, 9381, 0, -20907, 0, -20895, 0, 15883, 0, -20894, 0, -20894, 0, 7792, 0, -20893, 0, -20866, 0, 15896, 0, -20864, 0, -20864, 0, 8335, 0, -20863, 0, -20860, 0, 15924, 0, -20859, 0, -20859, 0, 7746, 0, -20858, 0, -20854, 0, 15928, 0, -20853, 0, -20853, 0, 8014, 0, -20852, 0, -20845, 0, 15933, 0, -20844, 0, -20844, 0, 7857, 0, -20843, 0, -20833, 0, 15941, 0, -20832, 0, -20832, 0, 7819, 0, -20672, 0, -20637, 0, 15952, 0, -20636, 0, -20636, 0, 8134, 0, -20635, 0, -20614, 0, 15988, 0, -20613, 0, -20613, 0, 9646, 0, -20612, 0, -20610, 0, 16010, 0, -20608, 0, -20607, 0, 16013, 0, -20606, 0, -20606, 0, 7937, 0, -20605, 0, -20605, 0, 8704, 0, -20604, 0, -20595, 0, 16015, 0, -20594, 0, -20594, 0, 9650, 0, -20593, 0, -20593, 0, 7831, 0, -20592, 0, -20592, 0, 16025, 0, -20591, 0, -20591, 0, 8363, 0, -20590, 0, -20581, 0, 16026, 0, -20580, 0, -20580, 0, 9651, 0, -20579, 0, -20578, 0, 16036, 0, -20577, 0, -20577, 0, 8232, 0, -20576, 0, -20576, 0, 16038, 0, -20416, 0, -20416, 0, 16039, 0, -20415, 0, -20414, 0, 9647, 0, -20413, 0, -20413, 0, 16040, 0, -20412, 0, -20412, 0, 9649, 0, -20411, 0, -20402, 0, 16041, 0, -20401, 0, -20401, 0, 9644, 0, -20400, 0, -20397, 0, 16051, 0, -20396, 0, -20396, 0, 7758, 0, -20395, 0, -20394, 0, 16055, 0, -20393, 0, -20393, 0, 8706, 0, -20392, 0, -20392, 0, 9643, 0, -20391, 0, -20391, 0, 8838, 0, -20390, 0, -20390, 0, 16057, 0, -20389, 0, -20389, 0, 9645, 0, -20388, 0, -20388, 0, 16058, 0, -20387, 0, -20387, 0, 9654, 0, -20386, 0, -20386, 0, 16059, 0, -20385, 0, -20385, 0, 8675, 0, -20384, 0, -20383, 0, 9652, 0, -20382, 0, -20382, 0, 8751, 0, -20381, 0, -20381, 0, 8549, 0, -20380, 0, -20380, 0, 9655, 0, -20379, 0, -20373, 0, 16060, 0, -20372, 0, -20372, 0, 7913, 0, -20371, 0, -20356, 0, 16067, 0, -20355, 0, -20355, 0, 7717, 0, -20354, 0, -20354, 0, 16083, 0, -20352, 0, -20330, 0, 16084, 0, -20329, 0, -20329, 0, 9664, 0, -20328, 0, -20328, 0, 16107, 0, -20327, 0, -20327, 0, 8858, 0, -20326, 0, -20320, 0, 16108, 0, -20319, 0, -20226, 0, 940, 0, -20160, 0, -20150, 0, 16115, 0, -20149, 0, -20149, 0, 8814, 0, -20148, 0, -20148, 0, 16126, 0, -20147, 0, -20147, 0, 8125, 0, -20146, 0, -20146, 0, 16127, 0, -20145, 0, -20145, 0, 8068, 0, -20144, 0, -20144, 0, 8370, 0, -20143, 0, -20143, 0, 16128, 0, -20142, 0, -20142, 0, 8259, 0, -20141, 0, -20098, 0, 16129, 0, -20096, 0, -20074, 0, 16173, 0, -20073, 0, -20073, 0, 9860, 0, -20072, 0, -20064, 0, 16196, 0, -20063, 0, -19970, 0, 1034, 0, -19904, 0, -19904, 0, 16205, 0, -19903, 0, -19903, 0, 9455, 0, -19902, 0, -19866, 0, 16206, 0, -19865, 0, -19865, 0, 9454, 0, -19864, 0, -19860, 0, 16243, 0, -19859, 0, -19859, 0, 8308, 0, -19858, 0, -19853, 0, 16248, 0, -19852, 0, -19852, 0, 9863, 0, -19851, 0, -19842, 0, 16254, 0, -19840, 0, -19840, 0, 9456, 0, -19839, 0, -19832, 0, 16264, 0, -19831, 0, -19831, 0, 9869, 0, -19830, 0, -19815, 0, 16272, 0, -19814, 0, -19814, 0, 8864, 0, -19813, 0, -19808, 0, 16288, 0, -19807, 0, -19714, 0, 1128, 0, -19648, 0, -19646, 0, 16294, 0, -19645, 0, -19645, 0, 8107, 0, -19644, 0, -19601, 0, 16297, 0, -19600, 0, -19600, 0, 9896, 0, -19599, 0, -19586, 0, 16341, 0, -19584, 0, -19577, 0, 16355, 0, -19576, 0, -19576, 0, 9449, 0, -19575, 0, -19573, 0, 16363, 0, -19572, 0, -19572, 0, 9445, 0, -19571, 0, -19571, 0, 16366, 0, -19570, 0, -19570, 0, 8698, 0, -19569, 0, -19552, 0, 16367, 0, -19551, 0, -19458, 0, 1222, 0, -19392, 0, -19373, 0, 16385, 0, -19372, 0, -19372, 0, 8520, 0, -19371, 0, -19369, 0, 16405, 0, -19368, 0, -19368, 0, 9444, 0, -19367, 0, -19363, 0, 16408, 0, -19362, 0, -19362, 0, 9446, 0, -19361, 0, -19361, 0, 8439, 0, -19360, 0, -19360, 0, 16413, 0, -19359, 0, -19359, 0, 8299, 0, -19358, 0, -19340, 0, 16414, 0, -19339, 0, -19339, 0, 8871, 0, -19338, 0, -19331, 0, 16433, 0, -19330, 0, -19330, 0, 9452, 0, -19328, 0, -19326, 0, 16441, 0, -19325, 0, -19325, 0, 9451, 0, -19324, 0, -19320, 0, 16444, 0, -19319, 0, -19319, 0, 9443, 0, -19318, 0, -19310, 0, 16449, 0, -19309, 0, -19309, 0, 9450, 0, -19308, 0, -19296, 0, 16458, 0, -19295, 0, -19202, 0, 1316, 0, -19136, 0, -19136, 0, 16471, 0, -19135, 0, -19135, 0, 7826, 0, -19134, 0, -19126, 0, 16472, 0, -19125, 0, -19125, 0, 7719, 0, -19124, 0, -19115, 0, 16481, 0, -19114, 0, -19114, 0, 8166, 0, -19113, 0, -19111, 0, 16491, 0, -19110, 0, -19110, 0, 9447, 0, -19109, 0, -19109, 0, 8210, 0, -19108, 0, -19108, 0, 7916, 0, -19107, 0, -19104, 0, 16494, 0, -19103, 0, -19103, 0, 9448, 0, -19102, 0, -19074, 0, 16498, 0, -19072, 0, -19045, 0, 16527, 0, -19044, 0, -19044, 0, 8038, 0, -19043, 0, -19043, 0, 9436, 0, -19042, 0, -19040, 0, 16555, 0, -19039, 0, -18946, 0, 1410, 0, -18880, 0, -18863, 0, 16558, 0, -18862, 0, -18862, 0, 9890, 0, -18861, 0, -18860, 0, 16576, 0, -18859, 0, -18859, 0, 9437, 0, -18858, 0, -18856, 0, 16578, 0, -18855, 0, -18855, 0, 8206, 0, -18854, 0, -18854, 0, 16581, 0, -18853, 0, -18853, 0, 9435, 0, -18852, 0, -18852, 0, 7864, 0, -18851, 0, -18818, 0, 16582, 0, -18816, 0, -18784, 0, 16616, 0, -18783, 0, -18690, 0, 1504, 0, -18624, 0, -18611, 0, 16649, 0, -18610, 0, -18610, 0, 8853, 0, -18609, 0, -18608, 0, 16663, 0, -18607, 0, -18607, 0, 7808, 0, -18606, 0, -18600, 0, 16665, 0, -18599, 0, -18599, 0, 9847, 0, -18598, 0, -18589, 0, 16672, 0, -18588, 0, -18588, 0, 9764, 0, -18587, 0, -18587, 0, 8041, 0, -18586, 0, -18586, 0, 8747, 0, -18585, 0, -18570, 0, 16682, 0, -18569, 0, -18569, 0, 9599, 0, -18568, 0, -18568, 0, 8027, 0, -18567, 0, -18562, 0, 16698, 0, -18560, 0, -18560, 0, 8603, 0, -18559, 0, -18559, 0, 16704, 0, -18558, 0, -18558, 0, 9853, 0, -18557, 0, -18528, 0, 16705, 0, -18527, 0, -18434, 0, 1598, 0, -18368, 0, -18366, 0, 16735, 0, -18365, 0, -18365, 0, 8608, 0, -18364, 0, -18364, 0, 8582, 0, -18363, 0, -18363, 0, 16738, 0, -18362, 0, -18362, 0, 8429, 0, -18361, 0, -18356, 0, 16739, 0, -18355, 0, -18355, 0, 9657, 0, -18354, 0, -18352, 0, 16745, 0, -18351, 0, -18351, 0, 8170, 0, -18350, 0, -18343, 0, 16748, 0, -18342, 0, -18342, 0, 7844, 0, -18341, 0, -18341, 0, 8417, 0, -18340, 0, -18340, 0, 16756, 0, -18339, 0, -18339, 0, 9656, 0, -18338, 0, -18338, 0, 8800, 0, -18337, 0, -18337, 0, 16757, 0, -18336, 0, -18336, 0, 8418, 0, -18335, 0, -18314, 0, 16758, 0, -18313, 0, -18313, 0, 8513, 0, -18312, 0, -18306, 0, 16780, 0, -18304, 0, -18303, 0, 16787, 0, -18302, 0, -18302, 0, 8135, 0, -18301, 0, -18272, 0, 16789, 0, -18271, 0, -18178, 0, 1692, 0, -18112, 0, -18097, 0, 16819, 0, -18096, 0, -18096, 0, 7745, 0, -18095, 0, -18080, 0, 16835, 0, -18079, 0, -18079, 0, 9700, 0, -18078, 0, -18054, 0, 16851, 0, -18053, 0, -18053, 0, 8070, 0, -18052, 0, -18050, 0, 16876, 0, -18048, 0, -18020, 0, 16879, 0, -18019, 0, -18019, 0, 8115, 0, -18018, 0, -18017, 0, 16908, 0, -18016, 0, -18016, 0, 7919, 0, -18015, 0, -17922, 0, 1786, 0, -17856, 0, -17855, 0, 16910, 0, -17854, 0, -17854, 0, 8868, 0, -17853, 0, -17853, 0, 16912, 0, -17852, 0, -17852, 0, 9704, 0, -17851, 0, -17835, 0, 16913, 0, -17834, 0, -17834, 0, 9699, 0, -17833, 0, -17832, 0, 16930, 0, -17831, 0, -17831, 0, 8465, 0, -17830, 0, -17825, 0, 16932, 0, -17824, 0, -17824, 0, 9702, 0, -17823, 0, -17815, 0, 16938, 0, -17814, 0, -17814, 0, 9703, 0, -17813, 0, -17805, 0, 16947, 0, -17804, 0, -17804, 0, 8257, 0, -17803, 0, -17794, 0, 16956, 0, -17792, 0, -17789, 0, 16966, 0, -17788, 0, -17788, 0, 9706, 0, -17787, 0, -17787, 0, 16970, 0, -17786, 0, -17786, 0, 8079, 0, -17785, 0, -17785, 0, 16971, 0, -17784, 0, -17784, 0, 9708, 0, -17783, 0, -17780, 0, 16972, 0, -17779, 0, -17779, 0, 9707, 0, -17778, 0, -17763, 0, 16976, 0, -17762, 0, -17762, 0, 8400, 0, -17761, 0, -17761, 0, 8221, 0, -17760, 0, -17760, 0, 16992, 0, -17759, 0, -17666, 0, 1880, 0, -17600, 0, -17600, 0, 8183, 0, -17599, 0, -17592, 0, 16993, 0, -17591, 0, -17591, 0, 7821, 0, -17590, 0, -17577, 0, 17001, 0, -17576, 0, -17576, 0, 9705, 0, -17575, 0, -17574, 0, 17015, 0, -17573, 0, -17573, 0, 9710, 0, -17572, 0, -17572, 0, 8250, 0, -17571, 0, -17569, 0, 17017, 0, -17568, 0, -17568, 0, 9875, 0, -17567, 0, -17564, 0, 17020, 0, -17563, 0, -17563, 0, 9701, 0, -17562, 0, -17562, 0, 9709, 0, -17561, 0, -17561, 0, 17024, 0, -17560, 0, -17560, 0, 8201, 0, -17559, 0, -17559, 0, 17025, 0, -17558, 0, -17558, 0, 8293, 0, -17557, 0, -17555, 0, 17026, 0, -17554, 0, -17554, 0, 9891, 0, -17553, 0, -17538, 0, 17029, 0, -17536, 0, -17504, 0, 17045, 0, -17503, 0, -17410, 0, 1974, 0, -17344, 0, -17327, 0, 17078, 0, -17326, 0, -17326, 0, 9717, 0, -17325, 0, -17325, 0, 7932, 0, -17324, 0, -17319, 0, 17096, 0, -17318, 0, -17318, 0, 8228, 0, -17317, 0, -17312, 0, 17102, 0, -17311, 0, -17311, 0, 9883, 0, -17310, 0, -17310, 0, 17108, 0, -17309, 0, -17309, 0, 9715, 0, -17308, 0, -17308, 0, 17109, 0, -17307, 0, -17307, 0, 8921, 0, -17306, 0, -17306, 0, 17110, 0, -17305, 0, -17305, 0, 9716, 0, -17304, 0, -17304, 0, 17111, 0, -17303, 0, -17303, 0, 9243, 0, -17302, 0, -17300, 0, 17112, 0, -17299, 0, -17299, 0, 8136, 0, -17298, 0, -17298, 0, 17115, 0, -17297, 0, -17297, 0, 8059, 0, -17296, 0, -17296, 0, 17116, 0, -17295, 0, -17295, 0, 9245, 0, -17294, 0, -17294, 0, 17117, 0, -17293, 0, -17293, 0, 8780, 0, -17292, 0, -17292, 0, 8008, 0, -17291, 0, -17291, 0, 9244, 0, -17290, 0, -17289, 0, 9246, 0, -17288, 0, -17288, 0, 8447, 0, -17287, 0, -17287, 0, 8602, 0, -17286, 0, -17286, 0, 17118, 0, -17285, 0, -17285, 0, 8337, 0, -17284, 0, -17283, 0, 17119, 0, -17282, 0, -17282, 0, 8359, 0, -17280, 0, -17279, 0, 17121, 0, -17278, 0, -17278, 0, 9251, 0, -17277, 0, -17277, 0, 7835, 0, -17276, 0, -17276, 0, 9250, 0, -17275, 0, -17275, 0, 17123, 0, -17274, 0, -17274, 0, 8464, 0, -17273, 0, -17273, 0, 17124, 0, -17272, 0, -17272, 0, 8845, 0, -17271, 0, -17271, 0, 8049, 0, -17270, 0, -17270, 0, 7928, 0, -17269, 0, -17269, 0, 9249, 0, -17268, 0, -17266, 0, 17125, 0, -17265, 0, -17265, 0, 7923, 0, -17264, 0, -17255, 0, 17128, 0, -17254, 0, -17254, 0, 8625, 0, -17253, 0, -17253, 0, 9254, 0, -17252, 0, -17252, 0, 9253, 0, -17251, 0, -17251, 0, 8480, 0, -17250, 0, -17248, 0, 17138, 0, -17247, 0, -17154, 0, 2068, 0, -17088, 0, -17087, 0, 17141, 0, -17086, 0, -17086, 0, 8474, 0, -17085, 0, -17085, 0, 9252, 0, -17084, 0, -17084, 0, 17143, 0, -17083, 0, -17083, 0, 9256, 0, -17082, 0, -17081, 0, 17144, 0, -17080, 0, -17080, 0, 9258, 0, -17079, 0, -17079, 0, 9257, 0, -17078, 0, -17078, 0, 17146, 0, -17077, 0, -17077, 0, 8852, 0, -17076, 0, -17076, 0, 17147, 0, -17075, 0, -17075, 0, 8894, 0, -17074, 0, -17074, 0, 17148, 0, -17073, 0, -17073, 0, 7729, 0, -17072, 0, -17066, 0, 17149, 0, -17065, 0, -17065, 0, 9260, 0, -17064, 0, -17064, 0, 17156, 0, -17063, 0, -17063, 0, 8117, 0, -17062, 0, -17051, 0, 17157, 0, -17050, 0, -17050, 0, 9259, 0, -17049, 0, -17049, 0, 8111, 0, -17048, 0, -17047, 0, 17169, 0, -17046, 0, -17046, 0, 8296, 0, -17045, 0, -17045, 0, 8676, 0, -17044, 0, -17042, 0, 17171, 0, -17041, 0, -17041, 0, 7969, 0, -17040, 0, -17040, 0, 17174, 0, -17039, 0, -17039, 0, 8449, 0, -17038, 0, -17032, 0, 17175, 0, -17031, 0, -17031, 0, 8572, 0, -17030, 0, -17030, 0, 8522, 0, -17029, 0, -17029, 0, 9261, 0, -17028, 0, -17027, 0, 17182, 0, -17026, 0, -17026, 0, 8148, 0, -17024, 0, -17024, 0, 17184, 0, -17023, 0, -17023, 0, 8145, 0, -17022, 0, -17016, 0, 17185, 0, -17015, 0, -17015, 0, 7731, 0, -17014, 0, -17014, 0, 17192, 0, -17013, 0, -17013, 0, 9263, 0, -17012, 0, -17011, 0, 17193, 0, -17010, 0, -17010, 0, 9262, 0, -17009, 0, -17009, 0, 17195, 0, -17008, 0, -17008, 0, 9264, 0, -17007, 0, -17007, 0, 8667, 0, -17006, 0, -17002, 0, 17196, 0, -17001, 0, -17001, 0, 8536, 0, -17000, 0, -16998, 0, 17201, 0, -16997, 0, -16997, 0, 8130, 0, -16996, 0, -16992, 0, 17204, 0, -16991, 0, -16898, 0, 2162, 0, -16832, 0, -16830, 0, 17209, 0, -16829, 0, -16829, 0, 8889, 0, -16828, 0, -16828, 0, 17212, 0, -16827, 0, -16827, 0, 9270, 0, -16826, 0, -16824, 0, 17213, 0, -16823, 0, -16823, 0, 7822, 0, -16822, 0, -16822, 0, 9273, 0, -16821, 0, -16816, 0, 17216, 0, -16815, 0, -16815, 0, 8645, 0, -16814, 0, -16814, 0, 9271, 0, -16813, 0, -16813, 0, 8594, 0, -16812, 0, -16812, 0, 17222, 0, -16811, 0, -16811, 0, 9274, 0, -16810, 0, -16810, 0, 7961, 0, -16809, 0, -16809, 0, 8588, 0, -16808, 0, -16808, 0, 7744, 0, -16807, 0, -16807, 0, 8883, 0, -16806, 0, -16804, 0, 17223, 0, -16803, 0, -16803, 0, 8287, 0, -16802, 0, -16802, 0, 9272, 0, -16801, 0, -16801, 0, 9266, 0, -16800, 0, -16800, 0, 8820, 0, -16799, 0, -16799, 0, 17226, 0, -16798, 0, -16798, 0, 7836, 0, -16797, 0, -16797, 0, 9265, 0, -16796, 0, -16796, 0, 8325, 0, -16795, 0, -16792, 0, 17227, 0, -16791, 0, -16791, 0, 9269, 0, -16790, 0, -16789, 0, 17231, 0, -16788, 0, -16788, 0, 9275, 0, -16787, 0, -16786, 0, 17233, 0, -16785, 0, -16785, 0, 8119, 0, -16784, 0, -16784, 0, 9267, 0, -16783, 0, -16779, 0, 17235, 0, -16778, 0, -16778, 0, 8276, 0, -16777, 0, -16777, 0, 8670, 0, -16776, 0, -16776, 0, 17240, 0, -16775, 0, -16775, 0, 9268, 0, -16774, 0, -16773, 0, 17241, 0, -16772, 0, -16772, 0, 9277, 0, -16771, 0, -16771, 0, 8073, 0, -16770, 0, -16770, 0, 9276, 0, -16768, 0, -16766, 0, 17243, 0, -16765, 0, -16765, 0, 8046, 0, -16764, 0, -16764, 0, 7896, 0, -16763, 0, -16763, 0, 17246, 0, -16762, 0, -16762, 0, 7871, 0, -16761, 0, -16761, 0, 9285, 0, -16760, 0, -16760, 0, 17247, 0, -16759, 0, -16759, 0, 8777, 0, -16758, 0, -16757, 0, 17248, 0, -16756, 0, -16756, 0, 9281, 0, -16755, 0, -16755, 0, 17250, 0, -16754, 0, -16754, 0, 7751, 0, -16753, 0, -16753, 0, 8022, 0, -16752, 0, -16751, 0, 17251, 0, -16750, 0, -16750, 0, 8326, 0, -16749, 0, -16748, 0, 17253, 0, -16747, 0, -16747, 0, 8598, 0, -16746, 0, -16746, 0, 17255, 0, -16745, 0, -16745, 0, 9283, 0, -16744, 0, -16744, 0, 9279, 0, -16743, 0, -16743, 0, 17256, 0, -16742, 0, -16742, 0, 8227, 0, -16741, 0, -16741, 0, 17257, 0, -16740, 0, -16740, 0, 9282, 0, -16739, 0, -16738, 0, 17258, 0, -16737, 0, -16737, 0, 9278, 0, -16736, 0, -16736, 0, 17260, 0, -16735, 0, -16642, 0, 2256, 0, -16576, 0, -16576, 0, 9894, 0, -16575, 0, -16564, 0, 17261, 0, -16563, 0, -16563, 0, 9038, 0, -16562, 0, -16562, 0, 9286, 0, -16561, 0, -16561, 0, 9291, 0, -16560, 0, -16560, 0, 9284, 0, -16559, 0, -16556, 0, 17273, 0, -16555, 0, -16555, 0, 9255, 0, -16554, 0, -16554, 0, 9292, 0, -16553, 0, -16545, 0, 17277, 0, -16544, 0, -16544, 0, 7951, 0, -16543, 0, -16543, 0, 17286, 0, -16542, 0, -16542, 0, 9287, 0, -16541, 0, -16541, 0, 9289, 0, -16540, 0, -16540, 0, 9288, 0, -16539, 0, -16537, 0, 17287, 0, -16536, 0, -16536, 0, 8642, 0, -16535, 0, -16533, 0, 17290, 0, -16532, 0, -16532, 0, 8558, 0, -16531, 0, -16529, 0, 17293, 0, -16528, 0, -16528, 0, 7939, 0, -16527, 0, -16527, 0, 17296, 0, -16526, 0, -16526, 0, 9290, 0, -16525, 0, -16525, 0, 8540, 0, -16524, 0, -16523, 0, 17297, 0, -16522, 0, -16522, 0, 8891, 0, -16521, 0, -16521, 0, 9296, 0, -16520, 0, -16520, 0, 17299, 0, -16519, 0, -16519, 0, 9876, 0, -16518, 0, -16518, 0, 9295, 0, -16517, 0, -16517, 0, 9718, 0, -16516, 0, -16516, 0, 8273, 0, -16515, 0, -16515, 0, 17300, 0, -16514, 0, -16514, 0, 9294, 0, -16512, 0, -16511, 0, 17301, 0, -16510, 0, -16510, 0, 8890, 0, -16509, 0, -16509, 0, 8045, 0, -16508, 0, -16504, 0, 17303, 0, -16503, 0, -16503, 0, 9298, 0, -16502, 0, -16502, 0, 9297, 0, -16501, 0, -16492, 0, 17308, 0, -16491, 0, -16491, 0, 9301, 0, -16490, 0, -16490, 0, 17318, 0, -16489, 0, -16489, 0, 8841, 0, -16488, 0, -16488, 0, 8470, 0, -16487, 0, -16484, 0, 17319, 0, -16483, 0, -16483, 0, 9300, 0, -16482, 0, -16480, 0, 17323, 0, -16479, 0, -16386, 0, 2350, 0, -16320, 0, -16320, 0, 8443, 0, -16319, 0, -16317, 0, 17326, 0, -16316, 0, -16316, 0, 9280, 0, -16315, 0, -16310, 0, 17329, 0, -16309, 0, -16309, 0, 8486, 0, -16308, 0, -16308, 0, 8033, 0, -16307, 0, -16307, 0, 9885, 0, -16306, 0, -16306, 0, 17335, 0, -16305, 0, -16305, 0, 8074, 0, -16304, 0, -16304, 0, 9302, 0, -16303, 0, -16303, 0, 9305, 0, -16302, 0, -16302, 0, 9304, 0, -16301, 0, -16300, 0, 17336, 0, -16299, 0, -16299, 0, 8110, 0, -16298, 0, -16294, 0, 17338, 0, -16293, 0, -16293, 0, 8730, 0, -16292, 0, -16291, 0, 17343, 0, -16290, 0, -16290, 0, 8058, 0, -16289, 0, -16289, 0, 9293, 0, -16288, 0, -16288, 0, 9303, 0, -16287, 0, -16280, 0, 17345, 0, -16279, 0, -16279, 0, 9299, 0, -16278, 0, -16278, 0, 17353, 0, -16277, 0, -16277, 0, 9248, 0, -16276, 0, -16276, 0, 17354, 0, -16275, 0, -16275, 0, 8671, 0, -16274, 0, -16274, 0, 9861, 0, -16273, 0, -16273, 0, 17355, 0, -16272, 0, -16272, 0, 7790, 0, -16271, 0, -16269, 0, 17356, 0, -16268, 0, -16268, 0, 8740, 0, -16267, 0, -16267, 0, 9840, 0, -16266, 0, -16266, 0, 17359, 0, -16265, 0, -16265, 0, 8634, 0, -16264, 0, -16264, 0, 17360, 0, -16263, 0, -16263, 0, 9306, 0, -16262, 0, -16261, 0, 17361, 0, -16260, 0, -16260, 0, 8191, 0, -16259, 0, -16258, 0, 17363, 0, -16256, 0, -16230, 0, 17365, 0, -16229, 0, -16229, 0, 9698, 0, -16228, 0, -16228, 0, 17392, 0, -16227, 0, -16227, 0, 9882, 0, -16226, 0, -16224, 0, 17393, 0, -16223, 0, -16130, 0, 2444, 0, -16064, 0, -16049, 0, 17396, 0, -16048, 0, -16048, 0, 7914, 0, -16047, 0, -16045, 0, 17412, 0, -16044, 0, -16044, 0, 7724, 0, -16043, 0, -16034, 0, 17415, 0, -16033, 0, -16033, 0, 8290, 0, -16032, 0, -16032, 0, 9457, 0, -16031, 0, -16031, 0, 17425, 0, -16030, 0, -16030, 0, 9458, 0, -16029, 0, -16012, 0, 17426, 0, -16011, 0, -16011, 0, 9714, 0, -16010, 0, -16009, 0, 17444, 0, -16008, 0, -16008, 0, 8725, 0, -16007, 0, -16002, 0, 17446, 0, -16000, 0, -15980, 0, 17452, 0, -15979, 0, -15979, 0, 8622, 0, -15978, 0, -15968, 0, 17473, 0, -15967, 0, -15874, 0, 2538, 0, -15808, 0, -15795, 0, 17484, 0, -15794, 0, -15794, 0, 8416, 0, -15793, 0, -15772, 0, 17498, 0, -15771, 0, -15771, 0, 9666, 0, -15770, 0, -15770, 0, 17520, 0, -15769, 0, -15769, 0, 9665, 0, -15768, 0, -15748, 0, 17521, 0, -15747, 0, -15747, 0, 8488, 0, -15746, 0, -15746, 0, 17542, 0, -15744, 0, -15741, 0, 17543, 0, -15740, 0, -15740, 0, 8601, 0, -15739, 0, -15726, 0, 17547, 0, -15725, 0, -15725, 0, 8215, 0, -15724, 0, -15724, 0, 7840, 0, -15723, 0, -15723, 0, 8485, 0, -15722, 0, -15722, 0, 8525, 0, -15721, 0, -15721, 0, 17561, 0, -15720, 0, -15720, 0, 9668, 0, -15719, 0, -15719, 0, 8349, 0, -15718, 0, -15718, 0, 8842, 0, -15717, 0, -15717, 0, 17562, 0, -15716, 0, -15716, 0, 9667, 0, -15715, 0, -15713, 0, 17563, 0, -15712, 0, -15712, 0, 8569, 0, -15711, 0, -15618, 0, 2632, 0, -15552, 0, -15552, 0, 8248, 0, -15551, 0, -15550, 0, 17566, 0, -15549, 0, -15549, 0, 8533, 0, -15548, 0, -15494, 0, 17568, 0, -15493, 0, -15493, 0, 8658, 0, -15492, 0, -15490, 0, 17623, 0, -15488, 0, -15485, 0, 17626, 0, -15484, 0, -15484, 0, 9415, 0, -15483, 0, -15462, 0, 17630, 0, -15461, 0, -15461, 0, 8825, 0, -15460, 0, -15456, 0, 17652, 0, -15455, 0, -15362, 0, 2726, 0, -15296, 0, -15288, 0, 17657, 0, -15287, 0, -15287, 0, 8483, 0, -15286, 0, -15285, 0, 17666, 0, -15284, 0, -15284, 0, 9413, 0, -15283, 0, -15277, 0, 17668, 0, -15276, 0, -15276, 0, 9417, 0, -15275, 0, -15273, 0, 17675, 0, -15272, 0, -15272, 0, 8340, 0, -15271, 0, -15270, 0, 17678, 0, -15269, 0, -15269, 0, 8854, 0, -15268, 0, -15262, 0, 17680, 0, -15261, 0, -15261, 0, 7799, 0, -15260, 0, -15242, 0, 17687, 0, -15241, 0, -15241, 0, 7942, 0, -15240, 0, -15239, 0, 17706, 0, -15238, 0, -15238, 0, 8101, 0, -15237, 0, -15234, 0, 17708, 0, -15232, 0, -15232, 0, 17712, 0, -15231, 0, -15231, 0, 8345, 0, -15230, 0, -15216, 0, 17713, 0, -15215, 0, -15215, 0, 7853, 0, -15214, 0, -15214, 0, 9416, 0, -15213, 0, -15213, 0, 8360, 0, -15212, 0, -15209, 0, 17728, 0, -15208, 0, -15208, 0, 8223, 0, -15207, 0, -15207, 0, 17732, 0, -15206, 0, -15206, 0, 8389, 0, -15205, 0, -15205, 0, 17733, 0, -15204, 0, -15204, 0, 9418, 0, -15203, 0, -15200, 0, 17734, 0, -15199, 0, -15106, 0, 2820, 0, -15040, 0, -15037, 0, 17738, 0, -15036, 0, -15036, 0, 8176, 0, -15035, 0, -15035, 0, 17742, 0, -15034, 0, -15034, 0, 9414, 0, -15033, 0, -15030, 0, 17743, 0, -15029, 0, -15029, 0, 8797, 0, -15028, 0, -15028, 0, 8926, 0, -15027, 0, -15023, 0, 17747, 0, -15022, 0, -15022, 0, 8236, 0, -15021, 0, -15010, 0, 17752, 0, -15009, 0, -15009, 0, 8545, 0, -15008, 0, -15006, 0, 17764, 0, -15005, 0, -15005, 0, 8763, 0, -15004, 0, -15004, 0, 8665, 0, -15003, 0, -15003, 0, 8139, 0, -15002, 0, -15002, 0, 8137, 0, -15001, 0, -14978, 0, 17767, 0, -14976, 0, -14958, 0, 17791, 0, -14957, 0, -14957, 0, 7777, 0, -14956, 0, -14949, 0, 17810, 0, -14948, 0, -14948, 0, 9711, 0, -14947, 0, -14947, 0, 17818, 0, -14946, 0, -14946, 0, 8088, 0, -14945, 0, -14944, 0, 17819, 0, -14943, 0, -14850, 0, 2914, 0, -14784, 0, -14784, 0, 17821, 0, -14783, 0, -14783, 0, 9712, 0, -14782, 0, -14781, 0, 17822, 0, -14780, 0, -14780, 0, 8072, 0, -14779, 0, -14778, 0, 17824, 0, -14777, 0, -14777, 0, 8696, 0, -14776, 0, -14750, 0, 17826, 0, -14749, 0, -14749, 0, 8994, 0, -14748, 0, -14735, 0, 17853, 0, -14734, 0, -14734, 0, 9014, 0, -14733, 0, -14722, 0, 17867, 0, -14720, 0, -14688, 0, 17879, 0, -14687, 0, -14594, 0, 3008, 0, -14528, 0, -14491, 0, 17912, 0, -14490, 0, -14490, 0, 8875, 0, -14489, 0, -14482, 0, 17950, 0, -14481, 0, -14481, 0, 8127, 0, -14480, 0, -14475, 0, 17958, 0, -14474, 0, -14474, 0, 8061, 0, -14473, 0, -14470, 0, 17964, 0, -14469, 0, -14469, 0, 9011, 0, -14468, 0, -14466, 0, 17968, 0, -14464, 0, -14432, 0, 17971, 0, -14431, 0, -14338, 0, 3102, 0, -14272, 0, -14272, 0, 18004, 0, -14271, 0, -14271, 0, 8013, 0, -14270, 0, -14258, 0, 18005, 0, -14257, 0, -14257, 0, 9012, 0, -14256, 0, -14255, 0, 18018, 0, -14254, 0, -14254, 0, 8177, 0, -14253, 0, -14235, 0, 18020, 0, -14234, 0, -14234, 0, 8587, 0, -14233, 0, -14227, 0, 18039, 0, -14226, 0, -14226, 0, 9033, 0, -14225, 0, -14211, 0, 18046, 0, -14210, 0, -14210, 0, 8715, 0, -14208, 0, -14202, 0, 18061, 0, -14201, 0, -14201, 0, 9030, 0, -14200, 0, -14191, 0, 18068, 0, -14190, 0, -14190, 0, 9031, 0, -14189, 0, -14189, 0, 18078, 0, -14188, 0, -14188, 0, 8595, 0, -14187, 0, -14184, 0, 18079, 0, -14183, 0, -14183, 0, 9889, 0, -14182, 0, -14180, 0, 18083, 0, -14179, 0, -14179, 0, 8034, 0, -14178, 0, -14176, 0, 18086, 0, -14175, 0, -14082, 0, 3196, 0, -14016, 0, -14002, 0, 18089, 0, -14001, 0, -14001, 0, 9037, 0, -14000, 0, -14000, 0, 9032, 0, -13999, 0, -13971, 0, 18104, 0, -13970, 0, -13970, 0, 7776, 0, -13969, 0, -13969, 0, 18133, 0, -13968, 0, -13968, 0, 9029, 0, -13967, 0, -13962, 0, 18134, 0, -13961, 0, -13961, 0, 7954, 0, -13960, 0, -13954, 0, 18140, 0, -13952, 0, -13938, 0, 18147, 0, -13937, 0, -13937, 0, 8216, 0, -13936, 0, -13936, 0, 9013, 0, -13935, 0, -13925, 0, 18162, 0, -13924, 0, -13924, 0, 9020, 0, -13923, 0, -13920, 0, 18173, 0, -13919, 0, -13826, 0, 3290, 0, -13760, 0, -13747, 0, 18177, 0, -13746, 0, -13746, 0, 9839, 0, -13745, 0, -13739, 0, 18191, 0, -13738, 0, -13738, 0, 9041, 0, -13737, 0, -13736, 0, 18198, 0, -13735, 0, -13735, 0, 8096, 0, -13734, 0, -13733, 0, 18200, 0, -13732, 0, -13732, 0, 9016, 0, -13731, 0, -13728, 0, 18202, 0, -13727, 0, -13727, 0, 8731, 0, -13726, 0, -13715, 0, 18206, 0, -13714, 0, -13714, 0, 9026, 0, -13713, 0, -13711, 0, 18218, 0, -13710, 0, -13710, 0, 9039, 0, -13709, 0, -13706, 0, 18221, 0, -13705, 0, -13705, 0, 9021, 0, -13704, 0, -13702, 0, 18225, 0, -13701, 0, -13701, 0, 9028, 0, -13700, 0, -13700, 0, 9009, 0, -13699, 0, -13699, 0, 18228, 0, -13698, 0, -13698, 0, 9035, 0, -13696, 0, -13696, 0, 18229, 0, -13695, 0, -13695, 0, 9019, 0, -13694, 0, -13688, 0, 18230, 0, -13687, 0, -13687, 0, 9040, 0, -13686, 0, -13683, 0, 18237, 0, -13682, 0, -13682, 0, 7860, 0, -13681, 0, -13681, 0, 8614, 0, -13680, 0, -13679, 0, 18241, 0, -13678, 0, -13678, 0, 8651, 0, -13677, 0, -13671, 0, 18243, 0, -13670, 0, -13670, 0, 9045, 0, -13669, 0, -13664, 0, 18250, 0, -13663, 0, -13570, 0, 3384, 0, -13504, 0, -13502, 0, 18256, 0, -13501, 0, -13501, 0, 9022, 0, -13500, 0, -13500, 0, 18259, 0, -13499, 0, -13499, 0, 8052, 0, -13498, 0, -13498, 0, 18260, 0, -13497, 0, -13497, 0, 9008, 0, -13496, 0, -13494, 0, 18261, 0, -13493, 0, -13493, 0, 9856, 0, -13492, 0, -13491, 0, 18264, 0, -13490, 0, -13490, 0, 8410, 0, -13489, 0, -13482, 0, 18266, 0, -13481, 0, -13481, 0, 9034, 0, -13480, 0, -13476, 0, 18274, 0, -13475, 0, -13475, 0, 8081, 0, -13474, 0, -13474, 0, 18279, 0, -13473, 0, -13473, 0, 8455, 0, -13472, 0, -13463, 0, 18280, 0, -13462, 0, -13462, 0, 9023, 0, -13461, 0, -13446, 0, 18290, 0, -13445, 0, -13445, 0, 8180, 0, -13444, 0, -13444, 0, 9027, 0, -13443, 0, -13442, 0, 18306, 0, -13440, 0, -13434, 0, 18308, 0, -13433, 0, -13433, 0, 8722, 0, -13432, 0, -13427, 0, 18315, 0, -13426, 0, -13426, 0, 8711, 0, -13425, 0, -13423, 0, 18321, 0, -13422, 0, -13422, 0, 9049, 0, -13421, 0, -13413, 0, 18324, 0, -13412, 0, -13412, 0, 8788, 0, -13411, 0, -13411, 0, 18333, 0, -13410, 0, -13410, 0, 9010, 0, -13409, 0, -13408, 0, 18334, 0, -13407, 0, -13314, 0, 3478, 0, -13248, 0, -13248, 0, 7718, 0, -13247, 0, -13247, 0, 9047, 0, -13246, 0, -13240, 0, 18336, 0, -13239, 0, -13239, 0, 9048, 0, -13238, 0, -13238, 0, 8258, 0, -13237, 0, -13237, 0, 8531, 0, -13236, 0, -13234, 0, 18343, 0, -13233, 0, -13233, 0, 8379, 0, -13232, 0, -13221, 0, 18346, 0, -13220, 0, -13220, 0, 9050, 0, -13219, 0, -13217, 0, 18358, 0, -13216, 0, -13216, 0, 9046, 0, -13215, 0, -13213, 0, 18361, 0, -13212, 0, -13212, 0, 9015, 0, -13211, 0, -13204, 0, 18364, 0, -13203, 0, -13203, 0, 8185, 0, -13202, 0, -13192, 0, 18372, 0, -13191, 0, -13191, 0, 9043, 0, -13190, 0, -13188, 0, 18383, 0, -13187, 0, -13187, 0, 8289, 0, -13186, 0, -13186, 0, 18386, 0, -13184, 0, -13171, 0, 18387, 0, -13170, 0, -13170, 0, 7829, 0, -13169, 0, -13165, 0, 18401, 0, -13164, 0, -13164, 0, 8265, 0, -13163, 0, -13163, 0, 18406, 0, -13162, 0, -13162, 0, 8002, 0, -13161, 0, -13156, 0, 18407, 0, -13155, 0, -13155, 0, 8168, 0, -13154, 0, -13152, 0, 18413, 0, -13151, 0, -13058, 0, 3572, 0, -12992, 0, -12930, 0, 18416, 0, -12928, 0, -12913, 0, 18479, 0, -12912, 0, -12912, 0, 9690, 0, -12911, 0, -12905, 0, 18495, 0, -12904, 0, -12904, 0, 9687, 0, -12903, 0, -12896, 0, 18502, 0, -12895, 0, -12802, 0, 3666, 0, -12736, 0, -12698, 0, 18510, 0, -12697, 0, -12697, 0, 8494, 0, -12696, 0, -12687, 0, 18549, 0, -12686, 0, -12686, 0, 8626, 0, -12685, 0, -12674, 0, 18559, 0, -12672, 0, -12672, 0, 18571, 0, -12671, 0, -12671, 0, 8606, 0, -12670, 0, -12666, 0, 18572, 0, -12665, 0, -12665, 0, 9692, 0, -12664, 0, -12646, 0, 18577, 0, -12645, 0, -12645, 0, 8300, 0, -12644, 0, -12643, 0, 18596, 0, -12642, 0, -12642, 0, 8742, 0, -12641, 0, -12640, 0, 18598, 0, -12639, 0, -12546, 0, 3760, 0, -12480, 0, -12467, 0, 18600, 0, -12466, 0, -12466, 0, 9696, 0, -12465, 0, -12460, 0, 18614, 0, -12459, 0, -12459, 0, 8827, 0, -12458, 0, -12457, 0, 18620, 0, -12456, 0, -12456, 0, 9694, 0, -12455, 0, -12453, 0, 18622, 0, -12452, 0, -12452, 0, 9697, 0, -12451, 0, -12437, 0, 18625, 0, -12436, 0, -12436, 0, 9685, 0, -12435, 0, -12430, 0, 18640, 0, -12429, 0, -12429, 0, 7787, 0, -12428, 0, -12428, 0, 18646, 0, -12427, 0, -12427, 0, 9691, 0, -12426, 0, -12425, 0, 18647, 0, -12424, 0, -12424, 0, 7817, 0, -12423, 0, -12421, 0, 18649, 0, -12420, 0, -12420, 0, 9689, 0, -12419, 0, -12418, 0, 18652, 0, -12416, 0, -12416, 0, 18654, 0, -12415, 0, -12415, 0, 8721, 0, -12414, 0, -12408, 0, 18655, 0, -12407, 0, -12407, 0, 8745, 0, -12406, 0, -12406, 0, 9686, 0, -12405, 0, -12398, 0, 18662, 0, -12397, 0, -12397, 0, 9693, 0, -12396, 0, -12396, 0, 9695, 0, -12395, 0, -12387, 0, 18670, 0, -12386, 0, -12386, 0, 8175, 0, -12385, 0, -12385, 0, 18679, 0, -12384, 0, -12384, 0, 9688, 0, -12383, 0, -12290, 0, 3854, 0, -12224, 0, -12212, 0, 18680, 0, -12211, 0, -12211, 0, 7977, 0, -12210, 0, -12208, 0, 18693, 0, -12207, 0, -12207, 0, 7771, 0, -12206, 0, -12204, 0, 18696, 0, -12203, 0, -12203, 0, 8310, 0, -12202, 0, -12197, 0, 18699, 0, -12196, 0, -12196, 0, 8855, 0, -12195, 0, -12193, 0, 18705, 0, -12192, 0, -12192, 0, 9872, 0, -12191, 0, -12186, 0, 18708, 0, -12185, 0, -12185, 0, 8511, 0, -12184, 0, -12181, 0, 18714, 0, -12180, 0, -12180, 0, 8600, 0, -12179, 0, -12179, 0, 18718, 0, -12178, 0, -12178, 0, 7816, 0, -12177, 0, -12164, 0, 18719, 0, -12163, 0, -12163, 0, 8844, 0, -12162, 0, -12162, 0, 18733, 0, -12160, 0, -12128, 0, 18734, 0, -12127, 0, -12034, 0, 3948, 0, -11968, 0, -11948, 0, 18767, 0, -11947, 0, -11947, 0, 9713, 0, -11946, 0, -11944, 0, 18788, 0, -11943, 0, -11943, 0, 8204, 0, -11942, 0, -11936, 0, 18791, 0, -11935, 0, -11935, 0, 7768, 0, -11934, 0, -11934, 0, 8876, 0, -11933, 0, -11916, 0, 18798, 0, -11915, 0, -11915, 0, 9895, 0, -11914, 0, -11908, 0, 18816, 0, -11907, 0, -11907, 0, 9846, 0, -11906, 0, -11906, 0, 18823, 0, -11904, 0, -11876, 0, 18824, 0, -11875, 0, -11875, 0, 8161, 0, -11874, 0, -11874, 0, 9659, 0, -11873, 0, -11872, 0, 18853, 0, -11871, 0, -11778, 0, 4042, 0, -11712, 0, -11712, 0, 9662, 0, -11711, 0, -11710, 0, 18855, 0, -11709, 0, -11709, 0, 8925, 0, -11708, 0, -11700, 0, 18857, 0, -11699, 0, -11699, 0, 9661, 0, -11698, 0, -11685, 0, 18866, 0, -11684, 0, -11684, 0, 7722, 0, -11683, 0, -11678, 0, 18880, 0, -11677, 0, -11677, 0, 9660, 0, -11676, 0, -11676, 0, 9658, 0, -11675, 0, -11673, 0, 18886, 0, -11672, 0, -11672, 0, 9663, 0, -11671, 0, -11668, 0, 18889, 0, -11667, 0, -11667, 0, 8583, 0, -11666, 0, -11666, 0, 18893, 0, -11665, 0, -11665, 0, 9835, 0, -11664, 0, -11663, 0, 18894, 0, -11662, 0, -11662, 0, 7807, 0, -11661, 0, -11660, 0, 18896, 0, -11659, 0, -11659, 0, 8621, 0, -11658, 0, -11650, 0, 18898, 0, -11648, 0, -11639, 0, 18907, 0, -11638, 0, -11638, 0, 8086, 0, -11637, 0, -11635, 0, 18917, 0, -11634, 0, -11634, 0, 7986, 0, -11633, 0, -11631, 0, 18920, 0, -11630, 0, -11630, 0, 8324, 0, -11629, 0, -11628, 0, 18923, 0, -11627, 0, -11627, 0, 8502, 0, -11626, 0, -11626, 0, 18925, 0, -11625, 0, -11625, 0, 9400, 0, -11624, 0, -11617, 0, 18926, 0, -11616, 0, -11616, 0, 9402, 0, -11615, 0, -11522, 0, 4136, 0, -11456, 0, -11453, 0, 18934, 0, -11452, 0, -11452, 0, 9404, 0, -11451, 0, -11449, 0, 18938, 0, -11448, 0, -11448, 0, 8420, 0, -11447, 0, -11447, 0, 18941, 0, -11446, 0, -11446, 0, 9401, 0, -11445, 0, -11444, 0, 18942, 0, -11443, 0, -11443, 0, 9405, 0, -11442, 0, -11441, 0, 18944, 0, -11440, 0, -11440, 0, 9406, 0, -11439, 0, -11436, 0, 18946, 0, -11435, 0, -11435, 0, 9407, 0, -11434, 0, -11433, 0, 18950, 0, -11432, 0, -11432, 0, 8146, 0, -11431, 0, -11430, 0, 18952, 0, -11429, 0, -11429, 0, 8189, 0, -11428, 0, -11428, 0, 18954, 0, -11427, 0, -11427, 0, 9403, 0, -11426, 0, -11426, 0, 7981, 0, -11425, 0, -11401, 0, 18955, 0, -11400, 0, -11400, 0, 9737, 0, -11399, 0, -11399, 0, 18980, 0, -11398, 0, -11398, 0, 9738, 0, -11397, 0, -11397, 0, 18981, 0, -11396, 0, -11396, 0, 7828, 0, -11395, 0, -11394, 0, 18982, 0, -11392, 0, -11388, 0, 18984, 0, -11387, 0, -11387, 0, 8927, 0, -11386, 0, -11386, 0, 7883, 0, -11385, 0, -11385, 0, 7949, 0, -11384, 0, -11382, 0, 18989, 0, -11381, 0, -11381, 0, 8055, 0, -11380, 0, -11380, 0, 18992, 0, -11379, 0, -11379, 0, 8683, 0, -11378, 0, -11378, 0, 18993, 0, -11377, 0, -11377, 0, 8929, 0, -11376, 0, -11376, 0, 18994, 0, -11375, 0, -11375, 0, 8559, 0, -11374, 0, -11374, 0, 18995, 0, -11373, 0, -11373, 0, 8928, 0, -11372, 0, -11371, 0, 18996, 0, -11370, 0, -11370, 0, 8682, 0, -11369, 0, -11369, 0, 18998, 0, -11368, 0, -11368, 0, 8930, 0, -11367, 0, -11367, 0, 8395, 0, -11366, 0, -11366, 0, 18999, 0, -11365, 0, -11365, 0, 8056, 0, -11364, 0, -11363, 0, 19000, 0, -11362, 0, -11362, 0, 7906, 0, -11361, 0, -11361, 0, 19002, 0, -11360, 0, -11360, 0, 8690, 0, -11359, 0, -11266, 0, 4230, 0, -11200, 0, -11200, 0, 19003, 0, -11199, 0, -11199, 0, 8528, 0, -11198, 0, -11196, 0, 19004, 0, -11195, 0, -11195, 0, 8147, 0, -11194, 0, -11194, 0, 19007, 0, -11193, 0, -11193, 0, 8933, 0, -11192, 0, -11189, 0, 19008, 0, -11188, 0, -11188, 0, 7922, 0, -11187, 0, -11186, 0, 19012, 0, -11185, 0, -11185, 0, 8479, 0, -11184, 0, -11182, 0, 19014, 0, -11181, 0, -11181, 0, 8669, 0, -11180, 0, -11179, 0, 19017, 0, -11178, 0, -11178, 0, 8532, 0, -11177, 0, -11177, 0, 19019, 0, -11176, 0, -11176, 0, 8935, 0, -11175, 0, -11173, 0, 19020, 0, -11172, 0, -11172, 0, 8834, 0, -11171, 0, -11167, 0, 19023, 0, -11166, 0, -11166, 0, 8934, 0, -11165, 0, -11162, 0, 19028, 0, -11161, 0, -11161, 0, 8936, 0, -11160, 0, -11155, 0, 19032, 0, -11154, 0, -11154, 0, 8932, 0, -11153, 0, -11153, 0, 19038, 0, -11152, 0, -11152, 0, 8810, 0, -11151, 0, -11151, 0, 19039, 0, -11150, 0, -11150, 0, 8939, 0, -11149, 0, -11149, 0, 19040, 0, -11148, 0, -11148, 0, 8937, 0, -11147, 0, -11147, 0, 8381, 0, -11146, 0, -11145, 0, 19041, 0, -11144, 0, -11144, 0, 8938, 0, -11143, 0, -11142, 0, 19043, 0, -11141, 0, -11141, 0, 8893, 0, -11140, 0, -11139, 0, 19045, 0, -11138, 0, -11138, 0, 7838, 0, -11136, 0, -11135, 0, 19047, 0, -11134, 0, -11134, 0, 8950, 0, -11133, 0, -11133, 0, 8679, 0, -11132, 0, -11132, 0, 8726, 0, -11131, 0, -11130, 0, 19049, 0, -11129, 0, -11129, 0, 8503, 0, -11128, 0, -11127, 0, 19051, 0, -11126, 0, -11126, 0, 8492, 0, -11125, 0, -11125, 0, 19053, 0, -11124, 0, -11124, 0, 7784, 0, -11123, 0, -11123, 0, 8946, 0, -11122, 0, -11122, 0, 7991, 0, -11121, 0, -11121, 0, 8947, 0, -11120, 0, -11120, 0, 19054, 0, -11119, 0, -11119, 0, 8943, 0, -11118, 0, -11118, 0, 8016, 0, -11117, 0, -11117, 0, 7952, 0, -11116, 0, -11116, 0, 8648, 0, -11115, 0, -11115, 0, 19055, 0, -11114, 0, -11114, 0, 8945, 0, -11113, 0, -11109, 0, 19056, 0, -11108, 0, -11108, 0, 8944, 0, -11107, 0, -11106, 0, 19061, 0, -11105, 0, -11105, 0, 8942, 0, -11104, 0, -11104, 0, 19063, 0, -11103, 0, -11010, 0, 4324, 0, -10944, 0, -10942, 0, 19064, 0, -10941, 0, -10941, 0, 8941, 0, -10940, 0, -10940, 0, 8862, 0, -10939, 0, -10939, 0, 8940, 0, -10938, 0, -10938, 0, 8162, 0, -10937, 0, -10935, 0, 19067, 0, -10934, 0, -10934, 0, 8446, 0, -10933, 0, -10931, 0, 19070, 0, -10930, 0, -10929, 0, 8953, 0, -10928, 0, -10928, 0, 19073, 0, -10927, 0, -10927, 0, 7855, 0, -10926, 0, -10925, 0, 19074, 0, -10924, 0, -10924, 0, 8758, 0, -10923, 0, -10923, 0, 19076, 0, -10922, 0, -10922, 0, 8951, 0, -10921, 0, -10919, 0, 19077, 0, -10918, 0, -10918, 0, 8765, 0, -10917, 0, -10917, 0, 19080, 0, -10916, 0, -10916, 0, 7810, 0, -10915, 0, -10915, 0, 8118, 0, -10914, 0, -10914, 0, 19081, 0, -10913, 0, -10913, 0, 8612, 0, -10912, 0, -10912, 0, 8618, 0, -10911, 0, -10911, 0, 8952, 0, -10910, 0, -10910, 0, 8529, 0, -10909, 0, -10909, 0, 19082, 0, -10908, 0, -10908, 0, 8032, 0, -10907, 0, -10905, 0, 19083, 0, -10904, 0, -10904, 0, 8519, 0, -10903, 0, -10901, 0, 19086, 0, -10900, 0, -10900, 0, 8517, 0, -10899, 0, -10899, 0, 19089, 0, -10898, 0, -10898, 0, 8156, 0, -10897, 0, -10895, 0, 19090, 0, -10894, 0, -10894, 0, 8961, 0, -10893, 0, -10892, 0, 19093, 0, -10891, 0, -10891, 0, 7925, 0, -10890, 0, -10889, 0, 19095, 0, -10888, 0, -10888, 0, 8728, 0, -10887, 0, -10886, 0, 19097, 0, -10885, 0, -10885, 0, 7878, 0, -10884, 0, -10883, 0, 19099, 0, -10882, 0, -10882, 0, 8960, 0, -10880, 0, -10880, 0, 19101, 0, -10879, 0, -10879, 0, 8884, 0, -10878, 0, -10877, 0, 19102, 0, -10876, 0, -10876, 0, 8553, 0, -10875, 0, -10875, 0, 19104, 0, -10874, 0, -10874, 0, 8957, 0, -10873, 0, -10873, 0, 19105, 0, -10872, 0, -10872, 0, 8426, 0, -10871, 0, -10871, 0, 19106, 0, -10870, 0, -10870, 0, 8948, 0, -10869, 0, -10869, 0, 19107, 0, -10868, 0, -10868, 0, 8955, 0, -10867, 0, -10867, 0, 19108, 0, -10866, 0, -10866, 0, 8956, 0, -10865, 0, -10865, 0, 8231, 0, -10864, 0, -10862, 0, 19109, 0, -10861, 0, -10861, 0, 8288, 0, -10860, 0, -10860, 0, 8959, 0, -10859, 0, -10857, 0, 19112, 0, -10856, 0, -10856, 0, 8958, 0, -10855, 0, -10855, 0, 7879, 0, -10854, 0, -10854, 0, 19115, 0, -10853, 0, -10853, 0, 8972, 0, -10852, 0, -10850, 0, 19116, 0, -10849, 0, -10849, 0, 8949, 0, -10848, 0, -10848, 0, 19119, 0, -10847, 0, -10754, 0, 4418, 0, -10688, 0, -10688, 0, 8966, 0, -10687, 0, -10687, 0, 19120, 0, -10686, 0, -10686, 0, 8970, 0, -10685, 0, -10685, 0, 8659, 0, -10684, 0, -10682, 0, 19121, 0, -10681, 0, -10681, 0, 8963, 0, -10680, 0, -10680, 0, 19124, 0, -10679, 0, -10679, 0, 8967, 0, -10678, 0, -10678, 0, 8971, 0, -10677, 0, -10676, 0, 19125, 0, -10675, 0, -10675, 0, 8031, 0, -10674, 0, -10674, 0, 19127, 0, -10673, 0, -10673, 0, 8969, 0, -10672, 0, -10671, 0, 19128, 0, -10670, 0, -10670, 0, 8962, 0, -10669, 0, -10669, 0, 7940, 0, -10668, 0, -10668, 0, 8861, 0, -10667, 0, -10667, 0, 19130, 0, -10666, 0, -10666, 0, 8699, 0, -10665, 0, -10665, 0, 19131, 0, -10664, 0, -10664, 0, 8968, 0, -10663, 0, -10663, 0, 19132, 0, -10662, 0, -10662, 0, 8364, 0, -10661, 0, -10661, 0, 19133, 0, -10660, 0, -10660, 0, 8334, 0, -10659, 0, -10659, 0, 8965, 0, -10658, 0, -10658, 0, 8599, 0, -10657, 0, -10657, 0, 19134, 0, -10656, 0, -10656, 0, 8561, 0, -10655, 0, -10655, 0, 8856, 0, -10654, 0, -10652, 0, 19135, 0, -10651, 0, -10651, 0, 8023, 0, -10650, 0, -10648, 0, 19138, 0, -10647, 0, -10647, 0, 8322, 0, -10646, 0, -10646, 0, 19141, 0, -10645, 0, -10645, 0, 8977, 0, -10644, 0, -10642, 0, 19142, 0, -10641, 0, -10641, 0, 8964, 0, -10640, 0, -10640, 0, 19145, 0, -10639, 0, -10639, 0, 8975, 0, -10638, 0, -10638, 0, 7733, 0, -10637, 0, -10637, 0, 19146, 0, -10636, 0, -10636, 0, 8401, 0, -10635, 0, -10635, 0, 8976, 0, -10634, 0, -10634, 0, 8099, 0, -10633, 0, -10633, 0, 19147, 0, -10632, 0, -10632, 0, 8662, 0, -10631, 0, -10629, 0, 19148, 0, -10628, 0, -10628, 0, 8710, 0, -10627, 0, -10626, 0, 19151, 0, -10624, 0, -10622, 0, 19153, 0, -10621, 0, -10621, 0, 8973, 0, -10620, 0, -10619, 0, 19156, 0, -10618, 0, -10618, 0, 8978, 0, -10617, 0, -10617, 0, 8333, 0, -10616, 0, -10616, 0, 8979, 0, -10615, 0, -10611, 0, 19158, 0, -10610, 0, -10610, 0, 8931, 0, -10609, 0, -10605, 0, 19163, 0, -10604, 0, -10604, 0, 8122, 0, -10603, 0, -10600, 0, 19168, 0, -10599, 0, -10599, 0, 8312, 0, -10598, 0, -10592, 0, 19172, 0, -10591, 0, -10498, 0, 4512, 0, -10432, 0, -10430, 0, 19179, 0, -10429, 0, -10429, 0, 8840, 0, -10428, 0, -10425, 0, 19182, 0, -10424, 0, -10424, 0, 8982, 0, -10423, 0, -10423, 0, 8043, 0, -10422, 0, -10417, 0, 19186, 0, -10416, 0, -10416, 0, 8980, 0, -10415, 0, -10415, 0, 19192, 0, -10414, 0, -10414, 0, 8496, 0, -10413, 0, -10413, 0, 8981, 0, -10412, 0, -10412, 0, 8552, 0, -10411, 0, -10411, 0, 19193, 0, -10410, 0, -10410, 0, 8388, 0, -10409, 0, -10397, 0, 19194, 0, -10396, 0, -10396, 0, 8984, 0, -10395, 0, -10394, 0, 19207, 0, -10393, 0, -10393, 0, 8729, 0, -10392, 0, -10392, 0, 8727, 0, -10391, 0, -10389, 0, 19209, 0, -10388, 0, -10388, 0, 8405, 0, -10387, 0, -10386, 0, 19212, 0, -10385, 0, -10385, 0, 8010, 0, -10384, 0, -10380, 0, 19214, 0, -10379, 0, -10379, 0, 8768, 0, -10378, 0, -10377, 0, 19219, 0, -10376, 0, -10376, 0, 7891, 0, -10375, 0, -10370, 0, 19221, 0, -10368, 0, -10366, 0, 19227, 0, -10365, 0, -10365, 0, 7753, 0, -10364, 0, -10362, 0, 19230, 0, -10361, 0, -10361, 0, 9755, 0, -10360, 0, -10358, 0, 19233, 0, -10357, 0, -10357, 0, 7789, 0, -10356, 0, -10356, 0, 8440, 0, -10355, 0, -10355, 0, 19236, 0, -10354, 0, -10354, 0, 8187, 0, -10353, 0, -10353, 0, 8985, 0, -10352, 0, -10348, 0, 19237, 0, -10347, 0, -10347, 0, 8974, 0, -10346, 0, -10346, 0, 19242, 0, -10345, 0, -10345, 0, 8983, 0, -10344, 0, -10336, 0, 19243, 0, -10335, 0, -10247, 0, 4606, 0, -10176, 0, -10164, 0, 19252, 0, -10163, 0, -10163, 0, 8392, 0, -10162, 0, -10158, 0, 19265, 0, -10157, 0, -10157, 0, 7933, 0, -10156, 0, -10114, 0, 19270, 0, -10112, 0, -10097, 0, 19313, 0, -10096, 0, -10096, 0, 7739, 0, -10095, 0, -10095, 0, 8831, 0, -10094, 0, -10094, 0, 19329, 0, -10093, 0, -10093, 0, 7948, 0, -10092, 0, -10092, 0, 7769, 0, -10091, 0, -10091, 0, 7972, 0, -10090, 0, -10087, 0, 19330, 0, -10086, 0, -10086, 0, 8378, 0, -10085, 0, -10085, 0, 8037, 0, -10084, 0, -10084, 0, 7920, 0, -10083, 0, -10083, 0, 8548, 0, -10082, 0, -10082, 0, 7984, 0, -10081, 0, -10081, 0, 8801, 0, -10080, 0, -10080, 0, 19334, 0, -10079, 0, -9986, 0, 4695, 0, -9920, 0, -9920, 0, 19335, 0, -9919, 0, -9919, 0, 8866, 0, -9918, 0, -9918, 0, 9387, 0, -9917, 0, -9917, 0, 19336, 0, -9916, 0, -9916, 0, 9391, 0, -9915, 0, -9915, 0, 7912, 0, -9914, 0, -9914, 0, 7993, 0, -9913, 0, -9913, 0, 19337, 0, -9912, 0, -9912, 0, 7752, 0, -9911, 0, -9911, 0, 8304, 0, -9910, 0, -9910, 0, 7848, 0, -9909, 0, -9909, 0, 19338, 0, -9908, 0, -9908, 0, 9388, 0, -9907, 0, -9907, 0, 7927, 0, -9906, 0, -9906, 0, 8566, 0, -9905, 0, -9905, 0, 9389, 0, -9904, 0, -9904, 0, 19339, 0, -9903, 0, -9903, 0, 8315, 0, -9902, 0, -9902, 0, 8005, 0, -9901, 0, -9901, 0, 9386, 0, -9900, 0, -9900, 0, 8267, 0, -9899, 0, -9899, 0, 8239, 0, -9898, 0, -9898, 0, 8026, 0, -9897, 0, -9897, 0, 9392, 0, -9896, 0, -9896, 0, 19340, 0, -9895, 0, -9895, 0, 8887, 0, -9894, 0, -9894, 0, 8063, 0, -9893, 0, -9893, 0, 19341, 0, -9892, 0, -9892, 0, 8805, 0, -9891, 0, -9886, 0, 19342, 0, -9885, 0, -9885, 0, 9394, 0, -9884, 0, -9884, 0, 8475, 0, -9883, 0, -9883, 0, 7761, 0, -9882, 0, -9882, 0, 19348, 0, -9881, 0, -9881, 0, 9396, 0, -9880, 0, -9877, 0, 19349, 0, -9876, 0, -9876, 0, 9395, 0, -9875, 0, -9875, 0, 19353, 0, -9874, 0, -9874, 0, 7839, 0, -9873, 0, -9873, 0, 19354, 0, -9872, 0, -9872, 0, 8472, 0, -9871, 0, -9871, 0, 19355, 0, -9870, 0, -9870, 0, 8372, 0, -9869, 0, -9869, 0, 9135, 0, -9868, 0, -9868, 0, 8635, 0, -9867, 0, -9867, 0, 8306, 0, -9866, 0, -9866, 0, 8085, 0, -9865, 0, -9865, 0, 19356, 0, -9864, 0, -9864, 0, 7946, 0, -9863, 0, -9863, 0, 9398, 0, -9862, 0, -9861, 0, 19357, 0, -9860, 0, -9860, 0, 8849, 0, -9859, 0, -9859, 0, 9397, 0, -9858, 0, -9858, 0, 8824, 0, -9856, 0, -9856, 0, 7892, 0, -9855, 0, -9850, 0, 19359, 0, -9849, 0, -9849, 0, 8179, 0, -9848, 0, -9844, 0, 19365, 0, -9843, 0, -9843, 0, 8873, 0, -9842, 0, -9842, 0, 9399, 0, -9841, 0, -9841, 0, 7976, 0, -9840, 0, -9840, 0, 8457, 0, -9839, 0, -9839, 0, 8903, 0, -9838, 0, -9834, 0, 19370, 0, -9833, 0, -9833, 0, 9390, 0, -9832, 0, -9832, 0, 8881, 0, -9831, 0, -9830, 0, 19375, 0, -9829, 0, -9829, 0, 8806, 0, -9828, 0, -9828, 0, 19377, 0, -9827, 0, -9827, 0, 8795, 0, -9826, 0, -9826, 0, 8900, 0, -9825, 0, -9825, 0, 19378, 0, -9824, 0, -9824, 0, 8469, 0, -9823, 0, -9730, 0, 4789, 0, -9664, 0, -9664, 0, 19379, 0, -9663, 0, -9663, 0, 8746, 0, -9662, 0, -9662, 0, 9393, 0, -9661, 0, -9657, 0, 19380, 0, -9656, 0, -9656, 0, 8509, 0, -9655, 0, -9652, 0, 19385, 0, -9651, 0, -9651, 0, 7957, 0, -9650, 0, -9650, 0, 8796, 0, -9649, 0, -9614, 0, 19389, 0, -9613, 0, -9613, 0, 7956, 0, -9612, 0, -9610, 0, 19425, 0, -9609, 0, -9609, 0, 8826, 0, -9608, 0, -9602, 0, 19428, 0, -9600, 0, -9596, 0, 19435, 0, -9595, 0, -9595, 0, 8430, 0, -9594, 0, -9587, 0, 19440, 0, -9586, 0, -9586, 0, 9720, 0, -9585, 0, -9568, 0, 19448, 0, -9567, 0, -9474, 0, 4883, 0, -9408, 0, -9377, 0, 19466, 0, -9376, 0, -9376, 0, 8084, 0, -9375, 0, -9353, 0, 19498, 0, -9352, 0, -9352, 0, 8752, 0, -9351, 0, -9346, 0, 19521, 0, -9344, 0, -9341, 0, 19527, 0, -9340, 0, -9340, 0, 9725, 0, -9339, 0, -9334, 0, 19531, 0, -9333, 0, -9333, 0, 9728, 0, -9332, 0, -9321, 0, 19537, 0, -9320, 0, -9320, 0, 9734, 0, -9319, 0, -9312, 0, 19549, 0, -9311, 0, -9218, 0, 4977, 0, -9152, 0, -9148, 0, 19557, 0, -9147, 0, -9147, 0, 9727, 0, -9146, 0, -9138, 0, 19562, 0, -9137, 0, -9137, 0, 9724, 0, -9136, 0, -9136, 0, 7820, 0, -9135, 0, -9135, 0, 9730, 0, -9134, 0, -9134, 0, 19571, 0, -9133, 0, -9133, 0, 8781, 0, -9132, 0, -9132, 0, 19572, 0, -9131, 0, -9131, 0, 9732, 0, -9130, 0, -9130, 0, 9726, 0, -9129, 0, -9129, 0, 9731, 0, -9128, 0, -9124, 0, 19573, 0, -9123, 0, -9123, 0, 9729, 0, -9122, 0, -9119, 0, 19578, 0, -9118, 0, -9118, 0, 9733, 0, -9117, 0, -9115, 0, 19582, 0, -9114, 0, -9114, 0, 7843, 0, -9113, 0, -9113, 0, 9736, 0, -9112, 0, -9110, 0, 19585, 0, -9109, 0, -9109, 0, 9735, 0, -9108, 0, -9093, 0, 19588, 0, -9092, 0, -9092, 0, 8432, 0, -9091, 0, -9090, 0, 19604, 0, -9088, 0, -9082, 0, 19606, 0, -9081, 0, -9081, 0, 7803, 0, -9080, 0, -9080, 0, 8807, 0, -9079, 0, -9079, 0, 7990, 0, -9078, 0, -9078, 0, 8150, 0, -9077, 0, -9075, 0, 19613, 0, -9074, 0, -9074, 0, 8672, 0, -9073, 0, -9073, 0, 19616, 0, -9072, 0, -9072, 0, 9356, 0, -9071, 0, -9066, 0, 19617, 0, -9065, 0, -9065, 0, 9357, 0, -9064, 0, -9062, 0, 19623, 0, -9061, 0, -9061, 0, 8450, 0, -9060, 0, -9057, 0, 19626, 0, -9056, 0, -9056, 0, 9364, 0, -9055, 0, -8962, 0, 5071, 0, -8896, 0, -8891, 0, 19630, 0, -8890, 0, -8890, 0, 9363, 0, -8889, 0, -8884, 0, 19636, 0, -8883, 0, -8883, 0, 9358, 0, -8882, 0, -8878, 0, 19642, 0, -8877, 0, -8877, 0, 8857, 0, -8876, 0, -8876, 0, 9361, 0, -8875, 0, -8875, 0, 9366, 0, -8874, 0, -8874, 0, 9359, 0, -8873, 0, -8873, 0, 9362, 0, -8872, 0, -8872, 0, 19647, 0, -8871, 0, -8871, 0, 9367, 0, -8870, 0, -8867, 0, 19648, 0, -8866, 0, -8866, 0, 8113, 0, -8865, 0, -8865, 0, 19652, 0, -8864, 0, -8864, 0, 9370, 0, -8863, 0, -8863, 0, 19653, 0, -8862, 0, -8862, 0, 9369, 0, -8861, 0, -8861, 0, 19654, 0, -8860, 0, -8860, 0, 8792, 0, -8859, 0, -8859, 0, 9368, 0, -8858, 0, -8852, 0, 19655, 0, -8851, 0, -8851, 0, 9371, 0, -8850, 0, -8850, 0, 19662, 0, -8849, 0, -8849, 0, 7945, 0, -8848, 0, -8848, 0, 8422, 0, -8847, 0, -8843, 0, 19663, 0, -8842, 0, -8842, 0, 8230, 0, -8841, 0, -8841, 0, 9375, 0, -8840, 0, -8840, 0, 8025, 0, -8839, 0, -8838, 0, 9373, 0, -8837, 0, -8834, 0, 19668, 0, -8832, 0, -8832, 0, 19672, 0, -8831, 0, -8831, 0, 7995, 0, -8830, 0, -8830, 0, 9372, 0, -8829, 0, -8828, 0, 19673, 0, -8827, 0, -8827, 0, 7738, 0, -8826, 0, -8826, 0, 8283, 0, -8825, 0, -8822, 0, 19675, 0, -8821, 0, -8821, 0, 8048, 0, -8820, 0, -8818, 0, 19679, 0, -8817, 0, -8817, 0, 9376, 0, -8816, 0, -8813, 0, 19682, 0, -8812, 0, -8812, 0, 8507, 0, -8811, 0, -8810, 0, 19686, 0, -8809, 0, -8809, 0, 7943, 0, -8808, 0, -8807, 0, 19688, 0, -8806, 0, -8806, 0, 8816, 0, -8805, 0, -8805, 0, 8759, 0, -8804, 0, -8803, 0, 19690, 0, -8802, 0, -8802, 0, 9426, 0, -8801, 0, -8801, 0, 19692, 0, -8800, 0, -8800, 0, 8627, 0, -8799, 0, -8706, 0, 5165, 0, -8640, 0, -8640, 0, 8773, 0, -8639, 0, -8639, 0, 9377, 0, -8638, 0, -8637, 0, 19693, 0, -8636, 0, -8636, 0, 8872, 0, -8635, 0, -8633, 0, 19695, 0, -8632, 0, -8632, 0, 8828, 0, -8631, 0, -8631, 0, 8112, 0, -8630, 0, -8626, 0, 19698, 0, -8625, 0, -8625, 0, 9378, 0, -8624, 0, -8615, 0, 19703, 0, -8614, 0, -8614, 0, 8006, 0, -8613, 0, -8613, 0, 19713, 0, -8612, 0, -8612, 0, 9088, 0, -8611, 0, -8611, 0, 9365, 0, -8610, 0, -8610, 0, 19714, 0, -8609, 0, -8609, 0, 9360, 0, -8608, 0, -8598, 0, 19715, 0, -8597, 0, -8597, 0, 7728, 0, -8596, 0, -8594, 0, 19726, 0, -8593, 0, -8593, 0, 7837, 0, -8592, 0, -8592, 0, 7755, 0, -8591, 0, -8591, 0, 7754, 0, -8590, 0, -8590, 0, 8362, 0, -8589, 0, -8578, 0, 19729, 0, -8576, 0, -8559, 0, 19741, 0, -8558, 0, -8558, 0, 9851, 0, -8557, 0, -8546, 0, 19759, 0, -8545, 0, -8545, 0, 9202, 0, -8544, 0, -8544, 0, 19771, 0, -8543, 0, -8450, 0, 5259, 0, -8384, 0, -8384, 0, 8830, 0, -8383, 0, -8383, 0, 19772, 0, -8382, 0, -8382, 0, 8217, 0, -8381, 0, -8372, 0, 19773, 0, -8371, 0, -8371, 0, 8123, 0, -8370, 0, -8357, 0, 19783, 0, -8356, 0, -8356, 0, 8787, 0, -8355, 0, -8355, 0, 19797, 0, -8354, 0, -8354, 0, 7998, 0, -8353, 0, -8353, 0, 7846, 0, -8352, 0, -8352, 0, 8590, 0, -8351, 0, -8349, 0, 19798, 0, -8348, 0, -8348, 0, 8684, 0, -8347, 0, -8347, 0, 19801, 0, -8346, 0, -8346, 0, 7870, 0, -8345, 0, -8345, 0, 19802, 0, -8344, 0, -8344, 0, 8778, 0, -8343, 0, -8340, 0, 19803, 0, -8339, 0, -8339, 0, 8499, 0, -8338, 0, -8333, 0, 19807, 0, -8332, 0, -8332, 0, 7812, 0, -8331, 0, -8330, 0, 19813, 0, -8329, 0, -8329, 0, 8399, 0, -8328, 0, -8328, 0, 8674, 0, -8327, 0, -8327, 0, 19815, 0, -8326, 0, -8326, 0, 8719, 0, -8325, 0, -8325, 0, 19816, 0, -8324, 0, -8324, 0, 8233, 0, -8323, 0, -8323, 0, 19817, 0, -8322, 0, -8322, 0, 8307, 0, -8320, 0, -8320, 0, 8021, 0, -8319, 0, -8318, 0, 19818, 0, -8317, 0, -8317, 0, 9201, 0, -8316, 0, -8316, 0, 19820, 0, -8315, 0, -8315, 0, 7750, 0, -8314, 0, -8312, 0, 19821, 0, -8311, 0, -8311, 0, 8291, 0, -8310, 0, -8310, 0, 9203, 0, -8309, 0, -8288, 0, 19824, 0, -8287, 0, -8194, 0, 5353, 0, -8128, 0, -8113, 0, 19846, 0, -8112, 0, -8112, 0, 8990, 0, -8111, 0, -8100, 0, 19862, 0, -8099, 0, -8099, 0, 8755, 0, -8098, 0, -8088, 0, 19874, 0, -8087, 0, -8087, 0, 8992, 0, -8086, 0, -8085, 0, 19885, 0, -8084, 0, -8084, 0, 8647, 0, -8083, 0, -8076, 0, 19887, 0, -8075, 0, -8075, 0, 8892, 0, -8074, 0, -8074, 0, 19895, 0, -8073, 0, -8073, 0, 8988, 0, -8072, 0, -8072, 0, 19896, 0, -8071, 0, -8071, 0, 8785, 0, -8070, 0, -8066, 0, 19897, 0, -8064, 0, -8058, 0, 19902, 0, -8057, 0, -8057, 0, 7867, 0, -8056, 0, -8052, 0, 19909, 0, -8051, 0, -8051, 0, 8839, 0, -8050, 0, -8050, 0, 19914, 0, -8049, 0, -8049, 0, 8237, 0, -8048, 0, -8048, 0, 7851, 0, -8047, 0, -8047, 0, 19915, 0, -8046, 0, -8046, 0, 8989, 0, -8045, 0, -8045, 0, 19916, 0, -8044, 0, -8044, 0, 8991, 0, -8043, 0, -8042, 0, 19917, 0, -8041, 0, -8041, 0, 8987, 0, -8040, 0, -8032, 0, 19919, 0, -8031, 0, -7938, 0, 5447, 0, -7872, 0, -7871, 0, 19928, 0, -7870, 0, -7870, 0, 8993, 0, -7869, 0, -7837, 0, 19930, 0, -7836, 0, -7836, 0, 8789, 0, -7835, 0, -7833, 0, 19963, 0, -7832, 0, -7832, 0, 7823, 0, -7831, 0, -7821, 0, 19966, 0, -7820, 0, -7820, 0, 8716, 0, -7819, 0, -7819, 0, 8100, 0, -7818, 0, -7810, 0, 19977, 0, -7808, 0, -7805, 0, 19986, 0, -7804, 0, -7804, 0, 8347, 0, -7803, 0, -7803, 0, 8664, 0, -7802, 0, -7802, 0, 19990, 0, -7801, 0, -7801, 0, 9722, 0, -7800, 0, -7800, 0, 19991, 0, -7799, 0, -7799, 0, 9721, 0, -7798, 0, -7797, 0, 19992, 0, -7796, 0, -7796, 0, 8500, 0, -7795, 0, -7795, 0, 19994, 0, -7794, 0, -7792, 0, 9459, 0, -7791, 0, -7791, 0, 9464, 0, -7790, 0, -7790, 0, 19995, 0, -7789, 0, -7789, 0, 9463, 0, -7788, 0, -7788, 0, 7880, 0, -7787, 0, -7787, 0, 9462, 0, -7786, 0, -7785, 0, 19996, 0, -7784, 0, -7784, 0, 8832, 0, -7783, 0, -7779, 0, 19998, 0, -7778, 0, -7778, 0, 7877, 0, -7777, 0, -7777, 0, 9467, 0, -7776, 0, -7776, 0, 20003, 0, -7775, 0, -7682, 0, 5541, 0, -7616, 0, -7616, 0, 20004, 0, -7615, 0, -7615, 0, 9466, 0, -7614, 0, -7614, 0, 20005, 0, -7613, 0, -7613, 0, 7917, 0, -7612, 0, -7602, 0, 20006, 0, -7601, 0, -7601, 0, 9469, 0, -7600, 0, -7600, 0, 20017, 0, -7599, 0, -7599, 0, 9465, 0, -7598, 0, -7598, 0, 20018, 0, -7597, 0, -7597, 0, 9470, 0, -7596, 0, -7596, 0, 8397, 0, -7595, 0, -7591, 0, 20019, 0, -7590, 0, -7590, 0, 9480, 0, -7589, 0, -7589, 0, 9476, 0, -7588, 0, -7587, 0, 20024, 0, -7586, 0, -7586, 0, 9478, 0, -7585, 0, -7583, 0, 20026, 0, -7582, 0, -7582, 0, 9471, 0, -7581, 0, -7581, 0, 8336, 0, -7580, 0, -7578, 0, 20029, 0, -7577, 0, -7577, 0, 7901, 0, -7576, 0, -7576, 0, 7973, 0, -7575, 0, -7575, 0, 20032, 0, -7574, 0, -7574, 0, 9475, 0, -7573, 0, -7573, 0, 9474, 0, -7572, 0, -7571, 0, 20033, 0, -7570, 0, -7570, 0, 7802, 0, -7569, 0, -7569, 0, 8358, 0, -7568, 0, -7561, 0, 20035, 0, -7560, 0, -7560, 0, 8149, 0, -7559, 0, -7556, 0, 20043, 0, -7555, 0, -7555, 0, 7953, 0, -7554, 0, -7554, 0, 20047, 0, -7552, 0, -7552, 0, 9479, 0, -7551, 0, -7551, 0, 9472, 0, -7550, 0, -7550, 0, 9477, 0, -7549, 0, -7544, 0, 20048, 0, -7543, 0, -7543, 0, 9497, 0, -7542, 0, -7542, 0, 20054, 0, -7541, 0, -7541, 0, 9493, 0, -7540, 0, -7539, 0, 20055, 0, -7538, 0, -7538, 0, 9484, 0, -7537, 0, -7537, 0, 8241, 0, -7536, 0, -7535, 0, 20057, 0, -7534, 0, -7534, 0, 9483, 0, -7533, 0, -7533, 0, 9487, 0, -7532, 0, -7532, 0, 9498, 0, -7531, 0, -7531, 0, 9481, 0, -7530, 0, -7529, 0, 20059, 0, -7528, 0, -7528, 0, 9486, 0, -7527, 0, -7527, 0, 8756, 0, -7526, 0, -7526, 0, 9491, 0, -7525, 0, -7525, 0, 8064, 0, -7524, 0, -7521, 0, 20061, 0, -7520, 0, -7520, 0, 9473, 0, -7519, 0, -7426, 0, 5635, 0, -7360, 0, -7359, 0, 20065, 0, -7358, 0, -7358, 0, 9495, 0, -7357, 0, -7357, 0, 9494, 0, -7356, 0, -7354, 0, 20067, 0, -7353, 0, -7353, 0, 9496, 0, -7352, 0, -7350, 0, 20070, 0, -7349, 0, -7349, 0, 7766, 0, -7348, 0, -7346, 0, 20073, 0, -7345, 0, -7345, 0, 9485, 0, -7344, 0, -7344, 0, 20076, 0, -7343, 0, -7343, 0, 8403, 0, -7342, 0, -7341, 0, 20077, 0, -7340, 0, -7340, 0, 8314, 0, -7339, 0, -7339, 0, 8398, 0, -7338, 0, -7337, 0, 20079, 0, -7336, 0, -7336, 0, 9488, 0, -7335, 0, -7333, 0, 20081, 0, -7332, 0, -7332, 0, 7765, 0, -7331, 0, -7329, 0, 20084, 0, -7328, 0, -7328, 0, 9482, 0, -7327, 0, -7323, 0, 20087, 0, -7322, 0, -7321, 0, 9489, 0, -7320, 0, -7312, 0, 20092, 0, -7311, 0, -7311, 0, 8106, 0, -7310, 0, -7310, 0, 20101, 0, -7309, 0, -7309, 0, 9502, 0, -7308, 0, -7308, 0, 7967, 0, -7307, 0, -7305, 0, 20102, 0, -7304, 0, -7304, 0, 9517, 0, -7303, 0, -7303, 0, 8733, 0, -7302, 0, -7301, 0, 20105, 0, -7300, 0, -7300, 0, 9522, 0, -7299, 0, -7299, 0, 20107, 0, -7298, 0, -7298, 0, 8571, 0, -7296, 0, -7287, 0, 20108, 0, -7286, 0, -7286, 0, 8623, 0, -7285, 0, -7285, 0, 20118, 0, -7284, 0, -7284, 0, 9516, 0, -7283, 0, -7282, 0, 20119, 0, -7281, 0, -7281, 0, 9512, 0, -7280, 0, -7280, 0, 20121, 0, -7279, 0, -7279, 0, 8332, 0, -7278, 0, -7278, 0, 20122, 0, -7277, 0, -7277, 0, 9519, 0, -7276, 0, -7276, 0, 20123, 0, -7275, 0, -7275, 0, 8636, 0, -7274, 0, -7272, 0, 20124, 0, -7271, 0, -7271, 0, 9501, 0, -7270, 0, -7269, 0, 20127, 0, -7268, 0, -7268, 0, 9525, 0, -7267, 0, -7267, 0, 20129, 0, -7266, 0, -7266, 0, 8717, 0, -7265, 0, -7265, 0, 9510, 0, -7264, 0, -7264, 0, 20130, 0, -7263, 0, -7170, 0, 5729, 0, -7104, 0, -7104, 0, 9524, 0, -7103, 0, -7103, 0, 9514, 0, -7102, 0, -7102, 0, 9503, 0, -7101, 0, -7101, 0, 9521, 0, -7100, 0, -7100, 0, 9500, 0, -7099, 0, -7097, 0, 20131, 0, -7096, 0, -7096, 0, 9509, 0, -7095, 0, -7091, 0, 20134, 0, -7090, 0, -7090, 0, 8653, 0, -7089, 0, -7089, 0, 20139, 0, -7088, 0, -7088, 0, 8666, 0, -7087, 0, -7087, 0, 20140, 0, -7086, 0, -7086, 0, 8562, 0, -7085, 0, -7085, 0, 9534, 0, -7084, 0, -7081, 0, 20141, 0, -7080, 0, -7080, 0, 8271, 0, -7079, 0, -7079, 0, 20145, 0, -7078, 0, -7078, 0, 9539, 0, -7077, 0, -7077, 0, 20146, 0, -7076, 0, -7076, 0, 8663, 0, -7075, 0, -7075, 0, 20147, 0, -7074, 0, -7074, 0, 7740, 0, -7073, 0, -7071, 0, 20148, 0, -7070, 0, -7070, 0, 9513, 0, -7069, 0, -7068, 0, 20151, 0, -7067, 0, -7067, 0, 9505, 0, -7066, 0, -7065, 0, 20153, 0, -7064, 0, -7064, 0, 7935, 0, -7063, 0, -7054, 0, 20155, 0, -7053, 0, -7053, 0, 9535, 0, -7052, 0, -7052, 0, 20165, 0, -7051, 0, -7051, 0, 9540, 0, -7050, 0, -7048, 0, 20166, 0, -7047, 0, -7047, 0, 9507, 0, -7046, 0, -7046, 0, 7824, 0, -7045, 0, -7045, 0, 9530, 0, -7044, 0, -7044, 0, 9541, 0, -7043, 0, -7043, 0, 20169, 0, -7042, 0, -7042, 0, 9533, 0, -7040, 0, -7040, 0, 20170, 0, -7039, 0, -7039, 0, 8385, 0, -7038, 0, -7037, 0, 20171, 0, -7036, 0, -7036, 0, 8451, 0, -7035, 0, -7035, 0, 9504, 0, -7034, 0, -7034, 0, 9532, 0, -7033, 0, -7033, 0, 9531, 0, -7032, 0, -7032, 0, 9528, 0, -7031, 0, -7028, 0, 20173, 0, -7027, 0, -7027, 0, 9536, 0, -7026, 0, -7026, 0, 20177, 0, -7025, 0, -7025, 0, 8141, 0, -7024, 0, -7022, 0, 20178, 0, -7021, 0, -7021, 0, 7960, 0, -7020, 0, -7017, 0, 20181, 0, -7016, 0, -7016, 0, 9547, 0, -7015, 0, -7012, 0, 20185, 0, -7011, 0, -7011, 0, 9543, 0, -7010, 0, -7009, 0, 9551, 0, -7008, 0, -7008, 0, 20189, 0, -7007, 0, -6914, 0, 5823, 0, -6848, 0, -6843, 0, 20190, 0, -6842, 0, -6842, 0, 8880, 0, -6841, 0, -6841, 0, 20196, 0, -6840, 0, -6840, 0, 9542, 0, -6839, 0, -6838, 0, 20197, 0, -6837, 0, -6837, 0, 9548, 0, -6836, 0, -6835, 0, 20199, 0, -6834, 0, -6834, 0, 7834, 0, -6833, 0, -6833, 0, 9554, 0, -6832, 0, -6832, 0, 9520, 0, -6831, 0, -6831, 0, 9545, 0, -6830, 0, -6828, 0, 20201, 0, -6827, 0, -6827, 0, 9553, 0, -6826, 0, -6826, 0, 7882, 0, -6825, 0, -6825, 0, 20204, 0, -6824, 0, -6824, 0, 8402, 0, -6823, 0, -6821, 0, 20205, 0, -6820, 0, -6820, 0, 8120, 0, -6819, 0, -6819, 0, 20208, 0, -6818, 0, -6818, 0, 8313, 0, -6817, 0, -6816, 0, 20209, 0, -6815, 0, -6815, 0, 8619, 0, -6814, 0, -6813, 0, 20211, 0, -6812, 0, -6812, 0, 9549, 0, -6811, 0, -6811, 0, 7845, 0, -6810, 0, -6809, 0, 20213, 0, -6808, 0, -6808, 0, 8268, 0, -6807, 0, -6807, 0, 8320, 0, -6806, 0, -6805, 0, 20215, 0, -6804, 0, -6804, 0, 9837, 0, -6803, 0, -6803, 0, 20217, 0, -6802, 0, -6802, 0, 9527, 0, -6801, 0, -6796, 0, 20218, 0, -6795, 0, -6795, 0, 9546, 0, -6794, 0, -6794, 0, 8632, 0, -6793, 0, -6793, 0, 20224, 0, -6792, 0, -6792, 0, 9550, 0, -6791, 0, -6790, 0, 20225, 0, -6789, 0, -6789, 0, 9468, 0, -6788, 0, -6788, 0, 9556, 0, -6787, 0, -6786, 0, 20227, 0, -6784, 0, -6784, 0, 20229, 0, -6783, 0, -6783, 0, 7996, 0, -6782, 0, -6782, 0, 20230, 0, -6781, 0, -6781, 0, 7893, 0, -6780, 0, -6775, 0, 20231, 0, -6774, 0, -6774, 0, 9558, 0, -6773, 0, -6771, 0, 20237, 0, -6770, 0, -6770, 0, 8808, 0, -6769, 0, -6768, 0, 20240, 0, -6767, 0, -6767, 0, 7894, 0, -6766, 0, -6759, 0, 20242, 0, -6758, 0, -6758, 0, 9559, 0, -6757, 0, -6757, 0, 9555, 0, -6756, 0, -6754, 0, 20250, 0, -6753, 0, -6753, 0, 9544, 0, -6752, 0, -6752, 0, 20253, 0, -6751, 0, -6658, 0, 5917, 0, -6592, 0, -6592, 0, 8412, 0, -6591, 0, -6589, 0, 20254, 0, -6588, 0, -6588, 0, 9561, 0, -6587, 0, -6584, 0, 20257, 0, -6583, 0, -6583, 0, 8087, 0, -6582, 0, -6582, 0, 9557, 0, -6581, 0, -6579, 0, 20261, 0, -6578, 0, -6578, 0, 8829, 0, -6577, 0, -6575, 0, 20264, 0, -6574, 0, -6574, 0, 9598, 0, -6573, 0, -6571, 0, 20267, 0, -6570, 0, -6570, 0, 8316, 0, -6569, 0, -6569, 0, 20270, 0, -6568, 0, -6568, 0, 9562, 0, -6567, 0, -6566, 0, 20271, 0, -6565, 0, -6565, 0, 9566, 0, -6564, 0, -6563, 0, 20273, 0, -6562, 0, -6562, 0, 7732, 0, -6561, 0, -6552, 0, 20275, 0, -6551, 0, -6551, 0, 8542, 0, -6550, 0, -6550, 0, 20285, 0, -6549, 0, -6549, 0, 9568, 0, -6548, 0, -6540, 0, 20286, 0, -6539, 0, -6539, 0, 8610, 0, -6538, 0, -6538, 0, 9044, 0, -6537, 0, -6536, 0, 20295, 0, -6535, 0, -6535, 0, 9571, 0, -6534, 0, -6534, 0, 9511, 0, -6533, 0, -6533, 0, 20297, 0, -6532, 0, -6532, 0, 9518, 0, -6531, 0, -6531, 0, 9560, 0, -6530, 0, -6530, 0, 20298, 0, -6528, 0, -6528, 0, 7963, 0, -6527, 0, -6527, 0, 20299, 0, -6526, 0, -6526, 0, 8835, 0, -6525, 0, -6525, 0, 20300, 0, -6524, 0, -6524, 0, 9572, 0, -6523, 0, -6522, 0, 20301, 0, -6521, 0, -6521, 0, 8352, 0, -6520, 0, -6520, 0, 20303, 0, -6519, 0, -6519, 0, 9573, 0, -6518, 0, -6517, 0, 20304, 0, -6516, 0, -6516, 0, 9569, 0, -6515, 0, -6510, 0, 20306, 0, -6509, 0, -6509, 0, 9570, 0, -6508, 0, -6506, 0, 20312, 0, -6505, 0, -6505, 0, 9580, 0, -6504, 0, -6502, 0, 20315, 0, -6501, 0, -6501, 0, 9581, 0, -6500, 0, -6500, 0, 8224, 0, -6499, 0, -6498, 0, 20318, 0, -6497, 0, -6497, 0, 9567, 0, -6496, 0, -6496, 0, 9578, 0, -6495, 0, -6402, 0, 6011, 0, -6336, 0, -6334, 0, 20320, 0, -6333, 0, -6333, 0, 9582, 0, -6332, 0, -6329, 0, 20323, 0, -6328, 0, -6328, 0, 9529, 0, -6327, 0, -6327, 0, 9564, 0, -6326, 0, -6324, 0, 20327, 0, -6323, 0, -6322, 0, 9576, 0, -6321, 0, -6321, 0, 9579, 0, -6320, 0, -6320, 0, 7791, 0, -6319, 0, -6319, 0, 20330, 0, -6318, 0, -6318, 0, 8132, 0, -6317, 0, -6317, 0, 9575, 0, -6316, 0, -6316, 0, 20331, 0, -6315, 0, -6315, 0, 9563, 0, -6314, 0, -6312, 0, 20332, 0, -6311, 0, -6311, 0, 9757, 0, -6310, 0, -6299, 0, 20335, 0, -6298, 0, -6298, 0, 9515, 0, -6297, 0, -6297, 0, 20347, 0, -6296, 0, -6296, 0, 9585, 0, -6295, 0, -6295, 0, 20348, 0, -6294, 0, -6294, 0, 9591, 0, -6293, 0, -6285, 0, 20349, 0, -6284, 0, -6284, 0, 9506, 0, -6283, 0, -6277, 0, 20358, 0, -6276, 0, -6276, 0, 9523, 0, -6275, 0, -6274, 0, 20365, 0, -6272, 0, -6271, 0, 20367, 0, -6270, 0, -6270, 0, 8234, 0, -6269, 0, -6269, 0, 20369, 0, -6268, 0, -6268, 0, 9526, 0, -6267, 0, -6267, 0, 9587, 0, -6266, 0, -6266, 0, 9583, 0, -6265, 0, -6263, 0, 20370, 0, -6262, 0, -6262, 0, 8851, 0, -6261, 0, -6261, 0, 9592, 0, -6260, 0, -6258, 0, 20373, 0, -6257, 0, -6257, 0, 9584, 0, -6256, 0, -6255, 0, 20376, 0, -6254, 0, -6254, 0, 9589, 0, -6253, 0, -6249, 0, 20378, 0, -6248, 0, -6247, 0, 9537, 0, -6246, 0, -6246, 0, 9565, 0, -6245, 0, -6241, 0, 20383, 0, -6240, 0, -6240, 0, 8218, 0, -6239, 0, -6146, 0, 6105, 0, -6080, 0, -6078, 0, 20388, 0, -6077, 0, -6077, 0, 9594, 0, -6076, 0, -6076, 0, 8198, 0, -6075, 0, -6075, 0, 20391, 0, -6074, 0, -6074, 0, 8567, 0, -6073, 0, -6072, 0, 20392, 0, -6071, 0, -6071, 0, 9499, 0, -6070, 0, -6070, 0, 20394, 0, -6069, 0, -6069, 0, 9508, 0, -6068, 0, -6066, 0, 20395, 0, -6065, 0, -6065, 0, 9595, 0, -6064, 0, -6061, 0, 20398, 0, -6060, 0, -6060, 0, 8867, 0, -6059, 0, -6055, 0, 20402, 0, -6054, 0, -6054, 0, 9593, 0, -6053, 0, -6053, 0, 20407, 0, -6052, 0, -6052, 0, 9574, 0, -6051, 0, -6047, 0, 20408, 0, -6046, 0, -6046, 0, 8083, 0, -6045, 0, -6045, 0, 20413, 0, -6044, 0, -6044, 0, 9596, 0, -6043, 0, -6033, 0, 20414, 0, -6032, 0, -6032, 0, 9492, 0, -6031, 0, -6030, 0, 20425, 0, -6029, 0, -6029, 0, 9597, 0, -6028, 0, -6028, 0, 20427, 0, -6027, 0, -6027, 0, 9586, 0, -6026, 0, -6021, 0, 20428, 0, -6020, 0, -6020, 0, 9588, 0, -6019, 0, -6018, 0, 20434, 0, -6016, 0, -6016, 0, 8782, 0, -6015, 0, -6015, 0, 20436, 0, -6014, 0, -6014, 0, 8646, 0, -6013, 0, -6010, 0, 20437, 0, -6009, 0, -6009, 0, 8351, 0, -6008, 0, -6008, 0, 20441, 0, -6007, 0, -6007, 0, 9590, 0, -6006, 0, -6005, 0, 20442, 0, -6004, 0, -6004, 0, 8292, 0, -6003, 0, -6003, 0, 8895, 0, -6002, 0, -6002, 0, 9756, 0, -6001, 0, -6001, 0, 8798, 0, -6000, 0, -5984, 0, 20444, 0, -5983, 0, -5890, 0, 6199, 0, -5824, 0, -5813, 0, 20461, 0, -5812, 0, -5812, 0, 7797, 0, -5811, 0, -5805, 0, 20473, 0, -5804, 0, -5804, 0, 8317, 0, -5803, 0, -5803, 0, 20480, 0, -5802, 0, -5802, 0, 9151, 0, -5801, 0, -5801, 0, 8467, 0, -5800, 0, -5799, 0, 20481, 0, -5798, 0, -5798, 0, 9152, 0, -5797, 0, -5796, 0, 20483, 0, -5795, 0, -5795, 0, 7749, 0, -5794, 0, -5794, 0, 20485, 0, -5793, 0, -5793, 0, 8152, 0, -5792, 0, -5792, 0, 9156, 0, -5791, 0, -5791, 0, 20486, 0, -5790, 0, -5790, 0, 9154, 0, -5789, 0, -5789, 0, 8452, 0, -5788, 0, -5788, 0, 20487, 0, -5787, 0, -5787, 0, 8637, 0, -5786, 0, -5786, 0, 20488, 0, -5785, 0, -5785, 0, 8071, 0, -5784, 0, -5784, 0, 9155, 0, -5783, 0, -5781, 0, 20489, 0, -5780, 0, -5780, 0, 8809, 0, -5779, 0, -5772, 0, 20492, 0, -5771, 0, -5771, 0, 8003, 0, -5770, 0, -5770, 0, 20500, 0, -5769, 0, -5769, 0, 7966, 0, -5768, 0, -5768, 0, 9849, 0, -5767, 0, -5767, 0, 7915, 0, -5766, 0, -5765, 0, 20501, 0, -5764, 0, -5764, 0, 7989, 0, -5763, 0, -5763, 0, 8330, 0, -5762, 0, -5762, 0, 20503, 0, -5760, 0, -5760, 0, 9159, 0, -5759, 0, -5759, 0, 9161, 0, -5758, 0, -5758, 0, 9158, 0, -5757, 0, -5754, 0, 20504, 0, -5753, 0, -5753, 0, 8783, 0, -5752, 0, -5750, 0, 20508, 0, -5749, 0, -5749, 0, 9163, 0, -5748, 0, -5747, 0, 20511, 0, -5746, 0, -5746, 0, 8691, 0, -5745, 0, -5745, 0, 20513, 0, -5744, 0, -5744, 0, 8695, 0, -5743, 0, -5743, 0, 9167, 0, -5742, 0, -5742, 0, 9166, 0, -5741, 0, -5741, 0, 9162, 0, -5740, 0, -5740, 0, 9165, 0, -5739, 0, -5737, 0, 20514, 0, -5736, 0, -5736, 0, 9168, 0, -5735, 0, -5734, 0, 20517, 0, -5733, 0, -5733, 0, 9836, 0, -5732, 0, -5732, 0, 20519, 0, -5731, 0, -5731, 0, 9153, 0, -5730, 0, -5730, 0, 20520, 0, -5729, 0, -5729, 0, 8174, 0, -5728, 0, -5728, 0, 9169, 0, -5727, 0, -5634, 0, 6293, 0, -5568, 0, -5568, 0, 8184, 0, -5567, 0, -5565, 0, 20521, 0, -5564, 0, -5564, 0, 9171, 0, -5563, 0, -5561, 0, 20524, 0, -5560, 0, -5560, 0, 9170, 0, -5559, 0, -5559, 0, 9172, 0, -5558, 0, -5558, 0, 7832, 0, -5557, 0, -5553, 0, 20527, 0, -5552, 0, -5552, 0, 7980, 0, -5551, 0, -5551, 0, 20532, 0, -5550, 0, -5550, 0, 9173, 0, -5549, 0, -5548, 0, 20533, 0, -5547, 0, -5547, 0, 7793, 0, -5546, 0, -5546, 0, 9873, 0, -5545, 0, -5544, 0, 20535, 0, -5543, 0, -5543, 0, 9157, 0, -5542, 0, -5506, 0, 20537, 0, -5504, 0, -5504, 0, 8986, 0, -5503, 0, -5501, 0, 20574, 0, -5500, 0, -5500, 0, 8468, 0, -5499, 0, -5498, 0, 20577, 0, -5497, 0, -5497, 0, 8836, 0, -5496, 0, -5491, 0, 20579, 0, -5490, 0, -5490, 0, 8732, 0, -5489, 0, -5489, 0, 20585, 0, -5488, 0, -5488, 0, 7806, 0, -5487, 0, -5487, 0, 8269, 0, -5486, 0, -5483, 0, 20586, 0, -5482, 0, -5482, 0, 8705, 0, -5481, 0, -5473, 0, 20590, 0, -5472, 0, -5472, 0, 7897, 0, -5471, 0, -5378, 0, 6387, 0, -5312, 0, -5312, 0, 20599, 0, -5311, 0, -5311, 0, 8114, 0, -5310, 0, -5308, 0, 20600, 0, -5307, 0, -5307, 0, 8786, 0, -5306, 0, -5305, 0, 20603, 0, -5304, 0, -5304, 0, 8057, 0, -5303, 0, -5294, 0, 20605, 0, -5293, 0, -5293, 0, 8535, 0, -5292, 0, -5292, 0, 20615, 0, -5291, 0, -5291, 0, 8639, 0, -5290, 0, -5286, 0, 20616, 0, -5285, 0, -5285, 0, 8735, 0, -5284, 0, -5284, 0, 20621, 0, -5283, 0, -5283, 0, 8253, 0, -5282, 0, -5281, 0, 20622, 0, -5280, 0, -5280, 0, 8213, 0, -5279, 0, -5279, 0, 20624, 0, -5278, 0, -5278, 0, 9893, 0, -5277, 0, -5268, 0, 20625, 0, -5267, 0, -5267, 0, 8534, 0, -5266, 0, -5265, 0, 20635, 0, -5264, 0, -5264, 0, 8516, 0, -5263, 0, -5263, 0, 20637, 0, -5262, 0, -5262, 0, 7825, 0, -5261, 0, -5261, 0, 8791, 0, -5260, 0, -5257, 0, 20638, 0, -5256, 0, -5256, 0, 8202, 0, -5255, 0, -5255, 0, 8338, 0, -5254, 0, -5250, 0, 20642, 0, -5248, 0, -5244, 0, 20647, 0, -5243, 0, -5243, 0, 8784, 0, -5242, 0, -5239, 0, 20652, 0, -5238, 0, -5238, 0, 7875, 0, -5237, 0, -5216, 0, 20656, 0, -5215, 0, -5122, 0, 6481, 0, -5056, 0, -5051, 0, 20678, 0, -5050, 0, -5050, 0, 8616, 0, -5049, 0, -5035, 0, 20684, 0, -5034, 0, -5034, 0, 9741, 0, -5033, 0, -5031, 0, 20699, 0, -5030, 0, -5030, 0, 9740, 0, -5029, 0, -5029, 0, 20702, 0, -5028, 0, -5028, 0, 9742, 0, -5027, 0, -5025, 0, 20703, 0, -5024, 0, -5024, 0, 8242, 0, -5023, 0, -5011, 0, 20706, 0, -5010, 0, -5010, 0, 9739, 0, -5009, 0, -5003, 0, 20719, 0, -5002, 0, -5002, 0, 8899, 0, -5001, 0, -4994, 0, 20726, 0, -4992, 0, -4971, 0, 20734, 0, -4970, 0, -4970, 0, 7971, 0, -4969, 0, -4960, 0, 20756, 0, -4959, 0, -4866, 0, 6575, 0, -4800, 0, -4795, 0, 20766, 0, -4794, 0, -4794, 0, 9877, 0, -4793, 0, -4777, 0, 20772, 0, -4776, 0, -4776, 0, 9822, 0, -4775, 0, -4771, 0, 20789, 0, -4770, 0, -4770, 0, 9821, 0, -4769, 0, -4768, 0, 20794, 0, -4767, 0, -4767, 0, 9874, 0, -4766, 0, -4765, 0, 20796, 0, -4764, 0, -4764, 0, 9823, 0, -4763, 0, -4763, 0, 20798, 0, -4762, 0, -4762, 0, 8589, 0, -4761, 0, -4761, 0, 8445, 0, -4760, 0, -4755, 0, 20799, 0, -4754, 0, -4754, 0, 8000, 0, -4753, 0, -4749, 0, 20805, 0, -4748, 0, -4748, 0, 9317, 0, -4747, 0, -4746, 0, 20810, 0, -4745, 0, -4745, 0, 9319, 0, -4744, 0, -4744, 0, 20812, 0, -4743, 0, -4743, 0, 9318, 0, -4742, 0, -4738, 0, 20813, 0, -4736, 0, -4720, 0, 20818, 0, -4719, 0, -4719, 0, 8649, 0, -4718, 0, -4718, 0, 20835, 0, -4717, 0, -4717, 0, 8713, 0, -4716, 0, -4716, 0, 7881, 0, -4715, 0, -4715, 0, 8425, 0, -4714, 0, -4714, 0, 20836, 0, -4713, 0, -4713, 0, 8650, 0, -4712, 0, -4712, 0, 8518, 0, -4711, 0, -4711, 0, 9669, 0, -4710, 0, -4710, 0, 8668, 0, -4709, 0, -4709, 0, 20837, 0, -4708, 0, -4708, 0, 9310, 0, -4707, 0, -4707, 0, 20838, 0, -4706, 0, -4706, 0, 8527, 0, -4705, 0, -4705, 0, 20839, 0, -4704, 0, -4704, 0, 9670, 0, -4703, 0, -4610, 0, 6669, 0, -4544, 0, -4544, 0, 9671, 0, -4543, 0, -4543, 0, 8769, 0, -4542, 0, -4542, 0, 8586, 0, -4541, 0, -4541, 0, 7727, 0, -4540, 0, -4540, 0, 7900, 0, -4539, 0, -4537, 0, 20840, 0, -4536, 0, -4536, 0, 8383, 0, -4535, 0, -4535, 0, 8244, 0, -4534, 0, -4532, 0, 20843, 0, -4531, 0, -4531, 0, 9673, 0, -4530, 0, -4527, 0, 20846, 0, -4526, 0, -4526, 0, 9672, 0, -4525, 0, -4524, 0, 20850, 0, -4523, 0, -4523, 0, 8718, 0, -4522, 0, -4522, 0, 20852, 0, -4521, 0, -4521, 0, 9675, 0, -4520, 0, -4515, 0, 20853, 0, -4514, 0, -4514, 0, 8573, 0, -4513, 0, -4512, 0, 20859, 0, -4511, 0, -4511, 0, 8062, 0, -4510, 0, -4505, 0, 20861, 0, -4504, 0, -4504, 0, 9676, 0, -4503, 0, -4503, 0, 8131, 0, -4502, 0, -4501, 0, 20867, 0, -4500, 0, -4500, 0, 8377, 0, -4499, 0, -4499, 0, 20869, 0, -4498, 0, -4498, 0, 8577, 0, -4497, 0, -4490, 0, 20870, 0, -4489, 0, -4489, 0, 8154, 0, -4488, 0, -4484, 0, 20878, 0, -4483, 0, -4483, 0, 8563, 0, -4482, 0, -4482, 0, 7905, 0, -4480, 0, -4480, 0, 9677, 0, -4479, 0, -4476, 0, 20883, 0, -4475, 0, -4475, 0, 9678, 0, -4474, 0, -4474, 0, 8694, 0, -4473, 0, -4471, 0, 20887, 0, -4470, 0, -4470, 0, 8779, 0, -4469, 0, -4469, 0, 9681, 0, -4468, 0, -4468, 0, 20890, 0, -4467, 0, -4467, 0, 7872, 0, -4466, 0, -4465, 0, 20891, 0, -4464, 0, -4464, 0, 8200, 0, -4463, 0, -4461, 0, 20893, 0, -4460, 0, -4460, 0, 9680, 0, -4459, 0, -4458, 0, 20896, 0, -4457, 0, -4457, 0, 9682, 0, -4456, 0, -4456, 0, 20898, 0, -4455, 0, -4455, 0, 7978, 0, -4454, 0, -4452, 0, 20899, 0, -4451, 0, -4451, 0, 7794, 0, -4450, 0, -4450, 0, 9683, 0, -4449, 0, -4448, 0, 20902, 0, -4447, 0, -4354, 0, 6763, 0, -4288, 0, -4288, 0, 8638, 0, -4287, 0, -4287, 0, 9684, 0, -4286, 0, -4286, 0, 8260, 0, -4285, 0, -4285, 0, 20904, 0, -4284, 0, -4284, 0, 9679, 0, -4283, 0, -4283, 0, 8435, 0, -4282, 0, -4277, 0, 20905, 0, -4276, 0, -4276, 0, 7936, 0, -4275, 0, -4271, 0, 20911, 0, -4270, 0, -4269, 0, 9420, 0, -4268, 0, -4268, 0, 20916, 0, -4267, 0, -4267, 0, 9880, 0, -4266, 0, -4266, 0, 20917, 0, -4265, 0, -4265, 0, 9848, 0, -4264, 0, -4263, 0, 20918, 0, -4262, 0, -4262, 0, 9422, 0, -4261, 0, -4257, 0, 20920, 0, -4256, 0, -4256, 0, 9423, 0, -4255, 0, -4249, 0, 20925, 0, -4248, 0, -4248, 0, 8376, 0, -4247, 0, -4247, 0, 20932, 0, -4246, 0, -4246, 0, 9424, 0, -4245, 0, -4245, 0, 20933, 0, -4244, 0, -4244, 0, 9425, 0, -4243, 0, -4234, 0, 20934, 0, -4233, 0, -4233, 0, 7924, 0, -4232, 0, -4231, 0, 20944, 0, -4230, 0, -4230, 0, 9115, 0, -4229, 0, -4229, 0, 20946, 0, -4228, 0, -4228, 0, 9854, 0, -4227, 0, -4226, 0, 20947, 0, -4224, 0, -4223, 0, 20949, 0, -4222, 0, -4222, 0, 9117, 0, -4221, 0, -4220, 0, 9119, 0, -4219, 0, -4219, 0, 20951, 0, -4218, 0, -4218, 0, 9121, 0, -4217, 0, -4217, 0, 20952, 0, -4216, 0, -4216, 0, 7921, 0, -4215, 0, -4214, 0, 20953, 0, -4213, 0, -4213, 0, 8734, 0, -4212, 0, -4212, 0, 20955, 0, -4211, 0, -4211, 0, 9122, 0, -4210, 0, -4204, 0, 20956, 0, -4203, 0, -4203, 0, 8523, 0, -4202, 0, -4202, 0, 7734, 0, -4201, 0, -4201, 0, 8501, 0, -4200, 0, -4197, 0, 20963, 0, -4196, 0, -4196, 0, 8109, 0, -4195, 0, -4195, 0, 20967, 0, -4194, 0, -4194, 0, 7763, 0, -4193, 0, -4192, 0, 20968, 0, -4191, 0, -4098, 0, 6857, 0, -4032, 0, -4032, 0, 20970, 0, -4031, 0, -4031, 0, 9123, 0, -4030, 0, -4030, 0, 8707, 0, -4029, 0, -4029, 0, 20971, 0, -4028, 0, -4028, 0, 7911, 0, -4027, 0, -4026, 0, 20972, 0, -4025, 0, -4025, 0, 9124, 0, -4024, 0, -4024, 0, 8343, 0, -4023, 0, -4023, 0, 7908, 0, -4022, 0, -4019, 0, 20974, 0, -4018, 0, -4018, 0, 8760, 0, -4017, 0, -4016, 0, 20978, 0, -4015, 0, -4015, 0, 9125, 0, -4014, 0, -4013, 0, 20980, 0, -4012, 0, -4012, 0, 8090, 0, -4011, 0, -4010, 0, 20982, 0, -4009, 0, -4009, 0, 8643, 0, -4008, 0, -4003, 0, 20984, 0, -4002, 0, -4002, 0, 7982, 0, -4001, 0, -3993, 0, 20990, 0, -3992, 0, -3992, 0, 9116, 0, -3991, 0, -3989, 0, 20999, 0, -3988, 0, -3988, 0, 9126, 0, -3987, 0, -3984, 0, 21002, 0, -3983, 0, -3983, 0, 9118, 0, -3982, 0, -3982, 0, 21006, 0, -3981, 0, -3981, 0, 8245, 0, -3980, 0, -3980, 0, 9127, 0, -3979, 0, -3977, 0, 21007, 0, -3976, 0, -3976, 0, 9128, 0, -3975, 0, -3975, 0, 21010, 0, -3974, 0, -3974, 0, 8309, 0, -3973, 0, -3972, 0, 21011, 0, -3971, 0, -3970, 0, 9129, 0, -3968, 0, -3968, 0, 9131, 0, -3967, 0, -3967, 0, 8171, 0, -3966, 0, -3966, 0, 9132, 0, -3965, 0, -3962, 0, 21013, 0, -3961, 0, -3961, 0, 8042, 0, -3960, 0, -3960, 0, 8441, 0, -3959, 0, -3958, 0, 21017, 0, -3957, 0, -3957, 0, 9830, 0, -3956, 0, -3953, 0, 21019, 0, -3952, 0, -3952, 0, 9831, 0, -3951, 0, -3951, 0, 21023, 0, -3950, 0, -3950, 0, 7788, 0, -3949, 0, -3947, 0, 21024, 0, -3946, 0, -3946, 0, 9133, 0, -3945, 0, -3936, 0, 21027, 0, -3935, 0, -3842, 0, 6951, 0, -3776, 0, -3759, 0, 21037, 0, -3758, 0, -3758, 0, 8301, 0, -3757, 0, -3757, 0, 8770, 0, -3756, 0, -3756, 0, 7938, 0, -3755, 0, -3754, 0, 21055, 0, -3753, 0, -3753, 0, 8579, 0, -3752, 0, -3752, 0, 21057, 0, -3751, 0, -3751, 0, 7813, 0, -3750, 0, -3750, 0, 8681, 0, -3749, 0, -3738, 0, 21058, 0, -3737, 0, -3737, 0, 7767, 0, -3736, 0, -3723, 0, 21070, 0, -3722, 0, -3722, 0, 8869, 0, -3721, 0, -3721, 0, 9223, 0, -3720, 0, -3720, 0, 8138, 0, -3719, 0, -3719, 0, 21084, 0, -3718, 0, -3718, 0, 9218, 0, -3717, 0, -3717, 0, 8066, 0, -3716, 0, -3715, 0, 21085, 0, -3714, 0, -3714, 0, 9224, 0, -3712, 0, -3712, 0, 9220, 0, -3711, 0, -3711, 0, 21087, 0, -3710, 0, -3710, 0, 8497, 0, -3709, 0, -3709, 0, 21088, 0, -3708, 0, -3708, 0, 8580, 0, -3707, 0, -3707, 0, 21089, 0, -3706, 0, -3706, 0, 9219, 0, -3705, 0, -3705, 0, 21090, 0, -3704, 0, -3704, 0, 8302, 0, -3703, 0, -3703, 0, 9227, 0, -3702, 0, -3693, 0, 21091, 0, -3692, 0, -3692, 0, 7999, 0, -3691, 0, -3689, 0, 21101, 0, -3688, 0, -3688, 0, 8295, 0, -3687, 0, -3680, 0, 21104, 0, -3679, 0, -3586, 0, 7045, 0, -3520, 0, -3516, 0, 21112, 0, -3515, 0, -3515, 0, 8151, 0, -3514, 0, -3514, 0, 21117, 0, -3513, 0, -3513, 0, 7811, 0, -3512, 0, -3510, 0, 21118, 0, -3509, 0, -3509, 0, 9231, 0, -3508, 0, -3502, 0, 21121, 0, -3501, 0, -3501, 0, 9230, 0, -3500, 0, -3500, 0, 8391, 0, -3499, 0, -3499, 0, 9229, 0, -3498, 0, -3493, 0, 21128, 0, -3492, 0, -3492, 0, 9234, 0, -3491, 0, -3490, 0, 21134, 0, -3489, 0, -3489, 0, 8375, 0, -3488, 0, -3472, 0, 21136, 0, -3471, 0, -3471, 0, 9200, 0, -3470, 0, -3470, 0, 21153, 0, -3469, 0, -3469, 0, 9233, 0, -3468, 0, -3468, 0, 9236, 0, -3467, 0, -3467, 0, 21154, 0, -3466, 0, -3466, 0, 8560, 0, -3465, 0, -3461, 0, 21155, 0, -3460, 0, -3460, 0, 9221, 0, -3459, 0, -3459, 0, 8460, 0, -3458, 0, -3458, 0, 9237, 0, -3456, 0, -3452, 0, 21160, 0, -3451, 0, -3451, 0, 8294, 0, -3450, 0, -3450, 0, 21165, 0, -3449, 0, -3449, 0, 9042, 0, -3448, 0, -3448, 0, 9235, 0, -3447, 0, -3447, 0, 9232, 0, -3446, 0, -3445, 0, 9238, 0, -3444, 0, -3444, 0, 8433, 0, -3443, 0, -3440, 0, 21166, 0, -3439, 0, -3439, 0, 9226, 0, -3438, 0, -3437, 0, 21170, 0, -3436, 0, -3436, 0, 9225, 0, -3435, 0, -3435, 0, 21172, 0, -3434, 0, -3434, 0, 9240, 0, -3433, 0, -3429, 0, 21173, 0, -3428, 0, -3428, 0, 8103, 0, -3427, 0, -3427, 0, 21178, 0, -3426, 0, -3426, 0, 8700, 0, -3425, 0, -3424, 0, 21179, 0, -3423, 0, -3330, 0, 7139, 0, -3264, 0, -3264, 0, 8129, 0, -3263, 0, -3263, 0, 9222, 0, -3262, 0, -3260, 0, 21181, 0, -3259, 0, -3259, 0, 8860, 0, -3258, 0, -3257, 0, 21184, 0, -3256, 0, -3256, 0, 8270, 0, -3255, 0, -3255, 0, 21186, 0, -3254, 0, -3254, 0, 9242, 0, -3253, 0, -3253, 0, 9241, 0, -3252, 0, -3249, 0, 21187, 0, -3248, 0, -3248, 0, 9228, 0, -3247, 0, -3232, 0, 21191, 0, -3231, 0, -3231, 0, 7721, 0, -3230, 0, -3213, 0, 21207, 0, -3212, 0, -3212, 0, 9825, 0, -3211, 0, -3211, 0, 21225, 0, -3210, 0, -3210, 0, 9892, 0, -3209, 0, -3209, 0, 8564, 0, -3208, 0, -3208, 0, 9827, 0, -3207, 0, -3207, 0, 9826, 0, -3206, 0, -3202, 0, 21226, 0, -3200, 0, -3189, 0, 21231, 0, -3188, 0, -3188, 0, 9845, 0, -3187, 0, -3169, 0, 21243, 0, -3168, 0, -3168, 0, 8524, 0, -3167, 0, -3074, 0, 7233, 0, -3008, 0, -3004, 0, 21262, 0, -3003, 0, -3003, 0, 9850, 0, -3002, 0, -2993, 0, 21267, 0, -2992, 0, -2992, 0, 9888, 0, -2991, 0, -2986, 0, 21277, 0, -2985, 0, -2985, 0, 9832, 0, -2984, 0, -2984, 0, 21283, 0, -2983, 0, -2983, 0, 7888, 0, -2982, 0, -2982, 0, 21284, 0, -2981, 0, -2981, 0, 8342, 0, -2980, 0, -2980, 0, 21285, 0, -2979, 0, -2979, 0, 9164, 0, -2978, 0, -2975, 0, 21286, 0, -2974, 0, -2974, 0, 9160, 0, -2973, 0, -2973, 0, 21290, 0, -2972, 0, -2972, 0, 8766, 0, -2971, 0, -2956, 0, 21291, 0, -2955, 0, -2955, 0, 9829, 0, -2954, 0, -2949, 0, 21307, 0, -2948, 0, -2948, 0, 9828, 0, -2947, 0, -2947, 0, 21313, 0, -2946, 0, -2946, 0, 8761, 0, -2944, 0, -2925, 0, 21314, 0, -2924, 0, -2924, 0, 8266, 0, -2923, 0, -2920, 0, 21334, 0, -2919, 0, -2919, 0, 9759, 0, -2918, 0, -2917, 0, 21338, 0, -2916, 0, -2916, 0, 9758, 0, -2915, 0, -2912, 0, 21340, 0, -2911, 0, -2818, 0, 7327, 0, -2752, 0, -2748, 0, 21344, 0, -2747, 0, -2747, 0, 9760, 0, -2746, 0, -2746, 0, 21349, 0, -2745, 0, -2745, 0, 9761, 0, -2744, 0, -2735, 0, 21350, 0, -2734, 0, -2734, 0, 9762, 0, -2733, 0, -2733, 0, 21360, 0, -2732, 0, -2732, 0, 9767, 0, -2731, 0, -2731, 0, 7737, 0, -2730, 0, -2730, 0, 9765, 0, -2729, 0, -2723, 0, 21361, 0, -2722, 0, -2722, 0, 9769, 0, -2721, 0, -2720, 0, 21368, 0, -2719, 0, -2719, 0, 9774, 0, -2718, 0, -2718, 0, 9771, 0, -2717, 0, -2707, 0, 21370, 0, -2706, 0, -2706, 0, 9770, 0, -2705, 0, -2705, 0, 9773, 0, -2704, 0, -2704, 0, 21381, 0, -2703, 0, -2703, 0, 9768, 0, -2702, 0, -2702, 0, 8633, 0, -2701, 0, -2690, 0, 21382, 0, -2688, 0, -2684, 0, 21394, 0, -2683, 0, -2683, 0, 9782, 0, -2682, 0, -2682, 0, 9776, 0, -2681, 0, -2677, 0, 21399, 0, -2676, 0, -2676, 0, 9784, 0, -2675, 0, -2675, 0, 21404, 0, -2674, 0, -2674, 0, 8205, 0, -2673, 0, -2673, 0, 9783, 0, -2672, 0, -2664, 0, 21405, 0, -2663, 0, -2663, 0, 9797, 0, -2662, 0, -2662, 0, 21414, 0, -2661, 0, -2661, 0, 9786, 0, -2660, 0, -2657, 0, 21415, 0, -2656, 0, -2656, 0, 9795, 0, -2655, 0, -2562, 0, 7421, 0, -2496, 0, -2496, 0, 21419, 0, -2495, 0, -2495, 0, 9792, 0, -2494, 0, -2492, 0, 21420, 0, -2491, 0, -2491, 0, 9789, 0, -2490, 0, -2490, 0, 9793, 0, -2489, 0, -2489, 0, 21423, 0, -2488, 0, -2488, 0, 9790, 0, -2487, 0, -2486, 0, 21424, 0, -2485, 0, -2485, 0, 9791, 0, -2484, 0, -2484, 0, 8128, 0, -2483, 0, -2483, 0, 21426, 0, -2482, 0, -2481, 0, 9787, 0, -2480, 0, -2477, 0, 21427, 0, -2476, 0, -2476, 0, 9794, 0, -2475, 0, -2473, 0, 21431, 0, -2472, 0, -2472, 0, 9796, 0, -2471, 0, -2464, 0, 21434, 0, -2463, 0, -2463, 0, 9785, 0, -2462, 0, -2462, 0, 21442, 0, -2461, 0, -2461, 0, 9804, 0, -2460, 0, -2453, 0, 21443, 0, -2452, 0, -2452, 0, 9799, 0, -2451, 0, -2451, 0, 9803, 0, -2450, 0, -2448, 0, 21451, 0, -2447, 0, -2447, 0, 9801, 0, -2446, 0, -2445, 0, 21454, 0, -2444, 0, -2444, 0, 9800, 0, -2443, 0, -2443, 0, 21456, 0, -2442, 0, -2442, 0, 9802, 0, -2441, 0, -2441, 0, 8456, 0, -2440, 0, -2434, 0, 21457, 0, -2432, 0, -2428, 0, 21464, 0, -2427, 0, -2427, 0, 9805, 0, -2426, 0, -2425, 0, 21469, 0, -2424, 0, -2424, 0, 9780, 0, -2423, 0, -2423, 0, 21471, 0, -2422, 0, -2422, 0, 9809, 0, -2421, 0, -2420, 0, 21472, 0, -2419, 0, -2419, 0, 9808, 0, -2418, 0, -2418, 0, 9810, 0, -2417, 0, -2415, 0, 21474, 0, -2414, 0, -2414, 0, 9807, 0, -2413, 0, -2411, 0, 21477, 0, -2410, 0, -2410, 0, 9778, 0, -2409, 0, -2409, 0, 9806, 0, -2408, 0, -2408, 0, 9811, 0, -2407, 0, -2407, 0, 21480, 0, -2406, 0, -2406, 0, 9815, 0, -2405, 0, -2405, 0, 21481, 0, -2404, 0, -2404, 0, 9781, 0, -2403, 0, -2403, 0, 21482, 0, -2402, 0, -2402, 0, 9779, 0, -2401, 0, -2401, 0, 21483, 0, -2400, 0, -2400, 0, 9814, 0, -2399, 0, -2306, 0, 7515, 0, -2240, 0, -2239, 0, 21484, 0, -2238, 0, -2238, 0, 9812, 0, -2237, 0, -2232, 0, 21486, 0, -2231, 0, -2231, 0, 9816, 0, -2230, 0, -2229, 0, 21492, 0, -2228, 0, -2228, 0, 9813, 0, -2227, 0, -2227, 0, 7757, 0, -2226, 0, -2219, 0, 21494, 0, -2218, 0, -2218, 0, 9819, 0, -2217, 0, -2217, 0, 21502, 0, -2216, 0, -2216, 0, 9818, 0, -2215, 0, -2215, 0, 21503, 0, -2214, 0, -2214, 0, 9817, 0, -2213, 0, -2213, 0, 8238, 0, -2212, 0, -2212, 0, 9775, 0, -2211, 0, -2208, 0, 21504, 0, -2207, 0, -2207, 0, 9798, 0, -2206, 0, -2206, 0, 21508, 0, -2205, 0, -2205, 0, 9766, 0, -2204, 0, -2198, 0, 21509, 0, -2197, 0, -2197, 0, 9820, 0, -2196, 0, -2192, 0, 21516, 0, -2191, 0, -2191, 0, 9772, 0, -2190, 0, -2181, 0, 21521, 0, -2180, 0, -2180, 0, 9763, 0, -2179, 0, -2179, 0, 21531, 0, -2178, 0, -2178, 0, 9777, 0, -2176, 0, -2144, 0, 21532, 0, -2143, 0, -2050, 0, 7609, 0, -1984, 0, -1983, 0, 21565, 0, -1982, 0, -1982, 0, 8348, 0, -1981, 0, -1979, 0, 21567, 0, -1978, 0, -1978, 0, 9600, 0, -1977, 0, -1976, 0, 21570, 0, -1975, 0, -1975, 0, 8924, 0, -1974, 0, -1969, 0, 21572, 0, -1968, 0, -1968, 0, 7941, 0, -1967, 0, -1967, 0, 8331, 0, -1966, 0, -1966, 0, 21578, 0, -1965, 0, -1965, 0, 9601, 0, -1964, 0, -1950, 0, 21579, 0, -1949, 0, -1949, 0, 9603, 0, -1948, 0, -1948, 0, 9602, 0, -1947, 0, -1947, 0, 21594, 0, -1946, 0, -1946, 0, 8686, 0, -1945, 0, -1935, 0, 21595, 0, -1934, 0, -1934, 0, 8578, 0, -1933, 0, -1929, 0, 21606, 0, -1928, 0, -1928, 0, 8771, 0, -1927, 0, -1927, 0, 21611, 0, -1926, 0, -1926, 0, 9607, 0, -1925, 0, -1925, 0, 21612, 0, -1924, 0, -1924, 0, 9608, 0, -1923, 0, -1922, 0, 21613, 0, -1920, 0, -1920, 0, 21615, 0, -1919, 0, -1919, 0, 9604, 0, -1918, 0, -1917, 0, 21616, 0, -1916, 0, -1916, 0, 8701, 0, -1915, 0, -1915, 0, 21618, 0, -1914, 0, -1914, 0, 8687, 0, -1913, 0, -1908, 0, 21619, 0, -1907, 0, -1907, 0, 9610, 0, -1906, 0, -1906, 0, 9612, 0, -1905, 0, -1896, 0, 21625, 0, -1895, 0, -1895, 0, 8007, 0, -1894, 0, -1892, 0, 21635, 0, -1891, 0, -1891, 0, 7965, 0, -1890, 0, -1889, 0, 21638, 0, -1888, 0, -1888, 0, 9613, 0, -1728, 0, -1715, 0, 21640, 0, -1714, 0, -1714, 0, 8144, 0, -1713, 0, -1713, 0, 9618, 0, -1712, 0, -1712, 0, 9615, 0, -1711, 0, -1704, 0, 21654, 0, -1703, 0, -1703, 0, 9620, 0, -1702, 0, -1702, 0, 7904, 0, -1701, 0, -1700, 0, 21662, 0, -1699, 0, -1699, 0, 9617, 0, -1698, 0, -1698, 0, 9621, 0, -1697, 0, -1690, 0, 21664, 0, -1689, 0, -1689, 0, 9623, 0, -1688, 0, -1688, 0, 21672, 0, -1687, 0, -1687, 0, 8374, 0, -1686, 0, -1685, 0, 21673, 0, -1684, 0, -1684, 0, 9624, 0, -1683, 0, -1682, 0, 21675, 0, -1681, 0, -1681, 0, 8438, 0, -1680, 0, -1666, 0, 21677, 0, -1664, 0, -1660, 0, 21692, 0, -1659, 0, -1659, 0, 9605, 0, -1658, 0, -1658, 0, 21697, 0, -1657, 0, -1657, 0, 9625, 0, -1656, 0, -1648, 0, 21698, 0, -1647, 0, -1647, 0, 9622, 0, -1646, 0, -1643, 0, 21707, 0, -1642, 0, -1642, 0, 9626, 0, -1641, 0, -1641, 0, 21711, 0, -1640, 0, -1640, 0, 9627, 0, -1639, 0, -1632, 0, 21712, 0, -1472, 0, -1471, 0, 21720, 0, -1470, 0, -1470, 0, 9629, 0, -1469, 0, -1467, 0, 21722, 0, -1466, 0, -1466, 0, 9630, 0, -1465, 0, -1461, 0, 21725, 0, -1460, 0, -1460, 0, 9036, 0, -1459, 0, -1456, 0, 21730, 0, -1455, 0, -1455, 0, 8004, 0, -1454, 0, -1449, 0, 21734, 0, -1448, 0, -1448, 0, 9824, 0, -1447, 0, -1447, 0, 9632, 0, -1446, 0, -1444, 0, 21740, 0, -1443, 0, -1443, 0, 9628, 0, -1442, 0, -1442, 0, 21743, 0, -1441, 0, -1441, 0, 9631, 0, -1440, 0, -1440, 0, 21744, 0, -1439, 0, -1439, 0, 8044, 0, -1438, 0, -1425, 0, 21745, 0, -1424, 0, -1424, 0, 9634, 0, -1423, 0, -1421, 0, 21759, 0, -1420, 0, -1420, 0, 8366, 0, -1419, 0, -1419, 0, 21762, 0, -1418, 0, -1418, 0, 9611, 0, -1417, 0, -1417, 0, 9635, 0, -1416, 0, -1410, 0, 21763, 0, -1408, 0, -1406, 0, 21770, 0, -1405, 0, -1405, 0, 9609, 0, -1404, 0, -1404, 0, 9637, 0, -1403, 0, -1396, 0, 21773, 0, -1395, 0, -1395, 0, 9636, 0, -1394, 0, -1393, 0, 21781, 0, -1392, 0, -1392, 0, 9638, 0, -1391, 0, -1391, 0, 9619, 0, -1390, 0, -1387, 0, 21783, 0, -1386, 0, -1386, 0, 9639, 0, -1385, 0, -1385, 0, 8738, 0, -1384, 0, -1384, 0, 9641, 0, -1383, 0, -1376, 0, 21787, 0, -1216, 0, -1208, 0, 21795, 0, -1207, 0, -1207, 0, 9640, 0, -1206, 0, -1199, 0, 21804, 0, -1198, 0, -1198, 0, 9606, 0, -1197, 0, -1194, 0, 21812, 0, -1193, 0, -1193, 0, 9633, 0, -1192, 0, -1192, 0, 9642, 0, -1191, 0, -1191, 0, 21816, 0, -1190, 0, -1190, 0, 9616, 0, -1189, 0, -1189, 0, 9614, 0, -1188, 0, -1164, 0, 21817, 0, -1163, 0, -1163, 0, 9864, 0, -1162, 0, -1160, 0, 21842, 0, -1159, 0, -1159, 0, 9886, 0, -1158, 0, -1158, 0, 9723, 0, -1157, 0, -1157, 0, 21845, 0, -1156, 0, -1156, 0, 8076, 0, -1155, 0, -1155, 0, 8692, 0, -1154, 0, -1154, 0, 21846, 0, -1152, 0, -1137, 0, 21847, 0, -1136, 0, -1136, 0, 8207, 0, -1135, 0, -1125, 0, 21863, 0, -1124, 0, -1124, 0, 8305, 0, -1123, 0, -1122, 0, 21874, 0, -1121, 0, -1121, 0, 9719, 0, -1120, 0, -1120, 0, 21876, 0, -960, 0, -957, 0, 21877, 0, -956, 0, -956, 0, 9878, 0, -955, 0, -952, 0, 21881, 0, -951, 0, -951, 0, 9871, 0, -950, 0, -935, 0, 21885, 0, -934, 0, -934, 0, 8922, 0, -933, 0, -926, 0, 21901, 0, -925, 0, -925, 0, 7873, 0, -924, 0, -921, 0, 21909, 0, -920, 0, -920, 0, 7859, 0, -919, 0, -914, 0, 21913, 0, -913, 0, -913, 0, 9834, 0, -912, 0, -912, 0, 21919, 0, -911, 0, -911, 0, 9866, 0, -910, 0, -909, 0, 21920, 0, -908, 0, -908, 0, 9833, 0, -907, 0, -906, 0, 21922, 0, -905, 0, -904, 0, 9752, 0, -903, 0, -898, 0, 21924, 0, -896, 0, -894, 0, 21930, 0, -893, 0, -893, 0, 9754, 0, -892, 0, -887, 0, 21933, 0, -886, 0, -886, 0, 9843, 0, -885, 0, -864, 0, 21939, 0, -704, 0, -687, 0, 21961, 0, -686, 0, -686, 0, 8390, 0, -685, 0, -685, 0, 8811, 0, -684, 0, -682, 0, 21979, 0, -681, 0, -681, 0, 9427, 0, -680, 0, -680, 0, 7814, 0, -679, 0, -679, 0, 21982, 0, -678, 0, -678, 0, 9743, 0, -677, 0, -674, 0, 21983, 0, -673, 0, -673, 0, 9745, 0, -672, 0, -671, 0, 21987, 0, -670, 0, -670, 0, 9747, 0, -669, 0, -668, 0, 21989, 0, -667, 0, -667, 0, 9744, 0, -666, 0, -666, 0, 9746, 0, -665, 0, -665, 0, 8240, 0, -664, 0, -664, 0, 21991, 0, -663, 0, -663, 0, 9841, 0, -662, 0, -661, 0, 21992, 0, -660, 0, -660, 0, 9748, 0, -659, 0, -657, 0, 21994, 0, -656, 0, -656, 0, 9750, 0, -655, 0, -655, 0, 21997, 0, -654, 0, -654, 0, 9749, 0, -653, 0, -649, 0, 21998, 0, -648, 0, -648, 0, 8434, 0, -647, 0, -644, 0, 22003, 0, -643, 0, -643, 0, 9751, 0, -642, 0, -642, 0, 22007, 0, -640, 0, -633, 0, 22008, 0, -632, 0, -632, 0, 8247, 0, -631, 0, -630, 0, 22016, 0, -629, 0, -629, 0, 8371, 0, -628, 0, -626, 0, 22018, 0, -625, 0, -625, 0, 7970, 0, -624, 0, -624, 0, 9453, 0, -623, 0, -621, 0, 22021, 0, -620, 0, -620, 0, 7988, 0, -619, 0, -612, 0, 22024, 0, -611, 0, -611, 0, 2562, 0, -610, 0, -610, 0, 16595, 0, -609, 0, -609, 0, 8204, 0, -608, 0, -608, 0, 20611, 0, -448, 0, -448, 0, 4697, 0, -447, 0, -386, 0, 22032, 0, -384, 0, -352, 0, 22094, 0, -1, 0, -1, 0, 0, 0], ["i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0], ALLOC_STATIC);
_CMAP_ARRAY_GBK_EUC_V=allocate([-24158, 0, -24158, 0, 575, 0, -24157, 0, -24157, 0, 574, 0, -24150, 0, -24150, 0, 598, 0, -24149, 0, -24148, 0, 7704, 0, -24147, 0, -24147, 0, 599, 0, -24142, 0, -24129, 0, 582, 0, -24066, 0, -24066, 0, 7706, 0, -23647, 0, -23647, 0, 578, 0, -23640, 0, -23639, 0, 580, 0, -23636, 0, -23636, 0, 573, 0, -23634, 0, -23634, 0, 7707, 0, -23622, 0, -23621, 0, 576, 0, -23619, 0, -23619, 0, 7708, 0, -23617, 0, -23617, 0, 579, 0, -23589, 0, -23589, 0, 7709, 0, -23587, 0, -23587, 0, 7710, 0, -23585, 0, -23585, 0, 600, 0, -23557, 0, -23557, 0, 596, 0, -23555, 0, -23555, 0, 597, 0, -23554, 0, -23554, 0, 7711, 0, -1, 0, -1, 0, 0, 0], ["i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0], ALLOC_STATIC);
_GBK_EUC_NOTDEF_RANGE=allocate([0, 0, 31, 0, 7716, 0], ["i16",0,"i16",0,"i16",0], ALLOC_STATIC);
_CP936_UNICODE_ARRAY=allocate([0, 0, 0, 0, 1, 0, 1, 0, 2, 0, 2, 0, 3, 0, 3, 0, 4, 0, 4, 0, 5, 0, 5, 0, 6, 0, 6, 0, 7, 0, 7, 0, 8, 0, 8, 0, 9, 0, 9, 0, 10, 0, 10, 0, 11, 0, 11, 0, 12, 0, 12, 0, 13, 0, 13, 0, 14, 0, 14, 0, 15, 0, 15, 0, 16, 0, 16, 0, 17, 0, 17, 0, 18, 0, 18, 0, 19, 0, 19, 0, 20, 0, 20, 0, 21, 0, 21, 0, 22, 0, 22, 0, 23, 0, 23, 0, 24, 0, 24, 0, 25, 0, 25, 0, 26, 0, 26, 0, 27, 0, 27, 0, 28, 0, 28, 0, 29, 0, 29, 0, 30, 0, 30, 0, 31, 0, 31, 0, 32, 0, 32, 0, 33, 0, 33, 0, 34, 0, 34, 0, 35, 0, 35, 0, 36, 0, 36, 0, 37, 0, 37, 0, 38, 0, 38, 0, 39, 0, 39, 0, 40, 0, 40, 0, 41, 0, 41, 0, 42, 0, 42, 0, 43, 0, 43, 0, 44, 0, 44, 0, 45, 0, 45, 0, 46, 0, 46, 0, 47, 0, 47, 0, 48, 0, 48, 0, 49, 0, 49, 0, 50, 0, 50, 0, 51, 0, 51, 0, 52, 0, 52, 0, 53, 0, 53, 0, 54, 0, 54, 0, 55, 0, 55, 0, 56, 0, 56, 0, 57, 0, 57, 0, 58, 0, 58, 0, 59, 0, 59, 0, 60, 0, 60, 0, 61, 0, 61, 0, 62, 0, 62, 0, 63, 0, 63, 0, 64, 0, 64, 0, 65, 0, 65, 0, 66, 0, 66, 0, 67, 0, 67, 0, 68, 0, 68, 0, 69, 0, 69, 0, 70, 0, 70, 0, 71, 0, 71, 0, 72, 0, 72, 0, 73, 0, 73, 0, 74, 0, 74, 0, 75, 0, 75, 0, 76, 0, 76, 0, 77, 0, 77, 0, 78, 0, 78, 0, 79, 0, 79, 0, 80, 0, 80, 0, 81, 0, 81, 0, 82, 0, 82, 0, 83, 0, 83, 0, 84, 0, 84, 0, 85, 0, 85, 0, 86, 0, 86, 0, 87, 0, 87, 0, 88, 0, 88, 0, 89, 0, 89, 0, 90, 0, 90, 0, 91, 0, 91, 0, 92, 0, 92, 0, 93, 0, 93, 0, 94, 0, 94, 0, 95, 0, 95, 0, 96, 0, 96, 0, 97, 0, 97, 0, 98, 0, 98, 0, 99, 0, 99, 0, 100, 0, 100, 0, 101, 0, 101, 0, 102, 0, 102, 0, 103, 0, 103, 0, 104, 0, 104, 0, 105, 0, 105, 0, 106, 0, 106, 0, 107, 0, 107, 0, 108, 0, 108, 0, 109, 0, 109, 0, 110, 0, 110, 0, 111, 0, 111, 0, 112, 0, 112, 0, 113, 0, 113, 0, 114, 0, 114, 0, 115, 0, 115, 0, 116, 0, 116, 0, 117, 0, 117, 0, 118, 0, 118, 0, 119, 0, 119, 0, 120, 0, 120, 0, 121, 0, 121, 0, 122, 0, 122, 0, 123, 0, 123, 0, 124, 0, 124, 0, 125, 0, 125, 0, 126, 0, 126, 0, 127, 0, 127, 0, 128, 0, 128, 0, 255, 0, -1803, 0, -32448, 0, 19970, 0, -32447, 0, 19972, 0, -32446, 0, 19973, 0, -32445, 0, 19974, 0, -32444, 0, 19983, 0, -32443, 0, 19986, 0, -32442, 0, 19991, 0, -32441, 0, 19999, 0, -32440, 0, 20000, 0, -32439, 0, 20001, 0, -32438, 0, 20003, 0, -32437, 0, 20006, 0, -32436, 0, 20009, 0, -32435, 0, 20014, 0, -32434, 0, 20015, 0, -32433, 0, 20017, 0, -32432, 0, 20019, 0, -32431, 0, 20021, 0, -32430, 0, 20023, 0, -32429, 0, 20028, 0, -32428, 0, 20032, 0, -32427, 0, 20033, 0, -32426, 0, 20034, 0, -32425, 0, 20036, 0, -32424, 0, 20038, 0, -32423, 0, 20042, 0, -32422, 0, 20049, 0, -32421, 0, 20053, 0, -32420, 0, 20055, 0, -32419, 0, 20058, 0, -32418, 0, 20059, 0, -32417, 0, 20066, 0, -32416, 0, 20067, 0, -32415, 0, 20068, 0, -32414, 0, 20069, 0, -32413, 0, 20071, 0, -32412, 0, 20072, 0, -32411, 0, 20074, 0, -32410, 0, 20075, 0, -32409, 0, 20076, 0, -32408, 0, 20077, 0, -32407, 0, 20078, 0, -32406, 0, 20079, 0, -32405, 0, 20082, 0, -32404, 0, 20084, 0, -32403, 0, 20085, 0, -32402, 0, 20086, 0, -32401, 0, 20087, 0, -32400, 0, 20088, 0, -32399, 0, 20089, 0, -32398, 0, 20090, 0, -32397, 0, 20091, 0, -32396, 0, 20092, 0, -32395, 0, 20093, 0, -32394, 0, 20095, 0, -32393, 0, 20096, 0, -32392, 0, 20097, 0, -32391, 0, 20098, 0, -32390, 0, 20099, 0, -32389, 0, 20100, 0, -32388, 0, 20101, 0, -32387, 0, 20103, 0, -32386, 0, 20106, 0, -32384, 0, 20112, 0, -32383, 0, 20118, 0, -32382, 0, 20119, 0, -32381, 0, 20121, 0, -32380, 0, 20124, 0, -32379, 0, 20125, 0, -32378, 0, 20126, 0, -32377, 0, 20131, 0, -32376, 0, 20138, 0, -32375, 0, 20143, 0, -32374, 0, 20144, 0, -32373, 0, 20145, 0, -32372, 0, 20148, 0, -32371, 0, 20150, 0, -32370, 0, 20151, 0, -32369, 0, 20152, 0, -32368, 0, 20153, 0, -32367, 0, 20156, 0, -32366, 0, 20157, 0, -32365, 0, 20158, 0, -32364, 0, 20168, 0, -32363, 0, 20172, 0, -32362, 0, 20175, 0, -32361, 0, 20176, 0, -32360, 0, 20178, 0, -32359, 0, 20186, 0, -32358, 0, 20187, 0, -32357, 0, 20188, 0, -32356, 0, 20192, 0, -32355, 0, 20194, 0, -32354, 0, 20198, 0, -32353, 0, 20199, 0, -32352, 0, 20201, 0, -32351, 0, 20205, 0, -32350, 0, 20206, 0, -32349, 0, 20207, 0, -32348, 0, 20209, 0, -32347, 0, 20212, 0, -32346, 0, 20216, 0, -32345, 0, 20217, 0, -32344, 0, 20218, 0, -32343, 0, 20220, 0, -32342, 0, 20222, 0, -32341, 0, 20224, 0, -32340, 0, 20226, 0, -32339, 0, 20227, 0, -32338, 0, 20228, 0, -32337, 0, 20229, 0, -32336, 0, 20230, 0, -32335, 0, 20231, 0, -32334, 0, 20232, 0, -32333, 0, 20235, 0, -32332, 0, 20236, 0, -32331, 0, 20242, 0, -32330, 0, 20243, 0, -32329, 0, 20244, 0, -32328, 0, 20245, 0, -32327, 0, 20246, 0, -32326, 0, 20252, 0, -32325, 0, 20253, 0, -32324, 0, 20257, 0, -32323, 0, 20259, 0, -32322, 0, 20264, 0, -32321, 0, 20265, 0, -32320, 0, 20268, 0, -32319, 0, 20269, 0, -32318, 0, 20270, 0, -32317, 0, 20273, 0, -32316, 0, 20275, 0, -32315, 0, 20277, 0, -32314, 0, 20279, 0, -32313, 0, 20281, 0, -32312, 0, 20283, 0, -32311, 0, 20286, 0, -32310, 0, 20287, 0, -32309, 0, 20288, 0, -32308, 0, 20289, 0, -32307, 0, 20290, 0, -32306, 0, 20292, 0, -32305, 0, 20293, 0, -32304, 0, 20295, 0, -32303, 0, 20296, 0, -32302, 0, 20297, 0, -32301, 0, 20298, 0, -32300, 0, 20299, 0, -32299, 0, 20300, 0, -32298, 0, 20306, 0, -32297, 0, 20308, 0, -32296, 0, 20310, 0, -32295, 0, 20321, 0, -32294, 0, 20322, 0, -32293, 0, 20326, 0, -32292, 0, 20328, 0, -32291, 0, 20330, 0, -32290, 0, 20331, 0, -32289, 0, 20333, 0, -32288, 0, 20334, 0, -32287, 0, 20337, 0, -32286, 0, 20338, 0, -32285, 0, 20341, 0, -32284, 0, 20343, 0, -32283, 0, 20344, 0, -32282, 0, 20345, 0, -32281, 0, 20346, 0, -32280, 0, 20349, 0, -32279, 0, 20352, 0, -32278, 0, 20353, 0, -32277, 0, 20354, 0, -32276, 0, 20357, 0, -32275, 0, 20358, 0, -32274, 0, 20359, 0, -32273, 0, 20362, 0, -32272, 0, 20364, 0, -32271, 0, 20366, 0, -32270, 0, 20368, 0, -32269, 0, 20370, 0, -32268, 0, 20371, 0, -32267, 0, 20373, 0, -32266, 0, 20374, 0, -32265, 0, 20376, 0, -32264, 0, 20377, 0, -32263, 0, 20378, 0, -32262, 0, 20380, 0, -32261, 0, 20382, 0, -32260, 0, 20383, 0, -32259, 0, 20385, 0, -32258, 0, 20386, 0, -32192, 0, 20388, 0, -32191, 0, 20395, 0, -32190, 0, 20397, 0, -32189, 0, 20400, 0, -32188, 0, 20401, 0, -32187, 0, 20402, 0, -32186, 0, 20403, 0, -32185, 0, 20404, 0, -32184, 0, 20406, 0, -32183, 0, 20407, 0, -32182, 0, 20408, 0, -32181, 0, 20409, 0, -32180, 0, 20410, 0, -32179, 0, 20411, 0, -32178, 0, 20412, 0, -32177, 0, 20413, 0, -32176, 0, 20414, 0, -32175, 0, 20416, 0, -32174, 0, 20417, 0, -32173, 0, 20418, 0, -32172, 0, 20422, 0, -32171, 0, 20423, 0, -32170, 0, 20424, 0, -32169, 0, 20425, 0, -32168, 0, 20427, 0, -32167, 0, 20428, 0, -32166, 0, 20429, 0, -32165, 0, 20434, 0, -32164, 0, 20435, 0, -32163, 0, 20436, 0, -32162, 0, 20437, 0, -32161, 0, 20438, 0, -32160, 0, 20441, 0, -32159, 0, 20443, 0, -32158, 0, 20448, 0, -32157, 0, 20450, 0, -32156, 0, 20452, 0, -32155, 0, 20453, 0, -32154, 0, 20455, 0, -32153, 0, 20459, 0, -32152, 0, 20460, 0, -32151, 0, 20464, 0, -32150, 0, 20466, 0, -32149, 0, 20468, 0, -32148, 0, 20469, 0, -32147, 0, 20470, 0, -32146, 0, 20471, 0, -32145, 0, 20473, 0, -32144, 0, 20475, 0, -32143, 0, 20476, 0, -32142, 0, 20477, 0, -32141, 0, 20479, 0, -32140, 0, 20480, 0, -32139, 0, 20481, 0, -32138, 0, 20482, 0, -32137, 0, 20483, 0, -32136, 0, 20484, 0, -32135, 0, 20485, 0, -32134, 0, 20486, 0, -32133, 0, 20487, 0, -32132, 0, 20488, 0, -32131, 0, 20489, 0, -32130, 0, 20490, 0, -32128, 0, 20491, 0, -32127, 0, 20494, 0, -32126, 0, 20496, 0, -32125, 0, 20497, 0, -32124, 0, 20499, 0, -32123, 0, 20501, 0, -32122, 0, 20502, 0, -32121, 0, 20503, 0, -32120, 0, 20507, 0, -32119, 0, 20509, 0, -32118, 0, 20510, 0, -32117, 0, 20512, 0, -32116, 0, 20514, 0, -32115, 0, 20515, 0, -32114, 0, 20516, 0, -32113, 0, 20519, 0, -32112, 0, 20523, 0, -32111, 0, 20527, 0, -32110, 0, 20528, 0, -32109, 0, 20529, 0, -32108, 0, 20530, 0, -32107, 0, 20531, 0, -32106, 0, 20532, 0, -32105, 0, 20533, 0, -32104, 0, 20534, 0, -32103, 0, 20535, 0, -32102, 0, 20536, 0, -32101, 0, 20537, 0, -32100, 0, 20539, 0, -32099, 0, 20541, 0, -32098, 0, 20543, 0, -32097, 0, 20544, 0, -32096, 0, 20545, 0, -32095, 0, 20546, 0, -32094, 0, 20548, 0, -32093, 0, 20549, 0, -32092, 0, 20550, 0, -32091, 0, 20553, 0, -32090, 0, 20554, 0, -32089, 0, 20555, 0, -32088, 0, 20557, 0, -32087, 0, 20560, 0, -32086, 0, 20561, 0, -32085, 0, 20562, 0, -32084, 0, 20563, 0, -32083, 0, 20564, 0, -32082, 0, 20566, 0, -32081, 0, 20567, 0, -32080, 0, 20568, 0, -32079, 0, 20569, 0, -32078, 0, 20571, 0, -32077, 0, 20573, 0, -32076, 0, 20574, 0, -32075, 0, 20575, 0, -32074, 0, 20576, 0, -32073, 0, 20577, 0, -32072, 0, 20578, 0, -32071, 0, 20579, 0, -32070, 0, 20580, 0, -32069, 0, 20582, 0, -32068, 0, 20583, 0, -32067, 0, 20584, 0, -32066, 0, 20585, 0, -32065, 0, 20586, 0, -32064, 0, 20587, 0, -32063, 0, 20589, 0, -32062, 0, 20590, 0, -32061, 0, 20591, 0, -32060, 0, 20592, 0, -32059, 0, 20593, 0, -32058, 0, 20594, 0, -32057, 0, 20595, 0, -32056, 0, 20596, 0, -32055, 0, 20597, 0, -32054, 0, 20600, 0, -32053, 0, 20601, 0, -32052, 0, 20602, 0, -32051, 0, 20604, 0, -32050, 0, 20605, 0, -32049, 0, 20609, 0, -32048, 0, 20610, 0, -32047, 0, 20611, 0, -32046, 0, 20612, 0, -32045, 0, 20614, 0, -32044, 0, 20615, 0, -32043, 0, 20617, 0, -32042, 0, 20618, 0, -32041, 0, 20619, 0, -32040, 0, 20620, 0, -32039, 0, 20622, 0, -32038, 0, 20623, 0, -32037, 0, 20624, 0, -32036, 0, 20625, 0, -32035, 0, 20626, 0, -32034, 0, 20627, 0, -32033, 0, 20628, 0, -32032, 0, 20629, 0, -32031, 0, 20630, 0, -32030, 0, 20631, 0, -32029, 0, 20632, 0, -32028, 0, 20633, 0, -32027, 0, 20634, 0, -32026, 0, 20635, 0, -32025, 0, 20636, 0, -32024, 0, 20637, 0, -32023, 0, 20638, 0, -32022, 0, 20639, 0, -32021, 0, 20640, 0, -32020, 0, 20641, 0, -32019, 0, 20642, 0, -32018, 0, 20644, 0, -32017, 0, 20646, 0, -32016, 0, 20650, 0, -32015, 0, 20651, 0, -32014, 0, 20653, 0, -32013, 0, 20654, 0, -32012, 0, 20655, 0, -32011, 0, 20656, 0, -32010, 0, 20657, 0, -32009, 0, 20659, 0, -32008, 0, 20660, 0, -32007, 0, 20661, 0, -32006, 0, 20662, 0, -32005, 0, 20663, 0, -32004, 0, 20664, 0, -32003, 0, 20665, 0, -32002, 0, 20668, 0, -31936, 0, 20669, 0, -31935, 0, 20670, 0, -31934, 0, 20671, 0, -31933, 0, 20672, 0, -31932, 0, 20673, 0, -31931, 0, 20674, 0, -31930, 0, 20675, 0, -31929, 0, 20676, 0, -31928, 0, 20677, 0, -31927, 0, 20678, 0, -31926, 0, 20679, 0, -31925, 0, 20680, 0, -31924, 0, 20681, 0, -31923, 0, 20682, 0, -31922, 0, 20683, 0, -31921, 0, 20684, 0, -31920, 0, 20685, 0, -31919, 0, 20686, 0, -31918, 0, 20688, 0, -31917, 0, 20689, 0, -31916, 0, 20690, 0, -31915, 0, 20691, 0, -31914, 0, 20692, 0, -31913, 0, 20693, 0, -31912, 0, 20695, 0, -31911, 0, 20696, 0, -31910, 0, 20697, 0, -31909, 0, 20699, 0, -31908, 0, 20700, 0, -31907, 0, 20701, 0, -31906, 0, 20702, 0, -31905, 0, 20703, 0, -31904, 0, 20704, 0, -31903, 0, 20705, 0, -31902, 0, 20706, 0, -31901, 0, 20707, 0, -31900, 0, 20708, 0, -31899, 0, 20709, 0, -31898, 0, 20712, 0, -31897, 0, 20713, 0, -31896, 0, 20714, 0, -31895, 0, 20715, 0, -31894, 0, 20719, 0, -31893, 0, 20720, 0, -31892, 0, 20721, 0, -31891, 0, 20722, 0, -31890, 0, 20724, 0, -31889, 0, 20726, 0, -31888, 0, 20727, 0, -31887, 0, 20728, 0, -31886, 0, 20729, 0, -31885, 0, 20730, 0, -31884, 0, 20732, 0, -31883, 0, 20733, 0, -31882, 0, 20734, 0, -31881, 0, 20735, 0, -31880, 0, 20736, 0, -31879, 0, 20737, 0, -31878, 0, 20738, 0, -31877, 0, 20739, 0, -31876, 0, 20740, 0, -31875, 0, 20741, 0, -31874, 0, 20744, 0, -31872, 0, 20745, 0, -31871, 0, 20746, 0, -31870, 0, 20748, 0, -31869, 0, 20749, 0, -31868, 0, 20750, 0, -31867, 0, 20751, 0, -31866, 0, 20752, 0, -31865, 0, 20753, 0, -31864, 0, 20755, 0, -31863, 0, 20756, 0, -31862, 0, 20757, 0, -31861, 0, 20758, 0, -31860, 0, 20759, 0, -31859, 0, 20760, 0, -31858, 0, 20761, 0, -31857, 0, 20762, 0, -31856, 0, 20763, 0, -31855, 0, 20764, 0, -31854, 0, 20765, 0, -31853, 0, 20766, 0, -31852, 0, 20767, 0, -31851, 0, 20768, 0, -31850, 0, 20770, 0, -31849, 0, 20771, 0, -31848, 0, 20772, 0, -31847, 0, 20773, 0, -31846, 0, 20774, 0, -31845, 0, 20775, 0, -31844, 0, 20776, 0, -31843, 0, 20777, 0, -31842, 0, 20778, 0, -31841, 0, 20779, 0, -31840, 0, 20780, 0, -31839, 0, 20781, 0, -31838, 0, 20782, 0, -31837, 0, 20783, 0, -31836, 0, 20784, 0, -31835, 0, 20785, 0, -31834, 0, 20786, 0, -31833, 0, 20787, 0, -31832, 0, 20788, 0, -31831, 0, 20789, 0, -31830, 0, 20790, 0, -31829, 0, 20791, 0, -31828, 0, 20792, 0, -31827, 0, 20793, 0, -31826, 0, 20794, 0, -31825, 0, 20795, 0, -31824, 0, 20796, 0, -31823, 0, 20797, 0, -31822, 0, 20798, 0, -31821, 0, 20802, 0, -31820, 0, 20807, 0, -31819, 0, 20810, 0, -31818, 0, 20812, 0, -31817, 0, 20814, 0, -31816, 0, 20815, 0, -31815, 0, 20816, 0, -31814, 0, 20818, 0, -31813, 0, 20819, 0, -31812, 0, 20823, 0, -31811, 0, 20824, 0, -31810, 0, 20825, 0, -31809, 0, 20827, 0, -31808, 0, 20829, 0, -31807, 0, 20830, 0, -31806, 0, 20831, 0, -31805, 0, 20832, 0, -31804, 0, 20833, 0, -31803, 0, 20835, 0, -31802, 0, 20836, 0, -31801, 0, 20838, 0, -31800, 0, 20839, 0, -31799, 0, 20841, 0, -31798, 0, 20842, 0, -31797, 0, 20847, 0, -31796, 0, 20850, 0, -31795, 0, 20858, 0, -31794, 0, 20862, 0, -31793, 0, 20863, 0, -31792, 0, 20867, 0, -31791, 0, 20868, 0, -31790, 0, 20870, 0, -31789, 0, 20871, 0, -31788, 0, 20874, 0, -31787, 0, 20875, 0, -31786, 0, 20878, 0, -31785, 0, 20879, 0, -31784, 0, 20880, 0, -31783, 0, 20881, 0, -31782, 0, 20883, 0, -31781, 0, 20884, 0, -31780, 0, 20888, 0, -31779, 0, 20890, 0, -31778, 0, 20893, 0, -31777, 0, 20894, 0, -31776, 0, 20895, 0, -31775, 0, 20897, 0, -31774, 0, 20899, 0, -31773, 0, 20902, 0, -31772, 0, 20903, 0, -31771, 0, 20904, 0, -31770, 0, 20905, 0, -31769, 0, 20906, 0, -31768, 0, 20909, 0, -31767, 0, 20910, 0, -31766, 0, 20916, 0, -31765, 0, 20920, 0, -31764, 0, 20921, 0, -31763, 0, 20922, 0, -31762, 0, 20926, 0, -31761, 0, 20927, 0, -31760, 0, 20929, 0, -31759, 0, 20930, 0, -31758, 0, 20931, 0, -31757, 0, 20933, 0, -31756, 0, 20936, 0, -31755, 0, 20938, 0, -31754, 0, 20941, 0, -31753, 0, 20942, 0, -31752, 0, 20944, 0, -31751, 0, 20946, 0, -31750, 0, 20947, 0, -31749, 0, 20948, 0, -31748, 0, 20949, 0, -31747, 0, 20950, 0, -31746, 0, 20951, 0, -31680, 0, 20952, 0, -31679, 0, 20953, 0, -31678, 0, 20954, 0, -31677, 0, 20956, 0, -31676, 0, 20958, 0, -31675, 0, 20959, 0, -31674, 0, 20962, 0, -31673, 0, 20963, 0, -31672, 0, 20965, 0, -31671, 0, 20966, 0, -31670, 0, 20967, 0, -31669, 0, 20968, 0, -31668, 0, 20969, 0, -31667, 0, 20970, 0, -31666, 0, 20972, 0, -31665, 0, 20974, 0, -31664, 0, 20977, 0, -31663, 0, 20978, 0, -31662, 0, 20980, 0, -31661, 0, 20983, 0, -31660, 0, 20990, 0, -31659, 0, 20996, 0, -31658, 0, 20997, 0, -31657, 0, 21001, 0, -31656, 0, 21003, 0, -31655, 0, 21004, 0, -31654, 0, 21007, 0, -31653, 0, 21008, 0, -31652, 0, 21011, 0, -31651, 0, 21012, 0, -31650, 0, 21013, 0, -31649, 0, 21020, 0, -31648, 0, 21022, 0, -31647, 0, 21023, 0, -31646, 0, 21025, 0, -31645, 0, 21026, 0, -31644, 0, 21027, 0, -31643, 0, 21029, 0, -31642, 0, 21030, 0, -31641, 0, 21031, 0, -31640, 0, 21034, 0, -31639, 0, 21036, 0, -31638, 0, 21039, 0, -31637, 0, 21041, 0, -31636, 0, 21042, 0, -31635, 0, 21044, 0, -31634, 0, 21045, 0, -31633, 0, 21052, 0, -31632, 0, 21054, 0, -31631, 0, 21060, 0, -31630, 0, 21061, 0, -31629, 0, 21062, 0, -31628, 0, 21063, 0, -31627, 0, 21064, 0, -31626, 0, 21065, 0, -31625, 0, 21067, 0, -31624, 0, 21070, 0, -31623, 0, 21071, 0, -31622, 0, 21074, 0, -31621, 0, 21075, 0, -31620, 0, 21077, 0, -31619, 0, 21079, 0, -31618, 0, 21080, 0, -31616, 0, 21081, 0, -31615, 0, 21082, 0, -31614, 0, 21083, 0, -31613, 0, 21085, 0, -31612, 0, 21087, 0, -31611, 0, 21088, 0, -31610, 0, 21090, 0, -31609, 0, 21091, 0, -31608, 0, 21092, 0, -31607, 0, 21094, 0, -31606, 0, 21096, 0, -31605, 0, 21099, 0, -31604, 0, 21100, 0, -31603, 0, 21101, 0, -31602, 0, 21102, 0, -31601, 0, 21104, 0, -31600, 0, 21105, 0, -31599, 0, 21107, 0, -31598, 0, 21108, 0, -31597, 0, 21109, 0, -31596, 0, 21110, 0, -31595, 0, 21111, 0, -31594, 0, 21112, 0, -31593, 0, 21113, 0, -31592, 0, 21114, 0, -31591, 0, 21115, 0, -31590, 0, 21116, 0, -31589, 0, 21118, 0, -31588, 0, 21120, 0, -31587, 0, 21123, 0, -31586, 0, 21124, 0, -31585, 0, 21125, 0, -31584, 0, 21126, 0, -31583, 0, 21127, 0, -31582, 0, 21129, 0, -31581, 0, 21130, 0, -31580, 0, 21131, 0, -31579, 0, 21132, 0, -31578, 0, 21133, 0, -31577, 0, 21134, 0, -31576, 0, 21135, 0, -31575, 0, 21137, 0, -31574, 0, 21138, 0, -31573, 0, 21140, 0, -31572, 0, 21141, 0, -31571, 0, 21142, 0, -31570, 0, 21143, 0, -31569, 0, 21144, 0, -31568, 0, 21145, 0, -31567, 0, 21146, 0, -31566, 0, 21148, 0, -31565, 0, 21156, 0, -31564, 0, 21157, 0, -31563, 0, 21158, 0, -31562, 0, 21159, 0, -31561, 0, 21166, 0, -31560, 0, 21167, 0, -31559, 0, 21168, 0, -31558, 0, 21172, 0, -31557, 0, 21173, 0, -31556, 0, 21174, 0, -31555, 0, 21175, 0, -31554, 0, 21176, 0, -31553, 0, 21177, 0, -31552, 0, 21178, 0, -31551, 0, 21179, 0, -31550, 0, 21180, 0, -31549, 0, 21181, 0, -31548, 0, 21184, 0, -31547, 0, 21185, 0, -31546, 0, 21186, 0, -31545, 0, 21188, 0, -31544, 0, 21189, 0, -31543, 0, 21190, 0, -31542, 0, 21192, 0, -31541, 0, 21194, 0, -31540, 0, 21196, 0, -31539, 0, 21197, 0, -31538, 0, 21198, 0, -31537, 0, 21199, 0, -31536, 0, 21201, 0, -31535, 0, 21203, 0, -31534, 0, 21204, 0, -31533, 0, 21205, 0, -31532, 0, 21207, 0, -31531, 0, 21209, 0, -31530, 0, 21210, 0, -31529, 0, 21211, 0, -31528, 0, 21212, 0, -31527, 0, 21213, 0, -31526, 0, 21214, 0, -31525, 0, 21216, 0, -31524, 0, 21217, 0, -31523, 0, 21218, 0, -31522, 0, 21219, 0, -31521, 0, 21221, 0, -31520, 0, 21222, 0, -31519, 0, 21223, 0, -31518, 0, 21224, 0, -31517, 0, 21225, 0, -31516, 0, 21226, 0, -31515, 0, 21227, 0, -31514, 0, 21228, 0, -31513, 0, 21229, 0, -31512, 0, 21230, 0, -31511, 0, 21231, 0, -31510, 0, 21233, 0, -31509, 0, 21234, 0, -31508, 0, 21235, 0, -31507, 0, 21236, 0, -31506, 0, 21237, 0, -31505, 0, 21238, 0, -31504, 0, 21239, 0, -31503, 0, 21240, 0, -31502, 0, 21243, 0, -31501, 0, 21244, 0, -31500, 0, 21245, 0, -31499, 0, 21249, 0, -31498, 0, 21250, 0, -31497, 0, 21251, 0, -31496, 0, 21252, 0, -31495, 0, 21255, 0, -31494, 0, 21257, 0, -31493, 0, 21258, 0, -31492, 0, 21259, 0, -31491, 0, 21260, 0, -31490, 0, 21262, 0, -31424, 0, 21265, 0, -31423, 0, 21266, 0, -31422, 0, 21267, 0, -31421, 0, 21268, 0, -31420, 0, 21272, 0, -31419, 0, 21275, 0, -31418, 0, 21276, 0, -31417, 0, 21278, 0, -31416, 0, 21279, 0, -31415, 0, 21282, 0, -31414, 0, 21284, 0, -31413, 0, 21285, 0, -31412, 0, 21287, 0, -31411, 0, 21288, 0, -31410, 0, 21289, 0, -31409, 0, 21291, 0, -31408, 0, 21292, 0, -31407, 0, 21293, 0, -31406, 0, 21295, 0, -31405, 0, 21296, 0, -31404, 0, 21297, 0, -31403, 0, 21298, 0, -31402, 0, 21299, 0, -31401, 0, 21300, 0, -31400, 0, 21301, 0, -31399, 0, 21302, 0, -31398, 0, 21303, 0, -31397, 0, 21304, 0, -31396, 0, 21308, 0, -31395, 0, 21309, 0, -31394, 0, 21312, 0, -31393, 0, 21314, 0, -31392, 0, 21316, 0, -31391, 0, 21318, 0, -31390, 0, 21323, 0, -31389, 0, 21324, 0, -31388, 0, 21325, 0, -31387, 0, 21328, 0, -31386, 0, 21332, 0, -31385, 0, 21336, 0, -31384, 0, 21337, 0, -31383, 0, 21339, 0, -31382, 0, 21341, 0, -31381, 0, 21349, 0, -31380, 0, 21352, 0, -31379, 0, 21354, 0, -31378, 0, 21356, 0, -31377, 0, 21357, 0, -31376, 0, 21362, 0, -31375, 0, 21366, 0, -31374, 0, 21369, 0, -31373, 0, 21371, 0, -31372, 0, 21372, 0, -31371, 0, 21373, 0, -31370, 0, 21374, 0, -31369, 0, 21376, 0, -31368, 0, 21377, 0, -31367, 0, 21379, 0, -31366, 0, 21383, 0, -31365, 0, 21384, 0, -31364, 0, 21386, 0, -31363, 0, 21390, 0, -31362, 0, 21391, 0, -31360, 0, 21392, 0, -31359, 0, 21393, 0, -31358, 0, 21394, 0, -31357, 0, 21395, 0, -31356, 0, 21396, 0, -31355, 0, 21398, 0, -31354, 0, 21399, 0, -31353, 0, 21401, 0, -31352, 0, 21403, 0, -31351, 0, 21404, 0, -31350, 0, 21406, 0, -31349, 0, 21408, 0, -31348, 0, 21409, 0, -31347, 0, 21412, 0, -31346, 0, 21415, 0, -31345, 0, 21418, 0, -31344, 0, 21419, 0, -31343, 0, 21420, 0, -31342, 0, 21421, 0, -31341, 0, 21423, 0, -31340, 0, 21424, 0, -31339, 0, 21425, 0, -31338, 0, 21426, 0, -31337, 0, 21427, 0, -31336, 0, 21428, 0, -31335, 0, 21429, 0, -31334, 0, 21431, 0, -31333, 0, 21432, 0, -31332, 0, 21433, 0, -31331, 0, 21434, 0, -31330, 0, 21436, 0, -31329, 0, 21437, 0, -31328, 0, 21438, 0, -31327, 0, 21440, 0, -31326, 0, 21443, 0, -31325, 0, 21444, 0, -31324, 0, 21445, 0, -31323, 0, 21446, 0, -31322, 0, 21447, 0, -31321, 0, 21454, 0, -31320, 0, 21455, 0, -31319, 0, 21456, 0, -31318, 0, 21458, 0, -31317, 0, 21459, 0, -31316, 0, 21461, 0, -31315, 0, 21466, 0, -31314, 0, 21468, 0, -31313, 0, 21469, 0, -31312, 0, 21470, 0, -31311, 0, 21473, 0, -31310, 0, 21474, 0, -31309, 0, 21479, 0, -31308, 0, 21492, 0, -31307, 0, 21498, 0, -31306, 0, 21502, 0, -31305, 0, 21503, 0, -31304, 0, 21504, 0, -31303, 0, 21506, 0, -31302, 0, 21509, 0, -31301, 0, 21511, 0, -31300, 0, 21515, 0, -31299, 0, 21524, 0, -31298, 0, 21528, 0, -31297, 0, 21529, 0, -31296, 0, 21530, 0, -31295, 0, 21532, 0, -31294, 0, 21538, 0, -31293, 0, 21540, 0, -31292, 0, 21541, 0, -31291, 0, 21546, 0, -31290, 0, 21552, 0, -31289, 0, 21555, 0, -31288, 0, 21558, 0, -31287, 0, 21559, 0, -31286, 0, 21562, 0, -31285, 0, 21565, 0, -31284, 0, 21567, 0, -31283, 0, 21569, 0, -31282, 0, 21570, 0, -31281, 0, 21572, 0, -31280, 0, 21573, 0, -31279, 0, 21575, 0, -31278, 0, 21577, 0, -31277, 0, 21580, 0, -31276, 0, 21581, 0, -31275, 0, 21582, 0, -31274, 0, 21583, 0, -31273, 0, 21585, 0, -31272, 0, 21594, 0, -31271, 0, 21597, 0, -31270, 0, 21598, 0, -31269, 0, 21599, 0, -31268, 0, 21600, 0, -31267, 0, 21601, 0, -31266, 0, 21603, 0, -31265, 0, 21605, 0, -31264, 0, 21607, 0, -31263, 0, 21609, 0, -31262, 0, 21610, 0, -31261, 0, 21611, 0, -31260, 0, 21612, 0, -31259, 0, 21613, 0, -31258, 0, 21614, 0, -31257, 0, 21615, 0, -31256, 0, 21616, 0, -31255, 0, 21620, 0, -31254, 0, 21625, 0, -31253, 0, 21626, 0, -31252, 0, 21630, 0, -31251, 0, 21631, 0, -31250, 0, 21633, 0, -31249, 0, 21635, 0, -31248, 0, 21637, 0, -31247, 0, 21639, 0, -31246, 0, 21640, 0, -31245, 0, 21641, 0, -31244, 0, 21642, 0, -31243, 0, 21645, 0, -31242, 0, 21649, 0, -31241, 0, 21651, 0, -31240, 0, 21655, 0, -31239, 0, 21656, 0, -31238, 0, 21660, 0, -31237, 0, 21662, 0, -31236, 0, 21663, 0, -31235, 0, 21664, 0, -31234, 0, 21665, 0, -31168, 0, 21666, 0, -31167, 0, 21669, 0, -31166, 0, 21678, 0, -31165, 0, 21680, 0, -31164, 0, 21682, 0, -31163, 0, 21685, 0, -31162, 0, 21686, 0, -31161, 0, 21687, 0, -31160, 0, 21689, 0, -31159, 0, 21690, 0, -31158, 0, 21692, 0, -31157, 0, 21694, 0, -31156, 0, 21699, 0, -31155, 0, 21701, 0, -31154, 0, 21706, 0, -31153, 0, 21707, 0, -31152, 0, 21718, 0, -31151, 0, 21720, 0, -31150, 0, 21723, 0, -31149, 0, 21728, 0, -31148, 0, 21729, 0, -31147, 0, 21730, 0, -31146, 0, 21731, 0, -31145, 0, 21732, 0, -31144, 0, 21739, 0, -31143, 0, 21740, 0, -31142, 0, 21743, 0, -31141, 0, 21744, 0, -31140, 0, 21745, 0, -31139, 0, 21748, 0, -31138, 0, 21749, 0, -31137, 0, 21750, 0, -31136, 0, 21751, 0, -31135, 0, 21752, 0, -31134, 0, 21753, 0, -31133, 0, 21755, 0, -31132, 0, 21758, 0, -31131, 0, 21760, 0, -31130, 0, 21762, 0, -31129, 0, 21763, 0, -31128, 0, 21764, 0, -31127, 0, 21765, 0, -31126, 0, 21768, 0, -31125, 0, 21770, 0, -31124, 0, 21771, 0, -31123, 0, 21772, 0, -31122, 0, 21773, 0, -31121, 0, 21774, 0, -31120, 0, 21778, 0, -31119, 0, 21779, 0, -31118, 0, 21781, 0, -31117, 0, 21782, 0, -31116, 0, 21783, 0, -31115, 0, 21784, 0, -31114, 0, 21785, 0, -31113, 0, 21786, 0, -31112, 0, 21788, 0, -31111, 0, 21789, 0, -31110, 0, 21790, 0, -31109, 0, 21791, 0, -31108, 0, 21793, 0, -31107, 0, 21797, 0, -31106, 0, 21798, 0, -31104, 0, 21800, 0, -31103, 0, 21801, 0, -31102, 0, 21803, 0, -31101, 0, 21805, 0, -31100, 0, 21810, 0, -31099, 0, 21812, 0, -31098, 0, 21813, 0, -31097, 0, 21814, 0, -31096, 0, 21816, 0, -31095, 0, 21817, 0, -31094, 0, 21818, 0, -31093, 0, 21819, 0, -31092, 0, 21821, 0, -31091, 0, 21824, 0, -31090, 0, 21826, 0, -31089, 0, 21829, 0, -31088, 0, 21831, 0, -31087, 0, 21832, 0, -31086, 0, 21835, 0, -31085, 0, 21836, 0, -31084, 0, 21837, 0, -31083, 0, 21838, 0, -31082, 0, 21839, 0, -31081, 0, 21841, 0, -31080, 0, 21842, 0, -31079, 0, 21843, 0, -31078, 0, 21844, 0, -31077, 0, 21847, 0, -31076, 0, 21848, 0, -31075, 0, 21849, 0, -31074, 0, 21850, 0, -31073, 0, 21851, 0, -31072, 0, 21853, 0, -31071, 0, 21854, 0, -31070, 0, 21855, 0, -31069, 0, 21856, 0, -31068, 0, 21858, 0, -31067, 0, 21859, 0, -31066, 0, 21864, 0, -31065, 0, 21865, 0, -31064, 0, 21867, 0, -31063, 0, 21871, 0, -31062, 0, 21872, 0, -31061, 0, 21873, 0, -31060, 0, 21874, 0, -31059, 0, 21875, 0, -31058, 0, 21876, 0, -31057, 0, 21881, 0, -31056, 0, 21882, 0, -31055, 0, 21885, 0, -31054, 0, 21887, 0, -31053, 0, 21893, 0, -31052, 0, 21894, 0, -31051, 0, 21900, 0, -31050, 0, 21901, 0, -31049, 0, 21902, 0, -31048, 0, 21904, 0, -31047, 0, 21906, 0, -31046, 0, 21907, 0, -31045, 0, 21909, 0, -31044, 0, 21910, 0, -31043, 0, 21911, 0, -31042, 0, 21914, 0, -31041, 0, 21915, 0, -31040, 0, 21918, 0, -31039, 0, 21920, 0, -31038, 0, 21921, 0, -31037, 0, 21922, 0, -31036, 0, 21923, 0, -31035, 0, 21924, 0, -31034, 0, 21925, 0, -31033, 0, 21926, 0, -31032, 0, 21928, 0, -31031, 0, 21929, 0, -31030, 0, 21930, 0, -31029, 0, 21931, 0, -31028, 0, 21932, 0, -31027, 0, 21933, 0, -31026, 0, 21934, 0, -31025, 0, 21935, 0, -31024, 0, 21936, 0, -31023, 0, 21938, 0, -31022, 0, 21940, 0, -31021, 0, 21942, 0, -31020, 0, 21944, 0, -31019, 0, 21946, 0, -31018, 0, 21948, 0, -31017, 0, 21951, 0, -31016, 0, 21952, 0, -31015, 0, 21953, 0, -31014, 0, 21954, 0, -31013, 0, 21955, 0, -31012, 0, 21958, 0, -31011, 0, 21959, 0, -31010, 0, 21960, 0, -31009, 0, 21962, 0, -31008, 0, 21963, 0, -31007, 0, 21966, 0, -31006, 0, 21967, 0, -31005, 0, 21968, 0, -31004, 0, 21973, 0, -31003, 0, 21975, 0, -31002, 0, 21976, 0, -31001, 0, 21977, 0, -31000, 0, 21978, 0, -30999, 0, 21979, 0, -30998, 0, 21982, 0, -30997, 0, 21984, 0, -30996, 0, 21986, 0, -30995, 0, 21991, 0, -30994, 0, 21993, 0, -30993, 0, 21997, 0, -30992, 0, 21998, 0, -30991, 0, 22000, 0, -30990, 0, 22001, 0, -30989, 0, 22004, 0, -30988, 0, 22006, 0, -30987, 0, 22008, 0, -30986, 0, 22009, 0, -30985, 0, 22010, 0, -30984, 0, 22011, 0, -30983, 0, 22012, 0, -30982, 0, 22015, 0, -30981, 0, 22018, 0, -30980, 0, 22019, 0, -30979, 0, 22020, 0, -30978, 0, 22021, 0, -30912, 0, 22022, 0, -30911, 0, 22023, 0, -30910, 0, 22026, 0, -30909, 0, 22027, 0, -30908, 0, 22029, 0, -30907, 0, 22032, 0, -30906, 0, 22033, 0, -30905, 0, 22034, 0, -30904, 0, 22035, 0, -30903, 0, 22036, 0, -30902, 0, 22037, 0, -30901, 0, 22038, 0, -30900, 0, 22039, 0, -30899, 0, 22041, 0, -30898, 0, 22042, 0, -30897, 0, 22044, 0, -30896, 0, 22045, 0, -30895, 0, 22048, 0, -30894, 0, 22049, 0, -30893, 0, 22050, 0, -30892, 0, 22053, 0, -30891, 0, 22054, 0, -30890, 0, 22056, 0, -30889, 0, 22057, 0, -30888, 0, 22058, 0, -30887, 0, 22059, 0, -30886, 0, 22062, 0, -30885, 0, 22063, 0, -30884, 0, 22064, 0, -30883, 0, 22067, 0, -30882, 0, 22069, 0, -30881, 0, 22071, 0, -30880, 0, 22072, 0, -30879, 0, 22074, 0, -30878, 0, 22076, 0, -30877, 0, 22077, 0, -30876, 0, 22078, 0, -30875, 0, 22080, 0, -30874, 0, 22081, 0, -30873, 0, 22082, 0, -30872, 0, 22083, 0, -30871, 0, 22084, 0, -30870, 0, 22085, 0, -30869, 0, 22086, 0, -30868, 0, 22087, 0, -30867, 0, 22088, 0, -30866, 0, 22089, 0, -30865, 0, 22090, 0, -30864, 0, 22091, 0, -30863, 0, 22095, 0, -30862, 0, 22096, 0, -30861, 0, 22097, 0, -30860, 0, 22098, 0, -30859, 0, 22099, 0, -30858, 0, 22101, 0, -30857, 0, 22102, 0, -30856, 0, 22106, 0, -30855, 0, 22107, 0, -30854, 0, 22109, 0, -30853, 0, 22110, 0, -30852, 0, 22111, 0, -30851, 0, 22112, 0, -30850, 0, 22113, 0, -30848, 0, 22115, 0, -30847, 0, 22117, 0, -30846, 0, 22118, 0, -30845, 0, 22119, 0, -30844, 0, 22125, 0, -30843, 0, 22126, 0, -30842, 0, 22127, 0, -30841, 0, 22128, 0, -30840, 0, 22130, 0, -30839, 0, 22131, 0, -30838, 0, 22132, 0, -30837, 0, 22133, 0, -30836, 0, 22135, 0, -30835, 0, 22136, 0, -30834, 0, 22137, 0, -30833, 0, 22138, 0, -30832, 0, 22141, 0, -30831, 0, 22142, 0, -30830, 0, 22143, 0, -30829, 0, 22144, 0, -30828, 0, 22145, 0, -30827, 0, 22146, 0, -30826, 0, 22147, 0, -30825, 0, 22148, 0, -30824, 0, 22151, 0, -30823, 0, 22152, 0, -30822, 0, 22153, 0, -30821, 0, 22154, 0, -30820, 0, 22155, 0, -30819, 0, 22156, 0, -30818, 0, 22157, 0, -30817, 0, 22160, 0, -30816, 0, 22161, 0, -30815, 0, 22162, 0, -30814, 0, 22164, 0, -30813, 0, 22165, 0, -30812, 0, 22166, 0, -30811, 0, 22167, 0, -30810, 0, 22168, 0, -30809, 0, 22169, 0, -30808, 0, 22170, 0, -30807, 0, 22171, 0, -30806, 0, 22172, 0, -30805, 0, 22173, 0, -30804, 0, 22174, 0, -30803, 0, 22175, 0, -30802, 0, 22176, 0, -30801, 0, 22177, 0, -30800, 0, 22178, 0, -30799, 0, 22180, 0, -30798, 0, 22181, 0, -30797, 0, 22182, 0, -30796, 0, 22183, 0, -30795, 0, 22184, 0, -30794, 0, 22185, 0, -30793, 0, 22186, 0, -30792, 0, 22187, 0, -30791, 0, 22188, 0, -30790, 0, 22189, 0, -30789, 0, 22190, 0, -30788, 0, 22192, 0, -30787, 0, 22193, 0, -30786, 0, 22194, 0, -30785, 0, 22195, 0, -30784, 0, 22196, 0, -30783, 0, 22197, 0, -30782, 0, 22198, 0, -30781, 0, 22200, 0, -30780, 0, 22201, 0, -30779, 0, 22202, 0, -30778, 0, 22203, 0, -30777, 0, 22205, 0, -30776, 0, 22206, 0, -30775, 0, 22207, 0, -30774, 0, 22208, 0, -30773, 0, 22209, 0, -30772, 0, 22210, 0, -30771, 0, 22211, 0, -30770, 0, 22212, 0, -30769, 0, 22213, 0, -30768, 0, 22214, 0, -30767, 0, 22215, 0, -30766, 0, 22216, 0, -30765, 0, 22217, 0, -30764, 0, 22219, 0, -30763, 0, 22220, 0, -30762, 0, 22221, 0, -30761, 0, 22222, 0, -30760, 0, 22223, 0, -30759, 0, 22224, 0, -30758, 0, 22225, 0, -30757, 0, 22226, 0, -30756, 0, 22227, 0, -30755, 0, 22229, 0, -30754, 0, 22230, 0, -30753, 0, 22232, 0, -30752, 0, 22233, 0, -30751, 0, 22236, 0, -30750, 0, 22243, 0, -30749, 0, 22245, 0, -30748, 0, 22246, 0, -30747, 0, 22247, 0, -30746, 0, 22248, 0, -30745, 0, 22249, 0, -30744, 0, 22250, 0, -30743, 0, 22252, 0, -30742, 0, 22254, 0, -30741, 0, 22255, 0, -30740, 0, 22258, 0, -30739, 0, 22259, 0, -30738, 0, 22262, 0, -30737, 0, 22263, 0, -30736, 0, 22264, 0, -30735, 0, 22267, 0, -30734, 0, 22268, 0, -30733, 0, 22272, 0, -30732, 0, 22273, 0, -30731, 0, 22274, 0, -30730, 0, 22277, 0, -30729, 0, 22279, 0, -30728, 0, 22283, 0, -30727, 0, 22284, 0, -30726, 0, 22285, 0, -30725, 0, 22286, 0, -30724, 0, 22287, 0, -30723, 0, 22288, 0, -30722, 0, 22289, 0, -30656, 0, 22290, 0, -30655, 0, 22291, 0, -30654, 0, 22292, 0, -30653, 0, 22293, 0, -30652, 0, 22294, 0, -30651, 0, 22295, 0, -30650, 0, 22296, 0, -30649, 0, 22297, 0, -30648, 0, 22298, 0, -30647, 0, 22299, 0, -30646, 0, 22301, 0, -30645, 0, 22302, 0, -30644, 0, 22304, 0, -30643, 0, 22305, 0, -30642, 0, 22306, 0, -30641, 0, 22308, 0, -30640, 0, 22309, 0, -30639, 0, 22310, 0, -30638, 0, 22311, 0, -30637, 0, 22315, 0, -30636, 0, 22321, 0, -30635, 0, 22322, 0, -30634, 0, 22324, 0, -30633, 0, 22325, 0, -30632, 0, 22326, 0, -30631, 0, 22327, 0, -30630, 0, 22328, 0, -30629, 0, 22332, 0, -30628, 0, 22333, 0, -30627, 0, 22335, 0, -30626, 0, 22337, 0, -30625, 0, 22339, 0, -30624, 0, 22340, 0, -30623, 0, 22341, 0, -30622, 0, 22342, 0, -30621, 0, 22344, 0, -30620, 0, 22345, 0, -30619, 0, 22347, 0, -30618, 0, 22354, 0, -30617, 0, 22355, 0, -30616, 0, 22356, 0, -30615, 0, 22357, 0, -30614, 0, 22358, 0, -30613, 0, 22360, 0, -30612, 0, 22361, 0, -30611, 0, 22370, 0, -30610, 0, 22371, 0, -30609, 0, 22373, 0, -30608, 0, 22375, 0, -30607, 0, 22380, 0, -30606, 0, 22382, 0, -30605, 0, 22384, 0, -30604, 0, 22385, 0, -30603, 0, 22386, 0, -30602, 0, 22388, 0, -30601, 0, 22389, 0, -30600, 0, 22392, 0, -30599, 0, 22393, 0, -30598, 0, 22394, 0, -30597, 0, 22397, 0, -30596, 0, 22398, 0, -30595, 0, 22399, 0, -30594, 0, 22400, 0, -30592, 0, 22401, 0, -30591, 0, 22407, 0, -30590, 0, 22408, 0, -30589, 0, 22409, 0, -30588, 0, 22410, 0, -30587, 0, 22413, 0, -30586, 0, 22414, 0, -30585, 0, 22415, 0, -30584, 0, 22416, 0, -30583, 0, 22417, 0, -30582, 0, 22420, 0, -30581, 0, 22421, 0, -30580, 0, 22422, 0, -30579, 0, 22423, 0, -30578, 0, 22424, 0, -30577, 0, 22425, 0, -30576, 0, 22426, 0, -30575, 0, 22428, 0, -30574, 0, 22429, 0, -30573, 0, 22430, 0, -30572, 0, 22431, 0, -30571, 0, 22437, 0, -30570, 0, 22440, 0, -30569, 0, 22442, 0, -30568, 0, 22444, 0, -30567, 0, 22447, 0, -30566, 0, 22448, 0, -30565, 0, 22449, 0, -30564, 0, 22451, 0, -30563, 0, 22453, 0, -30562, 0, 22454, 0, -30561, 0, 22455, 0, -30560, 0, 22457, 0, -30559, 0, 22458, 0, -30558, 0, 22459, 0, -30557, 0, 22460, 0, -30556, 0, 22461, 0, -30555, 0, 22462, 0, -30554, 0, 22463, 0, -30553, 0, 22464, 0, -30552, 0, 22465, 0, -30551, 0, 22468, 0, -30550, 0, 22469, 0, -30549, 0, 22470, 0, -30548, 0, 22471, 0, -30547, 0, 22472, 0, -30546, 0, 22473, 0, -30545, 0, 22474, 0, -30544, 0, 22476, 0, -30543, 0, 22477, 0, -30542, 0, 22480, 0, -30541, 0, 22481, 0, -30540, 0, 22483, 0, -30539, 0, 22486, 0, -30538, 0, 22487, 0, -30537, 0, 22491, 0, -30536, 0, 22492, 0, -30535, 0, 22494, 0, -30534, 0, 22497, 0, -30533, 0, 22498, 0, -30532, 0, 22499, 0, -30531, 0, 22501, 0, -30530, 0, 22502, 0, -30529, 0, 22503, 0, -30528, 0, 22504, 0, -30527, 0, 22505, 0, -30526, 0, 22506, 0, -30525, 0, 22507, 0, -30524, 0, 22508, 0, -30523, 0, 22510, 0, -30522, 0, 22512, 0, -30521, 0, 22513, 0, -30520, 0, 22514, 0, -30519, 0, 22515, 0, -30518, 0, 22517, 0, -30517, 0, 22518, 0, -30516, 0, 22519, 0, -30515, 0, 22523, 0, -30514, 0, 22524, 0, -30513, 0, 22526, 0, -30512, 0, 22527, 0, -30511, 0, 22529, 0, -30510, 0, 22531, 0, -30509, 0, 22532, 0, -30508, 0, 22533, 0, -30507, 0, 22536, 0, -30506, 0, 22537, 0, -30505, 0, 22538, 0, -30504, 0, 22540, 0, -30503, 0, 22542, 0, -30502, 0, 22543, 0, -30501, 0, 22544, 0, -30500, 0, 22546, 0, -30499, 0, 22547, 0, -30498, 0, 22548, 0, -30497, 0, 22550, 0, -30496, 0, 22551, 0, -30495, 0, 22552, 0, -30494, 0, 22554, 0, -30493, 0, 22555, 0, -30492, 0, 22556, 0, -30491, 0, 22557, 0, -30490, 0, 22559, 0, -30489, 0, 22562, 0, -30488, 0, 22563, 0, -30487, 0, 22565, 0, -30486, 0, 22566, 0, -30485, 0, 22567, 0, -30484, 0, 22568, 0, -30483, 0, 22569, 0, -30482, 0, 22571, 0, -30481, 0, 22572, 0, -30480, 0, 22573, 0, -30479, 0, 22574, 0, -30478, 0, 22575, 0, -30477, 0, 22577, 0, -30476, 0, 22578, 0, -30475, 0, 22579, 0, -30474, 0, 22580, 0, -30473, 0, 22582, 0, -30472, 0, 22583, 0, -30471, 0, 22584, 0, -30470, 0, 22585, 0, -30469, 0, 22586, 0, -30468, 0, 22587, 0, -30467, 0, 22588, 0, -30466, 0, 22589, 0, -30400, 0, 22590, 0, -30399, 0, 22591, 0, -30398, 0, 22592, 0, -30397, 0, 22593, 0, -30396, 0, 22594, 0, -30395, 0, 22595, 0, -30394, 0, 22597, 0, -30393, 0, 22598, 0, -30392, 0, 22599, 0, -30391, 0, 22600, 0, -30390, 0, 22601, 0, -30389, 0, 22602, 0, -30388, 0, 22603, 0, -30387, 0, 22606, 0, -30386, 0, 22607, 0, -30385, 0, 22608, 0, -30384, 0, 22610, 0, -30383, 0, 22611, 0, -30382, 0, 22613, 0, -30381, 0, 22614, 0, -30380, 0, 22615, 0, -30379, 0, 22617, 0, -30378, 0, 22618, 0, -30377, 0, 22619, 0, -30376, 0, 22620, 0, -30375, 0, 22621, 0, -30374, 0, 22623, 0, -30373, 0, 22624, 0, -30372, 0, 22625, 0, -30371, 0, 22626, 0, -30370, 0, 22627, 0, -30369, 0, 22628, 0, -30368, 0, 22630, 0, -30367, 0, 22631, 0, -30366, 0, 22632, 0, -30365, 0, 22633, 0, -30364, 0, 22634, 0, -30363, 0, 22637, 0, -30362, 0, 22638, 0, -30361, 0, 22639, 0, -30360, 0, 22640, 0, -30359, 0, 22641, 0, -30358, 0, 22642, 0, -30357, 0, 22643, 0, -30356, 0, 22644, 0, -30355, 0, 22645, 0, -30354, 0, 22646, 0, -30353, 0, 22647, 0, -30352, 0, 22648, 0, -30351, 0, 22649, 0, -30350, 0, 22650, 0, -30349, 0, 22651, 0, -30348, 0, 22652, 0, -30347, 0, 22653, 0, -30346, 0, 22655, 0, -30345, 0, 22658, 0, -30344, 0, 22660, 0, -30343, 0, 22662, 0, -30342, 0, 22663, 0, -30341, 0, 22664, 0, -30340, 0, 22666, 0, -30339, 0, 22667, 0, -30338, 0, 22668, 0, -30336, 0, 22669, 0, -30335, 0, 22670, 0, -30334, 0, 22671, 0, -30333, 0, 22672, 0, -30332, 0, 22673, 0, -30331, 0, 22676, 0, -30330, 0, 22677, 0, -30329, 0, 22678, 0, -30328, 0, 22679, 0, -30327, 0, 22680, 0, -30326, 0, 22683, 0, -30325, 0, 22684, 0, -30324, 0, 22685, 0, -30323, 0, 22688, 0, -30322, 0, 22689, 0, -30321, 0, 22690, 0, -30320, 0, 22691, 0, -30319, 0, 22692, 0, -30318, 0, 22693, 0, -30317, 0, 22694, 0, -30316, 0, 22695, 0, -30315, 0, 22698, 0, -30314, 0, 22699, 0, -30313, 0, 22700, 0, -30312, 0, 22701, 0, -30311, 0, 22702, 0, -30310, 0, 22703, 0, -30309, 0, 22704, 0, -30308, 0, 22705, 0, -30307, 0, 22706, 0, -30306, 0, 22707, 0, -30305, 0, 22708, 0, -30304, 0, 22709, 0, -30303, 0, 22710, 0, -30302, 0, 22711, 0, -30301, 0, 22712, 0, -30300, 0, 22713, 0, -30299, 0, 22714, 0, -30298, 0, 22715, 0, -30297, 0, 22717, 0, -30296, 0, 22718, 0, -30295, 0, 22719, 0, -30294, 0, 22720, 0, -30293, 0, 22722, 0, -30292, 0, 22723, 0, -30291, 0, 22724, 0, -30290, 0, 22726, 0, -30289, 0, 22727, 0, -30288, 0, 22728, 0, -30287, 0, 22729, 0, -30286, 0, 22730, 0, -30285, 0, 22731, 0, -30284, 0, 22732, 0, -30283, 0, 22733, 0, -30282, 0, 22734, 0, -30281, 0, 22735, 0, -30280, 0, 22736, 0, -30279, 0, 22738, 0, -30278, 0, 22739, 0, -30277, 0, 22740, 0, -30276, 0, 22742, 0, -30275, 0, 22743, 0, -30274, 0, 22744, 0, -30273, 0, 22745, 0, -30272, 0, 22746, 0, -30271, 0, 22747, 0, -30270, 0, 22748, 0, -30269, 0, 22749, 0, -30268, 0, 22750, 0, -30267, 0, 22751, 0, -30266, 0, 22752, 0, -30265, 0, 22753, 0, -30264, 0, 22754, 0, -30263, 0, 22755, 0, -30262, 0, 22757, 0, -30261, 0, 22758, 0, -30260, 0, 22759, 0, -30259, 0, 22760, 0, -30258, 0, 22761, 0, -30257, 0, 22762, 0, -30256, 0, 22765, 0, -30255, 0, 22767, 0, -30254, 0, 22769, 0, -30253, 0, 22770, 0, -30252, 0, 22772, 0, -30251, 0, 22773, 0, -30250, 0, 22775, 0, -30249, 0, 22776, 0, -30248, 0, 22778, 0, -30247, 0, 22779, 0, -30246, 0, 22780, 0, -30245, 0, 22781, 0, -30244, 0, 22782, 0, -30243, 0, 22783, 0, -30242, 0, 22784, 0, -30241, 0, 22785, 0, -30240, 0, 22787, 0, -30239, 0, 22789, 0, -30238, 0, 22790, 0, -30237, 0, 22792, 0, -30236, 0, 22793, 0, -30235, 0, 22794, 0, -30234, 0, 22795, 0, -30233, 0, 22796, 0, -30232, 0, 22798, 0, -30231, 0, 22800, 0, -30230, 0, 22801, 0, -30229, 0, 22802, 0, -30228, 0, 22803, 0, -30227, 0, 22807, 0, -30226, 0, 22808, 0, -30225, 0, 22811, 0, -30224, 0, 22813, 0, -30223, 0, 22814, 0, -30222, 0, 22816, 0, -30221, 0, 22817, 0, -30220, 0, 22818, 0, -30219, 0, 22819, 0, -30218, 0, 22822, 0, -30217, 0, 22824, 0, -30216, 0, 22828, 0, -30215, 0, 22832, 0, -30214, 0, 22834, 0, -30213, 0, 22835, 0, -30212, 0, 22837, 0, -30211, 0, 22838, 0, -30210, 0, 22843, 0, -30144, 0, 22845, 0, -30143, 0, 22846, 0, -30142, 0, 22847, 0, -30141, 0, 22848, 0, -30140, 0, 22851, 0, -30139, 0, 22853, 0, -30138, 0, 22854, 0, -30137, 0, 22858, 0, -30136, 0, 22860, 0, -30135, 0, 22861, 0, -30134, 0, 22864, 0, -30133, 0, 22866, 0, -30132, 0, 22867, 0, -30131, 0, 22873, 0, -30130, 0, 22875, 0, -30129, 0, 22876, 0, -30128, 0, 22877, 0, -30127, 0, 22878, 0, -30126, 0, 22879, 0, -30125, 0, 22881, 0, -30124, 0, 22883, 0, -30123, 0, 22884, 0, -30122, 0, 22886, 0, -30121, 0, 22887, 0, -30120, 0, 22888, 0, -30119, 0, 22889, 0, -30118, 0, 22890, 0, -30117, 0, 22891, 0, -30116, 0, 22892, 0, -30115, 0, 22893, 0, -30114, 0, 22894, 0, -30113, 0, 22895, 0, -30112, 0, 22896, 0, -30111, 0, 22897, 0, -30110, 0, 22898, 0, -30109, 0, 22901, 0, -30108, 0, 22903, 0, -30107, 0, 22906, 0, -30106, 0, 22907, 0, -30105, 0, 22908, 0, -30104, 0, 22910, 0, -30103, 0, 22911, 0, -30102, 0, 22912, 0, -30101, 0, 22917, 0, -30100, 0, 22921, 0, -30099, 0, 22923, 0, -30098, 0, 22924, 0, -30097, 0, 22926, 0, -30096, 0, 22927, 0, -30095, 0, 22928, 0, -30094, 0, 22929, 0, -30093, 0, 22932, 0, -30092, 0, 22933, 0, -30091, 0, 22936, 0, -30090, 0, 22938, 0, -30089, 0, 22939, 0, -30088, 0, 22940, 0, -30087, 0, 22941, 0, -30086, 0, 22943, 0, -30085, 0, 22944, 0, -30084, 0, 22945, 0, -30083, 0, 22946, 0, -30082, 0, 22950, 0, -30080, 0, 22951, 0, -30079, 0, 22956, 0, -30078, 0, 22957, 0, -30077, 0, 22960, 0, -30076, 0, 22961, 0, -30075, 0, 22963, 0, -30074, 0, 22964, 0, -30073, 0, 22965, 0, -30072, 0, 22966, 0, -30071, 0, 22967, 0, -30070, 0, 22968, 0, -30069, 0, 22970, 0, -30068, 0, 22972, 0, -30067, 0, 22973, 0, -30066, 0, 22975, 0, -30065, 0, 22976, 0, -30064, 0, 22977, 0, -30063, 0, 22978, 0, -30062, 0, 22979, 0, -30061, 0, 22980, 0, -30060, 0, 22981, 0, -30059, 0, 22983, 0, -30058, 0, 22984, 0, -30057, 0, 22985, 0, -30056, 0, 22988, 0, -30055, 0, 22989, 0, -30054, 0, 22990, 0, -30053, 0, 22991, 0, -30052, 0, 22997, 0, -30051, 0, 22998, 0, -30050, 0, 23001, 0, -30049, 0, 23003, 0, -30048, 0, 23006, 0, -30047, 0, 23007, 0, -30046, 0, 23008, 0, -30045, 0, 23009, 0, -30044, 0, 23010, 0, -30043, 0, 23012, 0, -30042, 0, 23014, 0, -30041, 0, 23015, 0, -30040, 0, 23017, 0, -30039, 0, 23018, 0, -30038, 0, 23019, 0, -30037, 0, 23021, 0, -30036, 0, 23022, 0, -30035, 0, 23023, 0, -30034, 0, 23024, 0, -30033, 0, 23025, 0, -30032, 0, 23026, 0, -30031, 0, 23027, 0, -30030, 0, 23028, 0, -30029, 0, 23029, 0, -30028, 0, 23030, 0, -30027, 0, 23031, 0, -30026, 0, 23032, 0, -30025, 0, 23034, 0, -30024, 0, 23036, 0, -30023, 0, 23037, 0, -30022, 0, 23038, 0, -30021, 0, 23040, 0, -30020, 0, 23042, 0, -30019, 0, 23050, 0, -30018, 0, 23051, 0, -30017, 0, 23053, 0, -30016, 0, 23054, 0, -30015, 0, 23055, 0, -30014, 0, 23056, 0, -30013, 0, 23058, 0, -30012, 0, 23060, 0, -30011, 0, 23061, 0, -30010, 0, 23062, 0, -30009, 0, 23063, 0, -30008, 0, 23065, 0, -30007, 0, 23066, 0, -30006, 0, 23067, 0, -30005, 0, 23069, 0, -30004, 0, 23070, 0, -30003, 0, 23073, 0, -30002, 0, 23074, 0, -30001, 0, 23076, 0, -30000, 0, 23078, 0, -29999, 0, 23079, 0, -29998, 0, 23080, 0, -29997, 0, 23082, 0, -29996, 0, 23083, 0, -29995, 0, 23084, 0, -29994, 0, 23085, 0, -29993, 0, 23086, 0, -29992, 0, 23087, 0, -29991, 0, 23088, 0, -29990, 0, 23091, 0, -29989, 0, 23093, 0, -29988, 0, 23095, 0, -29987, 0, 23096, 0, -29986, 0, 23097, 0, -29985, 0, 23098, 0, -29984, 0, 23099, 0, -29983, 0, 23101, 0, -29982, 0, 23102, 0, -29981, 0, 23103, 0, -29980, 0, 23105, 0, -29979, 0, 23106, 0, -29978, 0, 23107, 0, -29977, 0, 23108, 0, -29976, 0, 23109, 0, -29975, 0, 23111, 0, -29974, 0, 23112, 0, -29973, 0, 23115, 0, -29972, 0, 23116, 0, -29971, 0, 23117, 0, -29970, 0, 23118, 0, -29969, 0, 23119, 0, -29968, 0, 23120, 0, -29967, 0, 23121, 0, -29966, 0, 23122, 0, -29965, 0, 23123, 0, -29964, 0, 23124, 0, -29963, 0, 23126, 0, -29962, 0, 23127, 0, -29961, 0, 23128, 0, -29960, 0, 23129, 0, -29959, 0, 23131, 0, -29958, 0, 23132, 0, -29957, 0, 23133, 0, -29956, 0, 23134, 0, -29955, 0, 23135, 0, -29954, 0, 23136, 0, -29888, 0, 23137, 0, -29887, 0, 23139, 0, -29886, 0, 23140, 0, -29885, 0, 23141, 0, -29884, 0, 23142, 0, -29883, 0, 23144, 0, -29882, 0, 23145, 0, -29881, 0, 23147, 0, -29880, 0, 23148, 0, -29879, 0, 23149, 0, -29878, 0, 23150, 0, -29877, 0, 23151, 0, -29876, 0, 23152, 0, -29875, 0, 23153, 0, -29874, 0, 23154, 0, -29873, 0, 23155, 0, -29872, 0, 23160, 0, -29871, 0, 23161, 0, -29870, 0, 23163, 0, -29869, 0, 23164, 0, -29868, 0, 23165, 0, -29867, 0, 23166, 0, -29866, 0, 23168, 0, -29865, 0, 23169, 0, -29864, 0, 23170, 0, -29863, 0, 23171, 0, -29862, 0, 23172, 0, -29861, 0, 23173, 0, -29860, 0, 23174, 0, -29859, 0, 23175, 0, -29858, 0, 23176, 0, -29857, 0, 23177, 0, -29856, 0, 23178, 0, -29855, 0, 23179, 0, -29854, 0, 23180, 0, -29853, 0, 23181, 0, -29852, 0, 23182, 0, -29851, 0, 23183, 0, -29850, 0, 23184, 0, -29849, 0, 23185, 0, -29848, 0, 23187, 0, -29847, 0, 23188, 0, -29846, 0, 23189, 0, -29845, 0, 23190, 0, -29844, 0, 23191, 0, -29843, 0, 23192, 0, -29842, 0, 23193, 0, -29841, 0, 23196, 0, -29840, 0, 23197, 0, -29839, 0, 23198, 0, -29838, 0, 23199, 0, -29837, 0, 23200, 0, -29836, 0, 23201, 0, -29835, 0, 23202, 0, -29834, 0, 23203, 0, -29833, 0, 23204, 0, -29832, 0, 23205, 0, -29831, 0, 23206, 0, -29830, 0, 23207, 0, -29829, 0, 23208, 0, -29828, 0, 23209, 0, -29827, 0, 23211, 0, -29826, 0, 23212, 0, -29824, 0, 23213, 0, -29823, 0, 23214, 0, -29822, 0, 23215, 0, -29821, 0, 23216, 0, -29820, 0, 23217, 0, -29819, 0, 23220, 0, -29818, 0, 23222, 0, -29817, 0, 23223, 0, -29816, 0, 23225, 0, -29815, 0, 23226, 0, -29814, 0, 23227, 0, -29813, 0, 23228, 0, -29812, 0, 23229, 0, -29811, 0, 23231, 0, -29810, 0, 23232, 0, -29809, 0, 23235, 0, -29808, 0, 23236, 0, -29807, 0, 23237, 0, -29806, 0, 23238, 0, -29805, 0, 23239, 0, -29804, 0, 23240, 0, -29803, 0, 23242, 0, -29802, 0, 23243, 0, -29801, 0, 23245, 0, -29800, 0, 23246, 0, -29799, 0, 23247, 0, -29798, 0, 23248, 0, -29797, 0, 23249, 0, -29796, 0, 23251, 0, -29795, 0, 23253, 0, -29794, 0, 23255, 0, -29793, 0, 23257, 0, -29792, 0, 23258, 0, -29791, 0, 23259, 0, -29790, 0, 23261, 0, -29789, 0, 23262, 0, -29788, 0, 23263, 0, -29787, 0, 23266, 0, -29786, 0, 23268, 0, -29785, 0, 23269, 0, -29784, 0, 23271, 0, -29783, 0, 23272, 0, -29782, 0, 23274, 0, -29781, 0, 23276, 0, -29780, 0, 23277, 0, -29779, 0, 23278, 0, -29778, 0, 23279, 0, -29777, 0, 23280, 0, -29776, 0, 23282, 0, -29775, 0, 23283, 0, -29774, 0, 23284, 0, -29773, 0, 23285, 0, -29772, 0, 23286, 0, -29771, 0, 23287, 0, -29770, 0, 23288, 0, -29769, 0, 23289, 0, -29768, 0, 23290, 0, -29767, 0, 23291, 0, -29766, 0, 23292, 0, -29765, 0, 23293, 0, -29764, 0, 23294, 0, -29763, 0, 23295, 0, -29762, 0, 23296, 0, -29761, 0, 23297, 0, -29760, 0, 23298, 0, -29759, 0, 23299, 0, -29758, 0, 23300, 0, -29757, 0, 23301, 0, -29756, 0, 23302, 0, -29755, 0, 23303, 0, -29754, 0, 23304, 0, -29753, 0, 23306, 0, -29752, 0, 23307, 0, -29751, 0, 23308, 0, -29750, 0, 23309, 0, -29749, 0, 23310, 0, -29748, 0, 23311, 0, -29747, 0, 23312, 0, -29746, 0, 23313, 0, -29745, 0, 23314, 0, -29744, 0, 23315, 0, -29743, 0, 23316, 0, -29742, 0, 23317, 0, -29741, 0, 23320, 0, -29740, 0, 23321, 0, -29739, 0, 23322, 0, -29738, 0, 23323, 0, -29737, 0, 23324, 0, -29736, 0, 23325, 0, -29735, 0, 23326, 0, -29734, 0, 23327, 0, -29733, 0, 23328, 0, -29732, 0, 23329, 0, -29731, 0, 23330, 0, -29730, 0, 23331, 0, -29729, 0, 23332, 0, -29728, 0, 23333, 0, -29727, 0, 23334, 0, -29726, 0, 23335, 0, -29725, 0, 23336, 0, -29724, 0, 23337, 0, -29723, 0, 23338, 0, -29722, 0, 23339, 0, -29721, 0, 23340, 0, -29720, 0, 23341, 0, -29719, 0, 23342, 0, -29718, 0, 23343, 0, -29717, 0, 23344, 0, -29716, 0, 23345, 0, -29715, 0, 23347, 0, -29714, 0, 23349, 0, -29713, 0, 23350, 0, -29712, 0, 23352, 0, -29711, 0, 23353, 0, -29710, 0, 23354, 0, -29709, 0, 23355, 0, -29708, 0, 23356, 0, -29707, 0, 23357, 0, -29706, 0, 23358, 0, -29705, 0, 23359, 0, -29704, 0, 23361, 0, -29703, 0, 23362, 0, -29702, 0, 23363, 0, -29701, 0, 23364, 0, -29700, 0, 23365, 0, -29699, 0, 23366, 0, -29698, 0, 23367, 0, -29632, 0, 23368, 0, -29631, 0, 23369, 0, -29630, 0, 23370, 0, -29629, 0, 23371, 0, -29628, 0, 23372, 0, -29627, 0, 23373, 0, -29626, 0, 23374, 0, -29625, 0, 23375, 0, -29624, 0, 23378, 0, -29623, 0, 23382, 0, -29622, 0, 23390, 0, -29621, 0, 23392, 0, -29620, 0, 23393, 0, -29619, 0, 23399, 0, -29618, 0, 23400, 0, -29617, 0, 23403, 0, -29616, 0, 23405, 0, -29615, 0, 23406, 0, -29614, 0, 23407, 0, -29613, 0, 23410, 0, -29612, 0, 23412, 0, -29611, 0, 23414, 0, -29610, 0, 23415, 0, -29609, 0, 23416, 0, -29608, 0, 23417, 0, -29607, 0, 23419, 0, -29606, 0, 23420, 0, -29605, 0, 23422, 0, -29604, 0, 23423, 0, -29603, 0, 23426, 0, -29602, 0, 23430, 0, -29601, 0, 23434, 0, -29600, 0, 23437, 0, -29599, 0, 23438, 0, -29598, 0, 23440, 0, -29597, 0, 23441, 0, -29596, 0, 23442, 0, -29595, 0, 23444, 0, -29594, 0, 23446, 0, -29593, 0, 23455, 0, -29592, 0, 23463, 0, -29591, 0, 23464, 0, -29590, 0, 23465, 0, -29589, 0, 23468, 0, -29588, 0, 23469, 0, -29587, 0, 23470, 0, -29586, 0, 23471, 0, -29585, 0, 23473, 0, -29584, 0, 23474, 0, -29583, 0, 23479, 0, -29582, 0, 23482, 0, -29581, 0, 23483, 0, -29580, 0, 23484, 0, -29579, 0, 23488, 0, -29578, 0, 23489, 0, -29577, 0, 23491, 0, -29576, 0, 23496, 0, -29575, 0, 23497, 0, -29574, 0, 23498, 0, -29573, 0, 23499, 0, -29572, 0, 23501, 0, -29571, 0, 23502, 0, -29570, 0, 23503, 0, -29568, 0, 23505, 0, -29567, 0, 23508, 0, -29566, 0, 23509, 0, -29565, 0, 23510, 0, -29564, 0, 23511, 0, -29563, 0, 23512, 0, -29562, 0, 23513, 0, -29561, 0, 23514, 0, -29560, 0, 23515, 0, -29559, 0, 23516, 0, -29558, 0, 23520, 0, -29557, 0, 23522, 0, -29556, 0, 23523, 0, -29555, 0, 23526, 0, -29554, 0, 23527, 0, -29553, 0, 23529, 0, -29552, 0, 23530, 0, -29551, 0, 23531, 0, -29550, 0, 23532, 0, -29549, 0, 23533, 0, -29548, 0, 23535, 0, -29547, 0, 23537, 0, -29546, 0, 23538, 0, -29545, 0, 23539, 0, -29544, 0, 23540, 0, -29543, 0, 23541, 0, -29542, 0, 23542, 0, -29541, 0, 23543, 0, -29540, 0, 23549, 0, -29539, 0, 23550, 0, -29538, 0, 23552, 0, -29537, 0, 23554, 0, -29536, 0, 23555, 0, -29535, 0, 23557, 0, -29534, 0, 23559, 0, -29533, 0, 23560, 0, -29532, 0, 23563, 0, -29531, 0, 23564, 0, -29530, 0, 23565, 0, -29529, 0, 23566, 0, -29528, 0, 23568, 0, -29527, 0, 23570, 0, -29526, 0, 23571, 0, -29525, 0, 23575, 0, -29524, 0, 23577, 0, -29523, 0, 23579, 0, -29522, 0, 23582, 0, -29521, 0, 23583, 0, -29520, 0, 23584, 0, -29519, 0, 23585, 0, -29518, 0, 23587, 0, -29517, 0, 23590, 0, -29516, 0, 23592, 0, -29515, 0, 23593, 0, -29514, 0, 23594, 0, -29513, 0, 23595, 0, -29512, 0, 23597, 0, -29511, 0, 23598, 0, -29510, 0, 23599, 0, -29509, 0, 23600, 0, -29508, 0, 23602, 0, -29507, 0, 23603, 0, -29506, 0, 23605, 0, -29505, 0, 23606, 0, -29504, 0, 23607, 0, -29503, 0, 23619, 0, -29502, 0, 23620, 0, -29501, 0, 23622, 0, -29500, 0, 23623, 0, -29499, 0, 23628, 0, -29498, 0, 23629, 0, -29497, 0, 23634, 0, -29496, 0, 23635, 0, -29495, 0, 23636, 0, -29494, 0, 23638, 0, -29493, 0, 23639, 0, -29492, 0, 23640, 0, -29491, 0, 23642, 0, -29490, 0, 23643, 0, -29489, 0, 23644, 0, -29488, 0, 23645, 0, -29487, 0, 23647, 0, -29486, 0, 23650, 0, -29485, 0, 23652, 0, -29484, 0, 23655, 0, -29483, 0, 23656, 0, -29482, 0, 23657, 0, -29481, 0, 23658, 0, -29480, 0, 23659, 0, -29479, 0, 23660, 0, -29478, 0, 23661, 0, -29477, 0, 23664, 0, -29476, 0, 23666, 0, -29475, 0, 23667, 0, -29474, 0, 23668, 0, -29473, 0, 23669, 0, -29472, 0, 23670, 0, -29471, 0, 23671, 0, -29470, 0, 23672, 0, -29469, 0, 23675, 0, -29468, 0, 23676, 0, -29467, 0, 23677, 0, -29466, 0, 23678, 0, -29465, 0, 23680, 0, -29464, 0, 23683, 0, -29463, 0, 23684, 0, -29462, 0, 23685, 0, -29461, 0, 23686, 0, -29460, 0, 23687, 0, -29459, 0, 23689, 0, -29458, 0, 23690, 0, -29457, 0, 23691, 0, -29456, 0, 23694, 0, -29455, 0, 23695, 0, -29454, 0, 23698, 0, -29453, 0, 23699, 0, -29452, 0, 23701, 0, -29451, 0, 23709, 0, -29450, 0, 23710, 0, -29449, 0, 23711, 0, -29448, 0, 23712, 0, -29447, 0, 23713, 0, -29446, 0, 23716, 0, -29445, 0, 23717, 0, -29444, 0, 23718, 0, -29443, 0, 23719, 0, -29442, 0, 23720, 0, -29376, 0, 23722, 0, -29375, 0, 23726, 0, -29374, 0, 23727, 0, -29373, 0, 23728, 0, -29372, 0, 23730, 0, -29371, 0, 23732, 0, -29370, 0, 23734, 0, -29369, 0, 23737, 0, -29368, 0, 23738, 0, -29367, 0, 23739, 0, -29366, 0, 23740, 0, -29365, 0, 23742, 0, -29364, 0, 23744, 0, -29363, 0, 23746, 0, -29362, 0, 23747, 0, -29361, 0, 23749, 0, -29360, 0, 23750, 0, -29359, 0, 23751, 0, -29358, 0, 23752, 0, -29357, 0, 23753, 0, -29356, 0, 23754, 0, -29355, 0, 23756, 0, -29354, 0, 23757, 0, -29353, 0, 23758, 0, -29352, 0, 23759, 0, -29351, 0, 23760, 0, -29350, 0, 23761, 0, -29349, 0, 23763, 0, -29348, 0, 23764, 0, -29347, 0, 23765, 0, -29346, 0, 23766, 0, -29345, 0, 23767, 0, -29344, 0, 23768, 0, -29343, 0, 23770, 0, -29342, 0, 23771, 0, -29341, 0, 23772, 0, -29340, 0, 23773, 0, -29339, 0, 23774, 0, -29338, 0, 23775, 0, -29337, 0, 23776, 0, -29336, 0, 23778, 0, -29335, 0, 23779, 0, -29334, 0, 23783, 0, -29333, 0, 23785, 0, -29332, 0, 23787, 0, -29331, 0, 23788, 0, -29330, 0, 23790, 0, -29329, 0, 23791, 0, -29328, 0, 23793, 0, -29327, 0, 23794, 0, -29326, 0, 23795, 0, -29325, 0, 23796, 0, -29324, 0, 23797, 0, -29323, 0, 23798, 0, -29322, 0, 23799, 0, -29321, 0, 23800, 0, -29320, 0, 23801, 0, -29319, 0, 23802, 0, -29318, 0, 23804, 0, -29317, 0, 23805, 0, -29316, 0, 23806, 0, -29315, 0, 23807, 0, -29314, 0, 23808, 0, -29312, 0, 23809, 0, -29311, 0, 23812, 0, -29310, 0, 23813, 0, -29309, 0, 23816, 0, -29308, 0, 23817, 0, -29307, 0, 23818, 0, -29306, 0, 23819, 0, -29305, 0, 23820, 0, -29304, 0, 23821, 0, -29303, 0, 23823, 0, -29302, 0, 23824, 0, -29301, 0, 23825, 0, -29300, 0, 23826, 0, -29299, 0, 23827, 0, -29298, 0, 23829, 0, -29297, 0, 23831, 0, -29296, 0, 23832, 0, -29295, 0, 23833, 0, -29294, 0, 23834, 0, -29293, 0, 23836, 0, -29292, 0, 23837, 0, -29291, 0, 23839, 0, -29290, 0, 23840, 0, -29289, 0, 23841, 0, -29288, 0, 23842, 0, -29287, 0, 23843, 0, -29286, 0, 23845, 0, -29285, 0, 23848, 0, -29284, 0, 23850, 0, -29283, 0, 23851, 0, -29282, 0, 23852, 0, -29281, 0, 23855, 0, -29280, 0, 23856, 0, -29279, 0, 23857, 0, -29278, 0, 23858, 0, -29277, 0, 23859, 0, -29276, 0, 23861, 0, -29275, 0, 23862, 0, -29274, 0, 23863, 0, -29273, 0, 23864, 0, -29272, 0, 23865, 0, -29271, 0, 23866, 0, -29270, 0, 23867, 0, -29269, 0, 23868, 0, -29268, 0, 23871, 0, -29267, 0, 23872, 0, -29266, 0, 23873, 0, -29265, 0, 23874, 0, -29264, 0, 23875, 0, -29263, 0, 23876, 0, -29262, 0, 23877, 0, -29261, 0, 23878, 0, -29260, 0, 23880, 0, -29259, 0, 23881, 0, -29258, 0, 23885, 0, -29257, 0, 23886, 0, -29256, 0, 23887, 0, -29255, 0, 23888, 0, -29254, 0, 23889, 0, -29253, 0, 23890, 0, -29252, 0, 23891, 0, -29251, 0, 23892, 0, -29250, 0, 23893, 0, -29249, 0, 23894, 0, -29248, 0, 23895, 0, -29247, 0, 23897, 0, -29246, 0, 23898, 0, -29245, 0, 23900, 0, -29244, 0, 23902, 0, -29243, 0, 23903, 0, -29242, 0, 23904, 0, -29241, 0, 23905, 0, -29240, 0, 23906, 0, -29239, 0, 23907, 0, -29238, 0, 23908, 0, -29237, 0, 23909, 0, -29236, 0, 23910, 0, -29235, 0, 23911, 0, -29234, 0, 23912, 0, -29233, 0, 23914, 0, -29232, 0, 23917, 0, -29231, 0, 23918, 0, -29230, 0, 23920, 0, -29229, 0, 23921, 0, -29228, 0, 23922, 0, -29227, 0, 23923, 0, -29226, 0, 23925, 0, -29225, 0, 23926, 0, -29224, 0, 23927, 0, -29223, 0, 23928, 0, -29222, 0, 23929, 0, -29221, 0, 23930, 0, -29220, 0, 23931, 0, -29219, 0, 23932, 0, -29218, 0, 23933, 0, -29217, 0, 23934, 0, -29216, 0, 23935, 0, -29215, 0, 23936, 0, -29214, 0, 23937, 0, -29213, 0, 23939, 0, -29212, 0, 23940, 0, -29211, 0, 23941, 0, -29210, 0, 23942, 0, -29209, 0, 23943, 0, -29208, 0, 23944, 0, -29207, 0, 23945, 0, -29206, 0, 23946, 0, -29205, 0, 23947, 0, -29204, 0, 23948, 0, -29203, 0, 23949, 0, -29202, 0, 23950, 0, -29201, 0, 23951, 0, -29200, 0, 23952, 0, -29199, 0, 23953, 0, -29198, 0, 23954, 0, -29197, 0, 23955, 0, -29196, 0, 23956, 0, -29195, 0, 23957, 0, -29194, 0, 23958, 0, -29193, 0, 23959, 0, -29192, 0, 23960, 0, -29191, 0, 23962, 0, -29190, 0, 23963, 0, -29189, 0, 23964, 0, -29188, 0, 23966, 0, -29187, 0, 23967, 0, -29186, 0, 23968, 0, -29120, 0, 23969, 0, -29119, 0, 23970, 0, -29118, 0, 23971, 0, -29117, 0, 23972, 0, -29116, 0, 23973, 0, -29115, 0, 23974, 0, -29114, 0, 23975, 0, -29113, 0, 23976, 0, -29112, 0, 23977, 0, -29111, 0, 23978, 0, -29110, 0, 23979, 0, -29109, 0, 23980, 0, -29108, 0, 23981, 0, -29107, 0, 23982, 0, -29106, 0, 23983, 0, -29105, 0, 23984, 0, -29104, 0, 23985, 0, -29103, 0, 23986, 0, -29102, 0, 23987, 0, -29101, 0, 23988, 0, -29100, 0, 23989, 0, -29099, 0, 23990, 0, -29098, 0, 23992, 0, -29097, 0, 23993, 0, -29096, 0, 23994, 0, -29095, 0, 23995, 0, -29094, 0, 23996, 0, -29093, 0, 23997, 0, -29092, 0, 23998, 0, -29091, 0, 23999, 0, -29090, 0, 24000, 0, -29089, 0, 24001, 0, -29088, 0, 24002, 0, -29087, 0, 24003, 0, -29086, 0, 24004, 0, -29085, 0, 24006, 0, -29084, 0, 24007, 0, -29083, 0, 24008, 0, -29082, 0, 24009, 0, -29081, 0, 24010, 0, -29080, 0, 24011, 0, -29079, 0, 24012, 0, -29078, 0, 24014, 0, -29077, 0, 24015, 0, -29076, 0, 24016, 0, -29075, 0, 24017, 0, -29074, 0, 24018, 0, -29073, 0, 24019, 0, -29072, 0, 24020, 0, -29071, 0, 24021, 0, -29070, 0, 24022, 0, -29069, 0, 24023, 0, -29068, 0, 24024, 0, -29067, 0, 24025, 0, -29066, 0, 24026, 0, -29065, 0, 24028, 0, -29064, 0, 24031, 0, -29063, 0, 24032, 0, -29062, 0, 24035, 0, -29061, 0, 24036, 0, -29060, 0, 24042, 0, -29059, 0, 24044, 0, -29058, 0, 24045, 0, -29056, 0, 24048, 0, -29055, 0, 24053, 0, -29054, 0, 24054, 0, -29053, 0, 24056, 0, -29052, 0, 24057, 0, -29051, 0, 24058, 0, -29050, 0, 24059, 0, -29049, 0, 24060, 0, -29048, 0, 24063, 0, -29047, 0, 24064, 0, -29046, 0, 24068, 0, -29045, 0, 24071, 0, -29044, 0, 24073, 0, -29043, 0, 24074, 0, -29042, 0, 24075, 0, -29041, 0, 24077, 0, -29040, 0, 24078, 0, -29039, 0, 24082, 0, -29038, 0, 24083, 0, -29037, 0, 24087, 0, -29036, 0, 24094, 0, -29035, 0, 24095, 0, -29034, 0, 24096, 0, -29033, 0, 24097, 0, -29032, 0, 24098, 0, -29031, 0, 24099, 0, -29030, 0, 24100, 0, -29029, 0, 24101, 0, -29028, 0, 24104, 0, -29027, 0, 24105, 0, -29026, 0, 24106, 0, -29025, 0, 24107, 0, -29024, 0, 24108, 0, -29023, 0, 24111, 0, -29022, 0, 24112, 0, -29021, 0, 24114, 0, -29020, 0, 24115, 0, -29019, 0, 24116, 0, -29018, 0, 24117, 0, -29017, 0, 24118, 0, -29016, 0, 24121, 0, -29015, 0, 24122, 0, -29014, 0, 24126, 0, -29013, 0, 24127, 0, -29012, 0, 24128, 0, -29011, 0, 24129, 0, -29010, 0, 24131, 0, -29009, 0, 24134, 0, -29008, 0, 24135, 0, -29007, 0, 24136, 0, -29006, 0, 24137, 0, -29005, 0, 24138, 0, -29004, 0, 24139, 0, -29003, 0, 24141, 0, -29002, 0, 24142, 0, -29001, 0, 24143, 0, -29000, 0, 24144, 0, -28999, 0, 24145, 0, -28998, 0, 24146, 0, -28997, 0, 24147, 0, -28996, 0, 24150, 0, -28995, 0, 24151, 0, -28994, 0, 24152, 0, -28993, 0, 24153, 0, -28992, 0, 24154, 0, -28991, 0, 24156, 0, -28990, 0, 24157, 0, -28989, 0, 24159, 0, -28988, 0, 24160, 0, -28987, 0, 24163, 0, -28986, 0, 24164, 0, -28985, 0, 24165, 0, -28984, 0, 24166, 0, -28983, 0, 24167, 0, -28982, 0, 24168, 0, -28981, 0, 24169, 0, -28980, 0, 24170, 0, -28979, 0, 24171, 0, -28978, 0, 24172, 0, -28977, 0, 24173, 0, -28976, 0, 24174, 0, -28975, 0, 24175, 0, -28974, 0, 24176, 0, -28973, 0, 24177, 0, -28972, 0, 24181, 0, -28971, 0, 24183, 0, -28970, 0, 24185, 0, -28969, 0, 24190, 0, -28968, 0, 24193, 0, -28967, 0, 24194, 0, -28966, 0, 24195, 0, -28965, 0, 24197, 0, -28964, 0, 24200, 0, -28963, 0, 24201, 0, -28962, 0, 24204, 0, -28961, 0, 24205, 0, -28960, 0, 24206, 0, -28959, 0, 24210, 0, -28958, 0, 24216, 0, -28957, 0, 24219, 0, -28956, 0, 24221, 0, -28955, 0, 24225, 0, -28954, 0, 24226, 0, -28953, 0, 24227, 0, -28952, 0, 24228, 0, -28951, 0, 24232, 0, -28950, 0, 24233, 0, -28949, 0, 24234, 0, -28948, 0, 24235, 0, -28947, 0, 24236, 0, -28946, 0, 24238, 0, -28945, 0, 24239, 0, -28944, 0, 24240, 0, -28943, 0, 24241, 0, -28942, 0, 24242, 0, -28941, 0, 24244, 0, -28940, 0, 24250, 0, -28939, 0, 24251, 0, -28938, 0, 24252, 0, -28937, 0, 24253, 0, -28936, 0, 24255, 0, -28935, 0, 24256, 0, -28934, 0, 24257, 0, -28933, 0, 24258, 0, -28932, 0, 24259, 0, -28931, 0, 24260, 0, -28930, 0, 24261, 0, -28864, 0, 24262, 0, -28863, 0, 24263, 0, -28862, 0, 24264, 0, -28861, 0, 24267, 0, -28860, 0, 24268, 0, -28859, 0, 24269, 0, -28858, 0, 24270, 0, -28857, 0, 24271, 0, -28856, 0, 24272, 0, -28855, 0, 24276, 0, -28854, 0, 24277, 0, -28853, 0, 24279, 0, -28852, 0, 24280, 0, -28851, 0, 24281, 0, -28850, 0, 24282, 0, -28849, 0, 24284, 0, -28848, 0, 24285, 0, -28847, 0, 24286, 0, -28846, 0, 24287, 0, -28845, 0, 24288, 0, -28844, 0, 24289, 0, -28843, 0, 24290, 0, -28842, 0, 24291, 0, -28841, 0, 24292, 0, -28840, 0, 24293, 0, -28839, 0, 24294, 0, -28838, 0, 24295, 0, -28837, 0, 24297, 0, -28836, 0, 24299, 0, -28835, 0, 24300, 0, -28834, 0, 24301, 0, -28833, 0, 24302, 0, -28832, 0, 24303, 0, -28831, 0, 24304, 0, -28830, 0, 24305, 0, -28829, 0, 24306, 0, -28828, 0, 24307, 0, -28827, 0, 24309, 0, -28826, 0, 24312, 0, -28825, 0, 24313, 0, -28824, 0, 24315, 0, -28823, 0, 24316, 0, -28822, 0, 24317, 0, -28821, 0, 24325, 0, -28820, 0, 24326, 0, -28819, 0, 24327, 0, -28818, 0, 24329, 0, -28817, 0, 24332, 0, -28816, 0, 24333, 0, -28815, 0, 24334, 0, -28814, 0, 24336, 0, -28813, 0, 24338, 0, -28812, 0, 24340, 0, -28811, 0, 24342, 0, -28810, 0, 24345, 0, -28809, 0, 24346, 0, -28808, 0, 24348, 0, -28807, 0, 24349, 0, -28806, 0, 24350, 0, -28805, 0, 24353, 0, -28804, 0, 24354, 0, -28803, 0, 24355, 0, -28802, 0, 24356, 0, -28800, 0, 24360, 0, -28799, 0, 24363, 0, -28798, 0, 24364, 0, -28797, 0, 24366, 0, -28796, 0, 24368, 0, -28795, 0, 24370, 0, -28794, 0, 24371, 0, -28793, 0, 24372, 0, -28792, 0, 24373, 0, -28791, 0, 24374, 0, -28790, 0, 24375, 0, -28789, 0, 24376, 0, -28788, 0, 24379, 0, -28787, 0, 24381, 0, -28786, 0, 24382, 0, -28785, 0, 24383, 0, -28784, 0, 24385, 0, -28783, 0, 24386, 0, -28782, 0, 24387, 0, -28781, 0, 24388, 0, -28780, 0, 24389, 0, -28779, 0, 24390, 0, -28778, 0, 24391, 0, -28777, 0, 24392, 0, -28776, 0, 24393, 0, -28775, 0, 24394, 0, -28774, 0, 24395, 0, -28773, 0, 24396, 0, -28772, 0, 24397, 0, -28771, 0, 24398, 0, -28770, 0, 24399, 0, -28769, 0, 24401, 0, -28768, 0, 24404, 0, -28767, 0, 24409, 0, -28766, 0, 24410, 0, -28765, 0, 24411, 0, -28764, 0, 24412, 0, -28763, 0, 24414, 0, -28762, 0, 24415, 0, -28761, 0, 24416, 0, -28760, 0, 24419, 0, -28759, 0, 24421, 0, -28758, 0, 24423, 0, -28757, 0, 24424, 0, -28756, 0, 24427, 0, -28755, 0, 24430, 0, -28754, 0, 24431, 0, -28753, 0, 24434, 0, -28752, 0, 24436, 0, -28751, 0, 24437, 0, -28750, 0, 24438, 0, -28749, 0, 24440, 0, -28748, 0, 24442, 0, -28747, 0, 24445, 0, -28746, 0, 24446, 0, -28745, 0, 24447, 0, -28744, 0, 24451, 0, -28743, 0, 24454, 0, -28742, 0, 24461, 0, -28741, 0, 24462, 0, -28740, 0, 24463, 0, -28739, 0, 24465, 0, -28738, 0, 24467, 0, -28737, 0, 24468, 0, -28736, 0, 24470, 0, -28735, 0, 24474, 0, -28734, 0, 24475, 0, -28733, 0, 24477, 0, -28732, 0, 24478, 0, -28731, 0, 24479, 0, -28730, 0, 24480, 0, -28729, 0, 24482, 0, -28728, 0, 24483, 0, -28727, 0, 24484, 0, -28726, 0, 24485, 0, -28725, 0, 24486, 0, -28724, 0, 24487, 0, -28723, 0, 24489, 0, -28722, 0, 24491, 0, -28721, 0, 24492, 0, -28720, 0, 24495, 0, -28719, 0, 24496, 0, -28718, 0, 24497, 0, -28717, 0, 24498, 0, -28716, 0, 24499, 0, -28715, 0, 24500, 0, -28714, 0, 24502, 0, -28713, 0, 24504, 0, -28712, 0, 24505, 0, -28711, 0, 24506, 0, -28710, 0, 24507, 0, -28709, 0, 24510, 0, -28708, 0, 24511, 0, -28707, 0, 24512, 0, -28706, 0, 24513, 0, -28705, 0, 24514, 0, -28704, 0, 24519, 0, -28703, 0, 24520, 0, -28702, 0, 24522, 0, -28701, 0, 24523, 0, -28700, 0, 24526, 0, -28699, 0, 24531, 0, -28698, 0, 24532, 0, -28697, 0, 24533, 0, -28696, 0, 24538, 0, -28695, 0, 24539, 0, -28694, 0, 24540, 0, -28693, 0, 24542, 0, -28692, 0, 24543, 0, -28691, 0, 24546, 0, -28690, 0, 24547, 0, -28689, 0, 24549, 0, -28688, 0, 24550, 0, -28687, 0, 24552, 0, -28686, 0, 24553, 0, -28685, 0, 24556, 0, -28684, 0, 24559, 0, -28683, 0, 24560, 0, -28682, 0, 24562, 0, -28681, 0, 24563, 0, -28680, 0, 24564, 0, -28679, 0, 24566, 0, -28678, 0, 24567, 0, -28677, 0, 24569, 0, -28676, 0, 24570, 0, -28675, 0, 24572, 0, -28674, 0, 24583, 0, -28608, 0, 24584, 0, -28607, 0, 24585, 0, -28606, 0, 24587, 0, -28605, 0, 24588, 0, -28604, 0, 24592, 0, -28603, 0, 24593, 0, -28602, 0, 24595, 0, -28601, 0, 24599, 0, -28600, 0, 24600, 0, -28599, 0, 24602, 0, -28598, 0, 24606, 0, -28597, 0, 24607, 0, -28596, 0, 24610, 0, -28595, 0, 24611, 0, -28594, 0, 24612, 0, -28593, 0, 24620, 0, -28592, 0, 24621, 0, -28591, 0, 24622, 0, -28590, 0, 24624, 0, -28589, 0, 24625, 0, -28588, 0, 24626, 0, -28587, 0, 24627, 0, -28586, 0, 24628, 0, -28585, 0, 24630, 0, -28584, 0, 24631, 0, -28583, 0, 24632, 0, -28582, 0, 24633, 0, -28581, 0, 24634, 0, -28580, 0, 24637, 0, -28579, 0, 24638, 0, -28578, 0, 24640, 0, -28577, 0, 24644, 0, -28576, 0, 24645, 0, -28575, 0, 24646, 0, -28574, 0, 24647, 0, -28573, 0, 24648, 0, -28572, 0, 24649, 0, -28571, 0, 24650, 0, -28570, 0, 24652, 0, -28569, 0, 24654, 0, -28568, 0, 24655, 0, -28567, 0, 24657, 0, -28566, 0, 24659, 0, -28565, 0, 24660, 0, -28564, 0, 24662, 0, -28563, 0, 24663, 0, -28562, 0, 24664, 0, -28561, 0, 24667, 0, -28560, 0, 24668, 0, -28559, 0, 24670, 0, -28558, 0, 24671, 0, -28557, 0, 24672, 0, -28556, 0, 24673, 0, -28555, 0, 24677, 0, -28554, 0, 24678, 0, -28553, 0, 24686, 0, -28552, 0, 24689, 0, -28551, 0, 24690, 0, -28550, 0, 24692, 0, -28549, 0, 24693, 0, -28548, 0, 24695, 0, -28547, 0, 24702, 0, -28546, 0, 24704, 0, -28544, 0, 24705, 0, -28543, 0, 24706, 0, -28542, 0, 24709, 0, -28541, 0, 24710, 0, -28540, 0, 24711, 0, -28539, 0, 24712, 0, -28538, 0, 24714, 0, -28537, 0, 24715, 0, -28536, 0, 24718, 0, -28535, 0, 24719, 0, -28534, 0, 24720, 0, -28533, 0, 24721, 0, -28532, 0, 24723, 0, -28531, 0, 24725, 0, -28530, 0, 24727, 0, -28529, 0, 24728, 0, -28528, 0, 24729, 0, -28527, 0, 24732, 0, -28526, 0, 24734, 0, -28525, 0, 24737, 0, -28524, 0, 24738, 0, -28523, 0, 24740, 0, -28522, 0, 24741, 0, -28521, 0, 24743, 0, -28520, 0, 24745, 0, -28519, 0, 24746, 0, -28518, 0, 24750, 0, -28517, 0, 24752, 0, -28516, 0, 24755, 0, -28515, 0, 24757, 0, -28514, 0, 24758, 0, -28513, 0, 24759, 0, -28512, 0, 24761, 0, -28511, 0, 24762, 0, -28510, 0, 24765, 0, -28509, 0, 24766, 0, -28508, 0, 24767, 0, -28507, 0, 24768, 0, -28506, 0, 24769, 0, -28505, 0, 24770, 0, -28504, 0, 24771, 0, -28503, 0, 24772, 0, -28502, 0, 24775, 0, -28501, 0, 24776, 0, -28500, 0, 24777, 0, -28499, 0, 24780, 0, -28498, 0, 24781, 0, -28497, 0, 24782, 0, -28496, 0, 24783, 0, -28495, 0, 24784, 0, -28494, 0, 24786, 0, -28493, 0, 24787, 0, -28492, 0, 24788, 0, -28491, 0, 24790, 0, -28490, 0, 24791, 0, -28489, 0, 24793, 0, -28488, 0, 24795, 0, -28487, 0, 24798, 0, -28486, 0, 24801, 0, -28485, 0, 24802, 0, -28484, 0, 24803, 0, -28483, 0, 24804, 0, -28482, 0, 24805, 0, -28481, 0, 24810, 0, -28480, 0, 24817, 0, -28479, 0, 24818, 0, -28478, 0, 24821, 0, -28477, 0, 24823, 0, -28476, 0, 24824, 0, -28475, 0, 24827, 0, -28474, 0, 24828, 0, -28473, 0, 24829, 0, -28472, 0, 24830, 0, -28471, 0, 24831, 0, -28470, 0, 24834, 0, -28469, 0, 24835, 0, -28468, 0, 24836, 0, -28467, 0, 24837, 0, -28466, 0, 24839, 0, -28465, 0, 24842, 0, -28464, 0, 24843, 0, -28463, 0, 24844, 0, -28462, 0, 24848, 0, -28461, 0, 24849, 0, -28460, 0, 24850, 0, -28459, 0, 24851, 0, -28458, 0, 24852, 0, -28457, 0, 24854, 0, -28456, 0, 24855, 0, -28455, 0, 24856, 0, -28454, 0, 24857, 0, -28453, 0, 24859, 0, -28452, 0, 24860, 0, -28451, 0, 24861, 0, -28450, 0, 24862, 0, -28449, 0, 24865, 0, -28448, 0, 24866, 0, -28447, 0, 24869, 0, -28446, 0, 24872, 0, -28445, 0, 24873, 0, -28444, 0, 24874, 0, -28443, 0, 24876, 0, -28442, 0, 24877, 0, -28441, 0, 24878, 0, -28440, 0, 24879, 0, -28439, 0, 24880, 0, -28438, 0, 24881, 0, -28437, 0, 24882, 0, -28436, 0, 24883, 0, -28435, 0, 24884, 0, -28434, 0, 24885, 0, -28433, 0, 24886, 0, -28432, 0, 24887, 0, -28431, 0, 24888, 0, -28430, 0, 24889, 0, -28429, 0, 24890, 0, -28428, 0, 24891, 0, -28427, 0, 24892, 0, -28426, 0, 24893, 0, -28425, 0, 24894, 0, -28424, 0, 24896, 0, -28423, 0, 24897, 0, -28422, 0, 24898, 0, -28421, 0, 24899, 0, -28420, 0, 24900, 0, -28419, 0, 24901, 0, -28418, 0, 24902, 0, -28352, 0, 24903, 0, -28351, 0, 24905, 0, -28350, 0, 24907, 0, -28349, 0, 24909, 0, -28348, 0, 24911, 0, -28347, 0, 24912, 0, -28346, 0, 24914, 0, -28345, 0, 24915, 0, -28344, 0, 24916, 0, -28343, 0, 24918, 0, -28342, 0, 24919, 0, -28341, 0, 24920, 0, -28340, 0, 24921, 0, -28339, 0, 24922, 0, -28338, 0, 24923, 0, -28337, 0, 24924, 0, -28336, 0, 24926, 0, -28335, 0, 24927, 0, -28334, 0, 24928, 0, -28333, 0, 24929, 0, -28332, 0, 24931, 0, -28331, 0, 24932, 0, -28330, 0, 24933, 0, -28329, 0, 24934, 0, -28328, 0, 24937, 0, -28327, 0, 24938, 0, -28326, 0, 24939, 0, -28325, 0, 24940, 0, -28324, 0, 24941, 0, -28323, 0, 24942, 0, -28322, 0, 24943, 0, -28321, 0, 24945, 0, -28320, 0, 24946, 0, -28319, 0, 24947, 0, -28318, 0, 24948, 0, -28317, 0, 24950, 0, -28316, 0, 24952, 0, -28315, 0, 24953, 0, -28314, 0, 24954, 0, -28313, 0, 24955, 0, -28312, 0, 24956, 0, -28311, 0, 24957, 0, -28310, 0, 24958, 0, -28309, 0, 24959, 0, -28308, 0, 24960, 0, -28307, 0, 24961, 0, -28306, 0, 24962, 0, -28305, 0, 24963, 0, -28304, 0, 24964, 0, -28303, 0, 24965, 0, -28302, 0, 24966, 0, -28301, 0, 24967, 0, -28300, 0, 24968, 0, -28299, 0, 24969, 0, -28298, 0, 24970, 0, -28297, 0, 24972, 0, -28296, 0, 24973, 0, -28295, 0, 24975, 0, -28294, 0, 24976, 0, -28293, 0, 24977, 0, -28292, 0, 24978, 0, -28291, 0, 24979, 0, -28290, 0, 24981, 0, -28288, 0, 24982, 0, -28287, 0, 24983, 0, -28286, 0, 24984, 0, -28285, 0, 24985, 0, -28284, 0, 24986, 0, -28283, 0, 24987, 0, -28282, 0, 24988, 0, -28281, 0, 24990, 0, -28280, 0, 24991, 0, -28279, 0, 24992, 0, -28278, 0, 24993, 0, -28277, 0, 24994, 0, -28276, 0, 24995, 0, -28275, 0, 24996, 0, -28274, 0, 24997, 0, -28273, 0, 24998, 0, -28272, 0, 25002, 0, -28271, 0, 25003, 0, -28270, 0, 25005, 0, -28269, 0, 25006, 0, -28268, 0, 25007, 0, -28267, 0, 25008, 0, -28266, 0, 25009, 0, -28265, 0, 25010, 0, -28264, 0, 25011, 0, -28263, 0, 25012, 0, -28262, 0, 25013, 0, -28261, 0, 25014, 0, -28260, 0, 25016, 0, -28259, 0, 25017, 0, -28258, 0, 25018, 0, -28257, 0, 25019, 0, -28256, 0, 25020, 0, -28255, 0, 25021, 0, -28254, 0, 25023, 0, -28253, 0, 25024, 0, -28252, 0, 25025, 0, -28251, 0, 25027, 0, -28250, 0, 25028, 0, -28249, 0, 25029, 0, -28248, 0, 25030, 0, -28247, 0, 25031, 0, -28246, 0, 25033, 0, -28245, 0, 25036, 0, -28244, 0, 25037, 0, -28243, 0, 25038, 0, -28242, 0, 25039, 0, -28241, 0, 25040, 0, -28240, 0, 25043, 0, -28239, 0, 25045, 0, -28238, 0, 25046, 0, -28237, 0, 25047, 0, -28236, 0, 25048, 0, -28235, 0, 25049, 0, -28234, 0, 25050, 0, -28233, 0, 25051, 0, -28232, 0, 25052, 0, -28231, 0, 25053, 0, -28230, 0, 25054, 0, -28229, 0, 25055, 0, -28228, 0, 25056, 0, -28227, 0, 25057, 0, -28226, 0, 25058, 0, -28225, 0, 25059, 0, -28224, 0, 25060, 0, -28223, 0, 25061, 0, -28222, 0, 25063, 0, -28221, 0, 25064, 0, -28220, 0, 25065, 0, -28219, 0, 25066, 0, -28218, 0, 25067, 0, -28217, 0, 25068, 0, -28216, 0, 25069, 0, -28215, 0, 25070, 0, -28214, 0, 25071, 0, -28213, 0, 25072, 0, -28212, 0, 25073, 0, -28211, 0, 25074, 0, -28210, 0, 25075, 0, -28209, 0, 25076, 0, -28208, 0, 25078, 0, -28207, 0, 25079, 0, -28206, 0, 25080, 0, -28205, 0, 25081, 0, -28204, 0, 25082, 0, -28203, 0, 25083, 0, -28202, 0, 25084, 0, -28201, 0, 25085, 0, -28200, 0, 25086, 0, -28199, 0, 25088, 0, -28198, 0, 25089, 0, -28197, 0, 25090, 0, -28196, 0, 25091, 0, -28195, 0, 25092, 0, -28194, 0, 25093, 0, -28193, 0, 25095, 0, -28192, 0, 25097, 0, -28191, 0, 25107, 0, -28190, 0, 25108, 0, -28189, 0, 25113, 0, -28188, 0, 25116, 0, -28187, 0, 25117, 0, -28186, 0, 25118, 0, -28185, 0, 25120, 0, -28184, 0, 25123, 0, -28183, 0, 25126, 0, -28182, 0, 25127, 0, -28181, 0, 25128, 0, -28180, 0, 25129, 0, -28179, 0, 25131, 0, -28178, 0, 25133, 0, -28177, 0, 25135, 0, -28176, 0, 25136, 0, -28175, 0, 25137, 0, -28174, 0, 25138, 0, -28173, 0, 25141, 0, -28172, 0, 25142, 0, -28171, 0, 25144, 0, -28170, 0, 25145, 0, -28169, 0, 25146, 0, -28168, 0, 25147, 0, -28167, 0, 25148, 0, -28166, 0, 25154, 0, -28165, 0, 25156, 0, -28164, 0, 25157, 0, -28163, 0, 25158, 0, -28162, 0, 25162, 0, -28096, 0, 25167, 0, -28095, 0, 25168, 0, -28094, 0, 25173, 0, -28093, 0, 25174, 0, -28092, 0, 25175, 0, -28091, 0, 25177, 0, -28090, 0, 25178, 0, -28089, 0, 25180, 0, -28088, 0, 25181, 0, -28087, 0, 25182, 0, -28086, 0, 25183, 0, -28085, 0, 25184, 0, -28084, 0, 25185, 0, -28083, 0, 25186, 0, -28082, 0, 25188, 0, -28081, 0, 25189, 0, -28080, 0, 25192, 0, -28079, 0, 25201, 0, -28078, 0, 25202, 0, -28077, 0, 25204, 0, -28076, 0, 25205, 0, -28075, 0, 25207, 0, -28074, 0, 25208, 0, -28073, 0, 25210, 0, -28072, 0, 25211, 0, -28071, 0, 25213, 0, -28070, 0, 25217, 0, -28069, 0, 25218, 0, -28068, 0, 25219, 0, -28067, 0, 25221, 0, -28066, 0, 25222, 0, -28065, 0, 25223, 0, -28064, 0, 25224, 0, -28063, 0, 25227, 0, -28062, 0, 25228, 0, -28061, 0, 25229, 0, -28060, 0, 25230, 0, -28059, 0, 25231, 0, -28058, 0, 25232, 0, -28057, 0, 25236, 0, -28056, 0, 25241, 0, -28055, 0, 25244, 0, -28054, 0, 25245, 0, -28053, 0, 25246, 0, -28052, 0, 25251, 0, -28051, 0, 25254, 0, -28050, 0, 25255, 0, -28049, 0, 25257, 0, -28048, 0, 25258, 0, -28047, 0, 25261, 0, -28046, 0, 25262, 0, -28045, 0, 25263, 0, -28044, 0, 25264, 0, -28043, 0, 25266, 0, -28042, 0, 25267, 0, -28041, 0, 25268, 0, -28040, 0, 25270, 0, -28039, 0, 25271, 0, -28038, 0, 25272, 0, -28037, 0, 25274, 0, -28036, 0, 25278, 0, -28035, 0, 25280, 0, -28034, 0, 25281, 0, -28032, 0, 25283, 0, -28031, 0, 25291, 0, -28030, 0, 25295, 0, -28029, 0, 25297, 0, -28028, 0, 25301, 0, -28027, 0, 25309, 0, -28026, 0, 25310, 0, -28025, 0, 25312, 0, -28024, 0, 25313, 0, -28023, 0, 25316, 0, -28022, 0, 25322, 0, -28021, 0, 25323, 0, -28020, 0, 25328, 0, -28019, 0, 25330, 0, -28018, 0, 25333, 0, -28017, 0, 25336, 0, -28016, 0, 25337, 0, -28015, 0, 25338, 0, -28014, 0, 25339, 0, -28013, 0, 25344, 0, -28012, 0, 25347, 0, -28011, 0, 25348, 0, -28010, 0, 25349, 0, -28009, 0, 25350, 0, -28008, 0, 25354, 0, -28007, 0, 25355, 0, -28006, 0, 25356, 0, -28005, 0, 25357, 0, -28004, 0, 25359, 0, -28003, 0, 25360, 0, -28002, 0, 25362, 0, -28001, 0, 25363, 0, -28000, 0, 25364, 0, -27999, 0, 25365, 0, -27998, 0, 25367, 0, -27997, 0, 25368, 0, -27996, 0, 25369, 0, -27995, 0, 25372, 0, -27994, 0, 25382, 0, -27993, 0, 25383, 0, -27992, 0, 25385, 0, -27991, 0, 25388, 0, -27990, 0, 25389, 0, -27989, 0, 25390, 0, -27988, 0, 25392, 0, -27987, 0, 25393, 0, -27986, 0, 25395, 0, -27985, 0, 25396, 0, -27984, 0, 25397, 0, -27983, 0, 25398, 0, -27982, 0, 25399, 0, -27981, 0, 25400, 0, -27980, 0, 25403, 0, -27979, 0, 25404, 0, -27978, 0, 25406, 0, -27977, 0, 25407, 0, -27976, 0, 25408, 0, -27975, 0, 25409, 0, -27974, 0, 25412, 0, -27973, 0, 25415, 0, -27972, 0, 25416, 0, -27971, 0, 25418, 0, -27970, 0, 25425, 0, -27969, 0, 25426, 0, -27968, 0, 25427, 0, -27967, 0, 25428, 0, -27966, 0, 25430, 0, -27965, 0, 25431, 0, -27964, 0, 25432, 0, -27963, 0, 25433, 0, -27962, 0, 25434, 0, -27961, 0, 25435, 0, -27960, 0, 25436, 0, -27959, 0, 25437, 0, -27958, 0, 25440, 0, -27957, 0, 25444, 0, -27956, 0, 25445, 0, -27955, 0, 25446, 0, -27954, 0, 25448, 0, -27953, 0, 25450, 0, -27952, 0, 25451, 0, -27951, 0, 25452, 0, -27950, 0, 25455, 0, -27949, 0, 25456, 0, -27948, 0, 25458, 0, -27947, 0, 25459, 0, -27946, 0, 25460, 0, -27945, 0, 25461, 0, -27944, 0, 25464, 0, -27943, 0, 25465, 0, -27942, 0, 25468, 0, -27941, 0, 25469, 0, -27940, 0, 25470, 0, -27939, 0, 25471, 0, -27938, 0, 25473, 0, -27937, 0, 25475, 0, -27936, 0, 25476, 0, -27935, 0, 25477, 0, -27934, 0, 25478, 0, -27933, 0, 25483, 0, -27932, 0, 25485, 0, -27931, 0, 25489, 0, -27930, 0, 25491, 0, -27929, 0, 25492, 0, -27928, 0, 25493, 0, -27927, 0, 25495, 0, -27926, 0, 25497, 0, -27925, 0, 25498, 0, -27924, 0, 25499, 0, -27923, 0, 25500, 0, -27922, 0, 25501, 0, -27921, 0, 25502, 0, -27920, 0, 25503, 0, -27919, 0, 25505, 0, -27918, 0, 25508, 0, -27917, 0, 25510, 0, -27916, 0, 25515, 0, -27915, 0, 25519, 0, -27914, 0, 25521, 0, -27913, 0, 25522, 0, -27912, 0, 25525, 0, -27911, 0, 25526, 0, -27910, 0, 25529, 0, -27909, 0, 25531, 0, -27908, 0, 25533, 0, -27907, 0, 25535, 0, -27906, 0, 25536, 0, -27840, 0, 25537, 0, -27839, 0, 25538, 0, -27838, 0, 25539, 0, -27837, 0, 25541, 0, -27836, 0, 25543, 0, -27835, 0, 25544, 0, -27834, 0, 25546, 0, -27833, 0, 25547, 0, -27832, 0, 25548, 0, -27831, 0, 25553, 0, -27830, 0, 25555, 0, -27829, 0, 25556, 0, -27828, 0, 25557, 0, -27827, 0, 25559, 0, -27826, 0, 25560, 0, -27825, 0, 25561, 0, -27824, 0, 25562, 0, -27823, 0, 25563, 0, -27822, 0, 25564, 0, -27821, 0, 25565, 0, -27820, 0, 25567, 0, -27819, 0, 25570, 0, -27818, 0, 25572, 0, -27817, 0, 25573, 0, -27816, 0, 25574, 0, -27815, 0, 25575, 0, -27814, 0, 25576, 0, -27813, 0, 25579, 0, -27812, 0, 25580, 0, -27811, 0, 25582, 0, -27810, 0, 25583, 0, -27809, 0, 25584, 0, -27808, 0, 25585, 0, -27807, 0, 25587, 0, -27806, 0, 25589, 0, -27805, 0, 25591, 0, -27804, 0, 25593, 0, -27803, 0, 25594, 0, -27802, 0, 25595, 0, -27801, 0, 25596, 0, -27800, 0, 25598, 0, -27799, 0, 25603, 0, -27798, 0, 25604, 0, -27797, 0, 25606, 0, -27796, 0, 25607, 0, -27795, 0, 25608, 0, -27794, 0, 25609, 0, -27793, 0, 25610, 0, -27792, 0, 25613, 0, -27791, 0, 25614, 0, -27790, 0, 25617, 0, -27789, 0, 25618, 0, -27788, 0, 25621, 0, -27787, 0, 25622, 0, -27786, 0, 25623, 0, -27785, 0, 25624, 0, -27784, 0, 25625, 0, -27783, 0, 25626, 0, -27782, 0, 25629, 0, -27781, 0, 25631, 0, -27780, 0, 25634, 0, -27779, 0, 25635, 0, -27778, 0, 25636, 0, -27776, 0, 25637, 0, -27775, 0, 25639, 0, -27774, 0, 25640, 0, -27773, 0, 25641, 0, -27772, 0, 25643, 0, -27771, 0, 25646, 0, -27770, 0, 25647, 0, -27769, 0, 25648, 0, -27768, 0, 25649, 0, -27767, 0, 25650, 0, -27766, 0, 25651, 0, -27765, 0, 25653, 0, -27764, 0, 25654, 0, -27763, 0, 25655, 0, -27762, 0, 25656, 0, -27761, 0, 25657, 0, -27760, 0, 25659, 0, -27759, 0, 25660, 0, -27758, 0, 25662, 0, -27757, 0, 25664, 0, -27756, 0, 25666, 0, -27755, 0, 25667, 0, -27754, 0, 25673, 0, -27753, 0, 25675, 0, -27752, 0, 25676, 0, -27751, 0, 25677, 0, -27750, 0, 25678, 0, -27749, 0, 25679, 0, -27748, 0, 25680, 0, -27747, 0, 25681, 0, -27746, 0, 25683, 0, -27745, 0, 25685, 0, -27744, 0, 25686, 0, -27743, 0, 25687, 0, -27742, 0, 25689, 0, -27741, 0, 25690, 0, -27740, 0, 25691, 0, -27739, 0, 25692, 0, -27738, 0, 25693, 0, -27737, 0, 25695, 0, -27736, 0, 25696, 0, -27735, 0, 25697, 0, -27734, 0, 25698, 0, -27733, 0, 25699, 0, -27732, 0, 25700, 0, -27731, 0, 25701, 0, -27730, 0, 25702, 0, -27729, 0, 25704, 0, -27728, 0, 25706, 0, -27727, 0, 25707, 0, -27726, 0, 25708, 0, -27725, 0, 25710, 0, -27724, 0, 25711, 0, -27723, 0, 25712, 0, -27722, 0, 25713, 0, -27721, 0, 25714, 0, -27720, 0, 25715, 0, -27719, 0, 25716, 0, -27718, 0, 25717, 0, -27717, 0, 25718, 0, -27716, 0, 25719, 0, -27715, 0, 25723, 0, -27714, 0, 25724, 0, -27713, 0, 25725, 0, -27712, 0, 25726, 0, -27711, 0, 25727, 0, -27710, 0, 25728, 0, -27709, 0, 25729, 0, -27708, 0, 25731, 0, -27707, 0, 25734, 0, -27706, 0, 25736, 0, -27705, 0, 25737, 0, -27704, 0, 25738, 0, -27703, 0, 25739, 0, -27702, 0, 25740, 0, -27701, 0, 25741, 0, -27700, 0, 25742, 0, -27699, 0, 25743, 0, -27698, 0, 25744, 0, -27697, 0, 25747, 0, -27696, 0, 25748, 0, -27695, 0, 25751, 0, -27694, 0, 25752, 0, -27693, 0, 25754, 0, -27692, 0, 25755, 0, -27691, 0, 25756, 0, -27690, 0, 25757, 0, -27689, 0, 25759, 0, -27688, 0, 25760, 0, -27687, 0, 25761, 0, -27686, 0, 25762, 0, -27685, 0, 25763, 0, -27684, 0, 25765, 0, -27683, 0, 25766, 0, -27682, 0, 25767, 0, -27681, 0, 25768, 0, -27680, 0, 25770, 0, -27679, 0, 25771, 0, -27678, 0, 25775, 0, -27677, 0, 25777, 0, -27676, 0, 25778, 0, -27675, 0, 25779, 0, -27674, 0, 25780, 0, -27673, 0, 25782, 0, -27672, 0, 25785, 0, -27671, 0, 25787, 0, -27670, 0, 25789, 0, -27669, 0, 25790, 0, -27668, 0, 25791, 0, -27667, 0, 25793, 0, -27666, 0, 25795, 0, -27665, 0, 25796, 0, -27664, 0, 25798, 0, -27663, 0, 25799, 0, -27662, 0, 25800, 0, -27661, 0, 25801, 0, -27660, 0, 25802, 0, -27659, 0, 25803, 0, -27658, 0, 25804, 0, -27657, 0, 25807, 0, -27656, 0, 25809, 0, -27655, 0, 25811, 0, -27654, 0, 25812, 0, -27653, 0, 25813, 0, -27652, 0, 25814, 0, -27651, 0, 25817, 0, -27650, 0, 25818, 0, -27584, 0, 25819, 0, -27583, 0, 25820, 0, -27582, 0, 25821, 0, -27581, 0, 25823, 0, -27580, 0, 25824, 0, -27579, 0, 25825, 0, -27578, 0, 25827, 0, -27577, 0, 25829, 0, -27576, 0, 25831, 0, -27575, 0, 25832, 0, -27574, 0, 25833, 0, -27573, 0, 25834, 0, -27572, 0, 25835, 0, -27571, 0, 25836, 0, -27570, 0, 25837, 0, -27569, 0, 25838, 0, -27568, 0, 25839, 0, -27567, 0, 25840, 0, -27566, 0, 25841, 0, -27565, 0, 25842, 0, -27564, 0, 25843, 0, -27563, 0, 25844, 0, -27562, 0, 25845, 0, -27561, 0, 25846, 0, -27560, 0, 25847, 0, -27559, 0, 25848, 0, -27558, 0, 25849, 0, -27557, 0, 25850, 0, -27556, 0, 25851, 0, -27555, 0, 25852, 0, -27554, 0, 25853, 0, -27553, 0, 25854, 0, -27552, 0, 25855, 0, -27551, 0, 25857, 0, -27550, 0, 25858, 0, -27549, 0, 25859, 0, -27548, 0, 25860, 0, -27547, 0, 25861, 0, -27546, 0, 25862, 0, -27545, 0, 25863, 0, -27544, 0, 25864, 0, -27543, 0, 25866, 0, -27542, 0, 25867, 0, -27541, 0, 25868, 0, -27540, 0, 25869, 0, -27539, 0, 25870, 0, -27538, 0, 25871, 0, -27537, 0, 25872, 0, -27536, 0, 25873, 0, -27535, 0, 25875, 0, -27534, 0, 25876, 0, -27533, 0, 25877, 0, -27532, 0, 25878, 0, -27531, 0, 25879, 0, -27530, 0, 25881, 0, -27529, 0, 25882, 0, -27528, 0, 25883, 0, -27527, 0, 25884, 0, -27526, 0, 25885, 0, -27525, 0, 25886, 0, -27524, 0, 25887, 0, -27523, 0, 25888, 0, -27522, 0, 25889, 0, -27520, 0, 25890, 0, -27519, 0, 25891, 0, -27518, 0, 25892, 0, -27517, 0, 25894, 0, -27516, 0, 25895, 0, -27515, 0, 25896, 0, -27514, 0, 25897, 0, -27513, 0, 25898, 0, -27512, 0, 25900, 0, -27511, 0, 25901, 0, -27510, 0, 25904, 0, -27509, 0, 25905, 0, -27508, 0, 25906, 0, -27507, 0, 25907, 0, -27506, 0, 25911, 0, -27505, 0, 25914, 0, -27504, 0, 25916, 0, -27503, 0, 25917, 0, -27502, 0, 25920, 0, -27501, 0, 25921, 0, -27500, 0, 25922, 0, -27499, 0, 25923, 0, -27498, 0, 25924, 0, -27497, 0, 25926, 0, -27496, 0, 25927, 0, -27495, 0, 25930, 0, -27494, 0, 25931, 0, -27493, 0, 25933, 0, -27492, 0, 25934, 0, -27491, 0, 25936, 0, -27490, 0, 25938, 0, -27489, 0, 25939, 0, -27488, 0, 25940, 0, -27487, 0, 25943, 0, -27486, 0, 25944, 0, -27485, 0, 25946, 0, -27484, 0, 25948, 0, -27483, 0, 25951, 0, -27482, 0, 25952, 0, -27481, 0, 25953, 0, -27480, 0, 25956, 0, -27479, 0, 25957, 0, -27478, 0, 25959, 0, -27477, 0, 25960, 0, -27476, 0, 25961, 0, -27475, 0, 25962, 0, -27474, 0, 25965, 0, -27473, 0, 25966, 0, -27472, 0, 25967, 0, -27471, 0, 25969, 0, -27470, 0, 25971, 0, -27469, 0, 25973, 0, -27468, 0, 25974, 0, -27467, 0, 25976, 0, -27466, 0, 25977, 0, -27465, 0, 25978, 0, -27464, 0, 25979, 0, -27463, 0, 25980, 0, -27462, 0, 25981, 0, -27461, 0, 25982, 0, -27460, 0, 25983, 0, -27459, 0, 25984, 0, -27458, 0, 25985, 0, -27457, 0, 25986, 0, -27456, 0, 25987, 0, -27455, 0, 25988, 0, -27454, 0, 25989, 0, -27453, 0, 25990, 0, -27452, 0, 25992, 0, -27451, 0, 25993, 0, -27450, 0, 25994, 0, -27449, 0, 25997, 0, -27448, 0, 25998, 0, -27447, 0, 25999, 0, -27446, 0, 26002, 0, -27445, 0, 26004, 0, -27444, 0, 26005, 0, -27443, 0, 26006, 0, -27442, 0, 26008, 0, -27441, 0, 26010, 0, -27440, 0, 26013, 0, -27439, 0, 26014, 0, -27438, 0, 26016, 0, -27437, 0, 26018, 0, -27436, 0, 26019, 0, -27435, 0, 26022, 0, -27434, 0, 26024, 0, -27433, 0, 26026, 0, -27432, 0, 26028, 0, -27431, 0, 26030, 0, -27430, 0, 26033, 0, -27429, 0, 26034, 0, -27428, 0, 26035, 0, -27427, 0, 26036, 0, -27426, 0, 26037, 0, -27425, 0, 26038, 0, -27424, 0, 26039, 0, -27423, 0, 26040, 0, -27422, 0, 26042, 0, -27421, 0, 26043, 0, -27420, 0, 26046, 0, -27419, 0, 26047, 0, -27418, 0, 26048, 0, -27417, 0, 26050, 0, -27416, 0, 26055, 0, -27415, 0, 26056, 0, -27414, 0, 26057, 0, -27413, 0, 26058, 0, -27412, 0, 26061, 0, -27411, 0, 26064, 0, -27410, 0, 26065, 0, -27409, 0, 26067, 0, -27408, 0, 26068, 0, -27407, 0, 26069, 0, -27406, 0, 26072, 0, -27405, 0, 26073, 0, -27404, 0, 26074, 0, -27403, 0, 26075, 0, -27402, 0, 26076, 0, -27401, 0, 26077, 0, -27400, 0, 26078, 0, -27399, 0, 26079, 0, -27398, 0, 26081, 0, -27397, 0, 26083, 0, -27396, 0, 26084, 0, -27395, 0, 26090, 0, -27394, 0, 26091, 0, -27328, 0, 26098, 0, -27327, 0, 26099, 0, -27326, 0, 26100, 0, -27325, 0, 26101, 0, -27324, 0, 26104, 0, -27323, 0, 26105, 0, -27322, 0, 26107, 0, -27321, 0, 26108, 0, -27320, 0, 26109, 0, -27319, 0, 26110, 0, -27318, 0, 26111, 0, -27317, 0, 26113, 0, -27316, 0, 26116, 0, -27315, 0, 26117, 0, -27314, 0, 26119, 0, -27313, 0, 26120, 0, -27312, 0, 26121, 0, -27311, 0, 26123, 0, -27310, 0, 26125, 0, -27309, 0, 26128, 0, -27308, 0, 26129, 0, -27307, 0, 26130, 0, -27306, 0, 26134, 0, -27305, 0, 26135, 0, -27304, 0, 26136, 0, -27303, 0, 26138, 0, -27302, 0, 26139, 0, -27301, 0, 26140, 0, -27300, 0, 26142, 0, -27299, 0, 26145, 0, -27298, 0, 26146, 0, -27297, 0, 26147, 0, -27296, 0, 26148, 0, -27295, 0, 26150, 0, -27294, 0, 26153, 0, -27293, 0, 26154, 0, -27292, 0, 26155, 0, -27291, 0, 26156, 0, -27290, 0, 26158, 0, -27289, 0, 26160, 0, -27288, 0, 26162, 0, -27287, 0, 26163, 0, -27286, 0, 26167, 0, -27285, 0, 26168, 0, -27284, 0, 26169, 0, -27283, 0, 26170, 0, -27282, 0, 26171, 0, -27281, 0, 26173, 0, -27280, 0, 26175, 0, -27279, 0, 26176, 0, -27278, 0, 26178, 0, -27277, 0, 26180, 0, -27276, 0, 26181, 0, -27275, 0, 26182, 0, -27274, 0, 26183, 0, -27273, 0, 26184, 0, -27272, 0, 26185, 0, -27271, 0, 26186, 0, -27270, 0, 26189, 0, -27269, 0, 26190, 0, -27268, 0, 26192, 0, -27267, 0, 26193, 0, -27266, 0, 26200, 0, -27264, 0, 26201, 0, -27263, 0, 26203, 0, -27262, 0, 26204, 0, -27261, 0, 26205, 0, -27260, 0, 26206, 0, -27259, 0, 26208, 0, -27258, 0, 26210, 0, -27257, 0, 26211, 0, -27256, 0, 26213, 0, -27255, 0, 26215, 0, -27254, 0, 26217, 0, -27253, 0, 26218, 0, -27252, 0, 26219, 0, -27251, 0, 26220, 0, -27250, 0, 26221, 0, -27249, 0, 26225, 0, -27248, 0, 26226, 0, -27247, 0, 26227, 0, -27246, 0, 26229, 0, -27245, 0, 26232, 0, -27244, 0, 26233, 0, -27243, 0, 26235, 0, -27242, 0, 26236, 0, -27241, 0, 26237, 0, -27240, 0, 26239, 0, -27239, 0, 26240, 0, -27238, 0, 26241, 0, -27237, 0, 26243, 0, -27236, 0, 26245, 0, -27235, 0, 26246, 0, -27234, 0, 26248, 0, -27233, 0, 26249, 0, -27232, 0, 26250, 0, -27231, 0, 26251, 0, -27230, 0, 26253, 0, -27229, 0, 26254, 0, -27228, 0, 26255, 0, -27227, 0, 26256, 0, -27226, 0, 26258, 0, -27225, 0, 26259, 0, -27224, 0, 26260, 0, -27223, 0, 26261, 0, -27222, 0, 26264, 0, -27221, 0, 26265, 0, -27220, 0, 26266, 0, -27219, 0, 26267, 0, -27218, 0, 26268, 0, -27217, 0, 26270, 0, -27216, 0, 26271, 0, -27215, 0, 26272, 0, -27214, 0, 26273, 0, -27213, 0, 26274, 0, -27212, 0, 26275, 0, -27211, 0, 26276, 0, -27210, 0, 26277, 0, -27209, 0, 26278, 0, -27208, 0, 26281, 0, -27207, 0, 26282, 0, -27206, 0, 26283, 0, -27205, 0, 26284, 0, -27204, 0, 26285, 0, -27203, 0, 26287, 0, -27202, 0, 26288, 0, -27201, 0, 26289, 0, -27200, 0, 26290, 0, -27199, 0, 26291, 0, -27198, 0, 26293, 0, -27197, 0, 26294, 0, -27196, 0, 26295, 0, -27195, 0, 26296, 0, -27194, 0, 26298, 0, -27193, 0, 26299, 0, -27192, 0, 26300, 0, -27191, 0, 26301, 0, -27190, 0, 26303, 0, -27189, 0, 26304, 0, -27188, 0, 26305, 0, -27187, 0, 26306, 0, -27186, 0, 26307, 0, -27185, 0, 26308, 0, -27184, 0, 26309, 0, -27183, 0, 26310, 0, -27182, 0, 26311, 0, -27181, 0, 26312, 0, -27180, 0, 26313, 0, -27179, 0, 26314, 0, -27178, 0, 26315, 0, -27177, 0, 26316, 0, -27176, 0, 26317, 0, -27175, 0, 26318, 0, -27174, 0, 26319, 0, -27173, 0, 26320, 0, -27172, 0, 26321, 0, -27171, 0, 26322, 0, -27170, 0, 26323, 0, -27169, 0, 26324, 0, -27168, 0, 26325, 0, -27167, 0, 26326, 0, -27166, 0, 26327, 0, -27165, 0, 26328, 0, -27164, 0, 26330, 0, -27163, 0, 26334, 0, -27162, 0, 26335, 0, -27161, 0, 26336, 0, -27160, 0, 26337, 0, -27159, 0, 26338, 0, -27158, 0, 26339, 0, -27157, 0, 26340, 0, -27156, 0, 26341, 0, -27155, 0, 26343, 0, -27154, 0, 26344, 0, -27153, 0, 26346, 0, -27152, 0, 26347, 0, -27151, 0, 26348, 0, -27150, 0, 26349, 0, -27149, 0, 26350, 0, -27148, 0, 26351, 0, -27147, 0, 26353, 0, -27146, 0, 26357, 0, -27145, 0, 26358, 0, -27144, 0, 26360, 0, -27143, 0, 26362, 0, -27142, 0, 26363, 0, -27141, 0, 26365, 0, -27140, 0, 26369, 0, -27139, 0, 26370, 0, -27138, 0, 26371, 0, -27072, 0, 26372, 0, -27071, 0, 26373, 0, -27070, 0, 26374, 0, -27069, 0, 26375, 0, -27068, 0, 26380, 0, -27067, 0, 26382, 0, -27066, 0, 26383, 0, -27065, 0, 26385, 0, -27064, 0, 26386, 0, -27063, 0, 26387, 0, -27062, 0, 26390, 0, -27061, 0, 26392, 0, -27060, 0, 26393, 0, -27059, 0, 26394, 0, -27058, 0, 26396, 0, -27057, 0, 26398, 0, -27056, 0, 26400, 0, -27055, 0, 26401, 0, -27054, 0, 26402, 0, -27053, 0, 26403, 0, -27052, 0, 26404, 0, -27051, 0, 26405, 0, -27050, 0, 26407, 0, -27049, 0, 26409, 0, -27048, 0, 26414, 0, -27047, 0, 26416, 0, -27046, 0, 26418, 0, -27045, 0, 26419, 0, -27044, 0, 26422, 0, -27043, 0, 26423, 0, -27042, 0, 26424, 0, -27041, 0, 26425, 0, -27040, 0, 26427, 0, -27039, 0, 26428, 0, -27038, 0, 26430, 0, -27037, 0, 26431, 0, -27036, 0, 26433, 0, -27035, 0, 26436, 0, -27034, 0, 26437, 0, -27033, 0, 26439, 0, -27032, 0, 26442, 0, -27031, 0, 26443, 0, -27030, 0, 26445, 0, -27029, 0, 26450, 0, -27028, 0, 26452, 0, -27027, 0, 26453, 0, -27026, 0, 26455, 0, -27025, 0, 26456, 0, -27024, 0, 26457, 0, -27023, 0, 26458, 0, -27022, 0, 26459, 0, -27021, 0, 26461, 0, -27020, 0, 26466, 0, -27019, 0, 26467, 0, -27018, 0, 26468, 0, -27017, 0, 26470, 0, -27016, 0, 26471, 0, -27015, 0, 26475, 0, -27014, 0, 26476, 0, -27013, 0, 26478, 0, -27012, 0, 26481, 0, -27011, 0, 26484, 0, -27010, 0, 26486, 0, -27008, 0, 26488, 0, -27007, 0, 26489, 0, -27006, 0, 26490, 0, -27005, 0, 26491, 0, -27004, 0, 26493, 0, -27003, 0, 26496, 0, -27002, 0, 26498, 0, -27001, 0, 26499, 0, -27000, 0, 26501, 0, -26999, 0, 26502, 0, -26998, 0, 26504, 0, -26997, 0, 26506, 0, -26996, 0, 26508, 0, -26995, 0, 26509, 0, -26994, 0, 26510, 0, -26993, 0, 26511, 0, -26992, 0, 26513, 0, -26991, 0, 26514, 0, -26990, 0, 26515, 0, -26989, 0, 26516, 0, -26988, 0, 26518, 0, -26987, 0, 26521, 0, -26986, 0, 26523, 0, -26985, 0, 26527, 0, -26984, 0, 26528, 0, -26983, 0, 26529, 0, -26982, 0, 26532, 0, -26981, 0, 26534, 0, -26980, 0, 26537, 0, -26979, 0, 26540, 0, -26978, 0, 26542, 0, -26977, 0, 26545, 0, -26976, 0, 26546, 0, -26975, 0, 26548, 0, -26974, 0, 26553, 0, -26973, 0, 26554, 0, -26972, 0, 26555, 0, -26971, 0, 26556, 0, -26970, 0, 26557, 0, -26969, 0, 26558, 0, -26968, 0, 26559, 0, -26967, 0, 26560, 0, -26966, 0, 26562, 0, -26965, 0, 26565, 0, -26964, 0, 26566, 0, -26963, 0, 26567, 0, -26962, 0, 26568, 0, -26961, 0, 26569, 0, -26960, 0, 26570, 0, -26959, 0, 26571, 0, -26958, 0, 26572, 0, -26957, 0, 26573, 0, -26956, 0, 26574, 0, -26955, 0, 26581, 0, -26954, 0, 26582, 0, -26953, 0, 26583, 0, -26952, 0, 26587, 0, -26951, 0, 26591, 0, -26950, 0, 26593, 0, -26949, 0, 26595, 0, -26948, 0, 26596, 0, -26947, 0, 26598, 0, -26946, 0, 26599, 0, -26945, 0, 26600, 0, -26944, 0, 26602, 0, -26943, 0, 26603, 0, -26942, 0, 26605, 0, -26941, 0, 26606, 0, -26940, 0, 26610, 0, -26939, 0, 26613, 0, -26938, 0, 26614, 0, -26937, 0, 26615, 0, -26936, 0, 26616, 0, -26935, 0, 26617, 0, -26934, 0, 26618, 0, -26933, 0, 26619, 0, -26932, 0, 26620, 0, -26931, 0, 26622, 0, -26930, 0, 26625, 0, -26929, 0, 26626, 0, -26928, 0, 26627, 0, -26927, 0, 26628, 0, -26926, 0, 26630, 0, -26925, 0, 26637, 0, -26924, 0, 26640, 0, -26923, 0, 26642, 0, -26922, 0, 26644, 0, -26921, 0, 26645, 0, -26920, 0, 26648, 0, -26919, 0, 26649, 0, -26918, 0, 26650, 0, -26917, 0, 26651, 0, -26916, 0, 26652, 0, -26915, 0, 26654, 0, -26914, 0, 26655, 0, -26913, 0, 26656, 0, -26912, 0, 26658, 0, -26911, 0, 26659, 0, -26910, 0, 26660, 0, -26909, 0, 26661, 0, -26908, 0, 26662, 0, -26907, 0, 26663, 0, -26906, 0, 26664, 0, -26905, 0, 26667, 0, -26904, 0, 26668, 0, -26903, 0, 26669, 0, -26902, 0, 26670, 0, -26901, 0, 26671, 0, -26900, 0, 26672, 0, -26899, 0, 26673, 0, -26898, 0, 26676, 0, -26897, 0, 26677, 0, -26896, 0, 26678, 0, -26895, 0, 26682, 0, -26894, 0, 26683, 0, -26893, 0, 26687, 0, -26892, 0, 26695, 0, -26891, 0, 26699, 0, -26890, 0, 26701, 0, -26889, 0, 26703, 0, -26888, 0, 26706, 0, -26887, 0, 26710, 0, -26886, 0, 26711, 0, -26885, 0, 26712, 0, -26884, 0, 26713, 0, -26883, 0, 26714, 0, -26882, 0, 26715, 0, -26816, 0, 26716, 0, -26815, 0, 26717, 0, -26814, 0, 26718, 0, -26813, 0, 26719, 0, -26812, 0, 26730, 0, -26811, 0, 26732, 0, -26810, 0, 26733, 0, -26809, 0, 26734, 0, -26808, 0, 26735, 0, -26807, 0, 26736, 0, -26806, 0, 26737, 0, -26805, 0, 26738, 0, -26804, 0, 26739, 0, -26803, 0, 26741, 0, -26802, 0, 26744, 0, -26801, 0, 26745, 0, -26800, 0, 26746, 0, -26799, 0, 26747, 0, -26798, 0, 26748, 0, -26797, 0, 26749, 0, -26796, 0, 26750, 0, -26795, 0, 26751, 0, -26794, 0, 26752, 0, -26793, 0, 26754, 0, -26792, 0, 26756, 0, -26791, 0, 26759, 0, -26790, 0, 26760, 0, -26789, 0, 26761, 0, -26788, 0, 26762, 0, -26787, 0, 26763, 0, -26786, 0, 26764, 0, -26785, 0, 26765, 0, -26784, 0, 26766, 0, -26783, 0, 26768, 0, -26782, 0, 26769, 0, -26781, 0, 26770, 0, -26780, 0, 26772, 0, -26779, 0, 26773, 0, -26778, 0, 26774, 0, -26777, 0, 26776, 0, -26776, 0, 26777, 0, -26775, 0, 26778, 0, -26774, 0, 26779, 0, -26773, 0, 26780, 0, -26772, 0, 26781, 0, -26771, 0, 26782, 0, -26770, 0, 26783, 0, -26769, 0, 26784, 0, -26768, 0, 26785, 0, -26767, 0, 26787, 0, -26766, 0, 26788, 0, -26765, 0, 26789, 0, -26764, 0, 26793, 0, -26763, 0, 26794, 0, -26762, 0, 26795, 0, -26761, 0, 26796, 0, -26760, 0, 26798, 0, -26759, 0, 26801, 0, -26758, 0, 26802, 0, -26757, 0, 26804, 0, -26756, 0, 26806, 0, -26755, 0, 26807, 0, -26754, 0, 26808, 0, -26752, 0, 26809, 0, -26751, 0, 26810, 0, -26750, 0, 26811, 0, -26749, 0, 26812, 0, -26748, 0, 26813, 0, -26747, 0, 26814, 0, -26746, 0, 26815, 0, -26745, 0, 26817, 0, -26744, 0, 26819, 0, -26743, 0, 26820, 0, -26742, 0, 26821, 0, -26741, 0, 26822, 0, -26740, 0, 26823, 0, -26739, 0, 26824, 0, -26738, 0, 26826, 0, -26737, 0, 26828, 0, -26736, 0, 26830, 0, -26735, 0, 26831, 0, -26734, 0, 26832, 0, -26733, 0, 26833, 0, -26732, 0, 26835, 0, -26731, 0, 26836, 0, -26730, 0, 26838, 0, -26729, 0, 26839, 0, -26728, 0, 26841, 0, -26727, 0, 26843, 0, -26726, 0, 26844, 0, -26725, 0, 26845, 0, -26724, 0, 26846, 0, -26723, 0, 26847, 0, -26722, 0, 26849, 0, -26721, 0, 26850, 0, -26720, 0, 26852, 0, -26719, 0, 26853, 0, -26718, 0, 26854, 0, -26717, 0, 26855, 0, -26716, 0, 26856, 0, -26715, 0, 26857, 0, -26714, 0, 26858, 0, -26713, 0, 26859, 0, -26712, 0, 26860, 0, -26711, 0, 26861, 0, -26710, 0, 26863, 0, -26709, 0, 26866, 0, -26708, 0, 26867, 0, -26707, 0, 26868, 0, -26706, 0, 26870, 0, -26705, 0, 26871, 0, -26704, 0, 26872, 0, -26703, 0, 26875, 0, -26702, 0, 26877, 0, -26701, 0, 26878, 0, -26700, 0, 26879, 0, -26699, 0, 26880, 0, -26698, 0, 26882, 0, -26697, 0, 26883, 0, -26696, 0, 26884, 0, -26695, 0, 26886, 0, -26694, 0, 26887, 0, -26693, 0, 26888, 0, -26692, 0, 26889, 0, -26691, 0, 26890, 0, -26690, 0, 26892, 0, -26689, 0, 26895, 0, -26688, 0, 26897, 0, -26687, 0, 26899, 0, -26686, 0, 26900, 0, -26685, 0, 26901, 0, -26684, 0, 26902, 0, -26683, 0, 26903, 0, -26682, 0, 26904, 0, -26681, 0, 26905, 0, -26680, 0, 26906, 0, -26679, 0, 26907, 0, -26678, 0, 26908, 0, -26677, 0, 26909, 0, -26676, 0, 26910, 0, -26675, 0, 26913, 0, -26674, 0, 26914, 0, -26673, 0, 26915, 0, -26672, 0, 26917, 0, -26671, 0, 26918, 0, -26670, 0, 26919, 0, -26669, 0, 26920, 0, -26668, 0, 26921, 0, -26667, 0, 26922, 0, -26666, 0, 26923, 0, -26665, 0, 26924, 0, -26664, 0, 26926, 0, -26663, 0, 26927, 0, -26662, 0, 26929, 0, -26661, 0, 26930, 0, -26660, 0, 26931, 0, -26659, 0, 26933, 0, -26658, 0, 26934, 0, -26657, 0, 26935, 0, -26656, 0, 26936, 0, -26655, 0, 26938, 0, -26654, 0, 26939, 0, -26653, 0, 26940, 0, -26652, 0, 26942, 0, -26651, 0, 26944, 0, -26650, 0, 26945, 0, -26649, 0, 26947, 0, -26648, 0, 26948, 0, -26647, 0, 26949, 0, -26646, 0, 26950, 0, -26645, 0, 26951, 0, -26644, 0, 26952, 0, -26643, 0, 26953, 0, -26642, 0, 26954, 0, -26641, 0, 26955, 0, -26640, 0, 26956, 0, -26639, 0, 26957, 0, -26638, 0, 26958, 0, -26637, 0, 26959, 0, -26636, 0, 26960, 0, -26635, 0, 26961, 0, -26634, 0, 26962, 0, -26633, 0, 26963, 0, -26632, 0, 26965, 0, -26631, 0, 26966, 0, -26630, 0, 26968, 0, -26629, 0, 26969, 0, -26628, 0, 26971, 0, -26627, 0, 26972, 0, -26626, 0, 26975, 0, -26560, 0, 26977, 0, -26559, 0, 26978, 0, -26558, 0, 26980, 0, -26557, 0, 26981, 0, -26556, 0, 26983, 0, -26555, 0, 26984, 0, -26554, 0, 26985, 0, -26553, 0, 26986, 0, -26552, 0, 26988, 0, -26551, 0, 26989, 0, -26550, 0, 26991, 0, -26549, 0, 26992, 0, -26548, 0, 26994, 0, -26547, 0, 26995, 0, -26546, 0, 26996, 0, -26545, 0, 26997, 0, -26544, 0, 26998, 0, -26543, 0, 27002, 0, -26542, 0, 27003, 0, -26541, 0, 27005, 0, -26540, 0, 27006, 0, -26539, 0, 27007, 0, -26538, 0, 27009, 0, -26537, 0, 27011, 0, -26536, 0, 27013, 0, -26535, 0, 27018, 0, -26534, 0, 27019, 0, -26533, 0, 27020, 0, -26532, 0, 27022, 0, -26531, 0, 27023, 0, -26530, 0, 27024, 0, -26529, 0, 27025, 0, -26528, 0, 27026, 0, -26527, 0, 27027, 0, -26526, 0, 27030, 0, -26525, 0, 27031, 0, -26524, 0, 27033, 0, -26523, 0, 27034, 0, -26522, 0, 27037, 0, -26521, 0, 27038, 0, -26520, 0, 27039, 0, -26519, 0, 27040, 0, -26518, 0, 27041, 0, -26517, 0, 27042, 0, -26516, 0, 27043, 0, -26515, 0, 27044, 0, -26514, 0, 27045, 0, -26513, 0, 27046, 0, -26512, 0, 27049, 0, -26511, 0, 27050, 0, -26510, 0, 27052, 0, -26509, 0, 27054, 0, -26508, 0, 27055, 0, -26507, 0, 27056, 0, -26506, 0, 27058, 0, -26505, 0, 27059, 0, -26504, 0, 27061, 0, -26503, 0, 27062, 0, -26502, 0, 27064, 0, -26501, 0, 27065, 0, -26500, 0, 27066, 0, -26499, 0, 27068, 0, -26498, 0, 27069, 0, -26496, 0, 27070, 0, -26495, 0, 27071, 0, -26494, 0, 27072, 0, -26493, 0, 27074, 0, -26492, 0, 27075, 0, -26491, 0, 27076, 0, -26490, 0, 27077, 0, -26489, 0, 27078, 0, -26488, 0, 27079, 0, -26487, 0, 27080, 0, -26486, 0, 27081, 0, -26485, 0, 27083, 0, -26484, 0, 27085, 0, -26483, 0, 27087, 0, -26482, 0, 27089, 0, -26481, 0, 27090, 0, -26480, 0, 27091, 0, -26479, 0, 27093, 0, -26478, 0, 27094, 0, -26477, 0, 27095, 0, -26476, 0, 27096, 0, -26475, 0, 27097, 0, -26474, 0, 27098, 0, -26473, 0, 27100, 0, -26472, 0, 27101, 0, -26471, 0, 27102, 0, -26470, 0, 27105, 0, -26469, 0, 27106, 0, -26468, 0, 27107, 0, -26467, 0, 27108, 0, -26466, 0, 27109, 0, -26465, 0, 27110, 0, -26464, 0, 27111, 0, -26463, 0, 27112, 0, -26462, 0, 27113, 0, -26461, 0, 27114, 0, -26460, 0, 27115, 0, -26459, 0, 27116, 0, -26458, 0, 27118, 0, -26457, 0, 27119, 0, -26456, 0, 27120, 0, -26455, 0, 27121, 0, -26454, 0, 27123, 0, -26453, 0, 27124, 0, -26452, 0, 27125, 0, -26451, 0, 27126, 0, -26450, 0, 27127, 0, -26449, 0, 27128, 0, -26448, 0, 27129, 0, -26447, 0, 27130, 0, -26446, 0, 27131, 0, -26445, 0, 27132, 0, -26444, 0, 27134, 0, -26443, 0, 27136, 0, -26442, 0, 27137, 0, -26441, 0, 27138, 0, -26440, 0, 27139, 0, -26439, 0, 27140, 0, -26438, 0, 27141, 0, -26437, 0, 27142, 0, -26436, 0, 27143, 0, -26435, 0, 27144, 0, -26434, 0, 27145, 0, -26433, 0, 27147, 0, -26432, 0, 27148, 0, -26431, 0, 27149, 0, -26430, 0, 27150, 0, -26429, 0, 27151, 0, -26428, 0, 27152, 0, -26427, 0, 27153, 0, -26426, 0, 27154, 0, -26425, 0, 27155, 0, -26424, 0, 27156, 0, -26423, 0, 27157, 0, -26422, 0, 27158, 0, -26421, 0, 27161, 0, -26420, 0, 27162, 0, -26419, 0, 27163, 0, -26418, 0, 27164, 0, -26417, 0, 27165, 0, -26416, 0, 27166, 0, -26415, 0, 27168, 0, -26414, 0, 27170, 0, -26413, 0, 27171, 0, -26412, 0, 27172, 0, -26411, 0, 27173, 0, -26410, 0, 27174, 0, -26409, 0, 27175, 0, -26408, 0, 27177, 0, -26407, 0, 27179, 0, -26406, 0, 27180, 0, -26405, 0, 27181, 0, -26404, 0, 27182, 0, -26403, 0, 27184, 0, -26402, 0, 27186, 0, -26401, 0, 27187, 0, -26400, 0, 27188, 0, -26399, 0, 27190, 0, -26398, 0, 27191, 0, -26397, 0, 27192, 0, -26396, 0, 27193, 0, -26395, 0, 27194, 0, -26394, 0, 27195, 0, -26393, 0, 27196, 0, -26392, 0, 27199, 0, -26391, 0, 27200, 0, -26390, 0, 27201, 0, -26389, 0, 27202, 0, -26388, 0, 27203, 0, -26387, 0, 27205, 0, -26386, 0, 27206, 0, -26385, 0, 27208, 0, -26384, 0, 27209, 0, -26383, 0, 27210, 0, -26382, 0, 27211, 0, -26381, 0, 27212, 0, -26380, 0, 27213, 0, -26379, 0, 27214, 0, -26378, 0, 27215, 0, -26377, 0, 27217, 0, -26376, 0, 27218, 0, -26375, 0, 27219, 0, -26374, 0, 27220, 0, -26373, 0, 27221, 0, -26372, 0, 27222, 0, -26371, 0, 27223, 0, -26370, 0, 27226, 0, -26304, 0, 27228, 0, -26303, 0, 27229, 0, -26302, 0, 27230, 0, -26301, 0, 27231, 0, -26300, 0, 27232, 0, -26299, 0, 27234, 0, -26298, 0, 27235, 0, -26297, 0, 27236, 0, -26296, 0, 27238, 0, -26295, 0, 27239, 0, -26294, 0, 27240, 0, -26293, 0, 27241, 0, -26292, 0, 27242, 0, -26291, 0, 27243, 0, -26290, 0, 27244, 0, -26289, 0, 27245, 0, -26288, 0, 27246, 0, -26287, 0, 27247, 0, -26286, 0, 27248, 0, -26285, 0, 27250, 0, -26284, 0, 27251, 0, -26283, 0, 27252, 0, -26282, 0, 27253, 0, -26281, 0, 27254, 0, -26280, 0, 27255, 0, -26279, 0, 27256, 0, -26278, 0, 27258, 0, -26277, 0, 27259, 0, -26276, 0, 27261, 0, -26275, 0, 27262, 0, -26274, 0, 27263, 0, -26273, 0, 27265, 0, -26272, 0, 27266, 0, -26271, 0, 27267, 0, -26270, 0, 27269, 0, -26269, 0, 27270, 0, -26268, 0, 27271, 0, -26267, 0, 27272, 0, -26266, 0, 27273, 0, -26265, 0, 27274, 0, -26264, 0, 27275, 0, -26263, 0, 27276, 0, -26262, 0, 27277, 0, -26261, 0, 27279, 0, -26260, 0, 27282, 0, -26259, 0, 27283, 0, -26258, 0, 27284, 0, -26257, 0, 27285, 0, -26256, 0, 27286, 0, -26255, 0, 27288, 0, -26254, 0, 27289, 0, -26253, 0, 27290, 0, -26252, 0, 27291, 0, -26251, 0, 27292, 0, -26250, 0, 27293, 0, -26249, 0, 27294, 0, -26248, 0, 27295, 0, -26247, 0, 27297, 0, -26246, 0, 27298, 0, -26245, 0, 27299, 0, -26244, 0, 27300, 0, -26243, 0, 27301, 0, -26242, 0, 27302, 0, -26240, 0, 27303, 0, -26239, 0, 27304, 0, -26238, 0, 27306, 0, -26237, 0, 27309, 0, -26236, 0, 27310, 0, -26235, 0, 27311, 0, -26234, 0, 27312, 0, -26233, 0, 27313, 0, -26232, 0, 27314, 0, -26231, 0, 27315, 0, -26230, 0, 27316, 0, -26229, 0, 27317, 0, -26228, 0, 27318, 0, -26227, 0, 27319, 0, -26226, 0, 27320, 0, -26225, 0, 27321, 0, -26224, 0, 27322, 0, -26223, 0, 27323, 0, -26222, 0, 27324, 0, -26221, 0, 27325, 0, -26220, 0, 27326, 0, -26219, 0, 27327, 0, -26218, 0, 27328, 0, -26217, 0, 27329, 0, -26216, 0, 27330, 0, -26215, 0, 27331, 0, -26214, 0, 27332, 0, -26213, 0, 27333, 0, -26212, 0, 27334, 0, -26211, 0, 27335, 0, -26210, 0, 27336, 0, -26209, 0, 27337, 0, -26208, 0, 27338, 0, -26207, 0, 27339, 0, -26206, 0, 27340, 0, -26205, 0, 27341, 0, -26204, 0, 27342, 0, -26203, 0, 27343, 0, -26202, 0, 27344, 0, -26201, 0, 27345, 0, -26200, 0, 27346, 0, -26199, 0, 27347, 0, -26198, 0, 27348, 0, -26197, 0, 27349, 0, -26196, 0, 27350, 0, -26195, 0, 27351, 0, -26194, 0, 27352, 0, -26193, 0, 27353, 0, -26192, 0, 27354, 0, -26191, 0, 27355, 0, -26190, 0, 27356, 0, -26189, 0, 27357, 0, -26188, 0, 27358, 0, -26187, 0, 27359, 0, -26186, 0, 27360, 0, -26185, 0, 27361, 0, -26184, 0, 27362, 0, -26183, 0, 27363, 0, -26182, 0, 27364, 0, -26181, 0, 27365, 0, -26180, 0, 27366, 0, -26179, 0, 27367, 0, -26178, 0, 27368, 0, -26177, 0, 27369, 0, -26176, 0, 27370, 0, -26175, 0, 27371, 0, -26174, 0, 27372, 0, -26173, 0, 27373, 0, -26172, 0, 27374, 0, -26171, 0, 27375, 0, -26170, 0, 27376, 0, -26169, 0, 27377, 0, -26168, 0, 27378, 0, -26167, 0, 27379, 0, -26166, 0, 27380, 0, -26165, 0, 27381, 0, -26164, 0, 27382, 0, -26163, 0, 27383, 0, -26162, 0, 27384, 0, -26161, 0, 27385, 0, -26160, 0, 27386, 0, -26159, 0, 27387, 0, -26158, 0, 27388, 0, -26157, 0, 27389, 0, -26156, 0, 27390, 0, -26155, 0, 27391, 0, -26154, 0, 27392, 0, -26153, 0, 27393, 0, -26152, 0, 27394, 0, -26151, 0, 27395, 0, -26150, 0, 27396, 0, -26149, 0, 27397, 0, -26148, 0, 27398, 0, -26147, 0, 27399, 0, -26146, 0, 27400, 0, -26145, 0, 27401, 0, -26144, 0, 27402, 0, -26143, 0, 27403, 0, -26142, 0, 27404, 0, -26141, 0, 27405, 0, -26140, 0, 27406, 0, -26139, 0, 27407, 0, -26138, 0, 27408, 0, -26137, 0, 27409, 0, -26136, 0, 27410, 0, -26135, 0, 27411, 0, -26134, 0, 27412, 0, -26133, 0, 27413, 0, -26132, 0, 27414, 0, -26131, 0, 27415, 0, -26130, 0, 27416, 0, -26129, 0, 27417, 0, -26128, 0, 27418, 0, -26127, 0, 27419, 0, -26126, 0, 27420, 0, -26125, 0, 27421, 0, -26124, 0, 27422, 0, -26123, 0, 27423, 0, -26122, 0, 27429, 0, -26121, 0, 27430, 0, -26120, 0, 27432, 0, -26119, 0, 27433, 0, -26118, 0, 27434, 0, -26117, 0, 27435, 0, -26116, 0, 27436, 0, -26115, 0, 27437, 0, -26114, 0, 27438, 0, -26048, 0, 27439, 0, -26047, 0, 27440, 0, -26046, 0, 27441, 0, -26045, 0, 27443, 0, -26044, 0, 27444, 0, -26043, 0, 27445, 0, -26042, 0, 27446, 0, -26041, 0, 27448, 0, -26040, 0, 27451, 0, -26039, 0, 27452, 0, -26038, 0, 27453, 0, -26037, 0, 27455, 0, -26036, 0, 27456, 0, -26035, 0, 27457, 0, -26034, 0, 27458, 0, -26033, 0, 27460, 0, -26032, 0, 27461, 0, -26031, 0, 27464, 0, -26030, 0, 27466, 0, -26029, 0, 27467, 0, -26028, 0, 27469, 0, -26027, 0, 27470, 0, -26026, 0, 27471, 0, -26025, 0, 27472, 0, -26024, 0, 27473, 0, -26023, 0, 27474, 0, -26022, 0, 27475, 0, -26021, 0, 27476, 0, -26020, 0, 27477, 0, -26019, 0, 27478, 0, -26018, 0, 27479, 0, -26017, 0, 27480, 0, -26016, 0, 27482, 0, -26015, 0, 27483, 0, -26014, 0, 27484, 0, -26013, 0, 27485, 0, -26012, 0, 27486, 0, -26011, 0, 27487, 0, -26010, 0, 27488, 0, -26009, 0, 27489, 0, -26008, 0, 27496, 0, -26007, 0, 27497, 0, -26006, 0, 27499, 0, -26005, 0, 27500, 0, -26004, 0, 27501, 0, -26003, 0, 27502, 0, -26002, 0, 27503, 0, -26001, 0, 27504, 0, -26000, 0, 27505, 0, -25999, 0, 27506, 0, -25998, 0, 27507, 0, -25997, 0, 27508, 0, -25996, 0, 27509, 0, -25995, 0, 27510, 0, -25994, 0, 27511, 0, -25993, 0, 27512, 0, -25992, 0, 27514, 0, -25991, 0, 27517, 0, -25990, 0, 27518, 0, -25989, 0, 27519, 0, -25988, 0, 27520, 0, -25987, 0, 27525, 0, -25986, 0, 27528, 0, -25984, 0, 27532, 0, -25983, 0, 27534, 0, -25982, 0, 27535, 0, -25981, 0, 27536, 0, -25980, 0, 27537, 0, -25979, 0, 27540, 0, -25978, 0, 27541, 0, -25977, 0, 27543, 0, -25976, 0, 27544, 0, -25975, 0, 27545, 0, -25974, 0, 27548, 0, -25973, 0, 27549, 0, -25972, 0, 27550, 0, -25971, 0, 27551, 0, -25970, 0, 27552, 0, -25969, 0, 27554, 0, -25968, 0, 27555, 0, -25967, 0, 27556, 0, -25966, 0, 27557, 0, -25965, 0, 27558, 0, -25964, 0, 27559, 0, -25963, 0, 27560, 0, -25962, 0, 27561, 0, -25961, 0, 27563, 0, -25960, 0, 27564, 0, -25959, 0, 27565, 0, -25958, 0, 27566, 0, -25957, 0, 27567, 0, -25956, 0, 27568, 0, -25955, 0, 27569, 0, -25954, 0, 27570, 0, -25953, 0, 27574, 0, -25952, 0, 27576, 0, -25951, 0, 27577, 0, -25950, 0, 27578, 0, -25949, 0, 27579, 0, -25948, 0, 27580, 0, -25947, 0, 27581, 0, -25946, 0, 27582, 0, -25945, 0, 27584, 0, -25944, 0, 27587, 0, -25943, 0, 27588, 0, -25942, 0, 27590, 0, -25941, 0, 27591, 0, -25940, 0, 27592, 0, -25939, 0, 27593, 0, -25938, 0, 27594, 0, -25937, 0, 27596, 0, -25936, 0, 27598, 0, -25935, 0, 27600, 0, -25934, 0, 27601, 0, -25933, 0, 27608, 0, -25932, 0, 27610, 0, -25931, 0, 27612, 0, -25930, 0, 27613, 0, -25929, 0, 27614, 0, -25928, 0, 27615, 0, -25927, 0, 27616, 0, -25926, 0, 27618, 0, -25925, 0, 27619, 0, -25924, 0, 27620, 0, -25923, 0, 27621, 0, -25922, 0, 27622, 0, -25921, 0, 27623, 0, -25920, 0, 27624, 0, -25919, 0, 27625, 0, -25918, 0, 27628, 0, -25917, 0, 27629, 0, -25916, 0, 27630, 0, -25915, 0, 27632, 0, -25914, 0, 27633, 0, -25913, 0, 27634, 0, -25912, 0, 27636, 0, -25911, 0, 27638, 0, -25910, 0, 27639, 0, -25909, 0, 27640, 0, -25908, 0, 27642, 0, -25907, 0, 27643, 0, -25906, 0, 27644, 0, -25905, 0, 27646, 0, -25904, 0, 27647, 0, -25903, 0, 27648, 0, -25902, 0, 27649, 0, -25901, 0, 27650, 0, -25900, 0, 27651, 0, -25899, 0, 27652, 0, -25898, 0, 27656, 0, -25897, 0, 27657, 0, -25896, 0, 27658, 0, -25895, 0, 27659, 0, -25894, 0, 27660, 0, -25893, 0, 27662, 0, -25892, 0, 27666, 0, -25891, 0, 27671, 0, -25890, 0, 27676, 0, -25889, 0, 27677, 0, -25888, 0, 27678, 0, -25887, 0, 27680, 0, -25886, 0, 27683, 0, -25885, 0, 27685, 0, -25884, 0, 27691, 0, -25883, 0, 27692, 0, -25882, 0, 27693, 0, -25881, 0, 27697, 0, -25880, 0, 27699, 0, -25879, 0, 27702, 0, -25878, 0, 27703, 0, -25877, 0, 27705, 0, -25876, 0, 27706, 0, -25875, 0, 27707, 0, -25874, 0, 27708, 0, -25873, 0, 27710, 0, -25872, 0, 27711, 0, -25871, 0, 27715, 0, -25870, 0, 27716, 0, -25869, 0, 27717, 0, -25868, 0, 27720, 0, -25867, 0, 27723, 0, -25866, 0, 27724, 0, -25865, 0, 27725, 0, -25864, 0, 27726, 0, -25863, 0, 27727, 0, -25862, 0, 27729, 0, -25861, 0, 27730, 0, -25860, 0, 27731, 0, -25859, 0, 27734, 0, -25858, 0, 27736, 0, -25792, 0, 27737, 0, -25791, 0, 27738, 0, -25790, 0, 27746, 0, -25789, 0, 27747, 0, -25788, 0, 27749, 0, -25787, 0, 27750, 0, -25786, 0, 27751, 0, -25785, 0, 27755, 0, -25784, 0, 27756, 0, -25783, 0, 27757, 0, -25782, 0, 27758, 0, -25781, 0, 27759, 0, -25780, 0, 27761, 0, -25779, 0, 27763, 0, -25778, 0, 27765, 0, -25777, 0, 27767, 0, -25776, 0, 27768, 0, -25775, 0, 27770, 0, -25774, 0, 27771, 0, -25773, 0, 27772, 0, -25772, 0, 27775, 0, -25771, 0, 27776, 0, -25770, 0, 27780, 0, -25769, 0, 27783, 0, -25768, 0, 27786, 0, -25767, 0, 27787, 0, -25766, 0, 27789, 0, -25765, 0, 27790, 0, -25764, 0, 27793, 0, -25763, 0, 27794, 0, -25762, 0, 27797, 0, -25761, 0, 27798, 0, -25760, 0, 27799, 0, -25759, 0, 27800, 0, -25758, 0, 27802, 0, -25757, 0, 27804, 0, -25756, 0, 27805, 0, -25755, 0, 27806, 0, -25754, 0, 27808, 0, -25753, 0, 27810, 0, -25752, 0, 27816, 0, -25751, 0, 27820, 0, -25750, 0, 27823, 0, -25749, 0, 27824, 0, -25748, 0, 27828, 0, -25747, 0, 27829, 0, -25746, 0, 27830, 0, -25745, 0, 27831, 0, -25744, 0, 27834, 0, -25743, 0, 27840, 0, -25742, 0, 27841, 0, -25741, 0, 27842, 0, -25740, 0, 27843, 0, -25739, 0, 27846, 0, -25738, 0, 27847, 0, -25737, 0, 27848, 0, -25736, 0, 27851, 0, -25735, 0, 27853, 0, -25734, 0, 27854, 0, -25733, 0, 27855, 0, -25732, 0, 27857, 0, -25731, 0, 27858, 0, -25730, 0, 27864, 0, -25728, 0, 27865, 0, -25727, 0, 27866, 0, -25726, 0, 27868, 0, -25725, 0, 27869, 0, -25724, 0, 27871, 0, -25723, 0, 27876, 0, -25722, 0, 27878, 0, -25721, 0, 27879, 0, -25720, 0, 27881, 0, -25719, 0, 27884, 0, -25718, 0, 27885, 0, -25717, 0, 27890, 0, -25716, 0, 27892, 0, -25715, 0, 27897, 0, -25714, 0, 27903, 0, -25713, 0, 27904, 0, -25712, 0, 27906, 0, -25711, 0, 27907, 0, -25710, 0, 27909, 0, -25709, 0, 27910, 0, -25708, 0, 27912, 0, -25707, 0, 27913, 0, -25706, 0, 27914, 0, -25705, 0, 27917, 0, -25704, 0, 27919, 0, -25703, 0, 27920, 0, -25702, 0, 27921, 0, -25701, 0, 27923, 0, -25700, 0, 27924, 0, -25699, 0, 27925, 0, -25698, 0, 27926, 0, -25697, 0, 27928, 0, -25696, 0, 27932, 0, -25695, 0, 27933, 0, -25694, 0, 27935, 0, -25693, 0, 27936, 0, -25692, 0, 27937, 0, -25691, 0, 27938, 0, -25690, 0, 27939, 0, -25689, 0, 27940, 0, -25688, 0, 27942, 0, -25687, 0, 27944, 0, -25686, 0, 27945, 0, -25685, 0, 27948, 0, -25684, 0, 27949, 0, -25683, 0, 27951, 0, -25682, 0, 27952, 0, -25681, 0, 27956, 0, -25680, 0, 27958, 0, -25679, 0, 27959, 0, -25678, 0, 27960, 0, -25677, 0, 27962, 0, -25676, 0, 27967, 0, -25675, 0, 27968, 0, -25674, 0, 27970, 0, -25673, 0, 27972, 0, -25672, 0, 27977, 0, -25671, 0, 27980, 0, -25670, 0, 27984, 0, -25669, 0, 27989, 0, -25668, 0, 27990, 0, -25667, 0, 27991, 0, -25666, 0, 27992, 0, -25665, 0, 27995, 0, -25664, 0, 27997, 0, -25663, 0, 27999, 0, -25662, 0, 28001, 0, -25661, 0, 28002, 0, -25660, 0, 28004, 0, -25659, 0, 28005, 0, -25658, 0, 28007, 0, -25657, 0, 28008, 0, -25656, 0, 28011, 0, -25655, 0, 28012, 0, -25654, 0, 28013, 0, -25653, 0, 28016, 0, -25652, 0, 28017, 0, -25651, 0, 28018, 0, -25650, 0, 28019, 0, -25649, 0, 28021, 0, -25648, 0, 28022, 0, -25647, 0, 28025, 0, -25646, 0, 28026, 0, -25645, 0, 28027, 0, -25644, 0, 28029, 0, -25643, 0, 28030, 0, -25642, 0, 28031, 0, -25641, 0, 28032, 0, -25640, 0, 28033, 0, -25639, 0, 28035, 0, -25638, 0, 28036, 0, -25637, 0, 28038, 0, -25636, 0, 28039, 0, -25635, 0, 28042, 0, -25634, 0, 28043, 0, -25633, 0, 28045, 0, -25632, 0, 28047, 0, -25631, 0, 28048, 0, -25630, 0, 28050, 0, -25629, 0, 28054, 0, -25628, 0, 28055, 0, -25627, 0, 28056, 0, -25626, 0, 28057, 0, -25625, 0, 28058, 0, -25624, 0, 28060, 0, -25623, 0, 28066, 0, -25622, 0, 28069, 0, -25621, 0, 28076, 0, -25620, 0, 28077, 0, -25619, 0, 28080, 0, -25618, 0, 28081, 0, -25617, 0, 28083, 0, -25616, 0, 28084, 0, -25615, 0, 28086, 0, -25614, 0, 28087, 0, -25613, 0, 28089, 0, -25612, 0, 28090, 0, -25611, 0, 28091, 0, -25610, 0, 28092, 0, -25609, 0, 28093, 0, -25608, 0, 28094, 0, -25607, 0, 28097, 0, -25606, 0, 28098, 0, -25605, 0, 28099, 0, -25604, 0, 28104, 0, -25603, 0, 28105, 0, -25602, 0, 28106, 0, -25536, 0, 28109, 0, -25535, 0, 28110, 0, -25534, 0, 28111, 0, -25533, 0, 28112, 0, -25532, 0, 28114, 0, -25531, 0, 28115, 0, -25530, 0, 28116, 0, -25529, 0, 28117, 0, -25528, 0, 28119, 0, -25527, 0, 28122, 0, -25526, 0, 28123, 0, -25525, 0, 28124, 0, -25524, 0, 28127, 0, -25523, 0, 28130, 0, -25522, 0, 28131, 0, -25521, 0, 28133, 0, -25520, 0, 28135, 0, -25519, 0, 28136, 0, -25518, 0, 28137, 0, -25517, 0, 28138, 0, -25516, 0, 28141, 0, -25515, 0, 28143, 0, -25514, 0, 28144, 0, -25513, 0, 28146, 0, -25512, 0, 28148, 0, -25511, 0, 28149, 0, -25510, 0, 28150, 0, -25509, 0, 28152, 0, -25508, 0, 28154, 0, -25507, 0, 28157, 0, -25506, 0, 28158, 0, -25505, 0, 28159, 0, -25504, 0, 28160, 0, -25503, 0, 28161, 0, -25502, 0, 28162, 0, -25501, 0, 28163, 0, -25500, 0, 28164, 0, -25499, 0, 28166, 0, -25498, 0, 28167, 0, -25497, 0, 28168, 0, -25496, 0, 28169, 0, -25495, 0, 28171, 0, -25494, 0, 28175, 0, -25493, 0, 28178, 0, -25492, 0, 28179, 0, -25491, 0, 28181, 0, -25490, 0, 28184, 0, -25489, 0, 28185, 0, -25488, 0, 28187, 0, -25487, 0, 28188, 0, -25486, 0, 28190, 0, -25485, 0, 28191, 0, -25484, 0, 28194, 0, -25483, 0, 28198, 0, -25482, 0, 28199, 0, -25481, 0, 28200, 0, -25480, 0, 28202, 0, -25479, 0, 28204, 0, -25478, 0, 28206, 0, -25477, 0, 28208, 0, -25476, 0, 28209, 0, -25475, 0, 28211, 0, -25474, 0, 28213, 0, -25472, 0, 28214, 0, -25471, 0, 28215, 0, -25470, 0, 28217, 0, -25469, 0, 28219, 0, -25468, 0, 28220, 0, -25467, 0, 28221, 0, -25466, 0, 28222, 0, -25465, 0, 28223, 0, -25464, 0, 28224, 0, -25463, 0, 28225, 0, -25462, 0, 28226, 0, -25461, 0, 28229, 0, -25460, 0, 28230, 0, -25459, 0, 28231, 0, -25458, 0, 28232, 0, -25457, 0, 28233, 0, -25456, 0, 28234, 0, -25455, 0, 28235, 0, -25454, 0, 28236, 0, -25453, 0, 28239, 0, -25452, 0, 28240, 0, -25451, 0, 28241, 0, -25450, 0, 28242, 0, -25449, 0, 28245, 0, -25448, 0, 28247, 0, -25447, 0, 28249, 0, -25446, 0, 28250, 0, -25445, 0, 28252, 0, -25444, 0, 28253, 0, -25443, 0, 28254, 0, -25442, 0, 28256, 0, -25441, 0, 28257, 0, -25440, 0, 28258, 0, -25439, 0, 28259, 0, -25438, 0, 28260, 0, -25437, 0, 28261, 0, -25436, 0, 28262, 0, -25435, 0, 28263, 0, -25434, 0, 28264, 0, -25433, 0, 28265, 0, -25432, 0, 28266, 0, -25431, 0, 28268, 0, -25430, 0, 28269, 0, -25429, 0, 28271, 0, -25428, 0, 28272, 0, -25427, 0, 28273, 0, -25426, 0, 28274, 0, -25425, 0, 28275, 0, -25424, 0, 28276, 0, -25423, 0, 28277, 0, -25422, 0, 28278, 0, -25421, 0, 28279, 0, -25420, 0, 28280, 0, -25419, 0, 28281, 0, -25418, 0, 28282, 0, -25417, 0, 28283, 0, -25416, 0, 28284, 0, -25415, 0, 28285, 0, -25414, 0, 28288, 0, -25413, 0, 28289, 0, -25412, 0, 28290, 0, -25411, 0, 28292, 0, -25410, 0, 28295, 0, -25409, 0, 28296, 0, -25408, 0, 28298, 0, -25407, 0, 28299, 0, -25406, 0, 28300, 0, -25405, 0, 28301, 0, -25404, 0, 28302, 0, -25403, 0, 28305, 0, -25402, 0, 28306, 0, -25401, 0, 28307, 0, -25400, 0, 28308, 0, -25399, 0, 28309, 0, -25398, 0, 28310, 0, -25397, 0, 28311, 0, -25396, 0, 28313, 0, -25395, 0, 28314, 0, -25394, 0, 28315, 0, -25393, 0, 28317, 0, -25392, 0, 28318, 0, -25391, 0, 28320, 0, -25390, 0, 28321, 0, -25389, 0, 28323, 0, -25388, 0, 28324, 0, -25387, 0, 28326, 0, -25386, 0, 28328, 0, -25385, 0, 28329, 0, -25384, 0, 28331, 0, -25383, 0, 28332, 0, -25382, 0, 28333, 0, -25381, 0, 28334, 0, -25380, 0, 28336, 0, -25379, 0, 28339, 0, -25378, 0, 28341, 0, -25377, 0, 28344, 0, -25376, 0, 28345, 0, -25375, 0, 28348, 0, -25374, 0, 28350, 0, -25373, 0, 28351, 0, -25372, 0, 28352, 0, -25371, 0, 28355, 0, -25370, 0, 28356, 0, -25369, 0, 28357, 0, -25368, 0, 28358, 0, -25367, 0, 28360, 0, -25366, 0, 28361, 0, -25365, 0, 28362, 0, -25364, 0, 28364, 0, -25363, 0, 28365, 0, -25362, 0, 28366, 0, -25361, 0, 28368, 0, -25360, 0, 28370, 0, -25359, 0, 28374, 0, -25358, 0, 28376, 0, -25357, 0, 28377, 0, -25356, 0, 28379, 0, -25355, 0, 28380, 0, -25354, 0, 28381, 0, -25353, 0, 28387, 0, -25352, 0, 28391, 0, -25351, 0, 28394, 0, -25350, 0, 28395, 0, -25349, 0, 28396, 0, -25348, 0, 28397, 0, -25347, 0, 28398, 0, -25346, 0, 28399, 0, -25280, 0, 28400, 0, -25279, 0, 28401, 0, -25278, 0, 28402, 0, -25277, 0, 28403, 0, -25276, 0, 28405, 0, -25275, 0, 28406, 0, -25274, 0, 28407, 0, -25273, 0, 28408, 0, -25272, 0, 28410, 0, -25271, 0, 28411, 0, -25270, 0, 28412, 0, -25269, 0, 28413, 0, -25268, 0, 28414, 0, -25267, 0, 28415, 0, -25266, 0, 28416, 0, -25265, 0, 28417, 0, -25264, 0, 28419, 0, -25263, 0, 28420, 0, -25262, 0, 28421, 0, -25261, 0, 28423, 0, -25260, 0, 28424, 0, -25259, 0, 28426, 0, -25258, 0, 28427, 0, -25257, 0, 28428, 0, -25256, 0, 28429, 0, -25255, 0, 28430, 0, -25254, 0, 28432, 0, -25253, 0, 28433, 0, -25252, 0, 28434, 0, -25251, 0, 28438, 0, -25250, 0, 28439, 0, -25249, 0, 28440, 0, -25248, 0, 28441, 0, -25247, 0, 28442, 0, -25246, 0, 28443, 0, -25245, 0, 28444, 0, -25244, 0, 28445, 0, -25243, 0, 28446, 0, -25242, 0, 28447, 0, -25241, 0, 28449, 0, -25240, 0, 28450, 0, -25239, 0, 28451, 0, -25238, 0, 28453, 0, -25237, 0, 28454, 0, -25236, 0, 28455, 0, -25235, 0, 28456, 0, -25234, 0, 28460, 0, -25233, 0, 28462, 0, -25232, 0, 28464, 0, -25231, 0, 28466, 0, -25230, 0, 28468, 0, -25229, 0, 28469, 0, -25228, 0, 28471, 0, -25227, 0, 28472, 0, -25226, 0, 28473, 0, -25225, 0, 28474, 0, -25224, 0, 28475, 0, -25223, 0, 28476, 0, -25222, 0, 28477, 0, -25221, 0, 28479, 0, -25220, 0, 28480, 0, -25219, 0, 28481, 0, -25218, 0, 28482, 0, -25216, 0, 28483, 0, -25215, 0, 28484, 0, -25214, 0, 28485, 0, -25213, 0, 28488, 0, -25212, 0, 28489, 0, -25211, 0, 28490, 0, -25210, 0, 28492, 0, -25209, 0, 28494, 0, -25208, 0, 28495, 0, -25207, 0, 28496, 0, -25206, 0, 28497, 0, -25205, 0, 28498, 0, -25204, 0, 28499, 0, -25203, 0, 28500, 0, -25202, 0, 28501, 0, -25201, 0, 28502, 0, -25200, 0, 28503, 0, -25199, 0, 28505, 0, -25198, 0, 28506, 0, -25197, 0, 28507, 0, -25196, 0, 28509, 0, -25195, 0, 28511, 0, -25194, 0, 28512, 0, -25193, 0, 28513, 0, -25192, 0, 28515, 0, -25191, 0, 28516, 0, -25190, 0, 28517, 0, -25189, 0, 28519, 0, -25188, 0, 28520, 0, -25187, 0, 28521, 0, -25186, 0, 28522, 0, -25185, 0, 28523, 0, -25184, 0, 28524, 0, -25183, 0, 28527, 0, -25182, 0, 28528, 0, -25181, 0, 28529, 0, -25180, 0, 28531, 0, -25179, 0, 28533, 0, -25178, 0, 28534, 0, -25177, 0, 28535, 0, -25176, 0, 28537, 0, -25175, 0, 28539, 0, -25174, 0, 28541, 0, -25173, 0, 28542, 0, -25172, 0, 28543, 0, -25171, 0, 28544, 0, -25170, 0, 28545, 0, -25169, 0, 28546, 0, -25168, 0, 28547, 0, -25167, 0, 28549, 0, -25166, 0, 28550, 0, -25165, 0, 28551, 0, -25164, 0, 28554, 0, -25163, 0, 28555, 0, -25162, 0, 28559, 0, -25161, 0, 28560, 0, -25160, 0, 28561, 0, -25159, 0, 28562, 0, -25158, 0, 28563, 0, -25157, 0, 28564, 0, -25156, 0, 28565, 0, -25155, 0, 28566, 0, -25154, 0, 28567, 0, -25153, 0, 28568, 0, -25152, 0, 28569, 0, -25151, 0, 28570, 0, -25150, 0, 28571, 0, -25149, 0, 28573, 0, -25148, 0, 28574, 0, -25147, 0, 28575, 0, -25146, 0, 28576, 0, -25145, 0, 28578, 0, -25144, 0, 28579, 0, -25143, 0, 28580, 0, -25142, 0, 28581, 0, -25141, 0, 28582, 0, -25140, 0, 28584, 0, -25139, 0, 28585, 0, -25138, 0, 28586, 0, -25137, 0, 28587, 0, -25136, 0, 28588, 0, -25135, 0, 28589, 0, -25134, 0, 28590, 0, -25133, 0, 28591, 0, -25132, 0, 28592, 0, -25131, 0, 28593, 0, -25130, 0, 28594, 0, -25129, 0, 28596, 0, -25128, 0, 28597, 0, -25127, 0, 28599, 0, -25126, 0, 28600, 0, -25125, 0, 28602, 0, -25124, 0, 28603, 0, -25123, 0, 28604, 0, -25122, 0, 28605, 0, -25121, 0, 28606, 0, -25120, 0, 28607, 0, -25119, 0, 28609, 0, -25118, 0, 28611, 0, -25117, 0, 28612, 0, -25116, 0, 28613, 0, -25115, 0, 28614, 0, -25114, 0, 28615, 0, -25113, 0, 28616, 0, -25112, 0, 28618, 0, -25111, 0, 28619, 0, -25110, 0, 28620, 0, -25109, 0, 28621, 0, -25108, 0, 28622, 0, -25107, 0, 28623, 0, -25106, 0, 28624, 0, -25105, 0, 28627, 0, -25104, 0, 28628, 0, -25103, 0, 28629, 0, -25102, 0, 28630, 0, -25101, 0, 28631, 0, -25100, 0, 28632, 0, -25099, 0, 28633, 0, -25098, 0, 28634, 0, -25097, 0, 28635, 0, -25096, 0, 28636, 0, -25095, 0, 28637, 0, -25094, 0, 28639, 0, -25093, 0, 28642, 0, -25092, 0, 28643, 0, -25091, 0, 28644, 0, -25090, 0, 28645, 0, -25024, 0, 28646, 0, -25023, 0, 28647, 0, -25022, 0, 28648, 0, -25021, 0, 28649, 0, -25020, 0, 28650, 0, -25019, 0, 28651, 0, -25018, 0, 28652, 0, -25017, 0, 28653, 0, -25016, 0, 28656, 0, -25015, 0, 28657, 0, -25014, 0, 28658, 0, -25013, 0, 28659, 0, -25012, 0, 28660, 0, -25011, 0, 28661, 0, -25010, 0, 28662, 0, -25009, 0, 28663, 0, -25008, 0, 28664, 0, -25007, 0, 28665, 0, -25006, 0, 28666, 0, -25005, 0, 28667, 0, -25004, 0, 28668, 0, -25003, 0, 28669, 0, -25002, 0, 28670, 0, -25001, 0, 28671, 0, -25000, 0, 28672, 0, -24999, 0, 28673, 0, -24998, 0, 28674, 0, -24997, 0, 28675, 0, -24996, 0, 28676, 0, -24995, 0, 28677, 0, -24994, 0, 28678, 0, -24993, 0, 28679, 0, -24992, 0, 28680, 0, -24991, 0, 28681, 0, -24990, 0, 28682, 0, -24989, 0, 28683, 0, -24988, 0, 28684, 0, -24987, 0, 28685, 0, -24986, 0, 28686, 0, -24985, 0, 28687, 0, -24984, 0, 28688, 0, -24983, 0, 28690, 0, -24982, 0, 28691, 0, -24981, 0, 28692, 0, -24980, 0, 28693, 0, -24979, 0, 28694, 0, -24978, 0, 28695, 0, -24977, 0, 28696, 0, -24976, 0, 28697, 0, -24975, 0, 28700, 0, -24974, 0, 28701, 0, -24973, 0, 28702, 0, -24972, 0, 28703, 0, -24971, 0, 28704, 0, -24970, 0, 28705, 0, -24969, 0, 28706, 0, -24968, 0, 28708, 0, -24967, 0, 28709, 0, -24966, 0, 28710, 0, -24965, 0, 28711, 0, -24964, 0, 28712, 0, -24963, 0, 28713, 0, -24962, 0, 28714, 0, -24960, 0, 28715, 0, -24959, 0, 28716, 0, -24958, 0, 28717, 0, -24957, 0, 28718, 0, -24956, 0, 28719, 0, -24955, 0, 28720, 0, -24954, 0, 28721, 0, -24953, 0, 28722, 0, -24952, 0, 28723, 0, -24951, 0, 28724, 0, -24950, 0, 28726, 0, -24949, 0, 28727, 0, -24948, 0, 28728, 0, -24947, 0, 28730, 0, -24946, 0, 28731, 0, -24945, 0, 28732, 0, -24944, 0, 28733, 0, -24943, 0, 28734, 0, -24942, 0, 28735, 0, -24941, 0, 28736, 0, -24940, 0, 28737, 0, -24939, 0, 28738, 0, -24938, 0, 28739, 0, -24937, 0, 28740, 0, -24936, 0, 28741, 0, -24935, 0, 28742, 0, -24934, 0, 28743, 0, -24933, 0, 28744, 0, -24932, 0, 28745, 0, -24931, 0, 28746, 0, -24930, 0, 28747, 0, -24929, 0, 28749, 0, -24928, 0, 28750, 0, -24927, 0, 28752, 0, -24926, 0, 28753, 0, -24925, 0, 28754, 0, -24924, 0, 28755, 0, -24923, 0, 28756, 0, -24922, 0, 28757, 0, -24921, 0, 28758, 0, -24920, 0, 28759, 0, -24919, 0, 28760, 0, -24918, 0, 28761, 0, -24917, 0, 28762, 0, -24916, 0, 28763, 0, -24915, 0, 28764, 0, -24914, 0, 28765, 0, -24913, 0, 28767, 0, -24912, 0, 28768, 0, -24911, 0, 28769, 0, -24910, 0, 28770, 0, -24909, 0, 28771, 0, -24908, 0, 28772, 0, -24907, 0, 28773, 0, -24906, 0, 28774, 0, -24905, 0, 28775, 0, -24904, 0, 28776, 0, -24903, 0, 28777, 0, -24902, 0, 28778, 0, -24901, 0, 28782, 0, -24900, 0, 28785, 0, -24899, 0, 28786, 0, -24898, 0, 28787, 0, -24897, 0, 28788, 0, -24896, 0, 28791, 0, -24895, 0, 28793, 0, -24894, 0, 28794, 0, -24893, 0, 28795, 0, -24892, 0, 28797, 0, -24891, 0, 28801, 0, -24890, 0, 28802, 0, -24889, 0, 28803, 0, -24888, 0, 28804, 0, -24887, 0, 28806, 0, -24886, 0, 28807, 0, -24885, 0, 28808, 0, -24884, 0, 28811, 0, -24883, 0, 28812, 0, -24882, 0, 28813, 0, -24881, 0, 28815, 0, -24880, 0, 28816, 0, -24879, 0, 28817, 0, -24878, 0, 28819, 0, -24877, 0, 28823, 0, -24876, 0, 28824, 0, -24875, 0, 28826, 0, -24874, 0, 28827, 0, -24873, 0, 28830, 0, -24872, 0, 28831, 0, -24871, 0, 28832, 0, -24870, 0, 28833, 0, -24869, 0, 28834, 0, -24868, 0, 28835, 0, -24867, 0, 28836, 0, -24866, 0, 28837, 0, -24865, 0, 28838, 0, -24864, 0, 28839, 0, -24863, 0, 28840, 0, -24862, 0, 28841, 0, -24861, 0, 28842, 0, -24860, 0, 28848, 0, -24859, 0, 28850, 0, -24858, 0, 28852, 0, -24857, 0, 28853, 0, -24856, 0, 28854, 0, -24855, 0, 28858, 0, -24854, 0, 28862, 0, -24853, 0, 28863, 0, -24852, 0, 28868, 0, -24851, 0, 28869, 0, -24850, 0, 28870, 0, -24849, 0, 28871, 0, -24848, 0, 28873, 0, -24847, 0, 28875, 0, -24846, 0, 28876, 0, -24845, 0, 28877, 0, -24844, 0, 28878, 0, -24843, 0, 28879, 0, -24842, 0, 28880, 0, -24841, 0, 28881, 0, -24840, 0, 28882, 0, -24839, 0, 28883, 0, -24838, 0, 28884, 0, -24837, 0, 28885, 0, -24836, 0, 28886, 0, -24835, 0, 28887, 0, -24834, 0, 28890, 0, -24768, 0, 28892, 0, -24767, 0, 28893, 0, -24766, 0, 28894, 0, -24765, 0, 28896, 0, -24764, 0, 28897, 0, -24763, 0, 28898, 0, -24762, 0, 28899, 0, -24761, 0, 28901, 0, -24760, 0, 28906, 0, -24759, 0, 28910, 0, -24758, 0, 28912, 0, -24757, 0, 28913, 0, -24756, 0, 28914, 0, -24755, 0, 28915, 0, -24754, 0, 28916, 0, -24753, 0, 28917, 0, -24752, 0, 28918, 0, -24751, 0, 28920, 0, -24750, 0, 28922, 0, -24749, 0, 28923, 0, -24748, 0, 28924, 0, -24747, 0, 28926, 0, -24746, 0, 28927, 0, -24745, 0, 28928, 0, -24744, 0, 28929, 0, -24743, 0, 28930, 0, -24742, 0, 28931, 0, -24741, 0, 28932, 0, -24740, 0, 28933, 0, -24739, 0, 28934, 0, -24738, 0, 28935, 0, -24737, 0, 28936, 0, -24736, 0, 28939, 0, -24735, 0, 28940, 0, -24734, 0, 28941, 0, -24733, 0, 28942, 0, -24732, 0, 28943, 0, -24731, 0, 28945, 0, -24730, 0, 28946, 0, -24729, 0, 28948, 0, -24728, 0, 28951, 0, -24727, 0, 28955, 0, -24726, 0, 28956, 0, -24725, 0, 28957, 0, -24724, 0, 28958, 0, -24723, 0, 28959, 0, -24722, 0, 28960, 0, -24721, 0, 28961, 0, -24720, 0, 28962, 0, -24719, 0, 28963, 0, -24718, 0, 28964, 0, -24717, 0, 28965, 0, -24716, 0, 28967, 0, -24715, 0, 28968, 0, -24714, 0, 28969, 0, -24713, 0, 28970, 0, -24712, 0, 28971, 0, -24711, 0, 28972, 0, -24710, 0, 28973, 0, -24709, 0, 28974, 0, -24708, 0, 28978, 0, -24707, 0, 28979, 0, -24706, 0, 28980, 0, -24704, 0, 28981, 0, -24703, 0, 28983, 0, -24702, 0, 28984, 0, -24701, 0, 28985, 0, -24700, 0, 28986, 0, -24699, 0, 28987, 0, -24698, 0, 28988, 0, -24697, 0, 28989, 0, -24696, 0, 28990, 0, -24695, 0, 28991, 0, -24694, 0, 28992, 0, -24693, 0, 28993, 0, -24692, 0, 28994, 0, -24691, 0, 28995, 0, -24690, 0, 28996, 0, -24689, 0, 28998, 0, -24688, 0, 28999, 0, -24687, 0, 29000, 0, -24686, 0, 29001, 0, -24685, 0, 29003, 0, -24684, 0, 29005, 0, -24683, 0, 29007, 0, -24682, 0, 29008, 0, -24681, 0, 29009, 0, -24680, 0, 29010, 0, -24679, 0, 29011, 0, -24678, 0, 29012, 0, -24677, 0, 29013, 0, -24676, 0, 29014, 0, -24675, 0, 29015, 0, -24674, 0, 29016, 0, -24673, 0, 29017, 0, -24672, 0, 29018, 0, -24671, 0, 29019, 0, -24670, 0, 29021, 0, -24669, 0, 29023, 0, -24668, 0, 29024, 0, -24667, 0, 29025, 0, -24666, 0, 29026, 0, -24665, 0, 29027, 0, -24664, 0, 29029, 0, -24663, 0, 29033, 0, -24662, 0, 29034, 0, -24661, 0, 29035, 0, -24660, 0, 29036, 0, -24659, 0, 29037, 0, -24658, 0, 29039, 0, -24657, 0, 29040, 0, -24656, 0, 29041, 0, -24655, 0, 29044, 0, -24654, 0, 29045, 0, -24653, 0, 29046, 0, -24652, 0, 29047, 0, -24651, 0, 29049, 0, -24650, 0, 29051, 0, -24649, 0, 29052, 0, -24648, 0, 29054, 0, -24647, 0, 29055, 0, -24646, 0, 29056, 0, -24645, 0, 29057, 0, -24644, 0, 29058, 0, -24643, 0, 29059, 0, -24642, 0, 29061, 0, -24641, 0, 29062, 0, -24640, 0, 29063, 0, -24639, 0, 29064, 0, -24638, 0, 29065, 0, -24637, 0, 29067, 0, -24636, 0, 29068, 0, -24635, 0, 29069, 0, -24634, 0, 29070, 0, -24633, 0, 29072, 0, -24632, 0, 29073, 0, -24631, 0, 29074, 0, -24630, 0, 29075, 0, -24629, 0, 29077, 0, -24628, 0, 29078, 0, -24627, 0, 29079, 0, -24626, 0, 29082, 0, -24625, 0, 29083, 0, -24624, 0, 29084, 0, -24623, 0, 29085, 0, -24622, 0, 29086, 0, -24621, 0, 29089, 0, -24620, 0, 29090, 0, -24619, 0, 29091, 0, -24618, 0, 29092, 0, -24617, 0, 29093, 0, -24616, 0, 29094, 0, -24615, 0, 29095, 0, -24614, 0, 29097, 0, -24613, 0, 29098, 0, -24612, 0, 29099, 0, -24611, 0, 29101, 0, -24610, 0, 29102, 0, -24609, 0, 29103, 0, -24608, 0, 29104, 0, -24607, 0, 29105, 0, -24606, 0, 29106, 0, -24605, 0, 29108, 0, -24604, 0, 29110, 0, -24603, 0, 29111, 0, -24602, 0, 29112, 0, -24601, 0, 29114, 0, -24600, 0, 29115, 0, -24599, 0, 29116, 0, -24598, 0, 29117, 0, -24597, 0, 29118, 0, -24596, 0, 29119, 0, -24595, 0, 29120, 0, -24594, 0, 29121, 0, -24593, 0, 29122, 0, -24592, 0, 29124, 0, -24591, 0, 29125, 0, -24590, 0, 29126, 0, -24589, 0, 29127, 0, -24588, 0, 29128, 0, -24587, 0, 29129, 0, -24586, 0, 29130, 0, -24585, 0, 29131, 0, -24584, 0, 29132, 0, -24583, 0, 29133, 0, -24582, 0, 29135, 0, -24581, 0, 29136, 0, -24580, 0, 29137, 0, -24579, 0, 29138, 0, -24578, 0, 29139, 0, -24512, 0, 29142, 0, -24511, 0, 29143, 0, -24510, 0, 29144, 0, -24509, 0, 29145, 0, -24508, 0, 29146, 0, -24507, 0, 29147, 0, -24506, 0, 29148, 0, -24505, 0, 29149, 0, -24504, 0, 29150, 0, -24503, 0, 29151, 0, -24502, 0, 29153, 0, -24501, 0, 29154, 0, -24500, 0, 29155, 0, -24499, 0, 29156, 0, -24498, 0, 29158, 0, -24497, 0, 29160, 0, -24496, 0, 29161, 0, -24495, 0, 29162, 0, -24494, 0, 29163, 0, -24493, 0, 29164, 0, -24492, 0, 29165, 0, -24491, 0, 29167, 0, -24490, 0, 29168, 0, -24489, 0, 29169, 0, -24488, 0, 29170, 0, -24487, 0, 29171, 0, -24486, 0, 29172, 0, -24485, 0, 29173, 0, -24484, 0, 29174, 0, -24483, 0, 29175, 0, -24482, 0, 29176, 0, -24481, 0, 29178, 0, -24480, 0, 29179, 0, -24479, 0, 29180, 0, -24478, 0, 29181, 0, -24477, 0, 29182, 0, -24476, 0, 29183, 0, -24475, 0, 29184, 0, -24474, 0, 29185, 0, -24473, 0, 29186, 0, -24472, 0, 29187, 0, -24471, 0, 29188, 0, -24470, 0, 29189, 0, -24469, 0, 29191, 0, -24468, 0, 29192, 0, -24467, 0, 29193, 0, -24466, 0, 29194, 0, -24465, 0, 29195, 0, -24464, 0, 29196, 0, -24463, 0, 29197, 0, -24462, 0, 29198, 0, -24461, 0, 29199, 0, -24460, 0, 29200, 0, -24459, 0, 29201, 0, -24458, 0, 29202, 0, -24457, 0, 29203, 0, -24456, 0, 29204, 0, -24455, 0, 29205, 0, -24454, 0, 29206, 0, -24453, 0, 29207, 0, -24452, 0, 29208, 0, -24451, 0, 29209, 0, -24450, 0, 29210, 0, -24448, 0, 29211, 0, -24447, 0, 29212, 0, -24446, 0, 29214, 0, -24445, 0, 29215, 0, -24444, 0, 29216, 0, -24443, 0, 29217, 0, -24442, 0, 29218, 0, -24441, 0, 29219, 0, -24440, 0, 29220, 0, -24439, 0, 29221, 0, -24438, 0, 29222, 0, -24437, 0, 29223, 0, -24436, 0, 29225, 0, -24435, 0, 29227, 0, -24434, 0, 29229, 0, -24433, 0, 29230, 0, -24432, 0, 29231, 0, -24431, 0, 29234, 0, -24430, 0, 29235, 0, -24429, 0, 29236, 0, -24428, 0, 29242, 0, -24427, 0, 29244, 0, -24426, 0, 29246, 0, -24425, 0, 29248, 0, -24424, 0, 29249, 0, -24423, 0, 29250, 0, -24422, 0, 29251, 0, -24421, 0, 29252, 0, -24420, 0, 29253, 0, -24419, 0, 29254, 0, -24418, 0, 29257, 0, -24417, 0, 29258, 0, -24416, 0, 29259, 0, -24415, 0, 29262, 0, -24414, 0, 29263, 0, -24413, 0, 29264, 0, -24412, 0, 29265, 0, -24411, 0, 29267, 0, -24410, 0, 29268, 0, -24409, 0, 29269, 0, -24408, 0, 29271, 0, -24407, 0, 29272, 0, -24406, 0, 29274, 0, -24405, 0, 29276, 0, -24404, 0, 29278, 0, -24403, 0, 29280, 0, -24402, 0, 29283, 0, -24401, 0, 29284, 0, -24400, 0, 29285, 0, -24399, 0, 29288, 0, -24398, 0, 29290, 0, -24397, 0, 29291, 0, -24396, 0, 29292, 0, -24395, 0, 29293, 0, -24394, 0, 29296, 0, -24393, 0, 29297, 0, -24392, 0, 29299, 0, -24391, 0, 29300, 0, -24390, 0, 29302, 0, -24389, 0, 29303, 0, -24388, 0, 29304, 0, -24387, 0, 29307, 0, -24386, 0, 29308, 0, -24385, 0, 29309, 0, -24384, 0, 29314, 0, -24383, 0, 29315, 0, -24382, 0, 29317, 0, -24381, 0, 29318, 0, -24380, 0, 29319, 0, -24379, 0, 29320, 0, -24378, 0, 29321, 0, -24377, 0, 29324, 0, -24376, 0, 29326, 0, -24375, 0, 29328, 0, -24374, 0, 29329, 0, -24373, 0, 29331, 0, -24372, 0, 29332, 0, -24371, 0, 29333, 0, -24370, 0, 29334, 0, -24369, 0, 29335, 0, -24368, 0, 29336, 0, -24367, 0, 29337, 0, -24366, 0, 29338, 0, -24365, 0, 29339, 0, -24364, 0, 29340, 0, -24363, 0, 29341, 0, -24362, 0, 29342, 0, -24361, 0, 29344, 0, -24360, 0, 29345, 0, -24359, 0, 29346, 0, -24358, 0, 29347, 0, -24357, 0, 29348, 0, -24356, 0, 29349, 0, -24355, 0, 29350, 0, -24354, 0, 29351, 0, -24353, 0, 29352, 0, -24352, 0, 29353, 0, -24351, 0, 29354, 0, -24350, 0, 29355, 0, -24349, 0, 29358, 0, -24348, 0, 29361, 0, -24347, 0, 29362, 0, -24346, 0, 29363, 0, -24345, 0, 29365, 0, -24344, 0, 29370, 0, -24343, 0, 29371, 0, -24342, 0, 29372, 0, -24341, 0, 29373, 0, -24340, 0, 29374, 0, -24339, 0, 29375, 0, -24338, 0, 29376, 0, -24337, 0, 29381, 0, -24336, 0, 29382, 0, -24335, 0, 29383, 0, -24334, 0, 29385, 0, -24333, 0, 29386, 0, -24332, 0, 29387, 0, -24331, 0, 29388, 0, -24330, 0, 29391, 0, -24329, 0, 29393, 0, -24328, 0, 29395, 0, -24327, 0, 29396, 0, -24326, 0, 29397, 0, -24325, 0, 29398, 0, -24324, 0, 29400, 0, -24323, 0, 29402, 0, -24322, 0, 29403, 0, -24256, 0, -6970, 0, -24255, 0, -6969, 0, -24254, 0, -6968, 0, -24253, 0, -6967, 0, -24252, 0, -6966, 0, -24251, 0, -6965, 0, -24250, 0, -6964, 0, -24249, 0, -6963, 0, -24248, 0, -6962, 0, -24247, 0, -6961, 0, -24246, 0, -6960, 0, -24245, 0, -6959, 0, -24244, 0, -6958, 0, -24243, 0, -6957, 0, -24242, 0, -6956, 0, -24241, 0, -6955, 0, -24240, 0, -6954, 0, -24239, 0, -6953, 0, -24238, 0, -6952, 0, -24237, 0, -6951, 0, -24236, 0, -6950, 0, -24235, 0, -6949, 0, -24234, 0, -6948, 0, -24233, 0, -6947, 0, -24232, 0, -6946, 0, -24231, 0, -6945, 0, -24230, 0, -6944, 0, -24229, 0, -6943, 0, -24228, 0, -6942, 0, -24227, 0, -6941, 0, -24226, 0, -6940, 0, -24225, 0, -6939, 0, -24224, 0, -6938, 0, -24223, 0, -6937, 0, -24222, 0, -6936, 0, -24221, 0, -6935, 0, -24220, 0, -6934, 0, -24219, 0, -6933, 0, -24218, 0, -6932, 0, -24217, 0, -6931, 0, -24216, 0, -6930, 0, -24215, 0, -6929, 0, -24214, 0, -6928, 0, -24213, 0, -6927, 0, -24212, 0, -6926, 0, -24211, 0, -6925, 0, -24210, 0, -6924, 0, -24209, 0, -6923, 0, -24208, 0, -6922, 0, -24207, 0, -6921, 0, -24206, 0, -6920, 0, -24205, 0, -6919, 0, -24204, 0, -6918, 0, -24203, 0, -6917, 0, -24202, 0, -6916, 0, -24201, 0, -6915, 0, -24200, 0, -6914, 0, -24199, 0, -6913, 0, -24198, 0, -6912, 0, -24197, 0, -6911, 0, -24196, 0, -6910, 0, -24195, 0, -6909, 0, -24194, 0, -6908, 0, -24192, 0, -6907, 0, -24191, 0, -6906, 0, -24190, 0, -6905, 0, -24189, 0, -6904, 0, -24188, 0, -6903, 0, -24187, 0, -6902, 0, -24186, 0, -6901, 0, -24185, 0, -6900, 0, -24184, 0, -6899, 0, -24183, 0, -6898, 0, -24182, 0, -6897, 0, -24181, 0, -6896, 0, -24180, 0, -6895, 0, -24179, 0, -6894, 0, -24178, 0, -6893, 0, -24177, 0, -6892, 0, -24176, 0, -6891, 0, -24175, 0, -6890, 0, -24174, 0, -6889, 0, -24173, 0, -6888, 0, -24172, 0, -6887, 0, -24171, 0, -6886, 0, -24170, 0, -6885, 0, -24169, 0, -6884, 0, -24168, 0, -6883, 0, -24167, 0, -6882, 0, -24166, 0, -6881, 0, -24165, 0, -6880, 0, -24164, 0, -6879, 0, -24163, 0, -6878, 0, -24162, 0, -6877, 0, -24161, 0, -6876, 0, -24160, 0, -6875, 0, -24159, 0, 12288, 0, -24158, 0, 12289, 0, -24157, 0, 12290, 0, -24156, 0, 183, 0, -24155, 0, 713, 0, -24154, 0, 711, 0, -24153, 0, 168, 0, -24152, 0, 12291, 0, -24151, 0, 12293, 0, -24150, 0, 8212, 0, -24149, 0, -162, 0, -24148, 0, 8214, 0, -24147, 0, 8230, 0, -24146, 0, 8216, 0, -24145, 0, 8217, 0, -24144, 0, 8220, 0, -24143, 0, 8221, 0, -24142, 0, 12308, 0, -24141, 0, 12309, 0, -24140, 0, 12296, 0, -24139, 0, 12297, 0, -24138, 0, 12298, 0, -24137, 0, 12299, 0, -24136, 0, 12300, 0, -24135, 0, 12301, 0, -24134, 0, 12302, 0, -24133, 0, 12303, 0, -24132, 0, 12310, 0, -24131, 0, 12311, 0, -24130, 0, 12304, 0, -24129, 0, 12305, 0, -24128, 0, 177, 0, -24127, 0, 215, 0, -24126, 0, 247, 0, -24125, 0, 8758, 0, -24124, 0, 8743, 0, -24123, 0, 8744, 0, -24122, 0, 8721, 0, -24121, 0, 8719, 0, -24120, 0, 8746, 0, -24119, 0, 8745, 0, -24118, 0, 8712, 0, -24117, 0, 8759, 0, -24116, 0, 8730, 0, -24115, 0, 8869, 0, -24114, 0, 8741, 0, -24113, 0, 8736, 0, -24112, 0, 8978, 0, -24111, 0, 8857, 0, -24110, 0, 8747, 0, -24109, 0, 8750, 0, -24108, 0, 8801, 0, -24107, 0, 8780, 0, -24106, 0, 8776, 0, -24105, 0, 8765, 0, -24104, 0, 8733, 0, -24103, 0, 8800, 0, -24102, 0, 8814, 0, -24101, 0, 8815, 0, -24100, 0, 8804, 0, -24099, 0, 8805, 0, -24098, 0, 8734, 0, -24097, 0, 8757, 0, -24096, 0, 8756, 0, -24095, 0, 9794, 0, -24094, 0, 9792, 0, -24093, 0, 176, 0, -24092, 0, 8242, 0, -24091, 0, 8243, 0, -24090, 0, 8451, 0, -24089, 0, -252, 0, -24088, 0, 164, 0, -24087, 0, -32, 0, -24086, 0, -31, 0, -24085, 0, 8240, 0, -24084, 0, 167, 0, -24083, 0, 8470, 0, -24082, 0, 9734, 0, -24081, 0, 9733, 0, -24080, 0, 9675, 0, -24079, 0, 9679, 0, -24078, 0, 9678, 0, -24077, 0, 9671, 0, -24076, 0, 9670, 0, -24075, 0, 9633, 0, -24074, 0, 9632, 0, -24073, 0, 9651, 0, -24072, 0, 9650, 0, -24071, 0, 8251, 0, -24070, 0, 8594, 0, -24069, 0, 8592, 0, -24068, 0, 8593, 0, -24067, 0, 8595, 0, -24066, 0, 12307, 0, -24000, 0, -6874, 0, -23999, 0, -6873, 0, -23998, 0, -6872, 0, -23997, 0, -6871, 0, -23996, 0, -6870, 0, -23995, 0, -6869, 0, -23994, 0, -6868, 0, -23993, 0, -6867, 0, -23992, 0, -6866, 0, -23991, 0, -6865, 0, -23990, 0, -6864, 0, -23989, 0, -6863, 0, -23988, 0, -6862, 0, -23987, 0, -6861, 0, -23986, 0, -6860, 0, -23985, 0, -6859, 0, -23984, 0, -6858, 0, -23983, 0, -6857, 0, -23982, 0, -6856, 0, -23981, 0, -6855, 0, -23980, 0, -6854, 0, -23979, 0, -6853, 0, -23978, 0, -6852, 0, -23977, 0, -6851, 0, -23976, 0, -6850, 0, -23975, 0, -6849, 0, -23974, 0, -6848, 0, -23973, 0, -6847, 0, -23972, 0, -6846, 0, -23971, 0, -6845, 0, -23970, 0, -6844, 0, -23969, 0, -6843, 0, -23968, 0, -6842, 0, -23967, 0, -6841, 0, -23966, 0, -6840, 0, -23965, 0, -6839, 0, -23964, 0, -6838, 0, -23963, 0, -6837, 0, -23962, 0, -6836, 0, -23961, 0, -6835, 0, -23960, 0, -6834, 0, -23959, 0, -6833, 0, -23958, 0, -6832, 0, -23957, 0, -6831, 0, -23956, 0, -6830, 0, -23955, 0, -6829, 0, -23954, 0, -6828, 0, -23953, 0, -6827, 0, -23952, 0, -6826, 0, -23951, 0, -6825, 0, -23950, 0, -6824, 0, -23949, 0, -6823, 0, -23948, 0, -6822, 0, -23947, 0, -6821, 0, -23946, 0, -6820, 0, -23945, 0, -6819, 0, -23944, 0, -6818, 0, -23943, 0, -6817, 0, -23942, 0, -6816, 0, -23941, 0, -6815, 0, -23940, 0, -6814, 0, -23939, 0, -6813, 0, -23938, 0, -6812, 0, -23936, 0, -6811, 0, -23935, 0, -6810, 0, -23934, 0, -6809, 0, -23933, 0, -6808, 0, -23932, 0, -6807, 0, -23931, 0, -6806, 0, -23930, 0, -6805, 0, -23929, 0, -6804, 0, -23928, 0, -6803, 0, -23927, 0, -6802, 0, -23926, 0, -6801, 0, -23925, 0, -6800, 0, -23924, 0, -6799, 0, -23923, 0, -6798, 0, -23922, 0, -6797, 0, -23921, 0, -6796, 0, -23920, 0, -6795, 0, -23919, 0, -6794, 0, -23918, 0, -6793, 0, -23917, 0, -6792, 0, -23916, 0, -6791, 0, -23915, 0, -6790, 0, -23914, 0, -6789, 0, -23913, 0, -6788, 0, -23912, 0, -6787, 0, -23911, 0, -6786, 0, -23910, 0, -6785, 0, -23909, 0, -6784, 0, -23908, 0, -6783, 0, -23907, 0, -6782, 0, -23906, 0, -6781, 0, -23905, 0, -6780, 0, -23904, 0, -6779, 0, -23903, 0, 8560, 0, -23902, 0, 8561, 0, -23901, 0, 8562, 0, -23900, 0, 8563, 0, -23899, 0, 8564, 0, -23898, 0, 8565, 0, -23897, 0, 8566, 0, -23896, 0, 8567, 0, -23895, 0, 8568, 0, -23894, 0, 8569, 0, -23893, 0, -6298, 0, -23892, 0, -6297, 0, -23891, 0, -6296, 0, -23890, 0, -6295, 0, -23889, 0, -6294, 0, -23888, 0, -6293, 0, -23887, 0, 9352, 0, -23886, 0, 9353, 0, -23885, 0, 9354, 0, -23884, 0, 9355, 0, -23883, 0, 9356, 0, -23882, 0, 9357, 0, -23881, 0, 9358, 0, -23880, 0, 9359, 0, -23879, 0, 9360, 0, -23878, 0, 9361, 0, -23877, 0, 9362, 0, -23876, 0, 9363, 0, -23875, 0, 9364, 0, -23874, 0, 9365, 0, -23873, 0, 9366, 0, -23872, 0, 9367, 0, -23871, 0, 9368, 0, -23870, 0, 9369, 0, -23869, 0, 9370, 0, -23868, 0, 9371, 0, -23867, 0, 9332, 0, -23866, 0, 9333, 0, -23865, 0, 9334, 0, -23864, 0, 9335, 0, -23863, 0, 9336, 0, -23862, 0, 9337, 0, -23861, 0, 9338, 0, -23860, 0, 9339, 0, -23859, 0, 9340, 0, -23858, 0, 9341, 0, -23857, 0, 9342, 0, -23856, 0, 9343, 0, -23855, 0, 9344, 0, -23854, 0, 9345, 0, -23853, 0, 9346, 0, -23852, 0, 9347, 0, -23851, 0, 9348, 0, -23850, 0, 9349, 0, -23849, 0, 9350, 0, -23848, 0, 9351, 0, -23847, 0, 9312, 0, -23846, 0, 9313, 0, -23845, 0, 9314, 0, -23844, 0, 9315, 0, -23843, 0, 9316, 0, -23842, 0, 9317, 0, -23841, 0, 9318, 0, -23840, 0, 9319, 0, -23839, 0, 9320, 0, -23838, 0, 9321, 0, -23837, 0, -6292, 0, -23836, 0, -6291, 0, -23835, 0, 12832, 0, -23834, 0, 12833, 0, -23833, 0, 12834, 0, -23832, 0, 12835, 0, -23831, 0, 12836, 0, -23830, 0, 12837, 0, -23829, 0, 12838, 0, -23828, 0, 12839, 0, -23827, 0, 12840, 0, -23826, 0, 12841, 0, -23825, 0, -6290, 0, -23824, 0, -6289, 0, -23823, 0, 8544, 0, -23822, 0, 8545, 0, -23821, 0, 8546, 0, -23820, 0, 8547, 0, -23819, 0, 8548, 0, -23818, 0, 8549, 0, -23817, 0, 8550, 0, -23816, 0, 8551, 0, -23815, 0, 8552, 0, -23814, 0, 8553, 0, -23813, 0, 8554, 0, -23812, 0, 8555, 0, -23811, 0, -6288, 0, -23810, 0, -6287, 0, -23744, 0, -6778, 0, -23743, 0, -6777, 0, -23742, 0, -6776, 0, -23741, 0, -6775, 0, -23740, 0, -6774, 0, -23739, 0, -6773, 0, -23738, 0, -6772, 0, -23737, 0, -6771, 0, -23736, 0, -6770, 0, -23735, 0, -6769, 0, -23734, 0, -6768, 0, -23733, 0, -6767, 0, -23732, 0, -6766, 0, -23731, 0, -6765, 0, -23730, 0, -6764, 0, -23729, 0, -6763, 0, -23728, 0, -6762, 0, -23727, 0, -6761, 0, -23726, 0, -6760, 0, -23725, 0, -6759, 0, -23724, 0, -6758, 0, -23723, 0, -6757, 0, -23722, 0, -6756, 0, -23721, 0, -6755, 0, -23720, 0, -6754, 0, -23719, 0, -6753, 0, -23718, 0, -6752, 0, -23717, 0, -6751, 0, -23716, 0, -6750, 0, -23715, 0, -6749, 0, -23714, 0, -6748, 0, -23713, 0, -6747, 0, -23712, 0, -6746, 0, -23711, 0, -6745, 0, -23710, 0, -6744, 0, -23709, 0, -6743, 0, -23708, 0, -6742, 0, -23707, 0, -6741, 0, -23706, 0, -6740, 0, -23705, 0, -6739, 0, -23704, 0, -6738, 0, -23703, 0, -6737, 0, -23702, 0, -6736, 0, -23701, 0, -6735, 0, -23700, 0, -6734, 0, -23699, 0, -6733, 0, -23698, 0, -6732, 0, -23697, 0, -6731, 0, -23696, 0, -6730, 0, -23695, 0, -6729, 0, -23694, 0, -6728, 0, -23693, 0, -6727, 0, -23692, 0, -6726, 0, -23691, 0, -6725, 0, -23690, 0, -6724, 0, -23689, 0, -6723, 0, -23688, 0, -6722, 0, -23687, 0, -6721, 0, -23686, 0, -6720, 0, -23685, 0, -6719, 0, -23684, 0, -6718, 0, -23683, 0, -6717, 0, -23682, 0, -6716, 0, -23680, 0, -6715, 0, -23679, 0, -6714, 0, -23678, 0, -6713, 0, -23677, 0, -6712, 0, -23676, 0, -6711, 0, -23675, 0, -6710, 0, -23674, 0, -6709, 0, -23673, 0, -6708, 0, -23672, 0, -6707, 0, -23671, 0, -6706, 0, -23670, 0, -6705, 0, -23669, 0, -6704, 0, -23668, 0, -6703, 0, -23667, 0, -6702, 0, -23666, 0, -6701, 0, -23665, 0, -6700, 0, -23664, 0, -6699, 0, -23663, 0, -6698, 0, -23662, 0, -6697, 0, -23661, 0, -6696, 0, -23660, 0, -6695, 0, -23659, 0, -6694, 0, -23658, 0, -6693, 0, -23657, 0, -6692, 0, -23656, 0, -6691, 0, -23655, 0, -6690, 0, -23654, 0, -6689, 0, -23653, 0, -6688, 0, -23652, 0, -6687, 0, -23651, 0, -6686, 0, -23650, 0, -6685, 0, -23649, 0, -6684, 0, -23648, 0, -6683, 0, -23647, 0, -255, 0, -23646, 0, -254, 0, -23645, 0, -253, 0, -23644, 0, -27, 0, -23643, 0, -251, 0, -23642, 0, -250, 0, -23641, 0, -249, 0, -23640, 0, -248, 0, -23639, 0, -247, 0, -23638, 0, -246, 0, -23637, 0, -245, 0, -23636, 0, -244, 0, -23635, 0, -243, 0, -23634, 0, -242, 0, -23633, 0, -241, 0, -23632, 0, -240, 0, -23631, 0, -239, 0, -23630, 0, -238, 0, -23629, 0, -237, 0, -23628, 0, -236, 0, -23627, 0, -235, 0, -23626, 0, -234, 0, -23625, 0, -233, 0, -23624, 0, -232, 0, -23623, 0, -231, 0, -23622, 0, -230, 0, -23621, 0, -229, 0, -23620, 0, -228, 0, -23619, 0, -227, 0, -23618, 0, -226, 0, -23617, 0, -225, 0, -23616, 0, -224, 0, -23615, 0, -223, 0, -23614, 0, -222, 0, -23613, 0, -221, 0, -23612, 0, -220, 0, -23611, 0, -219, 0, -23610, 0, -218, 0, -23609, 0, -217, 0, -23608, 0, -216, 0, -23607, 0, -215, 0, -23606, 0, -214, 0, -23605, 0, -213, 0, -23604, 0, -212, 0, -23603, 0, -211, 0, -23602, 0, -210, 0, -23601, 0, -209, 0, -23600, 0, -208, 0, -23599, 0, -207, 0, -23598, 0, -206, 0, -23597, 0, -205, 0, -23596, 0, -204, 0, -23595, 0, -203, 0, -23594, 0, -202, 0, -23593, 0, -201, 0, -23592, 0, -200, 0, -23591, 0, -199, 0, -23590, 0, -198, 0, -23589, 0, -197, 0, -23588, 0, -196, 0, -23587, 0, -195, 0, -23586, 0, -194, 0, -23585, 0, -193, 0, -23584, 0, -192, 0, -23583, 0, -191, 0, -23582, 0, -190, 0, -23581, 0, -189, 0, -23580, 0, -188, 0, -23579, 0, -187, 0, -23578, 0, -186, 0, -23577, 0, -185, 0, -23576, 0, -184, 0, -23575, 0, -183, 0, -23574, 0, -182, 0, -23573, 0, -181, 0, -23572, 0, -180, 0, -23571, 0, -179, 0, -23570, 0, -178, 0, -23569, 0, -177, 0, -23568, 0, -176, 0, -23567, 0, -175, 0, -23566, 0, -174, 0, -23565, 0, -173, 0, -23564, 0, -172, 0, -23563, 0, -171, 0, -23562, 0, -170, 0, -23561, 0, -169, 0, -23560, 0, -168, 0, -23559, 0, -167, 0, -23558, 0, -166, 0, -23557, 0, -165, 0, -23556, 0, -164, 0, -23555, 0, -163, 0, -23554, 0, -29, 0, -23488, 0, -6682, 0, -23487, 0, -6681, 0, -23486, 0, -6680, 0, -23485, 0, -6679, 0, -23484, 0, -6678, 0, -23483, 0, -6677, 0, -23482, 0, -6676, 0, -23481, 0, -6675, 0, -23480, 0, -6674, 0, -23479, 0, -6673, 0, -23478, 0, -6672, 0, -23477, 0, -6671, 0, -23476, 0, -6670, 0, -23475, 0, -6669, 0, -23474, 0, -6668, 0, -23473, 0, -6667, 0, -23472, 0, -6666, 0, -23471, 0, -6665, 0, -23470, 0, -6664, 0, -23469, 0, -6663, 0, -23468, 0, -6662, 0, -23467, 0, -6661, 0, -23466, 0, -6660, 0, -23465, 0, -6659, 0, -23464, 0, -6658, 0, -23463, 0, -6657, 0, -23462, 0, -6656, 0, -23461, 0, -6655, 0, -23460, 0, -6654, 0, -23459, 0, -6653, 0, -23458, 0, -6652, 0, -23457, 0, -6651, 0, -23456, 0, -6650, 0, -23455, 0, -6649, 0, -23454, 0, -6648, 0, -23453, 0, -6647, 0, -23452, 0, -6646, 0, -23451, 0, -6645, 0, -23450, 0, -6644, 0, -23449, 0, -6643, 0, -23448, 0, -6642, 0, -23447, 0, -6641, 0, -23446, 0, -6640, 0, -23445, 0, -6639, 0, -23444, 0, -6638, 0, -23443, 0, -6637, 0, -23442, 0, -6636, 0, -23441, 0, -6635, 0, -23440, 0, -6634, 0, -23439, 0, -6633, 0, -23438, 0, -6632, 0, -23437, 0, -6631, 0, -23436, 0, -6630, 0, -23435, 0, -6629, 0, -23434, 0, -6628, 0, -23433, 0, -6627, 0, -23432, 0, -6626, 0, -23431, 0, -6625, 0, -23430, 0, -6624, 0, -23429, 0, -6623, 0, -23428, 0, -6622, 0, -23427, 0, -6621, 0, -23426, 0, -6620, 0, -23424, 0, -6619, 0, -23423, 0, -6618, 0, -23422, 0, -6617, 0, -23421, 0, -6616, 0, -23420, 0, -6615, 0, -23419, 0, -6614, 0, -23418, 0, -6613, 0, -23417, 0, -6612, 0, -23416, 0, -6611, 0, -23415, 0, -6610, 0, -23414, 0, -6609, 0, -23413, 0, -6608, 0, -23412, 0, -6607, 0, -23411, 0, -6606, 0, -23410, 0, -6605, 0, -23409, 0, -6604, 0, -23408, 0, -6603, 0, -23407, 0, -6602, 0, -23406, 0, -6601, 0, -23405, 0, -6600, 0, -23404, 0, -6599, 0, -23403, 0, -6598, 0, -23402, 0, -6597, 0, -23401, 0, -6596, 0, -23400, 0, -6595, 0, -23399, 0, -6594, 0, -23398, 0, -6593, 0, -23397, 0, -6592, 0, -23396, 0, -6591, 0, -23395, 0, -6590, 0, -23394, 0, -6589, 0, -23393, 0, -6588, 0, -23392, 0, -6587, 0, -23391, 0, 12353, 0, -23390, 0, 12354, 0, -23389, 0, 12355, 0, -23388, 0, 12356, 0, -23387, 0, 12357, 0, -23386, 0, 12358, 0, -23385, 0, 12359, 0, -23384, 0, 12360, 0, -23383, 0, 12361, 0, -23382, 0, 12362, 0, -23381, 0, 12363, 0, -23380, 0, 12364, 0, -23379, 0, 12365, 0, -23378, 0, 12366, 0, -23377, 0, 12367, 0, -23376, 0, 12368, 0, -23375, 0, 12369, 0, -23374, 0, 12370, 0, -23373, 0, 12371, 0, -23372, 0, 12372, 0, -23371, 0, 12373, 0, -23370, 0, 12374, 0, -23369, 0, 12375, 0, -23368, 0, 12376, 0, -23367, 0, 12377, 0, -23366, 0, 12378, 0, -23365, 0, 12379, 0, -23364, 0, 12380, 0, -23363, 0, 12381, 0, -23362, 0, 12382, 0, -23361, 0, 12383, 0, -23360, 0, 12384, 0, -23359, 0, 12385, 0, -23358, 0, 12386, 0, -23357, 0, 12387, 0, -23356, 0, 12388, 0, -23355, 0, 12389, 0, -23354, 0, 12390, 0, -23353, 0, 12391, 0, -23352, 0, 12392, 0, -23351, 0, 12393, 0, -23350, 0, 12394, 0, -23349, 0, 12395, 0, -23348, 0, 12396, 0, -23347, 0, 12397, 0, -23346, 0, 12398, 0, -23345, 0, 12399, 0, -23344, 0, 12400, 0, -23343, 0, 12401, 0, -23342, 0, 12402, 0, -23341, 0, 12403, 0, -23340, 0, 12404, 0, -23339, 0, 12405, 0, -23338, 0, 12406, 0, -23337, 0, 12407, 0, -23336, 0, 12408, 0, -23335, 0, 12409, 0, -23334, 0, 12410, 0, -23333, 0, 12411, 0, -23332, 0, 12412, 0, -23331, 0, 12413, 0, -23330, 0, 12414, 0, -23329, 0, 12415, 0, -23328, 0, 12416, 0, -23327, 0, 12417, 0, -23326, 0, 12418, 0, -23325, 0, 12419, 0, -23324, 0, 12420, 0, -23323, 0, 12421, 0, -23322, 0, 12422, 0, -23321, 0, 12423, 0, -23320, 0, 12424, 0, -23319, 0, 12425, 0, -23318, 0, 12426, 0, -23317, 0, 12427, 0, -23316, 0, 12428, 0, -23315, 0, 12429, 0, -23314, 0, 12430, 0, -23313, 0, 12431, 0, -23312, 0, 12432, 0, -23311, 0, 12433, 0, -23310, 0, 12434, 0, -23309, 0, 12435, 0, -23308, 0, -6286, 0, -23307, 0, -6285, 0, -23306, 0, -6284, 0, -23305, 0, -6283, 0, -23304, 0, -6282, 0, -23303, 0, -6281, 0, -23302, 0, -6280, 0, -23301, 0, -6279, 0, -23300, 0, -6278, 0, -23299, 0, -6277, 0, -23298, 0, -6276, 0, -23232, 0, -6586, 0, -23231, 0, -6585, 0, -23230, 0, -6584, 0, -23229, 0, -6583, 0, -23228, 0, -6582, 0, -23227, 0, -6581, 0, -23226, 0, -6580, 0, -23225, 0, -6579, 0, -23224, 0, -6578, 0, -23223, 0, -6577, 0, -23222, 0, -6576, 0, -23221, 0, -6575, 0, -23220, 0, -6574, 0, -23219, 0, -6573, 0, -23218, 0, -6572, 0, -23217, 0, -6571, 0, -23216, 0, -6570, 0, -23215, 0, -6569, 0, -23214, 0, -6568, 0, -23213, 0, -6567, 0, -23212, 0, -6566, 0, -23211, 0, -6565, 0, -23210, 0, -6564, 0, -23209, 0, -6563, 0, -23208, 0, -6562, 0, -23207, 0, -6561, 0, -23206, 0, -6560, 0, -23205, 0, -6559, 0, -23204, 0, -6558, 0, -23203, 0, -6557, 0, -23202, 0, -6556, 0, -23201, 0, -6555, 0, -23200, 0, -6554, 0, -23199, 0, -6553, 0, -23198, 0, -6552, 0, -23197, 0, -6551, 0, -23196, 0, -6550, 0, -23195, 0, -6549, 0, -23194, 0, -6548, 0, -23193, 0, -6547, 0, -23192, 0, -6546, 0, -23191, 0, -6545, 0, -23190, 0, -6544, 0, -23189, 0, -6543, 0, -23188, 0, -6542, 0, -23187, 0, -6541, 0, -23186, 0, -6540, 0, -23185, 0, -6539, 0, -23184, 0, -6538, 0, -23183, 0, -6537, 0, -23182, 0, -6536, 0, -23181, 0, -6535, 0, -23180, 0, -6534, 0, -23179, 0, -6533, 0, -23178, 0, -6532, 0, -23177, 0, -6531, 0, -23176, 0, -6530, 0, -23175, 0, -6529, 0, -23174, 0, -6528, 0, -23173, 0, -6527, 0, -23172, 0, -6526, 0, -23171, 0, -6525, 0, -23170, 0, -6524, 0, -23168, 0, -6523, 0, -23167, 0, -6522, 0, -23166, 0, -6521, 0, -23165, 0, -6520, 0, -23164, 0, -6519, 0, -23163, 0, -6518, 0, -23162, 0, -6517, 0, -23161, 0, -6516, 0, -23160, 0, -6515, 0, -23159, 0, -6514, 0, -23158, 0, -6513, 0, -23157, 0, -6512, 0, -23156, 0, -6511, 0, -23155, 0, -6510, 0, -23154, 0, -6509, 0, -23153, 0, -6508, 0, -23152, 0, -6507, 0, -23151, 0, -6506, 0, -23150, 0, -6505, 0, -23149, 0, -6504, 0, -23148, 0, -6503, 0, -23147, 0, -6502, 0, -23146, 0, -6501, 0, -23145, 0, -6500, 0, -23144, 0, -6499, 0, -23143, 0, -6498, 0, -23142, 0, -6497, 0, -23141, 0, -6496, 0, -23140, 0, -6495, 0, -23139, 0, -6494, 0, -23138, 0, -6493, 0, -23137, 0, -6492, 0, -23136, 0, -6491, 0, -23135, 0, 12449, 0, -23134, 0, 12450, 0, -23133, 0, 12451, 0, -23132, 0, 12452, 0, -23131, 0, 12453, 0, -23130, 0, 12454, 0, -23129, 0, 12455, 0, -23128, 0, 12456, 0, -23127, 0, 12457, 0, -23126, 0, 12458, 0, -23125, 0, 12459, 0, -23124, 0, 12460, 0, -23123, 0, 12461, 0, -23122, 0, 12462, 0, -23121, 0, 12463, 0, -23120, 0, 12464, 0, -23119, 0, 12465, 0, -23118, 0, 12466, 0, -23117, 0, 12467, 0, -23116, 0, 12468, 0, -23115, 0, 12469, 0, -23114, 0, 12470, 0, -23113, 0, 12471, 0, -23112, 0, 12472, 0, -23111, 0, 12473, 0, -23110, 0, 12474, 0, -23109, 0, 12475, 0, -23108, 0, 12476, 0, -23107, 0, 12477, 0, -23106, 0, 12478, 0, -23105, 0, 12479, 0, -23104, 0, 12480, 0, -23103, 0, 12481, 0, -23102, 0, 12482, 0, -23101, 0, 12483, 0, -23100, 0, 12484, 0, -23099, 0, 12485, 0, -23098, 0, 12486, 0, -23097, 0, 12487, 0, -23096, 0, 12488, 0, -23095, 0, 12489, 0, -23094, 0, 12490, 0, -23093, 0, 12491, 0, -23092, 0, 12492, 0, -23091, 0, 12493, 0, -23090, 0, 12494, 0, -23089, 0, 12495, 0, -23088, 0, 12496, 0, -23087, 0, 12497, 0, -23086, 0, 12498, 0, -23085, 0, 12499, 0, -23084, 0, 12500, 0, -23083, 0, 12501, 0, -23082, 0, 12502, 0, -23081, 0, 12503, 0, -23080, 0, 12504, 0, -23079, 0, 12505, 0, -23078, 0, 12506, 0, -23077, 0, 12507, 0, -23076, 0, 12508, 0, -23075, 0, 12509, 0, -23074, 0, 12510, 0, -23073, 0, 12511, 0, -23072, 0, 12512, 0, -23071, 0, 12513, 0, -23070, 0, 12514, 0, -23069, 0, 12515, 0, -23068, 0, 12516, 0, -23067, 0, 12517, 0, -23066, 0, 12518, 0, -23065, 0, 12519, 0, -23064, 0, 12520, 0, -23063, 0, 12521, 0, -23062, 0, 12522, 0, -23061, 0, 12523, 0, -23060, 0, 12524, 0, -23059, 0, 12525, 0, -23058, 0, 12526, 0, -23057, 0, 12527, 0, -23056, 0, 12528, 0, -23055, 0, 12529, 0, -23054, 0, 12530, 0, -23053, 0, 12531, 0, -23052, 0, 12532, 0, -23051, 0, 12533, 0, -23050, 0, 12534, 0, -23049, 0, -6275, 0, -23048, 0, -6274, 0, -23047, 0, -6273, 0, -23046, 0, -6272, 0, -23045, 0, -6271, 0, -23044, 0, -6270, 0, -23043, 0, -6269, 0, -23042, 0, -6268, 0, -22976, 0, -6490, 0, -22975, 0, -6489, 0, -22974, 0, -6488, 0, -22973, 0, -6487, 0, -22972, 0, -6486, 0, -22971, 0, -6485, 0, -22970, 0, -6484, 0, -22969, 0, -6483, 0, -22968, 0, -6482, 0, -22967, 0, -6481, 0, -22966, 0, -6480, 0, -22965, 0, -6479, 0, -22964, 0, -6478, 0, -22963, 0, -6477, 0, -22962, 0, -6476, 0, -22961, 0, -6475, 0, -22960, 0, -6474, 0, -22959, 0, -6473, 0, -22958, 0, -6472, 0, -22957, 0, -6471, 0, -22956, 0, -6470, 0, -22955, 0, -6469, 0, -22954, 0, -6468, 0, -22953, 0, -6467, 0, -22952, 0, -6466, 0, -22951, 0, -6465, 0, -22950, 0, -6464, 0, -22949, 0, -6463, 0, -22948, 0, -6462, 0, -22947, 0, -6461, 0, -22946, 0, -6460, 0, -22945, 0, -6459, 0, -22944, 0, -6458, 0, -22943, 0, -6457, 0, -22942, 0, -6456, 0, -22941, 0, -6455, 0, -22940, 0, -6454, 0, -22939, 0, -6453, 0, -22938, 0, -6452, 0, -22937, 0, -6451, 0, -22936, 0, -6450, 0, -22935, 0, -6449, 0, -22934, 0, -6448, 0, -22933, 0, -6447, 0, -22932, 0, -6446, 0, -22931, 0, -6445, 0, -22930, 0, -6444, 0, -22929, 0, -6443, 0, -22928, 0, -6442, 0, -22927, 0, -6441, 0, -22926, 0, -6440, 0, -22925, 0, -6439, 0, -22924, 0, -6438, 0, -22923, 0, -6437, 0, -22922, 0, -6436, 0, -22921, 0, -6435, 0, -22920, 0, -6434, 0, -22919, 0, -6433, 0, -22918, 0, -6432, 0, -22917, 0, -6431, 0, -22916, 0, -6430, 0, -22915, 0, -6429, 0, -22914, 0, -6428, 0, -22912, 0, -6427, 0, -22911, 0, -6426, 0, -22910, 0, -6425, 0, -22909, 0, -6424, 0, -22908, 0, -6423, 0, -22907, 0, -6422, 0, -22906, 0, -6421, 0, -22905, 0, -6420, 0, -22904, 0, -6419, 0, -22903, 0, -6418, 0, -22902, 0, -6417, 0, -22901, 0, -6416, 0, -22900, 0, -6415, 0, -22899, 0, -6414, 0, -22898, 0, -6413, 0, -22897, 0, -6412, 0, -22896, 0, -6411, 0, -22895, 0, -6410, 0, -22894, 0, -6409, 0, -22893, 0, -6408, 0, -22892, 0, -6407, 0, -22891, 0, -6406, 0, -22890, 0, -6405, 0, -22889, 0, -6404, 0, -22888, 0, -6403, 0, -22887, 0, -6402, 0, -22886, 0, -6401, 0, -22885, 0, -6400, 0, -22884, 0, -6399, 0, -22883, 0, -6398, 0, -22882, 0, -6397, 0, -22881, 0, -6396, 0, -22880, 0, -6395, 0, -22879, 0, 913, 0, -22878, 0, 914, 0, -22877, 0, 915, 0, -22876, 0, 916, 0, -22875, 0, 917, 0, -22874, 0, 918, 0, -22873, 0, 919, 0, -22872, 0, 920, 0, -22871, 0, 921, 0, -22870, 0, 922, 0, -22869, 0, 923, 0, -22868, 0, 924, 0, -22867, 0, 925, 0, -22866, 0, 926, 0, -22865, 0, 927, 0, -22864, 0, 928, 0, -22863, 0, 929, 0, -22862, 0, 931, 0, -22861, 0, 932, 0, -22860, 0, 933, 0, -22859, 0, 934, 0, -22858, 0, 935, 0, -22857, 0, 936, 0, -22856, 0, 937, 0, -22855, 0, -6267, 0, -22854, 0, -6266, 0, -22853, 0, -6265, 0, -22852, 0, -6264, 0, -22851, 0, -6263, 0, -22850, 0, -6262, 0, -22849, 0, -6261, 0, -22848, 0, -6260, 0, -22847, 0, 945, 0, -22846, 0, 946, 0, -22845, 0, 947, 0, -22844, 0, 948, 0, -22843, 0, 949, 0, -22842, 0, 950, 0, -22841, 0, 951, 0, -22840, 0, 952, 0, -22839, 0, 953, 0, -22838, 0, 954, 0, -22837, 0, 955, 0, -22836, 0, 956, 0, -22835, 0, 957, 0, -22834, 0, 958, 0, -22833, 0, 959, 0, -22832, 0, 960, 0, -22831, 0, 961, 0, -22830, 0, 963, 0, -22829, 0, 964, 0, -22828, 0, 965, 0, -22827, 0, 966, 0, -22826, 0, 967, 0, -22825, 0, 968, 0, -22824, 0, 969, 0, -22823, 0, -6259, 0, -22822, 0, -6258, 0, -22821, 0, -6257, 0, -22820, 0, -6256, 0, -22819, 0, -6255, 0, -22818, 0, -6254, 0, -22817, 0, -6253, 0, -22816, 0, -459, 0, -22815, 0, -458, 0, -22814, 0, -455, 0, -22813, 0, -454, 0, -22812, 0, -449, 0, -22811, 0, -448, 0, -22810, 0, -451, 0, -22809, 0, -450, 0, -22808, 0, -447, 0, -22807, 0, -446, 0, -22806, 0, -445, 0, -22805, 0, -444, 0, -22804, 0, -6252, 0, -22803, 0, -6251, 0, -22802, 0, -453, 0, -22801, 0, -452, 0, -22800, 0, -457, 0, -22799, 0, -456, 0, -22798, 0, -463, 0, -22797, 0, -6250, 0, -22796, 0, -461, 0, -22795, 0, -460, 0, -22794, 0, -6249, 0, -22793, 0, -6248, 0, -22792, 0, -6247, 0, -22791, 0, -6246, 0, -22790, 0, -6245, 0, -22789, 0, -6244, 0, -22788, 0, -6243, 0, -22787, 0, -6242, 0, -22786, 0, -6241, 0, -22720, 0, -6394, 0, -22719, 0, -6393, 0, -22718, 0, -6392, 0, -22717, 0, -6391, 0, -22716, 0, -6390, 0, -22715, 0, -6389, 0, -22714, 0, -6388, 0, -22713, 0, -6387, 0, -22712, 0, -6386, 0, -22711, 0, -6385, 0, -22710, 0, -6384, 0, -22709, 0, -6383, 0, -22708, 0, -6382, 0, -22707, 0, -6381, 0, -22706, 0, -6380, 0, -22705, 0, -6379, 0, -22704, 0, -6378, 0, -22703, 0, -6377, 0, -22702, 0, -6376, 0, -22701, 0, -6375, 0, -22700, 0, -6374, 0, -22699, 0, -6373, 0, -22698, 0, -6372, 0, -22697, 0, -6371, 0, -22696, 0, -6370, 0, -22695, 0, -6369, 0, -22694, 0, -6368, 0, -22693, 0, -6367, 0, -22692, 0, -6366, 0, -22691, 0, -6365, 0, -22690, 0, -6364, 0, -22689, 0, -6363, 0, -22688, 0, -6362, 0, -22687, 0, -6361, 0, -22686, 0, -6360, 0, -22685, 0, -6359, 0, -22684, 0, -6358, 0, -22683, 0, -6357, 0, -22682, 0, -6356, 0, -22681, 0, -6355, 0, -22680, 0, -6354, 0, -22679, 0, -6353, 0, -22678, 0, -6352, 0, -22677, 0, -6351, 0, -22676, 0, -6350, 0, -22675, 0, -6349, 0, -22674, 0, -6348, 0, -22673, 0, -6347, 0, -22672, 0, -6346, 0, -22671, 0, -6345, 0, -22670, 0, -6344, 0, -22669, 0, -6343, 0, -22668, 0, -6342, 0, -22667, 0, -6341, 0, -22666, 0, -6340, 0, -22665, 0, -6339, 0, -22664, 0, -6338, 0, -22663, 0, -6337, 0, -22662, 0, -6336, 0, -22661, 0, -6335, 0, -22660, 0, -6334, 0, -22659, 0, -6333, 0, -22658, 0, -6332, 0, -22656, 0, -6331, 0, -22655, 0, -6330, 0, -22654, 0, -6329, 0, -22653, 0, -6328, 0, -22652, 0, -6327, 0, -22651, 0, -6326, 0, -22650, 0, -6325, 0, -22649, 0, -6324, 0, -22648, 0, -6323, 0, -22647, 0, -6322, 0, -22646, 0, -6321, 0, -22645, 0, -6320, 0, -22644, 0, -6319, 0, -22643, 0, -6318, 0, -22642, 0, -6317, 0, -22641, 0, -6316, 0, -22640, 0, -6315, 0, -22639, 0, -6314, 0, -22638, 0, -6313, 0, -22637, 0, -6312, 0, -22636, 0, -6311, 0, -22635, 0, -6310, 0, -22634, 0, -6309, 0, -22633, 0, -6308, 0, -22632, 0, -6307, 0, -22631, 0, -6306, 0, -22630, 0, -6305, 0, -22629, 0, -6304, 0, -22628, 0, -6303, 0, -22627, 0, -6302, 0, -22626, 0, -6301, 0, -22625, 0, -6300, 0, -22624, 0, -6299, 0, -22623, 0, 1040, 0, -22622, 0, 1041, 0, -22621, 0, 1042, 0, -22620, 0, 1043, 0, -22619, 0, 1044, 0, -22618, 0, 1045, 0, -22617, 0, 1025, 0, -22616, 0, 1046, 0, -22615, 0, 1047, 0, -22614, 0, 1048, 0, -22613, 0, 1049, 0, -22612, 0, 1050, 0, -22611, 0, 1051, 0, -22610, 0, 1052, 0, -22609, 0, 1053, 0, -22608, 0, 1054, 0, -22607, 0, 1055, 0, -22606, 0, 1056, 0, -22605, 0, 1057, 0, -22604, 0, 1058, 0, -22603, 0, 1059, 0, -22602, 0, 1060, 0, -22601, 0, 1061, 0, -22600, 0, 1062, 0, -22599, 0, 1063, 0, -22598, 0, 1064, 0, -22597, 0, 1065, 0, -22596, 0, 1066, 0, -22595, 0, 1067, 0, -22594, 0, 1068, 0, -22593, 0, 1069, 0, -22592, 0, 1070, 0, -22591, 0, 1071, 0, -22590, 0, -6240, 0, -22589, 0, -6239, 0, -22588, 0, -6238, 0, -22587, 0, -6237, 0, -22586, 0, -6236, 0, -22585, 0, -6235, 0, -22584, 0, -6234, 0, -22583, 0, -6233, 0, -22582, 0, -6232, 0, -22581, 0, -6231, 0, -22580, 0, -6230, 0, -22579, 0, -6229, 0, -22578, 0, -6228, 0, -22577, 0, -6227, 0, -22576, 0, -6226, 0, -22575, 0, 1072, 0, -22574, 0, 1073, 0, -22573, 0, 1074, 0, -22572, 0, 1075, 0, -22571, 0, 1076, 0, -22570, 0, 1077, 0, -22569, 0, 1105, 0, -22568, 0, 1078, 0, -22567, 0, 1079, 0, -22566, 0, 1080, 0, -22565, 0, 1081, 0, -22564, 0, 1082, 0, -22563, 0, 1083, 0, -22562, 0, 1084, 0, -22561, 0, 1085, 0, -22560, 0, 1086, 0, -22559, 0, 1087, 0, -22558, 0, 1088, 0, -22557, 0, 1089, 0, -22556, 0, 1090, 0, -22555, 0, 1091, 0, -22554, 0, 1092, 0, -22553, 0, 1093, 0, -22552, 0, 1094, 0, -22551, 0, 1095, 0, -22550, 0, 1096, 0, -22549, 0, 1097, 0, -22548, 0, 1098, 0, -22547, 0, 1099, 0, -22546, 0, 1100, 0, -22545, 0, 1101, 0, -22544, 0, 1102, 0, -22543, 0, 1103, 0, -22542, 0, -6225, 0, -22541, 0, -6224, 0, -22540, 0, -6223, 0, -22539, 0, -6222, 0, -22538, 0, -6221, 0, -22537, 0, -6220, 0, -22536, 0, -6219, 0, -22535, 0, -6218, 0, -22534, 0, -6217, 0, -22533, 0, -6216, 0, -22532, 0, -6215, 0, -22531, 0, -6214, 0, -22530, 0, -6213, 0, -22464, 0, 714, 0, -22463, 0, 715, 0, -22462, 0, 729, 0, -22461, 0, 8211, 0, -22460, 0, 8213, 0, -22459, 0, 8229, 0, -22458, 0, 8245, 0, -22457, 0, 8453, 0, -22456, 0, 8457, 0, -22455, 0, 8598, 0, -22454, 0, 8599, 0, -22453, 0, 8600, 0, -22452, 0, 8601, 0, -22451, 0, 8725, 0, -22450, 0, 8735, 0, -22449, 0, 8739, 0, -22448, 0, 8786, 0, -22447, 0, 8806, 0, -22446, 0, 8807, 0, -22445, 0, 8895, 0, -22444, 0, 9552, 0, -22443, 0, 9553, 0, -22442, 0, 9554, 0, -22441, 0, 9555, 0, -22440, 0, 9556, 0, -22439, 0, 9557, 0, -22438, 0, 9558, 0, -22437, 0, 9559, 0, -22436, 0, 9560, 0, -22435, 0, 9561, 0, -22434, 0, 9562, 0, -22433, 0, 9563, 0, -22432, 0, 9564, 0, -22431, 0, 9565, 0, -22430, 0, 9566, 0, -22429, 0, 9567, 0, -22428, 0, 9568, 0, -22427, 0, 9569, 0, -22426, 0, 9570, 0, -22425, 0, 9571, 0, -22424, 0, 9572, 0, -22423, 0, 9573, 0, -22422, 0, 9574, 0, -22421, 0, 9575, 0, -22420, 0, 9576, 0, -22419, 0, 9577, 0, -22418, 0, 9578, 0, -22417, 0, 9579, 0, -22416, 0, 9580, 0, -22415, 0, 9581, 0, -22414, 0, 9582, 0, -22413, 0, 9583, 0, -22412, 0, 9584, 0, -22411, 0, 9585, 0, -22410, 0, 9586, 0, -22409, 0, 9587, 0, -22408, 0, 9601, 0, -22407, 0, 9602, 0, -22406, 0, 9603, 0, -22405, 0, 9604, 0, -22404, 0, 9605, 0, -22403, 0, 9606, 0, -22402, 0, 9607, 0, -22400, 0, 9608, 0, -22399, 0, 9609, 0, -22398, 0, 9610, 0, -22397, 0, 9611, 0, -22396, 0, 9612, 0, -22395, 0, 9613, 0, -22394, 0, 9614, 0, -22393, 0, 9615, 0, -22392, 0, 9619, 0, -22391, 0, 9620, 0, -22390, 0, 9621, 0, -22389, 0, 9660, 0, -22388, 0, 9661, 0, -22387, 0, 9698, 0, -22386, 0, 9699, 0, -22385, 0, 9700, 0, -22384, 0, 9701, 0, -22383, 0, 9737, 0, -22382, 0, 8853, 0, -22381, 0, 12306, 0, -22380, 0, 12317, 0, -22379, 0, 12318, 0, -22378, 0, -6212, 0, -22377, 0, -6211, 0, -22376, 0, -6210, 0, -22375, 0, -6209, 0, -22374, 0, -6208, 0, -22373, 0, -6207, 0, -22372, 0, -6206, 0, -22371, 0, -6205, 0, -22370, 0, -6204, 0, -22369, 0, -6203, 0, -22368, 0, -6202, 0, -22367, 0, 257, 0, -22366, 0, 225, 0, -22365, 0, 462, 0, -22364, 0, 224, 0, -22363, 0, 275, 0, -22362, 0, 233, 0, -22361, 0, 283, 0, -22360, 0, 232, 0, -22359, 0, 299, 0, -22358, 0, 237, 0, -22357, 0, 464, 0, -22356, 0, 236, 0, -22355, 0, 333, 0, -22354, 0, 243, 0, -22353, 0, 466, 0, -22352, 0, 242, 0, -22351, 0, 363, 0, -22350, 0, 250, 0, -22349, 0, 468, 0, -22348, 0, 249, 0, -22347, 0, 470, 0, -22346, 0, 472, 0, -22345, 0, 474, 0, -22344, 0, 476, 0, -22343, 0, 252, 0, -22342, 0, 234, 0, -22341, 0, 593, 0, -22340, 0, 7743, 0, -22339, 0, 324, 0, -22338, 0, 328, 0, -22337, 0, -6200, 0, -22336, 0, 609, 0, -22335, 0, -6199, 0, -22334, 0, -6198, 0, -22333, 0, -6197, 0, -22332, 0, -6196, 0, -22331, 0, 12549, 0, -22330, 0, 12550, 0, -22329, 0, 12551, 0, -22328, 0, 12552, 0, -22327, 0, 12553, 0, -22326, 0, 12554, 0, -22325, 0, 12555, 0, -22324, 0, 12556, 0, -22323, 0, 12557, 0, -22322, 0, 12558, 0, -22321, 0, 12559, 0, -22320, 0, 12560, 0, -22319, 0, 12561, 0, -22318, 0, 12562, 0, -22317, 0, 12563, 0, -22316, 0, 12564, 0, -22315, 0, 12565, 0, -22314, 0, 12566, 0, -22313, 0, 12567, 0, -22312, 0, 12568, 0, -22311, 0, 12569, 0, -22310, 0, 12570, 0, -22309, 0, 12571, 0, -22308, 0, 12572, 0, -22307, 0, 12573, 0, -22306, 0, 12574, 0, -22305, 0, 12575, 0, -22304, 0, 12576, 0, -22303, 0, 12577, 0, -22302, 0, 12578, 0, -22301, 0, 12579, 0, -22300, 0, 12580, 0, -22299, 0, 12581, 0, -22298, 0, 12582, 0, -22297, 0, 12583, 0, -22296, 0, 12584, 0, -22295, 0, 12585, 0, -22294, 0, -6195, 0, -22293, 0, -6194, 0, -22292, 0, -6193, 0, -22291, 0, -6192, 0, -22290, 0, -6191, 0, -22289, 0, -6190, 0, -22288, 0, -6189, 0, -22287, 0, -6188, 0, -22286, 0, -6187, 0, -22285, 0, -6186, 0, -22284, 0, -6185, 0, -22283, 0, -6184, 0, -22282, 0, -6183, 0, -22281, 0, -6182, 0, -22280, 0, -6181, 0, -22279, 0, -6180, 0, -22278, 0, -6179, 0, -22277, 0, -6178, 0, -22276, 0, -6177, 0, -22275, 0, -6176, 0, -22274, 0, -6175, 0, -22208, 0, 12321, 0, -22207, 0, 12322, 0, -22206, 0, 12323, 0, -22205, 0, 12324, 0, -22204, 0, 12325, 0, -22203, 0, 12326, 0, -22202, 0, 12327, 0, -22201, 0, 12328, 0, -22200, 0, 12329, 0, -22199, 0, 12963, 0, -22198, 0, 13198, 0, -22197, 0, 13199, 0, -22196, 0, 13212, 0, -22195, 0, 13213, 0, -22194, 0, 13214, 0, -22193, 0, 13217, 0, -22192, 0, 13252, 0, -22191, 0, 13262, 0, -22190, 0, 13265, 0, -22189, 0, 13266, 0, -22188, 0, 13269, 0, -22187, 0, -464, 0, -22186, 0, -30, 0, -22185, 0, -28, 0, -22184, 0, -6174, 0, -22183, 0, 8481, 0, -22182, 0, 12849, 0, -22181, 0, -6173, 0, -22180, 0, 8208, 0, -22179, 0, -6172, 0, -22178, 0, -6171, 0, -22177, 0, -6170, 0, -22176, 0, 12540, 0, -22175, 0, 12443, 0, -22174, 0, 12444, 0, -22173, 0, 12541, 0, -22172, 0, 12542, 0, -22171, 0, 12294, 0, -22170, 0, 12445, 0, -22169, 0, 12446, 0, -22168, 0, -439, 0, -22167, 0, -438, 0, -22166, 0, -437, 0, -22165, 0, -436, 0, -22164, 0, -435, 0, -22163, 0, -434, 0, -22162, 0, -433, 0, -22161, 0, -432, 0, -22160, 0, -431, 0, -22159, 0, -430, 0, -22158, 0, -428, 0, -22157, 0, -427, 0, -22156, 0, -426, 0, -22155, 0, -425, 0, -22154, 0, -423, 0, -22153, 0, -422, 0, -22152, 0, -421, 0, -22151, 0, -420, 0, -22150, 0, -419, 0, -22149, 0, -418, 0, -22148, 0, -417, 0, -22147, 0, -416, 0, -22146, 0, -415, 0, -22144, 0, -414, 0, -22143, 0, -413, 0, -22142, 0, -412, 0, -22141, 0, -411, 0, -22140, 0, -410, 0, -22139, 0, -408, 0, -22138, 0, -407, 0, -22137, 0, -406, 0, -22136, 0, -405, 0, -22135, 0, -6169, 0, -22134, 0, -6168, 0, -22133, 0, -6167, 0, -22132, 0, -6166, 0, -22131, 0, -6165, 0, -22130, 0, -6164, 0, -22129, 0, -6163, 0, -22128, 0, -6162, 0, -22127, 0, -6161, 0, -22126, 0, -6160, 0, -22125, 0, -6159, 0, -22124, 0, -6158, 0, -22123, 0, -6157, 0, -22122, 0, 12295, 0, -22121, 0, -6156, 0, -22120, 0, -6155, 0, -22119, 0, -6154, 0, -22118, 0, -6153, 0, -22117, 0, -6152, 0, -22116, 0, -6151, 0, -22115, 0, -6150, 0, -22114, 0, -6149, 0, -22113, 0, -6148, 0, -22112, 0, -6147, 0, -22111, 0, -6146, 0, -22110, 0, -6145, 0, -22109, 0, -6144, 0, -22108, 0, 9472, 0, -22107, 0, 9473, 0, -22106, 0, 9474, 0, -22105, 0, 9475, 0, -22104, 0, 9476, 0, -22103, 0, 9477, 0, -22102, 0, 9478, 0, -22101, 0, 9479, 0, -22100, 0, 9480, 0, -22099, 0, 9481, 0, -22098, 0, 9482, 0, -22097, 0, 9483, 0, -22096, 0, 9484, 0, -22095, 0, 9485, 0, -22094, 0, 9486, 0, -22093, 0, 9487, 0, -22092, 0, 9488, 0, -22091, 0, 9489, 0, -22090, 0, 9490, 0, -22089, 0, 9491, 0, -22088, 0, 9492, 0, -22087, 0, 9493, 0, -22086, 0, 9494, 0, -22085, 0, 9495, 0, -22084, 0, 9496, 0, -22083, 0, 9497, 0, -22082, 0, 9498, 0, -22081, 0, 9499, 0, -22080, 0, 9500, 0, -22079, 0, 9501, 0, -22078, 0, 9502, 0, -22077, 0, 9503, 0, -22076, 0, 9504, 0, -22075, 0, 9505, 0, -22074, 0, 9506, 0, -22073, 0, 9507, 0, -22072, 0, 9508, 0, -22071, 0, 9509, 0, -22070, 0, 9510, 0, -22069, 0, 9511, 0, -22068, 0, 9512, 0, -22067, 0, 9513, 0, -22066, 0, 9514, 0, -22065, 0, 9515, 0, -22064, 0, 9516, 0, -22063, 0, 9517, 0, -22062, 0, 9518, 0, -22061, 0, 9519, 0, -22060, 0, 9520, 0, -22059, 0, 9521, 0, -22058, 0, 9522, 0, -22057, 0, 9523, 0, -22056, 0, 9524, 0, -22055, 0, 9525, 0, -22054, 0, 9526, 0, -22053, 0, 9527, 0, -22052, 0, 9528, 0, -22051, 0, 9529, 0, -22050, 0, 9530, 0, -22049, 0, 9531, 0, -22048, 0, 9532, 0, -22047, 0, 9533, 0, -22046, 0, 9534, 0, -22045, 0, 9535, 0, -22044, 0, 9536, 0, -22043, 0, 9537, 0, -22042, 0, 9538, 0, -22041, 0, 9539, 0, -22040, 0, 9540, 0, -22039, 0, 9541, 0, -22038, 0, 9542, 0, -22037, 0, 9543, 0, -22036, 0, 9544, 0, -22035, 0, 9545, 0, -22034, 0, 9546, 0, -22033, 0, 9547, 0, -22032, 0, -6143, 0, -22031, 0, -6142, 0, -22030, 0, -6141, 0, -22029, 0, -6140, 0, -22028, 0, -6139, 0, -22027, 0, -6138, 0, -22026, 0, -6137, 0, -22025, 0, -6136, 0, -22024, 0, -6135, 0, -22023, 0, -6134, 0, -22022, 0, -6133, 0, -22021, 0, -6132, 0, -22020, 0, -6131, 0, -22019, 0, -6130, 0, -22018, 0, -6129, 0, -21952, 0, 29404, 0, -21951, 0, 29405, 0, -21950, 0, 29407, 0, -21949, 0, 29410, 0, -21948, 0, 29411, 0, -21947, 0, 29412, 0, -21946, 0, 29413, 0, -21945, 0, 29414, 0, -21944, 0, 29415, 0, -21943, 0, 29418, 0, -21942, 0, 29419, 0, -21941, 0, 29429, 0, -21940, 0, 29430, 0, -21939, 0, 29433, 0, -21938, 0, 29437, 0, -21937, 0, 29438, 0, -21936, 0, 29439, 0, -21935, 0, 29440, 0, -21934, 0, 29442, 0, -21933, 0, 29444, 0, -21932, 0, 29445, 0, -21931, 0, 29446, 0, -21930, 0, 29447, 0, -21929, 0, 29448, 0, -21928, 0, 29449, 0, -21927, 0, 29451, 0, -21926, 0, 29452, 0, -21925, 0, 29453, 0, -21924, 0, 29455, 0, -21923, 0, 29456, 0, -21922, 0, 29457, 0, -21921, 0, 29458, 0, -21920, 0, 29460, 0, -21919, 0, 29464, 0, -21918, 0, 29465, 0, -21917, 0, 29466, 0, -21916, 0, 29471, 0, -21915, 0, 29472, 0, -21914, 0, 29475, 0, -21913, 0, 29476, 0, -21912, 0, 29478, 0, -21911, 0, 29479, 0, -21910, 0, 29480, 0, -21909, 0, 29485, 0, -21908, 0, 29487, 0, -21907, 0, 29488, 0, -21906, 0, 29490, 0, -21905, 0, 29491, 0, -21904, 0, 29493, 0, -21903, 0, 29494, 0, -21902, 0, 29498, 0, -21901, 0, 29499, 0, -21900, 0, 29500, 0, -21899, 0, 29501, 0, -21898, 0, 29504, 0, -21897, 0, 29505, 0, -21896, 0, 29506, 0, -21895, 0, 29507, 0, -21894, 0, 29508, 0, -21893, 0, 29509, 0, -21892, 0, 29510, 0, -21891, 0, 29511, 0, -21890, 0, 29512, 0, -21888, 0, 29513, 0, -21887, 0, 29514, 0, -21886, 0, 29515, 0, -21885, 0, 29516, 0, -21884, 0, 29518, 0, -21883, 0, 29519, 0, -21882, 0, 29521, 0, -21881, 0, 29523, 0, -21880, 0, 29524, 0, -21879, 0, 29525, 0, -21878, 0, 29526, 0, -21877, 0, 29528, 0, -21876, 0, 29529, 0, -21875, 0, 29530, 0, -21874, 0, 29531, 0, -21873, 0, 29532, 0, -21872, 0, 29533, 0, -21871, 0, 29534, 0, -21870, 0, 29535, 0, -21869, 0, 29537, 0, -21868, 0, 29538, 0, -21867, 0, 29539, 0, -21866, 0, 29540, 0, -21865, 0, 29541, 0, -21864, 0, 29542, 0, -21863, 0, 29543, 0, -21862, 0, 29544, 0, -21861, 0, 29545, 0, -21860, 0, 29546, 0, -21859, 0, 29547, 0, -21858, 0, 29550, 0, -21857, 0, 29552, 0, -21856, 0, 29553, 0, -21855, 0, -8192, 0, -21854, 0, -8191, 0, -21853, 0, -8190, 0, -21852, 0, -8189, 0, -21851, 0, -8188, 0, -21850, 0, -8187, 0, -21849, 0, -8186, 0, -21848, 0, -8185, 0, -21847, 0, -8184, 0, -21846, 0, -8183, 0, -21845, 0, -8182, 0, -21844, 0, -8181, 0, -21843, 0, -8180, 0, -21842, 0, -8179, 0, -21841, 0, -8178, 0, -21840, 0, -8177, 0, -21839, 0, -8176, 0, -21838, 0, -8175, 0, -21837, 0, -8174, 0, -21836, 0, -8173, 0, -21835, 0, -8172, 0, -21834, 0, -8171, 0, -21833, 0, -8170, 0, -21832, 0, -8169, 0, -21831, 0, -8168, 0, -21830, 0, -8167, 0, -21829, 0, -8166, 0, -21828, 0, -8165, 0, -21827, 0, -8164, 0, -21826, 0, -8163, 0, -21825, 0, -8162, 0, -21824, 0, -8161, 0, -21823, 0, -8160, 0, -21822, 0, -8159, 0, -21821, 0, -8158, 0, -21820, 0, -8157, 0, -21819, 0, -8156, 0, -21818, 0, -8155, 0, -21817, 0, -8154, 0, -21816, 0, -8153, 0, -21815, 0, -8152, 0, -21814, 0, -8151, 0, -21813, 0, -8150, 0, -21812, 0, -8149, 0, -21811, 0, -8148, 0, -21810, 0, -8147, 0, -21809, 0, -8146, 0, -21808, 0, -8145, 0, -21807, 0, -8144, 0, -21806, 0, -8143, 0, -21805, 0, -8142, 0, -21804, 0, -8141, 0, -21803, 0, -8140, 0, -21802, 0, -8139, 0, -21801, 0, -8138, 0, -21800, 0, -8137, 0, -21799, 0, -8136, 0, -21798, 0, -8135, 0, -21797, 0, -8134, 0, -21796, 0, -8133, 0, -21795, 0, -8132, 0, -21794, 0, -8131, 0, -21793, 0, -8130, 0, -21792, 0, -8129, 0, -21791, 0, -8128, 0, -21790, 0, -8127, 0, -21789, 0, -8126, 0, -21788, 0, -8125, 0, -21787, 0, -8124, 0, -21786, 0, -8123, 0, -21785, 0, -8122, 0, -21784, 0, -8121, 0, -21783, 0, -8120, 0, -21782, 0, -8119, 0, -21781, 0, -8118, 0, -21780, 0, -8117, 0, -21779, 0, -8116, 0, -21778, 0, -8115, 0, -21777, 0, -8114, 0, -21776, 0, -8113, 0, -21775, 0, -8112, 0, -21774, 0, -8111, 0, -21773, 0, -8110, 0, -21772, 0, -8109, 0, -21771, 0, -8108, 0, -21770, 0, -8107, 0, -21769, 0, -8106, 0, -21768, 0, -8105, 0, -21767, 0, -8104, 0, -21766, 0, -8103, 0, -21765, 0, -8102, 0, -21764, 0, -8101, 0, -21763, 0, -8100, 0, -21762, 0, -8099, 0, -21696, 0, 29554, 0, -21695, 0, 29555, 0, -21694, 0, 29556, 0, -21693, 0, 29557, 0, -21692, 0, 29558, 0, -21691, 0, 29559, 0, -21690, 0, 29560, 0, -21689, 0, 29561, 0, -21688, 0, 29562, 0, -21687, 0, 29563, 0, -21686, 0, 29564, 0, -21685, 0, 29565, 0, -21684, 0, 29567, 0, -21683, 0, 29568, 0, -21682, 0, 29569, 0, -21681, 0, 29570, 0, -21680, 0, 29571, 0, -21679, 0, 29573, 0, -21678, 0, 29574, 0, -21677, 0, 29576, 0, -21676, 0, 29578, 0, -21675, 0, 29580, 0, -21674, 0, 29581, 0, -21673, 0, 29583, 0, -21672, 0, 29584, 0, -21671, 0, 29586, 0, -21670, 0, 29587, 0, -21669, 0, 29588, 0, -21668, 0, 29589, 0, -21667, 0, 29591, 0, -21666, 0, 29592, 0, -21665, 0, 29593, 0, -21664, 0, 29594, 0, -21663, 0, 29596, 0, -21662, 0, 29597, 0, -21661, 0, 29598, 0, -21660, 0, 29600, 0, -21659, 0, 29601, 0, -21658, 0, 29603, 0, -21657, 0, 29604, 0, -21656, 0, 29605, 0, -21655, 0, 29606, 0, -21654, 0, 29607, 0, -21653, 0, 29608, 0, -21652, 0, 29610, 0, -21651, 0, 29612, 0, -21650, 0, 29613, 0, -21649, 0, 29617, 0, -21648, 0, 29620, 0, -21647, 0, 29621, 0, -21646, 0, 29622, 0, -21645, 0, 29624, 0, -21644, 0, 29625, 0, -21643, 0, 29628, 0, -21642, 0, 29629, 0, -21641, 0, 29630, 0, -21640, 0, 29631, 0, -21639, 0, 29633, 0, -21638, 0, 29635, 0, -21637, 0, 29636, 0, -21636, 0, 29637, 0, -21635, 0, 29638, 0, -21634, 0, 29639, 0, -21632, 0, 29643, 0, -21631, 0, 29644, 0, -21630, 0, 29646, 0, -21629, 0, 29650, 0, -21628, 0, 29651, 0, -21627, 0, 29652, 0, -21626, 0, 29653, 0, -21625, 0, 29654, 0, -21624, 0, 29655, 0, -21623, 0, 29656, 0, -21622, 0, 29658, 0, -21621, 0, 29659, 0, -21620, 0, 29660, 0, -21619, 0, 29661, 0, -21618, 0, 29663, 0, -21617, 0, 29665, 0, -21616, 0, 29666, 0, -21615, 0, 29667, 0, -21614, 0, 29668, 0, -21613, 0, 29670, 0, -21612, 0, 29672, 0, -21611, 0, 29674, 0, -21610, 0, 29675, 0, -21609, 0, 29676, 0, -21608, 0, 29678, 0, -21607, 0, 29679, 0, -21606, 0, 29680, 0, -21605, 0, 29681, 0, -21604, 0, 29683, 0, -21603, 0, 29684, 0, -21602, 0, 29685, 0, -21601, 0, 29686, 0, -21600, 0, 29687, 0, -21599, 0, -8098, 0, -21598, 0, -8097, 0, -21597, 0, -8096, 0, -21596, 0, -8095, 0, -21595, 0, -8094, 0, -21594, 0, -8093, 0, -21593, 0, -8092, 0, -21592, 0, -8091, 0, -21591, 0, -8090, 0, -21590, 0, -8089, 0, -21589, 0, -8088, 0, -21588, 0, -8087, 0, -21587, 0, -8086, 0, -21586, 0, -8085, 0, -21585, 0, -8084, 0, -21584, 0, -8083, 0, -21583, 0, -8082, 0, -21582, 0, -8081, 0, -21581, 0, -8080, 0, -21580, 0, -8079, 0, -21579, 0, -8078, 0, -21578, 0, -8077, 0, -21577, 0, -8076, 0, -21576, 0, -8075, 0, -21575, 0, -8074, 0, -21574, 0, -8073, 0, -21573, 0, -8072, 0, -21572, 0, -8071, 0, -21571, 0, -8070, 0, -21570, 0, -8069, 0, -21569, 0, -8068, 0, -21568, 0, -8067, 0, -21567, 0, -8066, 0, -21566, 0, -8065, 0, -21565, 0, -8064, 0, -21564, 0, -8063, 0, -21563, 0, -8062, 0, -21562, 0, -8061, 0, -21561, 0, -8060, 0, -21560, 0, -8059, 0, -21559, 0, -8058, 0, -21558, 0, -8057, 0, -21557, 0, -8056, 0, -21556, 0, -8055, 0, -21555, 0, -8054, 0, -21554, 0, -8053, 0, -21553, 0, -8052, 0, -21552, 0, -8051, 0, -21551, 0, -8050, 0, -21550, 0, -8049, 0, -21549, 0, -8048, 0, -21548, 0, -8047, 0, -21547, 0, -8046, 0, -21546, 0, -8045, 0, -21545, 0, -8044, 0, -21544, 0, -8043, 0, -21543, 0, -8042, 0, -21542, 0, -8041, 0, -21541, 0, -8040, 0, -21540, 0, -8039, 0, -21539, 0, -8038, 0, -21538, 0, -8037, 0, -21537, 0, -8036, 0, -21536, 0, -8035, 0, -21535, 0, -8034, 0, -21534, 0, -8033, 0, -21533, 0, -8032, 0, -21532, 0, -8031, 0, -21531, 0, -8030, 0, -21530, 0, -8029, 0, -21529, 0, -8028, 0, -21528, 0, -8027, 0, -21527, 0, -8026, 0, -21526, 0, -8025, 0, -21525, 0, -8024, 0, -21524, 0, -8023, 0, -21523, 0, -8022, 0, -21522, 0, -8021, 0, -21521, 0, -8020, 0, -21520, 0, -8019, 0, -21519, 0, -8018, 0, -21518, 0, -8017, 0, -21517, 0, -8016, 0, -21516, 0, -8015, 0, -21515, 0, -8014, 0, -21514, 0, -8013, 0, -21513, 0, -8012, 0, -21512, 0, -8011, 0, -21511, 0, -8010, 0, -21510, 0, -8009, 0, -21509, 0, -8008, 0, -21508, 0, -8007, 0, -21507, 0, -8006, 0, -21506, 0, -8005, 0, -21440, 0, 29688, 0, -21439, 0, 29689, 0, -21438, 0, 29690, 0, -21437, 0, 29691, 0, -21436, 0, 29692, 0, -21435, 0, 29693, 0, -21434, 0, 29694, 0, -21433, 0, 29695, 0, -21432, 0, 29696, 0, -21431, 0, 29697, 0, -21430, 0, 29698, 0, -21429, 0, 29700, 0, -21428, 0, 29703, 0, -21427, 0, 29704, 0, -21426, 0, 29707, 0, -21425, 0, 29708, 0, -21424, 0, 29709, 0, -21423, 0, 29710, 0, -21422, 0, 29713, 0, -21421, 0, 29714, 0, -21420, 0, 29715, 0, -21419, 0, 29716, 0, -21418, 0, 29717, 0, -21417, 0, 29718, 0, -21416, 0, 29719, 0, -21415, 0, 29720, 0, -21414, 0, 29721, 0, -21413, 0, 29724, 0, -21412, 0, 29725, 0, -21411, 0, 29726, 0, -21410, 0, 29727, 0, -21409, 0, 29728, 0, -21408, 0, 29729, 0, -21407, 0, 29731, 0, -21406, 0, 29732, 0, -21405, 0, 29735, 0, -21404, 0, 29737, 0, -21403, 0, 29739, 0, -21402, 0, 29741, 0, -21401, 0, 29743, 0, -21400, 0, 29745, 0, -21399, 0, 29746, 0, -21398, 0, 29751, 0, -21397, 0, 29752, 0, -21396, 0, 29753, 0, -21395, 0, 29754, 0, -21394, 0, 29755, 0, -21393, 0, 29757, 0, -21392, 0, 29758, 0, -21391, 0, 29759, 0, -21390, 0, 29760, 0, -21389, 0, 29762, 0, -21388, 0, 29763, 0, -21387, 0, 29764, 0, -21386, 0, 29765, 0, -21385, 0, 29766, 0, -21384, 0, 29767, 0, -21383, 0, 29768, 0, -21382, 0, 29769, 0, -21381, 0, 29770, 0, -21380, 0, 29771, 0, -21379, 0, 29772, 0, -21378, 0, 29773, 0, -21376, 0, 29774, 0, -21375, 0, 29775, 0, -21374, 0, 29776, 0, -21373, 0, 29777, 0, -21372, 0, 29778, 0, -21371, 0, 29779, 0, -21370, 0, 29780, 0, -21369, 0, 29782, 0, -21368, 0, 29784, 0, -21367, 0, 29789, 0, -21366, 0, 29792, 0, -21365, 0, 29793, 0, -21364, 0, 29794, 0, -21363, 0, 29795, 0, -21362, 0, 29796, 0, -21361, 0, 29797, 0, -21360, 0, 29798, 0, -21359, 0, 29799, 0, -21358, 0, 29800, 0, -21357, 0, 29801, 0, -21356, 0, 29802, 0, -21355, 0, 29803, 0, -21354, 0, 29804, 0, -21353, 0, 29806, 0, -21352, 0, 29807, 0, -21351, 0, 29809, 0, -21350, 0, 29810, 0, -21349, 0, 29811, 0, -21348, 0, 29812, 0, -21347, 0, 29813, 0, -21346, 0, 29816, 0, -21345, 0, 29817, 0, -21344, 0, 29818, 0, -21343, 0, -8004, 0, -21342, 0, -8003, 0, -21341, 0, -8002, 0, -21340, 0, -8001, 0, -21339, 0, -8000, 0, -21338, 0, -7999, 0, -21337, 0, -7998, 0, -21336, 0, -7997, 0, -21335, 0, -7996, 0, -21334, 0, -7995, 0, -21333, 0, -7994, 0, -21332, 0, -7993, 0, -21331, 0, -7992, 0, -21330, 0, -7991, 0, -21329, 0, -7990, 0, -21328, 0, -7989, 0, -21327, 0, -7988, 0, -21326, 0, -7987, 0, -21325, 0, -7986, 0, -21324, 0, -7985, 0, -21323, 0, -7984, 0, -21322, 0, -7983, 0, -21321, 0, -7982, 0, -21320, 0, -7981, 0, -21319, 0, -7980, 0, -21318, 0, -7979, 0, -21317, 0, -7978, 0, -21316, 0, -7977, 0, -21315, 0, -7976, 0, -21314, 0, -7975, 0, -21313, 0, -7974, 0, -21312, 0, -7973, 0, -21311, 0, -7972, 0, -21310, 0, -7971, 0, -21309, 0, -7970, 0, -21308, 0, -7969, 0, -21307, 0, -7968, 0, -21306, 0, -7967, 0, -21305, 0, -7966, 0, -21304, 0, -7965, 0, -21303, 0, -7964, 0, -21302, 0, -7963, 0, -21301, 0, -7962, 0, -21300, 0, -7961, 0, -21299, 0, -7960, 0, -21298, 0, -7959, 0, -21297, 0, -7958, 0, -21296, 0, -7957, 0, -21295, 0, -7956, 0, -21294, 0, -7955, 0, -21293, 0, -7954, 0, -21292, 0, -7953, 0, -21291, 0, -7952, 0, -21290, 0, -7951, 0, -21289, 0, -7950, 0, -21288, 0, -7949, 0, -21287, 0, -7948, 0, -21286, 0, -7947, 0, -21285, 0, -7946, 0, -21284, 0, -7945, 0, -21283, 0, -7944, 0, -21282, 0, -7943, 0, -21281, 0, -7942, 0, -21280, 0, -7941, 0, -21279, 0, -7940, 0, -21278, 0, -7939, 0, -21277, 0, -7938, 0, -21276, 0, -7937, 0, -21275, 0, -7936, 0, -21274, 0, -7935, 0, -21273, 0, -7934, 0, -21272, 0, -7933, 0, -21271, 0, -7932, 0, -21270, 0, -7931, 0, -21269, 0, -7930, 0, -21268, 0, -7929, 0, -21267, 0, -7928, 0, -21266, 0, -7927, 0, -21265, 0, -7926, 0, -21264, 0, -7925, 0, -21263, 0, -7924, 0, -21262, 0, -7923, 0, -21261, 0, -7922, 0, -21260, 0, -7921, 0, -21259, 0, -7920, 0, -21258, 0, -7919, 0, -21257, 0, -7918, 0, -21256, 0, -7917, 0, -21255, 0, -7916, 0, -21254, 0, -7915, 0, -21253, 0, -7914, 0, -21252, 0, -7913, 0, -21251, 0, -7912, 0, -21250, 0, -7911, 0, -21184, 0, 29819, 0, -21183, 0, 29820, 0, -21182, 0, 29821, 0, -21181, 0, 29823, 0, -21180, 0, 29826, 0, -21179, 0, 29828, 0, -21178, 0, 29829, 0, -21177, 0, 29830, 0, -21176, 0, 29832, 0, -21175, 0, 29833, 0, -21174, 0, 29834, 0, -21173, 0, 29836, 0, -21172, 0, 29837, 0, -21171, 0, 29839, 0, -21170, 0, 29841, 0, -21169, 0, 29842, 0, -21168, 0, 29843, 0, -21167, 0, 29844, 0, -21166, 0, 29845, 0, -21165, 0, 29846, 0, -21164, 0, 29847, 0, -21163, 0, 29848, 0, -21162, 0, 29849, 0, -21161, 0, 29850, 0, -21160, 0, 29851, 0, -21159, 0, 29853, 0, -21158, 0, 29855, 0, -21157, 0, 29856, 0, -21156, 0, 29857, 0, -21155, 0, 29858, 0, -21154, 0, 29859, 0, -21153, 0, 29860, 0, -21152, 0, 29861, 0, -21151, 0, 29862, 0, -21150, 0, 29866, 0, -21149, 0, 29867, 0, -21148, 0, 29868, 0, -21147, 0, 29869, 0, -21146, 0, 29870, 0, -21145, 0, 29871, 0, -21144, 0, 29872, 0, -21143, 0, 29873, 0, -21142, 0, 29874, 0, -21141, 0, 29875, 0, -21140, 0, 29876, 0, -21139, 0, 29877, 0, -21138, 0, 29878, 0, -21137, 0, 29879, 0, -21136, 0, 29880, 0, -21135, 0, 29881, 0, -21134, 0, 29883, 0, -21133, 0, 29884, 0, -21132, 0, 29885, 0, -21131, 0, 29886, 0, -21130, 0, 29887, 0, -21129, 0, 29888, 0, -21128, 0, 29889, 0, -21127, 0, 29890, 0, -21126, 0, 29891, 0, -21125, 0, 29892, 0, -21124, 0, 29893, 0, -21123, 0, 29894, 0, -21122, 0, 29895, 0, -21120, 0, 29896, 0, -21119, 0, 29897, 0, -21118, 0, 29898, 0, -21117, 0, 29899, 0, -21116, 0, 29900, 0, -21115, 0, 29901, 0, -21114, 0, 29902, 0, -21113, 0, 29903, 0, -21112, 0, 29904, 0, -21111, 0, 29905, 0, -21110, 0, 29907, 0, -21109, 0, 29908, 0, -21108, 0, 29909, 0, -21107, 0, 29910, 0, -21106, 0, 29911, 0, -21105, 0, 29912, 0, -21104, 0, 29913, 0, -21103, 0, 29914, 0, -21102, 0, 29915, 0, -21101, 0, 29917, 0, -21100, 0, 29919, 0, -21099, 0, 29921, 0, -21098, 0, 29925, 0, -21097, 0, 29927, 0, -21096, 0, 29928, 0, -21095, 0, 29929, 0, -21094, 0, 29930, 0, -21093, 0, 29931, 0, -21092, 0, 29932, 0, -21091, 0, 29933, 0, -21090, 0, 29936, 0, -21089, 0, 29937, 0, -21088, 0, 29938, 0, -21087, 0, -7910, 0, -21086, 0, -7909, 0, -21085, 0, -7908, 0, -21084, 0, -7907, 0, -21083, 0, -7906, 0, -21082, 0, -7905, 0, -21081, 0, -7904, 0, -21080, 0, -7903, 0, -21079, 0, -7902, 0, -21078, 0, -7901, 0, -21077, 0, -7900, 0, -21076, 0, -7899, 0, -21075, 0, -7898, 0, -21074, 0, -7897, 0, -21073, 0, -7896, 0, -21072, 0, -7895, 0, -21071, 0, -7894, 0, -21070, 0, -7893, 0, -21069, 0, -7892, 0, -21068, 0, -7891, 0, -21067, 0, -7890, 0, -21066, 0, -7889, 0, -21065, 0, -7888, 0, -21064, 0, -7887, 0, -21063, 0, -7886, 0, -21062, 0, -7885, 0, -21061, 0, -7884, 0, -21060, 0, -7883, 0, -21059, 0, -7882, 0, -21058, 0, -7881, 0, -21057, 0, -7880, 0, -21056, 0, -7879, 0, -21055, 0, -7878, 0, -21054, 0, -7877, 0, -21053, 0, -7876, 0, -21052, 0, -7875, 0, -21051, 0, -7874, 0, -21050, 0, -7873, 0, -21049, 0, -7872, 0, -21048, 0, -7871, 0, -21047, 0, -7870, 0, -21046, 0, -7869, 0, -21045, 0, -7868, 0, -21044, 0, -7867, 0, -21043, 0, -7866, 0, -21042, 0, -7865, 0, -21041, 0, -7864, 0, -21040, 0, -7863, 0, -21039, 0, -7862, 0, -21038, 0, -7861, 0, -21037, 0, -7860, 0, -21036, 0, -7859, 0, -21035, 0, -7858, 0, -21034, 0, -7857, 0, -21033, 0, -7856, 0, -21032, 0, -7855, 0, -21031, 0, -7854, 0, -21030, 0, -7853, 0, -21029, 0, -7852, 0, -21028, 0, -7851, 0, -21027, 0, -7850, 0, -21026, 0, -7849, 0, -21025, 0, -7848, 0, -21024, 0, -7847, 0, -21023, 0, -7846, 0, -21022, 0, -7845, 0, -21021, 0, -7844, 0, -21020, 0, -7843, 0, -21019, 0, -7842, 0, -21018, 0, -7841, 0, -21017, 0, -7840, 0, -21016, 0, -7839, 0, -21015, 0, -7838, 0, -21014, 0, -7837, 0, -21013, 0, -7836, 0, -21012, 0, -7835, 0, -21011, 0, -7834, 0, -21010, 0, -7833, 0, -21009, 0, -7832, 0, -21008, 0, -7831, 0, -21007, 0, -7830, 0, -21006, 0, -7829, 0, -21005, 0, -7828, 0, -21004, 0, -7827, 0, -21003, 0, -7826, 0, -21002, 0, -7825, 0, -21001, 0, -7824, 0, -21000, 0, -7823, 0, -20999, 0, -7822, 0, -20998, 0, -7821, 0, -20997, 0, -7820, 0, -20996, 0, -7819, 0, -20995, 0, -7818, 0, -20994, 0, -7817, 0, -20928, 0, 29939, 0, -20927, 0, 29941, 0, -20926, 0, 29944, 0, -20925, 0, 29945, 0, -20924, 0, 29946, 0, -20923, 0, 29947, 0, -20922, 0, 29948, 0, -20921, 0, 29949, 0, -20920, 0, 29950, 0, -20919, 0, 29952, 0, -20918, 0, 29953, 0, -20917, 0, 29954, 0, -20916, 0, 29955, 0, -20915, 0, 29957, 0, -20914, 0, 29958, 0, -20913, 0, 29959, 0, -20912, 0, 29960, 0, -20911, 0, 29961, 0, -20910, 0, 29962, 0, -20909, 0, 29963, 0, -20908, 0, 29964, 0, -20907, 0, 29966, 0, -20906, 0, 29968, 0, -20905, 0, 29970, 0, -20904, 0, 29972, 0, -20903, 0, 29973, 0, -20902, 0, 29974, 0, -20901, 0, 29975, 0, -20900, 0, 29979, 0, -20899, 0, 29981, 0, -20898, 0, 29982, 0, -20897, 0, 29984, 0, -20896, 0, 29985, 0, -20895, 0, 29986, 0, -20894, 0, 29987, 0, -20893, 0, 29988, 0, -20892, 0, 29990, 0, -20891, 0, 29991, 0, -20890, 0, 29994, 0, -20889, 0, 29998, 0, -20888, 0, 30004, 0, -20887, 0, 30006, 0, -20886, 0, 30009, 0, -20885, 0, 30012, 0, -20884, 0, 30013, 0, -20883, 0, 30015, 0, -20882, 0, 30017, 0, -20881, 0, 30018, 0, -20880, 0, 30019, 0, -20879, 0, 30020, 0, -20878, 0, 30022, 0, -20877, 0, 30023, 0, -20876, 0, 30025, 0, -20875, 0, 30026, 0, -20874, 0, 30029, 0, -20873, 0, 30032, 0, -20872, 0, 30033, 0, -20871, 0, 30034, 0, -20870, 0, 30035, 0, -20869, 0, 30037, 0, -20868, 0, 30038, 0, -20867, 0, 30039, 0, -20866, 0, 30040, 0, -20864, 0, 30045, 0, -20863, 0, 30046, 0, -20862, 0, 30047, 0, -20861, 0, 30048, 0, -20860, 0, 30049, 0, -20859, 0, 30050, 0, -20858, 0, 30051, 0, -20857, 0, 30052, 0, -20856, 0, 30055, 0, -20855, 0, 30056, 0, -20854, 0, 30057, 0, -20853, 0, 30059, 0, -20852, 0, 30060, 0, -20851, 0, 30061, 0, -20850, 0, 30062, 0, -20849, 0, 30063, 0, -20848, 0, 30064, 0, -20847, 0, 30065, 0, -20846, 0, 30067, 0, -20845, 0, 30069, 0, -20844, 0, 30070, 0, -20843, 0, 30071, 0, -20842, 0, 30074, 0, -20841, 0, 30075, 0, -20840, 0, 30076, 0, -20839, 0, 30077, 0, -20838, 0, 30078, 0, -20837, 0, 30080, 0, -20836, 0, 30081, 0, -20835, 0, 30082, 0, -20834, 0, 30084, 0, -20833, 0, 30085, 0, -20832, 0, 30087, 0, -20831, 0, -7816, 0, -20830, 0, -7815, 0, -20829, 0, -7814, 0, -20828, 0, -7813, 0, -20827, 0, -7812, 0, -20826, 0, -7811, 0, -20825, 0, -7810, 0, -20824, 0, -7809, 0, -20823, 0, -7808, 0, -20822, 0, -7807, 0, -20821, 0, -7806, 0, -20820, 0, -7805, 0, -20819, 0, -7804, 0, -20818, 0, -7803, 0, -20817, 0, -7802, 0, -20816, 0, -7801, 0, -20815, 0, -7800, 0, -20814, 0, -7799, 0, -20813, 0, -7798, 0, -20812, 0, -7797, 0, -20811, 0, -7796, 0, -20810, 0, -7795, 0, -20809, 0, -7794, 0, -20808, 0, -7793, 0, -20807, 0, -7792, 0, -20806, 0, -7791, 0, -20805, 0, -7790, 0, -20804, 0, -7789, 0, -20803, 0, -7788, 0, -20802, 0, -7787, 0, -20801, 0, -7786, 0, -20800, 0, -7785, 0, -20799, 0, -7784, 0, -20798, 0, -7783, 0, -20797, 0, -7782, 0, -20796, 0, -7781, 0, -20795, 0, -7780, 0, -20794, 0, -7779, 0, -20793, 0, -7778, 0, -20792, 0, -7777, 0, -20791, 0, -7776, 0, -20790, 0, -7775, 0, -20789, 0, -7774, 0, -20788, 0, -7773, 0, -20787, 0, -7772, 0, -20786, 0, -7771, 0, -20785, 0, -7770, 0, -20784, 0, -7769, 0, -20783, 0, -7768, 0, -20782, 0, -7767, 0, -20781, 0, -7766, 0, -20780, 0, -7765, 0, -20779, 0, -7764, 0, -20778, 0, -7763, 0, -20777, 0, -7762, 0, -20776, 0, -7761, 0, -20775, 0, -7760, 0, -20774, 0, -7759, 0, -20773, 0, -7758, 0, -20772, 0, -7757, 0, -20771, 0, -7756, 0, -20770, 0, -7755, 0, -20769, 0, -7754, 0, -20768, 0, -7753, 0, -20767, 0, -7752, 0, -20766, 0, -7751, 0, -20765, 0, -7750, 0, -20764, 0, -7749, 0, -20763, 0, -7748, 0, -20762, 0, -7747, 0, -20761, 0, -7746, 0, -20760, 0, -7745, 0, -20759, 0, -7744, 0, -20758, 0, -7743, 0, -20757, 0, -7742, 0, -20756, 0, -7741, 0, -20755, 0, -7740, 0, -20754, 0, -7739, 0, -20753, 0, -7738, 0, -20752, 0, -7737, 0, -20751, 0, -7736, 0, -20750, 0, -7735, 0, -20749, 0, -7734, 0, -20748, 0, -7733, 0, -20747, 0, -7732, 0, -20746, 0, -7731, 0, -20745, 0, -7730, 0, -20744, 0, -7729, 0, -20743, 0, -7728, 0, -20742, 0, -7727, 0, -20741, 0, -7726, 0, -20740, 0, -7725, 0, -20739, 0, -7724, 0, -20738, 0, -7723, 0, -20672, 0, 30088, 0, -20671, 0, 30089, 0, -20670, 0, 30090, 0, -20669, 0, 30092, 0, -20668, 0, 30093, 0, -20667, 0, 30094, 0, -20666, 0, 30096, 0, -20665, 0, 30099, 0, -20664, 0, 30101, 0, -20663, 0, 30104, 0, -20662, 0, 30107, 0, -20661, 0, 30108, 0, -20660, 0, 30110, 0, -20659, 0, 30114, 0, -20658, 0, 30118, 0, -20657, 0, 30119, 0, -20656, 0, 30120, 0, -20655, 0, 30121, 0, -20654, 0, 30122, 0, -20653, 0, 30125, 0, -20652, 0, 30134, 0, -20651, 0, 30135, 0, -20650, 0, 30138, 0, -20649, 0, 30139, 0, -20648, 0, 30143, 0, -20647, 0, 30144, 0, -20646, 0, 30145, 0, -20645, 0, 30150, 0, -20644, 0, 30155, 0, -20643, 0, 30156, 0, -20642, 0, 30158, 0, -20641, 0, 30159, 0, -20640, 0, 30160, 0, -20639, 0, 30161, 0, -20638, 0, 30163, 0, -20637, 0, 30167, 0, -20636, 0, 30169, 0, -20635, 0, 30170, 0, -20634, 0, 30172, 0, -20633, 0, 30173, 0, -20632, 0, 30175, 0, -20631, 0, 30176, 0, -20630, 0, 30177, 0, -20629, 0, 30181, 0, -20628, 0, 30185, 0, -20627, 0, 30188, 0, -20626, 0, 30189, 0, -20625, 0, 30190, 0, -20624, 0, 30191, 0, -20623, 0, 30194, 0, -20622, 0, 30195, 0, -20621, 0, 30197, 0, -20620, 0, 30198, 0, -20619, 0, 30199, 0, -20618, 0, 30200, 0, -20617, 0, 30202, 0, -20616, 0, 30203, 0, -20615, 0, 30205, 0, -20614, 0, 30206, 0, -20613, 0, 30210, 0, -20612, 0, 30212, 0, -20611, 0, 30214, 0, -20610, 0, 30215, 0, -20608, 0, 30216, 0, -20607, 0, 30217, 0, -20606, 0, 30219, 0, -20605, 0, 30221, 0, -20604, 0, 30222, 0, -20603, 0, 30223, 0, -20602, 0, 30225, 0, -20601, 0, 30226, 0, -20600, 0, 30227, 0, -20599, 0, 30228, 0, -20598, 0, 30230, 0, -20597, 0, 30234, 0, -20596, 0, 30236, 0, -20595, 0, 30237, 0, -20594, 0, 30238, 0, -20593, 0, 30241, 0, -20592, 0, 30243, 0, -20591, 0, 30247, 0, -20590, 0, 30248, 0, -20589, 0, 30252, 0, -20588, 0, 30254, 0, -20587, 0, 30255, 0, -20586, 0, 30257, 0, -20585, 0, 30258, 0, -20584, 0, 30262, 0, -20583, 0, 30263, 0, -20582, 0, 30265, 0, -20581, 0, 30266, 0, -20580, 0, 30267, 0, -20579, 0, 30269, 0, -20578, 0, 30273, 0, -20577, 0, 30274, 0, -20576, 0, 30276, 0, -20575, 0, -7722, 0, -20574, 0, -7721, 0, -20573, 0, -7720, 0, -20572, 0, -7719, 0, -20571, 0, -7718, 0, -20570, 0, -7717, 0, -20569, 0, -7716, 0, -20568, 0, -7715, 0, -20567, 0, -7714, 0, -20566, 0, -7713, 0, -20565, 0, -7712, 0, -20564, 0, -7711, 0, -20563, 0, -7710, 0, -20562, 0, -7709, 0, -20561, 0, -7708, 0, -20560, 0, -7707, 0, -20559, 0, -7706, 0, -20558, 0, -7705, 0, -20557, 0, -7704, 0, -20556, 0, -7703, 0, -20555, 0, -7702, 0, -20554, 0, -7701, 0, -20553, 0, -7700, 0, -20552, 0, -7699, 0, -20551, 0, -7698, 0, -20550, 0, -7697, 0, -20549, 0, -7696, 0, -20548, 0, -7695, 0, -20547, 0, -7694, 0, -20546, 0, -7693, 0, -20545, 0, -7692, 0, -20544, 0, -7691, 0, -20543, 0, -7690, 0, -20542, 0, -7689, 0, -20541, 0, -7688, 0, -20540, 0, -7687, 0, -20539, 0, -7686, 0, -20538, 0, -7685, 0, -20537, 0, -7684, 0, -20536, 0, -7683, 0, -20535, 0, -7682, 0, -20534, 0, -7681, 0, -20533, 0, -7680, 0, -20532, 0, -7679, 0, -20531, 0, -7678, 0, -20530, 0, -7677, 0, -20529, 0, -7676, 0, -20528, 0, -7675, 0, -20527, 0, -7674, 0, -20526, 0, -7673, 0, -20525, 0, -7672, 0, -20524, 0, -7671, 0, -20523, 0, -7670, 0, -20522, 0, -7669, 0, -20521, 0, -7668, 0, -20520, 0, -7667, 0, -20519, 0, -7666, 0, -20518, 0, -7665, 0, -20517, 0, -7664, 0, -20516, 0, -7663, 0, -20515, 0, -7662, 0, -20514, 0, -7661, 0, -20513, 0, -7660, 0, -20512, 0, -7659, 0, -20511, 0, -7658, 0, -20510, 0, -7657, 0, -20509, 0, -7656, 0, -20508, 0, -7655, 0, -20507, 0, -7654, 0, -20506, 0, -7653, 0, -20505, 0, -7652, 0, -20504, 0, -7651, 0, -20503, 0, -7650, 0, -20502, 0, -7649, 0, -20501, 0, -7648, 0, -20500, 0, -7647, 0, -20499, 0, -7646, 0, -20498, 0, -7645, 0, -20497, 0, -7644, 0, -20496, 0, -7643, 0, -20495, 0, -7642, 0, -20494, 0, -7641, 0, -20493, 0, -7640, 0, -20492, 0, -7639, 0, -20491, 0, -7638, 0, -20490, 0, -7637, 0, -20489, 0, -7636, 0, -20488, 0, -7635, 0, -20487, 0, -7634, 0, -20486, 0, -7633, 0, -20485, 0, -7632, 0, -20484, 0, -7631, 0, -20483, 0, -7630, 0, -20482, 0, -7629, 0, -20416, 0, 30277, 0, -20415, 0, 30278, 0, -20414, 0, 30279, 0, -20413, 0, 30280, 0, -20412, 0, 30281, 0, -20411, 0, 30282, 0, -20410, 0, 30283, 0, -20409, 0, 30286, 0, -20408, 0, 30287, 0, -20407, 0, 30288, 0, -20406, 0, 30289, 0, -20405, 0, 30290, 0, -20404, 0, 30291, 0, -20403, 0, 30293, 0, -20402, 0, 30295, 0, -20401, 0, 30296, 0, -20400, 0, 30297, 0, -20399, 0, 30298, 0, -20398, 0, 30299, 0, -20397, 0, 30301, 0, -20396, 0, 30303, 0, -20395, 0, 30304, 0, -20394, 0, 30305, 0, -20393, 0, 30306, 0, -20392, 0, 30308, 0, -20391, 0, 30309, 0, -20390, 0, 30310, 0, -20389, 0, 30311, 0, -20388, 0, 30312, 0, -20387, 0, 30313, 0, -20386, 0, 30314, 0, -20385, 0, 30316, 0, -20384, 0, 30317, 0, -20383, 0, 30318, 0, -20382, 0, 30320, 0, -20381, 0, 30321, 0, -20380, 0, 30322, 0, -20379, 0, 30323, 0, -20378, 0, 30324, 0, -20377, 0, 30325, 0, -20376, 0, 30326, 0, -20375, 0, 30327, 0, -20374, 0, 30329, 0, -20373, 0, 30330, 0, -20372, 0, 30332, 0, -20371, 0, 30335, 0, -20370, 0, 30336, 0, -20369, 0, 30337, 0, -20368, 0, 30339, 0, -20367, 0, 30341, 0, -20366, 0, 30345, 0, -20365, 0, 30346, 0, -20364, 0, 30348, 0, -20363, 0, 30349, 0, -20362, 0, 30351, 0, -20361, 0, 30352, 0, -20360, 0, 30354, 0, -20359, 0, 30356, 0, -20358, 0, 30357, 0, -20357, 0, 30359, 0, -20356, 0, 30360, 0, -20355, 0, 30362, 0, -20354, 0, 30363, 0, -20352, 0, 30364, 0, -20351, 0, 30365, 0, -20350, 0, 30366, 0, -20349, 0, 30367, 0, -20348, 0, 30368, 0, -20347, 0, 30369, 0, -20346, 0, 30370, 0, -20345, 0, 30371, 0, -20344, 0, 30373, 0, -20343, 0, 30374, 0, -20342, 0, 30375, 0, -20341, 0, 30376, 0, -20340, 0, 30377, 0, -20339, 0, 30378, 0, -20338, 0, 30379, 0, -20337, 0, 30380, 0, -20336, 0, 30381, 0, -20335, 0, 30383, 0, -20334, 0, 30384, 0, -20333, 0, 30387, 0, -20332, 0, 30389, 0, -20331, 0, 30390, 0, -20330, 0, 30391, 0, -20329, 0, 30392, 0, -20328, 0, 30393, 0, -20327, 0, 30394, 0, -20326, 0, 30395, 0, -20325, 0, 30396, 0, -20324, 0, 30397, 0, -20323, 0, 30398, 0, -20322, 0, 30400, 0, -20321, 0, 30401, 0, -20320, 0, 30403, 0, -20319, 0, 21834, 0, -20318, 0, -27073, 0, -20317, 0, 22467, 0, -20316, 0, 25384, 0, -20315, 0, 21710, 0, -20314, 0, 21769, 0, -20313, 0, 21696, 0, -20312, 0, 30353, 0, -20311, 0, 30284, 0, -20310, 0, -31428, 0, -20309, 0, 30702, 0, -20308, 0, -32130, 0, -20307, 0, 30861, 0, -20306, 0, 29233, 0, -20305, 0, -26984, 0, -20304, 0, -26739, 0, -20303, 0, 27688, 0, -20302, 0, 23433, 0, -20301, 0, 20474, 0, -20300, 0, 25353, 0, -20299, 0, 26263, 0, -20298, 0, 23736, 0, -20297, 0, -32518, 0, -20296, 0, 26696, 0, -20295, 0, -32594, 0, -20294, 0, 26114, 0, -20293, 0, 30414, 0, -20292, 0, 20985, 0, -20291, 0, 25942, 0, -20290, 0, 29100, 0, -20289, 0, 32753, 0, -20288, 0, -30588, 0, -20287, 0, 20658, 0, -20286, 0, 22885, 0, -20285, 0, 25034, 0, -20284, 0, 28595, 0, -20283, 0, -32083, 0, -20282, 0, 25420, 0, -20281, 0, 25170, 0, -20280, 0, 21485, 0, -20279, 0, 21543, 0, -20278, 0, 31494, 0, -20277, 0, 20843, 0, -20276, 0, 30116, 0, -20275, 0, 24052, 0, -20274, 0, 25300, 0, -20273, 0, -29237, 0, -20272, 0, -26762, 0, -20271, 0, 25226, 0, -20270, 0, -32743, 0, -20269, 0, 22365, 0, -20268, 0, -26824, 0, -20267, 0, 32610, 0, -20266, 0, 29240, 0, -20265, 0, 30333, 0, -20264, 0, 26575, 0, -20263, 0, 30334, 0, -20262, 0, 25670, 0, -20261, 0, 20336, 0, -20260, 0, -29403, 0, -20259, 0, 25308, 0, -20258, 0, 31255, 0, -20257, 0, 26001, 0, -20256, 0, 29677, 0, -20255, 0, 25644, 0, -20254, 0, 25203, 0, -20253, 0, -32212, 0, -20252, 0, -26495, 0, -20251, 0, 26495, 0, -20250, 0, 29256, 0, -20249, 0, 25198, 0, -20248, 0, 25292, 0, -20247, 0, 20276, 0, -20246, 0, 29923, 0, -20245, 0, 21322, 0, -20244, 0, 21150, 0, -20243, 0, 32458, 0, -20242, 0, -28506, 0, -20241, 0, 24110, 0, -20240, 0, 26758, 0, -20239, 0, 27036, 0, -20238, 0, -32384, 0, -20237, 0, 32465, 0, -20236, 0, 26834, 0, -20235, 0, 30917, 0, -20234, 0, -31092, 0, -20233, 0, -27311, 0, -20232, 0, 20621, 0, -20231, 0, -29660, 0, -20230, 0, -32034, 0, -20229, 0, -32546, 0, -20228, 0, 21253, 0, -20227, 0, -30446, 0, -20226, 0, 21093, 0, -20160, 0, 30404, 0, -20159, 0, 30407, 0, -20158, 0, 30409, 0, -20157, 0, 30411, 0, -20156, 0, 30412, 0, -20155, 0, 30419, 0, -20154, 0, 30421, 0, -20153, 0, 30425, 0, -20152, 0, 30426, 0, -20151, 0, 30428, 0, -20150, 0, 30429, 0, -20149, 0, 30430, 0, -20148, 0, 30432, 0, -20147, 0, 30433, 0, -20146, 0, 30434, 0, -20145, 0, 30435, 0, -20144, 0, 30436, 0, -20143, 0, 30438, 0, -20142, 0, 30439, 0, -20141, 0, 30440, 0, -20140, 0, 30441, 0, -20139, 0, 30442, 0, -20138, 0, 30443, 0, -20137, 0, 30444, 0, -20136, 0, 30445, 0, -20135, 0, 30448, 0, -20134, 0, 30451, 0, -20133, 0, 30453, 0, -20132, 0, 30454, 0, -20131, 0, 30455, 0, -20130, 0, 30458, 0, -20129, 0, 30459, 0, -20128, 0, 30461, 0, -20127, 0, 30463, 0, -20126, 0, 30464, 0, -20125, 0, 30466, 0, -20124, 0, 30467, 0, -20123, 0, 30469, 0, -20122, 0, 30470, 0, -20121, 0, 30474, 0, -20120, 0, 30476, 0, -20119, 0, 30478, 0, -20118, 0, 30479, 0, -20117, 0, 30480, 0, -20116, 0, 30481, 0, -20115, 0, 30482, 0, -20114, 0, 30483, 0, -20113, 0, 30484, 0, -20112, 0, 30485, 0, -20111, 0, 30486, 0, -20110, 0, 30487, 0, -20109, 0, 30488, 0, -20108, 0, 30491, 0, -20107, 0, 30492, 0, -20106, 0, 30493, 0, -20105, 0, 30494, 0, -20104, 0, 30497, 0, -20103, 0, 30499, 0, -20102, 0, 30500, 0, -20101, 0, 30501, 0, -20100, 0, 30503, 0, -20099, 0, 30506, 0, -20098, 0, 30507, 0, -20096, 0, 30508, 0, -20095, 0, 30510, 0, -20094, 0, 30512, 0, -20093, 0, 30513, 0, -20092, 0, 30514, 0, -20091, 0, 30515, 0, -20090, 0, 30516, 0, -20089, 0, 30521, 0, -20088, 0, 30523, 0, -20087, 0, 30525, 0, -20086, 0, 30526, 0, -20085, 0, 30527, 0, -20084, 0, 30530, 0, -20083, 0, 30532, 0, -20082, 0, 30533, 0, -20081, 0, 30534, 0, -20080, 0, 30536, 0, -20079, 0, 30537, 0, -20078, 0, 30538, 0, -20077, 0, 30539, 0, -20076, 0, 30540, 0, -20075, 0, 30541, 0, -20074, 0, 30542, 0, -20073, 0, 30543, 0, -20072, 0, 30546, 0, -20071, 0, 30547, 0, -20070, 0, 30548, 0, -20069, 0, 30549, 0, -20068, 0, 30550, 0, -20067, 0, 30551, 0, -20066, 0, 30552, 0, -20065, 0, 30553, 0, -20064, 0, 30556, 0, -20063, 0, -31356, 0, -20062, 0, -26887, 0, -20061, 0, 20445, 0, -20060, 0, 22561, 0, -20059, 0, -26255, 0, -20058, 0, 23453, 0, -20057, 0, 25265, 0, -20056, 0, 25253, 0, -20055, 0, 26292, 0, -20054, 0, -29575, 0, -20053, 0, -25459, 0, -20052, 0, 29190, 0, -20051, 0, 26479, 0, -20050, 0, 30865, 0, -20049, 0, 24754, 0, -20048, 0, 21329, 0, -20047, 0, 21271, 0, -20046, 0, -28792, 0, -20045, 0, -32564, 0, -20044, 0, -29411, 0, -20043, 0, -27487, 0, -20042, 0, 20493, 0, -20041, 0, 29384, 0, -20040, 0, 22791, 0, -20039, 0, 24811, 0, -20038, 0, 28953, 0, -20037, 0, -30549, 0, -20036, 0, 22868, 0, -20035, 0, -32017, 0, -20034, 0, 26412, 0, -20033, 0, 31528, 0, -20032, 0, 23849, 0, -20031, 0, 32503, 0, -20030, 0, 29997, 0, -20029, 0, 27893, 0, -20028, 0, -29082, 0, -20027, 0, -28680, 0, -20026, 0, -28612, 0, -20025, 0, -24773, 0, -20024, 0, 27604, 0, -20023, 0, -28391, 0, -20022, 0, 31508, 0, -20021, 0, 24444, 0, -20020, 0, 30887, 0, -20019, 0, -31530, 0, -20018, 0, -31427, 0, -20017, 0, 27605, 0, -20016, 0, 27609, 0, -20015, 0, 27606, 0, -20014, 0, 24065, 0, -20013, 0, 24199, 0, -20012, 0, 30201, 0, -20011, 0, -27155, 0, -20010, 0, 25949, 0, -20009, 0, 24330, 0, -20008, 0, 24517, 0, -20007, 0, -28769, 0, -20006, 0, 22721, 0, -20005, 0, -32318, 0, -20004, 0, -28545, 0, -20003, 0, -27045, 0, -20002, 0, -26707, 0, -20001, 0, -28743, 0, -20000, 0, 32534, 0, -19999, 0, -29396, 0, -19998, 0, 25153, 0, -19997, 0, 20415, 0, -19996, 0, 21464, 0, -19995, 0, 21342, 0, -19994, 0, -28760, 0, -19993, 0, -28759, 0, -19992, 0, -28757, 0, -19991, 0, -28595, 0, -19990, 0, 26631, 0, -19989, 0, 24426, 0, -19988, 0, -32360, 0, -19987, 0, -30616, 0, -19986, 0, -25386, 0, -19985, 0, 24971, 0, -19984, 0, 21035, 0, -19983, 0, 30250, 0, -19982, 0, 24428, 0, -19981, 0, 25996, 0, -19980, 0, 28626, 0, -19979, 0, 28392, 0, -19978, 0, 23486, 0, -19977, 0, 25672, 0, -19976, 0, 20853, 0, -19975, 0, 20912, 0, -19974, 0, 26564, 0, -19973, 0, 19993, 0, -19972, 0, 31177, 0, -19971, 0, -26244, 0, -19970, 0, 28851, 0, -19904, 0, 30557, 0, -19903, 0, 30558, 0, -19902, 0, 30559, 0, -19901, 0, 30560, 0, -19900, 0, 30564, 0, -19899, 0, 30567, 0, -19898, 0, 30569, 0, -19897, 0, 30570, 0, -19896, 0, 30573, 0, -19895, 0, 30574, 0, -19894, 0, 30575, 0, -19893, 0, 30576, 0, -19892, 0, 30577, 0, -19891, 0, 30578, 0, -19890, 0, 30579, 0, -19889, 0, 30580, 0, -19888, 0, 30581, 0, -19887, 0, 30582, 0, -19886, 0, 30583, 0, -19885, 0, 30584, 0, -19884, 0, 30586, 0, -19883, 0, 30587, 0, -19882, 0, 30588, 0, -19881, 0, 30593, 0, -19880, 0, 30594, 0, -19879, 0, 30595, 0, -19878, 0, 30598, 0, -19877, 0, 30599, 0, -19876, 0, 30600, 0, -19875, 0, 30601, 0, -19874, 0, 30602, 0, -19873, 0, 30603, 0, -19872, 0, 30607, 0, -19871, 0, 30608, 0, -19870, 0, 30611, 0, -19869, 0, 30612, 0, -19868, 0, 30613, 0, -19867, 0, 30614, 0, -19866, 0, 30615, 0, -19865, 0, 30616, 0, -19864, 0, 30617, 0, -19863, 0, 30618, 0, -19862, 0, 30619, 0, -19861, 0, 30620, 0, -19860, 0, 30621, 0, -19859, 0, 30622, 0, -19858, 0, 30625, 0, -19857, 0, 30627, 0, -19856, 0, 30628, 0, -19855, 0, 30630, 0, -19854, 0, 30632, 0, -19853, 0, 30635, 0, -19852, 0, 30637, 0, -19851, 0, 30638, 0, -19850, 0, 30639, 0, -19849, 0, 30641, 0, -19848, 0, 30642, 0, -19847, 0, 30644, 0, -19846, 0, 30646, 0, -19845, 0, 30647, 0, -19844, 0, 30648, 0, -19843, 0, 30649, 0, -19842, 0, 30650, 0, -19840, 0, 30652, 0, -19839, 0, 30654, 0, -19838, 0, 30656, 0, -19837, 0, 30657, 0, -19836, 0, 30658, 0, -19835, 0, 30659, 0, -19834, 0, 30660, 0, -19833, 0, 30661, 0, -19832, 0, 30662, 0, -19831, 0, 30663, 0, -19830, 0, 30664, 0, -19829, 0, 30665, 0, -19828, 0, 30666, 0, -19827, 0, 30667, 0, -19826, 0, 30668, 0, -19825, 0, 30670, 0, -19824, 0, 30671, 0, -19823, 0, 30672, 0, -19822, 0, 30673, 0, -19821, 0, 30674, 0, -19820, 0, 30675, 0, -19819, 0, 30676, 0, -19818, 0, 30677, 0, -19817, 0, 30678, 0, -19816, 0, 30680, 0, -19815, 0, 30681, 0, -19814, 0, 30682, 0, -19813, 0, 30685, 0, -19812, 0, 30686, 0, -19811, 0, 30687, 0, -19810, 0, 30688, 0, -19809, 0, 30689, 0, -19808, 0, 30692, 0, -19807, 0, 30149, 0, -19806, 0, 24182, 0, -19805, 0, 29627, 0, -19804, 0, -31776, 0, -19803, 0, 25773, 0, -19802, 0, 25320, 0, -19801, 0, -27467, 0, -19800, 0, 27874, 0, -19799, 0, 21338, 0, -19798, 0, 21187, 0, -19797, 0, 25615, 0, -19796, 0, -27454, 0, -19795, 0, 31636, 0, -19794, 0, 20271, 0, -19793, 0, 24091, 0, -19792, 0, -32202, 0, -19791, 0, -32490, 0, -19790, 0, -32374, 0, -19789, 0, 28196, 0, -19788, 0, 27850, 0, -19787, 0, -25997, 0, -19786, 0, 25429, 0, -19785, 0, 21340, 0, -19784, 0, 21754, 0, -19783, 0, -30619, 0, -19782, 0, 22496, 0, -19781, 0, 19981, 0, -19780, 0, 24067, 0, -19779, 0, 27493, 0, -19778, 0, 31807, 0, -19777, 0, -28440, 0, -19776, 0, 24598, 0, -19775, 0, 25830, 0, -19774, 0, 29468, 0, -19773, 0, -30527, 0, -19772, 0, 26448, 0, -19771, 0, 25165, 0, -19770, 0, -29406, 0, -19769, 0, 30572, 0, -19768, 0, -29143, 0, -19767, 0, -28217, 0, -19766, 0, 24425, 0, -19765, 0, -31780, 0, -19764, 0, -31455, 0, -19763, 0, -26352, 0, -19762, 0, 21442, 0, -19761, 0, -31083, 0, -19760, 0, 27531, 0, -19759, 0, 24813, 0, -19758, 0, 24808, 0, -19757, 0, 28799, 0, -19756, 0, -32051, 0, -19755, 0, -32207, 0, -19754, 0, 20179, 0, -19753, 0, 27815, 0, -19752, 0, -31281, 0, -19751, 0, 25805, 0, -19750, 0, 31961, 0, -19749, 0, 27133, 0, -19748, 0, 26361, 0, -19747, 0, -31927, 0, -19746, 0, 21397, 0, -19745, 0, 31574, 0, -19744, 0, 20391, 0, -19743, 0, 20876, 0, -19742, 0, 27979, 0, -19741, 0, 23618, 0, -19740, 0, -29075, 0, -19739, 0, 25554, 0, -19738, 0, 21449, 0, -19737, 0, -31956, 0, -19736, 0, -31946, 0, -19735, 0, 26597, 0, -19734, 0, 30900, 0, -19733, 0, 25661, 0, -19732, 0, 23519, 0, -19731, 0, 23700, 0, -19730, 0, 24046, 0, -19729, 0, -29721, 0, -19728, 0, 25286, 0, -19727, 0, 26612, 0, -19726, 0, -29574, 0, -19725, 0, 25600, 0, -19724, 0, 25530, 0, -19723, 0, -30903, 0, -19722, 0, -26229, 0, -19721, 0, -29673, 0, -19720, 0, 32544, 0, -19719, 0, -27406, 0, -19718, 0, 20135, 0, -19717, 0, -27120, 0, -19716, 0, -26460, 0, -19715, 0, 26124, 0, -19714, 0, 29462, 0, -19648, 0, 30694, 0, -19647, 0, 30696, 0, -19646, 0, 30698, 0, -19645, 0, 30703, 0, -19644, 0, 30704, 0, -19643, 0, 30705, 0, -19642, 0, 30706, 0, -19641, 0, 30708, 0, -19640, 0, 30709, 0, -19639, 0, 30711, 0, -19638, 0, 30713, 0, -19637, 0, 30714, 0, -19636, 0, 30715, 0, -19635, 0, 30716, 0, -19634, 0, 30723, 0, -19633, 0, 30724, 0, -19632, 0, 30725, 0, -19631, 0, 30726, 0, -19630, 0, 30727, 0, -19629, 0, 30728, 0, -19628, 0, 30730, 0, -19627, 0, 30731, 0, -19626, 0, 30734, 0, -19625, 0, 30735, 0, -19624, 0, 30736, 0, -19623, 0, 30739, 0, -19622, 0, 30741, 0, -19621, 0, 30745, 0, -19620, 0, 30747, 0, -19619, 0, 30750, 0, -19618, 0, 30752, 0, -19617, 0, 30753, 0, -19616, 0, 30754, 0, -19615, 0, 30756, 0, -19614, 0, 30760, 0, -19613, 0, 30762, 0, -19612, 0, 30763, 0, -19611, 0, 30766, 0, -19610, 0, 30767, 0, -19609, 0, 30769, 0, -19608, 0, 30770, 0, -19607, 0, 30771, 0, -19606, 0, 30773, 0, -19605, 0, 30774, 0, -19604, 0, 30781, 0, -19603, 0, 30783, 0, -19602, 0, 30785, 0, -19601, 0, 30786, 0, -19600, 0, 30787, 0, -19599, 0, 30788, 0, -19598, 0, 30790, 0, -19597, 0, 30792, 0, -19596, 0, 30793, 0, -19595, 0, 30794, 0, -19594, 0, 30795, 0, -19593, 0, 30797, 0, -19592, 0, 30799, 0, -19591, 0, 30801, 0, -19590, 0, 30803, 0, -19589, 0, 30804, 0, -19588, 0, 30808, 0, -19587, 0, 30809, 0, -19586, 0, 30810, 0, -19584, 0, 30811, 0, -19583, 0, 30812, 0, -19582, 0, 30814, 0, -19581, 0, 30815, 0, -19580, 0, 30816, 0, -19579, 0, 30817, 0, -19578, 0, 30818, 0, -19577, 0, 30819, 0, -19576, 0, 30820, 0, -19575, 0, 30821, 0, -19574, 0, 30822, 0, -19573, 0, 30823, 0, -19572, 0, 30824, 0, -19571, 0, 30825, 0, -19570, 0, 30831, 0, -19569, 0, 30832, 0, -19568, 0, 30833, 0, -19567, 0, 30834, 0, -19566, 0, 30835, 0, -19565, 0, 30836, 0, -19564, 0, 30837, 0, -19563, 0, 30838, 0, -19562, 0, 30840, 0, -19561, 0, 30841, 0, -19560, 0, 30842, 0, -19559, 0, 30843, 0, -19558, 0, 30845, 0, -19557, 0, 30846, 0, -19556, 0, 30847, 0, -19555, 0, 30848, 0, -19554, 0, 30849, 0, -19553, 0, 30850, 0, -19552, 0, 30851, 0, -19551, 0, 22330, 0, -19550, 0, 23581, 0, -19549, 0, 24120, 0, -19548, 0, -27265, 0, -19547, 0, 20607, 0, -19546, 0, -32608, 0, -19545, 0, 21378, 0, -19544, 0, 25950, 0, -19543, 0, 30021, 0, -19542, 0, 21809, 0, -19541, 0, 20513, 0, -19540, 0, -29307, 0, -19539, 0, 25220, 0, -19538, 0, -27490, 0, -19537, 0, 26397, 0, -19536, 0, 22066, 0, -19535, 0, 28526, 0, -19534, 0, 24034, 0, -19533, 0, 21557, 0, -19532, 0, 28818, 0, -19531, 0, -28826, 0, -19530, 0, 25199, 0, -19529, 0, 25764, 0, -19528, 0, 25507, 0, -19527, 0, 24443, 0, -19526, 0, 28552, 0, -19525, 0, -28428, 0, -19524, 0, -32285, 0, -19523, 0, -28752, 0, -19522, 0, 23576, 0, -19521, 0, 26216, 0, -19520, 0, 24561, 0, -19519, 0, 27785, 0, -19518, 0, -27064, 0, -19517, 0, -29311, 0, -19516, 0, -30612, 0, -19515, 0, 25745, 0, -19514, 0, 31216, 0, -19513, 0, 22478, 0, -19512, 0, 27225, 0, -19511, 0, 25104, 0, -19510, 0, 21576, 0, -19509, 0, 20056, 0, -19508, 0, 31243, 0, -19507, 0, 24809, 0, -19506, 0, 28548, 0, -19505, 0, -29734, 0, -19504, 0, 25215, 0, -19503, 0, -28642, 0, -19502, 0, -25973, 0, -19501, 0, 31204, 0, -19500, 0, 21507, 0, -19499, 0, 30196, 0, -19498, 0, 25345, 0, -19497, 0, 21273, 0, -19496, 0, 27744, 0, -19495, 0, -28705, 0, -19494, 0, 24347, 0, -19493, 0, -26000, 0, -19492, 0, -32709, 0, -19491, 0, -24705, 0, -19490, 0, 20360, 0, -19489, 0, 23610, 0, -19488, 0, -29340, 0, -19487, 0, 32709, 0, -19486, 0, 26021, 0, -19485, 0, 28861, 0, -19484, 0, 20805, 0, -19483, 0, 20914, 0, -19482, 0, -31125, 0, -19481, 0, 23815, 0, -19480, 0, 23456, 0, -19479, 0, 25277, 0, -19478, 0, -28308, 0, -19477, 0, 30068, 0, -19476, 0, -29172, 0, -19475, 0, 31264, 0, -19474, 0, 24833, 0, -19473, 0, 31609, 0, -19472, 0, 20167, 0, -19471, 0, 32504, 0, -19470, 0, 30597, 0, -19469, 0, 19985, 0, -19468, 0, -32275, 0, -19467, 0, 21021, 0, -19466, 0, 20986, 0, -19465, 0, 27249, 0, -19464, 0, 21416, 0, -19463, 0, -29049, 0, -19462, 0, -27388, 0, -19461, 0, -26929, 0, -19460, 0, 28353, 0, -19459, 0, -27036, 0, -19458, 0, 26970, 0, -19392, 0, 30852, 0, -19391, 0, 30853, 0, -19390, 0, 30854, 0, -19389, 0, 30856, 0, -19388, 0, 30858, 0, -19387, 0, 30859, 0, -19386, 0, 30863, 0, -19385, 0, 30864, 0, -19384, 0, 30866, 0, -19383, 0, 30868, 0, -19382, 0, 30869, 0, -19381, 0, 30870, 0, -19380, 0, 30873, 0, -19379, 0, 30877, 0, -19378, 0, 30878, 0, -19377, 0, 30880, 0, -19376, 0, 30882, 0, -19375, 0, 30884, 0, -19374, 0, 30886, 0, -19373, 0, 30888, 0, -19372, 0, 30889, 0, -19371, 0, 30890, 0, -19370, 0, 30891, 0, -19369, 0, 30892, 0, -19368, 0, 30893, 0, -19367, 0, 30894, 0, -19366, 0, 30895, 0, -19365, 0, 30901, 0, -19364, 0, 30902, 0, -19363, 0, 30903, 0, -19362, 0, 30904, 0, -19361, 0, 30906, 0, -19360, 0, 30907, 0, -19359, 0, 30908, 0, -19358, 0, 30909, 0, -19357, 0, 30911, 0, -19356, 0, 30912, 0, -19355, 0, 30914, 0, -19354, 0, 30915, 0, -19353, 0, 30916, 0, -19352, 0, 30918, 0, -19351, 0, 30919, 0, -19350, 0, 30920, 0, -19349, 0, 30924, 0, -19348, 0, 30925, 0, -19347, 0, 30926, 0, -19346, 0, 30927, 0, -19345, 0, 30929, 0, -19344, 0, 30930, 0, -19343, 0, 30931, 0, -19342, 0, 30934, 0, -19341, 0, 30935, 0, -19340, 0, 30936, 0, -19339, 0, 30938, 0, -19338, 0, 30939, 0, -19337, 0, 30940, 0, -19336, 0, 30941, 0, -19335, 0, 30942, 0, -19334, 0, 30943, 0, -19333, 0, 30944, 0, -19332, 0, 30945, 0, -19331, 0, 30946, 0, -19330, 0, 30947, 0, -19328, 0, 30948, 0, -19327, 0, 30949, 0, -19326, 0, 30950, 0, -19325, 0, 30951, 0, -19324, 0, 30953, 0, -19323, 0, 30954, 0, -19322, 0, 30955, 0, -19321, 0, 30957, 0, -19320, 0, 30958, 0, -19319, 0, 30959, 0, -19318, 0, 30960, 0, -19317, 0, 30961, 0, -19316, 0, 30963, 0, -19315, 0, 30965, 0, -19314, 0, 30966, 0, -19313, 0, 30968, 0, -19312, 0, 30969, 0, -19311, 0, 30971, 0, -19310, 0, 30972, 0, -19309, 0, 30973, 0, -19308, 0, 30974, 0, -19307, 0, 30975, 0, -19306, 0, 30976, 0, -19305, 0, 30978, 0, -19304, 0, 30979, 0, -19303, 0, 30980, 0, -19302, 0, 30982, 0, -19301, 0, 30983, 0, -19300, 0, 30984, 0, -19299, 0, 30985, 0, -19298, 0, 30986, 0, -19297, 0, 30987, 0, -19296, 0, 30988, 0, -19295, 0, 30784, 0, -19294, 0, 20648, 0, -19293, 0, 30679, 0, -19292, 0, 25616, 0, -19291, 0, -30234, 0, -19290, 0, 22788, 0, -19289, 0, 25571, 0, -19288, 0, 24029, 0, -19287, 0, 31359, 0, -19286, 0, 26941, 0, -19285, 0, 20256, 0, -19284, 0, -32199, 0, -19283, 0, 21912, 0, -19282, 0, 20018, 0, -19281, 0, 30126, 0, -19280, 0, 31383, 0, -19279, 0, 24162, 0, -19278, 0, 24202, 0, -19277, 0, -27153, 0, -19276, 0, 21019, 0, -19275, 0, 21561, 0, -19274, 0, 28810, 0, -19273, 0, 25462, 0, -19272, 0, -27356, 0, -19271, 0, 22402, 0, -19270, 0, 26149, 0, -19269, 0, 26943, 0, -19268, 0, -28281, 0, -19267, 0, 21767, 0, -19266, 0, 28147, 0, -19265, 0, 32431, 0, -19264, 0, -30686, 0, -19263, 0, 25139, 0, -19262, 0, 32496, 0, -19261, 0, 30133, 0, -19260, 0, -31960, 0, -19259, 0, 30913, 0, -19258, 0, -26932, 0, -19257, 0, -28770, 0, -19256, 0, 24904, 0, -19255, 0, 29943, 0, -19254, 0, -29747, 0, -19253, 0, 27492, 0, -19252, 0, 21050, 0, -19251, 0, -29360, 0, -19250, 0, 27425, 0, -19249, 0, -32662, 0, -19248, 0, -31631, 0, -19247, 0, 22257, 0, -19246, 0, 21254, 0, -19245, 0, 20174, 0, -19244, 0, 19995, 0, -19243, 0, 20945, 0, -19242, 0, 31895, 0, -19241, 0, -28277, 0, -19240, 0, 31751, 0, -19239, 0, 20419, 0, -19238, 0, -29057, 0, -19237, 0, 31713, 0, -19236, 0, 31388, 0, -19235, 0, 25703, 0, -19234, 0, 23828, 0, -19233, 0, 20652, 0, -19232, 0, -32506, 0, -19231, 0, 30209, 0, -19230, 0, 31929, 0, -19229, 0, 28140, 0, -19228, 0, 32736, 0, -19227, 0, 26449, 0, -19226, 0, 23384, 0, -19225, 0, 23544, 0, -19224, 0, 30923, 0, -19223, 0, 25774, 0, -19222, 0, 25619, 0, -19221, 0, 25514, 0, -19220, 0, 25387, 0, -19219, 0, -27367, 0, -19218, 0, 25645, 0, -19217, 0, -28738, 0, -19216, 0, 31572, 0, -19215, 0, 30249, 0, -19214, 0, 25171, 0, -19213, 0, 22823, 0, -19212, 0, 21574, 0, -19211, 0, 27513, 0, -19210, 0, 20643, 0, -19209, 0, 25140, 0, -19208, 0, 24102, 0, -19207, 0, 27526, 0, -19206, 0, 20195, 0, -19205, 0, -29385, 0, -19204, 0, -30581, 0, -19203, 0, 24453, 0, -19202, 0, -28626, 0, -19136, 0, 30989, 0, -19135, 0, 30990, 0, -19134, 0, 30991, 0, -19133, 0, 30992, 0, -19132, 0, 30993, 0, -19131, 0, 30994, 0, -19130, 0, 30996, 0, -19129, 0, 30997, 0, -19128, 0, 30998, 0, -19127, 0, 30999, 0, -19126, 0, 31000, 0, -19125, 0, 31001, 0, -19124, 0, 31002, 0, -19123, 0, 31003, 0, -19122, 0, 31004, 0, -19121, 0, 31005, 0, -19120, 0, 31007, 0, -19119, 0, 31008, 0, -19118, 0, 31009, 0, -19117, 0, 31010, 0, -19116, 0, 31011, 0, -19115, 0, 31013, 0, -19114, 0, 31014, 0, -19113, 0, 31015, 0, -19112, 0, 31016, 0, -19111, 0, 31017, 0, -19110, 0, 31018, 0, -19109, 0, 31019, 0, -19108, 0, 31020, 0, -19107, 0, 31021, 0, -19106, 0, 31022, 0, -19105, 0, 31023, 0, -19104, 0, 31024, 0, -19103, 0, 31025, 0, -19102, 0, 31026, 0, -19101, 0, 31027, 0, -19100, 0, 31029, 0, -19099, 0, 31030, 0, -19098, 0, 31031, 0, -19097, 0, 31032, 0, -19096, 0, 31033, 0, -19095, 0, 31037, 0, -19094, 0, 31039, 0, -19093, 0, 31042, 0, -19092, 0, 31043, 0, -19091, 0, 31044, 0, -19090, 0, 31045, 0, -19089, 0, 31047, 0, -19088, 0, 31050, 0, -19087, 0, 31051, 0, -19086, 0, 31052, 0, -19085, 0, 31053, 0, -19084, 0, 31054, 0, -19083, 0, 31055, 0, -19082, 0, 31056, 0, -19081, 0, 31057, 0, -19080, 0, 31058, 0, -19079, 0, 31060, 0, -19078, 0, 31061, 0, -19077, 0, 31064, 0, -19076, 0, 31065, 0, -19075, 0, 31073, 0, -19074, 0, 31075, 0, -19072, 0, 31076, 0, -19071, 0, 31078, 0, -19070, 0, 31081, 0, -19069, 0, 31082, 0, -19068, 0, 31083, 0, -19067, 0, 31084, 0, -19066, 0, 31086, 0, -19065, 0, 31088, 0, -19064, 0, 31089, 0, -19063, 0, 31090, 0, -19062, 0, 31091, 0, -19061, 0, 31092, 0, -19060, 0, 31093, 0, -19059, 0, 31094, 0, -19058, 0, 31097, 0, -19057, 0, 31099, 0, -19056, 0, 31100, 0, -19055, 0, 31101, 0, -19054, 0, 31102, 0, -19053, 0, 31103, 0, -19052, 0, 31106, 0, -19051, 0, 31107, 0, -19050, 0, 31110, 0, -19049, 0, 31111, 0, -19048, 0, 31112, 0, -19047, 0, 31113, 0, -19046, 0, 31115, 0, -19045, 0, 31116, 0, -19044, 0, 31117, 0, -19043, 0, 31118, 0, -19042, 0, 31120, 0, -19041, 0, 31121, 0, -19040, 0, 31122, 0, -19039, 0, 24608, 0, -19038, 0, -32707, 0, -19037, 0, 25285, 0, -19036, 0, 20025, 0, -19035, 0, 21333, 0, -19034, 0, -28424, 0, -19033, 0, 25528, 0, -19032, 0, -32570, 0, -19031, 0, 26086, 0, -19030, 0, 27694, 0, -19029, 0, 20294, 0, -19028, 0, 24814, 0, -19027, 0, 28129, 0, -19026, 0, -29730, 0, -19025, 0, 24377, 0, -19024, 0, -31029, 0, -19023, 0, 24403, 0, -19022, 0, 25377, 0, -19021, 0, 20826, 0, -19020, 0, -31903, 0, -19019, 0, 26723, 0, -19018, 0, 20992, 0, -19017, 0, 25443, 0, -19016, 0, -29112, 0, -19015, 0, 20498, 0, -19014, 0, 23707, 0, -19013, 0, 31095, 0, -19012, 0, 23548, 0, -19011, 0, 21040, 0, -19010, 0, 31291, 0, -19009, 0, 24764, 0, -19008, 0, -28589, 0, -19007, 0, 30423, 0, -19006, 0, 24503, 0, -19005, 0, 24471, 0, -19004, 0, 30340, 0, -19003, 0, -29076, 0, -19002, 0, 28783, 0, -19001, 0, 30331, 0, -19000, 0, 31561, 0, -18999, 0, 30634, 0, -18998, 0, 20979, 0, -18997, 0, -28525, 0, -18996, 0, 22564, 0, -18995, 0, 20302, 0, -18994, 0, 28404, 0, -18993, 0, -28694, 0, -18992, 0, 25932, 0, -18991, 0, 31515, 0, -18990, 0, 29380, 0, -18989, 0, 28068, 0, -18988, 0, 32735, 0, -18987, 0, 23265, 0, -18986, 0, 25269, 0, -18985, 0, 24213, 0, -18984, 0, 22320, 0, -18983, 0, -31614, 0, -18982, 0, 31532, 0, -18981, 0, 24093, 0, -18980, 0, 24351, 0, -18979, 0, -28654, 0, -18978, 0, 32532, 0, -18977, 0, -26464, 0, -18976, 0, 25474, 0, -18975, 0, 28359, 0, -18974, 0, 30872, 0, -18973, 0, 28857, 0, -18972, 0, 20856, 0, -18971, 0, -26789, 0, -18970, 0, 22443, 0, -18969, 0, 30005, 0, -18968, 0, 20291, 0, -18967, 0, 30008, 0, -18966, 0, 24215, 0, -18965, 0, 24806, 0, -18964, 0, 22880, 0, -18963, 0, 28096, 0, -18962, 0, 27583, 0, -18961, 0, 30857, 0, -18960, 0, 21500, 0, -18959, 0, -26923, 0, -18958, 0, 20939, 0, -18957, 0, 20993, 0, -18956, 0, 25481, 0, -18955, 0, 21514, 0, -18954, 0, -27501, 0, -18953, 0, -29693, 0, -18952, 0, -29236, 0, -18951, 0, 29241, 0, -18950, 0, 30879, 0, -18949, 0, -30858, 0, -18948, 0, -28691, 0, -18947, 0, -29683, 0, -18946, 0, 21472, 0, -18880, 0, 31123, 0, -18879, 0, 31124, 0, -18878, 0, 31125, 0, -18877, 0, 31126, 0, -18876, 0, 31127, 0, -18875, 0, 31128, 0, -18874, 0, 31129, 0, -18873, 0, 31131, 0, -18872, 0, 31132, 0, -18871, 0, 31133, 0, -18870, 0, 31134, 0, -18869, 0, 31135, 0, -18868, 0, 31136, 0, -18867, 0, 31137, 0, -18866, 0, 31138, 0, -18865, 0, 31139, 0, -18864, 0, 31140, 0, -18863, 0, 31141, 0, -18862, 0, 31142, 0, -18861, 0, 31144, 0, -18860, 0, 31145, 0, -18859, 0, 31146, 0, -18858, 0, 31147, 0, -18857, 0, 31148, 0, -18856, 0, 31149, 0, -18855, 0, 31150, 0, -18854, 0, 31151, 0, -18853, 0, 31152, 0, -18852, 0, 31153, 0, -18851, 0, 31154, 0, -18850, 0, 31156, 0, -18849, 0, 31157, 0, -18848, 0, 31158, 0, -18847, 0, 31159, 0, -18846, 0, 31160, 0, -18845, 0, 31164, 0, -18844, 0, 31167, 0, -18843, 0, 31170, 0, -18842, 0, 31172, 0, -18841, 0, 31173, 0, -18840, 0, 31175, 0, -18839, 0, 31176, 0, -18838, 0, 31178, 0, -18837, 0, 31180, 0, -18836, 0, 31182, 0, -18835, 0, 31183, 0, -18834, 0, 31184, 0, -18833, 0, 31187, 0, -18832, 0, 31188, 0, -18831, 0, 31190, 0, -18830, 0, 31191, 0, -18829, 0, 31193, 0, -18828, 0, 31194, 0, -18827, 0, 31195, 0, -18826, 0, 31196, 0, -18825, 0, 31197, 0, -18824, 0, 31198, 0, -18823, 0, 31200, 0, -18822, 0, 31201, 0, -18821, 0, 31202, 0, -18820, 0, 31205, 0, -18819, 0, 31208, 0, -18818, 0, 31210, 0, -18816, 0, 31212, 0, -18815, 0, 31214, 0, -18814, 0, 31217, 0, -18813, 0, 31218, 0, -18812, 0, 31219, 0, -18811, 0, 31220, 0, -18810, 0, 31221, 0, -18809, 0, 31222, 0, -18808, 0, 31223, 0, -18807, 0, 31225, 0, -18806, 0, 31226, 0, -18805, 0, 31228, 0, -18804, 0, 31230, 0, -18803, 0, 31231, 0, -18802, 0, 31233, 0, -18801, 0, 31236, 0, -18800, 0, 31237, 0, -18799, 0, 31239, 0, -18798, 0, 31240, 0, -18797, 0, 31241, 0, -18796, 0, 31242, 0, -18795, 0, 31244, 0, -18794, 0, 31247, 0, -18793, 0, 31248, 0, -18792, 0, 31249, 0, -18791, 0, 31250, 0, -18790, 0, 31251, 0, -18789, 0, 31253, 0, -18788, 0, 31254, 0, -18787, 0, 31256, 0, -18786, 0, 31257, 0, -18785, 0, 31259, 0, -18784, 0, 31260, 0, -18783, 0, 19969, 0, -18782, 0, 30447, 0, -18781, 0, 21486, 0, -18780, 0, -27511, 0, -18779, 0, -26506, 0, -18778, 0, -24818, 0, -18777, 0, -27347, 0, -18776, 0, 23450, 0, -18775, 0, -29790, 0, -18774, 0, 20002, 0, -18773, 0, 19996, 0, -18772, 0, 20908, 0, -18771, 0, -31645, 0, -18770, 0, 25026, 0, -18769, 0, 21160, 0, -18768, 0, 26635, 0, -18767, 0, 20375, 0, -18766, 0, 24683, 0, -18765, 0, 20923, 0, -18764, 0, 27934, 0, -18763, 0, 20828, 0, -18762, 0, 25238, 0, -18761, 0, 26007, 0, -18760, 0, -27039, 0, -18759, 0, -29626, 0, -18758, 0, -28649, 0, -18757, 0, 30168, 0, -18756, 0, -28419, 0, -18755, 0, 30563, 0, -18754, 0, 27602, 0, -18753, 0, 29322, 0, -18752, 0, 29420, 0, -18751, 0, -29701, 0, -18750, 0, 22581, 0, -18749, 0, 30585, 0, -18748, 0, -29364, 0, -18747, 0, 26460, 0, -18746, 0, -27328, 0, -18745, 0, -32614, 0, -18744, 0, 24230, 0, -18743, 0, 28193, 0, -18742, 0, 22930, 0, -18741, 0, 31471, 0, -18740, 0, 30701, 0, -18739, 0, -27333, 0, -18738, 0, 27573, 0, -18737, 0, 26029, 0, -18736, 0, 32526, 0, -18735, 0, 22534, 0, -18734, 0, 20817, 0, -18733, 0, -27105, 0, -18732, 0, 23545, 0, -18731, 0, 22697, 0, -18730, 0, 21544, 0, -18729, 0, -29070, 0, -18728, 0, 25958, 0, -18727, 0, -26497, 0, -18726, 0, 22244, 0, -18725, 0, -27491, 0, -18724, 0, 30462, 0, -18723, 0, -28607, 0, -18722, 0, 25479, 0, -18721, 0, 21702, 0, -18720, 0, 22810, 0, -18719, 0, 22842, 0, -18718, 0, 22427, 0, -18717, 0, -29006, 0, -18716, 0, 26421, 0, -18715, 0, -29190, 0, -18714, 0, -32203, 0, -18713, 0, 21057, 0, -18712, 0, 24816, 0, -18711, 0, 22549, 0, -18710, 0, -30978, 0, -18709, 0, 23784, 0, -18708, 0, -25019, 0, -18707, 0, 20420, 0, -18706, 0, -26467, 0, -18705, 0, -29767, 0, -18704, 0, 23077, 0, -18703, 0, 24694, 0, -18702, 0, 21380, 0, -18701, 0, 25212, 0, -18700, 0, -28593, 0, -18699, 0, -28414, 0, -18698, 0, -26241, 0, -18697, 0, 24681, 0, -18696, 0, -32756, 0, -18695, 0, 20799, 0, -18694, 0, -32717, 0, -18693, 0, 23572, 0, -18692, 0, -26251, 0, -18691, 0, 27953, 0, -18690, 0, 20108, 0, -18624, 0, 31261, 0, -18623, 0, 31263, 0, -18622, 0, 31265, 0, -18621, 0, 31266, 0, -18620, 0, 31268, 0, -18619, 0, 31269, 0, -18618, 0, 31270, 0, -18617, 0, 31271, 0, -18616, 0, 31272, 0, -18615, 0, 31273, 0, -18614, 0, 31274, 0, -18613, 0, 31275, 0, -18612, 0, 31276, 0, -18611, 0, 31277, 0, -18610, 0, 31278, 0, -18609, 0, 31279, 0, -18608, 0, 31280, 0, -18607, 0, 31281, 0, -18606, 0, 31282, 0, -18605, 0, 31284, 0, -18604, 0, 31285, 0, -18603, 0, 31286, 0, -18602, 0, 31288, 0, -18601, 0, 31290, 0, -18600, 0, 31294, 0, -18599, 0, 31296, 0, -18598, 0, 31297, 0, -18597, 0, 31298, 0, -18596, 0, 31299, 0, -18595, 0, 31300, 0, -18594, 0, 31301, 0, -18593, 0, 31303, 0, -18592, 0, 31304, 0, -18591, 0, 31305, 0, -18590, 0, 31306, 0, -18589, 0, 31307, 0, -18588, 0, 31308, 0, -18587, 0, 31309, 0, -18586, 0, 31310, 0, -18585, 0, 31311, 0, -18584, 0, 31312, 0, -18583, 0, 31314, 0, -18582, 0, 31315, 0, -18581, 0, 31316, 0, -18580, 0, 31317, 0, -18579, 0, 31318, 0, -18578, 0, 31320, 0, -18577, 0, 31321, 0, -18576, 0, 31322, 0, -18575, 0, 31323, 0, -18574, 0, 31324, 0, -18573, 0, 31325, 0, -18572, 0, 31326, 0, -18571, 0, 31327, 0, -18570, 0, 31328, 0, -18569, 0, 31329, 0, -18568, 0, 31330, 0, -18567, 0, 31331, 0, -18566, 0, 31332, 0, -18565, 0, 31333, 0, -18564, 0, 31334, 0, -18563, 0, 31335, 0, -18562, 0, 31336, 0, -18560, 0, 31337, 0, -18559, 0, 31338, 0, -18558, 0, 31339, 0, -18557, 0, 31340, 0, -18556, 0, 31341, 0, -18555, 0, 31342, 0, -18554, 0, 31343, 0, -18553, 0, 31345, 0, -18552, 0, 31346, 0, -18551, 0, 31347, 0, -18550, 0, 31349, 0, -18549, 0, 31355, 0, -18548, 0, 31356, 0, -18547, 0, 31357, 0, -18546, 0, 31358, 0, -18545, 0, 31362, 0, -18544, 0, 31365, 0, -18543, 0, 31367, 0, -18542, 0, 31369, 0, -18541, 0, 31370, 0, -18540, 0, 31371, 0, -18539, 0, 31372, 0, -18538, 0, 31374, 0, -18537, 0, 31375, 0, -18536, 0, 31376, 0, -18535, 0, 31379, 0, -18534, 0, 31380, 0, -18533, 0, 31385, 0, -18532, 0, 31386, 0, -18531, 0, 31387, 0, -18530, 0, 31390, 0, -18529, 0, 31393, 0, -18528, 0, 31394, 0, -18527, 0, -29392, 0, -18526, 0, 21457, 0, -18525, 0, 32602, 0, -18524, 0, 31567, 0, -18523, 0, 20240, 0, -18522, 0, 20047, 0, -18521, 0, -27136, 0, -18520, 0, 27861, 0, -18519, 0, 29648, 0, -18518, 0, -31255, 0, -18517, 0, 24070, 0, -18516, 0, 30058, 0, -18515, 0, 32763, 0, -18514, 0, 27146, 0, -18513, 0, 30718, 0, -18512, 0, -27502, 0, -18511, 0, 32321, 0, -18510, 0, 20961, 0, -18509, 0, 28902, 0, -18508, 0, 21453, 0, -18507, 0, -28716, 0, -18506, 0, -31997, 0, -18505, 0, -29399, 0, -18504, 0, 29359, 0, -18503, 0, -26259, 0, -18502, 0, 27867, 0, -18501, 0, 22346, 0, -18500, 0, -32077, 0, -18499, 0, 26041, 0, -18498, 0, -32598, 0, -18497, 0, 25151, 0, -18496, 0, -27086, 0, -18495, 0, 22952, 0, -18494, 0, 20223, 0, -18493, 0, -29761, 0, -18492, 0, 32442, 0, -18491, 0, 25918, 0, -18490, 0, -31758, 0, -18489, 0, -26786, 0, -18488, 0, 21857, 0, -18487, 0, -26402, 0, -18486, 0, -32603, 0, -18485, 0, 21290, 0, -18484, 0, -29699, 0, -18483, 0, 21536, 0, -18482, 0, -32582, 0, -18481, 0, 24223, 0, -18480, 0, 27832, 0, -18479, 0, -29383, 0, -18478, 0, -32084, 0, -18477, 0, -28326, 0, -18476, 0, 21545, 0, -18475, 0, 27675, 0, -18474, 0, 20998, 0, -18473, 0, 32439, 0, -18472, 0, 22367, 0, -18471, 0, 28954, 0, -18470, 0, 27774, 0, -18469, 0, 31881, 0, -18468, 0, 22859, 0, -18467, 0, 20221, 0, -18466, 0, 24575, 0, -18465, 0, 24868, 0, -18464, 0, 31914, 0, -18463, 0, 20016, 0, -18462, 0, 23553, 0, -18461, 0, 26539, 0, -18460, 0, -30974, 0, -18459, 0, 23792, 0, -18458, 0, -27381, 0, -18457, 0, -26418, 0, -18456, 0, 30127, 0, -18455, 0, 28925, 0, -18454, 0, -28638, 0, -18453, 0, 20911, 0, -18452, 0, 32541, 0, -18451, 0, -29763, 0, -18450, 0, 22857, 0, -18449, 0, 20964, 0, -18448, 0, 20315, 0, -18447, 0, 21542, 0, -18446, 0, 22827, 0, -18445, 0, 25975, 0, -18444, 0, -32604, 0, -18443, 0, 23413, 0, -18442, 0, 25206, 0, -18441, 0, 25282, 0, -18440, 0, -28784, 0, -18439, 0, 24133, 0, -18438, 0, 27679, 0, -18437, 0, 31526, 0, -18436, 0, 20239, 0, -18435, 0, 20440, 0, -18434, 0, 26381, 0, -18368, 0, 31395, 0, -18367, 0, 31396, 0, -18366, 0, 31399, 0, -18365, 0, 31401, 0, -18364, 0, 31402, 0, -18363, 0, 31403, 0, -18362, 0, 31406, 0, -18361, 0, 31407, 0, -18360, 0, 31408, 0, -18359, 0, 31409, 0, -18358, 0, 31410, 0, -18357, 0, 31412, 0, -18356, 0, 31413, 0, -18355, 0, 31414, 0, -18354, 0, 31415, 0, -18353, 0, 31416, 0, -18352, 0, 31417, 0, -18351, 0, 31418, 0, -18350, 0, 31419, 0, -18349, 0, 31420, 0, -18348, 0, 31421, 0, -18347, 0, 31422, 0, -18346, 0, 31424, 0, -18345, 0, 31425, 0, -18344, 0, 31426, 0, -18343, 0, 31427, 0, -18342, 0, 31428, 0, -18341, 0, 31429, 0, -18340, 0, 31430, 0, -18339, 0, 31431, 0, -18338, 0, 31432, 0, -18337, 0, 31433, 0, -18336, 0, 31434, 0, -18335, 0, 31436, 0, -18334, 0, 31437, 0, -18333, 0, 31438, 0, -18332, 0, 31439, 0, -18331, 0, 31440, 0, -18330, 0, 31441, 0, -18329, 0, 31442, 0, -18328, 0, 31443, 0, -18327, 0, 31444, 0, -18326, 0, 31445, 0, -18325, 0, 31447, 0, -18324, 0, 31448, 0, -18323, 0, 31450, 0, -18322, 0, 31451, 0, -18321, 0, 31452, 0, -18320, 0, 31453, 0, -18319, 0, 31457, 0, -18318, 0, 31458, 0, -18317, 0, 31460, 0, -18316, 0, 31463, 0, -18315, 0, 31464, 0, -18314, 0, 31465, 0, -18313, 0, 31466, 0, -18312, 0, 31467, 0, -18311, 0, 31468, 0, -18310, 0, 31470, 0, -18309, 0, 31472, 0, -18308, 0, 31473, 0, -18307, 0, 31474, 0, -18306, 0, 31475, 0, -18304, 0, 31476, 0, -18303, 0, 31477, 0, -18302, 0, 31478, 0, -18301, 0, 31479, 0, -18300, 0, 31480, 0, -18299, 0, 31483, 0, -18298, 0, 31484, 0, -18297, 0, 31486, 0, -18296, 0, 31488, 0, -18295, 0, 31489, 0, -18294, 0, 31490, 0, -18293, 0, 31493, 0, -18292, 0, 31495, 0, -18291, 0, 31497, 0, -18290, 0, 31500, 0, -18289, 0, 31501, 0, -18288, 0, 31502, 0, -18287, 0, 31504, 0, -18286, 0, 31506, 0, -18285, 0, 31507, 0, -18284, 0, 31510, 0, -18283, 0, 31511, 0, -18282, 0, 31512, 0, -18281, 0, 31514, 0, -18280, 0, 31516, 0, -18279, 0, 31517, 0, -18278, 0, 31519, 0, -18277, 0, 31521, 0, -18276, 0, 31522, 0, -18275, 0, 31523, 0, -18274, 0, 31527, 0, -18273, 0, 31529, 0, -18272, 0, 31533, 0, -18271, 0, 28014, 0, -18270, 0, 28074, 0, -18269, 0, 31119, 0, -18268, 0, -30543, 0, -18267, 0, 24343, 0, -18266, 0, 29995, 0, -18265, 0, 25242, 0, -18264, 0, -28795, 0, -18263, 0, 20463, 0, -18262, 0, -28196, 0, -18261, 0, 26023, 0, -18260, 0, -32465, 0, -18259, 0, -32431, 0, -18258, 0, 24220, 0, -18257, 0, -32432, 0, -18256, 0, -29324, 0, -18255, 0, 21103, 0, -18254, 0, -30330, 0, -18253, 0, -29365, 0, -18252, 0, 22797, 0, -18251, 0, 20613, 0, -18250, 0, 20184, 0, -18249, 0, -27108, 0, -18248, 0, 29238, 0, -18247, 0, -32391, 0, -18246, 0, -29409, 0, -18245, 0, 23500, 0, -18244, 0, -29789, 0, -18243, 0, -27068, 0, -18242, 0, 22919, 0, -18241, 0, 32538, 0, -18240, 0, 21648, 0, -18239, 0, 22134, 0, -18238, 0, 22030, 0, -18237, 0, -29723, 0, -18236, 0, 25913, 0, -18235, 0, 27010, 0, -18234, 0, -27495, 0, -18233, 0, 30422, 0, -18232, 0, 28297, 0, -18231, 0, 24178, 0, -18230, 0, 29976, 0, -18229, 0, 26438, 0, -18228, 0, 26577, 0, -18227, 0, 31487, 0, -18226, 0, -32611, 0, -18225, 0, -29322, 0, -18224, 0, 24863, 0, -18223, 0, 31174, 0, -18222, 0, 25954, 0, -18221, 0, -29341, 0, -18220, 0, 20872, 0, -18219, 0, 21018, 0, -18218, 0, -27486, 0, -18217, 0, 32568, 0, -18216, 0, -32613, 0, -18215, 0, 32434, 0, -18214, 0, 23703, 0, -18213, 0, 28207, 0, -18212, 0, 26464, 0, -18211, 0, 31705, 0, -18210, 0, 30347, 0, -18209, 0, -25896, 0, -18208, 0, -32369, 0, -18207, 0, 32660, 0, -18206, 0, 31957, 0, -18205, 0, 25630, 0, -18204, 0, -27312, 0, -18203, 0, 31295, 0, -18202, 0, 21578, 0, -18201, 0, 21733, 0, -18200, 0, 27468, 0, -18199, 0, 25601, 0, -18198, 0, 25096, 0, -18197, 0, -25027, 0, -18196, 0, -32525, 0, -18195, 0, 30105, 0, -18194, 0, 21106, 0, -18193, 0, -26775, 0, -18192, 0, -31653, 0, -18191, 0, 26684, 0, -18190, 0, -31004, 0, -18189, 0, -27135, 0, -18188, 0, -26988, 0, -18187, 0, -27412, 0, -18186, 0, 20010, 0, -18185, 0, 21508, 0, -18184, 0, 32473, 0, -18183, 0, 26681, 0, -18182, 0, -29217, 0, -18181, 0, -32747, 0, -18180, 0, 26356, 0, -18179, 0, 24218, 0, -18178, 0, 32697, 0, -18112, 0, 31535, 0, -18111, 0, 31536, 0, -18110, 0, 31538, 0, -18109, 0, 31540, 0, -18108, 0, 31541, 0, -18107, 0, 31542, 0, -18106, 0, 31543, 0, -18105, 0, 31545, 0, -18104, 0, 31547, 0, -18103, 0, 31549, 0, -18102, 0, 31551, 0, -18101, 0, 31552, 0, -18100, 0, 31553, 0, -18099, 0, 31554, 0, -18098, 0, 31555, 0, -18097, 0, 31556, 0, -18096, 0, 31558, 0, -18095, 0, 31560, 0, -18094, 0, 31562, 0, -18093, 0, 31565, 0, -18092, 0, 31566, 0, -18091, 0, 31571, 0, -18090, 0, 31573, 0, -18089, 0, 31575, 0, -18088, 0, 31577, 0, -18087, 0, 31580, 0, -18086, 0, 31582, 0, -18085, 0, 31583, 0, -18084, 0, 31585, 0, -18083, 0, 31587, 0, -18082, 0, 31588, 0, -18081, 0, 31589, 0, -18080, 0, 31590, 0, -18079, 0, 31591, 0, -18078, 0, 31592, 0, -18077, 0, 31593, 0, -18076, 0, 31594, 0, -18075, 0, 31595, 0, -18074, 0, 31596, 0, -18073, 0, 31597, 0, -18072, 0, 31599, 0, -18071, 0, 31600, 0, -18070, 0, 31603, 0, -18069, 0, 31604, 0, -18068, 0, 31606, 0, -18067, 0, 31608, 0, -18066, 0, 31610, 0, -18065, 0, 31612, 0, -18064, 0, 31613, 0, -18063, 0, 31615, 0, -18062, 0, 31617, 0, -18061, 0, 31618, 0, -18060, 0, 31619, 0, -18059, 0, 31620, 0, -18058, 0, 31622, 0, -18057, 0, 31623, 0, -18056, 0, 31624, 0, -18055, 0, 31625, 0, -18054, 0, 31626, 0, -18053, 0, 31627, 0, -18052, 0, 31628, 0, -18051, 0, 31630, 0, -18050, 0, 31631, 0, -18048, 0, 31633, 0, -18047, 0, 31634, 0, -18046, 0, 31635, 0, -18045, 0, 31638, 0, -18044, 0, 31640, 0, -18043, 0, 31641, 0, -18042, 0, 31642, 0, -18041, 0, 31643, 0, -18040, 0, 31646, 0, -18039, 0, 31647, 0, -18038, 0, 31648, 0, -18037, 0, 31651, 0, -18036, 0, 31652, 0, -18035, 0, 31653, 0, -18034, 0, 31662, 0, -18033, 0, 31663, 0, -18032, 0, 31664, 0, -18031, 0, 31666, 0, -18030, 0, 31667, 0, -18029, 0, 31669, 0, -18028, 0, 31670, 0, -18027, 0, 31671, 0, -18026, 0, 31673, 0, -18025, 0, 31674, 0, -18024, 0, 31675, 0, -18023, 0, 31676, 0, -18022, 0, 31677, 0, -18021, 0, 31678, 0, -18020, 0, 31679, 0, -18019, 0, 31680, 0, -18018, 0, 31682, 0, -18017, 0, 31683, 0, -18016, 0, 31684, 0, -18015, 0, 22466, 0, -18014, 0, -32705, 0, -18013, 0, 26775, 0, -18012, 0, 24037, 0, -18011, 0, 25915, 0, -18010, 0, 21151, 0, -18009, 0, 24685, 0, -18008, 0, -24678, 0, -18007, 0, 20379, 0, -18006, 0, -29012, 0, -18005, 0, 20844, 0, -18004, 0, 23467, 0, -18003, 0, 24339, 0, -18002, 0, 24041, 0, -18001, 0, 27742, 0, -18000, 0, 25329, 0, -17999, 0, -29407, 0, -17998, 0, 20849, 0, -17997, 0, -27479, 0, -17996, 0, 21246, 0, -17995, 0, 27807, 0, -17994, 0, -32033, 0, -17993, 0, 29399, 0, -17992, 0, 22434, 0, -17991, 0, 26500, 0, -17990, 0, -29395, 0, -17989, 0, 22815, 0, -17988, 0, -28772, 0, -17987, 0, -31801, 0, -17986, 0, 21653, 0, -17985, 0, 31629, 0, -17984, 0, 20272, 0, -17983, 0, 27837, 0, -17982, 0, 23396, 0, -17981, 0, 22993, 0, -17980, 0, -24813, 0, -17979, 0, 21476, 0, -17978, 0, -31030, 0, -17977, 0, -25944, 0, -17976, 0, -29641, 0, -17975, 0, -32607, 0, -17974, 0, 25925, 0, -17973, 0, -26498, 0, -17972, 0, 22266, 0, -17971, 0, -26937, 0, -17970, 0, 21038, 0, -17969, 0, 29916, 0, -17968, 0, 21072, 0, -17967, 0, 23521, 0, -17966, 0, 25346, 0, -17965, 0, -30462, 0, -17964, 0, 20054, 0, -17963, 0, 25296, 0, -17962, 0, 24618, 0, -17961, 0, 26874, 0, -17960, 0, 20851, 0, -17959, 0, 23448, 0, -17958, 0, 20896, 0, -17957, 0, -30270, 0, -17956, 0, 31649, 0, -17955, 0, -26234, 0, -17954, 0, 32592, 0, -17953, 0, 24815, 0, -17952, 0, 28748, 0, -17951, 0, -29393, 0, -17950, 0, 20809, 0, -17949, 0, 24191, 0, -17948, 0, -28645, 0, -17947, 0, 29808, 0, -17946, 0, -30268, 0, -17945, 0, 22317, 0, -17944, 0, 30789, 0, -17943, 0, 24402, 0, -17942, 0, -24673, 0, -17941, 0, -27142, 0, -17940, 0, -28824, 0, -17939, 0, -25796, 0, -17938, 0, -29727, 0, -17937, 0, 30328, 0, -17936, 0, 26690, 0, -17935, 0, 26588, 0, -17934, 0, -29206, 0, -17933, 0, -29387, 0, -17932, 0, 21053, 0, -17931, 0, -28790, 0, -17930, 0, 28378, 0, -17929, 0, 26829, 0, -17928, 0, -27387, 0, -17927, 0, -28435, 0, -17926, 0, 22269, 0, -17925, 0, 26524, 0, -17924, 0, -30471, 0, -17923, 0, -28729, 0, -17922, 0, 21704, 0, -17856, 0, 31685, 0, -17855, 0, 31688, 0, -17854, 0, 31689, 0, -17853, 0, 31690, 0, -17852, 0, 31691, 0, -17851, 0, 31693, 0, -17850, 0, 31694, 0, -17849, 0, 31695, 0, -17848, 0, 31696, 0, -17847, 0, 31698, 0, -17846, 0, 31700, 0, -17845, 0, 31701, 0, -17844, 0, 31702, 0, -17843, 0, 31703, 0, -17842, 0, 31704, 0, -17841, 0, 31707, 0, -17840, 0, 31708, 0, -17839, 0, 31710, 0, -17838, 0, 31711, 0, -17837, 0, 31712, 0, -17836, 0, 31714, 0, -17835, 0, 31715, 0, -17834, 0, 31716, 0, -17833, 0, 31719, 0, -17832, 0, 31720, 0, -17831, 0, 31721, 0, -17830, 0, 31723, 0, -17829, 0, 31724, 0, -17828, 0, 31725, 0, -17827, 0, 31727, 0, -17826, 0, 31728, 0, -17825, 0, 31730, 0, -17824, 0, 31731, 0, -17823, 0, 31732, 0, -17822, 0, 31733, 0, -17821, 0, 31734, 0, -17820, 0, 31736, 0, -17819, 0, 31737, 0, -17818, 0, 31738, 0, -17817, 0, 31739, 0, -17816, 0, 31741, 0, -17815, 0, 31743, 0, -17814, 0, 31744, 0, -17813, 0, 31745, 0, -17812, 0, 31746, 0, -17811, 0, 31747, 0, -17810, 0, 31748, 0, -17809, 0, 31749, 0, -17808, 0, 31750, 0, -17807, 0, 31752, 0, -17806, 0, 31753, 0, -17805, 0, 31754, 0, -17804, 0, 31757, 0, -17803, 0, 31758, 0, -17802, 0, 31760, 0, -17801, 0, 31761, 0, -17800, 0, 31762, 0, -17799, 0, 31763, 0, -17798, 0, 31764, 0, -17797, 0, 31765, 0, -17796, 0, 31767, 0, -17795, 0, 31768, 0, -17794, 0, 31769, 0, -17792, 0, 31770, 0, -17791, 0, 31771, 0, -17790, 0, 31772, 0, -17789, 0, 31773, 0, -17788, 0, 31774, 0, -17787, 0, 31776, 0, -17786, 0, 31777, 0, -17785, 0, 31778, 0, -17784, 0, 31779, 0, -17783, 0, 31780, 0, -17782, 0, 31781, 0, -17781, 0, 31784, 0, -17780, 0, 31785, 0, -17779, 0, 31787, 0, -17778, 0, 31788, 0, -17777, 0, 31789, 0, -17776, 0, 31790, 0, -17775, 0, 31791, 0, -17774, 0, 31792, 0, -17773, 0, 31793, 0, -17772, 0, 31794, 0, -17771, 0, 31795, 0, -17770, 0, 31796, 0, -17769, 0, 31797, 0, -17768, 0, 31798, 0, -17767, 0, 31799, 0, -17766, 0, 31801, 0, -17765, 0, 31802, 0, -17764, 0, 31803, 0, -17763, 0, 31804, 0, -17762, 0, 31805, 0, -17761, 0, 31806, 0, -17760, 0, 31810, 0, -17759, 0, -25928, 0, -17758, 0, 23401, 0, -17757, 0, 28023, 0, -17756, 0, 27686, 0, -17755, 0, 20133, 0, -17754, 0, 23475, 0, -17753, 0, -25977, 0, -17752, 0, -28317, 0, -17751, 0, 25000, 0, -17750, 0, -28497, 0, -17749, 0, -26647, 0, -17748, 0, 21547, 0, -17747, 0, 28085, 0, -17746, 0, 23506, 0, -17745, 0, 20989, 0, -17744, 0, 21898, 0, -17743, 0, 32597, 0, -17742, 0, 32752, 0, -17741, 0, 25788, 0, -17740, 0, 25421, 0, -17739, 0, 26097, 0, -17738, 0, 25022, 0, -17737, 0, 24717, 0, -17736, 0, 28938, 0, -17735, 0, 27735, 0, -17734, 0, 27721, 0, -17733, 0, 22831, 0, -17732, 0, 26477, 0, -17731, 0, -32214, 0, -17730, 0, 22741, 0, -17729, 0, 22158, 0, -17728, 0, -29590, 0, -17727, 0, 27627, 0, -17726, 0, -28451, 0, -17725, 0, 22909, 0, -17724, 0, -32745, 0, -17723, 0, 21495, 0, -17722, 0, 28009, 0, -17721, 0, 21621, 0, -17720, 0, 21917, 0, -17719, 0, -31881, 0, -17718, 0, -31793, 0, -17717, 0, 26680, 0, -17716, 0, 31166, 0, -17715, 0, 21644, 0, -17714, 0, 20309, 0, -17713, 0, 21512, 0, -17712, 0, 30418, 0, -17711, 0, -29559, 0, -17710, 0, -27134, 0, -17709, 0, 27827, 0, -17708, 0, 28088, 0, -17707, 0, -29333, 0, -17706, 0, -30448, 0, -17705, 0, -24988, 0, -17704, 0, -29382, 0, -17703, 0, 22079, 0, -17702, 0, -24879, 0, -17701, 0, 30165, 0, -17700, 0, 24456, 0, -17699, 0, 29408, 0, -17698, 0, 24680, 0, -17697, 0, 21756, 0, -17696, 0, 20136, 0, -17695, 0, 27178, 0, -17694, 0, -30623, 0, -17693, 0, 24658, 0, -17692, 0, -28816, 0, -17691, 0, 21700, 0, -17690, 0, 28888, 0, -17689, 0, -31111, 0, -17688, 0, -25025, 0, -17687, 0, 27946, 0, -17686, 0, 23439, 0, -17685, 0, 24344, 0, -17684, 0, 32418, 0, -17683, 0, 21897, 0, -17682, 0, 20399, 0, -17681, 0, 29492, 0, -17680, 0, 21564, 0, -17679, 0, 21402, 0, -17678, 0, 20505, 0, -17677, 0, 21518, 0, -17676, 0, 21628, 0, -17675, 0, 20046, 0, -17674, 0, 24573, 0, -17673, 0, 29786, 0, -17672, 0, 22774, 0, -17671, 0, -31637, 0, -17670, 0, -32543, 0, -17669, 0, -30860, 0, -17668, 0, 29392, 0, -17667, 0, 31946, 0, -17666, 0, 28246, 0, -17600, 0, 31811, 0, -17599, 0, 31812, 0, -17598, 0, 31813, 0, -17597, 0, 31814, 0, -17596, 0, 31815, 0, -17595, 0, 31816, 0, -17594, 0, 31817, 0, -17593, 0, 31818, 0, -17592, 0, 31819, 0, -17591, 0, 31820, 0, -17590, 0, 31822, 0, -17589, 0, 31823, 0, -17588, 0, 31824, 0, -17587, 0, 31825, 0, -17586, 0, 31826, 0, -17585, 0, 31827, 0, -17584, 0, 31828, 0, -17583, 0, 31829, 0, -17582, 0, 31830, 0, -17581, 0, 31831, 0, -17580, 0, 31832, 0, -17579, 0, 31833, 0, -17578, 0, 31834, 0, -17577, 0, 31835, 0, -17576, 0, 31836, 0, -17575, 0, 31837, 0, -17574, 0, 31838, 0, -17573, 0, 31839, 0, -17572, 0, 31840, 0, -17571, 0, 31841, 0, -17570, 0, 31842, 0, -17569, 0, 31843, 0, -17568, 0, 31844, 0, -17567, 0, 31845, 0, -17566, 0, 31846, 0, -17565, 0, 31847, 0, -17564, 0, 31848, 0, -17563, 0, 31849, 0, -17562, 0, 31850, 0, -17561, 0, 31851, 0, -17560, 0, 31852, 0, -17559, 0, 31853, 0, -17558, 0, 31854, 0, -17557, 0, 31855, 0, -17556, 0, 31856, 0, -17555, 0, 31857, 0, -17554, 0, 31858, 0, -17553, 0, 31861, 0, -17552, 0, 31862, 0, -17551, 0, 31863, 0, -17550, 0, 31864, 0, -17549, 0, 31865, 0, -17548, 0, 31866, 0, -17547, 0, 31870, 0, -17546, 0, 31871, 0, -17545, 0, 31872, 0, -17544, 0, 31873, 0, -17543, 0, 31874, 0, -17542, 0, 31875, 0, -17541, 0, 31876, 0, -17540, 0, 31877, 0, -17539, 0, 31878, 0, -17538, 0, 31879, 0, -17536, 0, 31880, 0, -17535, 0, 31882, 0, -17534, 0, 31883, 0, -17533, 0, 31884, 0, -17532, 0, 31885, 0, -17531, 0, 31886, 0, -17530, 0, 31887, 0, -17529, 0, 31888, 0, -17528, 0, 31891, 0, -17527, 0, 31892, 0, -17526, 0, 31894, 0, -17525, 0, 31897, 0, -17524, 0, 31898, 0, -17523, 0, 31899, 0, -17522, 0, 31904, 0, -17521, 0, 31905, 0, -17520, 0, 31907, 0, -17519, 0, 31910, 0, -17518, 0, 31911, 0, -17517, 0, 31912, 0, -17516, 0, 31913, 0, -17515, 0, 31915, 0, -17514, 0, 31916, 0, -17513, 0, 31917, 0, -17512, 0, 31919, 0, -17511, 0, 31920, 0, -17510, 0, 31924, 0, -17509, 0, 31925, 0, -17508, 0, 31926, 0, -17507, 0, 31927, 0, -17506, 0, 31928, 0, -17505, 0, 31930, 0, -17504, 0, 31931, 0, -17503, 0, 24359, 0, -17502, 0, -31154, 0, -17501, 0, 21804, 0, -17500, 0, 25252, 0, -17499, 0, 20114, 0, -17498, 0, 27818, 0, -17497, 0, 25143, 0, -17496, 0, -32079, 0, -17495, 0, 21719, 0, -17494, 0, 21326, 0, -17493, 0, 29502, 0, -17492, 0, 28369, 0, -17491, 0, 30011, 0, -17490, 0, 21010, 0, -17489, 0, 21270, 0, -17488, 0, -29731, 0, -17487, 0, 27088, 0, -17486, 0, 24458, 0, -17485, 0, 24576, 0, -17484, 0, 28142, 0, -17483, 0, 22351, 0, -17482, 0, 27426, 0, -17481, 0, 29615, 0, -17480, 0, 26707, 0, -17479, 0, -28712, 0, -17478, 0, 32531, 0, -17477, 0, 25442, 0, -17476, 0, 24739, 0, -17475, 0, 21796, 0, -17474, 0, 30186, 0, -17473, 0, -29598, 0, -17472, 0, 28949, 0, -17471, 0, 28067, 0, -17470, 0, 23462, 0, -17469, 0, 24187, 0, -17468, 0, -31918, 0, -17467, 0, 24908, 0, -17466, 0, -24892, 0, -17465, 0, 30970, 0, -17464, 0, -30889, 0, -17463, 0, 31783, 0, -17462, 0, 30343, 0, -17461, 0, 20976, 0, -17460, 0, 24822, 0, -17459, 0, 29004, 0, -17458, 0, 26179, 0, -17457, 0, 24140, 0, -17456, 0, 24653, 0, -17455, 0, -29682, 0, -17454, 0, 28784, 0, -17453, 0, 25381, 0, -17452, 0, -28791, 0, -17451, 0, 24509, 0, -17450, 0, 24674, 0, -17449, 0, -31020, 0, -17448, 0, 22238, 0, -17447, 0, 27585, 0, -17446, 0, 24724, 0, -17445, 0, 24935, 0, -17444, 0, 21321, 0, -17443, 0, 24800, 0, -17442, 0, 26214, 0, -17441, 0, -29377, 0, -17440, 0, 31229, 0, -17439, 0, 20250, 0, -17438, 0, 28905, 0, -17437, 0, 27719, 0, -17436, 0, -29773, 0, -17435, 0, -29710, 0, -17434, 0, 32472, 0, -17433, 0, -31900, 0, -17432, 0, 26127, 0, -17431, 0, 23130, 0, -17430, 0, -25790, 0, -17429, 0, 27985, 0, -17428, 0, 28151, 0, -17427, 0, -29631, 0, -17426, 0, 27963, 0, -17425, 0, 20249, 0, -17424, 0, 28779, 0, -17423, 0, -31817, 0, -17422, 0, 25110, 0, -17421, 0, 24785, 0, -17420, 0, -26867, 0, -17419, 0, -29401, 0, -17418, 0, 31096, 0, -17417, 0, 20987, 0, -17416, 0, 22334, 0, -17415, 0, 22522, 0, -17414, 0, 26426, 0, -17413, 0, 30072, 0, -17412, 0, 31293, 0, -17411, 0, 31215, 0, -17410, 0, 31637, 0, -17344, 0, 31935, 0, -17343, 0, 31936, 0, -17342, 0, 31938, 0, -17341, 0, 31939, 0, -17340, 0, 31940, 0, -17339, 0, 31942, 0, -17338, 0, 31945, 0, -17337, 0, 31947, 0, -17336, 0, 31950, 0, -17335, 0, 31951, 0, -17334, 0, 31952, 0, -17333, 0, 31953, 0, -17332, 0, 31954, 0, -17331, 0, 31955, 0, -17330, 0, 31956, 0, -17329, 0, 31960, 0, -17328, 0, 31962, 0, -17327, 0, 31963, 0, -17326, 0, 31965, 0, -17325, 0, 31966, 0, -17324, 0, 31969, 0, -17323, 0, 31970, 0, -17322, 0, 31971, 0, -17321, 0, 31972, 0, -17320, 0, 31973, 0, -17319, 0, 31974, 0, -17318, 0, 31975, 0, -17317, 0, 31977, 0, -17316, 0, 31978, 0, -17315, 0, 31979, 0, -17314, 0, 31980, 0, -17313, 0, 31981, 0, -17312, 0, 31982, 0, -17311, 0, 31984, 0, -17310, 0, 31985, 0, -17309, 0, 31986, 0, -17308, 0, 31987, 0, -17307, 0, 31988, 0, -17306, 0, 31989, 0, -17305, 0, 31990, 0, -17304, 0, 31991, 0, -17303, 0, 31993, 0, -17302, 0, 31994, 0, -17301, 0, 31996, 0, -17300, 0, 31997, 0, -17299, 0, 31998, 0, -17298, 0, 31999, 0, -17297, 0, 32000, 0, -17296, 0, 32001, 0, -17295, 0, 32002, 0, -17294, 0, 32003, 0, -17293, 0, 32004, 0, -17292, 0, 32005, 0, -17291, 0, 32006, 0, -17290, 0, 32007, 0, -17289, 0, 32008, 0, -17288, 0, 32009, 0, -17287, 0, 32011, 0, -17286, 0, 32012, 0, -17285, 0, 32013, 0, -17284, 0, 32014, 0, -17283, 0, 32015, 0, -17282, 0, 32016, 0, -17280, 0, 32017, 0, -17279, 0, 32018, 0, -17278, 0, 32019, 0, -17277, 0, 32020, 0, -17276, 0, 32021, 0, -17275, 0, 32022, 0, -17274, 0, 32023, 0, -17273, 0, 32024, 0, -17272, 0, 32025, 0, -17271, 0, 32026, 0, -17270, 0, 32027, 0, -17269, 0, 32028, 0, -17268, 0, 32029, 0, -17267, 0, 32030, 0, -17266, 0, 32031, 0, -17265, 0, 32033, 0, -17264, 0, 32035, 0, -17263, 0, 32036, 0, -17262, 0, 32037, 0, -17261, 0, 32038, 0, -17260, 0, 32040, 0, -17259, 0, 32041, 0, -17258, 0, 32042, 0, -17257, 0, 32044, 0, -17256, 0, 32045, 0, -17255, 0, 32046, 0, -17254, 0, 32048, 0, -17253, 0, 32049, 0, -17252, 0, 32050, 0, -17251, 0, 32051, 0, -17250, 0, 32052, 0, -17249, 0, 32053, 0, -17248, 0, 32054, 0, -17247, 0, -32628, 0, -17246, 0, -26267, 0, -17245, 0, -28679, 0, -17244, 0, 28608, 0, -17243, 0, -29787, 0, -17242, 0, -25055, 0, -17241, 0, 23020, 0, -17240, 0, 32489, 0, -17239, 0, 32521, 0, -17238, 0, 21513, 0, -17237, 0, 26497, 0, -17236, 0, 26840, 0, -17235, 0, -28783, 0, -17234, 0, 31821, 0, -17233, 0, -26938, 0, -17232, 0, 21450, 0, -17231, 0, 24613, 0, -17230, 0, 30142, 0, -17229, 0, 27762, 0, -17228, 0, 21363, 0, -17227, 0, 23241, 0, -17226, 0, 32423, 0, -17225, 0, 25380, 0, -17224, 0, 20960, 0, -17223, 0, -32502, 0, -17222, 0, 24049, 0, -17221, 0, -31521, 0, -17220, 0, 25216, 0, -17219, 0, 20864, 0, -17218, 0, 23395, 0, -17217, 0, 20238, 0, -17216, 0, 31085, 0, -17215, 0, 21058, 0, -17214, 0, 24760, 0, -17213, 0, 27982, 0, -17212, 0, 23492, 0, -17211, 0, 23490, 0, -17210, 0, -29791, 0, -17209, 0, -29776, 0, -17208, 0, 26082, 0, -17207, 0, 24524, 0, -17206, 0, -27067, 0, -17205, 0, 22931, 0, -17204, 0, 32487, 0, -17203, 0, 32426, 0, -17202, 0, 22025, 0, -17201, 0, 26551, 0, -17200, 0, 22841, 0, -17199, 0, 20339, 0, -17198, 0, 23478, 0, -17197, 0, 21152, 0, -17196, 0, -31910, 0, -17195, 0, -26486, 0, -17194, 0, -29378, 0, -17193, 0, 30002, 0, -17192, 0, -27458, 0, -17191, 0, 20551, 0, -17190, 0, 31292, 0, -17189, 0, 20215, 0, -17188, 0, 26550, 0, -17187, 0, -25986, 0, -17186, 0, 23233, 0, -17185, 0, 27516, 0, -17184, 0, 30417, 0, -17183, 0, 22362, 0, -17182, 0, 23574, 0, -17181, 0, 31546, 0, -17180, 0, -27148, 0, -17179, 0, 29006, 0, -17178, 0, 20860, 0, -17177, 0, -32599, 0, -17176, 0, -32144, 0, -17175, 0, 22904, 0, -17174, 0, 32516, 0, -17173, 0, -31961, 0, -17172, 0, 26816, 0, -17171, 0, 26604, 0, -17170, 0, 30897, 0, -17169, 0, 30839, 0, -17168, 0, 25315, 0, -17167, 0, 25441, 0, -17166, 0, 31616, 0, -17165, 0, 20461, 0, -17164, 0, 21098, 0, -17163, 0, 20943, 0, -17162, 0, -31920, 0, -17161, 0, 27099, 0, -17160, 0, -28044, 0, -17159, 0, -29195, 0, -17158, 0, -29391, 0, -17157, 0, -30271, 0, -17156, 0, -27346, 0, -17155, 0, 31661, 0, -17154, 0, 20214, 0, -17088, 0, 32055, 0, -17087, 0, 32056, 0, -17086, 0, 32057, 0, -17085, 0, 32058, 0, -17084, 0, 32059, 0, -17083, 0, 32060, 0, -17082, 0, 32061, 0, -17081, 0, 32062, 0, -17080, 0, 32063, 0, -17079, 0, 32064, 0, -17078, 0, 32065, 0, -17077, 0, 32066, 0, -17076, 0, 32067, 0, -17075, 0, 32068, 0, -17074, 0, 32069, 0, -17073, 0, 32070, 0, -17072, 0, 32071, 0, -17071, 0, 32072, 0, -17070, 0, 32073, 0, -17069, 0, 32074, 0, -17068, 0, 32075, 0, -17067, 0, 32076, 0, -17066, 0, 32077, 0, -17065, 0, 32078, 0, -17064, 0, 32079, 0, -17063, 0, 32080, 0, -17062, 0, 32081, 0, -17061, 0, 32082, 0, -17060, 0, 32083, 0, -17059, 0, 32084, 0, -17058, 0, 32085, 0, -17057, 0, 32086, 0, -17056, 0, 32087, 0, -17055, 0, 32088, 0, -17054, 0, 32089, 0, -17053, 0, 32090, 0, -17052, 0, 32091, 0, -17051, 0, 32092, 0, -17050, 0, 32093, 0, -17049, 0, 32094, 0, -17048, 0, 32095, 0, -17047, 0, 32096, 0, -17046, 0, 32097, 0, -17045, 0, 32098, 0, -17044, 0, 32099, 0, -17043, 0, 32100, 0, -17042, 0, 32101, 0, -17041, 0, 32102, 0, -17040, 0, 32103, 0, -17039, 0, 32104, 0, -17038, 0, 32105, 0, -17037, 0, 32106, 0, -17036, 0, 32107, 0, -17035, 0, 32108, 0, -17034, 0, 32109, 0, -17033, 0, 32111, 0, -17032, 0, 32112, 0, -17031, 0, 32113, 0, -17030, 0, 32114, 0, -17029, 0, 32115, 0, -17028, 0, 32116, 0, -17027, 0, 32117, 0, -17026, 0, 32118, 0, -17024, 0, 32120, 0, -17023, 0, 32121, 0, -17022, 0, 32122, 0, -17021, 0, 32123, 0, -17020, 0, 32124, 0, -17019, 0, 32125, 0, -17018, 0, 32126, 0, -17017, 0, 32127, 0, -17016, 0, 32128, 0, -17015, 0, 32129, 0, -17014, 0, 32130, 0, -17013, 0, 32131, 0, -17012, 0, 32132, 0, -17011, 0, 32133, 0, -17010, 0, 32134, 0, -17009, 0, 32135, 0, -17008, 0, 32136, 0, -17007, 0, 32137, 0, -17006, 0, 32138, 0, -17005, 0, 32139, 0, -17004, 0, 32140, 0, -17003, 0, 32141, 0, -17002, 0, 32142, 0, -17001, 0, 32143, 0, -17000, 0, 32144, 0, -16999, 0, 32145, 0, -16998, 0, 32146, 0, -16997, 0, 32147, 0, -16996, 0, 32148, 0, -16995, 0, 32149, 0, -16994, 0, 32150, 0, -16993, 0, 32151, 0, -16992, 0, 32152, 0, -16991, 0, 20581, 0, -16990, 0, -32208, 0, -16989, 0, 21073, 0, -16988, 0, -26257, 0, -16987, 0, 28176, 0, -16986, 0, 28293, 0, -16985, 0, 28071, 0, -16984, 0, 24314, 0, -16983, 0, 20725, 0, -16982, 0, 23004, 0, -16981, 0, 23558, 0, -16980, 0, 27974, 0, -16979, 0, 27743, 0, -16978, 0, 30086, 0, -16977, 0, -31605, 0, -16976, 0, 26728, 0, -16975, 0, 22870, 0, -16974, 0, -29774, 0, -16973, 0, 21280, 0, -16972, 0, -28303, 0, -16971, 0, -27059, 0, -16970, 0, -31415, 0, -16969, 0, 26898, 0, -16968, 0, 30977, 0, -16967, 0, 28966, 0, -16966, 0, -32522, 0, -16965, 0, 20132, 0, -16964, 0, -28470, 0, -16963, 0, 27975, 0, -16962, 0, -25980, 0, -16961, 0, 23047, 0, -16960, 0, 22204, 0, -16959, 0, 25605, 0, -16958, 0, -27408, 0, -16957, 0, 30699, 0, -16956, 0, 20389, 0, -16955, 0, -32486, 0, -16954, 0, 29409, 0, -16953, 0, -30254, 0, -16952, 0, -26246, 0, -16951, 0, 32564, 0, -16950, 0, 32478, 0, -16949, 0, 21119, 0, -16948, 0, 25945, 0, -16947, 0, -28299, 0, -16946, 0, -28801, 0, -16945, 0, -28797, 0, -16944, 0, 21483, 0, -16943, 0, 31382, 0, -16942, 0, 25581, 0, -16941, 0, 25509, 0, -16940, 0, 30342, 0, -16939, 0, 31224, 0, -16938, 0, -30633, 0, -16937, 0, -27082, 0, -16936, 0, 25130, 0, -16935, 0, 21163, 0, -16934, 0, -32126, 0, -16933, 0, 26708, 0, -16932, 0, 26480, 0, -16931, 0, 25463, 0, -16930, 0, 30571, 0, -16929, 0, 31469, 0, -16928, 0, 27905, 0, -16927, 0, 32467, 0, -16926, 0, -30237, 0, -16925, 0, 22992, 0, -16924, 0, 25106, 0, -16923, 0, -31287, 0, -16922, 0, -32091, 0, -16921, 0, 30028, 0, -16920, 0, 20511, 0, -16919, 0, 20171, 0, -16918, 0, 30117, 0, -16917, 0, -29717, 0, -16916, 0, 23626, 0, -16915, 0, 24062, 0, -16914, 0, 31563, 0, -16913, 0, 26020, 0, -16912, 0, -28207, 0, -16911, 0, 20170, 0, -16910, 0, 27941, 0, -16909, 0, -30369, 0, -16908, 0, 32039, 0, -16907, 0, -27354, 0, -16906, 0, 20165, 0, -16905, 0, -29656, 0, -16904, 0, -28709, 0, -16903, 0, -26765, 0, -16902, 0, 26187, 0, -16901, 0, 31105, 0, -16900, 0, -28719, 0, -16899, 0, 28908, 0, -16898, 0, 28024, 0, -16832, 0, 32153, 0, -16831, 0, 32154, 0, -16830, 0, 32155, 0, -16829, 0, 32156, 0, -16828, 0, 32157, 0, -16827, 0, 32158, 0, -16826, 0, 32159, 0, -16825, 0, 32160, 0, -16824, 0, 32161, 0, -16823, 0, 32162, 0, -16822, 0, 32163, 0, -16821, 0, 32164, 0, -16820, 0, 32165, 0, -16819, 0, 32167, 0, -16818, 0, 32168, 0, -16817, 0, 32169, 0, -16816, 0, 32170, 0, -16815, 0, 32171, 0, -16814, 0, 32172, 0, -16813, 0, 32173, 0, -16812, 0, 32175, 0, -16811, 0, 32176, 0, -16810, 0, 32177, 0, -16809, 0, 32178, 0, -16808, 0, 32179, 0, -16807, 0, 32180, 0, -16806, 0, 32181, 0, -16805, 0, 32182, 0, -16804, 0, 32183, 0, -16803, 0, 32184, 0, -16802, 0, 32185, 0, -16801, 0, 32186, 0, -16800, 0, 32187, 0, -16799, 0, 32188, 0, -16798, 0, 32189, 0, -16797, 0, 32190, 0, -16796, 0, 32191, 0, -16795, 0, 32192, 0, -16794, 0, 32193, 0, -16793, 0, 32194, 0, -16792, 0, 32195, 0, -16791, 0, 32196, 0, -16790, 0, 32197, 0, -16789, 0, 32198, 0, -16788, 0, 32199, 0, -16787, 0, 32200, 0, -16786, 0, 32201, 0, -16785, 0, 32202, 0, -16784, 0, 32203, 0, -16783, 0, 32204, 0, -16782, 0, 32205, 0, -16781, 0, 32206, 0, -16780, 0, 32207, 0, -16779, 0, 32208, 0, -16778, 0, 32209, 0, -16777, 0, 32210, 0, -16776, 0, 32211, 0, -16775, 0, 32212, 0, -16774, 0, 32213, 0, -16773, 0, 32214, 0, -16772, 0, 32215, 0, -16771, 0, 32216, 0, -16770, 0, 32217, 0, -16768, 0, 32218, 0, -16767, 0, 32219, 0, -16766, 0, 32220, 0, -16765, 0, 32221, 0, -16764, 0, 32222, 0, -16763, 0, 32223, 0, -16762, 0, 32224, 0, -16761, 0, 32225, 0, -16760, 0, 32226, 0, -16759, 0, 32227, 0, -16758, 0, 32228, 0, -16757, 0, 32229, 0, -16756, 0, 32230, 0, -16755, 0, 32231, 0, -16754, 0, 32232, 0, -16753, 0, 32233, 0, -16752, 0, 32234, 0, -16751, 0, 32235, 0, -16750, 0, 32236, 0, -16749, 0, 32237, 0, -16748, 0, 32238, 0, -16747, 0, 32239, 0, -16746, 0, 32240, 0, -16745, 0, 32241, 0, -16744, 0, 32242, 0, -16743, 0, 32243, 0, -16742, 0, 32244, 0, -16741, 0, 32245, 0, -16740, 0, 32246, 0, -16739, 0, 32247, 0, -16738, 0, 32248, 0, -16737, 0, 32249, 0, -16736, 0, 32250, 0, -16735, 0, 23613, 0, -16734, 0, 21170, 0, -16733, 0, -31930, 0, -16732, 0, 20834, 0, -16731, 0, -31986, 0, -16730, 0, 30555, 0, -16729, 0, 26230, 0, -16728, 0, -25416, 0, -16727, 0, 20140, 0, -16726, 0, 24778, 0, -16725, 0, 31934, 0, -16724, 0, 31923, 0, -16723, 0, 32463, 0, -16722, 0, 20117, 0, -16721, 0, -29850, 0, -16720, 0, 26223, 0, -16719, 0, -26488, 0, -16718, 0, -26791, 0, -16717, 0, 22659, 0, -16716, 0, 25964, 0, -16715, 0, -27300, 0, -16714, 0, 24452, 0, -16713, 0, 30153, 0, -16712, 0, -26794, 0, -16711, 0, 31455, 0, -16710, 0, 31454, 0, -16709, 0, 20928, 0, -16708, 0, 28847, 0, -16707, 0, 31384, 0, -16706, 0, 25578, 0, -16705, 0, 31350, 0, -16704, 0, 32416, 0, -16703, 0, 29590, 0, -16702, 0, -26643, 0, -16701, 0, 20037, 0, -16700, 0, 28792, 0, -16699, 0, 20061, 0, -16698, 0, -28334, 0, -16697, 0, 21417, 0, -16696, 0, 25937, 0, -16695, 0, 26087, 0, -16694, 0, -32260, 0, -16693, 0, -32251, 0, -16692, 0, 21646, 0, -16691, 0, 23601, 0, -16690, 0, 30106, 0, -16689, 0, -26720, 0, -16688, 0, 25304, 0, -16687, 0, 29401, 0, -16686, 0, 30141, 0, -16685, 0, 23621, 0, -16684, 0, -25991, 0, -16683, 0, -31798, 0, -16682, 0, 23616, 0, -16681, 0, 21632, 0, -16680, 0, 30697, 0, -16679, 0, 20030, 0, -16678, 0, 27822, 0, -16677, 0, -32678, 0, -16676, 0, 25298, 0, -16675, 0, 25454, 0, -16674, 0, 24040, 0, -16673, 0, 20855, 0, -16672, 0, -29219, 0, -16671, 0, -29154, 0, -16670, 0, -27345, 0, -16669, 0, 20465, 0, -16668, 0, 21477, 0, -16667, 0, 24807, 0, -16666, 0, 28844, 0, -16665, 0, 21095, 0, -16664, 0, 25424, 0, -16663, 0, -25021, 0, -16662, 0, 23071, 0, -16661, 0, 20518, 0, -16660, 0, 30519, 0, -16659, 0, 21367, 0, -16658, 0, 32482, 0, -16657, 0, 25733, 0, -16656, 0, 25899, 0, -16655, 0, 25225, 0, -16654, 0, 25496, 0, -16653, 0, 20500, 0, -16652, 0, 29237, 0, -16651, 0, -30263, 0, -16650, 0, 20915, 0, -16649, 0, -29760, 0, -16648, 0, 32477, 0, -16647, 0, 22343, 0, -16646, 0, -31796, 0, -16645, 0, -27481, 0, -16644, 0, 20891, 0, -16643, 0, 21531, 0, -16642, 0, 23803, 0, -16576, 0, 32251, 0, -16575, 0, 32252, 0, -16574, 0, 32253, 0, -16573, 0, 32254, 0, -16572, 0, 32255, 0, -16571, 0, 32256, 0, -16570, 0, 32257, 0, -16569, 0, 32258, 0, -16568, 0, 32259, 0, -16567, 0, 32260, 0, -16566, 0, 32261, 0, -16565, 0, 32262, 0, -16564, 0, 32263, 0, -16563, 0, 32264, 0, -16562, 0, 32265, 0, -16561, 0, 32266, 0, -16560, 0, 32267, 0, -16559, 0, 32268, 0, -16558, 0, 32269, 0, -16557, 0, 32270, 0, -16556, 0, 32271, 0, -16555, 0, 32272, 0, -16554, 0, 32273, 0, -16553, 0, 32274, 0, -16552, 0, 32275, 0, -16551, 0, 32276, 0, -16550, 0, 32277, 0, -16549, 0, 32278, 0, -16548, 0, 32279, 0, -16547, 0, 32280, 0, -16546, 0, 32281, 0, -16545, 0, 32282, 0, -16544, 0, 32283, 0, -16543, 0, 32284, 0, -16542, 0, 32285, 0, -16541, 0, 32286, 0, -16540, 0, 32287, 0, -16539, 0, 32288, 0, -16538, 0, 32289, 0, -16537, 0, 32290, 0, -16536, 0, 32291, 0, -16535, 0, 32292, 0, -16534, 0, 32293, 0, -16533, 0, 32294, 0, -16532, 0, 32295, 0, -16531, 0, 32296, 0, -16530, 0, 32297, 0, -16529, 0, 32298, 0, -16528, 0, 32299, 0, -16527, 0, 32300, 0, -16526, 0, 32301, 0, -16525, 0, 32302, 0, -16524, 0, 32303, 0, -16523, 0, 32304, 0, -16522, 0, 32305, 0, -16521, 0, 32306, 0, -16520, 0, 32307, 0, -16519, 0, 32308, 0, -16518, 0, 32309, 0, -16517, 0, 32310, 0, -16516, 0, 32311, 0, -16515, 0, 32312, 0, -16514, 0, 32313, 0, -16512, 0, 32314, 0, -16511, 0, 32316, 0, -16510, 0, 32317, 0, -16509, 0, 32318, 0, -16508, 0, 32319, 0, -16507, 0, 32320, 0, -16506, 0, 32322, 0, -16505, 0, 32323, 0, -16504, 0, 32324, 0, -16503, 0, 32325, 0, -16502, 0, 32326, 0, -16501, 0, 32328, 0, -16500, 0, 32329, 0, -16499, 0, 32330, 0, -16498, 0, 32331, 0, -16497, 0, 32332, 0, -16496, 0, 32333, 0, -16495, 0, 32334, 0, -16494, 0, 32335, 0, -16493, 0, 32336, 0, -16492, 0, 32337, 0, -16491, 0, 32338, 0, -16490, 0, 32339, 0, -16489, 0, 32340, 0, -16488, 0, 32341, 0, -16487, 0, 32342, 0, -16486, 0, 32343, 0, -16485, 0, 32344, 0, -16484, 0, 32345, 0, -16483, 0, 32346, 0, -16482, 0, 32347, 0, -16481, 0, 32348, 0, -16480, 0, 32349, 0, -16479, 0, 20426, 0, -16478, 0, 31459, 0, -16477, 0, 27994, 0, -16476, 0, -28447, 0, -16475, 0, -25969, 0, -16474, 0, 21888, 0, -16473, 0, 21654, 0, -16472, 0, 21345, 0, -16471, 0, 21679, 0, -16470, 0, 24320, 0, -16469, 0, 25577, 0, -16468, 0, 26999, 0, -16467, 0, 20975, 0, -16466, 0, 24936, 0, -16465, 0, 21002, 0, -16464, 0, 22570, 0, -16463, 0, 21208, 0, -16462, 0, 22350, 0, -16461, 0, 30733, 0, -16460, 0, 30475, 0, -16459, 0, 24247, 0, -16458, 0, 24951, 0, -16457, 0, 31968, 0, -16456, 0, 25179, 0, -16455, 0, 25239, 0, -16454, 0, 20130, 0, -16453, 0, 28821, 0, -16452, 0, -32765, 0, -16451, 0, 25335, 0, -16450, 0, 28900, 0, -16449, 0, -26784, 0, -16448, 0, 22391, 0, -16447, 0, -32037, 0, -16446, 0, 26607, 0, -16445, 0, 26869, 0, -16444, 0, 30933, 0, -16443, 0, -26473, 0, -16442, 0, 31185, 0, -16441, 0, 22771, 0, -16440, 0, 21683, 0, -16439, 0, 21487, 0, -16438, 0, 28212, 0, -16437, 0, 20811, 0, -16436, 0, 21051, 0, -16435, 0, 23458, 0, -16434, 0, -29698, 0, -16433, 0, -32593, 0, -16432, 0, 21827, 0, -16431, 0, 22438, 0, -16430, 0, 24691, 0, -16429, 0, 22353, 0, -16428, 0, 21549, 0, -16427, 0, 31354, 0, -16426, 0, 24656, 0, -16425, 0, 23380, 0, -16424, 0, 25511, 0, -16423, 0, 25248, 0, -16422, 0, 21475, 0, -16421, 0, 25187, 0, -16420, 0, 23495, 0, -16419, 0, 26543, 0, -16418, 0, 21741, 0, -16417, 0, 31391, 0, -16416, 0, -32026, 0, -16415, 0, -28297, 0, -16414, 0, 24211, 0, -16413, 0, -30492, 0, -16412, 0, 22840, 0, -16411, 0, 22446, 0, -16410, 0, 25358, 0, -16409, 0, -29208, 0, -16408, 0, -32529, 0, -16407, 0, 22359, 0, -16406, 0, 31607, 0, -16405, 0, 20393, 0, -16404, 0, 24555, 0, -16403, 0, 23485, 0, -16402, 0, 27454, 0, -16401, 0, 21281, 0, -16400, 0, 31568, 0, -16399, 0, 29378, 0, -16398, 0, 26694, 0, -16397, 0, 30719, 0, -16396, 0, 30518, 0, -16395, 0, 26103, 0, -16394, 0, 20917, 0, -16393, 0, 20111, 0, -16392, 0, 30420, 0, -16391, 0, 23743, 0, -16390, 0, 31397, 0, -16389, 0, -31627, 0, -16388, 0, 22862, 0, -16387, 0, -25791, 0, -16386, 0, 20608, 0, -16320, 0, 32350, 0, -16319, 0, 32351, 0, -16318, 0, 32352, 0, -16317, 0, 32353, 0, -16316, 0, 32354, 0, -16315, 0, 32355, 0, -16314, 0, 32356, 0, -16313, 0, 32357, 0, -16312, 0, 32358, 0, -16311, 0, 32359, 0, -16310, 0, 32360, 0, -16309, 0, 32361, 0, -16308, 0, 32362, 0, -16307, 0, 32363, 0, -16306, 0, 32364, 0, -16305, 0, 32365, 0, -16304, 0, 32366, 0, -16303, 0, 32367, 0, -16302, 0, 32368, 0, -16301, 0, 32369, 0, -16300, 0, 32370, 0, -16299, 0, 32371, 0, -16298, 0, 32372, 0, -16297, 0, 32373, 0, -16296, 0, 32374, 0, -16295, 0, 32375, 0, -16294, 0, 32376, 0, -16293, 0, 32377, 0, -16292, 0, 32378, 0, -16291, 0, 32379, 0, -16290, 0, 32380, 0, -16289, 0, 32381, 0, -16288, 0, 32382, 0, -16287, 0, 32383, 0, -16286, 0, 32384, 0, -16285, 0, 32385, 0, -16284, 0, 32387, 0, -16283, 0, 32388, 0, -16282, 0, 32389, 0, -16281, 0, 32390, 0, -16280, 0, 32391, 0, -16279, 0, 32392, 0, -16278, 0, 32393, 0, -16277, 0, 32394, 0, -16276, 0, 32395, 0, -16275, 0, 32396, 0, -16274, 0, 32397, 0, -16273, 0, 32398, 0, -16272, 0, 32399, 0, -16271, 0, 32400, 0, -16270, 0, 32401, 0, -16269, 0, 32402, 0, -16268, 0, 32403, 0, -16267, 0, 32404, 0, -16266, 0, 32405, 0, -16265, 0, 32406, 0, -16264, 0, 32407, 0, -16263, 0, 32408, 0, -16262, 0, 32409, 0, -16261, 0, 32410, 0, -16260, 0, 32412, 0, -16259, 0, 32413, 0, -16258, 0, 32414, 0, -16256, 0, 32430, 0, -16255, 0, 32436, 0, -16254, 0, 32443, 0, -16253, 0, 32444, 0, -16252, 0, 32470, 0, -16251, 0, 32484, 0, -16250, 0, 32492, 0, -16249, 0, 32505, 0, -16248, 0, 32522, 0, -16247, 0, 32528, 0, -16246, 0, 32542, 0, -16245, 0, 32567, 0, -16244, 0, 32569, 0, -16243, 0, 32571, 0, -16242, 0, 32572, 0, -16241, 0, 32573, 0, -16240, 0, 32574, 0, -16239, 0, 32575, 0, -16238, 0, 32576, 0, -16237, 0, 32577, 0, -16236, 0, 32579, 0, -16235, 0, 32582, 0, -16234, 0, 32583, 0, -16233, 0, 32584, 0, -16232, 0, 32585, 0, -16231, 0, 32586, 0, -16230, 0, 32587, 0, -16229, 0, 32588, 0, -16228, 0, 32589, 0, -16227, 0, 32590, 0, -16226, 0, 32591, 0, -16225, 0, 32594, 0, -16224, 0, 32595, 0, -16223, 0, -26232, 0, -16222, 0, 24871, 0, -16221, 0, 28291, 0, -16220, 0, 22372, 0, -16219, 0, 26118, 0, -16218, 0, 25414, 0, -16217, 0, 22256, 0, -16216, 0, 25324, 0, -16215, 0, 25193, 0, -16214, 0, 24275, 0, -16213, 0, -27116, 0, -16212, 0, 22403, 0, -16211, 0, 25289, 0, -16210, 0, 21895, 0, -16209, 0, -30943, 0, -16208, 0, -32438, 0, -16207, 0, -28765, 0, -16206, 0, 21862, 0, -16205, 0, -31823, 0, -16204, 0, 26469, 0, -16203, 0, -29354, 0, -16202, 0, -31523, 0, -16201, 0, 23146, 0, -16200, 0, 26639, 0, -16199, 0, 25318, 0, -16198, 0, 31726, 0, -16197, 0, -27119, 0, -16196, 0, 20848, 0, -16195, 0, 28572, 0, -16194, 0, -29648, 0, -16193, 0, 25597, 0, -16192, 0, -30264, 0, -16191, 0, 25042, 0, -16190, 0, 32518, 0, -16189, 0, 28866, 0, -16188, 0, 28389, 0, -16187, 0, 29701, 0, -16186, 0, 27028, 0, -16185, 0, 29436, 0, -16184, 0, 24266, 0, -16183, 0, -28466, 0, -16182, 0, 26391, 0, -16181, 0, 28010, 0, -16180, 0, 25438, 0, -16179, 0, 21171, 0, -16178, 0, 29282, 0, -16177, 0, -32767, 0, -16176, 0, 20332, 0, -16175, 0, 23013, 0, -16174, 0, -28310, 0, -16173, 0, 28889, 0, -16172, 0, 28061, 0, -16171, 0, 21202, 0, -16170, 0, 20048, 0, -16169, 0, -26889, 0, -16168, 0, -27283, 0, -16167, 0, -31362, 0, -16166, 0, 30922, 0, -16165, 0, 32047, 0, -16164, 0, 20769, 0, -16163, 0, 22418, 0, -16162, 0, 25794, 0, -16161, 0, -32629, 0, -16160, 0, 31867, 0, -16159, 0, 27882, 0, -16158, 0, 26865, 0, -16157, 0, 26974, 0, -16156, 0, 20919, 0, -16155, 0, 21400, 0, -16154, 0, 26792, 0, -16153, 0, 29313, 0, -16152, 0, -24882, 0, -16151, 0, 31729, 0, -16150, 0, 29432, 0, -16149, 0, 31163, 0, -16148, 0, 28435, 0, -16147, 0, 29702, 0, -16146, 0, 26446, 0, -16145, 0, -28212, 0, -16144, 0, -25436, 0, -16143, 0, 31036, 0, -16142, 0, -31863, 0, -16141, 0, -31916, 0, -16140, 0, 21519, 0, -16139, 0, 26647, 0, -16138, 0, 20029, 0, -16137, 0, 21385, 0, -16136, 0, 21169, 0, -16135, 0, 30782, 0, -16134, 0, 21382, 0, -16133, 0, 21033, 0, -16132, 0, 20616, 0, -16131, 0, 20363, 0, -16130, 0, 20432, 0, -16064, 0, 32598, 0, -16063, 0, 32601, 0, -16062, 0, 32603, 0, -16061, 0, 32604, 0, -16060, 0, 32605, 0, -16059, 0, 32606, 0, -16058, 0, 32608, 0, -16057, 0, 32611, 0, -16056, 0, 32612, 0, -16055, 0, 32613, 0, -16054, 0, 32614, 0, -16053, 0, 32615, 0, -16052, 0, 32619, 0, -16051, 0, 32620, 0, -16050, 0, 32621, 0, -16049, 0, 32623, 0, -16048, 0, 32624, 0, -16047, 0, 32627, 0, -16046, 0, 32629, 0, -16045, 0, 32630, 0, -16044, 0, 32631, 0, -16043, 0, 32632, 0, -16042, 0, 32634, 0, -16041, 0, 32635, 0, -16040, 0, 32636, 0, -16039, 0, 32637, 0, -16038, 0, 32639, 0, -16037, 0, 32640, 0, -16036, 0, 32642, 0, -16035, 0, 32643, 0, -16034, 0, 32644, 0, -16033, 0, 32645, 0, -16032, 0, 32646, 0, -16031, 0, 32647, 0, -16030, 0, 32648, 0, -16029, 0, 32649, 0, -16028, 0, 32651, 0, -16027, 0, 32653, 0, -16026, 0, 32655, 0, -16025, 0, 32656, 0, -16024, 0, 32657, 0, -16023, 0, 32658, 0, -16022, 0, 32659, 0, -16021, 0, 32661, 0, -16020, 0, 32662, 0, -16019, 0, 32663, 0, -16018, 0, 32664, 0, -16017, 0, 32665, 0, -16016, 0, 32667, 0, -16015, 0, 32668, 0, -16014, 0, 32672, 0, -16013, 0, 32674, 0, -16012, 0, 32675, 0, -16011, 0, 32677, 0, -16010, 0, 32678, 0, -16009, 0, 32680, 0, -16008, 0, 32681, 0, -16007, 0, 32682, 0, -16006, 0, 32683, 0, -16005, 0, 32684, 0, -16004, 0, 32685, 0, -16003, 0, 32686, 0, -16002, 0, 32689, 0, -16000, 0, 32691, 0, -15999, 0, 32692, 0, -15998, 0, 32693, 0, -15997, 0, 32694, 0, -15996, 0, 32695, 0, -15995, 0, 32698, 0, -15994, 0, 32699, 0, -15993, 0, 32702, 0, -15992, 0, 32704, 0, -15991, 0, 32706, 0, -15990, 0, 32707, 0, -15989, 0, 32708, 0, -15988, 0, 32710, 0, -15987, 0, 32711, 0, -15986, 0, 32712, 0, -15985, 0, 32713, 0, -15984, 0, 32715, 0, -15983, 0, 32717, 0, -15982, 0, 32719, 0, -15981, 0, 32720, 0, -15980, 0, 32721, 0, -15979, 0, 32722, 0, -15978, 0, 32723, 0, -15977, 0, 32726, 0, -15976, 0, 32727, 0, -15975, 0, 32729, 0, -15974, 0, 32730, 0, -15973, 0, 32731, 0, -15972, 0, 32732, 0, -15971, 0, 32733, 0, -15970, 0, 32734, 0, -15969, 0, 32738, 0, -15968, 0, 32739, 0, -15967, 0, 30178, 0, -15966, 0, 31435, 0, -15965, 0, 31890, 0, -15964, 0, 27813, 0, -15963, 0, -26954, 0, -15962, 0, 21147, 0, -15961, 0, 29827, 0, -15960, 0, 21737, 0, -15959, 0, 20457, 0, -15958, 0, -32684, 0, -15957, 0, -31822, 0, -15956, 0, -28706, 0, -15955, 0, -27280, 0, -15954, 0, 24265, 0, -15953, 0, 24604, 0, -15952, 0, 28063, 0, -15951, 0, 24088, 0, -15950, 0, 25947, 0, -15949, 0, -32456, 0, -15948, 0, -27394, 0, -15947, 0, 24651, 0, -15946, 0, 28860, 0, -15945, 0, 32451, 0, -15944, 0, 31918, 0, -15943, 0, 20937, 0, -15942, 0, 26753, 0, -15941, 0, 31921, 0, -15940, 0, -32145, 0, -15939, 0, 20004, 0, -15938, 0, -28794, 0, -15937, 0, -28209, 0, -15936, 0, 26238, 0, -15935, 0, 20142, 0, -15934, 0, -29691, 0, -15933, 0, 25769, 0, -15932, 0, -32694, 0, -15931, 0, 20698, 0, -15930, 0, 30103, 0, -15929, 0, 29134, 0, -15928, 0, 23525, 0, -15927, 0, -28739, 0, -15926, 0, 28518, 0, -15925, 0, 20102, 0, -15924, 0, 25730, 0, -15923, 0, -27293, 0, -15922, 0, 24278, 0, -15921, 0, 26009, 0, -15920, 0, 21015, 0, -15919, 0, -30526, 0, -15918, 0, 28872, 0, -15917, 0, 21155, 0, -15916, 0, 29454, 0, -15915, 0, 29747, 0, -15914, 0, 26519, 0, -15913, 0, 30967, 0, -15912, 0, -26858, 0, -15911, 0, 20020, 0, -15910, 0, -28485, 0, -15909, 0, -25378, 0, -15908, 0, 28107, 0, -15907, 0, 20955, 0, -15906, 0, -29375, 0, -15905, 0, 21533, 0, -15904, 0, 25294, 0, -15903, 0, 29618, 0, -15902, 0, -31759, 0, -15901, 0, -26890, 0, -15900, 0, -24700, 0, -15899, 0, -27453, 0, -15898, 0, 20278, 0, -15897, 0, 32666, 0, -15896, 0, 20940, 0, -15895, 0, 28789, 0, -15894, 0, -27019, 0, -15893, 0, 23725, 0, -15892, 0, -26490, 0, -15891, 0, 21478, 0, -15890, 0, 20196, 0, -15889, 0, 28316, 0, -15888, 0, 29705, 0, -15887, 0, 27060, 0, -15886, 0, 30827, 0, -15885, 0, -26225, 0, -15884, 0, 30041, 0, -15883, 0, 21016, 0, -15882, 0, 30244, 0, -15881, 0, 27969, 0, -15880, 0, 26611, 0, -15879, 0, 20845, 0, -15878, 0, -24679, 0, -15877, 0, -32693, 0, -15876, 0, 21657, 0, -15875, 0, 31548, 0, -15874, 0, 31423, 0, -15808, 0, 32740, 0, -15807, 0, 32743, 0, -15806, 0, 32744, 0, -15805, 0, 32746, 0, -15804, 0, 32747, 0, -15803, 0, 32748, 0, -15802, 0, 32749, 0, -15801, 0, 32751, 0, -15800, 0, 32754, 0, -15799, 0, 32756, 0, -15798, 0, 32757, 0, -15797, 0, 32758, 0, -15796, 0, 32759, 0, -15795, 0, 32760, 0, -15794, 0, 32761, 0, -15793, 0, 32762, 0, -15792, 0, 32765, 0, -15791, 0, 32766, 0, -15790, 0, 32767, 0, -15789, 0, -32766, 0, -15788, 0, -32761, 0, -15787, 0, -32760, 0, -15786, 0, -32759, 0, -15785, 0, -32758, 0, -15784, 0, -32754, 0, -15783, 0, -32753, 0, -15782, 0, -32751, 0, -15781, 0, -32749, 0, -15780, 0, -32742, 0, -15779, 0, -32741, 0, -15778, 0, -32739, 0, -15777, 0, -32738, 0, -15776, 0, -32737, 0, -15775, 0, -32735, 0, -15774, 0, -32733, 0, -15773, 0, -32732, 0, -15772, 0, -32725, 0, -15771, 0, -32724, 0, -15770, 0, -32723, 0, -15769, 0, -32722, 0, -15768, 0, -32721, 0, -15767, 0, -32720, 0, -15766, 0, -32718, 0, -15765, 0, -32716, 0, -15764, 0, -32711, 0, -15763, 0, -32710, 0, -15762, 0, -32708, 0, -15761, 0, -32706, 0, -15760, 0, -32704, 0, -15759, 0, -32703, 0, -15758, 0, -32700, 0, -15757, 0, -32699, 0, -15756, 0, -32697, 0, -15755, 0, -32696, 0, -15754, 0, -32695, 0, -15753, 0, -32690, 0, -15752, 0, -32689, 0, -15751, 0, -32688, 0, -15750, 0, -32687, 0, -15749, 0, -32685, 0, -15748, 0, -32683, 0, -15747, 0, -32682, 0, -15746, 0, -32681, 0, -15744, 0, -32679, 0, -15743, 0, -32677, 0, -15742, 0, -32676, 0, -15741, 0, -32675, 0, -15740, 0, -32674, 0, -15739, 0, -32673, 0, -15738, 0, -32672, 0, -15737, 0, -32671, 0, -15736, 0, -32670, 0, -15735, 0, -32669, 0, -15734, 0, -32668, 0, -15733, 0, -32667, 0, -15732, 0, -32666, 0, -15731, 0, -32665, 0, -15730, 0, -32664, 0, -15729, 0, -32661, 0, -15728, 0, -32660, 0, -15727, 0, -32659, 0, -15726, 0, -32658, 0, -15725, 0, -32657, 0, -15724, 0, -32656, 0, -15723, 0, -32654, 0, -15722, 0, -32653, 0, -15721, 0, -32652, 0, -15720, 0, -32651, 0, -15719, 0, -32650, 0, -15718, 0, -32649, 0, -15717, 0, -32648, 0, -15716, 0, -32647, 0, -15715, 0, -32646, 0, -15714, 0, -32645, 0, -15713, 0, -32644, 0, -15712, 0, -32643, 0, -15711, 0, -27002, 0, -15710, 0, 22404, 0, -15709, 0, 25314, 0, -15708, 0, -27065, 0, -15707, 0, 27004, 0, -15706, 0, 23044, 0, -15705, 0, 25602, 0, -15704, 0, 31699, 0, -15703, 0, 28431, 0, -15702, 0, -27061, 0, -15701, 0, -32090, 0, -15700, 0, 21346, 0, -15699, 0, -26491, 0, -15698, 0, 24208, 0, -15697, 0, 28809, 0, -15696, 0, 25523, 0, -15695, 0, 21348, 0, -15694, 0, -31153, 0, -15693, 0, -25471, 0, -15692, 0, -24941, 0, -15691, 0, 30860, 0, -15690, 0, -26830, 0, -15689, 0, -29201, 0, -15688, 0, -29374, 0, -15687, 0, -24961, 0, -15686, 0, 28510, 0, -15685, 0, 31108, 0, -15684, 0, 24405, 0, -15683, 0, -27066, 0, -15682, 0, 25134, 0, -15681, 0, -25996, 0, -15680, 0, 21525, 0, -15679, 0, -27427, 0, -15678, 0, 20387, 0, -15677, 0, 26053, 0, -15676, 0, 23653, 0, -15675, 0, 23649, 0, -15674, 0, 32533, 0, -15673, 0, -31151, 0, -15672, 0, 27695, 0, -15671, 0, 24459, 0, -15670, 0, 29575, 0, -15669, 0, 28388, 0, -15668, 0, 32511, 0, -15667, 0, 23782, 0, -15666, 0, 25371, 0, -15665, 0, 23402, 0, -15664, 0, 28390, 0, -15663, 0, 21365, 0, -15662, 0, 20081, 0, -15661, 0, 25504, 0, -15660, 0, 30053, 0, -15659, 0, 25249, 0, -15658, 0, -28818, 0, -15657, 0, 20262, 0, -15656, 0, 20177, 0, -15655, 0, 27814, 0, -15654, 0, 32438, 0, -15653, 0, -29766, 0, -15652, 0, -31715, 0, -15651, 0, -30790, 0, -15650, 0, 32599, 0, -15649, 0, -28613, 0, -15648, 0, -27357, 0, -15647, 0, 31657, 0, -15646, 0, -25951, 0, -15645, 0, -30472, 0, -15644, 0, -31683, 0, -15643, 0, 27931, 0, -15642, 0, -25978, 0, -15641, 0, 32476, 0, -15640, 0, 22920, 0, -15639, 0, -24901, 0, -15638, 0, 29595, 0, -15637, 0, 30721, 0, -15636, 0, -31102, 0, -15635, 0, -26004, 0, -15634, 0, -25982, 0, -15633, 0, 22043, 0, -15632, 0, 21527, 0, -15631, 0, 22475, 0, -15630, 0, 20080, 0, -15629, 0, -24922, 0, -15628, 0, 21334, 0, -15627, 0, -28728, 0, -15626, 0, -32503, 0, -15625, 0, 30610, 0, -15624, 0, -26222, 0, -15623, 0, -30994, 0, -15622, 0, 28385, 0, -15621, 0, -31469, 0, -15620, 0, 26364, 0, -15619, 0, 24930, 0, -15618, 0, 28459, 0, -15552, 0, -32642, 0, -15551, 0, -32639, 0, -15550, 0, -32638, 0, -15549, 0, -32635, 0, -15548, 0, -32632, 0, -15547, 0, -32630, 0, -15546, 0, -32627, 0, -15545, 0, -32626, 0, -15544, 0, -32625, 0, -15543, 0, -32624, 0, -15542, 0, -32623, 0, -15541, 0, -32622, 0, -15540, 0, -32620, 0, -15539, 0, -32619, 0, -15538, 0, -32617, 0, -15537, 0, -32615, 0, -15536, 0, -32610, 0, -15535, 0, -32605, 0, -15534, 0, -32602, 0, -15533, 0, -32601, 0, -15532, 0, -32600, 0, -15531, 0, -32596, 0, -15530, 0, -32592, 0, -15529, 0, -32589, 0, -15528, 0, -32587, 0, -15527, 0, -32586, 0, -15526, 0, -32584, 0, -15525, 0, -32583, 0, -15524, 0, -32581, 0, -15523, 0, -32571, 0, -15522, 0, -32569, 0, -15521, 0, -32568, 0, -15520, 0, -32567, 0, -15519, 0, -32566, 0, -15518, 0, -32565, 0, -15517, 0, -32561, 0, -15516, 0, -32560, 0, -15515, 0, -32559, 0, -15514, 0, -32558, 0, -15513, 0, -32557, 0, -15512, 0, -32556, 0, -15511, 0, -32555, 0, -15510, 0, -32552, 0, -15509, 0, -32545, 0, -15508, 0, -32544, 0, -15507, 0, -32542, 0, -15506, 0, -32541, 0, -15505, 0, -32538, 0, -15504, 0, -32530, 0, -15503, 0, -32523, 0, -15502, 0, -32521, 0, -15501, 0, -32519, 0, -15500, 0, -32517, 0, -15499, 0, -32514, 0, -15498, 0, -32513, 0, -15497, 0, -32512, 0, -15496, 0, -32511, 0, -15495, 0, -32509, 0, -15494, 0, -32508, 0, -15493, 0, -32507, 0, -15492, 0, -32505, 0, -15491, 0, -32504, 0, -15490, 0, -32501, 0, -15488, 0, -32500, 0, -15487, 0, -32491, 0, -15486, 0, -32489, 0, -15485, 0, -32487, 0, -15484, 0, -32485, 0, -15483, 0, -32484, 0, -15482, 0, -32483, 0, -15481, 0, -32481, 0, -15480, 0, -32480, 0, -15479, 0, -32479, 0, -15478, 0, -32478, 0, -15477, 0, -32477, 0, -15476, 0, -32476, 0, -15475, 0, -32475, 0, -15474, 0, -32474, 0, -15473, 0, -32473, 0, -15472, 0, -32472, 0, -15471, 0, -32471, 0, -15470, 0, -32470, 0, -15469, 0, -32469, 0, -15468, 0, -32467, 0, -15467, 0, -32466, 0, -15466, 0, -32464, 0, -15465, 0, -32461, 0, -15464, 0, -32460, 0, -15463, 0, -32459, 0, -15462, 0, -32457, 0, -15461, 0, -32455, 0, -15460, 0, -32454, 0, -15459, 0, -32453, 0, -15458, 0, -32452, 0, -15457, 0, -32451, 0, -15456, 0, -32449, 0, -15455, 0, -29655, 0, -15454, 0, -32110, 0, -15453, 0, -31957, 0, -15452, 0, 30450, 0, -15451, 0, 27667, 0, -15450, 0, 24537, 0, -15449, 0, -31811, 0, -15448, 0, 29483, 0, -15447, 0, -31995, 0, -15446, 0, -27366, 0, -15445, 0, 27611, 0, -15444, 0, 30683, 0, -15443, 0, -27450, 0, -15442, 0, 21359, 0, -15441, 0, -31998, 0, -15440, 0, 20882, 0, -15439, 0, 24125, 0, -15438, 0, -29556, 0, -15437, 0, -29384, 0, -15436, 0, 20040, 0, -15435, 0, 29611, 0, -15434, 0, 26522, 0, -15433, 0, 26757, 0, -15432, 0, -28298, 0, -15431, 0, -26871, 0, -15430, 0, 29028, 0, -15429, 0, 27809, 0, -15428, 0, 30473, 0, -15427, 0, 23186, 0, -15426, 0, -27327, 0, -15425, 0, 27599, 0, -15424, 0, 32654, 0, -15423, 0, 26151, 0, -15422, 0, 23504, 0, -15421, 0, 22969, 0, -15420, 0, 23194, 0, -15419, 0, -27160, 0, -15418, 0, -27145, 0, -15417, 0, 20204, 0, -15416, 0, -31732, 0, -15415, 0, -31591, 0, -15414, 0, 27308, 0, -15413, 0, 30431, 0, -15412, 0, -27344, 0, -15411, 0, 29467, 0, -15410, 0, 26790, 0, -15409, 0, 23391, 0, -15408, 0, 30511, 0, -15407, 0, -28262, 0, -15406, 0, -26783, 0, -15405, 0, 31964, 0, -15404, 0, -28681, 0, -15403, 0, -29668, 0, -15402, 0, 24357, 0, -15401, 0, 31859, 0, -15400, 0, 31192, 0, -15399, 0, -30267, 0, -15398, 0, 27852, 0, -15397, 0, -30948, 0, -15396, 0, 23494, 0, -15395, 0, 24130, 0, -15394, 0, 26825, 0, -15393, 0, 30496, 0, -15392, 0, 32501, 0, -15391, 0, 20885, 0, -15390, 0, 20813, 0, -15389, 0, 21193, 0, -15388, 0, 23081, 0, -15387, 0, 32517, 0, -15386, 0, -26782, 0, -15385, 0, -32041, 0, -15384, 0, 25551, 0, -15383, 0, 30596, 0, -15382, 0, -31280, 0, -15381, 0, 31186, 0, -15380, 0, 28218, 0, -15379, 0, 24217, 0, -15378, 0, 22937, 0, -15377, 0, -31471, 0, -15376, 0, 28781, 0, -15375, 0, 27665, 0, -15374, 0, 25279, 0, -15373, 0, 30399, 0, -15372, 0, 25935, 0, -15371, 0, 24751, 0, -15370, 0, -27139, 0, -15369, 0, 26126, 0, -15368, 0, -30817, 0, -15367, 0, -25053, 0, -15366, 0, -27411, 0, -15365, 0, 21517, 0, -15364, 0, 21629, 0, -15363, 0, -29652, 0, -15362, 0, 25720, 0, -15296, 0, -32448, 0, -15295, 0, -32447, 0, -15294, 0, -32446, 0, -15293, 0, -32445, 0, -15292, 0, -32444, 0, -15291, 0, -32443, 0, -15290, 0, -32441, 0, -15289, 0, -32439, 0, -15288, 0, -32435, 0, -15287, 0, -32434, 0, -15286, 0, -32433, 0, -15285, 0, -32430, 0, -15284, 0, -32426, 0, -15283, 0, -32425, 0, -15282, 0, -32424, 0, -15281, 0, -32421, 0, -15280, 0, -32420, 0, -15279, 0, -32419, 0, -15278, 0, -32418, 0, -15277, 0, -32417, 0, -15276, 0, -32415, 0, -15275, 0, -32414, 0, -15274, 0, -32413, 0, -15273, 0, -32412, 0, -15272, 0, -32410, 0, -15271, 0, -32408, 0, -15270, 0, -32406, 0, -15269, 0, -32405, 0, -15268, 0, -32404, 0, -15267, 0, -32401, 0, -15266, 0, -32398, 0, -15265, 0, -32397, 0, -15264, 0, -32395, 0, -15263, 0, -32394, 0, -15262, 0, -32393, 0, -15261, 0, -32392, 0, -15260, 0, -32383, 0, -15259, 0, -32381, 0, -15258, 0, -32380, 0, -15257, 0, -32379, 0, -15256, 0, -32378, 0, -15255, 0, -32377, 0, -15254, 0, -32375, 0, -15253, 0, -32373, 0, -15252, 0, -32372, 0, -15251, 0, -32371, 0, -15250, 0, -32370, 0, -15249, 0, -32368, 0, -15248, 0, -32366, 0, -15247, 0, -32365, 0, -15246, 0, -32364, 0, -15245, 0, -32363, 0, -15244, 0, -32362, 0, -15243, 0, -32361, 0, -15242, 0, -32359, 0, -15241, 0, -32358, 0, -15240, 0, -32354, 0, -15239, 0, -32353, 0, -15238, 0, -32352, 0, -15237, 0, -32351, 0, -15236, 0, -32350, 0, -15235, 0, -32348, 0, -15234, 0, -32347, 0, -15232, 0, -32345, 0, -15231, 0, -32343, 0, -15230, 0, -32341, 0, -15229, 0, -32340, 0, -15228, 0, -32339, 0, -15227, 0, -32338, 0, -15226, 0, -32337, 0, -15225, 0, -32336, 0, -15224, 0, -32335, 0, -15223, 0, -32334, 0, -15222, 0, -32332, 0, -15221, 0, -32331, 0, -15220, 0, -32330, 0, -15219, 0, -32329, 0, -15218, 0, -32328, 0, -15217, 0, -32327, 0, -15216, 0, -32324, 0, -15215, 0, -32323, 0, -15214, 0, -32322, 0, -15213, 0, -32321, 0, -15212, 0, -32316, 0, -15211, 0, -32315, 0, -15210, 0, -32313, 0, -15209, 0, -32312, 0, -15208, 0, -32311, 0, -15207, 0, -32309, 0, -15206, 0, -32307, 0, -15205, 0, -32306, 0, -15204, 0, -32305, 0, -15203, 0, -32304, 0, -15202, 0, -32303, 0, -15201, 0, -32302, 0, -15200, 0, -32301, 0, -15199, 0, 25721, 0, -15198, 0, -31215, 0, -15197, 0, 27169, 0, -15196, 0, -32356, 0, -15195, 0, 30952, 0, -15194, 0, 25705, 0, -15193, 0, -25772, 0, -15192, 0, 25273, 0, -15191, 0, 26411, 0, -15190, 0, -31829, 0, -15189, 0, 22696, 0, -15188, 0, -24872, 0, -15187, 0, 27819, 0, -15186, 0, 28448, 0, -15185, 0, 23518, 0, -15184, 0, -27060, 0, -15183, 0, -29685, 0, -15182, 0, 29279, 0, -15181, 0, 26576, 0, -15180, 0, 25287, 0, -15179, 0, 29281, 0, -15178, 0, 20137, 0, -15177, 0, 22982, 0, -15176, 0, 27597, 0, -15175, 0, 22675, 0, -15174, 0, 26286, 0, -15173, 0, 24149, 0, -15172, 0, 21215, 0, -15171, 0, 24917, 0, -15170, 0, 26408, 0, -15169, 0, 30446, 0, -15168, 0, 30566, 0, -15167, 0, 29287, 0, -15166, 0, 31302, 0, -15165, 0, 25343, 0, -15164, 0, 21738, 0, -15163, 0, 21584, 0, -15162, 0, -27488, 0, -15161, 0, -28509, 0, -15160, 0, 23068, 0, -15159, 0, 32435, 0, -15158, 0, 27670, 0, -15157, 0, 20035, 0, -15156, 0, 22902, 0, -15155, 0, -32752, 0, -15154, 0, 22856, 0, -15153, 0, 21335, 0, -15152, 0, 30007, 0, -15151, 0, -26946, 0, -15150, 0, 22218, 0, -15149, 0, 25376, 0, -15148, 0, -32495, 0, -15147, 0, 24700, 0, -15146, 0, -27143, 0, -15145, 0, 28118, 0, -15144, 0, 21602, 0, -15143, 0, -26239, 0, -15142, 0, 20869, 0, -15141, 0, 23273, 0, -15140, 0, -32515, 0, -15139, 0, 22958, 0, -15138, 0, -26861, 0, -15137, 0, 20522, 0, -15136, 0, 27877, 0, -15135, 0, 23612, 0, -15134, 0, 25311, 0, -15133, 0, 20320, 0, -15132, 0, 21311, 0, -15131, 0, -32389, 0, -15130, 0, -28666, 0, -15129, 0, 28346, 0, -15128, 0, -31445, 0, -15127, 0, 25288, 0, -15126, 0, 24180, 0, -15125, 0, 30910, 0, -15124, 0, 25781, 0, -15123, 0, 25467, 0, -15122, 0, 24565, 0, -15121, 0, 23064, 0, -15120, 0, -28289, 0, -15119, 0, -25057, 0, -15118, 0, 23615, 0, -15117, 0, 25423, 0, -15116, 0, -32702, 0, -15115, 0, 23421, 0, -15114, 0, 21870, 0, -15113, 0, -27318, 0, -15112, 0, -27315, 0, -15111, 0, 28037, 0, -15110, 0, 24744, 0, -15109, 0, 26592, 0, -15108, 0, 29406, 0, -15107, 0, 20957, 0, -15106, 0, 23425, 0, -15040, 0, -32300, 0, -15039, 0, -32299, 0, -15038, 0, -32298, 0, -15037, 0, -32297, 0, -15036, 0, -32296, 0, -15035, 0, -32295, 0, -15034, 0, -32294, 0, -15033, 0, -32293, 0, -15032, 0, -32292, 0, -15031, 0, -32291, 0, -15030, 0, -32290, 0, -15029, 0, -32289, 0, -15028, 0, -32288, 0, -15027, 0, -32287, 0, -15026, 0, -32286, 0, -15025, 0, -32284, 0, -15024, 0, -32283, 0, -15023, 0, -32282, 0, -15022, 0, -32280, 0, -15021, 0, -32279, 0, -15020, 0, -32277, 0, -15019, 0, -32274, 0, -15018, 0, -32273, 0, -15017, 0, -32272, 0, -15016, 0, -32271, 0, -15015, 0, -32270, 0, -15014, 0, -32267, 0, -15013, 0, -32266, 0, -15012, 0, -32265, 0, -15011, 0, -32264, 0, -15010, 0, -32263, 0, -15009, 0, -32262, 0, -15008, 0, -32259, 0, -15007, 0, -32257, 0, -15006, 0, -32253, 0, -15005, 0, -32249, 0, -15004, 0, -32248, 0, -15003, 0, -32247, 0, -15002, 0, -32246, 0, -15001, 0, -32245, 0, -15000, 0, -32242, 0, -14999, 0, -32241, 0, -14998, 0, -32239, 0, -14997, 0, -32237, 0, -14996, 0, -32235, 0, -14995, 0, -32234, 0, -14994, 0, -32233, 0, -14993, 0, -32232, 0, -14992, 0, -32231, 0, -14991, 0, -32230, 0, -14990, 0, -32227, 0, -14989, 0, -32224, 0, -14988, 0, -32220, 0, -14987, 0, -32219, 0, -14986, 0, -32218, 0, -14985, 0, -32217, 0, -14984, 0, -32215, 0, -14983, 0, -32210, 0, -14982, 0, -32206, 0, -14981, 0, -32198, 0, -14980, 0, -32196, 0, -14979, 0, -32195, 0, -14978, 0, -32193, 0, -14976, 0, -32192, 0, -14975, 0, -32191, 0, -14974, 0, -32190, 0, -14973, 0, -32189, 0, -14972, 0, -32187, 0, -14971, 0, -32186, 0, -14970, 0, -32184, 0, -14969, 0, -32182, 0, -14968, 0, -32180, 0, -14967, 0, -32179, 0, -14966, 0, -32178, 0, -14965, 0, -32176, 0, -14964, 0, -32175, 0, -14963, 0, -32174, 0, -14962, 0, -32173, 0, -14961, 0, -32172, 0, -14960, 0, -32171, 0, -14959, 0, -32170, 0, -14958, 0, -32169, 0, -14957, 0, -32167, 0, -14956, 0, -32165, 0, -14955, 0, -32164, 0, -14954, 0, -32163, 0, -14953, 0, -32162, 0, -14952, 0, -32160, 0, -14951, 0, -32159, 0, -14950, 0, -32158, 0, -14949, 0, -32157, 0, -14948, 0, -32156, 0, -14947, 0, -32155, 0, -14946, 0, -32154, 0, -14945, 0, -32153, 0, -14944, 0, -32151, 0, -14943, 0, 25319, 0, -14942, 0, 27870, 0, -14941, 0, 29275, 0, -14940, 0, 25197, 0, -14939, 0, -27474, 0, -14938, 0, 32445, 0, -14937, 0, -32493, 0, -14936, 0, 27987, 0, -14935, 0, 20892, 0, -14934, 0, 24324, 0, -14933, 0, 22900, 0, -14932, 0, 21162, 0, -14931, 0, 24594, 0, -14930, 0, 22899, 0, -14929, 0, 26262, 0, -14928, 0, -31152, 0, -14927, 0, 30111, 0, -14926, 0, 25386, 0, -14925, 0, 25062, 0, -14924, 0, 31983, 0, -14923, 0, -29702, 0, -14922, 0, 21734, 0, -14921, 0, 27431, 0, -14920, 0, -25051, 0, -14919, 0, 27572, 0, -14918, 0, -31275, 0, -14917, 0, 21589, 0, -14916, 0, 20598, 0, -14915, 0, 27812, 0, -14914, 0, 21866, 0, -14913, 0, -29260, 0, -14912, 0, 29228, 0, -14911, 0, 24085, 0, -14910, 0, 24597, 0, -14909, 0, 29750, 0, -14908, 0, 25293, 0, -14907, 0, 25490, 0, -14906, 0, 29260, 0, -14905, 0, 24472, 0, -14904, 0, 28227, 0, -14903, 0, 27966, 0, -14902, 0, 25856, 0, -14901, 0, 28504, 0, -14900, 0, 30424, 0, -14899, 0, 30928, 0, -14898, 0, 30460, 0, -14897, 0, 30036, 0, -14896, 0, 21028, 0, -14895, 0, 21467, 0, -14894, 0, 20051, 0, -14893, 0, 24222, 0, -14892, 0, 26049, 0, -14891, 0, -32726, 0, -14890, 0, -32554, 0, -14889, 0, 25243, 0, -14888, 0, 21638, 0, -14887, 0, 21032, 0, -14886, 0, 28846, 0, -14885, 0, -30579, 0, -14884, 0, -29231, 0, -14883, 0, 27873, 0, -14882, 0, 21624, 0, -14881, 0, -32550, 0, -14880, 0, 22521, 0, -14879, 0, -30476, 0, -14878, 0, -29356, 0, -14877, 0, -27030, 0, -14876, 0, -28339, 0, -14875, 0, 20329, 0, -14874, 0, 27803, 0, -14873, 0, 21943, 0, -14872, 0, 30406, 0, -14871, 0, 30768, 0, -14870, 0, 25256, 0, -14869, 0, 28921, 0, -14868, 0, 28558, 0, -14867, 0, 24429, 0, -14866, 0, -31508, 0, -14865, 0, 26842, 0, -14864, 0, 30844, 0, -14863, 0, 31735, 0, -14862, 0, -32344, 0, -14861, 0, 26379, 0, -14860, 0, -25009, 0, -14859, 0, 25447, 0, -14858, 0, 30896, 0, -14857, 0, 22383, 0, -14856, 0, 30738, 0, -14855, 0, -26823, 0, -14854, 0, 25209, 0, -14853, 0, 25259, 0, -14852, 0, 21128, 0, -14851, 0, 29749, 0, -14850, 0, 27607, 0, -14784, 0, -32150, 0, -14783, 0, -32149, 0, -14782, 0, -32148, 0, -14781, 0, -32147, 0, -14780, 0, -32143, 0, -14779, 0, -32139, 0, -14778, 0, -32138, 0, -14777, 0, -32137, 0, -14776, 0, -32136, 0, -14775, 0, -32133, 0, -14774, 0, -32132, 0, -14773, 0, -32128, 0, -14772, 0, -32127, 0, -14771, 0, -32125, 0, -14770, 0, -32123, 0, -14769, 0, -32122, 0, -14768, 0, -32121, 0, -14767, 0, -32119, 0, -14766, 0, -32116, 0, -14765, 0, -32112, 0, -14764, 0, -32109, 0, -14763, 0, -32108, 0, -14762, 0, -32107, 0, -14761, 0, -32106, 0, -14760, 0, -32102, 0, -14759, 0, -32101, 0, -14758, 0, -32098, 0, -14757, 0, -32096, 0, -14756, 0, -32094, 0, -14755, 0, -32093, 0, -14754, 0, -32089, 0, -14753, 0, -32078, 0, -14752, 0, -32075, 0, -14751, 0, -32074, 0, -14750, 0, -32070, 0, -14749, 0, -32069, 0, -14748, 0, -32068, 0, -14747, 0, -32065, 0, -14746, 0, -32064, 0, -14745, 0, -32062, 0, -14744, 0, -32061, 0, -14743, 0, -32059, 0, -14742, 0, -32058, 0, -14741, 0, -32055, 0, -14740, 0, -32048, 0, -14739, 0, -32042, 0, -14738, 0, -32039, 0, -14737, 0, -32038, 0, -14736, 0, -32035, 0, -14735, 0, -32030, 0, -14734, 0, -32025, 0, -14733, 0, -32024, 0, -14732, 0, -32023, 0, -14731, 0, -32022, 0, -14730, 0, -32020, 0, -14729, 0, -32019, 0, -14728, 0, -32018, 0, -14727, 0, -32016, 0, -14726, 0, -32014, 0, -14725, 0, -32013, 0, -14724, 0, -32011, 0, -14723, 0, -32010, 0, -14722, 0, -32008, 0, -14720, 0, -32006, 0, -14719, 0, -32004, 0, -14718, 0, -32003, 0, -14717, 0, -32002, 0, -14716, 0, -32001, 0, -14715, 0, -32000, 0, -14714, 0, -31990, 0, -14713, 0, -31989, 0, -14712, 0, -31987, 0, -14711, 0, -31984, 0, -14710, 0, -31982, 0, -14709, 0, -31981, 0, -14708, 0, -31978, 0, -14707, 0, -31976, 0, -14706, 0, -31975, 0, -14705, 0, -31971, 0, -14704, 0, -31970, 0, -14703, 0, -31969, 0, -14702, 0, -31968, 0, -14701, 0, -31967, 0, -14700, 0, -31966, 0, -14699, 0, -31965, 0, -14698, 0, -31964, 0, -14697, 0, -31963, 0, -14696, 0, -31962, 0, -14695, 0, -31959, 0, -14694, 0, -31958, 0, -14693, 0, -31954, 0, -14692, 0, -31952, 0, -14691, 0, -31950, 0, -14690, 0, -31945, 0, -14689, 0, -31941, 0, -14688, 0, -31939, 0, -14687, 0, 21860, 0, -14686, 0, -32450, 0, -14685, 0, 30130, 0, -14684, 0, 30382, 0, -14683, 0, 21305, 0, -14682, 0, 30174, 0, -14681, 0, 20731, 0, -14680, 0, 23617, 0, -14679, 0, -29844, 0, -14678, 0, 31687, 0, -14677, 0, 20559, 0, -14676, 0, 29255, 0, -14675, 0, -25961, 0, -14674, 0, -26408, 0, -14673, 0, 28418, 0, -14672, 0, 29922, 0, -14671, 0, 31080, 0, -14670, 0, 25735, 0, -14669, 0, 30629, 0, -14668, 0, 25340, 0, -14667, 0, -26479, 0, -14666, 0, -29397, 0, -14665, 0, 21697, 0, -14664, 0, -32680, 0, -14663, 0, 20050, 0, -14662, 0, 22378, 0, -14661, 0, -32007, 0, -14660, 0, -31731, 0, -14659, 0, 24179, 0, -14658, 0, 20973, 0, -14657, 0, 29942, 0, -14656, 0, -29756, 0, -14655, 0, 23631, 0, -14654, 0, 22369, 0, -14653, 0, 27900, 0, -14652, 0, -26489, 0, -14651, 0, 23110, 0, -14650, 0, 30772, 0, -14649, 0, -25788, 0, -14648, 0, -28693, 0, -14647, 0, 31893, 0, -14646, 0, 21078, 0, -14645, 0, 25169, 0, -14644, 0, -27398, 0, -14643, 0, 20166, 0, -14642, 0, -31866, 0, -14641, 0, -31647, 0, -14640, 0, -31767, 0, -14639, 0, -31566, 0, -14638, 0, 22484, 0, -14637, 0, 26420, 0, -14636, 0, 22275, 0, -14635, 0, 26222, 0, -14634, 0, 28006, 0, -14633, 0, -29647, 0, -14632, 0, 26333, 0, -14631, 0, 28689, 0, -14630, 0, 26399, 0, -14629, 0, 27450, 0, -14628, 0, 26646, 0, -14627, 0, 25114, 0, -14626, 0, 22971, 0, -14625, 0, 19971, 0, -14624, 0, 20932, 0, -14623, 0, 28422, 0, -14622, 0, 26578, 0, -14621, 0, 27791, 0, -14620, 0, 20854, 0, -14619, 0, 26827, 0, -14618, 0, 22855, 0, -14617, 0, 27495, 0, -14616, 0, 30054, 0, -14615, 0, 23822, 0, -14614, 0, -32496, 0, -14613, 0, -24752, 0, -14612, 0, 26071, 0, -14611, 0, 31048, 0, -14610, 0, 31041, 0, -14609, 0, -25967, 0, -14608, 0, -29321, 0, -14607, 0, 23682, 0, -14606, 0, 20062, 0, -14605, 0, 20225, 0, -14604, 0, 21551, 0, -14603, 0, 22865, 0, -14602, 0, 30732, 0, -14601, 0, 22120, 0, -14600, 0, 27668, 0, -14599, 0, -28732, 0, -14598, 0, 24323, 0, -14597, 0, 27773, 0, -14596, 0, 27875, 0, -14595, 0, -29781, 0, -14594, 0, 25488, 0, -14528, 0, -31938, 0, -14527, 0, -31937, 0, -14526, 0, -31935, 0, -14525, 0, -31934, 0, -14524, 0, -31932, 0, -14523, 0, -31931, 0, -14522, 0, -31928, 0, -14521, 0, -31926, 0, -14520, 0, -31925, 0, -14519, 0, -31924, 0, -14518, 0, -31923, 0, -14517, 0, -31922, 0, -14516, 0, -31917, 0, -14515, 0, -31915, 0, -14514, 0, -31914, 0, -14513, 0, -31913, 0, -14512, 0, -31912, 0, -14511, 0, -31911, 0, -14510, 0, -31907, 0, -14509, 0, -31902, 0, -14508, 0, -31888, 0, -14507, 0, -31887, 0, -14506, 0, -31886, 0, -14505, 0, -31885, 0, -14504, 0, -31884, 0, -14503, 0, -31883, 0, -14502, 0, -31882, 0, -14501, 0, -31879, 0, -14500, 0, -31878, 0, -14499, 0, -31874, 0, -14498, 0, -31873, 0, -14497, 0, -31872, 0, -14496, 0, -31871, 0, -14495, 0, -31870, 0, -14494, 0, -31869, 0, -14493, 0, -31868, 0, -14492, 0, -31865, 0, -14491, 0, -31864, 0, -14490, 0, -31862, 0, -14489, 0, -31861, 0, -14488, 0, -31860, 0, -14487, 0, -31859, 0, -14486, 0, -31857, 0, -14485, 0, -31856, 0, -14484, 0, -31855, 0, -14483, 0, -31852, 0, -14482, 0, -31851, 0, -14481, 0, -31850, 0, -14480, 0, -31849, 0, -14479, 0, -31847, 0, -14478, 0, -31846, 0, -14477, 0, -31843, 0, -14476, 0, -31841, 0, -14475, 0, -31839, 0, -14474, 0, -31838, 0, -14473, 0, -31837, 0, -14472, 0, -31836, 0, -14471, 0, -31835, 0, -14470, 0, -31834, 0, -14469, 0, -31833, 0, -14468, 0, -31828, 0, -14467, 0, -31827, 0, -14466, 0, -31826, 0, -14464, 0, -31825, 0, -14463, 0, -31819, 0, -14462, 0, -31813, 0, -14461, 0, -31810, 0, -14460, 0, -31809, 0, -14459, 0, -31806, 0, -14458, 0, -31805, 0, -14457, 0, -31804, 0, -14456, 0, -31802, 0, -14455, 0, -31800, 0, -14454, 0, -31799, 0, -14453, 0, -31797, 0, -14452, 0, -31795, 0, -14451, 0, -31794, 0, -14450, 0, -31792, 0, -14449, 0, -31791, 0, -14448, 0, -31790, 0, -14447, 0, -31789, 0, -14446, 0, -31787, 0, -14445, 0, -31785, 0, -14444, 0, -31783, 0, -14443, 0, -31782, 0, -14442, 0, -31781, 0, -14441, 0, -31778, 0, -14440, 0, -31774, 0, -14439, 0, -31773, 0, -14438, 0, -31772, 0, -14437, 0, -31770, 0, -14436, 0, -31769, 0, -14435, 0, -31768, 0, -14434, 0, -31765, 0, -14433, 0, -31764, 0, -14432, 0, -31763, 0, -14431, 0, 24688, 0, -14430, 0, 27965, 0, -14429, 0, 29301, 0, -14428, 0, 25190, 0, -14427, 0, -27506, 0, -14426, 0, -27451, 0, -14425, 0, 21315, 0, -14424, 0, -28735, 0, -14423, 0, 31614, 0, -14422, 0, 20191, 0, -14421, 0, -29658, 0, -14420, 0, 20094, 0, -14419, 0, -24876, 0, -14418, 0, -27471, 0, -14417, 0, -27469, 0, -14416, 0, 21069, 0, -14415, 0, 28508, 0, -14414, 0, -28573, 0, -14413, 0, 27973, 0, -14412, 0, -29644, 0, -14411, 0, 22545, 0, -14410, 0, 23884, 0, -14409, 0, 27424, 0, -14408, 0, 27465, 0, -14407, 0, 26538, 0, -14406, 0, 21595, 0, -14405, 0, -32428, 0, -14404, 0, 32652, 0, -14403, 0, 22681, 0, -14402, 0, -31433, 0, -14401, 0, 24378, 0, -14400, 0, 25250, 0, -14399, 0, 27207, 0, -14398, 0, -27335, 0, -14397, 0, 25970, 0, -14396, 0, 24708, 0, -14395, 0, 26725, 0, -14394, 0, 30631, 0, -14393, 0, 20052, 0, -14392, 0, 20392, 0, -14391, 0, 24039, 0, -14390, 0, -26728, 0, -14389, 0, 25772, 0, -14388, 0, 32728, 0, -14387, 0, 23789, 0, -14386, 0, 20431, 0, -14385, 0, 31373, 0, -14384, 0, 20999, 0, -14383, 0, -31996, 0, -14382, 0, 19988, 0, -14381, 0, 24623, 0, -14380, 0, 31363, 0, -14379, 0, -27482, 0, -14378, 0, 20405, 0, -14377, 0, 20146, 0, -14376, 0, 31206, 0, -14375, 0, 29748, 0, -14374, 0, 21220, 0, -14373, 0, -32071, 0, -14372, 0, 25810, 0, -14371, 0, 31165, 0, -14370, 0, 23517, 0, -14369, 0, 27777, 0, -14368, 0, -26798, 0, -14367, 0, -28805, 0, -14366, 0, 27682, 0, -14365, 0, 20542, 0, -14364, 0, 21375, 0, -14363, 0, 28165, 0, -14362, 0, 25806, 0, -14361, 0, 26228, 0, -14360, 0, 27696, 0, -14359, 0, 24773, 0, -14358, 0, -26505, 0, -14357, 0, -29705, 0, -14356, 0, 24198, 0, -14355, 0, 29756, 0, -14354, 0, 31351, 0, -14353, 0, 31179, 0, -14352, 0, 19992, 0, -14351, 0, -28495, 0, -14350, 0, 29699, 0, -14349, 0, 27714, 0, -14348, 0, 22234, 0, -14347, 0, -28341, 0, -14346, 0, 27845, 0, -14345, 0, -29301, 0, -14344, 0, 21306, 0, -14343, 0, -31034, 0, -14342, 0, 26354, 0, -14341, 0, -29009, 0, -14340, 0, 23624, 0, -14339, 0, -25999, 0, -14338, 0, 28192, 0, -14272, 0, -31762, 0, -14271, 0, -31761, 0, -14270, 0, -31757, 0, -14269, 0, -31756, 0, -14268, 0, -31755, 0, -14267, 0, -31754, 0, -14266, 0, -31753, 0, -14265, 0, -31750, 0, -14264, 0, -31749, 0, -14263, 0, -31748, 0, -14262, 0, -31746, 0, -14261, 0, -31745, 0, -14260, 0, -31744, 0, -14259, 0, -31742, 0, -14258, 0, -31739, 0, -14257, 0, -31737, 0, -14256, 0, -31736, 0, -14255, 0, -31735, 0, -14254, 0, -31734, 0, -14253, 0, -31728, 0, -14252, 0, -31726, 0, -14251, 0, -31725, 0, -14250, 0, -31724, 0, -14249, 0, -31723, 0, -14248, 0, -31722, 0, -14247, 0, -31721, 0, -14246, 0, -31719, 0, -14245, 0, -31718, 0, -14244, 0, -31717, 0, -14243, 0, -31714, 0, -14242, 0, -31713, 0, -14241, 0, -31712, 0, -14240, 0, -31711, 0, -14239, 0, -31710, 0, -14238, 0, -31709, 0, -14237, 0, -31703, 0, -14236, 0, -31702, 0, -14235, 0, -31701, 0, -14234, 0, -31700, 0, -14233, 0, -31699, 0, -14232, 0, -31698, 0, -14231, 0, -31697, 0, -14230, 0, -31696, 0, -14229, 0, -31694, 0, -14228, 0, -31693, 0, -14227, 0, -31692, 0, -14226, 0, -31691, 0, -14225, 0, -31690, 0, -14224, 0, -31689, 0, -14223, 0, -31687, 0, -14222, 0, -31686, 0, -14221, 0, -31685, 0, -14220, 0, -31682, 0, -14219, 0, -31681, 0, -14218, 0, -31680, 0, -14217, 0, -31679, 0, -14216, 0, -31678, 0, -14215, 0, -31677, 0, -14214, 0, -31676, 0, -14213, 0, -31675, 0, -14212, 0, -31673, 0, -14211, 0, -31672, 0, -14210, 0, -31671, 0, -14208, 0, -31670, 0, -14207, 0, -31669, 0, -14206, 0, -31668, 0, -14205, 0, -31667, 0, -14204, 0, -31666, 0, -14203, 0, -31665, 0, -14202, 0, -31664, 0, -14201, 0, -31662, 0, -14200, 0, -31661, 0, -14199, 0, -31660, 0, -14198, 0, -31659, 0, -14197, 0, -31658, 0, -14196, 0, -31656, 0, -14195, 0, -31651, 0, -14194, 0, -31650, 0, -14193, 0, -31649, 0, -14192, 0, -31648, 0, -14191, 0, -31646, 0, -14190, 0, -31644, 0, -14189, 0, -31643, 0, -14188, 0, -31642, 0, -14187, 0, -31641, 0, -14186, 0, -31640, 0, -14185, 0, -31638, 0, -14184, 0, -31634, 0, -14183, 0, -31633, 0, -14182, 0, -31632, 0, -14181, 0, -31630, 0, -14180, 0, -31628, 0, -14179, 0, -31625, 0, -14178, 0, -31623, 0, -14177, 0, -31621, 0, -14176, 0, -31620, 0, -14175, 0, 21462, 0, -14174, 0, 23094, 0, -14173, 0, -24693, 0, -14172, 0, -29277, 0, -14171, 0, 21435, 0, -14170, 0, 22280, 0, -14169, 0, -26457, 0, -14168, 0, 26435, 0, -14167, 0, -28261, 0, -14166, 0, 27849, 0, -14165, 0, 20840, 0, -14164, 0, 30154, 0, -14163, 0, 25331, 0, -14162, 0, 29356, 0, -14161, 0, 21048, 0, -14160, 0, 21149, 0, -14159, 0, 32570, 0, -14158, 0, 28820, 0, -14157, 0, 30264, 0, -14156, 0, 21364, 0, -14155, 0, -25014, 0, -14154, 0, 27063, 0, -14153, 0, 30830, 0, -14152, 0, -26944, 0, -14151, 0, -30503, 0, -14150, 0, 32676, 0, -14149, 0, 28982, 0, -14148, 0, 29123, 0, -14147, 0, 20873, 0, -14146, 0, 26579, 0, -14145, 0, 29924, 0, -14144, 0, 22756, 0, -14143, 0, 25880, 0, -14142, 0, 22199, 0, -14141, 0, -29783, 0, -14140, 0, -26250, 0, -14139, 0, 25200, 0, -14138, 0, 32469, 0, -14137, 0, 24825, 0, -14136, 0, 28909, 0, -14135, 0, 22764, 0, -14134, 0, 20161, 0, -14133, 0, 20154, 0, -14132, 0, 24525, 0, -14131, 0, -26649, 0, -14130, 0, 20219, 0, -14129, 0, -29788, 0, -14128, 0, 20995, 0, -14127, 0, 22922, 0, -14126, 0, 32427, 0, -14125, 0, 25172, 0, -14124, 0, 20173, 0, -14123, 0, 26085, 0, -14122, 0, 25102, 0, -14121, 0, -31944, 0, -14120, 0, -31543, 0, -14119, 0, -31901, 0, -14118, 0, -30835, 0, -14117, 0, 29076, 0, -14116, 0, 28342, 0, -14115, 0, 23481, 0, -14114, 0, 32466, 0, -14113, 0, 20887, 0, -14112, 0, 25545, 0, -14111, 0, 26580, 0, -14110, 0, -32631, 0, -14109, 0, -31943, 0, -14108, 0, -30699, 0, -14107, 0, 20754, 0, -14106, 0, 23418, 0, -14105, 0, 22914, 0, -14104, 0, -28751, 0, -14103, 0, 20083, 0, -14102, 0, 27741, 0, -14101, 0, 20837, 0, -14100, 0, -30427, 0, -14099, 0, -28817, 0, -14098, 0, -27090, 0, -14097, 0, -31414, 0, -14096, 0, 29790, 0, -14095, 0, -27376, 0, -14094, 0, -27152, 0, -14093, 0, 28070, 0, -14092, 0, -32027, 0, -14091, 0, 24369, 0, -14090, 0, 25746, 0, -14089, 0, 27922, 0, -14088, 0, -31704, 0, -14087, 0, -32402, 0, -14086, 0, -25405, 0, -14085, 0, 22622, 0, -14084, 0, -29349, 0, -14083, 0, 19977, 0, -14082, 0, 21441, 0, -14016, 0, -31619, 0, -14015, 0, -31618, 0, -14014, 0, -31617, 0, -14013, 0, -31616, 0, -14012, 0, -31615, 0, -14011, 0, -31613, 0, -14010, 0, -31612, 0, -14009, 0, -31611, 0, -14008, 0, -31610, 0, -14007, 0, -31606, 0, -14006, 0, -31603, 0, -14005, 0, -31601, 0, -14004, 0, -31600, 0, -14003, 0, -31599, 0, -14002, 0, -31598, 0, -14001, 0, -31597, 0, -14000, 0, -31596, 0, -13999, 0, -31595, 0, -13998, 0, -31594, 0, -13997, 0, -31592, 0, -13996, 0, -31590, 0, -13995, 0, -31589, 0, -13994, 0, -31587, 0, -13993, 0, -31586, 0, -13992, 0, -31585, 0, -13991, 0, -31584, 0, -13990, 0, -31582, 0, -13989, 0, -31581, 0, -13988, 0, -31580, 0, -13987, 0, -31579, 0, -13986, 0, -31578, 0, -13985, 0, -31577, 0, -13984, 0, -31576, 0, -13983, 0, -31575, 0, -13982, 0, -31574, 0, -13981, 0, -31573, 0, -13980, 0, -31572, 0, -13979, 0, -31571, 0, -13978, 0, -31570, 0, -13977, 0, -31568, 0, -13976, 0, -31567, 0, -13975, 0, -31565, 0, -13974, 0, -31563, 0, -13973, 0, -31562, 0, -13972, 0, -31561, 0, -13971, 0, -31557, 0, -13970, 0, -31556, 0, -13969, 0, -31554, 0, -13968, 0, -31552, 0, -13967, 0, -31550, 0, -13966, 0, -31549, 0, -13965, 0, -31547, 0, -13964, 0, -31546, 0, -13963, 0, -31545, 0, -13962, 0, -31544, 0, -13961, 0, -31541, 0, -13960, 0, -31540, 0, -13959, 0, -31538, 0, -13958, 0, -31537, 0, -13957, 0, -31534, 0, -13956, 0, -31532, 0, -13955, 0, -31531, 0, -13954, 0, -31529, 0, -13952, 0, -31528, 0, -13951, 0, -31527, 0, -13950, 0, -31526, 0, -13949, 0, -31525, 0, -13948, 0, -31524, 0, -13947, 0, -31522, 0, -13946, 0, -31519, 0, -13945, 0, -31518, 0, -13944, 0, -31516, 0, -13943, 0, -31513, 0, -13942, 0, -31512, 0, -13941, 0, -31511, 0, -13940, 0, -31510, 0, -13939, 0, -31509, 0, -13938, 0, -31507, 0, -13937, 0, -31506, 0, -13936, 0, -31505, 0, -13935, 0, -31503, 0, -13934, 0, -31502, 0, -13933, 0, -31501, 0, -13932, 0, -31500, 0, -13931, 0, -31499, 0, -13930, 0, -31498, 0, -13929, 0, -31497, 0, -13928, 0, -31496, 0, -13927, 0, -31495, 0, -13926, 0, -31494, 0, -13925, 0, -31493, 0, -13924, 0, -31491, 0, -13923, 0, -31490, 0, -13922, 0, -31488, 0, -13921, 0, -31487, 0, -13920, 0, -31486, 0, -13919, 0, 20254, 0, -13918, 0, 25955, 0, -13917, 0, 26705, 0, -13916, 0, 21971, 0, -13915, 0, 20007, 0, -13914, 0, 25620, 0, -13913, 0, -25958, 0, -13912, 0, 25195, 0, -13911, 0, 23234, 0, -13910, 0, 29791, 0, -13909, 0, -32142, 0, -13908, 0, 28073, 0, -13907, 0, 26862, 0, -13906, 0, 20711, 0, -13905, 0, -31858, 0, -13904, 0, 30722, 0, -13903, 0, 26432, 0, -13902, 0, 21049, 0, -13901, 0, 27801, 0, -13900, 0, 32433, 0, -13899, 0, 20667, 0, -13898, 0, 21861, 0, -13897, 0, 29022, 0, -13896, 0, 31579, 0, -13895, 0, 26194, 0, -13894, 0, 29642, 0, -13893, 0, -32021, 0, -13892, 0, 26441, 0, -13891, 0, 23665, 0, -13890, 0, 21024, 0, -13889, 0, 29053, 0, -13888, 0, -30613, 0, -13887, 0, -27158, 0, -13886, 0, -27051, 0, -13885, 0, 25797, 0, -13884, 0, -29343, 0, -13883, 0, -32333, 0, -13882, 0, 21892, 0, -13881, 0, 27733, 0, -13880, 0, 25159, 0, -13879, 0, 32558, 0, -13878, 0, 22674, 0, -13877, 0, 20260, 0, -13876, 0, 21830, 0, -13875, 0, -29361, 0, -13874, 0, 26188, 0, -13873, 0, 19978, 0, -13872, 0, 23578, 0, -13871, 0, -30477, 0, -13870, 0, 26786, 0, -13869, 0, 25422, 0, -13868, 0, 31245, 0, -13867, 0, 28903, 0, -13866, 0, -32115, 0, -13865, 0, 21242, 0, -13864, 0, -26634, 0, -13863, 0, 23569, 0, -13862, 0, 21736, 0, -13861, 0, -28491, 0, -13860, 0, 32461, 0, -13859, 0, 22882, 0, -13858, 0, -29366, 0, -13857, 0, -31033, 0, -13856, 0, -32244, 0, -13855, 0, -32243, 0, -13854, 0, -29338, 0, -13853, 0, 25668, 0, -13852, 0, 23556, 0, -13851, 0, 24913, 0, -13850, 0, 28041, 0, -13849, 0, 31038, 0, -13848, 0, -29762, 0, -13847, 0, 30775, 0, -13846, 0, 30003, 0, -13845, 0, 21627, 0, -13844, 0, 20280, 0, -13843, 0, -29013, 0, -13842, 0, 28145, 0, -13841, 0, 23072, 0, -13840, 0, 32453, 0, -13839, 0, 31070, 0, -13838, 0, 27784, 0, -13837, 0, 23457, 0, -13836, 0, 23158, 0, -13835, 0, 29978, 0, -13834, 0, -32578, 0, -13833, 0, 24910, 0, -13832, 0, 28183, 0, -13831, 0, 22768, 0, -13830, 0, 29983, 0, -13829, 0, 29989, 0, -13828, 0, 29298, 0, -13827, 0, 21319, 0, -13826, 0, 32499, 0, -13760, 0, -31485, 0, -13759, 0, -31484, 0, -13758, 0, -31483, 0, -13757, 0, -31482, 0, -13756, 0, -31481, 0, -13755, 0, -31480, 0, -13754, 0, -31479, 0, -13753, 0, -31478, 0, -13752, 0, -31477, 0, -13751, 0, -31475, 0, -13750, 0, -31474, 0, -13749, 0, -31473, 0, -13748, 0, -31472, 0, -13747, 0, -31470, 0, -13746, 0, -31468, 0, -13745, 0, -31467, 0, -13744, 0, -31466, 0, -13743, 0, -31464, 0, -13742, 0, -31463, 0, -13741, 0, -31461, 0, -13740, 0, -31460, 0, -13739, 0, -31459, 0, -13738, 0, -31458, 0, -13737, 0, -31456, 0, -13736, 0, -31454, 0, -13735, 0, -31453, 0, -13734, 0, -31452, 0, -13733, 0, -31451, 0, -13732, 0, -31450, 0, -13731, 0, -31449, 0, -13730, 0, -31448, 0, -13729, 0, -31447, 0, -13728, 0, -31446, 0, -13727, 0, -31443, 0, -13726, 0, -31442, 0, -13725, 0, -31441, 0, -13724, 0, -31440, 0, -13723, 0, -31439, 0, -13722, 0, -31438, 0, -13721, 0, -31437, 0, -13720, 0, -31436, 0, -13719, 0, -31435, 0, -13718, 0, -31434, 0, -13717, 0, -31426, 0, -13716, 0, -31425, 0, -13715, 0, -31424, 0, -13714, 0, -31423, 0, -13713, 0, -31422, 0, -13712, 0, -31420, 0, -13711, 0, -31419, 0, -13710, 0, -31418, 0, -13709, 0, -31417, 0, -13708, 0, -31413, 0, -13707, 0, -31412, 0, -13706, 0, -31411, 0, -13705, 0, -31410, 0, -13704, 0, -31409, 0, -13703, 0, -31408, 0, -13702, 0, -31407, 0, -13701, 0, -31406, 0, -13700, 0, -31405, 0, -13699, 0, -31404, 0, -13698, 0, -31403, 0, -13696, 0, -31401, 0, -13695, 0, -31400, 0, -13694, 0, -31398, 0, -13693, 0, -31397, 0, -13692, 0, -31396, 0, -13691, 0, -31395, 0, -13690, 0, -31393, 0, -13689, 0, -31392, 0, -13688, 0, -31391, 0, -13687, 0, -31390, 0, -13686, 0, -31389, 0, -13685, 0, -31387, 0, -13684, 0, -31386, 0, -13683, 0, -31385, 0, -13682, 0, -31383, 0, -13681, 0, -31382, 0, -13680, 0, -31381, 0, -13679, 0, -31380, 0, -13678, 0, -31379, 0, -13677, 0, -31378, 0, -13676, 0, -31377, 0, -13675, 0, -31376, 0, -13674, 0, -31375, 0, -13673, 0, -31373, 0, -13672, 0, -31371, 0, -13671, 0, -31370, 0, -13670, 0, -31369, 0, -13669, 0, -31368, 0, -13668, 0, -31364, 0, -13667, 0, -31363, 0, -13666, 0, -31361, 0, -13665, 0, -31360, 0, -13664, 0, -31359, 0, -13663, 0, 30465, 0, -13662, 0, 30427, 0, -13661, 0, 21097, 0, -13660, 0, -32548, 0, -13659, 0, 22307, 0, -13658, 0, 24072, 0, -13657, 0, 22833, 0, -13656, 0, 29422, 0, -13655, 0, 26045, 0, -13654, 0, 28287, 0, -13653, 0, -29737, 0, -13652, 0, 23608, 0, -13651, 0, -31119, 0, -13650, 0, 21313, 0, -13649, 0, 30707, 0, -13648, 0, 25342, 0, -13647, 0, 26102, 0, -13646, 0, 20160, 0, -13645, 0, -26401, 0, -13644, 0, -31104, 0, -13643, 0, 23454, 0, -13642, 0, -29754, 0, -13641, 0, 21490, 0, -13640, 0, 30690, 0, -13639, 0, 20351, 0, -13638, 0, 23630, 0, -13637, 0, -25994, 0, -13636, 0, 22987, 0, -13635, 0, 24335, 0, -13634, 0, 31034, 0, -13633, 0, 22763, 0, -13632, 0, 19990, 0, -13631, 0, 26623, 0, -13630, 0, 20107, 0, -13629, 0, 25325, 0, -13628, 0, -30061, 0, -13627, 0, -28643, 0, -13626, 0, 21183, 0, -13625, 0, 26159, 0, -13624, 0, 21980, 0, -13623, 0, 22124, 0, -13622, 0, -28670, 0, -13621, 0, 20181, 0, -13620, 0, 20365, 0, -13619, 0, -28214, 0, -13618, 0, -26256, 0, -13617, 0, 27663, 0, -13616, 0, 24066, 0, -13615, 0, 24643, 0, -13614, 0, 23460, 0, -13613, 0, -30266, 0, -13612, 0, -29739, 0, -13611, 0, 25910, 0, -13610, 0, 25163, 0, -13609, 0, -26218, 0, -13608, 0, 23432, 0, -13607, 0, 23551, 0, -13606, 0, 25480, 0, -13605, 0, 21806, 0, -13604, 0, 21463, 0, -13603, 0, 30246, 0, -13602, 0, 20861, 0, -13601, 0, -31444, 0, -13600, 0, 26530, 0, -13599, 0, 26803, 0, -13598, 0, 27530, 0, -13597, 0, 25234, 0, -13596, 0, -28781, 0, -13595, 0, 21460, 0, -13594, 0, -32238, 0, -13593, 0, 28113, 0, -13592, 0, 30095, 0, -13591, 0, 20070, 0, -13590, 0, -29362, 0, -13589, 0, 23408, 0, -13588, 0, 29087, 0, -13587, 0, -31313, 0, -13586, 0, 26257, 0, -13585, 0, 26329, 0, -13584, 0, 32626, 0, -13583, 0, -30976, 0, -13582, 0, -24883, 0, -13581, 0, -24800, 0, -13580, 0, 23646, 0, -13579, 0, 26415, 0, -13578, 0, -28688, 0, -13577, 0, 26641, 0, -13576, 0, 26463, 0, -13575, 0, 25101, 0, -13574, 0, 31446, 0, -13573, 0, 22661, 0, -13572, 0, 24246, 0, -13571, 0, 25968, 0, -13570, 0, 28465, 0, -13504, 0, -31358, 0, -13503, 0, -31357, 0, -13502, 0, -31354, 0, -13501, 0, -31352, 0, -13500, 0, -31351, 0, -13499, 0, -31350, 0, -13498, 0, -31349, 0, -13497, 0, -31348, 0, -13496, 0, -31347, 0, -13495, 0, -31346, 0, -13494, 0, -31344, 0, -13493, 0, -31343, 0, -13492, 0, -31342, 0, -13491, 0, -31341, 0, -13490, 0, -31340, 0, -13489, 0, -31339, 0, -13488, 0, -31338, 0, -13487, 0, -31337, 0, -13486, 0, -31336, 0, -13485, 0, -31335, 0, -13484, 0, -31334, 0, -13483, 0, -31331, 0, -13482, 0, -31330, 0, -13481, 0, -31329, 0, -13480, 0, -31328, 0, -13479, 0, -31327, 0, -13478, 0, -31326, 0, -13477, 0, -31325, 0, -13476, 0, -31323, 0, -13475, 0, -31322, 0, -13474, 0, -31321, 0, -13473, 0, -31319, 0, -13472, 0, -31317, 0, -13471, 0, -31316, 0, -13470, 0, -31315, 0, -13469, 0, -31311, 0, -13468, 0, -31310, 0, -13467, 0, -31309, 0, -13466, 0, -31308, 0, -13465, 0, -31307, 0, -13464, 0, -31306, 0, -13463, 0, -31304, 0, -13462, 0, -31302, 0, -13461, 0, -31301, 0, -13460, 0, -31300, 0, -13459, 0, -31299, 0, -13458, 0, -31298, 0, -13457, 0, -31297, 0, -13456, 0, -31296, 0, -13455, 0, -31294, 0, -13454, 0, -31293, 0, -13453, 0, -31292, 0, -13452, 0, -31291, 0, -13451, 0, -31290, 0, -13450, 0, -31289, 0, -13449, 0, -31288, 0, -13448, 0, -31286, 0, -13447, 0, -31285, 0, -13446, 0, -31284, 0, -13445, 0, -31283, 0, -13444, 0, -31282, 0, -13443, 0, -31279, 0, -13442, 0, -31278, 0, -13440, 0, -31276, 0, -13439, 0, -31274, 0, -13438, 0, -31273, 0, -13437, 0, -31272, 0, -13436, 0, -31271, 0, -13435, 0, -31270, 0, -13434, 0, -31269, 0, -13433, 0, -31267, 0, -13432, 0, -31266, 0, -13431, 0, -31265, 0, -13430, 0, -31264, 0, -13429, 0, -31263, 0, -13428, 0, -31262, 0, -13427, 0, -31261, 0, -13426, 0, -31259, 0, -13425, 0, -31258, 0, -13424, 0, -31257, 0, -13423, 0, -31256, 0, -13422, 0, -31254, 0, -13421, 0, -31253, 0, -13420, 0, -31252, 0, -13419, 0, -31251, 0, -13418, 0, -31250, 0, -13417, 0, -31249, 0, -13416, 0, -31248, 0, -13415, 0, -31247, 0, -13414, 0, -31246, 0, -13413, 0, -31245, 0, -13412, 0, -31244, 0, -13411, 0, -31243, 0, -13410, 0, -31242, 0, -13409, 0, -31241, 0, -13408, 0, -31240, 0, -13407, 0, 24661, 0, -13406, 0, 21047, 0, -13405, 0, -32755, 0, -13404, 0, 25684, 0, -13403, 0, -30608, 0, -13402, 0, 29993, 0, -13401, 0, 24069, 0, -13400, 0, 26643, 0, -13399, 0, 25332, 0, -13398, 0, -26852, 0, -13397, 0, 21452, 0, -13396, 0, 29245, 0, -13395, 0, -29695, 0, -13394, 0, 27700, 0, -13393, 0, 30561, 0, -13392, 0, 31246, 0, -13391, 0, 21550, 0, -13390, 0, 30636, 0, -13389, 0, -26502, 0, -13388, 0, -32228, 0, -13387, 0, -29708, 0, -13386, 0, 30805, 0, -13385, 0, 26388, 0, -13384, 0, 28865, 0, -13383, 0, 26031, 0, -13382, 0, 25749, 0, -13381, 0, 22070, 0, -13380, 0, 24605, 0, -13379, 0, 31169, 0, -13378, 0, 21496, 0, -13377, 0, 19997, 0, -13376, 0, 27515, 0, -13375, 0, -32634, 0, -13374, 0, 23546, 0, -13373, 0, 21987, 0, -13372, 0, 22235, 0, -13371, 0, 20282, 0, -13370, 0, 20284, 0, -13369, 0, -26254, 0, -13368, 0, 24051, 0, -13367, 0, 26494, 0, -13366, 0, -32712, 0, -13365, 0, 24578, 0, -13364, 0, -26494, 0, -13363, 0, -28671, 0, -13362, 0, 23435, 0, -13361, 0, -29764, 0, -13360, 0, -29707, 0, -13359, 0, 25628, 0, -13358, 0, -32168, 0, -13357, 0, 25822, 0, -13356, 0, 22013, 0, -13355, 0, -32049, 0, -13354, 0, -28315, 0, -13353, 0, 20439, 0, -13352, 0, 32032, 0, -13351, 0, -28641, 0, -13350, 0, 31903, 0, -13349, 0, 20723, 0, -13348, 0, 22609, 0, -13347, 0, 28335, 0, -13346, 0, 23487, 0, -13345, 0, -29751, 0, -13344, 0, -32637, 0, -13343, 0, -28296, 0, -13342, 0, -31588, 0, -13341, 0, 31639, 0, -13340, 0, -31107, 0, -13339, 0, -26997, 0, -13338, 0, -26993, 0, -13337, 0, 32485, 0, -13336, 0, -25901, 0, -13335, 0, 30862, 0, -13334, 0, 23681, 0, -13333, 0, 31319, 0, -13332, 0, -28606, 0, -13331, 0, -26969, 0, -13330, 0, 31071, 0, -13329, 0, 23385, 0, -13328, 0, 25439, 0, -13327, 0, 31499, 0, -13326, 0, -31535, 0, -13325, 0, 26797, 0, -13324, 0, 21766, 0, -13323, 0, 32553, 0, -13322, 0, 29712, 0, -13321, 0, 32034, 0, -13320, 0, -27391, 0, -13319, 0, 25152, 0, -13318, 0, 22604, 0, -13317, 0, 20182, 0, -13316, 0, 23427, 0, -13315, 0, 22905, 0, -13314, 0, 22612, 0, -13248, 0, -31239, 0, -13247, 0, -31238, 0, -13246, 0, -31236, 0, -13245, 0, -31235, 0, -13244, 0, -31234, 0, -13243, 0, -31232, 0, -13242, 0, -31231, 0, -13241, 0, -31230, 0, -13240, 0, -31229, 0, -13239, 0, -31228, 0, -13238, 0, -31226, 0, -13237, 0, -31225, 0, -13236, 0, -31224, 0, -13235, 0, -31223, 0, -13234, 0, -31222, 0, -13233, 0, -31221, 0, -13232, 0, -31220, 0, -13231, 0, -31219, 0, -13230, 0, -31218, 0, -13229, 0, -31217, 0, -13228, 0, -31216, 0, -13227, 0, -31214, 0, -13226, 0, -31213, 0, -13225, 0, -31212, 0, -13224, 0, -31211, 0, -13223, 0, -31209, 0, -13222, 0, -31208, 0, -13221, 0, -31207, 0, -13220, 0, -31206, 0, -13219, 0, -31205, 0, -13218, 0, -31204, 0, -13217, 0, -31203, 0, -13216, 0, -31202, 0, -13215, 0, -31201, 0, -13214, 0, -31200, 0, -13213, 0, -31199, 0, -13212, 0, -31198, 0, -13211, 0, -31197, 0, -13210, 0, -31196, 0, -13209, 0, -31195, 0, -13208, 0, -31194, 0, -13207, 0, -31192, 0, -13206, 0, -31190, 0, -13205, 0, -31189, 0, -13204, 0, -31188, 0, -13203, 0, -31187, 0, -13202, 0, -31186, 0, -13201, 0, -31185, 0, -13200, 0, -31184, 0, -13199, 0, -31183, 0, -13198, 0, -31182, 0, -13197, 0, -31181, 0, -13196, 0, -31180, 0, -13195, 0, -31179, 0, -13194, 0, -31178, 0, -13193, 0, -31177, 0, -13192, 0, -31175, 0, -13191, 0, -31174, 0, -13190, 0, -31173, 0, -13189, 0, -31171, 0, -13188, 0, -31170, 0, -13187, 0, -31169, 0, -13186, 0, -31168, 0, -13184, 0, -31167, 0, -13183, 0, -31166, 0, -13182, 0, -31165, 0, -13181, 0, -31164, 0, -13180, 0, -31163, 0, -13179, 0, -31162, 0, -13178, 0, -31161, 0, -13177, 0, -31160, 0, -13176, 0, -31159, 0, -13175, 0, -31158, 0, -13174, 0, -31157, 0, -13173, 0, -31156, 0, -13172, 0, -31150, 0, -13171, 0, -31149, 0, -13170, 0, -31147, 0, -13169, 0, -31146, 0, -13168, 0, -31145, 0, -13167, 0, -31144, 0, -13166, 0, -31143, 0, -13165, 0, -31141, 0, -13164, 0, -31140, 0, -13163, 0, -31139, 0, -13162, 0, -31137, 0, -13161, 0, -31136, 0, -13160, 0, -31135, 0, -13159, 0, -31133, 0, -13158, 0, -31132, 0, -13157, 0, -31131, 0, -13156, 0, -31130, 0, -13155, 0, -31129, 0, -13154, 0, -31128, 0, -13153, 0, -31127, 0, -13152, 0, -31126, 0, -13151, 0, 29549, 0, -13150, 0, 25374, 0, -13149, 0, -29109, 0, -13148, 0, -29169, 0, -13147, 0, -32562, 0, -13146, 0, -32044, 0, -13145, 0, 25260, 0, -13144, 0, 21488, 0, -13143, 0, 27888, 0, -13142, 0, -28322, 0, -13141, 0, 22826, 0, -13140, 0, 24577, 0, -13139, 0, 27760, 0, -13138, 0, 22349, 0, -13137, 0, 25674, 0, -13136, 0, -29398, 0, -13135, 0, 30251, 0, -13134, 0, 28393, 0, -13133, 0, 22363, 0, -13132, 0, 27264, 0, -13131, 0, 30192, 0, -13130, 0, 28525, 0, -13129, 0, -29651, 0, -13128, 0, -29688, 0, -13127, 0, 22374, 0, -13126, 0, 27631, 0, -13125, 0, -30574, 0, -13124, 0, 30899, 0, -13123, 0, 25506, 0, -13122, 0, 21497, 0, -13121, 0, 28845, 0, -13120, 0, 27748, 0, -13119, 0, 22616, 0, -13118, 0, 25642, 0, -13117, 0, 22530, 0, -13116, 0, 26848, 0, -13115, 0, -32357, 0, -13114, 0, 21776, 0, -13113, 0, 31958, 0, -13112, 0, 20504, 0, -13111, 0, -28998, 0, -13110, 0, 28108, 0, -13109, 0, -29281, 0, -13108, 0, 28907, 0, -13107, 0, 25487, 0, -13106, 0, 28059, 0, -13105, 0, 28372, 0, -13104, 0, 32486, 0, -13103, 0, -31740, 0, -13102, 0, 26691, 0, -13101, 0, -28669, 0, -13100, 0, 28120, 0, -13099, 0, -27018, 0, -13098, 0, -29784, 0, -13097, 0, 22871, 0, -13096, 0, 29305, 0, -13095, 0, -31260, 0, -13094, 0, -32386, 0, -13093, 0, 30140, 0, -13092, 0, -30070, 0, -13091, 0, 26799, 0, -13090, 0, 21076, 0, -13089, 0, -29150, 0, -13088, 0, -27375, 0, -13087, 0, 25552, 0, -13086, 0, -26472, 0, -13085, 0, -29116, 0, -13084, 0, 21884, 0, -13083, 0, 20307, 0, -13082, 0, 26367, 0, -13081, 0, 22159, 0, -13080, 0, 24789, 0, -13079, 0, 28053, 0, -13078, 0, 21059, 0, -13077, 0, 23625, 0, -13076, 0, 22825, 0, -13075, 0, 28155, 0, -13074, 0, 22635, 0, -13073, 0, 30000, 0, -13072, 0, 29980, 0, -13071, 0, 24684, 0, -13070, 0, -32236, 0, -13069, 0, -32442, 0, -13068, 0, 25361, 0, -13067, 0, 26465, 0, -13066, 0, -28702, 0, -13065, 0, 30522, 0, -13064, 0, -29197, 0, -13063, 0, -29388, 0, -13062, 0, -27455, 0, -13061, 0, 24086, 0, -13060, 0, 21381, 0, -13059, 0, 21548, 0, -13058, 0, 28867, 0, -12992, 0, -31123, 0, -12991, 0, -31121, 0, -12990, 0, -31120, 0, -12989, 0, -31118, 0, -12988, 0, -31117, 0, -12987, 0, -31116, 0, -12986, 0, -31115, 0, -12985, 0, -31114, 0, -12984, 0, -31113, 0, -12983, 0, -31112, 0, -12982, 0, -31101, 0, -12981, 0, -31100, 0, -12980, 0, -31099, 0, -12979, 0, -31098, 0, -12978, 0, -31097, 0, -12977, 0, -31096, 0, -12976, 0, -31095, 0, -12975, 0, -31090, 0, -12974, 0, -31089, 0, -12973, 0, -31088, 0, -12972, 0, -31087, 0, -12971, 0, -31086, 0, -12970, 0, -31084, 0, -12969, 0, -31082, 0, -12968, 0, -31081, 0, -12967, 0, -31080, 0, -12966, 0, -31079, 0, -12965, 0, -31078, 0, -12964, 0, -31077, 0, -12963, 0, -31074, 0, -12962, 0, -31073, 0, -12961, 0, -31072, 0, -12960, 0, -31071, 0, -12959, 0, -31070, 0, -12958, 0, -31067, 0, -12957, 0, -31066, 0, -12956, 0, -31061, 0, -12955, 0, -31059, 0, -12954, 0, -31058, 0, -12953, 0, -31054, 0, -12952, 0, -31053, 0, -12951, 0, -31049, 0, -12950, 0, -31048, 0, -12949, 0, -31047, 0, -12948, 0, -31045, 0, -12947, 0, -31044, 0, -12946, 0, -31043, 0, -12945, 0, -31042, 0, -12944, 0, -31041, 0, -12943, 0, -31039, 0, -12942, 0, -31038, 0, -12941, 0, -31037, 0, -12940, 0, -31035, 0, -12939, 0, -31032, 0, -12938, 0, -31028, 0, -12937, 0, -31027, 0, -12936, 0, -31022, 0, -12935, 0, -31021, 0, -12934, 0, -31019, 0, -12933, 0, -31018, 0, -12932, 0, -31017, 0, -12931, 0, -31014, 0, -12930, 0, -31012, 0, -12928, 0, -31011, 0, -12927, 0, -31008, 0, -12926, 0, -31007, 0, -12925, 0, -31006, 0, -12924, 0, -31005, 0, -12923, 0, -31003, 0, -12922, 0, -31002, 0, -12921, 0, -31001, 0, -12920, 0, -31000, 0, -12919, 0, -30998, 0, -12918, 0, -30997, 0, -12917, 0, -30996, 0, -12916, 0, -30993, 0, -12915, 0, -30987, 0, -12914, 0, -30986, 0, -12913, 0, -30985, 0, -12912, 0, -30982, 0, -12911, 0, -30981, 0, -12910, 0, -30980, 0, -12909, 0, -30979, 0, -12908, 0, -30977, 0, -12907, 0, -30975, 0, -12906, 0, -30972, 0, -12905, 0, -30971, 0, -12904, 0, -30970, 0, -12903, 0, -30965, 0, -12902, 0, -30964, 0, -12901, 0, -30962, 0, -12900, 0, -30961, 0, -12899, 0, -30960, 0, -12898, 0, -30959, 0, -12897, 0, -30956, 0, -12896, 0, -30954, 0, -12895, 0, 27712, 0, -12894, 0, 24311, 0, -12893, 0, 20572, 0, -12892, 0, 20141, 0, -12891, 0, 24237, 0, -12890, 0, 25402, 0, -12889, 0, -32185, 0, -12888, 0, -28646, 0, -12887, 0, 26704, 0, -12886, 0, -28306, 0, -12885, 0, 30643, 0, -12884, 0, 21516, 0, -12883, 0, -27428, 0, -12882, 0, 24420, 0, -12881, 0, 31461, 0, -12880, 0, 26742, 0, -12879, 0, 25413, 0, -12878, 0, 31570, 0, -12877, 0, 32479, 0, -12876, 0, 30171, 0, -12875, 0, 20599, 0, -12874, 0, 25237, 0, -12873, 0, 22836, 0, -12872, 0, -28657, 0, -12871, 0, 20984, 0, -12870, 0, 31171, 0, -12869, 0, 31361, 0, -12868, 0, 22270, 0, -12867, 0, 24466, 0, -12866, 0, -28652, 0, -12865, 0, 28034, 0, -12864, 0, 23648, 0, -12863, 0, 22303, 0, -12862, 0, 21520, 0, -12861, 0, 20820, 0, -12860, 0, 28237, 0, -12859, 0, 22242, 0, -12858, 0, 25512, 0, -12857, 0, -26477, 0, -12856, 0, -32385, 0, -12855, 0, -30955, 0, -12854, 0, -30422, 0, -12853, 0, -28672, 0, -12852, 0, 21534, 0, -12851, 0, 23663, 0, -12850, 0, -32320, 0, -12849, 0, 25302, 0, -12848, 0, 25176, 0, -12847, 0, -32463, 0, -12846, 0, -25035, 0, -12845, 0, -27072, 0, -12844, 0, -26002, 0, -12843, 0, -25988, 0, -12842, 0, 26925, 0, -12841, 0, 22949, 0, -12840, 0, 25299, 0, -12839, 0, 21822, 0, -12838, 0, 25366, 0, -12837, 0, 21703, 0, -12836, 0, -31015, 0, -12835, 0, 27964, 0, -12834, 0, 23043, 0, -12833, 0, 29926, 0, -12832, 0, -30564, 0, -12831, 0, 27498, 0, -12830, 0, 22806, 0, -12829, 0, -29620, 0, -12828, 0, 24367, 0, -12827, 0, 28286, 0, -12826, 0, 29609, 0, -12825, 0, -26499, 0, -12824, 0, 20024, 0, -12823, 0, 28919, 0, -12822, 0, 23436, 0, -12821, 0, 30871, 0, -12820, 0, 25405, 0, -12819, 0, 26202, 0, -12818, 0, 30358, 0, -12817, 0, 24779, 0, -12816, 0, 23451, 0, -12815, 0, 23113, 0, -12814, 0, 19975, 0, -12813, 0, -32427, 0, -12812, 0, 27754, 0, -12811, 0, 29579, 0, -12810, 0, 20129, 0, -12809, 0, 26505, 0, -12808, 0, 32593, 0, -12807, 0, 24448, 0, -12806, 0, 26106, 0, -12805, 0, 26395, 0, -12804, 0, 24536, 0, -12803, 0, 22916, 0, -12802, 0, 23041, 0, -12736, 0, -30951, 0, -12735, 0, -30949, 0, -12734, 0, -30947, 0, -12733, 0, -30945, 0, -12732, 0, -30944, 0, -12731, 0, -30940, 0, -12730, 0, -30938, 0, -12729, 0, -30937, 0, -12728, 0, -30936, 0, -12727, 0, -30934, 0, -12726, 0, -30933, 0, -12725, 0, -30932, 0, -12724, 0, -30931, 0, -12723, 0, -30929, 0, -12722, 0, -30928, 0, -12721, 0, -30926, 0, -12720, 0, -30925, 0, -12719, 0, -30923, 0, -12718, 0, -30922, 0, -12717, 0, -30920, 0, -12716, 0, -30919, 0, -12715, 0, -30918, 0, -12714, 0, -30916, 0, -12713, 0, -30915, 0, -12712, 0, -30912, 0, -12711, 0, -30911, 0, -12710, 0, -30910, 0, -12709, 0, -30909, 0, -12708, 0, -30908, 0, -12707, 0, -30907, 0, -12706, 0, -30906, 0, -12705, 0, -30902, 0, -12704, 0, -30901, 0, -12703, 0, -30899, 0, -12702, 0, -30897, 0, -12701, 0, -30896, 0, -12700, 0, -30895, 0, -12699, 0, -30894, 0, -12698, 0, -30892, 0, -12697, 0, -30891, 0, -12696, 0, -30890, 0, -12695, 0, -30888, 0, -12694, 0, -30886, 0, -12693, 0, -30885, 0, -12692, 0, -30884, 0, -12691, 0, -30883, 0, -12690, 0, -30882, 0, -12689, 0, -30881, 0, -12688, 0, -30879, 0, -12687, 0, -30878, 0, -12686, 0, -30874, 0, -12685, 0, -30873, 0, -12684, 0, -30872, 0, -12683, 0, -30871, 0, -12682, 0, -30870, 0, -12681, 0, -30869, 0, -12680, 0, -30868, 0, -12679, 0, -30867, 0, -12678, 0, -30865, 0, -12677, 0, -30863, 0, -12676, 0, -30862, 0, -12675, 0, -30861, 0, -12674, 0, -30859, 0, -12672, 0, -30857, 0, -12671, 0, -30856, 0, -12670, 0, -30855, 0, -12669, 0, -30854, 0, -12668, 0, -30849, 0, -12667, 0, -30848, 0, -12666, 0, -30847, 0, -12665, 0, -30844, 0, -12664, 0, -30842, 0, -12663, 0, -30841, 0, -12662, 0, -30839, 0, -12661, 0, -30838, 0, -12660, 0, -30836, 0, -12659, 0, -30834, 0, -12658, 0, -30833, 0, -12657, 0, -30832, 0, -12656, 0, -30831, 0, -12655, 0, -30830, 0, -12654, 0, -30828, 0, -12653, 0, -30827, 0, -12652, 0, -30826, 0, -12651, 0, -30824, 0, -12650, 0, -30823, 0, -12649, 0, -30822, 0, -12648, 0, -30821, 0, -12647, 0, -30820, 0, -12646, 0, -30819, 0, -12645, 0, -30818, 0, -12644, 0, -30816, 0, -12643, 0, -30815, 0, -12642, 0, -30814, 0, -12641, 0, -30813, 0, -12640, 0, -30812, 0, -12639, 0, 24013, 0, -12638, 0, 24494, 0, -12637, 0, 21361, 0, -12636, 0, -26650, 0, -12635, 0, -28707, 0, -12634, 0, 26693, 0, -12633, 0, 22260, 0, -12632, 0, 21807, 0, -12631, 0, 24799, 0, -12630, 0, 20026, 0, -12629, 0, 28493, 0, -12628, 0, 32500, 0, -12627, 0, -32057, 0, -12626, 0, -31730, 0, -12625, 0, 22996, 0, -12624, 0, 20255, 0, -12623, 0, 20266, 0, -12622, 0, 23614, 0, -12621, 0, 32428, 0, -12620, 0, 26410, 0, -12619, 0, -31462, 0, -12618, 0, 21619, 0, -12617, 0, 30031, 0, -12616, 0, -32573, 0, -12615, 0, 21890, 0, -12614, 0, -25777, 0, -12613, 0, 20301, 0, -12612, 0, 28205, 0, -12611, 0, -29677, 0, -12610, 0, 23561, 0, -12609, 0, 24944, 0, -12608, 0, 21355, 0, -12607, 0, 30239, 0, -12606, 0, 28201, 0, -12605, 0, -31094, 0, -12604, 0, 25991, 0, -12603, 0, -27141, 0, -12602, 0, 32441, 0, -12601, 0, 21563, 0, -12600, 0, 31283, 0, -12599, 0, 32010, 0, -12598, 0, -27154, 0, -12597, 0, 21985, 0, -12596, 0, 32705, 0, -12595, 0, 29934, 0, -12594, 0, 25373, 0, -12593, 0, -30953, 0, -12592, 0, 28065, 0, -12591, 0, 31389, 0, -12590, 0, 25105, 0, -12589, 0, 26017, 0, -12588, 0, 21351, 0, -12587, 0, 25569, 0, -12586, 0, 27779, 0, -12585, 0, 24043, 0, -12584, 0, 21596, 0, -12583, 0, -27480, 0, -12582, 0, 20044, 0, -12581, 0, 27745, 0, -12580, 0, -29716, 0, -12579, 0, 23627, 0, -12578, 0, 26080, 0, -12577, 0, -32100, 0, -12576, 0, 26791, 0, -12575, 0, 21566, 0, -12574, 0, 21556, 0, -12573, 0, 27595, 0, -12572, 0, 27494, 0, -12571, 0, 20116, 0, -12570, 0, 25410, 0, -12569, 0, 21320, 0, -12568, 0, -32226, 0, -12567, 0, 20237, 0, -12566, 0, 20398, 0, -12565, 0, 22366, 0, -12564, 0, 25098, 0, -12563, 0, -26882, 0, -12562, 0, 26212, 0, -12561, 0, 29289, 0, -12560, 0, 21247, 0, -12559, 0, 21153, 0, -12558, 0, 24735, 0, -12557, 0, -29713, 0, -12556, 0, 26132, 0, -12555, 0, 29081, 0, -12554, 0, 26512, 0, -12553, 0, -30337, 0, -12552, 0, 30802, 0, -12551, 0, 30717, 0, -12550, 0, 26224, 0, -12549, 0, 22075, 0, -12548, 0, 21560, 0, -12547, 0, -27359, 0, -12546, 0, 29306, 0, -12480, 0, -30811, 0, -12479, 0, -30810, 0, -12478, 0, -30809, 0, -12477, 0, -30807, 0, -12476, 0, -30806, 0, -12475, 0, -30802, 0, -12474, 0, -30800, 0, -12473, 0, -30799, 0, -12472, 0, -30798, 0, -12471, 0, -30796, 0, -12470, 0, -30794, 0, -12469, 0, -30793, 0, -12468, 0, -30792, 0, -12467, 0, -30791, 0, -12466, 0, -30789, 0, -12465, 0, -30788, 0, -12464, 0, -30786, 0, -12463, 0, -30785, 0, -12462, 0, -30783, 0, -12461, 0, -30782, 0, -12460, 0, -30781, 0, -12459, 0, -30780, 0, -12458, 0, -30779, 0, -12457, 0, -30777, 0, -12456, 0, -30776, 0, -12455, 0, -30775, 0, -12454, 0, -30772, 0, -12453, 0, -30771, 0, -12452, 0, -30770, 0, -12451, 0, -30769, 0, -12450, 0, -30768, 0, -12449, 0, -30764, 0, -12448, 0, -30763, 0, -12447, 0, -30762, 0, -12446, 0, -30761, 0, -12445, 0, -30760, 0, -12444, 0, -30759, 0, -12443, 0, -30758, 0, -12442, 0, -30756, 0, -12441, 0, -30755, 0, -12440, 0, -30754, 0, -12439, 0, -30753, 0, -12438, 0, -30751, 0, -12437, 0, -30750, 0, -12436, 0, -30749, 0, -12435, 0, -30748, 0, -12434, 0, -30746, 0, -12433, 0, -30745, 0, -12432, 0, -30744, 0, -12431, 0, -30743, 0, -12430, 0, -30741, 0, -12429, 0, -30740, 0, -12428, 0, -30739, 0, -12427, 0, -30737, 0, -12426, 0, -30736, 0, -12425, 0, -30735, 0, -12424, 0, -30734, 0, -12423, 0, -30733, 0, -12422, 0, -30732, 0, -12421, 0, -30731, 0, -12420, 0, -30730, 0, -12419, 0, -30729, 0, -12418, 0, -30728, 0, -12416, 0, -30726, 0, -12415, 0, -30725, 0, -12414, 0, -30724, 0, -12413, 0, -30723, 0, -12412, 0, -30721, 0, -12411, 0, -30720, 0, -12410, 0, -30719, 0, -12409, 0, -30718, 0, -12408, 0, -30716, 0, -12407, 0, -30715, 0, -12406, 0, -30714, 0, -12405, 0, -30713, 0, -12404, 0, -30712, 0, -12403, 0, -30711, 0, -12402, 0, -30709, 0, -12401, 0, -30708, 0, -12400, 0, -30707, 0, -12399, 0, -30706, 0, -12398, 0, -30705, 0, -12397, 0, -30704, 0, -12396, 0, -30703, 0, -12395, 0, -30702, 0, -12394, 0, -30700, 0, -12393, 0, -30697, 0, -12392, 0, -30696, 0, -12391, 0, -30695, 0, -12390, 0, -30694, 0, -12389, 0, -30692, 0, -12388, 0, -30691, 0, -12387, 0, -30690, 0, -12386, 0, -30689, 0, -12385, 0, -30688, 0, -12384, 0, -30685, 0, -12383, 0, 31232, 0, -12382, 0, 24687, 0, -12381, 0, 24076, 0, -12380, 0, 24713, 0, -12379, 0, -32355, 0, -12378, 0, 22805, 0, -12377, 0, 24796, 0, -12376, 0, 29060, 0, -12375, 0, 28911, 0, -12374, 0, 28330, 0, -12373, 0, 27728, 0, -12372, 0, 29312, 0, -12371, 0, 27268, 0, -12370, 0, -30547, 0, -12369, 0, 24109, 0, -12368, 0, 20064, 0, -12367, 0, 23219, 0, -12366, 0, 21916, 0, -12365, 0, -27421, 0, -12364, 0, 27927, 0, -12363, 0, 31995, 0, -12362, 0, -26983, 0, -12361, 0, 25103, 0, -12360, 0, 32454, 0, -12359, 0, 30606, 0, -12358, 0, -31106, 0, -12357, 0, 21283, 0, -12356, 0, -26850, 0, -12355, 0, -28778, 0, -12354, 0, 26247, 0, -12353, 0, 23777, 0, -12352, 0, 20384, 0, -12351, 0, 29421, 0, -12350, 0, 19979, 0, -12349, 0, 21414, 0, -12348, 0, 22799, 0, -12347, 0, 21523, 0, -12346, 0, 25472, 0, -12345, 0, -27352, 0, -12344, 0, 20808, 0, -12343, 0, 20185, 0, -12342, 0, -25444, 0, -12341, 0, 32420, 0, -12340, 0, 21688, 0, -12339, 0, -29404, 0, -12338, 0, -30636, 0, -12337, 0, -32201, 0, -12336, 0, -27150, 0, -12335, 0, 28046, 0, -12334, 0, 24358, 0, -12333, 0, 23244, 0, -12332, 0, 26174, 0, -12331, 0, -27031, 0, -12330, 0, 29616, 0, -12329, 0, 29486, 0, -12328, 0, 21439, 0, -12327, 0, -32390, 0, -12326, 0, -26235, 0, -12325, 0, 32673, 0, -12324, 0, 23466, 0, -12323, 0, -27017, 0, -12322, 0, -27056, 0, -12321, 0, 32447, 0, -12320, 0, 30456, 0, -12319, 0, 21410, 0, -12318, 0, -27274, 0, -12317, 0, -26215, 0, -12316, 0, 31665, 0, -12315, 0, -30396, 0, -12314, 0, 28248, 0, -12313, 0, 20065, 0, -12312, 0, 32724, 0, -12311, 0, 31077, 0, -12310, 0, -29722, 0, -12309, 0, 24819, 0, -12308, 0, 21709, 0, -12307, 0, 20139, 0, -12306, 0, -26503, 0, -12305, 0, 24055, 0, -12304, 0, 27233, 0, -12303, 0, 20687, 0, -12302, 0, 21521, 0, -12301, 0, -29599, 0, -12300, 0, -31705, 0, -12299, 0, 30813, 0, -12298, 0, -26876, 0, -12297, 0, 21066, 0, -12296, 0, 21742, 0, -12295, 0, 22179, 0, -12294, 0, -27392, 0, -12293, 0, 28040, 0, -12292, 0, 23477, 0, -12291, 0, 28102, 0, -12290, 0, 26195, 0, -12224, 0, -30684, 0, -12223, 0, -30683, 0, -12222, 0, -30682, 0, -12221, 0, -30681, 0, -12220, 0, -30680, 0, -12219, 0, -30679, 0, -12218, 0, -30678, 0, -12217, 0, -30677, 0, -12216, 0, -30676, 0, -12215, 0, -30675, 0, -12214, 0, -30674, 0, -12213, 0, -30673, 0, -12212, 0, -30672, 0, -12211, 0, -30671, 0, -12210, 0, -30669, 0, -12209, 0, -30668, 0, -12208, 0, -30667, 0, -12207, 0, -30666, 0, -12206, 0, -30665, 0, -12205, 0, -30664, 0, -12204, 0, -30662, 0, -12203, 0, -30661, 0, -12202, 0, -30659, 0, -12201, 0, -30658, 0, -12200, 0, -30657, 0, -12199, 0, -30655, 0, -12198, 0, -30654, 0, -12197, 0, -30653, 0, -12196, 0, -30650, 0, -12195, 0, -30649, 0, -12194, 0, -30648, 0, -12193, 0, -30647, 0, -12192, 0, -30646, 0, -12191, 0, -30645, 0, -12190, 0, -30642, 0, -12189, 0, -30641, 0, -12188, 0, -30640, 0, -12187, 0, -30639, 0, -12186, 0, -30638, 0, -12185, 0, -30637, 0, -12184, 0, -30635, 0, -12183, 0, -30634, 0, -12182, 0, -30632, 0, -12181, 0, -30630, 0, -12180, 0, -30629, 0, -12179, 0, -30628, 0, -12178, 0, -30627, 0, -12177, 0, -30626, 0, -12176, 0, -30625, 0, -12175, 0, -30624, 0, -12174, 0, -30618, 0, -12173, 0, -30617, 0, -12172, 0, -30614, 0, -12171, 0, -30611, 0, -12170, 0, -30609, 0, -12169, 0, -30607, 0, -12168, 0, -30605, 0, -12167, 0, -30604, 0, -12166, 0, -30603, 0, -12165, 0, -30602, 0, -12164, 0, -30600, 0, -12163, 0, -30599, 0, -12162, 0, -30598, 0, -12160, 0, -30597, 0, -12159, 0, -30596, 0, -12158, 0, -30592, 0, -12157, 0, -30589, 0, -12156, 0, -30586, 0, -12155, 0, -30585, 0, -12154, 0, -30583, 0, -12153, 0, -30582, 0, -12152, 0, -30580, 0, -12151, 0, -30578, 0, -12150, 0, -30577, 0, -12149, 0, -30576, 0, -12148, 0, -30575, 0, -12147, 0, -30573, 0, -12146, 0, -30572, 0, -12145, 0, -30571, 0, -12144, 0, -30569, 0, -12143, 0, -30568, 0, -12142, 0, -30567, 0, -12141, 0, -30566, 0, -12140, 0, -30565, 0, -12139, 0, -30563, 0, -12138, 0, -30562, 0, -12137, 0, -30561, 0, -12136, 0, -30560, 0, -12135, 0, -30559, 0, -12134, 0, -30557, 0, -12133, 0, -30555, 0, -12132, 0, -30554, 0, -12131, 0, -30553, 0, -12130, 0, -30552, 0, -12129, 0, -30551, 0, -12128, 0, -30550, 0, -12127, 0, 23567, 0, -12126, 0, 23389, 0, -12125, 0, 26657, 0, -12124, 0, -32618, 0, -12123, 0, 21880, 0, -12122, 0, 31505, 0, -12121, 0, 25928, 0, -12120, 0, 26964, 0, -12119, 0, 20123, 0, -12118, 0, 27463, 0, -12117, 0, -30898, 0, -12116, 0, -26741, 0, -12115, 0, 21327, 0, -12114, 0, 25375, 0, -12113, 0, 25658, 0, -12112, 0, -28502, 0, -12111, 0, 26012, 0, -12110, 0, -32575, 0, -12109, 0, -29680, 0, -12108, 0, 20889, 0, -12107, 0, 26800, 0, -12106, 0, 21368, 0, -12105, 0, -30727, 0, -12104, 0, 25032, 0, -12103, 0, 27844, 0, -12102, 0, 27899, 0, -12101, 0, -29662, 0, -12100, 0, 23633, 0, -12099, 0, -31318, 0, -12098, 0, -32081, 0, -12097, 0, -27380, 0, -12096, 0, 27427, 0, -12095, 0, -28773, 0, -12094, 0, 26032, 0, -12093, 0, 24571, 0, -12092, 0, 24515, 0, -12091, 0, 20449, 0, -12090, 0, -30651, 0, -12089, 0, 26143, 0, -12088, 0, -32411, 0, -12087, 0, 29481, 0, -12086, 0, 24826, 0, -12085, 0, 20852, 0, -12084, 0, 21009, 0, -12083, 0, 22411, 0, -12082, 0, 24418, 0, -12081, 0, -28510, 0, -12080, 0, -30644, 0, -12079, 0, -28270, 0, -12078, 0, 24184, 0, -12077, 0, 26447, 0, -12076, 0, 24615, 0, -12075, 0, 22995, 0, -12074, 0, 20804, 0, -12073, 0, 20982, 0, -12072, 0, -32520, 0, -12071, 0, 21256, 0, -12070, 0, 27769, 0, -12069, 0, -26940, 0, -12068, 0, 29066, 0, -12067, 0, 20241, 0, -12066, 0, 20462, 0, -12065, 0, 32670, 0, -12064, 0, 26429, 0, -12063, 0, 21957, 0, -12062, 0, -27384, 0, -12061, 0, 31168, 0, -12060, 0, -30570, 0, -12059, 0, 32483, 0, -12058, 0, 22687, 0, -12057, 0, 25100, 0, -12056, 0, -26880, 0, -12055, 0, -31142, 0, -12054, 0, 22040, 0, -12053, 0, -26501, 0, -12052, 0, 24464, 0, -12051, 0, -29768, 0, -12050, 0, -31548, 0, -12049, 0, -28329, 0, -12048, 0, 21465, 0, -12047, 0, 26093, 0, -12046, 0, 24207, 0, -12045, 0, 30044, 0, -12044, 0, 24676, 0, -12043, 0, 32110, 0, -12042, 0, 23167, 0, -12041, 0, 32490, 0, -12040, 0, 32493, 0, -12039, 0, -28823, 0, -12038, 0, 21927, 0, -12037, 0, 23459, 0, -12036, 0, 24748, 0, -12035, 0, 26059, 0, -12034, 0, 29572, 0, -11968, 0, -30548, 0, -11967, 0, -30546, 0, -11966, 0, -30545, 0, -11965, 0, -30544, 0, -11964, 0, -30542, 0, -11963, 0, -30541, 0, -11962, 0, -30540, 0, -11961, 0, -30539, 0, -11960, 0, -30538, 0, -11959, 0, -30536, 0, -11958, 0, -30535, 0, -11957, 0, -30534, 0, -11956, 0, -30533, 0, -11955, 0, -30531, 0, -11954, 0, -30530, 0, -11953, 0, -30529, 0, -11952, 0, -30528, 0, -11951, 0, -30525, 0, -11950, 0, -30524, 0, -11949, 0, -30521, 0, -11948, 0, -30520, 0, -11947, 0, -30518, 0, -11946, 0, -30517, 0, -11945, 0, -30516, 0, -11944, 0, -30515, 0, -11943, 0, -30513, 0, -11942, 0, -30512, 0, -11941, 0, -30511, 0, -11940, 0, -30509, 0, -11939, 0, -30506, 0, -11938, 0, -30505, 0, -11937, 0, -30502, 0, -11936, 0, -30501, 0, -11935, 0, -30500, 0, -11934, 0, -30499, 0, -11933, 0, -30498, 0, -11932, 0, -30496, 0, -11931, 0, -30495, 0, -11930, 0, -30490, 0, -11929, 0, -30489, 0, -11928, 0, -30487, 0, -11927, 0, -30486, 0, -11926, 0, -30485, 0, -11925, 0, -30484, 0, -11924, 0, -30483, 0, -11923, 0, -30482, 0, -11922, 0, -30481, 0, -11921, 0, -30478, 0, -11920, 0, -30475, 0, -11919, 0, -30474, 0, -11918, 0, -30473, 0, -11917, 0, -30470, 0, -11916, 0, -30469, 0, -11915, 0, -30467, 0, -11914, 0, -30465, 0, -11913, 0, -30464, 0, -11912, 0, -30463, 0, -11911, 0, -30461, 0, -11910, 0, -30460, 0, -11909, 0, -30459, 0, -11908, 0, -30458, 0, -11907, 0, -30457, 0, -11906, 0, -30456, 0, -11904, 0, -30455, 0, -11903, 0, -30453, 0, -11902, 0, -30452, 0, -11901, 0, -30451, 0, -11900, 0, -30450, 0, -11899, 0, -30449, 0, -11898, 0, -30447, 0, -11897, 0, -30444, 0, -11896, 0, -30443, 0, -11895, 0, -30442, 0, -11894, 0, -30441, 0, -11893, 0, -30440, 0, -11892, 0, -30436, 0, -11891, 0, -30435, 0, -11890, 0, -30434, 0, -11889, 0, -30433, 0, -11888, 0, -30432, 0, -11887, 0, -30430, 0, -11886, 0, -30429, 0, -11885, 0, -30428, 0, -11884, 0, -30426, 0, -11883, 0, -30425, 0, -11882, 0, -30424, 0, -11881, 0, -30423, 0, -11880, 0, -30420, 0, -11879, 0, -30419, 0, -11878, 0, -30418, 0, -11877, 0, -30417, 0, -11876, 0, -30415, 0, -11875, 0, -30414, 0, -11874, 0, -30413, 0, -11873, 0, -30411, 0, -11872, 0, -30409, 0, -11871, 0, -28663, 0, -11870, 0, 30307, 0, -11869, 0, 30505, 0, -11868, 0, 32474, 0, -11867, 0, -26764, 0, -11866, 0, -31333, 0, -11865, 0, 23398, 0, -11864, 0, 31348, 0, -11863, 0, -26902, 0, -11862, 0, -30656, 0, -11861, 0, 21195, 0, -11860, 0, 29071, 0, -11859, 0, 24490, 0, -11858, 0, 26092, 0, -11857, 0, -29726, 0, -11856, 0, 23547, 0, -11855, 0, -26001, 0, -11854, 0, 24033, 0, -11853, 0, 27529, 0, -11852, 0, 27739, 0, -11851, 0, -29779, 0, -11850, 0, -29777, 0, -11849, 0, -28662, 0, -11848, 0, -28731, 0, -11847, 0, 21387, 0, -11846, 0, 25276, 0, -11845, 0, -25050, 0, -11844, 0, -25043, 0, -11843, 0, 21568, 0, -11842, 0, 20011, 0, -11841, 0, -32067, 0, -11840, 0, 29273, 0, -11839, 0, -31076, 0, -11838, 0, 23830, 0, -11837, 0, -30631, 0, -11836, 0, 28079, 0, -11835, 0, -26939, 0, -11834, 0, 21713, 0, -11833, 0, 20122, 0, -11832, 0, -29770, 0, -11831, 0, 28937, 0, -11830, 0, 21693, 0, -11829, 0, -27127, 0, -11828, 0, 28895, 0, -11827, 0, 28153, 0, -11826, 0, 30416, 0, -11825, 0, 20005, 0, -11824, 0, 30740, 0, -11823, 0, -30958, 0, -11822, 0, 23721, 0, -11821, 0, 24310, 0, -11820, 0, -30208, 0, -11819, 0, -26468, 0, -11818, 0, -27122, 0, -11817, 0, 28814, 0, -11816, 0, 27839, 0, -11815, 0, 22852, 0, -11814, 0, 25513, 0, -11813, 0, 30524, 0, -11812, 0, -30643, 0, -11811, 0, 28436, 0, -11810, 0, -32141, 0, -11809, 0, 22576, 0, -11808, 0, 29141, 0, -11807, 0, 21388, 0, -11806, 0, 30746, 0, -11805, 0, -26943, 0, -11804, 0, 21761, 0, -11803, 0, 24422, 0, -11802, 0, 28976, 0, -11801, 0, 23476, 0, -11800, 0, -29670, 0, -11799, 0, -25972, 0, -11798, 0, 27523, 0, -11797, 0, 22830, 0, -11796, 0, -25041, 0, -11795, 0, 31207, 0, -11794, 0, 26472, 0, -11793, 0, 25196, 0, -11792, 0, 20335, 0, -11791, 0, 30113, 0, -11790, 0, 32650, 0, -11789, 0, 27915, 0, -11788, 0, -27085, 0, -11787, 0, 27687, 0, -11786, 0, 20208, 0, -11785, 0, 30162, 0, -11784, 0, 20859, 0, -11783, 0, 26679, 0, -11782, 0, 28478, 0, -11781, 0, -28544, 0, -11780, 0, -32400, 0, -11779, 0, 22934, 0, -11778, 0, 29814, 0, -11712, 0, -30408, 0, -11711, 0, -30407, 0, -11710, 0, -30406, 0, -11709, 0, -30405, 0, -11708, 0, -30404, 0, -11707, 0, -30403, 0, -11706, 0, -30402, 0, -11705, 0, -30401, 0, -11704, 0, -30400, 0, -11703, 0, -30398, 0, -11702, 0, -30397, 0, -11701, 0, -30395, 0, -11700, 0, -30394, 0, -11699, 0, -30393, 0, -11698, 0, -30392, 0, -11697, 0, -30391, 0, -11696, 0, -30390, 0, -11695, 0, -30389, 0, -11694, 0, -30388, 0, -11693, 0, -30387, 0, -11692, 0, -30386, 0, -11691, 0, -30385, 0, -11690, 0, -30384, 0, -11689, 0, -30383, 0, -11688, 0, -30382, 0, -11687, 0, -30381, 0, -11686, 0, -30380, 0, -11685, 0, -30379, 0, -11684, 0, -30378, 0, -11683, 0, -30377, 0, -11682, 0, -30376, 0, -11681, 0, -30375, 0, -11680, 0, -30374, 0, -11679, 0, -30373, 0, -11678, 0, -30372, 0, -11677, 0, -30371, 0, -11676, 0, -30368, 0, -11675, 0, -30367, 0, -11674, 0, -30366, 0, -11673, 0, -30365, 0, -11672, 0, -30364, 0, -11671, 0, -30363, 0, -11670, 0, -30361, 0, -11669, 0, -30360, 0, -11668, 0, -30359, 0, -11667, 0, -30358, 0, -11666, 0, -30357, 0, -11665, 0, -30356, 0, -11664, 0, -30355, 0, -11663, 0, -30354, 0, -11662, 0, -30353, 0, -11661, 0, -30352, 0, -11660, 0, -30351, 0, -11659, 0, -30350, 0, -11658, 0, -30349, 0, -11657, 0, -30348, 0, -11656, 0, -30347, 0, -11655, 0, -30346, 0, -11654, 0, -30345, 0, -11653, 0, -30344, 0, -11652, 0, -30343, 0, -11651, 0, -30342, 0, -11650, 0, -30340, 0, -11648, 0, -30339, 0, -11647, 0, -30338, 0, -11646, 0, -30336, 0, -11645, 0, -30334, 0, -11644, 0, -30332, 0, -11643, 0, -30331, 0, -11642, 0, -30329, 0, -11641, 0, -30328, 0, -11640, 0, -30327, 0, -11639, 0, -30326, 0, -11638, 0, -30325, 0, -11637, 0, -30324, 0, -11636, 0, -30323, 0, -11635, 0, -30322, 0, -11634, 0, -30321, 0, -11633, 0, -30320, 0, -11632, 0, -30319, 0, -11631, 0, -30318, 0, -11630, 0, -30317, 0, -11629, 0, -30316, 0, -11628, 0, -30315, 0, -11627, 0, -30314, 0, -11626, 0, -30313, 0, -11625, 0, -30312, 0, -11624, 0, -30311, 0, -11623, 0, -30310, 0, -11622, 0, -30309, 0, -11621, 0, -30308, 0, -11620, 0, -30307, 0, -11619, 0, -30306, 0, -11618, 0, -30305, 0, -11617, 0, -30304, 0, -11616, 0, -30303, 0, -11615, 0, 25671, 0, -11614, 0, 23591, 0, -11613, 0, -28571, 0, -11612, 0, 31377, 0, -11611, 0, -29661, 0, -11610, 0, 23002, 0, -11609, 0, 21676, 0, -11608, 0, -32256, 0, -11607, 0, -31889, 0, -11606, 0, -30335, 0, -11605, 0, -32768, 0, -11604, 0, 26928, 0, -11603, 0, 22094, 0, -11602, 0, -32714, 0, -11601, 0, 29239, 0, -11600, 0, -28210, 0, -11599, 0, 20918, 0, -11598, 0, 20063, 0, -11597, 0, -26507, 0, -11596, 0, 25494, 0, -11595, 0, 19994, 0, -11594, 0, 21494, 0, -11593, 0, 26355, 0, -11592, 0, -32437, 0, -11591, 0, 22812, 0, -11590, 0, 28082, 0, -11589, 0, 19968, 0, -11588, 0, 22777, 0, -11587, 0, 21307, 0, -11586, 0, 25558, 0, -11585, 0, -27407, 0, -11584, 0, 20381, 0, -11583, 0, 20234, 0, -11582, 0, -30621, 0, -11581, 0, -26480, 0, -11580, 0, 22839, 0, -11579, 0, -28585, 0, -11578, 0, 31227, 0, -11577, 0, 20202, 0, -11576, 0, -32528, 0, -11575, 0, 30097, 0, -11574, 0, 27778, 0, -11573, 0, 23452, 0, -11572, 0, 23016, 0, -11571, 0, 24413, 0, -11570, 0, 26885, 0, -11569, 0, -31103, 0, -11568, 0, 20506, 0, -11567, 0, 24050, 0, -11566, 0, 20057, 0, -11565, 0, 30691, 0, -11564, 0, 20197, 0, -11563, 0, -32134, 0, -11562, 0, 25233, 0, -11561, 0, 26131, 0, -11560, 0, -28527, 0, -11559, 0, 23673, 0, -11558, 0, 20159, 0, -11557, 0, 24441, 0, -11556, 0, -32314, 0, -11555, 0, -28616, 0, -11554, 0, -32636, 0, -11553, 0, 30123, 0, -11552, 0, 20134, 0, -11551, 0, -30508, 0, -11550, 0, 24847, 0, -11549, 0, 27589, 0, -11548, 0, 24518, 0, -11547, 0, 20041, 0, -11546, 0, 30410, 0, -11545, 0, 28322, 0, -11544, 0, -29725, 0, -11543, 0, -29778, 0, -11542, 0, -29686, 0, -11541, 0, -29743, 0, -11540, 0, 24322, 0, -11539, 0, 32764, 0, -11538, 0, 32716, 0, -11537, 0, 32462, 0, -11536, 0, -31947, 0, -11535, 0, -31893, 0, -11534, 0, 22240, 0, -11533, 0, 27575, 0, -11532, 0, -26637, 0, -11531, 0, -27084, 0, -11530, 0, 23035, 0, -11529, 0, 21535, 0, -11528, 0, -27402, 0, -11527, 0, 28139, 0, -11526, 0, 23493, 0, -11525, 0, -26258, 0, -11524, 0, 23609, 0, -11523, 0, 24341, 0, -11522, 0, -26992, 0, -11456, 0, -30302, 0, -11455, 0, -30301, 0, -11454, 0, -30300, 0, -11453, 0, -30299, 0, -11452, 0, -30298, 0, -11451, 0, -30297, 0, -11450, 0, -30296, 0, -11449, 0, -30295, 0, -11448, 0, -30294, 0, -11447, 0, -30293, 0, -11446, 0, -30292, 0, -11445, 0, -30291, 0, -11444, 0, -30290, 0, -11443, 0, -30289, 0, -11442, 0, -30288, 0, -11441, 0, -30287, 0, -11440, 0, -30286, 0, -11439, 0, -30285, 0, -11438, 0, -30284, 0, -11437, 0, -30283, 0, -11436, 0, -30282, 0, -11435, 0, -30281, 0, -11434, 0, -30280, 0, -11433, 0, -30279, 0, -11432, 0, -30278, 0, -11431, 0, -30277, 0, -11430, 0, -30276, 0, -11429, 0, -30275, 0, -11428, 0, -30274, 0, -11427, 0, -30273, 0, -11426, 0, -30272, 0, -11425, 0, -30269, 0, -11424, 0, -30259, 0, -11423, 0, -30253, 0, -11422, 0, -30252, 0, -11421, 0, -30251, 0, -11420, 0, -30249, 0, -11419, 0, -30248, 0, -11418, 0, -30247, 0, -11417, 0, -30245, 0, -11416, 0, -30243, 0, -11415, 0, -30241, 0, -11414, 0, -30240, 0, -11413, 0, -30239, 0, -11412, 0, -30238, 0, -11411, 0, -30236, 0, -11410, 0, -30233, 0, -11409, 0, -30232, 0, -11408, 0, -30231, 0, -11407, 0, -30230, 0, -11406, 0, -30228, 0, -11405, 0, -30227, 0, -11404, 0, -30226, 0, -11403, 0, -30224, 0, -11402, 0, -30223, 0, -11401, 0, -30222, 0, -11400, 0, -30220, 0, -11399, 0, -30219, 0, -11398, 0, -30218, 0, -11397, 0, -30217, 0, -11396, 0, -30216, 0, -11395, 0, -30215, 0, -11394, 0, -30214, 0, -11392, 0, -30213, 0, -11391, 0, -30212, 0, -11390, 0, -30211, 0, -11389, 0, -30210, 0, -11388, 0, -30209, 0, -11387, 0, -30207, 0, -11386, 0, -30206, 0, -11385, 0, -30205, 0, -11384, 0, -30204, 0, -11383, 0, -30203, 0, -11382, 0, -30202, 0, -11381, 0, -30200, 0, -11380, 0, -30199, 0, -11379, 0, -30198, 0, -11378, 0, -30197, 0, -11377, 0, -30196, 0, -11376, 0, -30195, 0, -11375, 0, -30194, 0, -11374, 0, -30193, 0, -11373, 0, -30192, 0, -11372, 0, -30191, 0, -11371, 0, -30190, 0, -11370, 0, -30189, 0, -11369, 0, -30188, 0, -11368, 0, -30187, 0, -11367, 0, -30186, 0, -11366, 0, -30185, 0, -11365, 0, -30184, 0, -11364, 0, -30183, 0, -11363, 0, -30182, 0, -11362, 0, -30181, 0, -11361, 0, -30180, 0, -11360, 0, -30179, 0, -11359, 0, 21360, 0, -11358, 0, -32015, 0, -11357, 0, 27185, 0, -11356, 0, 23156, 0, -11355, 0, -24976, 0, -11354, 0, 24212, 0, -11353, 0, 32552, 0, -11352, 0, -31815, 0, -11351, 0, -31708, 0, -11350, 0, -31707, 0, -11349, 0, -31897, 0, -11348, 0, -30905, 0, -11347, 0, -28722, 0, -11346, 0, -29342, 0, -11345, 0, 30408, 0, -11344, 0, 24433, 0, -11343, 0, -26474, 0, -11342, 0, 30828, 0, -11341, 0, 26144, 0, -11340, 0, 21727, 0, -11339, 0, 25317, 0, -11338, 0, 20323, 0, -11337, 0, -32317, 0, -11336, 0, 30152, 0, -11335, 0, 24248, 0, -11334, 0, -26931, 0, -11333, 0, -29174, 0, -11332, 0, -30983, 0, -11331, 0, 21647, 0, -11330, 0, 27891, 0, -11329, 0, 28044, 0, -11328, 0, 27704, 0, -11327, 0, 24703, 0, -11326, 0, 21191, 0, -11325, 0, 29992, 0, -11324, 0, 24189, 0, -11323, 0, 20248, 0, -11322, 0, 24736, 0, -11321, 0, 24551, 0, -11320, 0, 23588, 0, -11319, 0, 30001, 0, -11318, 0, -28498, 0, -11317, 0, -27456, 0, -11316, 0, 29369, 0, -11315, 0, 27833, 0, -11314, 0, 28216, 0, -11313, 0, -28343, 0, -11312, 0, 26377, 0, -11311, 0, 21451, 0, -11310, 0, 21491, 0, -11309, 0, 20305, 0, -11308, 0, -28215, 0, -11307, 0, -29711, 0, -11306, 0, 21448, 0, -11305, 0, 24188, 0, -11304, 0, -28734, 0, -11303, 0, 28132, 0, -11302, 0, 20110, 0, -11301, 0, 30402, 0, -11300, 0, 27014, 0, -11299, 0, -31138, 0, -11298, 0, 24858, 0, -11297, 0, -32250, 0, -11296, 0, 20313, 0, -11295, 0, 20446, 0, -11294, 0, -28610, 0, -11293, 0, -25476, 0, -11292, 0, 24841, 0, -11291, 0, 28189, 0, -11290, 0, 28180, 0, -11289, 0, -27003, 0, -11288, 0, 20104, 0, -11287, 0, 23089, 0, -11286, 0, -26904, 0, -11285, 0, 19982, 0, -11284, 0, 23679, 0, -11283, 0, 31161, 0, -11282, 0, 23431, 0, -11281, 0, -29715, 0, -11280, 0, 32701, 0, -11279, 0, 29577, 0, -11278, 0, 22495, 0, -11277, 0, -32117, 0, -11276, 0, -28479, 0, -11275, 0, 21505, 0, -11274, 0, -28601, 0, -11273, 0, 21947, 0, -11272, 0, 23786, 0, -11271, 0, 24481, 0, -11270, 0, 24840, 0, -11269, 0, 27442, 0, -11268, 0, 29425, 0, -11267, 0, -32590, 0, -11266, 0, -30071, 0, -11200, 0, -30178, 0, -11199, 0, -30177, 0, -11198, 0, -30176, 0, -11197, 0, -30175, 0, -11196, 0, -30174, 0, -11195, 0, -30173, 0, -11194, 0, -30172, 0, -11193, 0, -30171, 0, -11192, 0, -30170, 0, -11191, 0, -30169, 0, -11190, 0, -30168, 0, -11189, 0, -30167, 0, -11188, 0, -30166, 0, -11187, 0, -30165, 0, -11186, 0, -30164, 0, -11185, 0, -30163, 0, -11184, 0, -30162, 0, -11183, 0, -30161, 0, -11182, 0, -30160, 0, -11181, 0, -30159, 0, -11180, 0, -30158, 0, -11179, 0, -30157, 0, -11178, 0, -30156, 0, -11177, 0, -30155, 0, -11176, 0, -30154, 0, -11175, 0, -30153, 0, -11174, 0, -30152, 0, -11173, 0, -30151, 0, -11172, 0, -30150, 0, -11171, 0, -30149, 0, -11170, 0, -30148, 0, -11169, 0, -30147, 0, -11168, 0, -30145, 0, -11167, 0, -30144, 0, -11166, 0, -30143, 0, -11165, 0, -30142, 0, -11164, 0, -30141, 0, -11163, 0, -30140, 0, -11162, 0, -30139, 0, -11161, 0, -30138, 0, -11160, 0, -30137, 0, -11159, 0, -30135, 0, -11158, 0, -30134, 0, -11157, 0, -30133, 0, -11156, 0, -30132, 0, -11155, 0, -30131, 0, -11154, 0, -30130, 0, -11153, 0, -30129, 0, -11152, 0, -30128, 0, -11151, 0, -30127, 0, -11150, 0, -30126, 0, -11149, 0, -30125, 0, -11148, 0, -30124, 0, -11147, 0, -30123, 0, -11146, 0, -30122, 0, -11145, 0, -30121, 0, -11144, 0, -30120, 0, -11143, 0, -30119, 0, -11142, 0, -30118, 0, -11141, 0, -30117, 0, -11140, 0, -30116, 0, -11139, 0, -30115, 0, -11138, 0, -30114, 0, -11136, 0, -30113, 0, -11135, 0, -30112, 0, -11134, 0, -30111, 0, -11133, 0, -30110, 0, -11132, 0, -30109, 0, -11131, 0, -30108, 0, -11130, 0, -30107, 0, -11129, 0, -30106, 0, -11128, 0, -30105, 0, -11127, 0, -30104, 0, -11126, 0, -30103, 0, -11125, 0, -30102, 0, -11124, 0, -30101, 0, -11123, 0, -30100, 0, -11122, 0, -30099, 0, -11121, 0, -30098, 0, -11120, 0, -30097, 0, -11119, 0, -30096, 0, -11118, 0, -30095, 0, -11117, 0, -30094, 0, -11116, 0, -30093, 0, -11115, 0, -30092, 0, -11114, 0, -30091, 0, -11113, 0, -30090, 0, -11112, 0, -30089, 0, -11111, 0, -30088, 0, -11110, 0, -30086, 0, -11109, 0, -30085, 0, -11108, 0, -30084, 0, -11107, 0, -30083, 0, -11106, 0, -30082, 0, -11105, 0, -30081, 0, -11104, 0, -30080, 0, -11103, 0, 28020, 0, -11102, 0, 23507, 0, -11101, 0, -30507, 0, -11100, 0, -26492, 0, -11099, 0, -29589, 0, -11098, 0, -26003, 0, -11097, 0, -25037, 0, -11096, 0, 28170, 0, -11095, 0, 20900, 0, -11094, 0, 20803, 0, -11093, 0, 22435, 0, -11092, 0, -30591, 0, -11091, 0, 21407, 0, -11090, 0, 25588, 0, -11089, 0, -28779, 0, -11088, 0, 22253, 0, -11087, 0, 21592, 0, -11086, 0, 22278, 0, -11085, 0, 29503, 0, -11084, 0, 28304, 0, -11083, 0, 32536, 0, -11082, 0, -28708, 0, -11081, 0, -32047, 0, -11080, 0, 24895, 0, -11079, 0, 24616, 0, -11078, 0, -27038, 0, -11077, 0, 26352, 0, -11076, 0, 32422, 0, -11075, 0, -29302, 0, -11074, 0, -29245, 0, -11073, 0, -27483, 0, -11072, 0, 23731, 0, -11071, 0, 31908, 0, -11070, 0, 26376, 0, -11069, 0, 24742, 0, -11068, 0, -27131, 0, -11067, 0, -32744, 0, -11066, 0, 20113, 0, -11065, 0, -28441, 0, -11064, 0, 21248, 0, -11063, 0, -27032, 0, -11062, 0, 20801, 0, -11061, 0, -28720, 0, -11060, 0, -31372, 0, -11059, 0, -28323, 0, -11058, 0, 26197, 0, -11057, 0, -26635, 0, -11056, 0, 23381, 0, -11055, 0, 21277, 0, -11054, 0, 30776, 0, -11053, 0, 26434, 0, -11052, 0, 26685, 0, -11051, 0, 21705, 0, -11050, 0, 28798, 0, -11049, 0, 23472, 0, -11048, 0, -28803, 0, -11047, 0, 20877, 0, -11046, 0, 22312, 0, -11045, 0, 21681, 0, -11044, 0, 25874, 0, -11043, 0, 26242, 0, -11042, 0, -29346, 0, -11041, 0, -29373, 0, -11040, 0, -32497, 0, -11039, 0, -31636, 0, -11038, 0, -28563, 0, -11037, 0, 31967, 0, -11036, 0, 20991, 0, -11035, 0, -31237, 0, -11034, 0, 26531, 0, -11033, 0, 26089, 0, -11032, 0, 28577, 0, -11031, 0, -31068, 0, -11030, 0, -29055, 0, -11029, 0, 22122, 0, -11028, 0, -28640, 0, -11027, 0, 30338, 0, -11026, 0, 28790, 0, -11025, 0, 29157, 0, -11024, 0, -29405, 0, -11023, 0, 25321, 0, -11022, 0, 21017, 0, -11021, 0, 27901, 0, -11020, 0, -29380, 0, -11019, 0, 24590, 0, -11018, 0, 22686, 0, -11017, 0, 24974, 0, -11016, 0, 26366, 0, -11015, 0, -29344, 0, -11014, 0, 25166, 0, -11013, 0, 21939, 0, -11012, 0, 28195, 0, -11011, 0, 26413, 0, -11010, 0, -28825, 0, -10944, 0, -30079, 0, -10943, 0, -30078, 0, -10942, 0, -30077, 0, -10941, 0, -30076, 0, -10940, 0, -30075, 0, -10939, 0, -30074, 0, -10938, 0, -30073, 0, -10937, 0, -30072, 0, -10936, 0, -30069, 0, -10935, 0, -30068, 0, -10934, 0, -30067, 0, -10933, 0, -30066, 0, -10932, 0, -30065, 0, -10931, 0, -30064, 0, -10930, 0, -30063, 0, -10929, 0, -30062, 0, -10928, 0, -30060, 0, -10927, 0, -30059, 0, -10926, 0, -30058, 0, -10925, 0, -30057, 0, -10924, 0, -30056, 0, -10923, 0, -30055, 0, -10922, 0, -30054, 0, -10921, 0, -30053, 0, -10920, 0, -30052, 0, -10919, 0, -30051, 0, -10918, 0, -30050, 0, -10917, 0, -30049, 0, -10916, 0, -30048, 0, -10915, 0, -30047, 0, -10914, 0, -30046, 0, -10913, 0, -30045, 0, -10912, 0, -30044, 0, -10911, 0, -30043, 0, -10910, 0, -30042, 0, -10909, 0, -30041, 0, -10908, 0, -30040, 0, -10907, 0, -30039, 0, -10906, 0, -30038, 0, -10905, 0, -30037, 0, -10904, 0, -30036, 0, -10903, 0, -30035, 0, -10902, 0, -30034, 0, -10901, 0, -30033, 0, -10900, 0, -30032, 0, -10899, 0, -30031, 0, -10898, 0, -30030, 0, -10897, 0, -30029, 0, -10896, 0, -30028, 0, -10895, 0, -30027, 0, -10894, 0, -30026, 0, -10893, 0, -30025, 0, -10892, 0, -30024, 0, -10891, 0, -30023, 0, -10890, 0, -30022, 0, -10889, 0, -30021, 0, -10888, 0, -30020, 0, -10887, 0, -30019, 0, -10886, 0, -30018, 0, -10885, 0, -30017, 0, -10884, 0, -30016, 0, -10883, 0, -30015, 0, -10882, 0, -30014, 0, -10880, 0, -30013, 0, -10879, 0, -30012, 0, -10878, 0, -30011, 0, -10877, 0, -30010, 0, -10876, 0, -30009, 0, -10875, 0, -30008, 0, -10874, 0, -30007, 0, -10873, 0, -30006, 0, -10872, 0, -30005, 0, -10871, 0, -30004, 0, -10870, 0, -30003, 0, -10869, 0, -30002, 0, -10868, 0, -30001, 0, -10867, 0, -30000, 0, -10866, 0, -29999, 0, -10865, 0, -29998, 0, -10864, 0, -29997, 0, -10863, 0, -29996, 0, -10862, 0, -29995, 0, -10861, 0, -29994, 0, -10860, 0, -29993, 0, -10859, 0, -29992, 0, -10858, 0, -29991, 0, -10857, 0, -29990, 0, -10856, 0, -29989, 0, -10855, 0, -29988, 0, -10854, 0, -29987, 0, -10853, 0, -29986, 0, -10852, 0, -29985, 0, -10851, 0, -29984, 0, -10850, 0, -29983, 0, -10849, 0, -29982, 0, -10848, 0, -29981, 0, -10847, 0, -27423, 0, -10846, 0, -27144, 0, -10845, 0, 30504, 0, -10844, 0, 26629, 0, -10843, 0, 27048, 0, -10842, 0, 21643, 0, -10841, 0, 20045, 0, -10840, 0, 28856, 0, -10839, 0, -29752, 0, -10838, 0, 25688, 0, -10837, 0, 25995, 0, -10836, 0, 23429, 0, -10835, 0, 31364, 0, -10834, 0, 20538, 0, -10833, 0, 23528, 0, -10832, 0, 30651, 0, -10831, 0, 27617, 0, -10830, 0, -30087, 0, -10829, 0, 31896, 0, -10828, 0, 27838, 0, -10827, 0, 30415, 0, -10826, 0, 26025, 0, -10825, 0, -28777, 0, -10824, 0, 23853, 0, -10823, 0, 23637, 0, -10822, 0, -31176, 0, -10821, 0, 26632, 0, -10820, 0, 21344, 0, -10819, 0, 25112, 0, -10818, 0, 31449, 0, -10817, 0, 28251, 0, -10816, 0, 32509, 0, -10815, 0, 27167, 0, -10814, 0, 31456, 0, -10813, 0, 24432, 0, -10812, 0, 28467, 0, -10811, 0, 24352, 0, -10810, 0, 25484, 0, -10809, 0, 28072, 0, -10808, 0, 26454, 0, -10807, 0, 19976, 0, -10806, 0, 24080, 0, -10805, 0, -29402, 0, -10804, 0, 20183, 0, -10803, 0, -32576, 0, -10802, 0, 30260, 0, -10801, 0, -26980, 0, -10800, 0, 25307, 0, -10799, 0, 26157, 0, -10798, 0, 25214, 0, -10797, 0, 27836, 0, -10796, 0, -29323, 0, -10795, 0, 29031, 0, -10794, 0, 32617, 0, -10793, 0, 20806, 0, -10792, 0, -32633, 0, -10791, 0, 21484, 0, -10790, 0, -28562, 0, -10789, 0, 25240, 0, -10788, 0, 21746, 0, -10787, 0, -30992, 0, -10786, 0, -28775, 0, -10785, 0, -32763, 0, -10784, 0, -27369, 0, -10783, 0, -31465, 0, -10782, 0, -28711, 0, -10781, 0, 27993, 0, -10780, 0, 29645, 0, -10779, 0, 26015, 0, -10778, 0, 30495, 0, -10777, 0, 29956, 0, -10776, 0, 30759, 0, -10775, 0, -32261, 0, -10774, 0, -29410, 0, -10773, 0, -27512, 0, -10772, 0, 20390, 0, -10771, 0, 26517, 0, -10770, 0, 30137, 0, -10769, 0, -29750, 0, -10768, 0, -26873, 0, -10767, 0, 25391, 0, -10766, 0, -27321, 0, -10765, 0, -27083, 0, -10764, 0, -31560, 0, -10763, 0, 25379, 0, -10762, 0, 30529, 0, -10761, 0, 24449, 0, -10760, 0, 29424, 0, -10759, 0, 20105, 0, -10758, 0, 24596, 0, -10757, 0, 25972, 0, -10756, 0, 25327, 0, -10755, 0, 27491, 0, -10754, 0, 25919, 0, -10688, 0, -29980, 0, -10687, 0, -29979, 0, -10686, 0, -29978, 0, -10685, 0, -29977, 0, -10684, 0, -29976, 0, -10683, 0, -29975, 0, -10682, 0, -29974, 0, -10681, 0, -29973, 0, -10680, 0, -29972, 0, -10679, 0, -29971, 0, -10678, 0, -29970, 0, -10677, 0, -29969, 0, -10676, 0, -29968, 0, -10675, 0, -29967, 0, -10674, 0, -29966, 0, -10673, 0, -29965, 0, -10672, 0, -29964, 0, -10671, 0, -29963, 0, -10670, 0, -29962, 0, -10669, 0, -29961, 0, -10668, 0, -29960, 0, -10667, 0, -29959, 0, -10666, 0, -29958, 0, -10665, 0, -29957, 0, -10664, 0, -29956, 0, -10663, 0, -29955, 0, -10662, 0, -29954, 0, -10661, 0, -29953, 0, -10660, 0, -29952, 0, -10659, 0, -29951, 0, -10658, 0, -29950, 0, -10657, 0, -29949, 0, -10656, 0, -29948, 0, -10655, 0, -29947, 0, -10654, 0, -29946, 0, -10653, 0, -29944, 0, -10652, 0, -29943, 0, -10651, 0, -29942, 0, -10650, 0, -29941, 0, -10649, 0, -29940, 0, -10648, 0, -29939, 0, -10647, 0, -29938, 0, -10646, 0, -29937, 0, -10645, 0, -29936, 0, -10644, 0, -29935, 0, -10643, 0, -29934, 0, -10642, 0, -29933, 0, -10641, 0, -29932, 0, -10640, 0, -29931, 0, -10639, 0, -29930, 0, -10638, 0, -29929, 0, -10637, 0, -29928, 0, -10636, 0, -29927, 0, -10635, 0, -29926, 0, -10634, 0, -29925, 0, -10633, 0, -29924, 0, -10632, 0, -29923, 0, -10631, 0, -29922, 0, -10630, 0, -29921, 0, -10629, 0, -29920, 0, -10628, 0, -29919, 0, -10627, 0, -29918, 0, -10626, 0, -29917, 0, -10624, 0, -29916, 0, -10623, 0, -29915, 0, -10622, 0, -29913, 0, -10621, 0, -29912, 0, -10620, 0, -29911, 0, -10619, 0, -29910, 0, -10618, 0, -29909, 0, -10617, 0, -29908, 0, -10616, 0, -29907, 0, -10615, 0, -29906, 0, -10614, 0, -29905, 0, -10613, 0, -29904, 0, -10612, 0, -29903, 0, -10611, 0, -29902, 0, -10610, 0, -29901, 0, -10609, 0, -29900, 0, -10608, 0, -29899, 0, -10607, 0, -29898, 0, -10606, 0, -29897, 0, -10605, 0, -29896, 0, -10604, 0, -29895, 0, -10603, 0, -29894, 0, -10602, 0, -29893, 0, -10601, 0, -29892, 0, -10600, 0, -29891, 0, -10599, 0, -29890, 0, -10598, 0, -29889, 0, -10597, 0, -29888, 0, -10596, 0, -29887, 0, -10595, 0, -29886, 0, -10594, 0, -29885, 0, -10593, 0, -29884, 0, -10592, 0, -29883, 0, -10591, 0, 24103, 0, -10590, 0, 30151, 0, -10589, 0, -28463, 0, -10588, 0, -29759, 0, -10587, 0, -32099, 0, -10586, 0, 26525, 0, -10585, 0, 25903, 0, -10584, 0, 21553, 0, -10583, 0, -30952, 0, -10582, 0, 30693, 0, -10581, 0, -32606, 0, -10580, 0, -32510, 0, -10579, 0, 27713, 0, -10578, 0, 20043, 0, -10577, 0, 32455, 0, -10576, 0, -32692, 0, -10575, 0, 30452, 0, -10574, 0, 26893, 0, -10573, 0, 27542, 0, -10572, 0, 25191, 0, -10571, 0, 20540, 0, -10570, 0, 20356, 0, -10569, 0, 22336, 0, -10568, 0, 25351, 0, -10567, 0, 27490, 0, -10566, 0, -29250, 0, -10565, 0, 21482, 0, -10564, 0, 26088, 0, -10563, 0, 32440, 0, -10562, 0, 24535, 0, -10561, 0, 25370, 0, -10560, 0, 25527, 0, -10559, 0, -32269, 0, -10558, 0, -32268, 0, -10557, 0, 32622, 0, -10556, 0, 24092, 0, -10555, 0, 23769, 0, -10554, 0, 21046, 0, -10553, 0, 26234, 0, -10552, 0, 31209, 0, -10551, 0, 31258, 0, -10550, 0, -29400, 0, -10549, 0, 28825, 0, -10548, 0, 30164, 0, -10547, 0, 28382, 0, -10546, 0, 27835, 0, -10545, 0, 31378, 0, -10544, 0, 20013, 0, -10543, 0, 30405, 0, -10542, 0, 24544, 0, -10541, 0, -27489, 0, -10540, 0, -30601, 0, -10539, 0, 32456, 0, -10538, 0, 31181, 0, -10537, 0, -32577, 0, -10536, 0, -28211, 0, -10535, 0, 20210, 0, -10534, 0, 20247, 0, -10533, 0, -32225, 0, -10532, 0, 21608, 0, -10531, 0, 24030, 0, -10530, 0, 27954, 0, -10529, 0, -29748, 0, -10528, 0, 31909, 0, -10527, 0, -28812, 0, -10526, 0, -32616, 0, -10525, 0, 24090, 0, -10524, 0, 21650, 0, -10523, 0, 30385, 0, -10522, 0, 23449, 0, -10521, 0, 26172, 0, -10520, 0, -25948, 0, -10519, 0, 29664, 0, -10518, 0, 26666, 0, -10517, 0, -31013, 0, -10516, 0, 26417, 0, -10515, 0, 29482, 0, -10514, 0, -29704, 0, -10513, 0, -29733, 0, -10512, 0, -28656, 0, -10511, 0, 31481, 0, -10510, 0, 28891, 0, -10509, 0, 29038, 0, -10508, 0, 25284, 0, -10507, 0, 30633, 0, -10506, 0, 22065, 0, -10505, 0, 20027, 0, -10504, 0, -31657, 0, -10503, 0, 26609, 0, -10502, 0, 21161, 0, -10501, 0, -31040, 0, -10500, 0, -29394, 0, -10499, 0, -27400, 0, -10498, 0, 31569, 0, -10432, 0, -29882, 0, -10431, 0, -29881, 0, -10430, 0, -29880, 0, -10429, 0, -29879, 0, -10428, 0, -29878, 0, -10427, 0, -29877, 0, -10426, 0, -29876, 0, -10425, 0, -29875, 0, -10424, 0, -29874, 0, -10423, 0, -29873, 0, -10422, 0, -29872, 0, -10421, 0, -29871, 0, -10420, 0, -29870, 0, -10419, 0, -29869, 0, -10418, 0, -29868, 0, -10417, 0, -29867, 0, -10416, 0, -29866, 0, -10415, 0, -29865, 0, -10414, 0, -29864, 0, -10413, 0, -29863, 0, -10412, 0, -29862, 0, -10411, 0, -29861, 0, -10410, 0, -29860, 0, -10409, 0, -29859, 0, -10408, 0, -29858, 0, -10407, 0, -29857, 0, -10406, 0, -29856, 0, -10405, 0, -29855, 0, -10404, 0, -29854, 0, -10403, 0, -29853, 0, -10402, 0, -29852, 0, -10401, 0, -29851, 0, -10400, 0, -29849, 0, -10399, 0, -29848, 0, -10398, 0, -29847, 0, -10397, 0, -29846, 0, -10396, 0, -29845, 0, -10395, 0, -29843, 0, -10394, 0, -29842, 0, -10393, 0, -29841, 0, -10392, 0, -29840, 0, -10391, 0, -29839, 0, -10390, 0, -29838, 0, -10389, 0, -29837, 0, -10388, 0, -29836, 0, -10387, 0, -29835, 0, -10386, 0, -29834, 0, -10385, 0, -29833, 0, -10384, 0, -29832, 0, -10383, 0, -29831, 0, -10382, 0, -29830, 0, -10381, 0, -29829, 0, -10380, 0, -29828, 0, -10379, 0, -29827, 0, -10378, 0, -29826, 0, -10377, 0, -29825, 0, -10376, 0, -29824, 0, -10375, 0, -29823, 0, -10374, 0, -29822, 0, -10373, 0, -29821, 0, -10372, 0, -29820, 0, -10371, 0, -29819, 0, -10370, 0, -29818, 0, -10368, 0, -29817, 0, -10367, 0, -29816, 0, -10366, 0, -29815, 0, -10365, 0, -29814, 0, -10364, 0, -29813, 0, -10363, 0, -29812, 0, -10362, 0, -29811, 0, -10361, 0, -29810, 0, -10360, 0, -29809, 0, -10359, 0, -29808, 0, -10358, 0, -29807, 0, -10357, 0, -29806, 0, -10356, 0, -29805, 0, -10355, 0, -29804, 0, -10354, 0, -29803, 0, -10353, 0, -29802, 0, -10352, 0, -29801, 0, -10351, 0, -29800, 0, -10350, 0, -29799, 0, -10349, 0, -29798, 0, -10348, 0, -29797, 0, -10347, 0, -29796, 0, -10346, 0, -29795, 0, -10345, 0, -29794, 0, -10344, 0, -29793, 0, -10343, 0, -29780, 0, -10342, 0, -29775, 0, -10341, 0, -29765, 0, -10340, 0, -29753, 0, -10339, 0, -29744, 0, -10338, 0, -29718, 0, -10337, 0, -29687, 0, -10336, 0, -29666, 0, -10335, 0, 20303, 0, -10334, 0, 27880, 0, -10333, 0, 31069, 0, -10332, 0, -25989, 0, -10331, 0, 25235, 0, -10330, 0, 29226, 0, -10329, 0, 25341, 0, -10328, 0, 19987, 0, -10327, 0, 30742, 0, -10326, 0, -28820, 0, -10325, 0, 25776, 0, -10324, 0, -29350, 0, -10323, 0, 31686, 0, -10322, 0, 26729, 0, -10321, 0, 24196, 0, -10320, 0, -30523, 0, -10319, 0, 22918, 0, -10318, 0, 25758, 0, -10317, 0, 22766, 0, -10316, 0, 29366, 0, -10315, 0, 26894, 0, -10314, 0, -27355, 0, -10313, 0, -28675, 0, -10312, 0, -29352, 0, -10311, 0, 22368, 0, -10310, 0, 32512, 0, -10309, 0, -29690, 0, -10308, 0, 20934, 0, -10307, 0, 25417, 0, -10306, 0, 25305, 0, -10305, 0, 21331, 0, -10304, 0, 26700, 0, -10303, 0, 29730, 0, -10302, 0, -31999, 0, -10301, 0, -28340, 0, -10300, 0, 21828, 0, -10299, 0, 30528, 0, -10298, 0, 28796, 0, -10297, 0, 27978, 0, -10296, 0, 20857, 0, -10295, 0, 21672, 0, -10294, 0, -29372, 0, -10293, 0, 23039, 0, -10292, 0, 28363, 0, -10291, 0, 28100, 0, -10290, 0, 23388, 0, -10289, 0, 32043, 0, -10288, 0, 20180, 0, -10287, 0, 31869, 0, -10286, 0, 28371, 0, -10285, 0, 23376, 0, -10284, 0, -32278, 0, -10283, 0, 28173, 0, -10282, 0, 23383, 0, -10281, 0, -25853, 0, -10280, 0, 26837, 0, -10279, 0, -29142, 0, -10278, 0, 23447, 0, -10277, 0, 32508, 0, -10276, 0, 24635, 0, -10275, 0, 32437, 0, -10274, 0, -28487, 0, -10273, 0, -29328, 0, -10272, 0, 22863, 0, -10271, 0, 25549, 0, -10270, 0, 31199, 0, -10269, 0, -29261, 0, -10268, 0, 21330, 0, -10267, 0, 26063, 0, -10266, 0, 31062, 0, -10265, 0, -29755, 0, -10264, 0, -27077, 0, -10263, 0, 32452, 0, -10262, 0, -27461, 0, -10261, 0, 32386, 0, -10260, 0, 22068, 0, -10259, 0, -28279, 0, -10258, 0, 26368, 0, -10257, 0, 32618, 0, -10256, 0, 23562, 0, -10255, 0, -28555, 0, -10254, 0, 26152, 0, -10253, 0, 24038, 0, -10252, 0, 20304, 0, -10251, 0, 26590, 0, -10250, 0, 20570, 0, -10249, 0, 20316, 0, -10248, 0, 22352, 0, -10247, 0, 24231, 0, -10246, 0, -6128, 0, -10245, 0, -6127, 0, -10244, 0, -6126, 0, -10243, 0, -6125, 0, -10242, 0, -6124, 0, -10176, 0, -29640, 0, -10175, 0, -29639, 0, -10174, 0, -29638, 0, -10173, 0, -29637, 0, -10172, 0, -29636, 0, -10171, 0, -29635, 0, -10170, 0, -29634, 0, -10169, 0, -29633, 0, -10168, 0, -29632, 0, -10167, 0, -29630, 0, -10166, 0, -29629, 0, -10165, 0, -29628, 0, -10164, 0, -29627, 0, -10163, 0, -29624, 0, -10162, 0, -29622, 0, -10161, 0, -29621, 0, -10160, 0, -29619, 0, -10159, 0, -29618, 0, -10158, 0, -29617, 0, -10157, 0, -29616, 0, -10156, 0, -29615, 0, -10155, 0, -29614, 0, -10154, 0, -29613, 0, -10153, 0, -29612, 0, -10152, 0, -29610, 0, -10151, 0, -29609, 0, -10150, 0, -29608, 0, -10149, 0, -29607, 0, -10148, 0, -29605, 0, -10147, 0, -29604, 0, -10146, 0, -29603, 0, -10145, 0, -29602, 0, -10144, 0, -29601, 0, -10143, 0, -29600, 0, -10142, 0, -29597, 0, -10141, 0, -29596, 0, -10140, 0, -29595, 0, -10139, 0, -29594, 0, -10138, 0, -29593, 0, -10137, 0, -29592, 0, -10136, 0, -29591, 0, -10135, 0, -29588, 0, -10134, 0, -29587, 0, -10133, 0, -29586, 0, -10132, 0, -29585, 0, -10131, 0, -29584, 0, -10130, 0, -29583, 0, -10129, 0, -29582, 0, -10128, 0, -29580, 0, -10127, 0, -29579, 0, -10126, 0, -29578, 0, -10125, 0, -29577, 0, -10124, 0, -29573, 0, -10123, 0, -29572, 0, -10122, 0, -29571, 0, -10121, 0, -29570, 0, -10120, 0, -29569, 0, -10119, 0, -29568, 0, -10118, 0, -29567, 0, -10117, 0, -29565, 0, -10116, 0, -29564, 0, -10115, 0, -29562, 0, -10114, 0, -29561, 0, -10112, 0, -29560, 0, -10111, 0, -29557, 0, -10110, 0, -29555, 0, -10109, 0, -29554, 0, -10108, 0, -29553, 0, -10107, 0, -29552, 0, -10106, 0, -29551, 0, -10105, 0, -29550, 0, -10104, 0, -29549, 0, -10103, 0, -29547, 0, -10102, 0, -29546, 0, -10101, 0, -29545, 0, -10100, 0, -29543, 0, -10099, 0, -29542, 0, -10098, 0, -29541, 0, -10097, 0, -29540, 0, -10096, 0, -29539, 0, -10095, 0, -29538, 0, -10094, 0, -29537, 0, -10093, 0, -29536, 0, -10092, 0, -29535, 0, -10091, 0, -29534, 0, -10090, 0, -29533, 0, -10089, 0, -29532, 0, -10088, 0, -29531, 0, -10087, 0, -29530, 0, -10086, 0, -29529, 0, -10085, 0, -29528, 0, -10084, 0, -29527, 0, -10083, 0, -29526, 0, -10082, 0, -29525, 0, -10081, 0, -29524, 0, -10080, 0, -29523, 0, -10079, 0, 20109, 0, -10078, 0, 19980, 0, -10077, 0, 20800, 0, -10076, 0, 19984, 0, -10075, 0, 24319, 0, -10074, 0, 21317, 0, -10073, 0, 19989, 0, -10072, 0, 20120, 0, -10071, 0, 19998, 0, -10070, 0, -25806, 0, -10069, 0, 23404, 0, -10068, 0, 22121, 0, -10067, 0, 20008, 0, -10066, 0, 31162, 0, -10065, 0, 20031, 0, -10064, 0, 21269, 0, -10063, 0, 20039, 0, -10062, 0, 22829, 0, -10061, 0, 29243, 0, -10060, 0, 21358, 0, -10059, 0, 27664, 0, -10058, 0, 22239, 0, -10057, 0, -32540, 0, -10056, 0, -26217, 0, -10055, 0, 27603, 0, -10054, 0, 30590, 0, -10053, 0, -24809, 0, -10052, 0, 20022, 0, -10051, 0, 20127, 0, -10050, 0, -24816, 0, -10049, 0, 20060, 0, -10048, 0, 20073, 0, -10047, 0, 20115, 0, -10046, 0, -32120, 0, -10045, 0, 23387, 0, -10044, 0, 21868, 0, -10043, 0, 22031, 0, -10042, 0, 20164, 0, -10041, 0, 21389, 0, -10040, 0, 21405, 0, -10039, 0, 21411, 0, -10038, 0, 21413, 0, -10037, 0, 21422, 0, -10036, 0, -26779, 0, -10035, 0, -29347, 0, -10034, 0, 21274, 0, -10033, 0, 21493, 0, -10032, 0, 21286, 0, -10031, 0, 21294, 0, -10030, 0, 21310, 0, -10029, 0, -29348, 0, -10028, 0, 21350, 0, -10027, 0, 21347, 0, -10026, 0, 20994, 0, -10025, 0, 21000, 0, -10024, 0, 21006, 0, -10023, 0, 21037, 0, -10022, 0, 21043, 0, -10021, 0, 21055, 0, -10020, 0, 21056, 0, -10019, 0, 21068, 0, -10018, 0, 21086, 0, -10017, 0, 21089, 0, -10016, 0, 21084, 0, -10015, 0, -31569, 0, -10014, 0, 21117, 0, -10013, 0, 21122, 0, -10012, 0, 21121, 0, -10011, 0, 21136, 0, -10010, 0, 21139, 0, -10009, 0, 20866, 0, -10008, 0, 32596, 0, -10007, 0, 20155, 0, -10006, 0, 20163, 0, -10005, 0, 20169, 0, -10004, 0, 20162, 0, -10003, 0, 20200, 0, -10002, 0, 20193, 0, -10001, 0, 20203, 0, -10000, 0, 20190, 0, -9999, 0, 20251, 0, -9998, 0, 20211, 0, -9997, 0, 20258, 0, -9996, 0, 20324, 0, -9995, 0, 20213, 0, -9994, 0, 20261, 0, -9993, 0, 20263, 0, -9992, 0, 20233, 0, -9991, 0, 20267, 0, -9990, 0, 20318, 0, -9989, 0, 20327, 0, -9988, 0, 25912, 0, -9987, 0, 20314, 0, -9986, 0, 20317, 0, -9920, 0, -29522, 0, -9919, 0, -29521, 0, -9918, 0, -29520, 0, -9917, 0, -29519, 0, -9916, 0, -29518, 0, -9915, 0, -29517, 0, -9914, 0, -29516, 0, -9913, 0, -29515, 0, -9912, 0, -29514, 0, -9911, 0, -29513, 0, -9910, 0, -29512, 0, -9909, 0, -29511, 0, -9908, 0, -29510, 0, -9907, 0, -29509, 0, -9906, 0, -29508, 0, -9905, 0, -29507, 0, -9904, 0, -29506, 0, -9903, 0, -29505, 0, -9902, 0, -29504, 0, -9901, 0, -29503, 0, -9900, 0, -29502, 0, -9899, 0, -29501, 0, -9898, 0, -29500, 0, -9897, 0, -29499, 0, -9896, 0, -29498, 0, -9895, 0, -29497, 0, -9894, 0, -29496, 0, -9893, 0, -29495, 0, -9892, 0, -29494, 0, -9891, 0, -29493, 0, -9890, 0, -29492, 0, -9889, 0, -29491, 0, -9888, 0, -29490, 0, -9887, 0, -29489, 0, -9886, 0, -29488, 0, -9885, 0, -29487, 0, -9884, 0, -29486, 0, -9883, 0, -29485, 0, -9882, 0, -29484, 0, -9881, 0, -29483, 0, -9880, 0, -29482, 0, -9879, 0, -29481, 0, -9878, 0, -29480, 0, -9877, 0, -29479, 0, -9876, 0, -29478, 0, -9875, 0, -29477, 0, -9874, 0, -29476, 0, -9873, 0, -29475, 0, -9872, 0, -29474, 0, -9871, 0, -29473, 0, -9870, 0, -29472, 0, -9869, 0, -29471, 0, -9868, 0, -29470, 0, -9867, 0, -29469, 0, -9866, 0, -29468, 0, -9865, 0, -29467, 0, -9864, 0, -29466, 0, -9863, 0, -29465, 0, -9862, 0, -29464, 0, -9861, 0, -29463, 0, -9860, 0, -29462, 0, -9859, 0, -29461, 0, -9858, 0, -29460, 0, -9856, 0, -29459, 0, -9855, 0, -29458, 0, -9854, 0, -29457, 0, -9853, 0, -29456, 0, -9852, 0, -29455, 0, -9851, 0, -29454, 0, -9850, 0, -29453, 0, -9849, 0, -29452, 0, -9848, 0, -29451, 0, -9847, 0, -29450, 0, -9846, 0, -29449, 0, -9845, 0, -29448, 0, -9844, 0, -29447, 0, -9843, 0, -29446, 0, -9842, 0, -29445, 0, -9841, 0, -29444, 0, -9840, 0, -29443, 0, -9839, 0, -29442, 0, -9838, 0, -29441, 0, -9837, 0, -29440, 0, -9836, 0, -29439, 0, -9835, 0, -29438, 0, -9834, 0, -29437, 0, -9833, 0, -29436, 0, -9832, 0, -29435, 0, -9831, 0, -29434, 0, -9830, 0, -29433, 0, -9829, 0, -29432, 0, -9828, 0, -29431, 0, -9827, 0, -29430, 0, -9826, 0, -29429, 0, -9825, 0, -29428, 0, -9824, 0, -29427, 0, -9823, 0, 20319, 0, -9822, 0, 20311, 0, -9821, 0, 20274, 0, -9820, 0, 20285, 0, -9819, 0, 20342, 0, -9818, 0, 20340, 0, -9817, 0, 20369, 0, -9816, 0, 20361, 0, -9815, 0, 20355, 0, -9814, 0, 20367, 0, -9813, 0, 20350, 0, -9812, 0, 20347, 0, -9811, 0, 20394, 0, -9810, 0, 20348, 0, -9809, 0, 20396, 0, -9808, 0, 20372, 0, -9807, 0, 20454, 0, -9806, 0, 20456, 0, -9805, 0, 20458, 0, -9804, 0, 20421, 0, -9803, 0, 20442, 0, -9802, 0, 20451, 0, -9801, 0, 20444, 0, -9800, 0, 20433, 0, -9799, 0, 20447, 0, -9798, 0, 20472, 0, -9797, 0, 20521, 0, -9796, 0, 20556, 0, -9795, 0, 20467, 0, -9794, 0, 20524, 0, -9793, 0, 20495, 0, -9792, 0, 20526, 0, -9791, 0, 20525, 0, -9790, 0, 20478, 0, -9789, 0, 20508, 0, -9788, 0, 20492, 0, -9787, 0, 20517, 0, -9786, 0, 20520, 0, -9785, 0, 20606, 0, -9784, 0, 20547, 0, -9783, 0, 20565, 0, -9782, 0, 20552, 0, -9781, 0, 20558, 0, -9780, 0, 20588, 0, -9779, 0, 20603, 0, -9778, 0, 20645, 0, -9777, 0, 20647, 0, -9776, 0, 20649, 0, -9775, 0, 20666, 0, -9774, 0, 20694, 0, -9773, 0, 20742, 0, -9772, 0, 20717, 0, -9771, 0, 20716, 0, -9770, 0, 20710, 0, -9769, 0, 20718, 0, -9768, 0, 20743, 0, -9767, 0, 20747, 0, -9766, 0, 20189, 0, -9765, 0, 27709, 0, -9764, 0, 20312, 0, -9763, 0, 20325, 0, -9762, 0, 20430, 0, -9761, 0, -24672, 0, -9760, 0, 27718, 0, -9759, 0, 31860, 0, -9758, 0, 20846, 0, -9757, 0, 24061, 0, -9756, 0, -24887, 0, -9755, 0, -26216, 0, -9754, 0, 20865, 0, -9753, 0, 22804, 0, -9752, 0, 21241, 0, -9751, 0, 21261, 0, -9750, 0, -30201, 0, -9749, 0, 21264, 0, -9748, 0, 20971, 0, -9747, 0, 22809, 0, -9746, 0, 20821, 0, -9745, 0, 20128, 0, -9744, 0, 20822, 0, -9743, 0, 20147, 0, -9742, 0, -30610, 0, -9741, 0, -30556, 0, -9740, 0, 20149, 0, -9739, 0, -32492, 0, -9738, 0, -30510, 0, -9737, 0, 31104, 0, -9736, 0, 23348, 0, -9735, 0, -30717, 0, -9734, 0, 32696, 0, -9733, 0, 20907, 0, -9732, 0, 20913, 0, -9731, 0, 20925, 0, -9730, 0, 20924, 0, -9664, 0, -29426, 0, -9663, 0, -29425, 0, -9662, 0, -29424, 0, -9661, 0, -29423, 0, -9660, 0, -29422, 0, -9659, 0, -29421, 0, -9658, 0, -29420, 0, -9657, 0, -29419, 0, -9656, 0, -29418, 0, -9655, 0, -29417, 0, -9654, 0, -29416, 0, -9653, 0, -29415, 0, -9652, 0, -29414, 0, -9651, 0, -29413, 0, -9650, 0, -29412, 0, -9649, 0, -29408, 0, -9648, 0, -29359, 0, -9647, 0, -29358, 0, -9646, 0, -29353, 0, -9645, 0, -29345, 0, -9644, 0, -29339, 0, -9643, 0, -29336, 0, -9642, 0, -29335, 0, -9641, 0, -29334, 0, -9640, 0, -29332, 0, -9639, 0, -29330, 0, -9638, 0, -29329, 0, -9637, 0, -29327, 0, -9636, 0, -29326, 0, -9635, 0, -29320, 0, -9634, 0, -29319, 0, -9633, 0, -29318, 0, -9632, 0, -29317, 0, -9631, 0, -29316, 0, -9630, 0, -29315, 0, -9629, 0, -29314, 0, -9628, 0, -29313, 0, -9627, 0, -29312, 0, -9626, 0, -29310, 0, -9625, 0, -29309, 0, -9624, 0, -29306, 0, -9623, 0, -29305, 0, -9622, 0, -29304, 0, -9621, 0, -29303, 0, -9620, 0, -29300, 0, -9619, 0, -29299, 0, -9618, 0, -29298, 0, -9617, 0, -29297, 0, -9616, 0, -29296, 0, -9615, 0, -29294, 0, -9614, 0, -29293, 0, -9613, 0, -29291, 0, -9612, 0, -29290, 0, -9611, 0, -29289, 0, -9610, 0, -29288, 0, -9609, 0, -29287, 0, -9608, 0, -29286, 0, -9607, 0, -29285, 0, -9606, 0, -29284, 0, -9605, 0, -29283, 0, -9604, 0, -29282, 0, -9603, 0, -29280, 0, -9602, 0, -29279, 0, -9600, 0, -29278, 0, -9599, 0, -29276, 0, -9598, 0, -29275, 0, -9597, 0, -29274, 0, -9596, 0, -29273, 0, -9595, 0, -29272, 0, -9594, 0, -29271, 0, -9593, 0, -29270, 0, -9592, 0, -29269, 0, -9591, 0, -29268, 0, -9590, 0, -29267, 0, -9589, 0, -29266, 0, -9588, 0, -29265, 0, -9587, 0, -29264, 0, -9586, 0, -29262, 0, -9585, 0, -29258, 0, -9584, 0, -29257, 0, -9583, 0, -29255, 0, -9582, 0, -29253, 0, -9581, 0, -29251, 0, -9580, 0, -29248, 0, -9579, 0, -29247, 0, -9578, 0, -29246, 0, -9577, 0, -29243, 0, -9576, 0, -29241, 0, -9575, 0, -29240, 0, -9574, 0, -29239, 0, -9573, 0, -29238, 0, -9572, 0, -29235, 0, -9571, 0, -29232, 0, -9570, 0, -29230, 0, -9569, 0, -29229, 0, -9568, 0, -29228, 0, -9567, 0, 20935, 0, -9566, 0, 20886, 0, -9565, 0, 20898, 0, -9564, 0, 20901, 0, -9563, 0, -29792, 0, -9562, 0, -29786, 0, -9561, 0, -29785, 0, -9560, 0, -29782, 0, -9559, 0, -29772, 0, -9558, 0, -29771, 0, -9557, 0, -29769, 0, -9556, 0, -29758, 0, -9555, 0, -29757, 0, -9554, 0, -29749, 0, -9553, 0, -29745, 0, -9552, 0, -29746, 0, -9551, 0, -29742, 0, -9550, 0, -29741, 0, -9549, 0, -29740, 0, -9548, 0, -29738, 0, -9547, 0, -29736, 0, -9546, 0, -29735, 0, -9545, 0, -29732, 0, -9544, 0, -29729, 0, -9543, 0, -29728, 0, -9542, 0, -29724, 0, -9541, 0, -29720, 0, -9540, 0, -29719, 0, -9539, 0, -29714, 0, -9538, 0, -29712, 0, -9537, 0, -29709, 0, -9536, 0, -29706, 0, -9535, 0, -29703, 0, -9534, 0, -29700, 0, -9533, 0, -29697, 0, -9532, 0, -29696, 0, -9531, 0, -29694, 0, -9530, 0, -29692, 0, -9529, 0, -29689, 0, -9528, 0, -29684, 0, -9527, 0, -29681, 0, -9526, 0, -29679, 0, -9525, 0, -29678, 0, -9524, 0, -29676, 0, -9523, 0, -29675, 0, -9522, 0, -29674, 0, -9521, 0, -29671, 0, -9520, 0, -29669, 0, -9519, 0, -29672, 0, -9518, 0, -29667, 0, -9517, 0, -29665, 0, -9516, 0, -29664, 0, -9515, 0, -29663, 0, -9514, 0, -29659, 0, -9513, 0, -29657, 0, -9512, 0, -29654, 0, -9511, 0, -29653, 0, -9510, 0, -29650, 0, -9509, 0, -29649, 0, -9508, 0, -29646, 0, -9507, 0, -29645, 0, -9506, 0, -29643, 0, -9505, 0, -29642, 0, -9504, 0, 21353, 0, -9503, 0, 21370, 0, -9502, 0, -27107, 0, -9501, 0, -27102, 0, -9500, 0, -27103, 0, -9499, 0, -27087, 0, -9498, 0, -27094, 0, -9497, 0, -27075, 0, -9496, 0, -27076, 0, -9495, 0, -27070, 0, -9494, 0, -27063, 0, -9493, 0, -27052, 0, -9492, 0, -27041, 0, -9491, 0, -27033, 0, -9490, 0, -27028, 0, -9489, 0, -27022, 0, -9488, 0, -27020, 0, -9487, 0, -27000, 0, -9486, 0, -26995, 0, -9485, 0, -26985, 0, -9484, 0, -26960, 0, -9483, 0, -28521, 0, -9482, 0, -28517, 0, -9481, 0, -28515, 0, -9480, 0, -28519, 0, -9479, 0, -28500, 0, -9478, 0, -28511, 0, -9477, 0, -28492, 0, -9476, 0, -28493, 0, -9475, 0, -28490, 0, -9474, 0, -28486, 0, -9408, 0, -29227, 0, -9407, 0, -29224, 0, -9406, 0, -29223, 0, -9405, 0, -29220, 0, -9404, 0, -29216, 0, -9403, 0, -29215, 0, -9402, 0, -29214, 0, -9401, 0, -29211, 0, -9400, 0, -29210, 0, -9399, 0, -29209, 0, -9398, 0, -29207, 0, -9397, 0, -29203, 0, -9396, 0, -29202, 0, -9395, 0, -29200, 0, -9394, 0, -29199, 0, -9393, 0, -29198, 0, -9392, 0, -29196, 0, -9391, 0, -29194, 0, -9390, 0, -29188, 0, -9389, 0, -29186, 0, -9388, 0, -29185, 0, -9387, 0, -29184, 0, -9386, 0, -29183, 0, -9385, 0, -29182, 0, -9384, 0, -29181, 0, -9383, 0, -29180, 0, -9382, 0, -29178, 0, -9381, 0, -29177, 0, -9380, 0, -29176, 0, -9379, 0, -29173, 0, -9378, 0, -29171, 0, -9377, 0, -29170, 0, -9376, 0, -29168, 0, -9375, 0, -29167, 0, -9374, 0, -29166, 0, -9373, 0, -29165, 0, -9372, 0, -29163, 0, -9371, 0, -29162, 0, -9370, 0, -29161, 0, -9369, 0, -29160, 0, -9368, 0, -29159, 0, -9367, 0, -29158, 0, -9366, 0, -29157, 0, -9365, 0, -29156, 0, -9364, 0, -29152, 0, -9363, 0, -29151, 0, -9362, 0, -29148, 0, -9361, 0, -29147, 0, -9360, 0, -29146, 0, -9359, 0, -29145, 0, -9358, 0, -29144, 0, -9357, 0, -29141, 0, -9356, 0, -29139, 0, -9355, 0, -29136, 0, -9354, 0, -29134, 0, -9353, 0, -29133, 0, -9352, 0, -29132, 0, -9351, 0, -29130, 0, -9350, 0, -29129, 0, -9349, 0, -29128, 0, -9348, 0, -29125, 0, -9347, 0, -29124, 0, -9346, 0, -29122, 0, -9344, 0, -29121, 0, -9343, 0, -29117, 0, -9342, 0, -29115, 0, -9341, 0, -29114, 0, -9340, 0, -29108, 0, -9339, 0, -29107, 0, -9338, 0, -29106, 0, -9337, 0, -29105, 0, -9336, 0, -29104, 0, -9335, 0, -29101, 0, -9334, 0, -29100, 0, -9333, 0, -29099, 0, -9332, 0, -29098, 0, -9331, 0, -29097, 0, -9330, 0, -29096, 0, -9329, 0, -29094, 0, -9328, 0, -29093, 0, -9327, 0, -29092, 0, -9326, 0, -29091, 0, -9325, 0, -29090, 0, -9324, 0, -29089, 0, -9323, 0, -29088, 0, -9322, 0, -29087, 0, -9321, 0, -29086, 0, -9320, 0, -29085, 0, -9319, 0, -29084, 0, -9318, 0, -29083, 0, -9317, 0, -29081, 0, -9316, 0, -29080, 0, -9315, 0, -29078, 0, -9314, 0, -29077, 0, -9313, 0, -29074, 0, -9312, 0, -29071, 0, -9311, 0, -28488, 0, -9310, 0, -28496, 0, -9309, 0, -28465, 0, -9308, 0, -28475, 0, -9307, 0, -28482, 0, -9306, 0, -28464, 0, -9305, 0, -28476, 0, -9304, 0, -28473, 0, -9303, 0, -28461, 0, -9302, 0, -28442, 0, -9301, 0, -28446, 0, -9300, 0, -28452, 0, -9299, 0, -28457, 0, -9298, 0, -28453, 0, -9297, 0, -28437, 0, -9296, 0, -28433, 0, -9295, 0, -28418, 0, -9294, 0, -28412, 0, -9293, 0, -28382, 0, -9292, 0, -28386, 0, -9291, 0, -28381, 0, -9290, 0, -28367, 0, -9289, 0, -28369, 0, -9288, 0, -28359, 0, -9287, 0, -28349, 0, -9286, 0, -28346, 0, -9285, 0, 21005, 0, -9284, 0, 22850, 0, -9283, 0, 21154, 0, -9282, 0, 21164, 0, -9281, 0, 21165, 0, -9280, 0, 21182, 0, -9279, 0, 21759, 0, -9278, 0, 21200, 0, -9277, 0, 21206, 0, -9276, 0, 21232, 0, -9275, 0, 21471, 0, -9274, 0, 29166, 0, -9273, 0, 30669, 0, -9272, 0, 24308, 0, -9271, 0, 20981, 0, -9270, 0, 20988, 0, -9269, 0, -25809, 0, -9268, 0, 21430, 0, -9267, 0, 24321, 0, -9266, 0, 30042, 0, -9265, 0, 24047, 0, -9264, 0, 22348, 0, -9263, 0, 22441, 0, -9262, 0, 22433, 0, -9261, 0, 22654, 0, -9260, 0, 22716, 0, -9259, 0, 22725, 0, -9258, 0, 22737, 0, -9257, 0, 22313, 0, -9256, 0, 22316, 0, -9255, 0, 22314, 0, -9254, 0, 22323, 0, -9253, 0, 22329, 0, -9252, 0, 22318, 0, -9251, 0, 22319, 0, -9250, 0, 22364, 0, -9249, 0, 22331, 0, -9248, 0, 22338, 0, -9247, 0, 22377, 0, -9246, 0, 22405, 0, -9245, 0, 22379, 0, -9244, 0, 22406, 0, -9243, 0, 22396, 0, -9242, 0, 22395, 0, -9241, 0, 22376, 0, -9240, 0, 22381, 0, -9239, 0, 22390, 0, -9238, 0, 22387, 0, -9237, 0, 22445, 0, -9236, 0, 22436, 0, -9235, 0, 22412, 0, -9234, 0, 22450, 0, -9233, 0, 22479, 0, -9232, 0, 22439, 0, -9231, 0, 22452, 0, -9230, 0, 22419, 0, -9229, 0, 22432, 0, -9228, 0, 22485, 0, -9227, 0, 22488, 0, -9226, 0, 22490, 0, -9225, 0, 22489, 0, -9224, 0, 22482, 0, -9223, 0, 22456, 0, -9222, 0, 22516, 0, -9221, 0, 22511, 0, -9220, 0, 22520, 0, -9219, 0, 22500, 0, -9218, 0, 22493, 0, -9152, 0, -29069, 0, -9151, 0, -29067, 0, -9150, 0, -29065, 0, -9149, 0, -29064, 0, -9148, 0, -29063, 0, -9147, 0, -29062, 0, -9146, 0, -29061, 0, -9145, 0, -29059, 0, -9144, 0, -29058, 0, -9143, 0, -29056, 0, -9142, 0, -29054, 0, -9141, 0, -29053, 0, -9140, 0, -29052, 0, -9139, 0, -29050, 0, -9138, 0, -29048, 0, -9137, 0, -29047, 0, -9136, 0, -29046, 0, -9135, 0, -29045, 0, -9134, 0, -29044, 0, -9133, 0, -29043, 0, -9132, 0, -29042, 0, -9131, 0, -29039, 0, -9130, 0, -29038, 0, -9129, 0, -29037, 0, -9128, 0, -29035, 0, -9127, 0, -29034, 0, -9126, 0, -29033, 0, -9125, 0, -29032, 0, -9124, 0, -29031, 0, -9123, 0, -29030, 0, -9122, 0, -29029, 0, -9121, 0, -29027, 0, -9120, 0, -29025, 0, -9119, 0, -29024, 0, -9118, 0, -29023, 0, -9117, 0, -29022, 0, -9116, 0, -29021, 0, -9115, 0, -29020, 0, -9114, 0, -29019, 0, -9113, 0, -29018, 0, -9112, 0, -29017, 0, -9111, 0, -29016, 0, -9110, 0, -29015, 0, -9109, 0, -29014, 0, -9108, 0, -29011, 0, -9107, 0, -29010, 0, -9106, 0, -29008, 0, -9105, 0, -29007, 0, -9104, 0, -29005, 0, -9103, 0, -29004, 0, -9102, 0, -29003, 0, -9101, 0, -29002, 0, -9100, 0, -29001, 0, -9099, 0, -29000, 0, -9098, 0, -28999, 0, -9097, 0, -28997, 0, -9096, 0, -28996, 0, -9095, 0, -28995, 0, -9094, 0, -28994, 0, -9093, 0, -28993, 0, -9092, 0, -28992, 0, -9091, 0, -28991, 0, -9090, 0, -28990, 0, -9088, 0, -28989, 0, -9087, 0, -28988, 0, -9086, 0, -28987, 0, -9085, 0, -28986, 0, -9084, 0, -28985, 0, -9083, 0, -28984, 0, -9082, 0, -28983, 0, -9081, 0, -28982, 0, -9080, 0, -28981, 0, -9079, 0, -28980, 0, -9078, 0, -28979, 0, -9077, 0, -28977, 0, -9076, 0, -28976, 0, -9075, 0, -28975, 0, -9074, 0, -28974, 0, -9073, 0, -28973, 0, -9072, 0, -28972, 0, -9071, 0, -28971, 0, -9070, 0, -28970, 0, -9069, 0, -28969, 0, -9068, 0, -28968, 0, -9067, 0, -28967, 0, -9066, 0, -28966, 0, -9065, 0, -28965, 0, -9064, 0, -28964, 0, -9063, 0, -28963, 0, -9062, 0, -28962, 0, -9061, 0, -28961, 0, -9060, 0, -28960, 0, -9059, 0, -28959, 0, -9058, 0, -28958, 0, -9057, 0, -28957, 0, -9056, 0, -28956, 0, -9055, 0, 22539, 0, -9054, 0, 22541, 0, -9053, 0, 22525, 0, -9052, 0, 22509, 0, -9051, 0, 22528, 0, -9050, 0, 22558, 0, -9049, 0, 22553, 0, -9048, 0, 22596, 0, -9047, 0, 22560, 0, -9046, 0, 22629, 0, -9045, 0, 22636, 0, -9044, 0, 22657, 0, -9043, 0, 22665, 0, -9042, 0, 22682, 0, -9041, 0, 22656, 0, -9040, 0, -26200, 0, -9039, 0, -24807, 0, -9038, 0, 25087, 0, -9037, 0, -32135, 0, -9036, 0, -32131, 0, -9035, 0, -32129, 0, -9034, 0, -32113, 0, -9033, 0, -32118, 0, -9032, 0, -32088, 0, -9031, 0, -32124, 0, -9030, 0, -32114, 0, -9029, 0, -32111, 0, -9028, 0, -32105, 0, -9027, 0, -32103, 0, -9026, 0, -32085, 0, -9025, 0, -32072, 0, -9024, 0, -32066, 0, -9023, 0, -32080, 0, -9022, 0, -32056, 0, -9021, 0, -32054, 0, -9020, 0, -32029, 0, -9019, 0, -32104, 0, -9018, 0, -32073, 0, -9017, 0, -32082, 0, -9016, 0, -32053, 0, -9015, 0, -32052, 0, -9014, 0, -32063, 0, -9013, 0, -32087, 0, -9012, 0, -32076, 0, -9011, 0, -32095, 0, -9010, 0, -32086, 0, -9009, 0, -32097, 0, -9008, 0, -32060, 0, -9007, 0, -32050, 0, -9006, 0, -32092, 0, -9005, 0, -32031, 0, -9004, 0, -31991, 0, -9003, 0, -32009, 0, -9002, 0, -32028, 0, -9001, 0, -31985, 0, -9000, 0, -31993, 0, -8999, 0, -32036, 0, -8998, 0, -32012, 0, -8997, 0, -32046, 0, -8996, 0, -32040, 0, -8995, 0, -31988, 0, -8994, 0, -32005, 0, -8993, 0, -32045, 0, -8992, 0, -31983, 0, -8991, 0, -31974, 0, -8990, 0, -31994, 0, -8989, 0, -31980, 0, -8988, 0, -31979, 0, -8987, 0, -32032, 0, -8986, 0, -32043, 0, -8985, 0, -31972, 0, -8984, 0, -31919, 0, -8983, 0, -31909, 0, -8982, 0, -31908, 0, -8981, 0, -31992, 0, -8980, 0, -31854, 0, -8979, 0, -31940, 0, -8978, 0, -31948, 0, -8977, 0, -31951, 0, -8976, 0, -31845, 0, -8975, 0, -31906, 0, -8974, 0, -31953, 0, -8973, 0, -31921, 0, -8972, 0, -31929, 0, -8971, 0, -31933, 0, -8970, 0, -31905, 0, -8969, 0, -31936, 0, -8968, 0, -31977, 0, -8967, 0, -31904, 0, -8966, 0, -31955, 0, -8965, 0, -31942, 0, -8964, 0, -31949, 0, -8963, 0, -31898, 0, -8962, 0, -31899, 0, -8896, 0, -28955, 0, -8895, 0, -28954, 0, -8894, 0, -28953, 0, -8893, 0, -28952, 0, -8892, 0, -28951, 0, -8891, 0, -28950, 0, -8890, 0, -28949, 0, -8889, 0, -28948, 0, -8888, 0, -28947, 0, -8887, 0, -28946, 0, -8886, 0, -28945, 0, -8885, 0, -28944, 0, -8884, 0, -28943, 0, -8883, 0, -28942, 0, -8882, 0, -28941, 0, -8881, 0, -28940, 0, -8880, 0, -28939, 0, -8879, 0, -28938, 0, -8878, 0, -28937, 0, -8877, 0, -28936, 0, -8876, 0, -28935, 0, -8875, 0, -28934, 0, -8874, 0, -28933, 0, -8873, 0, -28932, 0, -8872, 0, -28931, 0, -8871, 0, -28930, 0, -8870, 0, -28929, 0, -8869, 0, -28928, 0, -8868, 0, -28927, 0, -8867, 0, -28926, 0, -8866, 0, -28925, 0, -8865, 0, -28924, 0, -8864, 0, -28923, 0, -8863, 0, -28922, 0, -8862, 0, -28921, 0, -8861, 0, -28920, 0, -8860, 0, -28919, 0, -8859, 0, -28918, 0, -8858, 0, -28917, 0, -8857, 0, -28916, 0, -8856, 0, -28915, 0, -8855, 0, -28914, 0, -8854, 0, -28913, 0, -8853, 0, -28912, 0, -8852, 0, -28911, 0, -8851, 0, -28910, 0, -8850, 0, -28909, 0, -8849, 0, -28908, 0, -8848, 0, -28907, 0, -8847, 0, -28906, 0, -8846, 0, -28905, 0, -8845, 0, -28904, 0, -8844, 0, -28903, 0, -8843, 0, -28902, 0, -8842, 0, -28901, 0, -8841, 0, -28900, 0, -8840, 0, -28899, 0, -8839, 0, -28898, 0, -8838, 0, -28897, 0, -8837, 0, -28896, 0, -8836, 0, -28895, 0, -8835, 0, -28894, 0, -8834, 0, -28893, 0, -8832, 0, -28892, 0, -8831, 0, -28891, 0, -8830, 0, -28890, 0, -8829, 0, -28889, 0, -8828, 0, -28888, 0, -8827, 0, -28887, 0, -8826, 0, -28886, 0, -8825, 0, -28885, 0, -8824, 0, -28884, 0, -8823, 0, -28883, 0, -8822, 0, -28882, 0, -8821, 0, -28881, 0, -8820, 0, -28880, 0, -8819, 0, -28879, 0, -8818, 0, -28878, 0, -8817, 0, -28877, 0, -8816, 0, -28876, 0, -8815, 0, -28875, 0, -8814, 0, -28874, 0, -8813, 0, -28873, 0, -8812, 0, -28872, 0, -8811, 0, -28871, 0, -8810, 0, -28870, 0, -8809, 0, -28869, 0, -8808, 0, -28868, 0, -8807, 0, -28867, 0, -8806, 0, -28866, 0, -8805, 0, -28865, 0, -8804, 0, -28864, 0, -8803, 0, -28863, 0, -8802, 0, -28862, 0, -8801, 0, -28861, 0, -8800, 0, -28860, 0, -8799, 0, -31896, 0, -8798, 0, -31973, 0, -8797, 0, -31895, 0, -8796, 0, -31892, 0, -8795, 0, -31894, 0, -8794, 0, -31891, 0, -8793, 0, -31890, 0, -8792, 0, -31824, 0, -8791, 0, -31880, 0, -8790, 0, -31821, 0, -8789, 0, -31820, 0, -8788, 0, -31840, 0, -8787, 0, -31830, 0, -8786, 0, -31853, 0, -8785, 0, -31844, 0, -8784, 0, -31867, 0, -8783, 0, -31876, 0, -8782, 0, -31818, 0, -8781, 0, -31831, 0, -8780, 0, -31875, 0, -8779, 0, -31816, 0, -8778, 0, -31877, 0, -8777, 0, -31848, 0, -8776, 0, -31842, 0, -8775, 0, -31832, 0, -8774, 0, -31814, 0, -8773, 0, -31812, 0, -8772, 0, -31807, 0, -8771, 0, -31743, 0, -8770, 0, -31771, 0, -8769, 0, -31784, 0, -8768, 0, 22535, 0, -8767, 0, -31720, 0, -8766, 0, -31733, 0, -8765, 0, -31779, 0, -8764, 0, -31747, 0, -8763, 0, -31786, 0, -8762, 0, -31716, 0, -8761, 0, -31688, 0, -8760, 0, -31727, 0, -8759, 0, -31738, 0, -8758, 0, -31788, 0, -8757, 0, -31777, 0, -8756, 0, -31729, 0, -8755, 0, -31741, 0, -8754, 0, -31752, 0, -8753, 0, -31751, 0, -8752, 0, -31766, 0, -8751, 0, -31803, 0, -8750, 0, -31808, 0, -8749, 0, -31706, 0, -8748, 0, -31760, 0, -8747, 0, -31775, 0, -8746, 0, -31652, 0, -8745, 0, -31663, 0, -8744, 0, -31654, 0, -8743, 0, -31655, 0, -8742, 0, -31629, 0, -8741, 0, -31609, 0, -8740, 0, -31608, 0, -8739, 0, -31622, 0, -8738, 0, -31607, 0, -8737, 0, -31624, 0, -8736, 0, -31684, 0, -8735, 0, -31674, 0, -8734, 0, -31639, 0, -8733, 0, -31626, 0, -8732, 0, -31604, 0, -8731, 0, -31602, 0, -8730, 0, -31695, 0, -8729, 0, -31635, 0, -8728, 0, -31551, 0, -8727, 0, -31539, 0, -8726, 0, -31536, 0, -8725, 0, -31514, 0, -8724, 0, -31555, 0, -8723, 0, -31533, 0, -8722, 0, -31542, 0, -8721, 0, -31553, 0, -8720, 0, -31558, 0, -8719, 0, -31520, 0, -8718, 0, -31583, 0, -8717, 0, -31559, 0, -8716, 0, -31564, 0, -8715, 0, -31593, 0, -8714, 0, -31515, 0, -8713, 0, -31517, 0, -8712, 0, -31476, 0, -8711, 0, 29965, 0, -8710, 0, -31432, 0, -8709, 0, -31504, 0, -8708, 0, -31431, 0, -8707, 0, -31457, 0, -8706, 0, -31430, 0, -8640, 0, -28859, 0, -8639, 0, -28858, 0, -8638, 0, -28857, 0, -8637, 0, -28856, 0, -8636, 0, -28855, 0, -8635, 0, -28854, 0, -8634, 0, -28853, 0, -8633, 0, -28852, 0, -8632, 0, -28851, 0, -8631, 0, -28850, 0, -8630, 0, -28849, 0, -8629, 0, -28848, 0, -8628, 0, -28847, 0, -8627, 0, -28846, 0, -8626, 0, -28845, 0, -8625, 0, -28844, 0, -8624, 0, -28843, 0, -8623, 0, -28842, 0, -8622, 0, -28841, 0, -8621, 0, -28840, 0, -8620, 0, -28839, 0, -8619, 0, -28838, 0, -8618, 0, -28837, 0, -8617, 0, -28836, 0, -8616, 0, -28835, 0, -8615, 0, -28834, 0, -8614, 0, -28833, 0, -8613, 0, -28832, 0, -8612, 0, -28831, 0, -8611, 0, -28830, 0, -8610, 0, -28829, 0, -8609, 0, -28828, 0, -8608, 0, -28827, 0, -8607, 0, -28822, 0, -8606, 0, -28800, 0, -8605, 0, -28788, 0, -8604, 0, -28782, 0, -8603, 0, -28771, 0, -8602, 0, -28768, 0, -8601, 0, -28767, 0, -8600, 0, -28766, 0, -8599, 0, -28764, 0, -8598, 0, -28763, 0, -8597, 0, -28762, 0, -8596, 0, -28761, 0, -8595, 0, -28758, 0, -8594, 0, -28756, 0, -8593, 0, -28755, 0, -8592, 0, -28754, 0, -8591, 0, -28753, 0, -8590, 0, -28750, 0, -8589, 0, -28749, 0, -8588, 0, -28748, 0, -8587, 0, -28747, 0, -8586, 0, -28745, 0, -8585, 0, -28744, 0, -8584, 0, -28742, 0, -8583, 0, -28741, 0, -8582, 0, -28740, 0, -8581, 0, -28737, 0, -8580, 0, -28736, 0, -8579, 0, -28733, 0, -8578, 0, -28730, 0, -8576, 0, -28727, 0, -8575, 0, -28726, 0, -8574, 0, -28725, 0, -8573, 0, -28724, 0, -8572, 0, -28723, 0, -8571, 0, -28721, 0, -8570, 0, -28718, 0, -8569, 0, -28714, 0, -8568, 0, -28713, 0, -8567, 0, -28710, 0, -8566, 0, -28704, 0, -8565, 0, -28703, 0, -8564, 0, -28701, 0, -8563, 0, -28697, 0, -8562, 0, -28692, 0, -8561, 0, -28689, 0, -8560, 0, -28687, 0, -8559, 0, -28686, 0, -8558, 0, -28684, 0, -8557, 0, -28683, 0, -8556, 0, -28682, 0, -8555, 0, -28678, 0, -8554, 0, -28677, 0, -8553, 0, -28676, 0, -8552, 0, -28674, 0, -8551, 0, -28673, 0, -8550, 0, -28665, 0, -8549, 0, -28664, 0, -8548, 0, -28660, 0, -8547, 0, -28658, 0, -8546, 0, -28653, 0, -8545, 0, -28651, 0, -8544, 0, -28648, 0, -8543, 0, -31402, 0, -8542, 0, -31429, 0, -8541, 0, -31489, 0, -8540, 0, -31492, 0, -8539, 0, -31399, 0, -8538, 0, -31416, 0, -8537, 0, -31384, 0, -8536, 0, -31388, 0, -8535, 0, -31394, 0, -8534, 0, -31366, 0, -8533, 0, 30626, 0, -8532, 0, -31421, 0, -8531, 0, -31374, 0, -8530, 0, -31365, 0, -8529, 0, -31324, 0, -8528, 0, -31320, 0, -8527, 0, -31353, 0, -8526, 0, -31345, 0, -8525, 0, -31367, 0, -8524, 0, -31314, 0, -8523, 0, -31332, 0, -8522, 0, -31355, 0, -8521, 0, -31303, 0, -8520, 0, -31305, 0, -8519, 0, -31312, 0, -8518, 0, -31277, 0, -8517, 0, -31295, 0, -8516, 0, -31268, 0, -8515, 0, -31233, 0, -8514, 0, -31193, 0, -8513, 0, -31227, 0, -8512, 0, -31191, 0, -8511, 0, -31210, 0, -8510, 0, -31172, 0, -8509, 0, 24318, 0, -8508, 0, 24328, 0, -8507, 0, 22844, 0, -8506, 0, 22849, 0, -8505, 0, -32713, 0, -8504, 0, 22869, 0, -8503, 0, 22874, 0, -8502, 0, 22872, 0, -8501, 0, 21263, 0, -8500, 0, 23586, 0, -8499, 0, 23589, 0, -8498, 0, 23596, 0, -8497, 0, 23604, 0, -8496, 0, 25164, 0, -8495, 0, 25194, 0, -8494, 0, 25247, 0, -8493, 0, 25275, 0, -8492, 0, 25290, 0, -8491, 0, 25306, 0, -8490, 0, 25303, 0, -8489, 0, 25326, 0, -8488, 0, 25378, 0, -8487, 0, 25334, 0, -8486, 0, 25401, 0, -8485, 0, 25419, 0, -8484, 0, 25411, 0, -8483, 0, 25517, 0, -8482, 0, 25590, 0, -8481, 0, 25457, 0, -8480, 0, 25466, 0, -8479, 0, 25486, 0, -8478, 0, 25524, 0, -8477, 0, 25453, 0, -8476, 0, 25516, 0, -8475, 0, 25482, 0, -8474, 0, 25449, 0, -8473, 0, 25518, 0, -8472, 0, 25532, 0, -8471, 0, 25586, 0, -8470, 0, 25592, 0, -8469, 0, 25568, 0, -8468, 0, 25599, 0, -8467, 0, 25540, 0, -8466, 0, 25566, 0, -8465, 0, 25550, 0, -8464, 0, 25682, 0, -8463, 0, 25542, 0, -8462, 0, 25534, 0, -8461, 0, 25669, 0, -8460, 0, 25665, 0, -8459, 0, 25611, 0, -8458, 0, 25627, 0, -8457, 0, 25632, 0, -8456, 0, 25612, 0, -8455, 0, 25638, 0, -8454, 0, 25633, 0, -8453, 0, 25694, 0, -8452, 0, 25732, 0, -8451, 0, 25709, 0, -8450, 0, 25750, 0, -8384, 0, -28647, 0, -8383, 0, -28644, 0, -8382, 0, -28637, 0, -8381, 0, -28636, 0, -8380, 0, -28635, 0, -8379, 0, -28633, 0, -8378, 0, -28632, 0, -8377, 0, -28631, 0, -8376, 0, -28630, 0, -8375, 0, -28629, 0, -8374, 0, -28628, 0, -8373, 0, -28624, 0, -8372, 0, -28623, 0, -8371, 0, -28622, 0, -8370, 0, -28621, 0, -8369, 0, -28620, 0, -8368, 0, -28617, 0, -8367, 0, -28615, 0, -8366, 0, -28614, 0, -8365, 0, -28611, 0, -8364, 0, -28609, 0, -8363, 0, -28608, 0, -8362, 0, -28605, 0, -8361, 0, -28603, 0, -8360, 0, -28602, 0, -8359, 0, -28600, 0, -8358, 0, -28599, 0, -8357, 0, -28598, 0, -8356, 0, -28597, 0, -8355, 0, -28596, 0, -8354, 0, -28594, 0, -8353, 0, -28588, 0, -8352, 0, -28587, 0, -8351, 0, -28586, 0, -8350, 0, -28583, 0, -8349, 0, -28582, 0, -8348, 0, -28580, 0, -8347, 0, -28579, 0, -8346, 0, -28578, 0, -8345, 0, -28577, 0, -8344, 0, -28576, 0, -8343, 0, -28575, 0, -8342, 0, -28572, 0, -8341, 0, -28570, 0, -8340, 0, -28569, 0, -8339, 0, -28567, 0, -8338, 0, -28566, 0, -8337, 0, -28565, 0, -8336, 0, -28564, 0, -8335, 0, -28561, 0, -8334, 0, -28560, 0, -8333, 0, -28559, 0, -8332, 0, -28558, 0, -8331, 0, -28557, 0, -8330, 0, -28554, 0, -8329, 0, -28553, 0, -8328, 0, -28552, 0, -8327, 0, -28551, 0, -8326, 0, -28550, 0, -8325, 0, -28549, 0, -8324, 0, -28548, 0, -8323, 0, -28546, 0, -8322, 0, -28543, 0, -8320, 0, -28540, 0, -8319, 0, -28539, 0, -8318, 0, -28538, 0, -8317, 0, -28537, 0, -8316, 0, -28535, 0, -8315, 0, -28534, 0, -8314, 0, -28532, 0, -8313, 0, -28531, 0, -8312, 0, -28530, 0, -8311, 0, -28529, 0, -8310, 0, -28528, 0, -8309, 0, -28526, 0, -8308, 0, -28524, 0, -8307, 0, -28522, 0, -8306, 0, -28520, 0, -8305, 0, -28518, 0, -8304, 0, -28516, 0, -8303, 0, -28514, 0, -8302, 0, -28513, 0, -8301, 0, -28512, 0, -8300, 0, -28508, 0, -8299, 0, -28507, 0, -8298, 0, -28505, 0, -8297, 0, -28504, 0, -8296, 0, -28503, 0, -8295, 0, -28501, 0, -8294, 0, -28499, 0, -8293, 0, -28494, 0, -8292, 0, -28489, 0, -8291, 0, -28484, 0, -8290, 0, -28483, 0, -8289, 0, -28481, 0, -8288, 0, -28480, 0, -8287, 0, 25722, 0, -8286, 0, 25783, 0, -8285, 0, 25784, 0, -8284, 0, 25753, 0, -8283, 0, 25786, 0, -8282, 0, 25792, 0, -8281, 0, 25808, 0, -8280, 0, 25815, 0, -8279, 0, 25828, 0, -8278, 0, 25826, 0, -8277, 0, 25865, 0, -8276, 0, 25893, 0, -8275, 0, 25902, 0, -8274, 0, 24331, 0, -8273, 0, 24530, 0, -8272, 0, 29977, 0, -8271, 0, 24337, 0, -8270, 0, 21343, 0, -8269, 0, 21489, 0, -8268, 0, 21501, 0, -8267, 0, 21481, 0, -8266, 0, 21480, 0, -8265, 0, 21499, 0, -8264, 0, 21522, 0, -8263, 0, 21526, 0, -8262, 0, 21510, 0, -8261, 0, 21579, 0, -8260, 0, 21586, 0, -8259, 0, 21587, 0, -8258, 0, 21588, 0, -8257, 0, 21590, 0, -8256, 0, 21571, 0, -8255, 0, 21537, 0, -8254, 0, 21591, 0, -8253, 0, 21593, 0, -8252, 0, 21539, 0, -8251, 0, 21554, 0, -8250, 0, 21634, 0, -8249, 0, 21652, 0, -8248, 0, 21623, 0, -8247, 0, 21617, 0, -8246, 0, 21604, 0, -8245, 0, 21658, 0, -8244, 0, 21659, 0, -8243, 0, 21636, 0, -8242, 0, 21622, 0, -8241, 0, 21606, 0, -8240, 0, 21661, 0, -8239, 0, 21712, 0, -8238, 0, 21677, 0, -8237, 0, 21698, 0, -8236, 0, 21684, 0, -8235, 0, 21714, 0, -8234, 0, 21671, 0, -8233, 0, 21670, 0, -8232, 0, 21715, 0, -8231, 0, 21716, 0, -8230, 0, 21618, 0, -8229, 0, 21667, 0, -8228, 0, 21717, 0, -8227, 0, 21691, 0, -8226, 0, 21695, 0, -8225, 0, 21708, 0, -8224, 0, 21721, 0, -8223, 0, 21722, 0, -8222, 0, 21724, 0, -8221, 0, 21673, 0, -8220, 0, 21674, 0, -8219, 0, 21668, 0, -8218, 0, 21725, 0, -8217, 0, 21711, 0, -8216, 0, 21726, 0, -8215, 0, 21787, 0, -8214, 0, 21735, 0, -8213, 0, 21792, 0, -8212, 0, 21757, 0, -8211, 0, 21780, 0, -8210, 0, 21747, 0, -8209, 0, 21794, 0, -8208, 0, 21795, 0, -8207, 0, 21775, 0, -8206, 0, 21777, 0, -8205, 0, 21799, 0, -8204, 0, 21802, 0, -8203, 0, 21863, 0, -8202, 0, 21903, 0, -8201, 0, 21941, 0, -8200, 0, 21833, 0, -8199, 0, 21869, 0, -8198, 0, 21825, 0, -8197, 0, 21845, 0, -8196, 0, 21823, 0, -8195, 0, 21840, 0, -8194, 0, 21820, 0, -8128, 0, -28478, 0, -8127, 0, -28477, 0, -8126, 0, -28474, 0, -8125, 0, -28472, 0, -8124, 0, -28471, 0, -8123, 0, -28469, 0, -8122, 0, -28468, 0, -8121, 0, -28467, 0, -8120, 0, -28462, 0, -8119, 0, -28460, 0, -8118, 0, -28459, 0, -8117, 0, -28458, 0, -8116, 0, -28456, 0, -8115, 0, -28455, 0, -8114, 0, -28454, 0, -8113, 0, -28450, 0, -8112, 0, -28449, 0, -8111, 0, -28448, 0, -8110, 0, -28445, 0, -8109, 0, -28444, 0, -8108, 0, -28443, 0, -8107, 0, -28439, 0, -8106, 0, -28438, 0, -8105, 0, -28436, 0, -8104, 0, -28434, 0, -8103, 0, -28432, 0, -8102, 0, -28431, 0, -8101, 0, -28430, 0, -8100, 0, -28429, 0, -8099, 0, -28427, 0, -8098, 0, -28426, 0, -8097, 0, -28425, 0, -8096, 0, -28423, 0, -8095, 0, -28422, 0, -8094, 0, -28421, 0, -8093, 0, -28420, 0, -8092, 0, -28417, 0, -8091, 0, -28416, 0, -8090, 0, -28415, 0, -8089, 0, -28413, 0, -8088, 0, -28411, 0, -8087, 0, -28410, 0, -8086, 0, -28409, 0, -8085, 0, -28408, 0, -8084, 0, -28407, 0, -8083, 0, -28406, 0, -8082, 0, -28405, 0, -8081, 0, -28404, 0, -8080, 0, -28403, 0, -8079, 0, -28402, 0, -8078, 0, -28401, 0, -8077, 0, -28400, 0, -8076, 0, -28399, 0, -8075, 0, -28398, 0, -8074, 0, -28397, 0, -8073, 0, -28396, 0, -8072, 0, -28395, 0, -8071, 0, -28394, 0, -8070, 0, -28393, 0, -8069, 0, -28392, 0, -8068, 0, -28390, 0, -8067, 0, -28389, 0, -8066, 0, -28388, 0, -8064, 0, -28387, 0, -8063, 0, -28385, 0, -8062, 0, -28384, 0, -8061, 0, -28383, 0, -8060, 0, -28380, 0, -8059, 0, -28379, 0, -8058, 0, -28378, 0, -8057, 0, -28377, 0, -8056, 0, -28376, 0, -8055, 0, -28375, 0, -8054, 0, -28374, 0, -8053, 0, -28373, 0, -8052, 0, -28372, 0, -8051, 0, -28371, 0, -8050, 0, -28370, 0, -8049, 0, -28368, 0, -8048, 0, -28366, 0, -8047, 0, -28365, 0, -8046, 0, -28364, 0, -8045, 0, -28363, 0, -8044, 0, -28362, 0, -8043, 0, -28361, 0, -8042, 0, -28360, 0, -8041, 0, -28358, 0, -8040, 0, -28357, 0, -8039, 0, -28356, 0, -8038, 0, -28355, 0, -8037, 0, -28354, 0, -8036, 0, -28353, 0, -8035, 0, -28352, 0, -8034, 0, -28351, 0, -8033, 0, -28350, 0, -8032, 0, -28348, 0, -8031, 0, 21815, 0, -8030, 0, 21846, 0, -8029, 0, 21877, 0, -8028, 0, 21878, 0, -8027, 0, 21879, 0, -8026, 0, 21811, 0, -8025, 0, 21808, 0, -8024, 0, 21852, 0, -8023, 0, 21899, 0, -8022, 0, 21970, 0, -8021, 0, 21891, 0, -8020, 0, 21937, 0, -8019, 0, 21945, 0, -8018, 0, 21896, 0, -8017, 0, 21889, 0, -8016, 0, 21919, 0, -8015, 0, 21886, 0, -8014, 0, 21974, 0, -8013, 0, 21905, 0, -8012, 0, 21883, 0, -8011, 0, 21983, 0, -8010, 0, 21949, 0, -8009, 0, 21950, 0, -8008, 0, 21908, 0, -8007, 0, 21913, 0, -8006, 0, 21994, 0, -8005, 0, 22007, 0, -8004, 0, 21961, 0, -8003, 0, 22047, 0, -8002, 0, 21969, 0, -8001, 0, 21995, 0, -8000, 0, 21996, 0, -7999, 0, 21972, 0, -7998, 0, 21990, 0, -7997, 0, 21981, 0, -7996, 0, 21956, 0, -7995, 0, 21999, 0, -7994, 0, 21989, 0, -7993, 0, 22002, 0, -7992, 0, 22003, 0, -7991, 0, 21964, 0, -7990, 0, 21965, 0, -7989, 0, 21992, 0, -7988, 0, 22005, 0, -7987, 0, 21988, 0, -7986, 0, -28780, 0, -7985, 0, 22046, 0, -7984, 0, 22024, 0, -7983, 0, 22028, 0, -7982, 0, 22017, 0, -7981, 0, 22052, 0, -7980, 0, 22051, 0, -7979, 0, 22014, 0, -7978, 0, 22016, 0, -7977, 0, 22055, 0, -7976, 0, 22061, 0, -7975, 0, 22104, 0, -7974, 0, 22073, 0, -7973, 0, 22103, 0, -7972, 0, 22060, 0, -7971, 0, 22093, 0, -7970, 0, 22114, 0, -7969, 0, 22105, 0, -7968, 0, 22108, 0, -7967, 0, 22092, 0, -7966, 0, 22100, 0, -7965, 0, 22150, 0, -7964, 0, 22116, 0, -7963, 0, 22129, 0, -7962, 0, 22123, 0, -7961, 0, 22139, 0, -7960, 0, 22140, 0, -7959, 0, 22149, 0, -7958, 0, 22163, 0, -7957, 0, 22191, 0, -7956, 0, 22228, 0, -7955, 0, 22231, 0, -7954, 0, 22237, 0, -7953, 0, 22241, 0, -7952, 0, 22261, 0, -7951, 0, 22251, 0, -7950, 0, 22265, 0, -7949, 0, 22271, 0, -7948, 0, 22276, 0, -7947, 0, 22282, 0, -7946, 0, 22281, 0, -7945, 0, 22300, 0, -7944, 0, 24079, 0, -7943, 0, 24089, 0, -7942, 0, 24084, 0, -7941, 0, 24081, 0, -7940, 0, 24113, 0, -7939, 0, 24123, 0, -7938, 0, 24124, 0, -7872, 0, -28347, 0, -7871, 0, -28345, 0, -7870, 0, -28344, 0, -7869, 0, -28335, 0, -7868, 0, -28333, 0, -7867, 0, -28332, 0, -7866, 0, -28331, 0, -7865, 0, -28330, 0, -7864, 0, -28328, 0, -7863, 0, -28327, 0, -7862, 0, -28325, 0, -7861, 0, -28324, 0, -7860, 0, -28321, 0, -7859, 0, -28320, 0, -7858, 0, -28314, 0, -7857, 0, -28313, 0, -7856, 0, -28312, 0, -7855, 0, -28309, 0, -7854, 0, -28307, 0, -7853, 0, -28301, 0, -7852, 0, -28294, 0, -7851, 0, -28293, 0, -7850, 0, -28292, 0, -7849, 0, -28288, 0, -7848, 0, -28287, 0, -7847, 0, -28286, 0, -7846, 0, -28285, 0, -7845, 0, -28284, 0, -7844, 0, -28282, 0, -7843, 0, -28280, 0, -7842, 0, -28278, 0, -7841, 0, -28274, 0, -7840, 0, -28273, 0, -7839, 0, -28269, 0, -7838, 0, -28268, 0, -7837, 0, -28267, 0, -7836, 0, -28266, 0, -7835, 0, -28265, 0, -7834, 0, -28264, 0, -7833, 0, -28263, 0, -7832, 0, -28260, 0, -7831, 0, -28259, 0, -7830, 0, -28258, 0, -7829, 0, -28257, 0, -7828, 0, -28256, 0, -7827, 0, -28255, 0, -7826, 0, -28252, 0, -7825, 0, -28251, 0, -7824, 0, -28250, 0, -7823, 0, -28249, 0, -7822, 0, -28248, 0, -7821, 0, -28247, 0, -7820, 0, -28245, 0, -7819, 0, -28244, 0, -7818, 0, -28240, 0, -7817, 0, -28239, 0, -7816, 0, -28238, 0, -7815, 0, -28237, 0, -7814, 0, -28234, 0, -7813, 0, -28233, 0, -7812, 0, -28232, 0, -7811, 0, -28231, 0, -7810, 0, -28229, 0, -7808, 0, -28228, 0, -7807, 0, -28227, 0, -7806, 0, -28226, 0, -7805, 0, -28225, 0, -7804, 0, -28224, 0, -7803, 0, -28223, 0, -7802, 0, -28222, 0, -7801, 0, -28221, 0, -7800, 0, -28220, 0, -7799, 0, -28219, 0, -7798, 0, -28218, 0, -7797, 0, -28216, 0, -7796, 0, -28213, 0, -7795, 0, -28208, 0, -7794, 0, -28206, 0, -7793, 0, -28205, 0, -7792, 0, -28204, 0, -7791, 0, -28203, 0, -7790, 0, -28202, 0, -7789, 0, -28201, 0, -7788, 0, -28200, 0, -7787, 0, -28199, 0, -7786, 0, -28198, 0, -7785, 0, -28197, 0, -7784, 0, -28195, 0, -7783, 0, -28194, 0, -7782, 0, -28193, 0, -7781, 0, -28192, 0, -7780, 0, -28191, 0, -7779, 0, -28190, 0, -7778, 0, -28189, 0, -7777, 0, -28188, 0, -7776, 0, -28187, 0, -7775, 0, 24119, 0, -7774, 0, 24132, 0, -7773, 0, 24148, 0, -7772, 0, 24155, 0, -7771, 0, 24158, 0, -7770, 0, 24161, 0, -7769, 0, 23692, 0, -7768, 0, 23674, 0, -7767, 0, 23693, 0, -7766, 0, 23696, 0, -7765, 0, 23702, 0, -7764, 0, 23688, 0, -7763, 0, 23704, 0, -7762, 0, 23705, 0, -7761, 0, 23697, 0, -7760, 0, 23706, 0, -7759, 0, 23708, 0, -7758, 0, 23733, 0, -7757, 0, 23714, 0, -7756, 0, 23741, 0, -7755, 0, 23724, 0, -7754, 0, 23723, 0, -7753, 0, 23729, 0, -7752, 0, 23715, 0, -7751, 0, 23745, 0, -7750, 0, 23735, 0, -7749, 0, 23748, 0, -7748, 0, 23762, 0, -7747, 0, 23780, 0, -7746, 0, 23755, 0, -7745, 0, 23781, 0, -7744, 0, 23810, 0, -7743, 0, 23811, 0, -7742, 0, 23847, 0, -7741, 0, 23846, 0, -7740, 0, 23854, 0, -7739, 0, 23844, 0, -7738, 0, 23838, 0, -7737, 0, 23814, 0, -7736, 0, 23835, 0, -7735, 0, 23896, 0, -7734, 0, 23870, 0, -7733, 0, 23860, 0, -7732, 0, 23869, 0, -7731, 0, 23916, 0, -7730, 0, 23899, 0, -7729, 0, 23919, 0, -7728, 0, 23901, 0, -7727, 0, 23915, 0, -7726, 0, 23883, 0, -7725, 0, 23882, 0, -7724, 0, 23913, 0, -7723, 0, 23924, 0, -7722, 0, 23938, 0, -7721, 0, 23961, 0, -7720, 0, 23965, 0, -7719, 0, -29581, 0, -7718, 0, 23991, 0, -7717, 0, 24005, 0, -7716, 0, 24435, 0, -7715, 0, 24439, 0, -7714, 0, 24450, 0, -7713, 0, 24455, 0, -7712, 0, 24457, 0, -7711, 0, 24460, 0, -7710, 0, 24469, 0, -7709, 0, 24473, 0, -7708, 0, 24476, 0, -7707, 0, 24488, 0, -7706, 0, 24493, 0, -7705, 0, 24501, 0, -7704, 0, 24508, 0, -7703, 0, -30622, 0, -7702, 0, 24417, 0, -7701, 0, 29357, 0, -7700, 0, 29360, 0, -7699, 0, 29364, 0, -7698, 0, 29367, 0, -7697, 0, 29368, 0, -7696, 0, 29379, 0, -7695, 0, 29377, 0, -7694, 0, 29390, 0, -7693, 0, 29389, 0, -7692, 0, 29394, 0, -7691, 0, 29416, 0, -7690, 0, 29423, 0, -7689, 0, 29417, 0, -7688, 0, 29426, 0, -7687, 0, 29428, 0, -7686, 0, 29431, 0, -7685, 0, 29441, 0, -7684, 0, 29427, 0, -7683, 0, 29443, 0, -7682, 0, 29434, 0, -7616, 0, -28186, 0, -7615, 0, -28185, 0, -7614, 0, -28184, 0, -7613, 0, -28183, 0, -7612, 0, -28182, 0, -7611, 0, -28181, 0, -7610, 0, -28180, 0, -7609, 0, -28179, 0, -7608, 0, -28178, 0, -7607, 0, -28177, 0, -7606, 0, -28176, 0, -7605, 0, -28175, 0, -7604, 0, -28174, 0, -7603, 0, -28173, 0, -7602, 0, -28172, 0, -7601, 0, -28171, 0, -7600, 0, -28170, 0, -7599, 0, -28169, 0, -7598, 0, -28168, 0, -7597, 0, -28167, 0, -7596, 0, -28166, 0, -7595, 0, -28165, 0, -7594, 0, -28164, 0, -7593, 0, -28163, 0, -7592, 0, -28162, 0, -7591, 0, -28161, 0, -7590, 0, -28160, 0, -7589, 0, -28159, 0, -7588, 0, -28158, 0, -7587, 0, -28157, 0, -7586, 0, -28156, 0, -7585, 0, -28155, 0, -7584, 0, -28154, 0, -7583, 0, -28153, 0, -7582, 0, -28152, 0, -7581, 0, -28151, 0, -7580, 0, -28150, 0, -7579, 0, -28149, 0, -7578, 0, -28148, 0, -7577, 0, -28147, 0, -7576, 0, -28146, 0, -7575, 0, -28145, 0, -7574, 0, -28144, 0, -7573, 0, -28143, 0, -7572, 0, -28142, 0, -7571, 0, -28141, 0, -7570, 0, -28140, 0, -7569, 0, -28139, 0, -7568, 0, -28138, 0, -7567, 0, -28137, 0, -7566, 0, -28136, 0, -7565, 0, -28135, 0, -7564, 0, -28134, 0, -7563, 0, -28133, 0, -7562, 0, -28132, 0, -7561, 0, -28131, 0, -7560, 0, -28130, 0, -7559, 0, -28129, 0, -7558, 0, -28128, 0, -7557, 0, -28127, 0, -7556, 0, -28126, 0, -7555, 0, -28125, 0, -7554, 0, -28124, 0, -7552, 0, -28123, 0, -7551, 0, -28122, 0, -7550, 0, -28121, 0, -7549, 0, -28120, 0, -7548, 0, -28119, 0, -7547, 0, -28118, 0, -7546, 0, -28117, 0, -7545, 0, -28116, 0, -7544, 0, -28115, 0, -7543, 0, -28114, 0, -7542, 0, -28113, 0, -7541, 0, -28112, 0, -7540, 0, -28111, 0, -7539, 0, -28110, 0, -7538, 0, -28109, 0, -7537, 0, -28108, 0, -7536, 0, -28107, 0, -7535, 0, -28106, 0, -7534, 0, -28105, 0, -7533, 0, -28104, 0, -7532, 0, -28103, 0, -7531, 0, -28102, 0, -7530, 0, -28101, 0, -7529, 0, -28100, 0, -7528, 0, -28099, 0, -7527, 0, -28098, 0, -7526, 0, -28097, 0, -7525, 0, -28096, 0, -7524, 0, -28095, 0, -7523, 0, -28094, 0, -7522, 0, -28093, 0, -7521, 0, -28092, 0, -7520, 0, -28091, 0, -7519, 0, 29435, 0, -7518, 0, 29463, 0, -7517, 0, 29459, 0, -7516, 0, 29473, 0, -7515, 0, 29450, 0, -7514, 0, 29470, 0, -7513, 0, 29469, 0, -7512, 0, 29461, 0, -7511, 0, 29474, 0, -7510, 0, 29497, 0, -7509, 0, 29477, 0, -7508, 0, 29484, 0, -7507, 0, 29496, 0, -7506, 0, 29489, 0, -7505, 0, 29520, 0, -7504, 0, 29517, 0, -7503, 0, 29527, 0, -7502, 0, 29536, 0, -7501, 0, 29548, 0, -7500, 0, 29551, 0, -7499, 0, 29566, 0, -7498, 0, -32229, 0, -7497, 0, 22821, 0, -7496, 0, -26393, 0, -7495, 0, 22820, 0, -7494, 0, 22786, 0, -7493, 0, -26269, 0, -7492, 0, -26265, 0, -7491, 0, -26264, 0, -7490, 0, -26263, 0, -7489, 0, -26262, 0, -7488, 0, -26261, 0, -7487, 0, -26260, 0, -7486, 0, -26252, 0, -7485, 0, -26249, 0, -7484, 0, -26243, 0, -7483, 0, -26240, 0, -7482, 0, -26236, 0, -7481, 0, -26233, 0, -7480, 0, -26230, 0, -7479, 0, -26227, 0, -7478, 0, -26224, 0, -7477, 0, -26223, 0, -7476, 0, -26221, 0, -7475, 0, -26220, 0, -7474, 0, -26219, 0, -7473, 0, 24192, 0, -7472, 0, 24209, 0, -7471, 0, 24203, 0, -7470, 0, 24214, 0, -7469, 0, 24229, 0, -7468, 0, 24224, 0, -7467, 0, 24249, 0, -7466, 0, 24245, 0, -7465, 0, 24254, 0, -7464, 0, 24243, 0, -7463, 0, -29357, 0, -7462, 0, 24274, 0, -7461, 0, 24273, 0, -7460, 0, 24283, 0, -7459, 0, 24296, 0, -7458, 0, 24298, 0, -7457, 0, -32326, 0, -7456, 0, 24516, 0, -7455, 0, 24521, 0, -7454, 0, 24534, 0, -7453, 0, 24527, 0, -7452, 0, 24579, 0, -7451, 0, 24558, 0, -7450, 0, 24580, 0, -7449, 0, 24545, 0, -7448, 0, 24548, 0, -7447, 0, 24574, 0, -7446, 0, 24581, 0, -7445, 0, 24582, 0, -7444, 0, 24554, 0, -7443, 0, 24557, 0, -7442, 0, 24568, 0, -7441, 0, 24601, 0, -7440, 0, 24629, 0, -7439, 0, 24614, 0, -7438, 0, 24603, 0, -7437, 0, 24591, 0, -7436, 0, 24589, 0, -7435, 0, 24617, 0, -7434, 0, 24619, 0, -7433, 0, 24586, 0, -7432, 0, 24639, 0, -7431, 0, 24609, 0, -7430, 0, 24696, 0, -7429, 0, 24697, 0, -7428, 0, 24699, 0, -7427, 0, 24698, 0, -7426, 0, 24642, 0, -7360, 0, -28090, 0, -7359, 0, -28089, 0, -7358, 0, -28088, 0, -7357, 0, -28087, 0, -7356, 0, -28086, 0, -7355, 0, -28085, 0, -7354, 0, -28084, 0, -7353, 0, -28083, 0, -7352, 0, -28082, 0, -7351, 0, -28081, 0, -7350, 0, -28080, 0, -7349, 0, -28079, 0, -7348, 0, -28078, 0, -7347, 0, -28077, 0, -7346, 0, -28076, 0, -7345, 0, -28075, 0, -7344, 0, -28074, 0, -7343, 0, -28073, 0, -7342, 0, -28072, 0, -7341, 0, -28071, 0, -7340, 0, -28070, 0, -7339, 0, -28069, 0, -7338, 0, -28068, 0, -7337, 0, -28067, 0, -7336, 0, -28066, 0, -7335, 0, -28065, 0, -7334, 0, -28064, 0, -7333, 0, -28063, 0, -7332, 0, -28062, 0, -7331, 0, -28061, 0, -7330, 0, -28060, 0, -7329, 0, -28059, 0, -7328, 0, -28058, 0, -7327, 0, -28057, 0, -7326, 0, -28056, 0, -7325, 0, -28055, 0, -7324, 0, -28054, 0, -7323, 0, -28053, 0, -7322, 0, -28052, 0, -7321, 0, -28051, 0, -7320, 0, -28050, 0, -7319, 0, -28049, 0, -7318, 0, -28048, 0, -7317, 0, -28047, 0, -7316, 0, -28046, 0, -7315, 0, -28045, 0, -7314, 0, -28043, 0, -7313, 0, -28042, 0, -7312, 0, -28041, 0, -7311, 0, -28040, 0, -7310, 0, -28039, 0, -7309, 0, -28038, 0, -7308, 0, -28037, 0, -7307, 0, -28036, 0, -7306, 0, -28035, 0, -7305, 0, -28034, 0, -7304, 0, -28033, 0, -7303, 0, -28032, 0, -7302, 0, -28031, 0, -7301, 0, -28030, 0, -7300, 0, -28029, 0, -7299, 0, -28028, 0, -7298, 0, -28027, 0, -7296, 0, -28026, 0, -7295, 0, -28025, 0, -7294, 0, -28024, 0, -7293, 0, -28023, 0, -7292, 0, -28022, 0, -7291, 0, -28021, 0, -7290, 0, -28020, 0, -7289, 0, -28019, 0, -7288, 0, -28017, 0, -7287, 0, -28016, 0, -7286, 0, -28015, 0, -7285, 0, -28014, 0, -7284, 0, -28013, 0, -7283, 0, -28012, 0, -7282, 0, -28011, 0, -7281, 0, -28010, 0, -7280, 0, -28009, 0, -7279, 0, -28008, 0, -7278, 0, -28007, 0, -7277, 0, -28006, 0, -7276, 0, -28005, 0, -7275, 0, -28004, 0, -7274, 0, -28003, 0, -7273, 0, -28002, 0, -7272, 0, -28001, 0, -7271, 0, -28000, 0, -7270, 0, -27999, 0, -7269, 0, -27998, 0, -7268, 0, -27997, 0, -7267, 0, -27996, 0, -7266, 0, -27995, 0, -7265, 0, -27994, 0, -7264, 0, -27993, 0, -7263, 0, 24682, 0, -7262, 0, 24701, 0, -7261, 0, 24726, 0, -7260, 0, 24730, 0, -7259, 0, 24749, 0, -7258, 0, 24733, 0, -7257, 0, 24707, 0, -7256, 0, 24722, 0, -7255, 0, 24716, 0, -7254, 0, 24731, 0, -7253, 0, 24812, 0, -7252, 0, 24763, 0, -7251, 0, 24753, 0, -7250, 0, 24797, 0, -7249, 0, 24792, 0, -7248, 0, 24774, 0, -7247, 0, 24794, 0, -7246, 0, 24756, 0, -7245, 0, 24864, 0, -7244, 0, 24870, 0, -7243, 0, 24853, 0, -7242, 0, 24867, 0, -7241, 0, 24820, 0, -7240, 0, 24832, 0, -7239, 0, 24846, 0, -7238, 0, 24875, 0, -7237, 0, 24906, 0, -7236, 0, 24949, 0, -7235, 0, 25004, 0, -7234, 0, 24980, 0, -7233, 0, 24999, 0, -7232, 0, 25015, 0, -7231, 0, 25044, 0, -7230, 0, 25077, 0, -7229, 0, 24541, 0, -7228, 0, -26957, 0, -7227, 0, -27159, 0, -7226, 0, -27157, 0, -7225, 0, -27151, 0, -7224, 0, -27149, 0, -7223, 0, -27147, 0, -7222, 0, -27146, 0, -7221, 0, -27140, 0, -7220, 0, -27138, 0, -7219, 0, -27133, 0, -7218, 0, -27132, 0, -7217, 0, -27130, 0, -7216, 0, -27128, 0, -7215, 0, -27126, 0, -7214, 0, -27125, 0, -7213, 0, -27124, 0, -7212, 0, -27123, 0, -7211, 0, -27121, 0, -7210, 0, -27118, 0, -7209, 0, -27115, 0, -7208, 0, -27114, 0, -7207, 0, -27113, 0, -7206, 0, -27111, 0, -7205, 0, -27110, 0, -7204, 0, 20012, 0, -7203, 0, 29247, 0, -7202, 0, 25109, 0, -7201, 0, 27701, 0, -7200, 0, 27732, 0, -7199, 0, 27740, 0, -7198, 0, 27722, 0, -7197, 0, 27811, 0, -7196, 0, 27781, 0, -7195, 0, 27792, 0, -7194, 0, 27796, 0, -7193, 0, 27788, 0, -7192, 0, 27752, 0, -7191, 0, 27753, 0, -7190, 0, 27764, 0, -7189, 0, 27766, 0, -7188, 0, 27782, 0, -7187, 0, 27817, 0, -7186, 0, 27856, 0, -7185, 0, 27860, 0, -7184, 0, 27821, 0, -7183, 0, 27895, 0, -7182, 0, 27896, 0, -7181, 0, 27889, 0, -7180, 0, 27863, 0, -7179, 0, 27826, 0, -7178, 0, 27872, 0, -7177, 0, 27862, 0, -7176, 0, 27898, 0, -7175, 0, 27883, 0, -7174, 0, 27886, 0, -7173, 0, 27825, 0, -7172, 0, 27859, 0, -7171, 0, 27887, 0, -7170, 0, 27902, 0, -7104, 0, -27992, 0, -7103, 0, -27991, 0, -7102, 0, -27990, 0, -7101, 0, -27989, 0, -7100, 0, -27988, 0, -7099, 0, -27987, 0, -7098, 0, -27985, 0, -7097, 0, -27984, 0, -7096, 0, -27983, 0, -7095, 0, -27982, 0, -7094, 0, -27981, 0, -7093, 0, -27980, 0, -7092, 0, -27979, 0, -7091, 0, -27978, 0, -7090, 0, -27977, 0, -7089, 0, -27976, 0, -7088, 0, -27975, 0, -7087, 0, -27974, 0, -7086, 0, -27973, 0, -7085, 0, -27972, 0, -7084, 0, -27971, 0, -7083, 0, -27970, 0, -7082, 0, -27969, 0, -7081, 0, -27968, 0, -7080, 0, -27967, 0, -7079, 0, -27966, 0, -7078, 0, -27965, 0, -7077, 0, -27964, 0, -7076, 0, -27963, 0, -7075, 0, -27962, 0, -7074, 0, -27961, 0, -7073, 0, -27959, 0, -7072, 0, -27958, 0, -7071, 0, -27957, 0, -7070, 0, -27956, 0, -7069, 0, -27955, 0, -7068, 0, -27954, 0, -7067, 0, -27953, 0, -7066, 0, -27952, 0, -7065, 0, -27951, 0, -7064, 0, -27950, 0, -7063, 0, -27949, 0, -7062, 0, -27948, 0, -7061, 0, -27947, 0, -7060, 0, -27946, 0, -7059, 0, -27945, 0, -7058, 0, -27944, 0, -7057, 0, -27943, 0, -7056, 0, -27942, 0, -7055, 0, -27941, 0, -7054, 0, -27940, 0, -7053, 0, -27939, 0, -7052, 0, -27938, 0, -7051, 0, -27937, 0, -7050, 0, -27936, 0, -7049, 0, -27935, 0, -7048, 0, -27934, 0, -7047, 0, -27933, 0, -7046, 0, -27932, 0, -7045, 0, -27931, 0, -7044, 0, -27930, 0, -7043, 0, -27929, 0, -7042, 0, -27928, 0, -7040, 0, -27927, 0, -7039, 0, -27926, 0, -7038, 0, -27925, 0, -7037, 0, -27924, 0, -7036, 0, -27923, 0, -7035, 0, -27922, 0, -7034, 0, -27921, 0, -7033, 0, -27920, 0, -7032, 0, -27919, 0, -7031, 0, -27918, 0, -7030, 0, -27917, 0, -7029, 0, -27916, 0, -7028, 0, -27915, 0, -7027, 0, -27914, 0, -7026, 0, -27913, 0, -7025, 0, -27912, 0, -7024, 0, -27911, 0, -7023, 0, -27910, 0, -7022, 0, -27909, 0, -7021, 0, -27908, 0, -7020, 0, -27907, 0, -7019, 0, -27906, 0, -7018, 0, -27905, 0, -7017, 0, -27904, 0, -7016, 0, -27903, 0, -7015, 0, -27902, 0, -7014, 0, -27901, 0, -7013, 0, -27900, 0, -7012, 0, -27899, 0, -7011, 0, -27898, 0, -7010, 0, -27897, 0, -7009, 0, -27896, 0, -7008, 0, -27895, 0, -7007, 0, 27961, 0, -7006, 0, 27943, 0, -7005, 0, 27916, 0, -7004, 0, 27971, 0, -7003, 0, 27976, 0, -7002, 0, 27911, 0, -7001, 0, 27908, 0, -7000, 0, 27929, 0, -6999, 0, 27918, 0, -6998, 0, 27947, 0, -6997, 0, 27981, 0, -6996, 0, 27950, 0, -6995, 0, 27957, 0, -6994, 0, 27930, 0, -6993, 0, 27983, 0, -6992, 0, 27986, 0, -6991, 0, 27988, 0, -6990, 0, 27955, 0, -6989, 0, 28049, 0, -6988, 0, 28015, 0, -6987, 0, 28062, 0, -6986, 0, 28064, 0, -6985, 0, 27998, 0, -6984, 0, 28051, 0, -6983, 0, 28052, 0, -6982, 0, 27996, 0, -6981, 0, 28000, 0, -6980, 0, 28028, 0, -6979, 0, 28003, 0, -6978, 0, 28186, 0, -6977, 0, 28103, 0, -6976, 0, 28101, 0, -6975, 0, 28126, 0, -6974, 0, 28174, 0, -6973, 0, 28095, 0, -6972, 0, 28128, 0, -6971, 0, 28177, 0, -6970, 0, 28134, 0, -6969, 0, 28125, 0, -6968, 0, 28121, 0, -6967, 0, 28182, 0, -6966, 0, 28075, 0, -6965, 0, 28172, 0, -6964, 0, 28078, 0, -6963, 0, 28203, 0, -6962, 0, 28270, 0, -6961, 0, 28238, 0, -6960, 0, 28267, 0, -6959, 0, 28338, 0, -6958, 0, 28255, 0, -6957, 0, 28294, 0, -6956, 0, 28243, 0, -6955, 0, 28244, 0, -6954, 0, 28210, 0, -6953, 0, 28197, 0, -6952, 0, 28228, 0, -6951, 0, 28383, 0, -6950, 0, 28337, 0, -6949, 0, 28312, 0, -6948, 0, 28384, 0, -6947, 0, 28461, 0, -6946, 0, 28386, 0, -6945, 0, 28325, 0, -6944, 0, 28327, 0, -6943, 0, 28349, 0, -6942, 0, 28347, 0, -6941, 0, 28343, 0, -6940, 0, 28375, 0, -6939, 0, 28340, 0, -6938, 0, 28367, 0, -6937, 0, 28303, 0, -6936, 0, 28354, 0, -6935, 0, 28319, 0, -6934, 0, 28514, 0, -6933, 0, 28486, 0, -6932, 0, 28487, 0, -6931, 0, 28452, 0, -6930, 0, 28437, 0, -6929, 0, 28409, 0, -6928, 0, 28463, 0, -6927, 0, 28470, 0, -6926, 0, 28491, 0, -6925, 0, 28532, 0, -6924, 0, 28458, 0, -6923, 0, 28425, 0, -6922, 0, 28457, 0, -6921, 0, 28553, 0, -6920, 0, 28557, 0, -6919, 0, 28556, 0, -6918, 0, 28536, 0, -6917, 0, 28530, 0, -6916, 0, 28540, 0, -6915, 0, 28538, 0, -6914, 0, 28625, 0, -6848, 0, -27894, 0, -6847, 0, -27893, 0, -6846, 0, -27892, 0, -6845, 0, -27891, 0, -6844, 0, -27890, 0, -6843, 0, -27889, 0, -6842, 0, -27888, 0, -6841, 0, -27887, 0, -6840, 0, -27886, 0, -6839, 0, -27885, 0, -6838, 0, -27884, 0, -6837, 0, -27883, 0, -6836, 0, -27882, 0, -6835, 0, -27881, 0, -6834, 0, -27880, 0, -6833, 0, -27879, 0, -6832, 0, -27878, 0, -6831, 0, -27877, 0, -6830, 0, -27876, 0, -6829, 0, -27875, 0, -6828, 0, -27874, 0, -6827, 0, -27873, 0, -6826, 0, -27872, 0, -6825, 0, -27871, 0, -6824, 0, -27870, 0, -6823, 0, -27869, 0, -6822, 0, -27868, 0, -6821, 0, -27867, 0, -6820, 0, -27866, 0, -6819, 0, -27865, 0, -6818, 0, -27864, 0, -6817, 0, -27863, 0, -6816, 0, -27862, 0, -6815, 0, -27861, 0, -6814, 0, -27860, 0, -6813, 0, -27859, 0, -6812, 0, -27858, 0, -6811, 0, -27857, 0, -6810, 0, -27856, 0, -6809, 0, -27855, 0, -6808, 0, -27854, 0, -6807, 0, -27853, 0, -6806, 0, -27852, 0, -6805, 0, -27851, 0, -6804, 0, -27850, 0, -6803, 0, -27849, 0, -6802, 0, -27848, 0, -6801, 0, -27847, 0, -6800, 0, -27846, 0, -6799, 0, -27845, 0, -6798, 0, -27844, 0, -6797, 0, -27843, 0, -6796, 0, -27841, 0, -6795, 0, -27840, 0, -6794, 0, -27839, 0, -6793, 0, -27838, 0, -6792, 0, -27837, 0, -6791, 0, -27836, 0, -6790, 0, -27835, 0, -6789, 0, -27834, 0, -6788, 0, -27833, 0, -6787, 0, -27832, 0, -6786, 0, -27831, 0, -6784, 0, -27830, 0, -6783, 0, -27829, 0, -6782, 0, -27828, 0, -6781, 0, -27827, 0, -6780, 0, -27826, 0, -6779, 0, -27825, 0, -6778, 0, -27824, 0, -6777, 0, -27823, 0, -6776, 0, -27822, 0, -6775, 0, -27821, 0, -6774, 0, -27820, 0, -6773, 0, -27819, 0, -6772, 0, -27818, 0, -6771, 0, -27817, 0, -6770, 0, -27816, 0, -6769, 0, -27815, 0, -6768, 0, -27814, 0, -6767, 0, -27813, 0, -6766, 0, -27812, 0, -6765, 0, -27811, 0, -6764, 0, -27810, 0, -6763, 0, -27809, 0, -6762, 0, -27808, 0, -6761, 0, -27807, 0, -6760, 0, -27806, 0, -6759, 0, -27805, 0, -6758, 0, -27804, 0, -6757, 0, -27803, 0, -6756, 0, -27802, 0, -6755, 0, -27801, 0, -6754, 0, -27800, 0, -6753, 0, -27799, 0, -6752, 0, -27797, 0, -6751, 0, 28617, 0, -6750, 0, 28583, 0, -6749, 0, 28601, 0, -6748, 0, 28598, 0, -6747, 0, 28610, 0, -6746, 0, 28641, 0, -6745, 0, 28654, 0, -6744, 0, 28638, 0, -6743, 0, 28640, 0, -6742, 0, 28655, 0, -6741, 0, 28698, 0, -6740, 0, 28707, 0, -6739, 0, 28699, 0, -6738, 0, 28729, 0, -6737, 0, 28725, 0, -6736, 0, 28751, 0, -6735, 0, 28766, 0, -6734, 0, 23424, 0, -6733, 0, 23428, 0, -6732, 0, 23445, 0, -6731, 0, 23443, 0, -6730, 0, 23461, 0, -6729, 0, 23480, 0, -6728, 0, 29999, 0, -6727, 0, -25954, 0, -6726, 0, 25652, 0, -6725, 0, 23524, 0, -6724, 0, 23534, 0, -6723, 0, -30416, 0, -6722, 0, 23536, 0, -6721, 0, -29113, 0, -6720, 0, -29945, 0, -6719, 0, -28746, 0, -6718, 0, -28717, 0, -6717, 0, -28715, 0, -6716, 0, -28699, 0, -6715, 0, -28690, 0, -6714, 0, -28700, 0, -6713, 0, -28695, 0, -6712, 0, -28698, 0, -6711, 0, -28685, 0, -6710, 0, -28696, 0, -6709, 0, -28667, 0, -6708, 0, -28668, 0, -6707, 0, -28661, 0, -6706, 0, -28634, 0, -6705, 0, -28655, 0, -6704, 0, -28659, 0, -6703, 0, -28650, 0, -6702, 0, -28639, 0, -6701, 0, -28619, 0, -6700, 0, -28618, 0, -6699, 0, -28627, 0, -6698, 0, -28625, 0, -6697, 0, -28604, 0, -6696, 0, -28591, 0, -6695, 0, -28590, 0, -6694, 0, -28592, 0, -6693, 0, -28568, 0, -6692, 0, -28584, 0, -6691, 0, -28574, 0, -6690, 0, -28581, 0, -6689, 0, 26297, 0, -6688, 0, -28556, 0, -6687, 0, -28547, 0, -6686, 0, -28542, 0, -6685, 0, -28536, 0, -6684, 0, -28541, 0, -6683, 0, -28533, 0, -6682, 0, 24400, 0, -6681, 0, 24407, 0, -6680, 0, 24406, 0, -6679, 0, 24408, 0, -6678, 0, 23611, 0, -6677, 0, 21675, 0, -6676, 0, 23632, 0, -6675, 0, 23641, 0, -6674, 0, 23409, 0, -6673, 0, 23651, 0, -6672, 0, 23654, 0, -6671, 0, 32700, 0, -6670, 0, 24362, 0, -6669, 0, 24361, 0, -6668, 0, 24365, 0, -6667, 0, -32140, 0, -6666, 0, 24380, 0, -6665, 0, -25797, 0, -6664, 0, 23662, 0, -6663, 0, 22913, 0, -6662, 0, 22915, 0, -6661, 0, 22925, 0, -6660, 0, 22953, 0, -6659, 0, 22954, 0, -6658, 0, 22947, 0, -6592, 0, -27796, 0, -6591, 0, -27795, 0, -6590, 0, -27794, 0, -6589, 0, -27793, 0, -6588, 0, -27792, 0, -6587, 0, -27791, 0, -6586, 0, -27790, 0, -6585, 0, -27789, 0, -6584, 0, -27788, 0, -6583, 0, -27787, 0, -6582, 0, -27786, 0, -6581, 0, -27785, 0, -6580, 0, -27784, 0, -6579, 0, -27783, 0, -6578, 0, -27782, 0, -6577, 0, -27781, 0, -6576, 0, -27780, 0, -6575, 0, -27779, 0, -6574, 0, -27778, 0, -6573, 0, -27777, 0, -6572, 0, -27776, 0, -6571, 0, -27775, 0, -6570, 0, -27774, 0, -6569, 0, -27773, 0, -6568, 0, -27772, 0, -6567, 0, -27771, 0, -6566, 0, -27770, 0, -6565, 0, -27769, 0, -6564, 0, -27768, 0, -6563, 0, -27767, 0, -6562, 0, -27766, 0, -6561, 0, -27765, 0, -6560, 0, -27764, 0, -6559, 0, -27763, 0, -6558, 0, -27762, 0, -6557, 0, -27760, 0, -6556, 0, -27759, 0, -6555, 0, -27758, 0, -6554, 0, -27757, 0, -6553, 0, -27756, 0, -6552, 0, -27755, 0, -6551, 0, -27754, 0, -6550, 0, -27753, 0, -6549, 0, -27752, 0, -6548, 0, -27751, 0, -6547, 0, -27750, 0, -6546, 0, -27749, 0, -6545, 0, -27748, 0, -6544, 0, -27747, 0, -6543, 0, -27746, 0, -6542, 0, -27745, 0, -6541, 0, -27744, 0, -6540, 0, -27743, 0, -6539, 0, -27742, 0, -6538, 0, -27741, 0, -6537, 0, -27740, 0, -6536, 0, -27739, 0, -6535, 0, -27738, 0, -6534, 0, -27737, 0, -6533, 0, -27736, 0, -6532, 0, -27735, 0, -6531, 0, -27734, 0, -6530, 0, -27733, 0, -6528, 0, -27732, 0, -6527, 0, -27731, 0, -6526, 0, -27730, 0, -6525, 0, -27729, 0, -6524, 0, -27728, 0, -6523, 0, -27727, 0, -6522, 0, -27726, 0, -6521, 0, -27725, 0, -6520, 0, -27724, 0, -6519, 0, -27723, 0, -6518, 0, -27722, 0, -6517, 0, -27721, 0, -6516, 0, -27720, 0, -6515, 0, -27719, 0, -6514, 0, -27718, 0, -6513, 0, -27717, 0, -6512, 0, -27716, 0, -6511, 0, -27715, 0, -6510, 0, -27714, 0, -6509, 0, -27713, 0, -6508, 0, -27712, 0, -6507, 0, -27711, 0, -6506, 0, -27710, 0, -6505, 0, -27709, 0, -6504, 0, -27708, 0, -6503, 0, -27707, 0, -6502, 0, -27706, 0, -6501, 0, -27705, 0, -6500, 0, -27704, 0, -6499, 0, -27703, 0, -6498, 0, -27701, 0, -6497, 0, -27700, 0, -6496, 0, -27699, 0, -6495, 0, 22935, 0, -6494, 0, 22986, 0, -6493, 0, 22955, 0, -6492, 0, 22942, 0, -6491, 0, 22948, 0, -6490, 0, 22994, 0, -6489, 0, 22962, 0, -6488, 0, 22959, 0, -6487, 0, 22999, 0, -6486, 0, 22974, 0, -6485, 0, 23045, 0, -6484, 0, 23046, 0, -6483, 0, 23005, 0, -6482, 0, 23048, 0, -6481, 0, 23011, 0, -6480, 0, 23000, 0, -6479, 0, 23033, 0, -6478, 0, 23052, 0, -6477, 0, 23049, 0, -6476, 0, 23090, 0, -6475, 0, 23092, 0, -6474, 0, 23057, 0, -6473, 0, 23075, 0, -6472, 0, 23059, 0, -6471, 0, 23104, 0, -6470, 0, 23143, 0, -6469, 0, 23114, 0, -6468, 0, 23125, 0, -6467, 0, 23100, 0, -6466, 0, 23138, 0, -6465, 0, 23157, 0, -6464, 0, -32532, 0, -6463, 0, 23210, 0, -6462, 0, 23195, 0, -6461, 0, 23159, 0, -6460, 0, 23162, 0, -6459, 0, 23230, 0, -6458, 0, 23275, 0, -6457, 0, 23218, 0, -6456, 0, 23250, 0, -6455, 0, 23252, 0, -6454, 0, 23224, 0, -6453, 0, 23264, 0, -6452, 0, 23267, 0, -6451, 0, 23281, 0, -6450, 0, 23254, 0, -6449, 0, 23270, 0, -6448, 0, 23256, 0, -6447, 0, 23260, 0, -6446, 0, 23305, 0, -6445, 0, 23319, 0, -6444, 0, 23318, 0, -6443, 0, 23346, 0, -6442, 0, 23351, 0, -6441, 0, 23360, 0, -6440, 0, 23573, 0, -6439, 0, 23580, 0, -6438, 0, 23386, 0, -6437, 0, 23397, 0, -6436, 0, 23411, 0, -6435, 0, 23377, 0, -6434, 0, 23379, 0, -6433, 0, 23394, 0, -6432, 0, -25995, 0, -6431, 0, -25993, 0, -6430, 0, -25992, 0, -6429, 0, -25990, 0, -6428, 0, -25985, 0, -6427, 0, -25987, 0, -6426, 0, -25984, 0, -6425, 0, -25983, 0, -6424, 0, -25979, 0, -6423, 0, -25976, 0, -6422, 0, -25974, 0, -6421, 0, -25968, 0, -6420, 0, -25966, 0, -6419, 0, -25965, 0, -6418, 0, -25962, 0, -6417, 0, -25960, 0, -6416, 0, -25957, 0, -6415, 0, -25956, 0, -6414, 0, -25955, 0, -6413, 0, -25953, 0, -6412, 0, -25952, 0, -6411, 0, -25950, 0, -6410, 0, -25949, 0, -6409, 0, -25947, 0, -6408, 0, -25945, 0, -6407, 0, 32415, 0, -6406, 0, 32417, 0, -6405, 0, 32419, 0, -6404, 0, 32421, 0, -6403, 0, 32424, 0, -6402, 0, 32425, 0, -6336, 0, -27698, 0, -6335, 0, -27697, 0, -6334, 0, -27696, 0, -6333, 0, -27695, 0, -6332, 0, -27694, 0, -6331, 0, -27693, 0, -6330, 0, -27692, 0, -6329, 0, -27691, 0, -6328, 0, -27689, 0, -6327, 0, -27688, 0, -6326, 0, -27687, 0, -6325, 0, -27686, 0, -6324, 0, -27685, 0, -6323, 0, -27684, 0, -6322, 0, -27683, 0, -6321, 0, -27682, 0, -6320, 0, -27681, 0, -6319, 0, -27680, 0, -6318, 0, -27679, 0, -6317, 0, -27678, 0, -6316, 0, -27677, 0, -6315, 0, -27676, 0, -6314, 0, -27675, 0, -6313, 0, -27674, 0, -6312, 0, -27673, 0, -6311, 0, -27672, 0, -6310, 0, -27671, 0, -6309, 0, -27670, 0, -6308, 0, -27669, 0, -6307, 0, -27668, 0, -6306, 0, -27667, 0, -6305, 0, -27666, 0, -6304, 0, -27665, 0, -6303, 0, -27664, 0, -6302, 0, -27663, 0, -6301, 0, -27662, 0, -6300, 0, -27661, 0, -6299, 0, -27660, 0, -6298, 0, -27659, 0, -6297, 0, -27658, 0, -6296, 0, -27657, 0, -6295, 0, -27656, 0, -6294, 0, -27655, 0, -6293, 0, -27654, 0, -6292, 0, -27653, 0, -6291, 0, -27652, 0, -6290, 0, -27651, 0, -6289, 0, -27650, 0, -6288, 0, -27649, 0, -6287, 0, -27648, 0, -6286, 0, -27647, 0, -6285, 0, -27646, 0, -6284, 0, -27645, 0, -6283, 0, -27644, 0, -6282, 0, -27643, 0, -6281, 0, -27642, 0, -6280, 0, -27641, 0, -6279, 0, -27640, 0, -6278, 0, -27639, 0, -6277, 0, -27638, 0, -6276, 0, -27637, 0, -6275, 0, -27636, 0, -6274, 0, -27635, 0, -6272, 0, -27634, 0, -6271, 0, -27633, 0, -6270, 0, -27632, 0, -6269, 0, -27631, 0, -6268, 0, -27630, 0, -6267, 0, -27629, 0, -6266, 0, -27628, 0, -6265, 0, -27627, 0, -6264, 0, -27626, 0, -6263, 0, -27625, 0, -6262, 0, -27624, 0, -6261, 0, -27623, 0, -6260, 0, -27622, 0, -6259, 0, -27621, 0, -6258, 0, -27620, 0, -6257, 0, -27619, 0, -6256, 0, -27618, 0, -6255, 0, -27617, 0, -6254, 0, -27616, 0, -6253, 0, -27615, 0, -6252, 0, -27614, 0, -6251, 0, -27613, 0, -6250, 0, -27612, 0, -6249, 0, -27611, 0, -6248, 0, -27610, 0, -6247, 0, -27609, 0, -6246, 0, -27608, 0, -6245, 0, -27607, 0, -6244, 0, -27606, 0, -6243, 0, -27605, 0, -6242, 0, -27604, 0, -6241, 0, -27603, 0, -6240, 0, -27602, 0, -6239, 0, 32429, 0, -6238, 0, 32432, 0, -6237, 0, 32446, 0, -6236, 0, 32448, 0, -6235, 0, 32449, 0, -6234, 0, 32450, 0, -6233, 0, 32457, 0, -6232, 0, 32459, 0, -6231, 0, 32460, 0, -6230, 0, 32464, 0, -6229, 0, 32468, 0, -6228, 0, 32471, 0, -6227, 0, 32475, 0, -6226, 0, 32480, 0, -6225, 0, 32481, 0, -6224, 0, 32488, 0, -6223, 0, 32491, 0, -6222, 0, 32494, 0, -6221, 0, 32495, 0, -6220, 0, 32497, 0, -6219, 0, 32498, 0, -6218, 0, 32525, 0, -6217, 0, 32502, 0, -6216, 0, 32506, 0, -6215, 0, 32507, 0, -6214, 0, 32510, 0, -6213, 0, 32513, 0, -6212, 0, 32514, 0, -6211, 0, 32515, 0, -6210, 0, 32519, 0, -6209, 0, 32520, 0, -6208, 0, 32523, 0, -6207, 0, 32524, 0, -6206, 0, 32527, 0, -6205, 0, 32529, 0, -6204, 0, 32530, 0, -6203, 0, 32535, 0, -6202, 0, 32537, 0, -6201, 0, 32540, 0, -6200, 0, 32539, 0, -6199, 0, 32543, 0, -6198, 0, 32545, 0, -6197, 0, 32546, 0, -6196, 0, 32547, 0, -6195, 0, 32548, 0, -6194, 0, 32549, 0, -6193, 0, 32550, 0, -6192, 0, 32551, 0, -6191, 0, 32554, 0, -6190, 0, 32555, 0, -6189, 0, 32556, 0, -6188, 0, 32557, 0, -6187, 0, 32559, 0, -6186, 0, 32560, 0, -6185, 0, 32561, 0, -6184, 0, 32562, 0, -6183, 0, 32563, 0, -6182, 0, 32565, 0, -6181, 0, 24186, 0, -6180, 0, 30079, 0, -6179, 0, 24027, 0, -6178, 0, 30014, 0, -6177, 0, -28523, 0, -6176, 0, 29582, 0, -6175, 0, 29585, 0, -6174, 0, 29614, 0, -6173, 0, 29602, 0, -6172, 0, 29599, 0, -6171, 0, 29647, 0, -6170, 0, 29634, 0, -6169, 0, 29649, 0, -6168, 0, 29623, 0, -6167, 0, 29619, 0, -6166, 0, 29632, 0, -6165, 0, 29641, 0, -6164, 0, 29640, 0, -6163, 0, 29669, 0, -6162, 0, 29657, 0, -6161, 0, -26500, 0, -6160, 0, 29706, 0, -6159, 0, 29673, 0, -6158, 0, 29671, 0, -6157, 0, 29662, 0, -6156, 0, 29626, 0, -6155, 0, 29682, 0, -6154, 0, 29711, 0, -6153, 0, 29738, 0, -6152, 0, 29787, 0, -6151, 0, 29734, 0, -6150, 0, 29733, 0, -6149, 0, 29736, 0, -6148, 0, 29744, 0, -6147, 0, 29742, 0, -6146, 0, 29740, 0, -6080, 0, -27601, 0, -6079, 0, -27600, 0, -6078, 0, -27599, 0, -6077, 0, -27598, 0, -6076, 0, -27597, 0, -6075, 0, -27596, 0, -6074, 0, -27595, 0, -6073, 0, -27594, 0, -6072, 0, -27593, 0, -6071, 0, -27592, 0, -6070, 0, -27591, 0, -6069, 0, -27590, 0, -6068, 0, -27589, 0, -6067, 0, -27588, 0, -6066, 0, -27587, 0, -6065, 0, -27585, 0, -6064, 0, -27584, 0, -6063, 0, -27583, 0, -6062, 0, -27582, 0, -6061, 0, -27581, 0, -6060, 0, -27580, 0, -6059, 0, -27579, 0, -6058, 0, -27578, 0, -6057, 0, -27577, 0, -6056, 0, -27576, 0, -6055, 0, -27575, 0, -6054, 0, -27574, 0, -6053, 0, -27573, 0, -6052, 0, -27572, 0, -6051, 0, -27571, 0, -6050, 0, -27570, 0, -6049, 0, -27569, 0, -6048, 0, -27568, 0, -6047, 0, -27567, 0, -6046, 0, -27566, 0, -6045, 0, -27565, 0, -6044, 0, -27564, 0, -6043, 0, -27563, 0, -6042, 0, -27562, 0, -6041, 0, -27561, 0, -6040, 0, -27560, 0, -6039, 0, -27559, 0, -6038, 0, -27558, 0, -6037, 0, -27557, 0, -6036, 0, -27556, 0, -6035, 0, -27555, 0, -6034, 0, -27554, 0, -6033, 0, -27553, 0, -6032, 0, -27552, 0, -6031, 0, -27551, 0, -6030, 0, -27550, 0, -6029, 0, -27549, 0, -6028, 0, -27548, 0, -6027, 0, -27547, 0, -6026, 0, -27546, 0, -6025, 0, -27545, 0, -6024, 0, -27544, 0, -6023, 0, -27543, 0, -6022, 0, -27542, 0, -6021, 0, -27540, 0, -6020, 0, -27539, 0, -6019, 0, -27538, 0, -6018, 0, -27537, 0, -6016, 0, -27536, 0, -6015, 0, -27535, 0, -6014, 0, -27534, 0, -6013, 0, -27533, 0, -6012, 0, -27532, 0, -6011, 0, -27531, 0, -6010, 0, -27530, 0, -6009, 0, -27529, 0, -6008, 0, -27528, 0, -6007, 0, -27527, 0, -6006, 0, -27526, 0, -6005, 0, -27525, 0, -6004, 0, -27524, 0, -6003, 0, -27523, 0, -6002, 0, -27522, 0, -6001, 0, -27521, 0, -6000, 0, -27520, 0, -5999, 0, -27519, 0, -5998, 0, -27518, 0, -5997, 0, -27517, 0, -5996, 0, -27516, 0, -5995, 0, -27503, 0, -5994, 0, -27498, 0, -5993, 0, -27496, 0, -5992, 0, -27449, 0, -5991, 0, -27441, 0, -5990, 0, -27437, 0, -5989, 0, -27436, 0, -5988, 0, -27430, 0, -5987, 0, -27418, 0, -5986, 0, -27397, 0, -5985, 0, -27364, 0, -5984, 0, -27360, 0, -5983, 0, 29723, 0, -5982, 0, 29722, 0, -5981, 0, 29761, 0, -5980, 0, 29788, 0, -5979, 0, 29783, 0, -5978, 0, 29781, 0, -5977, 0, 29785, 0, -5976, 0, 29815, 0, -5975, 0, 29805, 0, -5974, 0, 29822, 0, -5973, 0, 29852, 0, -5972, 0, 29838, 0, -5971, 0, 29824, 0, -5970, 0, 29825, 0, -5969, 0, 29831, 0, -5968, 0, 29835, 0, -5967, 0, 29854, 0, -5966, 0, 29864, 0, -5965, 0, 29865, 0, -5964, 0, 29840, 0, -5963, 0, 29863, 0, -5962, 0, 29906, 0, -5961, 0, 29882, 0, -5960, 0, -26646, 0, -5959, 0, -26645, 0, -5958, 0, -26644, 0, -5957, 0, 26444, 0, -5956, 0, 26451, 0, -5955, 0, 26462, 0, -5954, 0, 26440, 0, -5953, 0, 26473, 0, -5952, 0, 26533, 0, -5951, 0, 26503, 0, -5950, 0, 26474, 0, -5949, 0, 26483, 0, -5948, 0, 26520, 0, -5947, 0, 26535, 0, -5946, 0, 26485, 0, -5945, 0, 26536, 0, -5944, 0, 26526, 0, -5943, 0, 26541, 0, -5942, 0, 26507, 0, -5941, 0, 26487, 0, -5940, 0, 26492, 0, -5939, 0, 26608, 0, -5938, 0, 26633, 0, -5937, 0, 26584, 0, -5936, 0, 26634, 0, -5935, 0, 26601, 0, -5934, 0, 26544, 0, -5933, 0, 26636, 0, -5932, 0, 26585, 0, -5931, 0, 26549, 0, -5930, 0, 26586, 0, -5929, 0, 26547, 0, -5928, 0, 26589, 0, -5927, 0, 26624, 0, -5926, 0, 26563, 0, -5925, 0, 26552, 0, -5924, 0, 26594, 0, -5923, 0, 26638, 0, -5922, 0, 26561, 0, -5921, 0, 26621, 0, -5920, 0, 26674, 0, -5919, 0, 26675, 0, -5918, 0, 26720, 0, -5917, 0, 26721, 0, -5916, 0, 26702, 0, -5915, 0, 26722, 0, -5914, 0, 26692, 0, -5913, 0, 26724, 0, -5912, 0, 26755, 0, -5911, 0, 26653, 0, -5910, 0, 26709, 0, -5909, 0, 26726, 0, -5908, 0, 26689, 0, -5907, 0, 26727, 0, -5906, 0, 26688, 0, -5905, 0, 26686, 0, -5904, 0, 26698, 0, -5903, 0, 26697, 0, -5902, 0, 26665, 0, -5901, 0, 26805, 0, -5900, 0, 26767, 0, -5899, 0, 26740, 0, -5898, 0, 26743, 0, -5897, 0, 26771, 0, -5896, 0, 26731, 0, -5895, 0, 26818, 0, -5894, 0, 26990, 0, -5893, 0, 26876, 0, -5892, 0, 26911, 0, -5891, 0, 26912, 0, -5890, 0, 26873, 0, -5824, 0, -27353, 0, -5823, 0, -27341, 0, -5822, 0, -27331, 0, -5821, 0, -27325, 0, -5820, 0, -27320, 0, -5819, 0, -27317, 0, -5818, 0, -27307, 0, -5817, 0, -27302, 0, -5816, 0, -27296, 0, -5815, 0, -27282, 0, -5814, 0, -27276, 0, -5813, 0, -27275, 0, -5812, 0, -27273, 0, -5811, 0, -27272, 0, -5810, 0, -27271, 0, -5809, 0, -27270, 0, -5808, 0, -27269, 0, -5807, 0, -27268, 0, -5806, 0, -27267, 0, -5805, 0, -27266, 0, -5804, 0, -27264, 0, -5803, 0, -27263, 0, -5802, 0, -27262, 0, -5801, 0, -27261, 0, -5800, 0, -27260, 0, -5799, 0, -27259, 0, -5798, 0, -27258, 0, -5797, 0, -27257, 0, -5796, 0, -27256, 0, -5795, 0, -27255, 0, -5794, 0, -27254, 0, -5793, 0, -27253, 0, -5792, 0, -27252, 0, -5791, 0, -27251, 0, -5790, 0, -27250, 0, -5789, 0, -27249, 0, -5788, 0, -27248, 0, -5787, 0, -27247, 0, -5786, 0, -27246, 0, -5785, 0, -27245, 0, -5784, 0, -27244, 0, -5783, 0, -27243, 0, -5782, 0, -27242, 0, -5781, 0, -27241, 0, -5780, 0, -27240, 0, -5779, 0, -27239, 0, -5778, 0, -27238, 0, -5777, 0, -27237, 0, -5776, 0, -27236, 0, -5775, 0, -27235, 0, -5774, 0, -27234, 0, -5773, 0, -27233, 0, -5772, 0, -27232, 0, -5771, 0, -27231, 0, -5770, 0, -27230, 0, -5769, 0, -27229, 0, -5768, 0, -27228, 0, -5767, 0, -27227, 0, -5766, 0, -27226, 0, -5765, 0, -27225, 0, -5764, 0, -27224, 0, -5763, 0, -27223, 0, -5762, 0, -27222, 0, -5760, 0, -27221, 0, -5759, 0, -27220, 0, -5758, 0, -27219, 0, -5757, 0, -27218, 0, -5756, 0, -27217, 0, -5755, 0, -27216, 0, -5754, 0, -27215, 0, -5753, 0, -27214, 0, -5752, 0, -27213, 0, -5751, 0, -27212, 0, -5750, 0, -27211, 0, -5749, 0, -27210, 0, -5748, 0, -27209, 0, -5747, 0, -27208, 0, -5746, 0, -27207, 0, -5745, 0, -27206, 0, -5744, 0, -27205, 0, -5743, 0, -27204, 0, -5742, 0, -27203, 0, -5741, 0, -27202, 0, -5740, 0, -27201, 0, -5739, 0, -27200, 0, -5738, 0, -27199, 0, -5737, 0, -27198, 0, -5736, 0, -27197, 0, -5735, 0, -27196, 0, -5734, 0, -27195, 0, -5733, 0, -27194, 0, -5732, 0, -27193, 0, -5731, 0, -27192, 0, -5730, 0, -27191, 0, -5729, 0, -27190, 0, -5728, 0, -27189, 0, -5727, 0, 26916, 0, -5726, 0, 26864, 0, -5725, 0, 26891, 0, -5724, 0, 26881, 0, -5723, 0, 26967, 0, -5722, 0, 26851, 0, -5721, 0, 26896, 0, -5720, 0, 26993, 0, -5719, 0, 26937, 0, -5718, 0, 26976, 0, -5717, 0, 26946, 0, -5716, 0, 26973, 0, -5715, 0, 27012, 0, -5714, 0, 26987, 0, -5713, 0, 27008, 0, -5712, 0, 27032, 0, -5711, 0, 27000, 0, -5710, 0, 26932, 0, -5709, 0, 27084, 0, -5708, 0, 27015, 0, -5707, 0, 27016, 0, -5706, 0, 27086, 0, -5705, 0, 27017, 0, -5704, 0, 26982, 0, -5703, 0, 26979, 0, -5702, 0, 27001, 0, -5701, 0, 27035, 0, -5700, 0, 27047, 0, -5699, 0, 27067, 0, -5698, 0, 27051, 0, -5697, 0, 27053, 0, -5696, 0, 27092, 0, -5695, 0, 27057, 0, -5694, 0, 27073, 0, -5693, 0, 27082, 0, -5692, 0, 27103, 0, -5691, 0, 27029, 0, -5690, 0, 27104, 0, -5689, 0, 27021, 0, -5688, 0, 27135, 0, -5687, 0, 27183, 0, -5686, 0, 27117, 0, -5685, 0, 27159, 0, -5684, 0, 27160, 0, -5683, 0, 27237, 0, -5682, 0, 27122, 0, -5681, 0, 27204, 0, -5680, 0, 27198, 0, -5679, 0, 27296, 0, -5678, 0, 27216, 0, -5677, 0, 27227, 0, -5676, 0, 27189, 0, -5675, 0, 27278, 0, -5674, 0, 27257, 0, -5673, 0, 27197, 0, -5672, 0, 27176, 0, -5671, 0, 27224, 0, -5670, 0, 27260, 0, -5669, 0, 27281, 0, -5668, 0, 27280, 0, -5667, 0, 27305, 0, -5666, 0, 27287, 0, -5665, 0, 27307, 0, -5664, 0, 29495, 0, -5663, 0, 29522, 0, -5662, 0, 27521, 0, -5661, 0, 27522, 0, -5660, 0, 27527, 0, -5659, 0, 27524, 0, -5658, 0, 27538, 0, -5657, 0, 27539, 0, -5656, 0, 27533, 0, -5655, 0, 27546, 0, -5654, 0, 27547, 0, -5653, 0, 27553, 0, -5652, 0, 27562, 0, -5651, 0, -28821, 0, -5650, 0, -28819, 0, -5649, 0, -28815, 0, -5648, 0, -28814, 0, -5647, 0, -28813, 0, -5646, 0, -28811, 0, -5645, 0, -28810, 0, -5644, 0, -28808, 0, -5643, 0, -28809, 0, -5642, 0, -28807, 0, -5641, 0, -28806, 0, -5640, 0, -28804, 0, -5639, 0, -28802, 0, -5638, 0, -28799, 0, -5637, 0, -28798, 0, -5636, 0, -28796, 0, -5635, 0, -28793, 0, -5634, 0, -28789, 0, -5568, 0, -27188, 0, -5567, 0, -27187, 0, -5566, 0, -27186, 0, -5565, 0, -27185, 0, -5564, 0, -27184, 0, -5563, 0, -27183, 0, -5562, 0, -27182, 0, -5561, 0, -27181, 0, -5560, 0, -27180, 0, -5559, 0, -27179, 0, -5558, 0, -27178, 0, -5557, 0, -27177, 0, -5556, 0, -27176, 0, -5555, 0, -27175, 0, -5554, 0, -27174, 0, -5553, 0, -27173, 0, -5552, 0, -27172, 0, -5551, 0, -27171, 0, -5550, 0, -27170, 0, -5549, 0, -27169, 0, -5548, 0, -27168, 0, -5547, 0, -27167, 0, -5546, 0, -27166, 0, -5545, 0, -27165, 0, -5544, 0, -27164, 0, -5543, 0, -27163, 0, -5542, 0, -27162, 0, -5541, 0, -27161, 0, -5540, 0, -27156, 0, -5539, 0, -27137, 0, -5538, 0, -27129, 0, -5537, 0, -27117, 0, -5536, 0, -27112, 0, -5535, 0, -27109, 0, -5534, 0, -27106, 0, -5533, 0, -27104, 0, -5532, 0, -27101, 0, -5531, 0, -27100, 0, -5530, 0, -27099, 0, -5529, 0, -27098, 0, -5528, 0, -27097, 0, -5527, 0, -27096, 0, -5526, 0, -27095, 0, -5525, 0, -27093, 0, -5524, 0, -27092, 0, -5523, 0, -27091, 0, -5522, 0, -27089, 0, -5521, 0, -27088, 0, -5520, 0, -27081, 0, -5519, 0, -27080, 0, -5518, 0, -27079, 0, -5517, 0, -27078, 0, -5516, 0, -27074, 0, -5515, 0, -27071, 0, -5514, 0, -27069, 0, -5513, 0, -27062, 0, -5512, 0, -27058, 0, -5511, 0, -27057, 0, -5510, 0, -27055, 0, -5509, 0, -27054, 0, -5508, 0, -27053, 0, -5507, 0, -27050, 0, -5506, 0, -27049, 0, -5504, 0, -27048, 0, -5503, 0, -27047, 0, -5502, 0, -27046, 0, -5501, 0, -27044, 0, -5500, 0, -27043, 0, -5499, 0, -27042, 0, -5498, 0, -27040, 0, -5497, 0, -27037, 0, -5496, 0, -27035, 0, -5495, 0, -27034, 0, -5494, 0, -27029, 0, -5493, 0, -27027, 0, -5492, 0, -27026, 0, -5491, 0, -27025, 0, -5490, 0, -27024, 0, -5489, 0, -27023, 0, -5488, 0, -27021, 0, -5487, 0, -27016, 0, -5486, 0, -27015, 0, -5485, 0, -27014, 0, -5484, 0, -27013, 0, -5483, 0, -27012, 0, -5482, 0, -27011, 0, -5481, 0, -27010, 0, -5480, 0, -27009, 0, -5479, 0, -27008, 0, -5478, 0, -27007, 0, -5477, 0, -27006, 0, -5476, 0, -27005, 0, -5475, 0, -27004, 0, -5474, 0, -27001, 0, -5473, 0, -26999, 0, -5472, 0, -26998, 0, -5471, 0, -28787, 0, -5470, 0, -28786, 0, -5469, 0, -28785, 0, -5468, 0, -28776, 0, -5467, 0, -28774, 0, -5466, 0, -28978, 0, -5465, 0, 25099, 0, -5464, 0, 25111, 0, -5463, 0, 25115, 0, -5462, 0, 25119, 0, -5461, 0, 25122, 0, -5460, 0, 25121, 0, -5459, 0, 25125, 0, -5458, 0, 25124, 0, -5457, 0, 25132, 0, -5456, 0, -32281, 0, -5455, 0, 29935, 0, -5454, 0, 29940, 0, -5453, 0, 29951, 0, -5452, 0, 29967, 0, -5451, 0, 29969, 0, -5450, 0, 29971, 0, -5449, 0, 25908, 0, -5448, 0, 26094, 0, -5447, 0, 26095, 0, -5446, 0, 26096, 0, -5445, 0, 26122, 0, -5444, 0, 26137, 0, -5443, 0, 26482, 0, -5442, 0, 26115, 0, -5441, 0, 26133, 0, -5440, 0, 26112, 0, -5439, 0, 28805, 0, -5438, 0, 26359, 0, -5437, 0, 26141, 0, -5436, 0, 26164, 0, -5435, 0, 26161, 0, -5434, 0, 26166, 0, -5433, 0, 26165, 0, -5432, 0, -32762, 0, -5431, 0, 26207, 0, -5430, 0, 26196, 0, -5429, 0, 26177, 0, -5428, 0, 26191, 0, -5427, 0, 26198, 0, -5426, 0, 26209, 0, -5425, 0, 26199, 0, -5424, 0, 26231, 0, -5423, 0, 26244, 0, -5422, 0, 26252, 0, -5421, 0, 26279, 0, -5420, 0, 26269, 0, -5419, 0, 26302, 0, -5418, 0, 26331, 0, -5417, 0, 26332, 0, -5416, 0, 26342, 0, -5415, 0, 26345, 0, -5414, 0, -29390, 0, -5413, 0, -29389, 0, -5412, 0, -29386, 0, -5411, 0, -29381, 0, -5410, 0, -29379, 0, -5409, 0, -29376, 0, -5408, 0, -29371, 0, -5407, 0, -29370, 0, -5406, 0, -29368, 0, -5405, 0, -29367, 0, -5404, 0, -29369, 0, -5403, 0, -29363, 0, -5402, 0, -29355, 0, -5401, 0, -29351, 0, -5400, 0, -30265, 0, -5399, 0, -30262, 0, -5398, 0, -30261, 0, -5397, 0, -30260, 0, -5396, 0, -30258, 0, -5395, 0, -30257, 0, -5394, 0, -30256, 0, -5393, 0, -30255, 0, -5392, 0, 29294, 0, -5391, 0, 29343, 0, -5390, 0, 29277, 0, -5389, 0, 29286, 0, -5388, 0, 29295, 0, -5387, 0, 29310, 0, -5386, 0, 29311, 0, -5385, 0, 29316, 0, -5384, 0, 29323, 0, -5383, 0, 29325, 0, -5382, 0, 29327, 0, -5381, 0, 29330, 0, -5380, 0, 25352, 0, -5379, 0, 25394, 0, -5378, 0, 25520, 0, -5312, 0, -26996, 0, -5311, 0, -26994, 0, -5310, 0, -26991, 0, -5309, 0, -26990, 0, -5308, 0, -26989, 0, -5307, 0, -26987, 0, -5306, 0, -26986, 0, -5305, 0, -26982, 0, -5304, 0, -26981, 0, -5303, 0, -26979, 0, -5302, 0, -26978, 0, -5301, 0, -26977, 0, -5300, 0, -26976, 0, -5299, 0, -26975, 0, -5298, 0, -26974, 0, -5297, 0, -26973, 0, -5296, 0, -26972, 0, -5295, 0, -26971, 0, -5294, 0, -26970, 0, -5293, 0, -26968, 0, -5292, 0, -26967, 0, -5291, 0, -26966, 0, -5290, 0, -26965, 0, -5289, 0, -26964, 0, -5288, 0, -26963, 0, -5287, 0, -26962, 0, -5286, 0, -26961, 0, -5285, 0, -26959, 0, -5284, 0, -26958, 0, -5283, 0, -26956, 0, -5282, 0, -26955, 0, -5281, 0, -26953, 0, -5280, 0, -26952, 0, -5279, 0, -26950, 0, -5278, 0, -26949, 0, -5277, 0, -26945, 0, -5276, 0, -26942, 0, -5275, 0, -26941, 0, -5274, 0, -26936, 0, -5273, 0, -26934, 0, -5272, 0, -26933, 0, -5271, 0, -26928, 0, -5270, 0, -26927, 0, -5269, 0, -26925, 0, -5268, 0, -26924, 0, -5267, 0, -26922, 0, -5266, 0, -26921, 0, -5265, 0, -26920, 0, -5264, 0, -26919, 0, -5263, 0, -26918, 0, -5262, 0, -26917, 0, -5261, 0, -26916, 0, -5260, 0, -26915, 0, -5259, 0, -26914, 0, -5258, 0, -26913, 0, -5257, 0, -26911, 0, -5256, 0, -26910, 0, -5255, 0, -26909, 0, -5254, 0, -26908, 0, -5253, 0, -26907, 0, -5252, 0, -26906, 0, -5251, 0, -26905, 0, -5250, 0, -26901, 0, -5248, 0, -26900, 0, -5247, 0, -26899, 0, -5246, 0, -26898, 0, -5245, 0, -26896, 0, -5244, 0, -26895, 0, -5243, 0, -26894, 0, -5242, 0, -26892, 0, -5241, 0, -26891, 0, -5240, 0, -26888, 0, -5239, 0, -26886, 0, -5238, 0, -26885, 0, -5237, 0, -26884, 0, -5236, 0, -26883, 0, -5235, 0, -26881, 0, -5234, 0, -26878, 0, -5233, 0, -26877, 0, -5232, 0, -26875, 0, -5231, 0, -26870, 0, -5230, 0, -26869, 0, -5229, 0, -26868, 0, -5228, 0, -26864, 0, -5227, 0, -26863, 0, -5226, 0, -26862, 0, -5225, 0, -26860, 0, -5224, 0, -26859, 0, -5223, 0, -26857, 0, -5222, 0, -26856, 0, -5221, 0, -26855, 0, -5220, 0, -26854, 0, -5219, 0, -26853, 0, -5218, 0, -26851, 0, -5217, 0, -26849, 0, -5216, 0, -26848, 0, -5215, 0, 25663, 0, -5214, 0, 25816, 0, -5213, 0, -32764, 0, -5212, 0, 27626, 0, -5211, 0, 27635, 0, -5210, 0, 27645, 0, -5209, 0, 27637, 0, -5208, 0, 27641, 0, -5207, 0, 27653, 0, -5206, 0, 27655, 0, -5205, 0, 27654, 0, -5204, 0, 27661, 0, -5203, 0, 27669, 0, -5202, 0, 27672, 0, -5201, 0, 27673, 0, -5200, 0, 27674, 0, -5199, 0, 27681, 0, -5198, 0, 27689, 0, -5197, 0, 27684, 0, -5196, 0, 27690, 0, -5195, 0, 27698, 0, -5194, 0, 25909, 0, -5193, 0, 25941, 0, -5192, 0, 25963, 0, -5191, 0, 29261, 0, -5190, 0, 29266, 0, -5189, 0, 29270, 0, -5188, 0, 29232, 0, -5187, 0, -31134, 0, -5186, 0, 21014, 0, -5185, 0, -32609, 0, -5184, 0, -32612, 0, -5183, 0, -32621, 0, -5182, 0, -32580, 0, -5181, 0, 26378, 0, -5180, 0, -32579, 0, -5179, 0, -32591, 0, -5178, 0, -32597, 0, -5177, 0, -32595, 0, -5176, 0, -32588, 0, -5175, 0, -32585, 0, -5174, 0, -32537, 0, -5173, 0, -32536, 0, -5172, 0, -32535, 0, -5171, 0, -32534, 0, -5170, 0, -32549, 0, -5169, 0, -32574, 0, -5168, 0, -32572, 0, -5167, 0, -32551, 0, -5166, 0, -32563, 0, -5165, 0, -32553, 0, -5164, 0, 26384, 0, -5163, 0, -32547, 0, -5162, 0, -32533, 0, -5161, 0, -32527, 0, -5160, 0, -32524, 0, -5159, 0, -32531, 0, -5158, 0, -32499, 0, -5157, 0, -32498, 0, -5156, 0, -32526, 0, -5155, 0, -32516, 0, -5154, 0, 26389, 0, -5153, 0, -32494, 0, -5152, 0, -29606, 0, -5151, 0, -32458, 0, -5150, 0, -32482, 0, -5149, 0, -32468, 0, -5148, 0, -32488, 0, -5147, 0, -32462, 0, -5146, 0, -32440, 0, -5145, 0, -32436, 0, -5144, 0, -32429, 0, -5143, 0, -32396, 0, -5142, 0, -32423, 0, -5141, 0, -32422, 0, -5140, 0, -32399, 0, -5139, 0, -32416, 0, -5138, 0, -32407, 0, -5137, 0, -32388, 0, -5136, 0, -32387, 0, -5135, 0, -32403, 0, -5134, 0, -32409, 0, -5133, 0, 22605, 0, -5132, 0, 23221, 0, -5131, 0, -32376, 0, -5130, 0, -32382, 0, -5129, 0, -32367, 0, -5128, 0, 28373, 0, -5127, 0, -32349, 0, -5126, 0, -32342, 0, -5125, 0, -32308, 0, -5124, 0, 26406, 0, -5123, 0, -32310, 0, -5122, 0, -32325, 0, -5056, 0, -26847, 0, -5055, 0, -26846, 0, -5054, 0, -26845, 0, -5053, 0, -26844, 0, -5052, 0, -26843, 0, -5051, 0, -26842, 0, -5050, 0, -26841, 0, -5049, 0, -26840, 0, -5048, 0, -26839, 0, -5047, 0, -26837, 0, -5046, 0, -26836, 0, -5045, 0, -26834, 0, -5044, 0, -26833, 0, -5043, 0, -26831, 0, -5042, 0, -26829, 0, -5041, 0, -26828, 0, -5040, 0, -26827, 0, -5039, 0, -26826, 0, -5038, 0, -26825, 0, -5037, 0, -26822, 0, -5036, 0, -26821, 0, -5035, 0, -26820, 0, -5034, 0, -26819, 0, -5033, 0, -26817, 0, -5032, 0, -26816, 0, -5031, 0, -26815, 0, -5030, 0, -26814, 0, -5029, 0, -26813, 0, -5028, 0, -26812, 0, -5027, 0, -26811, 0, -5026, 0, -26810, 0, -5025, 0, -26809, 0, -5024, 0, -26808, 0, -5023, 0, -26807, 0, -5022, 0, -26806, 0, -5021, 0, -26805, 0, -5020, 0, -26804, 0, -5019, 0, -26803, 0, -5018, 0, -26802, 0, -5017, 0, -26801, 0, -5016, 0, -26800, 0, -5015, 0, -26799, 0, -5014, 0, -26796, 0, -5013, 0, -26795, 0, -5012, 0, -26793, 0, -5011, 0, -26792, 0, -5010, 0, -26790, 0, -5009, 0, -26788, 0, -5008, 0, -26787, 0, -5007, 0, -26785, 0, -5006, 0, -26781, 0, -5005, 0, -26780, 0, -5004, 0, -26778, 0, -5003, 0, -26777, 0, -5002, 0, -26776, 0, -5001, 0, -26774, 0, -5000, 0, -26773, 0, -4999, 0, -26772, 0, -4998, 0, -26771, 0, -4997, 0, -26770, 0, -4996, 0, -26769, 0, -4995, 0, -26768, 0, -4994, 0, -26767, 0, -4992, 0, -26766, 0, -4991, 0, -26763, 0, -4990, 0, -26761, 0, -4989, 0, -26760, 0, -4988, 0, -26759, 0, -4987, 0, -26758, 0, -4986, 0, -26757, 0, -4985, 0, -26755, 0, -4984, 0, -26754, 0, -4983, 0, -26753, 0, -4982, 0, -26752, 0, -4981, 0, -26751, 0, -4980, 0, -26750, 0, -4979, 0, -26749, 0, -4978, 0, -26748, 0, -4977, 0, -26746, 0, -4976, 0, -26745, 0, -4975, 0, -26744, 0, -4974, 0, -26743, 0, -4973, 0, -26742, 0, -4972, 0, -26740, 0, -4971, 0, -26738, 0, -4970, 0, -26737, 0, -4969, 0, -26736, 0, -4968, 0, -26733, 0, -4967, 0, -26731, 0, -4966, 0, -26730, 0, -4965, 0, -26729, 0, -4964, 0, -26727, 0, -4963, 0, -26726, 0, -4962, 0, -26725, 0, -4961, 0, -26724, 0, -4960, 0, -26723, 0, -4959, 0, -32319, 0, -4958, 0, -32346, 0, -4957, 0, 27428, 0, -4956, 0, 27447, 0, -4955, 0, 27449, 0, -4954, 0, 27459, 0, -4953, 0, 27462, 0, -4952, 0, 27481, 0, -4951, 0, -26415, 0, -4950, 0, -26414, 0, -4949, 0, -26413, 0, -4948, 0, -26411, 0, -4947, 0, -26407, 0, -4946, 0, -26406, 0, -4945, 0, 27571, 0, -4944, 0, 24384, 0, -4943, 0, 27586, 0, -4942, 0, -30221, 0, -4941, 0, 26000, 0, -4940, 0, -24751, 0, -4939, 0, 26003, 0, -4938, 0, 26044, 0, -4937, 0, 26054, 0, -4936, 0, 26052, 0, -4935, 0, 26051, 0, -4934, 0, 26060, 0, -4933, 0, 26062, 0, -4932, 0, 26066, 0, -4931, 0, 26070, 0, -4930, 0, 28800, 0, -4929, 0, 28828, 0, -4928, 0, 28822, 0, -4927, 0, 28829, 0, -4926, 0, 28859, 0, -4925, 0, 28864, 0, -4924, 0, 28855, 0, -4923, 0, 28843, 0, -4922, 0, 28849, 0, -4921, 0, 28904, 0, -4920, 0, 28874, 0, -4919, 0, 28944, 0, -4918, 0, 28947, 0, -4917, 0, 28950, 0, -4916, 0, 28975, 0, -4915, 0, 28977, 0, -4914, 0, 29043, 0, -4913, 0, 29020, 0, -4912, 0, 29032, 0, -4911, 0, 28997, 0, -4910, 0, 29042, 0, -4909, 0, 29002, 0, -4908, 0, 29048, 0, -4907, 0, 29050, 0, -4906, 0, 29080, 0, -4905, 0, 29107, 0, -4904, 0, 29109, 0, -4903, 0, 29096, 0, -4902, 0, 29088, 0, -4901, 0, 29152, 0, -4900, 0, 29140, 0, -4899, 0, 29159, 0, -4898, 0, 29177, 0, -4897, 0, 29213, 0, -4896, 0, 29224, 0, -4895, 0, 28780, 0, -4894, 0, 28952, 0, -4893, 0, 29030, 0, -4892, 0, 29113, 0, -4891, 0, 25150, 0, -4890, 0, 25149, 0, -4889, 0, 25155, 0, -4888, 0, 25160, 0, -4887, 0, 25161, 0, -4886, 0, 31035, 0, -4885, 0, 31040, 0, -4884, 0, 31046, 0, -4883, 0, 31049, 0, -4882, 0, 31067, 0, -4881, 0, 31068, 0, -4880, 0, 31059, 0, -4879, 0, 31066, 0, -4878, 0, 31074, 0, -4877, 0, 31063, 0, -4876, 0, 31072, 0, -4875, 0, 31087, 0, -4874, 0, 31079, 0, -4873, 0, 31098, 0, -4872, 0, 31109, 0, -4871, 0, 31114, 0, -4870, 0, 31130, 0, -4869, 0, 31143, 0, -4868, 0, 31155, 0, -4867, 0, 24529, 0, -4866, 0, 24528, 0, -4800, 0, -26722, 0, -4799, 0, -26721, 0, -4798, 0, -26719, 0, -4797, 0, -26718, 0, -4796, 0, -26716, 0, -4795, 0, -26715, 0, -4794, 0, -26714, 0, -4793, 0, -26713, 0, -4792, 0, -26712, 0, -4791, 0, -26711, 0, -4790, 0, -26710, 0, -4789, 0, -26708, 0, -4788, 0, -26706, 0, -4787, 0, -26704, 0, -4786, 0, -26703, 0, -4785, 0, -26701, 0, -4784, 0, -26699, 0, -4783, 0, -26698, 0, -4782, 0, -26697, 0, -4781, 0, -26696, 0, -4780, 0, -26695, 0, -4779, 0, -26694, 0, -4778, 0, -26693, 0, -4777, 0, -26692, 0, -4776, 0, -26691, 0, -4775, 0, -26690, 0, -4774, 0, -26689, 0, -4773, 0, -26688, 0, -4772, 0, -26687, 0, -4771, 0, -26686, 0, -4770, 0, -26685, 0, -4769, 0, -26684, 0, -4768, 0, -26683, 0, -4767, 0, -26682, 0, -4766, 0, -26681, 0, -4765, 0, -26680, 0, -4764, 0, -26679, 0, -4763, 0, -26678, 0, -4762, 0, -26677, 0, -4761, 0, -26676, 0, -4760, 0, -26675, 0, -4759, 0, -26674, 0, -4758, 0, -26673, 0, -4757, 0, -26672, 0, -4756, 0, -26671, 0, -4755, 0, -26670, 0, -4754, 0, -26669, 0, -4753, 0, -26668, 0, -4752, 0, -26667, 0, -4751, 0, -26666, 0, -4750, 0, -26665, 0, -4749, 0, -26664, 0, -4748, 0, -26663, 0, -4747, 0, -26662, 0, -4746, 0, -26661, 0, -4745, 0, -26660, 0, -4744, 0, -26659, 0, -4743, 0, -26658, 0, -4742, 0, -26657, 0, -4741, 0, -26656, 0, -4740, 0, -26655, 0, -4739, 0, -26654, 0, -4738, 0, -26653, 0, -4736, 0, -26652, 0, -4735, 0, -26651, 0, -4734, 0, -26648, 0, -4733, 0, -26642, 0, -4732, 0, -26641, 0, -4731, 0, -26640, 0, -4730, 0, -26639, 0, -4729, 0, -26638, 0, -4728, 0, -26636, 0, -4727, 0, -26633, 0, -4726, 0, -26632, 0, -4725, 0, -26631, 0, -4724, 0, -26630, 0, -4723, 0, -26629, 0, -4722, 0, -26628, 0, -4721, 0, -26627, 0, -4720, 0, -26626, 0, -4719, 0, -26625, 0, -4718, 0, -26624, 0, -4717, 0, -26623, 0, -4716, 0, -26622, 0, -4715, 0, -26621, 0, -4714, 0, -26620, 0, -4713, 0, -26619, 0, -4712, 0, -26618, 0, -4711, 0, -26617, 0, -4710, 0, -26616, 0, -4709, 0, -26615, 0, -4708, 0, -26614, 0, -4707, 0, -26613, 0, -4706, 0, -26612, 0, -4705, 0, -26611, 0, -4704, 0, -26610, 0, -4703, 0, 24636, 0, -4702, 0, 24669, 0, -4701, 0, 24666, 0, -4700, 0, 24679, 0, -4699, 0, 24641, 0, -4698, 0, 24665, 0, -4697, 0, 24675, 0, -4696, 0, 24747, 0, -4695, 0, 24838, 0, -4694, 0, 24845, 0, -4693, 0, 24925, 0, -4692, 0, 25001, 0, -4691, 0, 24989, 0, -4690, 0, 25035, 0, -4689, 0, 25041, 0, -4688, 0, 25094, 0, -4687, 0, -32640, 0, -4686, 0, -32641, 0, -4685, 0, 27795, 0, -4684, 0, 27894, 0, -4683, 0, 28156, 0, -4682, 0, 30710, 0, -4681, 0, 30712, 0, -4680, 0, 30720, 0, -4679, 0, 30729, 0, -4678, 0, 30743, 0, -4677, 0, 30744, 0, -4676, 0, 30737, 0, -4675, 0, 26027, 0, -4674, 0, 30765, 0, -4673, 0, 30748, 0, -4672, 0, 30749, 0, -4671, 0, 30777, 0, -4670, 0, 30778, 0, -4669, 0, 30779, 0, -4668, 0, 30751, 0, -4667, 0, 30780, 0, -4666, 0, 30757, 0, -4665, 0, 30764, 0, -4664, 0, 30755, 0, -4663, 0, 30761, 0, -4662, 0, 30798, 0, -4661, 0, 30829, 0, -4660, 0, 30806, 0, -4659, 0, 30807, 0, -4658, 0, 30758, 0, -4657, 0, 30800, 0, -4656, 0, 30791, 0, -4655, 0, 30796, 0, -4654, 0, 30826, 0, -4653, 0, 30875, 0, -4652, 0, 30867, 0, -4651, 0, 30874, 0, -4650, 0, 30855, 0, -4649, 0, 30876, 0, -4648, 0, 30881, 0, -4647, 0, 30883, 0, -4646, 0, 30898, 0, -4645, 0, 30905, 0, -4644, 0, 30885, 0, -4643, 0, 30932, 0, -4642, 0, 30937, 0, -4641, 0, 30921, 0, -4640, 0, 30956, 0, -4639, 0, 30962, 0, -4638, 0, 30981, 0, -4637, 0, 30964, 0, -4636, 0, 30995, 0, -4635, 0, 31012, 0, -4634, 0, 31006, 0, -4633, 0, 31028, 0, -4632, 0, -24677, 0, -4631, 0, -24839, 0, -4630, 0, -24837, 0, -4629, 0, -24836, 0, -4628, 0, 30449, 0, -4627, 0, 30468, 0, -4626, 0, 30477, 0, -4625, 0, 30457, 0, -4624, 0, 30471, 0, -4623, 0, 30472, 0, -4622, 0, 30490, 0, -4621, 0, 30498, 0, -4620, 0, 30489, 0, -4619, 0, 30509, 0, -4618, 0, 30502, 0, -4617, 0, 30517, 0, -4616, 0, 30520, 0, -4615, 0, 30544, 0, -4614, 0, 30545, 0, -4613, 0, 30535, 0, -4612, 0, 30531, 0, -4611, 0, 30554, 0, -4610, 0, 30568, 0, -4544, 0, -26609, 0, -4543, 0, -26608, 0, -4542, 0, -26607, 0, -4541, 0, -26606, 0, -4540, 0, -26605, 0, -4539, 0, -26604, 0, -4538, 0, -26603, 0, -4537, 0, -26602, 0, -4536, 0, -26601, 0, -4535, 0, -26600, 0, -4534, 0, -26599, 0, -4533, 0, -26598, 0, -4532, 0, -26597, 0, -4531, 0, -26596, 0, -4530, 0, -26595, 0, -4529, 0, -26594, 0, -4528, 0, -26593, 0, -4527, 0, -26592, 0, -4526, 0, -26591, 0, -4525, 0, -26590, 0, -4524, 0, -26589, 0, -4523, 0, -26588, 0, -4522, 0, -26587, 0, -4521, 0, -26586, 0, -4520, 0, -26585, 0, -4519, 0, -26584, 0, -4518, 0, -26583, 0, -4517, 0, -26582, 0, -4516, 0, -26581, 0, -4515, 0, -26580, 0, -4514, 0, -26579, 0, -4513, 0, -26578, 0, -4512, 0, -26577, 0, -4511, 0, -26576, 0, -4510, 0, -26575, 0, -4509, 0, -26574, 0, -4508, 0, -26573, 0, -4507, 0, -26572, 0, -4506, 0, -26571, 0, -4505, 0, -26570, 0, -4504, 0, -26569, 0, -4503, 0, -26568, 0, -4502, 0, -26567, 0, -4501, 0, -26566, 0, -4500, 0, -26565, 0, -4499, 0, -26564, 0, -4498, 0, -26563, 0, -4497, 0, -26562, 0, -4496, 0, -26561, 0, -4495, 0, -26560, 0, -4494, 0, -26559, 0, -4493, 0, -26558, 0, -4492, 0, -26557, 0, -4491, 0, -26556, 0, -4490, 0, -26555, 0, -4489, 0, -26554, 0, -4488, 0, -26553, 0, -4487, 0, -26552, 0, -4486, 0, -26551, 0, -4485, 0, -26550, 0, -4484, 0, -26549, 0, -4483, 0, -26548, 0, -4482, 0, -26547, 0, -4480, 0, -26546, 0, -4479, 0, -26545, 0, -4478, 0, -26544, 0, -4477, 0, -26543, 0, -4476, 0, -26542, 0, -4475, 0, -26541, 0, -4474, 0, -26540, 0, -4473, 0, -26539, 0, -4472, 0, -26538, 0, -4471, 0, -26537, 0, -4470, 0, -26536, 0, -4469, 0, -26535, 0, -4468, 0, -26534, 0, -4467, 0, -26533, 0, -4466, 0, -26532, 0, -4465, 0, -26531, 0, -4464, 0, -26530, 0, -4463, 0, -26529, 0, -4462, 0, -26528, 0, -4461, 0, -26527, 0, -4460, 0, -26526, 0, -4459, 0, -26525, 0, -4458, 0, -26524, 0, -4457, 0, -26523, 0, -4456, 0, -26522, 0, -4455, 0, -26521, 0, -4454, 0, -26520, 0, -4453, 0, -26519, 0, -4452, 0, -26518, 0, -4451, 0, -26517, 0, -4450, 0, -26516, 0, -4449, 0, -26515, 0, -4448, 0, -26514, 0, -4447, 0, 30562, 0, -4446, 0, 30565, 0, -4445, 0, 30591, 0, -4444, 0, 30605, 0, -4443, 0, 30589, 0, -4442, 0, 30592, 0, -4441, 0, 30604, 0, -4440, 0, 30609, 0, -4439, 0, 30623, 0, -4438, 0, 30624, 0, -4437, 0, 30640, 0, -4436, 0, 30645, 0, -4435, 0, 30653, 0, -4434, 0, 30010, 0, -4433, 0, 30016, 0, -4432, 0, 30030, 0, -4431, 0, 30027, 0, -4430, 0, 30024, 0, -4429, 0, 30043, 0, -4428, 0, 30066, 0, -4427, 0, 30073, 0, -4426, 0, 30083, 0, -4425, 0, 32600, 0, -4424, 0, 32609, 0, -4423, 0, 32607, 0, -4422, 0, -30136, 0, -4421, 0, 32616, 0, -4420, 0, 32628, 0, -4419, 0, 32625, 0, -4418, 0, 32633, 0, -4417, 0, 32641, 0, -4416, 0, 32638, 0, -4415, 0, 30413, 0, -4414, 0, 30437, 0, -4413, 0, -30670, 0, -4412, 0, -27515, 0, -4411, 0, -27514, 0, -4410, 0, -27513, 0, -4409, 0, -27509, 0, -4408, 0, -27510, 0, -4407, 0, -27508, 0, -4406, 0, -27507, 0, -4405, 0, -27505, 0, -4404, 0, -27504, 0, -4403, 0, -27500, 0, -4402, 0, -27497, 0, -4401, 0, -27499, 0, -4400, 0, -27494, 0, -4399, 0, -27493, 0, -4398, 0, -27492, 0, -4397, 0, -27485, 0, -4396, 0, -27484, 0, -4395, 0, -27477, 0, -4394, 0, -27478, 0, -4393, 0, -27475, 0, -4392, 0, -27476, 0, -4391, 0, -27473, 0, -4390, 0, -27472, 0, -4389, 0, -27470, 0, -4388, 0, -27468, 0, -4387, 0, -27466, 0, -4386, 0, -27465, 0, -4385, 0, -27464, 0, -4384, 0, -27463, 0, -4383, 0, -27462, 0, -4382, 0, -27460, 0, -4381, 0, -27459, 0, -4380, 0, -27457, 0, -4379, 0, -27452, 0, -4378, 0, -27448, 0, -4377, 0, -27447, 0, -4376, 0, -27446, 0, -4375, 0, -27445, 0, -4374, 0, -27444, 0, -4373, 0, -27443, 0, -4372, 0, -27442, 0, -4371, 0, -27440, 0, -4370, 0, -27439, 0, -4369, 0, -27438, 0, -4368, 0, -27435, 0, -4367, 0, -27434, 0, -4366, 0, -27433, 0, -4365, 0, -27431, 0, -4364, 0, -27432, 0, -4363, 0, -27429, 0, -4362, 0, -27426, 0, -4361, 0, -27425, 0, -4360, 0, -27424, 0, -4359, 0, -27422, 0, -4358, 0, -27420, 0, -4357, 0, -27419, 0, -4356, 0, -27417, 0, -4355, 0, -27416, 0, -4354, 0, -27414, 0, -4288, 0, -26513, 0, -4287, 0, -26512, 0, -4286, 0, -26511, 0, -4285, 0, -26510, 0, -4284, 0, -26509, 0, -4283, 0, -26508, 0, -4282, 0, -26485, 0, -4281, 0, -26482, 0, -4280, 0, -26478, 0, -4279, 0, -26475, 0, -4278, 0, -26471, 0, -4277, 0, -26461, 0, -4276, 0, -26456, 0, -4275, 0, -26455, 0, -4274, 0, -26454, 0, -4273, 0, -26453, 0, -4272, 0, -26452, 0, -4271, 0, -26451, 0, -4270, 0, -26450, 0, -4269, 0, -26449, 0, -4268, 0, -26448, 0, -4267, 0, -26447, 0, -4266, 0, -26446, 0, -4265, 0, -26445, 0, -4264, 0, -26444, 0, -4263, 0, -26443, 0, -4262, 0, -26442, 0, -4261, 0, -26441, 0, -4260, 0, -26440, 0, -4259, 0, -26439, 0, -4258, 0, -26438, 0, -4257, 0, -26437, 0, -4256, 0, -26436, 0, -4255, 0, -26435, 0, -4254, 0, -26434, 0, -4253, 0, -26433, 0, -4252, 0, -26432, 0, -4251, 0, -26431, 0, -4250, 0, -26430, 0, -4249, 0, -26429, 0, -4248, 0, -26428, 0, -4247, 0, -26427, 0, -4246, 0, -26426, 0, -4245, 0, -26425, 0, -4244, 0, -26424, 0, -4243, 0, -26423, 0, -4242, 0, -26422, 0, -4241, 0, -26421, 0, -4240, 0, -26420, 0, -4239, 0, -26419, 0, -4238, 0, -26417, 0, -4237, 0, -26416, 0, -4236, 0, -26412, 0, -4235, 0, -26410, 0, -4234, 0, -26409, 0, -4233, 0, -26405, 0, -4232, 0, -26404, 0, -4231, 0, -26403, 0, -4230, 0, -26400, 0, -4229, 0, -26399, 0, -4228, 0, -26398, 0, -4227, 0, -26397, 0, -4226, 0, -26396, 0, -4224, 0, -26395, 0, -4223, 0, -26394, 0, -4222, 0, -26391, 0, -4221, 0, -26390, 0, -4220, 0, -26389, 0, -4219, 0, -26388, 0, -4218, 0, -26387, 0, -4217, 0, -26386, 0, -4216, 0, -26385, 0, -4215, 0, -26384, 0, -4214, 0, -26383, 0, -4213, 0, -26382, 0, -4212, 0, -26381, 0, -4211, 0, -26380, 0, -4210, 0, -26379, 0, -4209, 0, -26378, 0, -4208, 0, -26377, 0, -4207, 0, -26376, 0, -4206, 0, -26375, 0, -4205, 0, -26374, 0, -4204, 0, -26373, 0, -4203, 0, -26372, 0, -4202, 0, -26371, 0, -4201, 0, -26370, 0, -4200, 0, -26369, 0, -4199, 0, -26368, 0, -4198, 0, -26367, 0, -4197, 0, -26366, 0, -4196, 0, -26365, 0, -4195, 0, -26364, 0, -4194, 0, -26363, 0, -4193, 0, -26362, 0, -4192, 0, -26361, 0, -4191, 0, -27415, 0, -4190, 0, -27413, 0, -4189, 0, -27410, 0, -4188, 0, -27409, 0, -4187, 0, -27405, 0, -4186, 0, -27404, 0, -4185, 0, -27403, 0, -4184, 0, -27401, 0, -4183, 0, -27399, 0, -4182, 0, -27396, 0, -4181, 0, -27395, 0, -4180, 0, -27393, 0, -4179, 0, -27389, 0, -4178, 0, -27390, 0, -4177, 0, -27386, 0, -4176, 0, -27385, 0, -4175, 0, -27383, 0, -4174, 0, -27382, 0, -4173, 0, -27379, 0, -4172, 0, -27378, 0, -4171, 0, -27377, 0, -4170, 0, -27374, 0, -4169, 0, -27373, 0, -4168, 0, -27372, 0, -4167, 0, -27371, 0, -4166, 0, -27370, 0, -4165, 0, -27368, 0, -4164, 0, -27365, 0, -4163, 0, -27363, 0, -4162, 0, -27362, 0, -4161, 0, -27361, 0, -4160, 0, -27358, 0, -4159, 0, -27350, 0, -4158, 0, -27349, 0, -4157, 0, -27351, 0, -4156, 0, -27348, 0, -4155, 0, -27343, 0, -4154, 0, -27342, 0, -4153, 0, -27340, 0, -4152, 0, -27338, 0, -4151, 0, -27337, 0, -4150, 0, -27336, 0, -4149, 0, -27332, 0, -4148, 0, -27330, 0, -4147, 0, -27329, 0, -4146, 0, -27326, 0, -4145, 0, -27339, 0, -4144, 0, -27324, 0, -4143, 0, -27323, 0, -4142, 0, -27322, 0, -4141, 0, -27319, 0, -4140, 0, -27316, 0, -4139, 0, -27314, 0, -4138, 0, -27313, 0, -4137, 0, -27310, 0, -4136, 0, -27309, 0, -4135, 0, -27308, 0, -4134, 0, -27306, 0, -4133, 0, -27305, 0, -4132, 0, -27304, 0, -4131, 0, -27303, 0, -4130, 0, -27301, 0, -4129, 0, -27298, 0, -4128, 0, -27297, 0, -4127, 0, -27299, 0, -4126, 0, -27295, 0, -4125, 0, -27294, 0, -4124, 0, -27292, 0, -4123, 0, -27291, 0, -4122, 0, -27290, 0, -4121, 0, -27289, 0, -4120, 0, -27288, 0, -4119, 0, -27287, 0, -4118, 0, -27286, 0, -4117, 0, -27285, 0, -4116, 0, -27284, 0, -4115, 0, -27281, 0, -4114, 0, -27279, 0, -4113, 0, -27278, 0, -4112, 0, -27277, 0, -4111, 0, -27334, 0, -4110, 0, 30695, 0, -4109, 0, 30700, 0, -4108, 0, -26935, 0, -4107, 0, 31189, 0, -4106, 0, 31213, 0, -4105, 0, 31203, 0, -4104, 0, 31211, 0, -4103, 0, 31238, 0, -4102, 0, 23879, 0, -4101, 0, 31235, 0, -4100, 0, 31234, 0, -4099, 0, 31262, 0, -4098, 0, 31252, 0, -4032, 0, -26360, 0, -4031, 0, -26359, 0, -4030, 0, -26358, 0, -4029, 0, -26357, 0, -4028, 0, -26356, 0, -4027, 0, -26354, 0, -4026, 0, -26353, 0, -4025, 0, -26351, 0, -4024, 0, -26350, 0, -4023, 0, -26349, 0, -4022, 0, -26348, 0, -4021, 0, -26347, 0, -4020, 0, -26346, 0, -4019, 0, -26345, 0, -4018, 0, -26344, 0, -4017, 0, -26343, 0, -4016, 0, -26342, 0, -4015, 0, -26341, 0, -4014, 0, -26340, 0, -4013, 0, -26339, 0, -4012, 0, -26338, 0, -4011, 0, -26337, 0, -4010, 0, -26336, 0, -4009, 0, -26335, 0, -4008, 0, -26334, 0, -4007, 0, -26333, 0, -4006, 0, -26332, 0, -4005, 0, -26331, 0, -4004, 0, -26330, 0, -4003, 0, -26329, 0, -4002, 0, -26328, 0, -4001, 0, -26327, 0, -4000, 0, -26326, 0, -3999, 0, -26325, 0, -3998, 0, -26324, 0, -3997, 0, -26323, 0, -3996, 0, -26321, 0, -3995, 0, -26320, 0, -3994, 0, -26319, 0, -3993, 0, -26318, 0, -3992, 0, -26317, 0, -3991, 0, -26316, 0, -3990, 0, -26315, 0, -3989, 0, -26314, 0, -3988, 0, -26313, 0, -3987, 0, -26312, 0, -3986, 0, -26311, 0, -3985, 0, -26310, 0, -3984, 0, -26309, 0, -3983, 0, -26308, 0, -3982, 0, -26307, 0, -3981, 0, -26306, 0, -3980, 0, -26305, 0, -3979, 0, -26304, 0, -3978, 0, -26303, 0, -3977, 0, -26302, 0, -3976, 0, -26301, 0, -3975, 0, -26300, 0, -3974, 0, -26299, 0, -3973, 0, -26298, 0, -3972, 0, -26297, 0, -3971, 0, -26296, 0, -3970, 0, -26295, 0, -3968, 0, -26294, 0, -3967, 0, -26293, 0, -3966, 0, -26292, 0, -3965, 0, -26291, 0, -3964, 0, -26290, 0, -3963, 0, -26289, 0, -3962, 0, -26288, 0, -3961, 0, -26287, 0, -3960, 0, -26286, 0, -3959, 0, -26285, 0, -3958, 0, -26282, 0, -3957, 0, -26281, 0, -3956, 0, -26280, 0, -3955, 0, -26279, 0, -3954, 0, -26278, 0, -3953, 0, -26277, 0, -3952, 0, -26276, 0, -3951, 0, -26275, 0, -3950, 0, -26274, 0, -3949, 0, -26273, 0, -3948, 0, -26272, 0, -3947, 0, -26271, 0, -3946, 0, -26270, 0, -3945, 0, -26268, 0, -3944, 0, -26266, 0, -3943, 0, -26253, 0, -3942, 0, -26248, 0, -3941, 0, -26247, 0, -3940, 0, -26245, 0, -3939, 0, -26242, 0, -3938, 0, -26238, 0, -3937, 0, -26237, 0, -3936, 0, -26231, 0, -3935, 0, 31289, 0, -3934, 0, 31287, 0, -3933, 0, 31313, 0, -3932, 0, -24881, 0, -3931, 0, -26203, 0, -3930, 0, 31344, 0, -3929, 0, 30344, 0, -3928, 0, 30350, 0, -3927, 0, 30355, 0, -3926, 0, 30361, 0, -3925, 0, 30372, 0, -3924, 0, 29918, 0, -3923, 0, 29920, 0, -3922, 0, 29996, 0, -3921, 0, -25056, 0, -3920, 0, -25054, 0, -3919, 0, -25048, 0, -3918, 0, -25047, 0, -3917, 0, -25046, 0, -3916, 0, -25045, 0, -3915, 0, -25044, 0, -3914, 0, -25038, 0, -3913, 0, -25039, 0, -3912, 0, -25034, 0, -3911, 0, -25032, 0, -3910, 0, -25033, 0, -3909, 0, -25031, 0, -3908, 0, -25030, 0, -3907, 0, -25026, 0, -3906, 0, -25023, 0, -3905, 0, -25022, 0, -3904, 0, -25020, 0, -3903, 0, -25018, 0, -3902, 0, -25017, 0, -3901, 0, -25016, 0, -3900, 0, -25015, 0, -3899, 0, -25013, 0, -3898, 0, -25012, 0, -3897, 0, -25010, 0, -3896, 0, -25007, 0, -3895, 0, -25003, 0, -3894, 0, -25001, 0, -3893, 0, -24998, 0, -3892, 0, -24997, 0, -3891, 0, -24996, 0, -3890, 0, -24994, 0, -3889, 0, -24989, 0, -3888, 0, -24986, 0, -3887, 0, -24985, 0, -3886, 0, -24984, 0, -3885, 0, -24983, 0, -3884, 0, -24982, 0, -3883, 0, -24981, 0, -3882, 0, -24980, 0, -3881, 0, -24975, 0, -3880, 0, -24979, 0, -3879, 0, -24973, 0, -3878, 0, 30098, 0, -3877, 0, 30100, 0, -3876, 0, 30102, 0, -3875, 0, 30112, 0, -3874, 0, 30109, 0, -3873, 0, 30124, 0, -3872, 0, 30115, 0, -3871, 0, 30131, 0, -3870, 0, 30132, 0, -3869, 0, 30136, 0, -3868, 0, 30148, 0, -3867, 0, 30129, 0, -3866, 0, 30128, 0, -3865, 0, 30147, 0, -3864, 0, 30146, 0, -3863, 0, 30166, 0, -3862, 0, 30157, 0, -3861, 0, 30179, 0, -3860, 0, 30184, 0, -3859, 0, 30182, 0, -3858, 0, 30180, 0, -3857, 0, 30187, 0, -3856, 0, 30183, 0, -3855, 0, 30211, 0, -3854, 0, 30193, 0, -3853, 0, 30204, 0, -3852, 0, 30207, 0, -3851, 0, 30224, 0, -3850, 0, 30208, 0, -3849, 0, 30213, 0, -3848, 0, 30220, 0, -3847, 0, 30231, 0, -3846, 0, 30218, 0, -3845, 0, 30245, 0, -3844, 0, 30232, 0, -3843, 0, 30229, 0, -3842, 0, 30233, 0, -3776, 0, -26228, 0, -3775, 0, -26226, 0, -3774, 0, -26214, 0, -3773, 0, -26213, 0, -3772, 0, -26212, 0, -3771, 0, -26211, 0, -3770, 0, -26210, 0, -3769, 0, -26209, 0, -3768, 0, -26208, 0, -3767, 0, -26207, 0, -3766, 0, -26206, 0, -3765, 0, -26205, 0, -3764, 0, -26204, 0, -3763, 0, -26202, 0, -3762, 0, -26201, 0, -3761, 0, -26199, 0, -3760, 0, -26198, 0, -3759, 0, -26197, 0, -3758, 0, -26196, 0, -3757, 0, -26195, 0, -3756, 0, -26194, 0, -3755, 0, -26193, 0, -3754, 0, -26192, 0, -3753, 0, -26191, 0, -3752, 0, -26190, 0, -3751, 0, -26189, 0, -3750, 0, -26188, 0, -3749, 0, -26187, 0, -3748, 0, -26186, 0, -3747, 0, -26185, 0, -3746, 0, -26184, 0, -3745, 0, -26183, 0, -3744, 0, -26182, 0, -3743, 0, -26181, 0, -3742, 0, -26180, 0, -3741, 0, -26179, 0, -3740, 0, -26178, 0, -3739, 0, -26177, 0, -3738, 0, -26176, 0, -3737, 0, -26175, 0, -3736, 0, -26174, 0, -3735, 0, -26173, 0, -3734, 0, -26172, 0, -3733, 0, -26171, 0, -3732, 0, -26170, 0, -3731, 0, -26169, 0, -3730, 0, -26168, 0, -3729, 0, -26167, 0, -3728, 0, -26166, 0, -3727, 0, -26165, 0, -3726, 0, -26164, 0, -3725, 0, -26163, 0, -3724, 0, -26162, 0, -3723, 0, -26161, 0, -3722, 0, -26160, 0, -3721, 0, -26159, 0, -3720, 0, -26158, 0, -3719, 0, -26157, 0, -3718, 0, -26156, 0, -3717, 0, -26155, 0, -3716, 0, -26154, 0, -3715, 0, -26153, 0, -3714, 0, -26152, 0, -3712, 0, -26151, 0, -3711, 0, -26150, 0, -3710, 0, -26149, 0, -3709, 0, -26148, 0, -3708, 0, -26147, 0, -3707, 0, -26146, 0, -3706, 0, -26145, 0, -3705, 0, -26144, 0, -3704, 0, -26143, 0, -3703, 0, -26142, 0, -3702, 0, -26141, 0, -3701, 0, -26140, 0, -3700, 0, -26139, 0, -3699, 0, -26138, 0, -3698, 0, -26137, 0, -3697, 0, -26136, 0, -3696, 0, -26135, 0, -3695, 0, -26134, 0, -3694, 0, -26133, 0, -3693, 0, -26132, 0, -3692, 0, -26131, 0, -3691, 0, -26130, 0, -3690, 0, -26129, 0, -3689, 0, -26128, 0, -3688, 0, -26127, 0, -3687, 0, -26126, 0, -3686, 0, -26125, 0, -3685, 0, -26124, 0, -3684, 0, -26123, 0, -3683, 0, -26122, 0, -3682, 0, -26121, 0, -3681, 0, -26120, 0, -3680, 0, -26119, 0, -3679, 0, 30235, 0, -3678, 0, 30268, 0, -3677, 0, 30242, 0, -3676, 0, 30240, 0, -3675, 0, 30272, 0, -3674, 0, 30253, 0, -3673, 0, 30256, 0, -3672, 0, 30271, 0, -3671, 0, 30261, 0, -3670, 0, 30275, 0, -3669, 0, 30270, 0, -3668, 0, 30259, 0, -3667, 0, 30285, 0, -3666, 0, 30302, 0, -3665, 0, 30292, 0, -3664, 0, 30300, 0, -3663, 0, 30294, 0, -3662, 0, 30315, 0, -3661, 0, 30319, 0, -3660, 0, 32714, 0, -3659, 0, 31462, 0, -3658, 0, 31352, 0, -3657, 0, 31353, 0, -3656, 0, 31360, 0, -3655, 0, 31366, 0, -3654, 0, 31368, 0, -3653, 0, 31381, 0, -3652, 0, 31398, 0, -3651, 0, 31392, 0, -3650, 0, 31404, 0, -3649, 0, 31400, 0, -3648, 0, 31405, 0, -3647, 0, 31411, 0, -3646, 0, -30620, 0, -3645, 0, -30615, 0, -3644, 0, -30606, 0, -3643, 0, -30595, 0, -3642, 0, -30593, 0, -3641, 0, -30590, 0, -3640, 0, -30558, 0, -3639, 0, -30522, 0, -3638, 0, -30537, 0, -3637, 0, -30532, 0, -3636, 0, -30519, 0, -3635, 0, -30494, 0, -3634, 0, -30514, 0, -3633, 0, -30493, 0, -3632, 0, -30491, 0, -3631, 0, -30479, 0, -3630, 0, -30438, 0, -3629, 0, -30468, 0, -3628, 0, -30488, 0, -3627, 0, -30466, 0, -3626, 0, -30480, 0, -3625, 0, -30431, 0, -3624, 0, -30439, 0, -3623, 0, -30445, 0, -3622, 0, -30437, 0, -3621, 0, -30454, 0, -3620, 0, -30412, 0, -3619, 0, -30421, 0, -3618, 0, -30410, 0, -3617, 0, -30399, 0, -3616, 0, -30362, 0, -3615, 0, -30341, 0, -3614, 0, 30091, 0, -3613, 0, -32539, 0, -3612, 0, 30386, 0, -3611, 0, 30388, 0, -3610, 0, 30684, 0, -3609, 0, -32750, 0, -3608, 0, -32748, 0, -3607, 0, -32746, 0, -3606, 0, -32740, 0, -3605, 0, -32736, 0, -3604, 0, -32734, 0, -3603, 0, -32731, 0, -3602, 0, -32730, 0, -3601, 0, -32729, 0, -3600, 0, -32727, 0, -3599, 0, -32728, 0, -3598, 0, -32719, 0, -3597, 0, -32757, 0, -3596, 0, -32715, 0, -3595, 0, -32701, 0, -3594, 0, -32698, 0, -3593, 0, -32691, 0, -3592, 0, -32686, 0, -3591, 0, -32663, 0, -3590, 0, -32655, 0, -3589, 0, -30333, 0, -3588, 0, -26504, 0, -3587, 0, -26496, 0, -3586, 0, -26493, 0, -3520, 0, -26118, 0, -3519, 0, -26117, 0, -3518, 0, -26116, 0, -3517, 0, -26115, 0, -3516, 0, -26114, 0, -3515, 0, -26113, 0, -3514, 0, -26112, 0, -3513, 0, -26111, 0, -3512, 0, -26110, 0, -3511, 0, -26109, 0, -3510, 0, -26108, 0, -3509, 0, -26107, 0, -3508, 0, -26106, 0, -3507, 0, -26105, 0, -3506, 0, -26104, 0, -3505, 0, -26103, 0, -3504, 0, -26102, 0, -3503, 0, -26101, 0, -3502, 0, -26100, 0, -3501, 0, -26099, 0, -3500, 0, -26098, 0, -3499, 0, -26097, 0, -3498, 0, -26096, 0, -3497, 0, -26095, 0, -3496, 0, -26094, 0, -3495, 0, -26093, 0, -3494, 0, -26092, 0, -3493, 0, -26091, 0, -3492, 0, -26090, 0, -3491, 0, -26089, 0, -3490, 0, -26088, 0, -3489, 0, -26087, 0, -3488, 0, -26086, 0, -3487, 0, -26085, 0, -3486, 0, -26084, 0, -3485, 0, -26083, 0, -3484, 0, -26082, 0, -3483, 0, -26081, 0, -3482, 0, -26080, 0, -3481, 0, -26079, 0, -3480, 0, -26078, 0, -3479, 0, -26077, 0, -3478, 0, -26076, 0, -3477, 0, -26075, 0, -3476, 0, -26074, 0, -3475, 0, -26073, 0, -3474, 0, -26072, 0, -3473, 0, -26071, 0, -3472, 0, -26070, 0, -3471, 0, -26069, 0, -3470, 0, -26068, 0, -3469, 0, -26067, 0, -3468, 0, -26066, 0, -3467, 0, -26065, 0, -3466, 0, -26064, 0, -3465, 0, -26063, 0, -3464, 0, -26062, 0, -3463, 0, -26061, 0, -3462, 0, -26060, 0, -3461, 0, -26059, 0, -3460, 0, -26058, 0, -3459, 0, -26057, 0, -3458, 0, -26056, 0, -3456, 0, -26055, 0, -3455, 0, -26054, 0, -3454, 0, -26053, 0, -3453, 0, -26052, 0, -3452, 0, -26051, 0, -3451, 0, -26050, 0, -3450, 0, -26049, 0, -3449, 0, -26048, 0, -3448, 0, -26047, 0, -3447, 0, -26046, 0, -3446, 0, -26045, 0, -3445, 0, -26044, 0, -3444, 0, -26043, 0, -3443, 0, -26042, 0, -3442, 0, -26041, 0, -3441, 0, -26040, 0, -3440, 0, -26039, 0, -3439, 0, -26038, 0, -3438, 0, -26037, 0, -3437, 0, -26036, 0, -3436, 0, -26035, 0, -3435, 0, -26034, 0, -3434, 0, -26033, 0, -3433, 0, -26032, 0, -3432, 0, -26031, 0, -3431, 0, -26030, 0, -3430, 0, -26029, 0, -3429, 0, -26028, 0, -3428, 0, -26027, 0, -3427, 0, -26026, 0, -3426, 0, -26025, 0, -3425, 0, -26024, 0, -3424, 0, -26023, 0, -3423, 0, -26487, 0, -3422, 0, -26484, 0, -3421, 0, -26483, 0, -3420, 0, -26481, 0, -3419, 0, -26476, 0, -3418, 0, -26470, 0, -3417, 0, -26469, 0, -3416, 0, -26466, 0, -3415, 0, -26465, 0, -3414, 0, -26463, 0, -3413, 0, -26462, 0, -3412, 0, -26459, 0, -3411, 0, -26458, 0, -3410, 0, -31155, 0, -3409, 0, -31148, 0, -3408, 0, -31124, 0, -3407, 0, -31122, 0, -3406, 0, -31105, 0, -3405, 0, -31110, 0, -3404, 0, -31108, 0, -3403, 0, -31109, 0, -3402, 0, -31064, 0, -3401, 0, -31091, 0, -3400, 0, -31093, 0, -3399, 0, -31060, 0, -3398, 0, -31075, 0, -3397, 0, -31065, 0, -3396, 0, -31069, 0, -3395, 0, -31062, 0, -3394, 0, -31085, 0, -3393, 0, -31063, 0, -3392, 0, -31050, 0, -3391, 0, -31036, 0, -3390, 0, -31051, 0, -3389, 0, -31026, 0, -3388, 0, -31056, 0, -3387, 0, -31046, 0, -3386, 0, -31055, 0, -3385, 0, -31057, 0, -3384, 0, -31031, 0, -3383, 0, -31025, 0, -3382, 0, -31052, 0, -3381, 0, -30999, 0, -3380, 0, -30991, 0, -3379, 0, -30990, 0, -3378, 0, -30995, 0, -3377, 0, -30989, 0, -3376, 0, -31024, 0, -3375, 0, -30957, 0, -3374, 0, -31010, 0, -3373, 0, -30988, 0, -3372, 0, -31009, 0, -3371, 0, -31016, 0, -3370, 0, -31023, 0, -3369, 0, -30973, 0, -3368, 0, -30969, 0, -3367, 0, -30984, 0, -3366, 0, -30968, 0, -3365, 0, -30966, 0, -3364, 0, -30963, 0, -3363, 0, -30967, 0, -3362, 0, -30941, 0, -3361, 0, -30917, 0, -3360, 0, -30946, 0, -3359, 0, -30939, 0, -3358, 0, -30930, 0, -3357, 0, -30950, 0, -3356, 0, -30914, 0, -3355, 0, -30904, 0, -3354, 0, -30924, 0, -3353, 0, -30927, 0, -3352, 0, -30935, 0, -3351, 0, -30921, 0, -3350, 0, -30913, 0, -3349, 0, -30846, 0, -3348, 0, -30942, 0, -3347, 0, -30851, 0, -3346, 0, -30850, 0, -3345, 0, -30853, 0, -3344, 0, -30880, 0, -3343, 0, -30864, 0, -3342, 0, -30900, 0, -3341, 0, -30866, 0, -3340, 0, -30837, 0, -3339, 0, -30893, 0, -3338, 0, -30877, 0, -3337, 0, -30852, 0, -3336, 0, -30876, 0, -3335, 0, -30887, 0, -3334, 0, -30875, 0, -3333, 0, -30829, 0, -3332, 0, -30801, 0, -3331, 0, -30808, 0, -3330, 0, -30766, 0, -3264, 0, -26022, 0, -3263, 0, -26021, 0, -3262, 0, -26020, 0, -3261, 0, -26019, 0, -3260, 0, -26018, 0, -3259, 0, -26017, 0, -3258, 0, -26016, 0, -3257, 0, -26015, 0, -3256, 0, -26014, 0, -3255, 0, -26013, 0, -3254, 0, -26012, 0, -3253, 0, -26011, 0, -3252, 0, -26010, 0, -3251, 0, -26009, 0, -3250, 0, -26008, 0, -3249, 0, -26007, 0, -3248, 0, -26006, 0, -3247, 0, -26005, 0, -3246, 0, -25998, 0, -3245, 0, -25981, 0, -3244, 0, -25975, 0, -3243, 0, -25971, 0, -3242, 0, -25970, 0, -3241, 0, -25964, 0, -3240, 0, -25963, 0, -3239, 0, -25959, 0, -3238, 0, -25946, 0, -3237, 0, -25943, 0, -3236, 0, -25942, 0, -3235, 0, -25941, 0, -3234, 0, -25940, 0, -3233, 0, -25939, 0, -3232, 0, -25938, 0, -3231, 0, -25937, 0, -3230, 0, -25934, 0, -3229, 0, -25933, 0, -3228, 0, -25932, 0, -3227, 0, -25931, 0, -3226, 0, -25927, 0, -3225, 0, -25925, 0, -3224, 0, -25923, 0, -3223, 0, -25922, 0, -3222, 0, -25921, 0, -3221, 0, -25917, 0, -3220, 0, -25916, 0, -3219, 0, -25914, 0, -3218, 0, -25913, 0, -3217, 0, -25912, 0, -3216, 0, -25911, 0, -3215, 0, -25910, 0, -3214, 0, -25907, 0, -3213, 0, -25906, 0, -3212, 0, -25905, 0, -3211, 0, -25904, 0, -3210, 0, -25902, 0, -3209, 0, -25900, 0, -3208, 0, -25899, 0, -3207, 0, -25898, 0, -3206, 0, -25897, 0, -3205, 0, -25895, 0, -3204, 0, -25894, 0, -3203, 0, -25893, 0, -3202, 0, -25892, 0, -3200, 0, -25891, 0, -3199, 0, -25890, 0, -3198, 0, -25888, 0, -3197, 0, -25886, 0, -3196, 0, -25885, 0, -3195, 0, -25884, 0, -3194, 0, -25883, 0, -3193, 0, -25881, 0, -3192, 0, -25880, 0, -3191, 0, -25879, 0, -3190, 0, -25878, 0, -3189, 0, -25876, 0, -3188, 0, -25874, 0, -3187, 0, -25872, 0, -3186, 0, -25871, 0, -3185, 0, -25870, 0, -3184, 0, -25869, 0, -3183, 0, -25868, 0, -3182, 0, -25867, 0, -3181, 0, -25866, 0, -3180, 0, -25865, 0, -3179, 0, -25864, 0, -3178, 0, -25862, 0, -3177, 0, -25860, 0, -3176, 0, -25859, 0, -3175, 0, -25858, 0, -3174, 0, -25857, 0, -3173, 0, -25856, 0, -3172, 0, -25855, 0, -3171, 0, -25854, 0, -3170, 0, -25852, 0, -3169, 0, -25851, 0, -3168, 0, -25850, 0, -3167, 0, -30778, 0, -3166, 0, -30840, 0, -3165, 0, -30843, 0, -3164, 0, -30803, 0, -3163, 0, -30825, 0, -3162, 0, -30845, 0, -3161, 0, -30805, 0, -3160, 0, -30747, 0, -3159, 0, -30804, 0, -3158, 0, -30795, 0, -3157, 0, -30797, 0, -3156, 0, -30773, 0, -3155, 0, -30765, 0, -3154, 0, -30787, 0, -3153, 0, -30767, 0, -3152, 0, -30784, 0, -3151, 0, -30774, 0, -3150, 0, -30757, 0, -3149, 0, -30742, 0, -3148, 0, -30752, 0, -3147, 0, -30738, 0, -3146, 0, -30698, 0, -3145, 0, -30701, 0, -3144, 0, -30722, 0, -3143, 0, -30710, 0, -3142, 0, -30693, 0, -3141, 0, -30687, 0, -3140, 0, -30663, 0, -3139, 0, -30660, 0, -3138, 0, 32566, 0, -3137, 0, 32578, 0, -3136, 0, 32580, 0, -3135, 0, 32581, 0, -3134, 0, -32240, 0, -3133, 0, 31482, 0, -3132, 0, 31485, 0, -3131, 0, 31496, 0, -3130, 0, 31491, 0, -3129, 0, 31492, 0, -3128, 0, 31509, 0, -3127, 0, 31498, 0, -3126, 0, 31531, 0, -3125, 0, 31503, 0, -3124, 0, 31559, 0, -3123, 0, 31544, 0, -3122, 0, 31530, 0, -3121, 0, 31513, 0, -3120, 0, 31534, 0, -3119, 0, 31537, 0, -3118, 0, 31520, 0, -3117, 0, 31525, 0, -3116, 0, 31524, 0, -3115, 0, 31539, 0, -3114, 0, 31550, 0, -3113, 0, 31518, 0, -3112, 0, 31576, 0, -3111, 0, 31578, 0, -3110, 0, 31557, 0, -3109, 0, 31605, 0, -3108, 0, 31564, 0, -3107, 0, 31581, 0, -3106, 0, 31584, 0, -3105, 0, 31598, 0, -3104, 0, 31611, 0, -3103, 0, 31586, 0, -3102, 0, 31602, 0, -3101, 0, 31601, 0, -3100, 0, 31632, 0, -3099, 0, 31654, 0, -3098, 0, 31655, 0, -3097, 0, 31672, 0, -3096, 0, 31660, 0, -3095, 0, 31645, 0, -3094, 0, 31656, 0, -3093, 0, 31621, 0, -3092, 0, 31658, 0, -3091, 0, 31644, 0, -3090, 0, 31650, 0, -3089, 0, 31659, 0, -3088, 0, 31668, 0, -3087, 0, 31697, 0, -3086, 0, 31681, 0, -3085, 0, 31692, 0, -3084, 0, 31709, 0, -3083, 0, 31706, 0, -3082, 0, 31717, 0, -3081, 0, 31718, 0, -3080, 0, 31722, 0, -3079, 0, 31756, 0, -3078, 0, 31742, 0, -3077, 0, 31740, 0, -3076, 0, 31759, 0, -3075, 0, 31766, 0, -3074, 0, 31755, 0, -3008, 0, -25849, 0, -3007, 0, -25847, 0, -3006, 0, -25846, 0, -3005, 0, -25845, 0, -3004, 0, -25844, 0, -3003, 0, -25843, 0, -3002, 0, -25842, 0, -3001, 0, -25840, 0, -3000, 0, -25839, 0, -2999, 0, -25838, 0, -2998, 0, -25836, 0, -2997, 0, -25835, 0, -2996, 0, -25834, 0, -2995, 0, -25833, 0, -2994, 0, -25832, 0, -2993, 0, -25831, 0, -2992, 0, -25830, 0, -2991, 0, -25829, 0, -2990, 0, -25828, 0, -2989, 0, -25827, 0, -2988, 0, -25826, 0, -2987, 0, -25824, 0, -2986, 0, -25823, 0, -2985, 0, -25822, 0, -2984, 0, -25820, 0, -2983, 0, -25819, 0, -2982, 0, -25818, 0, -2981, 0, -25817, 0, -2980, 0, -25816, 0, -2979, 0, -25815, 0, -2978, 0, -25814, 0, -2977, 0, -25813, 0, -2976, 0, -25812, 0, -2975, 0, -25811, 0, -2974, 0, -25810, 0, -2973, 0, -25808, 0, -2972, 0, -25807, 0, -2971, 0, -25805, 0, -2970, 0, -25804, 0, -2969, 0, -25803, 0, -2968, 0, -25802, 0, -2967, 0, -25801, 0, -2966, 0, -25800, 0, -2965, 0, -25799, 0, -2964, 0, -25798, 0, -2963, 0, -25795, 0, -2962, 0, -25794, 0, -2961, 0, -25793, 0, -2960, 0, -25792, 0, -2959, 0, -25786, 0, -2958, 0, -25782, 0, -2957, 0, -25781, 0, -2956, 0, -25780, 0, -2955, 0, -25778, 0, -2954, 0, -25776, 0, -2953, 0, -25774, 0, -2952, 0, -25773, 0, -2951, 0, -25771, 0, -2950, 0, -25770, 0, -2949, 0, -25769, 0, -2948, 0, -25768, 0, -2947, 0, -25767, 0, -2946, 0, -25766, 0, -2944, 0, -25765, 0, -2943, 0, -25764, 0, -2942, 0, -25763, 0, -2941, 0, -25762, 0, -2940, 0, -25761, 0, -2939, 0, -25760, 0, -2938, 0, -25759, 0, -2937, 0, -25758, 0, -2936, 0, -25757, 0, -2935, 0, -25756, 0, -2934, 0, -25755, 0, -2933, 0, -25754, 0, -2932, 0, -25753, 0, -2931, 0, -25752, 0, -2930, 0, -25751, 0, -2929, 0, -25750, 0, -2928, 0, -25749, 0, -2927, 0, -25748, 0, -2926, 0, -25747, 0, -2925, 0, -25746, 0, -2924, 0, -25745, 0, -2923, 0, -25744, 0, -2922, 0, -25743, 0, -2921, 0, -25742, 0, -2920, 0, -25741, 0, -2919, 0, -25740, 0, -2918, 0, -25739, 0, -2917, 0, -25738, 0, -2916, 0, -25737, 0, -2915, 0, -25736, 0, -2914, 0, -25735, 0, -2913, 0, -25734, 0, -2912, 0, -25733, 0, -2911, 0, 31775, 0, -2910, 0, 31786, 0, -2909, 0, 31782, 0, -2908, 0, 31800, 0, -2907, 0, 31809, 0, -2906, 0, 31808, 0, -2905, 0, -32258, 0, -2904, 0, -32255, 0, -2903, 0, -32254, 0, -2902, 0, -32252, 0, -2901, 0, -32276, 0, -2900, 0, -30652, 0, -2899, 0, -32223, 0, -2898, 0, -32222, 0, -2897, 0, -32221, 0, -2896, 0, -32211, 0, -2895, 0, -32209, 0, -2894, 0, -32216, 0, -2893, 0, -32213, 0, -2892, 0, -32200, 0, -2891, 0, -32197, 0, -2890, 0, -32205, 0, -2889, 0, -32204, 0, -2888, 0, -32194, 0, -2887, 0, -32188, 0, -2886, 0, -32183, 0, -2885, 0, -32181, 0, -2884, 0, -32177, 0, -2883, 0, -32166, 0, -2882, 0, -32161, 0, -2881, 0, -32152, 0, -2880, 0, -30594, 0, -2879, 0, -30587, 0, -2878, 0, -30584, 0, -2877, 0, -30504, 0, -2876, 0, -30497, 0, -2875, 0, -30370, 0, -2874, 0, 32669, 0, -2873, 0, 32671, 0, -2872, 0, 32679, 0, -2871, 0, 32687, 0, -2870, 0, 32688, 0, -2869, 0, 32690, 0, -2868, 0, 31868, 0, -2867, 0, 25929, 0, -2866, 0, 31889, 0, -2865, 0, 31901, 0, -2864, 0, 31900, 0, -2863, 0, 31902, 0, -2862, 0, 31906, 0, -2861, 0, 31922, 0, -2860, 0, 31932, 0, -2859, 0, 31933, 0, -2858, 0, 31937, 0, -2857, 0, 31943, 0, -2856, 0, 31948, 0, -2855, 0, 31949, 0, -2854, 0, 31944, 0, -2853, 0, 31941, 0, -2852, 0, 31959, 0, -2851, 0, 31976, 0, -2850, 0, -32146, 0, -2849, 0, 26280, 0, -2848, 0, 32703, 0, -2847, 0, 32718, 0, -2846, 0, 32725, 0, -2845, 0, 32741, 0, -2844, 0, 32737, 0, -2843, 0, 32742, 0, -2842, 0, 32745, 0, -2841, 0, 32750, 0, -2840, 0, 32755, 0, -2839, 0, 31992, 0, -2838, 0, 32119, 0, -2837, 0, 32166, 0, -2836, 0, 32174, 0, -2835, 0, 32327, 0, -2834, 0, 32411, 0, -2833, 0, -24904, 0, -2832, 0, -24908, 0, -2831, 0, -29325, 0, -2830, 0, -29308, 0, -2829, 0, -29292, 0, -2828, 0, -29295, 0, -2827, 0, -29263, 0, -2826, 0, -29337, 0, -2825, 0, -29331, 0, -2824, 0, -29625, 0, -2823, 0, -29623, 0, -2822, 0, -28342, 0, -2821, 0, -28336, 0, -2820, 0, -28338, 0, -2819, 0, -28337, 0, -2818, 0, -28316, 0, -2752, 0, -25732, 0, -2751, 0, -25731, 0, -2750, 0, -25730, 0, -2749, 0, -25729, 0, -2748, 0, -25728, 0, -2747, 0, -25727, 0, -2746, 0, -25726, 0, -2745, 0, -25725, 0, -2744, 0, -25724, 0, -2743, 0, -25723, 0, -2742, 0, -25722, 0, -2741, 0, -25721, 0, -2740, 0, -25720, 0, -2739, 0, -25719, 0, -2738, 0, -25718, 0, -2737, 0, -25717, 0, -2736, 0, -25716, 0, -2735, 0, -25715, 0, -2734, 0, -25714, 0, -2733, 0, -25713, 0, -2732, 0, -25712, 0, -2731, 0, -25711, 0, -2730, 0, -25710, 0, -2729, 0, -25709, 0, -2728, 0, -25708, 0, -2727, 0, -25707, 0, -2726, 0, -25706, 0, -2725, 0, -25705, 0, -2724, 0, -25704, 0, -2723, 0, -25703, 0, -2722, 0, -25702, 0, -2721, 0, -25701, 0, -2720, 0, -25700, 0, -2719, 0, -25699, 0, -2718, 0, -25698, 0, -2717, 0, -25697, 0, -2716, 0, -25696, 0, -2715, 0, -25695, 0, -2714, 0, -25694, 0, -2713, 0, -25693, 0, -2712, 0, -25692, 0, -2711, 0, -25691, 0, -2710, 0, -25690, 0, -2709, 0, -25689, 0, -2708, 0, -25688, 0, -2707, 0, -25687, 0, -2706, 0, -25686, 0, -2705, 0, -25685, 0, -2704, 0, -25684, 0, -2703, 0, -25683, 0, -2702, 0, -25682, 0, -2701, 0, -25681, 0, -2700, 0, -25680, 0, -2699, 0, -25679, 0, -2698, 0, -25678, 0, -2697, 0, -25677, 0, -2696, 0, -25676, 0, -2695, 0, -25675, 0, -2694, 0, -25674, 0, -2693, 0, -25673, 0, -2692, 0, -25672, 0, -2691, 0, -25671, 0, -2690, 0, -25670, 0, -2688, 0, -25669, 0, -2687, 0, -25668, 0, -2686, 0, -25667, 0, -2685, 0, -25666, 0, -2684, 0, -25665, 0, -2683, 0, -25664, 0, -2682, 0, -25663, 0, -2681, 0, -25662, 0, -2680, 0, -25661, 0, -2679, 0, -25660, 0, -2678, 0, -25659, 0, -2677, 0, -25658, 0, -2676, 0, -25657, 0, -2675, 0, -25656, 0, -2674, 0, -25655, 0, -2673, 0, -25654, 0, -2672, 0, -25653, 0, -2671, 0, -25652, 0, -2670, 0, -25651, 0, -2669, 0, -25650, 0, -2668, 0, -25649, 0, -2667, 0, -25648, 0, -2666, 0, -25647, 0, -2665, 0, -25646, 0, -2664, 0, -25645, 0, -2663, 0, -25644, 0, -2662, 0, -25643, 0, -2661, 0, -25642, 0, -2660, 0, -25641, 0, -2659, 0, -25640, 0, -2658, 0, -25639, 0, -2657, 0, -25638, 0, -2656, 0, -25637, 0, -2655, 0, -28318, 0, -2654, 0, -28319, 0, -2653, 0, -28304, 0, -2652, 0, -28311, 0, -2651, 0, -28305, 0, -2650, 0, -28291, 0, -2649, 0, -28290, 0, -2648, 0, -28302, 0, -2647, 0, -28300, 0, -2646, 0, -28295, 0, -2645, 0, -28276, 0, -2644, 0, -28283, 0, -2643, 0, -28272, 0, -2642, 0, -28275, 0, -2641, 0, -28271, 0, -2640, 0, -28254, 0, -2639, 0, -28253, 0, -2638, 0, -28246, 0, -2637, 0, -28243, 0, -2636, 0, -28242, 0, -2635, 0, -28241, 0, -2634, 0, -28235, 0, -2633, 0, -28236, 0, -2632, 0, -28230, 0, -2631, 0, -29611, 0, -2630, 0, -24962, 0, -2629, 0, -29256, 0, -2628, 0, -29205, 0, -2627, 0, -29179, 0, -2626, 0, -29095, 0, -2625, 0, -29079, 0, -2624, 0, -29259, 0, -2623, 0, -29249, 0, -2622, 0, -29252, 0, -2621, 0, -29254, 0, -2620, 0, -29244, 0, -2619, 0, -29226, 0, -2618, 0, -29225, 0, -2617, 0, -29222, 0, -2616, 0, -29218, 0, -2615, 0, -29234, 0, -2614, 0, -29233, 0, -2613, 0, -29221, 0, -2612, 0, -29242, 0, -2611, 0, -29204, 0, -2610, 0, -29193, 0, -2609, 0, -29192, 0, -2608, 0, -29213, 0, -2607, 0, -29191, 0, -2606, 0, -29189, 0, -2605, 0, -29212, 0, -2604, 0, -29175, 0, -2603, 0, -29187, 0, -2602, 0, -29164, 0, -2601, 0, -29155, 0, -2600, 0, -29153, 0, -2599, 0, -29140, 0, -2598, 0, -29138, 0, -2597, 0, -29149, 0, -2596, 0, -29137, 0, -2595, 0, -29126, 0, -2594, 0, -29120, 0, -2593, 0, -29127, 0, -2592, 0, -29131, 0, -2591, 0, -29123, 0, -2590, 0, -29135, 0, -2589, 0, -29111, 0, -2588, 0, -29119, 0, -2587, 0, -29118, 0, -2586, 0, -29103, 0, -2585, 0, -29102, 0, -2584, 0, -29110, 0, -2583, 0, -29072, 0, -2582, 0, -29066, 0, -2581, 0, -29060, 0, -2580, 0, -29073, 0, -2579, 0, -29068, 0, -2578, 0, -29051, 0, -2577, 0, -29041, 0, -2576, 0, -29036, 0, -2575, 0, -29040, 0, -2574, 0, -29028, 0, -2573, 0, -29026, 0, -2572, 0, -29576, 0, -2571, 0, -29566, 0, -2570, 0, -29558, 0, -2569, 0, -29563, 0, -2568, 0, -29544, 0, -2567, 0, -29548, 0, -2566, 0, 26011, 0, -2565, 0, -30250, 0, -2564, 0, -30242, 0, -2563, 0, -30246, 0, -2562, 0, -30244, 0, -2496, 0, -25636, 0, -2495, 0, -25635, 0, -2494, 0, -25634, 0, -2493, 0, -25633, 0, -2492, 0, -25632, 0, -2491, 0, -25631, 0, -2490, 0, -25630, 0, -2489, 0, -25629, 0, -2488, 0, -25628, 0, -2487, 0, -25627, 0, -2486, 0, -25626, 0, -2485, 0, -25625, 0, -2484, 0, -25624, 0, -2483, 0, -25623, 0, -2482, 0, -25622, 0, -2481, 0, -25621, 0, -2480, 0, -25620, 0, -2479, 0, -25619, 0, -2478, 0, -25618, 0, -2477, 0, -25617, 0, -2476, 0, -25616, 0, -2475, 0, -25615, 0, -2474, 0, -25614, 0, -2473, 0, -25613, 0, -2472, 0, -25612, 0, -2471, 0, -25611, 0, -2470, 0, -25610, 0, -2469, 0, -25609, 0, -2468, 0, -25608, 0, -2467, 0, -25607, 0, -2466, 0, -25606, 0, -2465, 0, -25605, 0, -2464, 0, -25604, 0, -2463, 0, -25603, 0, -2462, 0, -25602, 0, -2461, 0, -25601, 0, -2460, 0, -25600, 0, -2459, 0, -25599, 0, -2458, 0, -25598, 0, -2457, 0, -25597, 0, -2456, 0, -25596, 0, -2455, 0, -25595, 0, -2454, 0, -25594, 0, -2453, 0, -25593, 0, -2452, 0, -25592, 0, -2451, 0, -25591, 0, -2450, 0, -25590, 0, -2449, 0, -25589, 0, -2448, 0, -25588, 0, -2447, 0, -25587, 0, -2446, 0, -25586, 0, -2445, 0, -25585, 0, -2444, 0, -25584, 0, -2443, 0, -25583, 0, -2442, 0, -25582, 0, -2441, 0, -25581, 0, -2440, 0, -25580, 0, -2439, 0, -25579, 0, -2438, 0, -25578, 0, -2437, 0, -25577, 0, -2436, 0, -25576, 0, -2435, 0, -25575, 0, -2434, 0, -25574, 0, -2432, 0, -25573, 0, -2431, 0, -25572, 0, -2430, 0, -25571, 0, -2429, 0, -25570, 0, -2428, 0, -25569, 0, -2427, 0, -25568, 0, -2426, 0, -25567, 0, -2425, 0, -25566, 0, -2424, 0, -25565, 0, -2423, 0, -25564, 0, -2422, 0, -25563, 0, -2421, 0, -25562, 0, -2420, 0, -25561, 0, -2419, 0, -25560, 0, -2418, 0, -25559, 0, -2417, 0, -25558, 0, -2416, 0, -25557, 0, -2415, 0, -25556, 0, -2414, 0, -25555, 0, -2413, 0, -25554, 0, -2412, 0, -25553, 0, -2411, 0, -25552, 0, -2410, 0, -25551, 0, -2409, 0, -25550, 0, -2408, 0, -25549, 0, -2407, 0, -25548, 0, -2406, 0, -25547, 0, -2405, 0, -25546, 0, -2404, 0, -25545, 0, -2403, 0, -25544, 0, -2402, 0, -25543, 0, -2401, 0, -25542, 0, -2400, 0, -25541, 0, -2399, 0, -30235, 0, -2398, 0, -30229, 0, -2397, 0, -30225, 0, -2396, 0, -30146, 0, -2395, 0, -29914, 0, -2394, 0, -26797, 0, -2393, 0, -26903, 0, -2392, 0, -26893, 0, -2391, 0, -26897, 0, -2390, 0, -26874, 0, -2389, 0, -26879, 0, -2388, 0, -26872, 0, -2387, 0, -26865, 0, -2386, 0, -26866, 0, -2385, 0, -26838, 0, -2384, 0, -26835, 0, -2383, 0, -26832, 0, -2382, 0, -26818, 0, -2381, 0, -24704, 0, -2380, 0, -24701, 0, -2379, 0, -24699, 0, -2378, 0, -24698, 0, -2377, 0, -24697, 0, -2376, 0, -24696, 0, -2375, 0, -24695, 0, -2374, 0, -24694, 0, -2373, 0, -24692, 0, -2372, 0, -24834, 0, -2371, 0, -24821, 0, -2370, 0, -24819, 0, -2369, 0, -26951, 0, -2368, 0, -26948, 0, -2367, 0, -26947, 0, -2366, 0, -26930, 0, -2365, 0, -26926, 0, -2364, 0, 30655, 0, -2363, 0, -26912, 0, -2362, 0, -28018, 0, -2361, 0, -27986, 0, -2360, 0, -27960, 0, -2359, 0, -27842, 0, -2358, 0, -27798, 0, -2357, 0, -27702, 0, -2356, 0, -27761, 0, -2355, 0, -27586, 0, -2354, 0, -27541, 0, -2353, 0, -25473, 0, -2352, 0, -25470, 0, -2351, 0, -25467, 0, -2350, 0, -25466, 0, -2349, 0, -25465, 0, -2348, 0, -25464, 0, -2347, 0, 31267, 0, -2346, 0, -25461, 0, -2345, 0, -25458, 0, -2344, 0, -25456, 0, -2343, 0, -25455, 0, -2342, 0, -25454, 0, -2341, 0, -25452, 0, -2340, 0, -25451, 0, -2339, 0, -25446, 0, -2338, 0, -25445, 0, -2337, 0, -25442, 0, -2336, 0, -25441, 0, -2335, 0, -25440, 0, -2334, 0, -25439, 0, -2333, 0, -25438, 0, -2332, 0, -25437, 0, -2331, 0, -25435, 0, -2330, 0, -25434, 0, -2329, 0, -25433, 0, -2328, 0, -25432, 0, -2327, 0, -25431, 0, -2326, 0, -25429, 0, -2325, 0, -25427, 0, -2324, 0, -25426, 0, -2323, 0, -25424, 0, -2322, 0, -25423, 0, -2321, 0, -25422, 0, -2320, 0, -25421, 0, -2319, 0, -25420, 0, -2318, 0, -25419, 0, -2317, 0, -25418, 0, -2316, 0, -25417, 0, -2315, 0, -25414, 0, -2314, 0, -25413, 0, -2313, 0, -25412, 0, -2312, 0, -25411, 0, -2311, 0, -25404, 0, -2310, 0, -25403, 0, -2309, 0, -25402, 0, -2308, 0, -25401, 0, -2307, 0, -25398, 0, -2306, 0, -25397, 0, -2240, 0, -25540, 0, -2239, 0, -25539, 0, -2238, 0, -25538, 0, -2237, 0, -25537, 0, -2236, 0, -25536, 0, -2235, 0, -25535, 0, -2234, 0, -25534, 0, -2233, 0, -25533, 0, -2232, 0, -25532, 0, -2231, 0, -25531, 0, -2230, 0, -25530, 0, -2229, 0, -25529, 0, -2228, 0, -25528, 0, -2227, 0, -25527, 0, -2226, 0, -25526, 0, -2225, 0, -25525, 0, -2224, 0, -25524, 0, -2223, 0, -25523, 0, -2222, 0, -25522, 0, -2221, 0, -25521, 0, -2220, 0, -25520, 0, -2219, 0, -25519, 0, -2218, 0, -25518, 0, -2217, 0, -25517, 0, -2216, 0, -25516, 0, -2215, 0, -25515, 0, -2214, 0, -25514, 0, -2213, 0, -25513, 0, -2212, 0, -25512, 0, -2211, 0, -25511, 0, -2210, 0, -25510, 0, -2209, 0, -25509, 0, -2208, 0, -25508, 0, -2207, 0, -25507, 0, -2206, 0, -25506, 0, -2205, 0, -25505, 0, -2204, 0, -25504, 0, -2203, 0, -25503, 0, -2202, 0, -25502, 0, -2201, 0, -25501, 0, -2200, 0, -25500, 0, -2199, 0, -25499, 0, -2198, 0, -25498, 0, -2197, 0, -25497, 0, -2196, 0, -25496, 0, -2195, 0, -25495, 0, -2194, 0, -25494, 0, -2193, 0, -25493, 0, -2192, 0, -25492, 0, -2191, 0, -25491, 0, -2190, 0, -25490, 0, -2189, 0, -25489, 0, -2188, 0, -25488, 0, -2187, 0, -25487, 0, -2186, 0, -25486, 0, -2185, 0, -25485, 0, -2184, 0, -25484, 0, -2183, 0, -25483, 0, -2182, 0, -25482, 0, -2181, 0, -25481, 0, -2180, 0, -25480, 0, -2179, 0, -25479, 0, -2178, 0, -25478, 0, -2176, 0, -25477, 0, -2175, 0, -25475, 0, -2174, 0, -25474, 0, -2173, 0, -25472, 0, -2172, 0, -25469, 0, -2171, 0, -25468, 0, -2170, 0, -25463, 0, -2169, 0, -25462, 0, -2168, 0, -25460, 0, -2167, 0, -25457, 0, -2166, 0, -25453, 0, -2165, 0, -25450, 0, -2164, 0, -25449, 0, -2163, 0, -25448, 0, -2162, 0, -25447, 0, -2161, 0, -25443, 0, -2160, 0, -25430, 0, -2159, 0, -25428, 0, -2158, 0, -25425, 0, -2157, 0, -25415, 0, -2156, 0, -25410, 0, -2155, 0, -25409, 0, -2154, 0, -25408, 0, -2153, 0, -25407, 0, -2152, 0, -25406, 0, -2151, 0, -25400, 0, -2150, 0, -25399, 0, -2149, 0, -25391, 0, -2148, 0, -25390, 0, -2147, 0, -25382, 0, -2146, 0, -25381, 0, -2145, 0, -25376, 0, -2144, 0, -25375, 0, -2143, 0, -25396, 0, -2142, 0, -25395, 0, -2141, 0, -25394, 0, -2140, 0, -25393, 0, -2139, 0, -25392, 0, -2138, 0, -25389, 0, -2137, 0, -25388, 0, -2136, 0, -25387, 0, -2135, 0, -25385, 0, -2134, 0, -25384, 0, -2133, 0, -25383, 0, -2132, 0, -25380, 0, -2131, 0, -25379, 0, -2130, 0, -25377, 0, -2129, 0, -25374, 0, -2128, 0, -26756, 0, -2127, 0, -26747, 0, -2126, 0, -26735, 0, -2125, 0, -26734, 0, -2124, 0, -26732, 0, -2123, 0, -26705, 0, -2122, 0, -26709, 0, -2121, 0, -26717, 0, -2120, 0, -26702, 0, -2119, 0, -26700, 0, -2118, 0, -25935, 0, -2117, 0, -25936, 0, -2116, 0, -25929, 0, -2115, 0, -25000, 0, -2114, 0, -25930, 0, -2113, 0, -25926, 0, -2112, 0, -25924, 0, -2111, 0, -25919, 0, -2110, 0, -25920, 0, -2109, 0, -25915, 0, -2108, 0, -25918, 0, -2107, 0, -25909, 0, -2106, 0, -25908, 0, -2105, 0, -25903, 0, -2104, 0, -25787, 0, -2103, 0, -25789, 0, -2102, 0, -25785, 0, -2101, 0, -25783, 0, -2100, 0, -25784, 0, -2099, 0, -25779, 0, -2098, 0, -25775, 0, -2097, 0, -26392, 0, -2096, 0, -26355, 0, -2095, 0, -26322, 0, -2094, 0, -26283, 0, -2093, 0, -26284, 0, -2092, 0, -25889, 0, -2091, 0, -25887, 0, -2090, 0, -25882, 0, -2089, 0, -25873, 0, -2088, 0, -25877, 0, -2087, 0, -25861, 0, -2086, 0, -25875, 0, -2085, 0, -25863, 0, -2084, 0, -25848, 0, -2083, 0, -25841, 0, -2082, 0, -25837, 0, -2081, 0, -25825, 0, -2080, 0, -25821, 0, -2079, 0, -24899, 0, -2078, 0, -24898, 0, -2077, 0, 32315, 0, -2076, 0, -24958, 0, -2075, 0, -24953, 0, -2074, 0, -24952, 0, -2073, 0, -24949, 0, -2072, 0, -24942, 0, -2071, 0, -27690, 0, -2070, 0, -24931, 0, -2069, 0, -24929, 0, -2068, 0, -24869, 0, -2067, 0, -24868, 0, -2066, 0, -24867, 0, -2065, 0, -24864, 0, -2064, 0, -24865, 0, -2063, 0, -24862, 0, -2062, 0, -24855, 0, -2061, 0, -24857, 0, -2060, 0, -24859, 0, -2059, 0, -24854, 0, -2058, 0, -24849, 0, -2057, 0, -24798, 0, -2056, 0, -24788, 0, -2055, 0, -24785, 0, -2054, 0, -24775, 0, -2053, 0, -24777, 0, -2052, 0, -24771, 0, -2051, 0, -24770, 0, -2050, 0, -24764, 0, -1984, 0, -25373, 0, -1983, 0, -25372, 0, -1982, 0, -25371, 0, -1981, 0, -25370, 0, -1980, 0, -25369, 0, -1979, 0, -25368, 0, -1978, 0, -25367, 0, -1977, 0, -25366, 0, -1976, 0, -25365, 0, -1975, 0, -25364, 0, -1974, 0, -25363, 0, -1973, 0, -25362, 0, -1972, 0, -25361, 0, -1971, 0, -25360, 0, -1970, 0, -25359, 0, -1969, 0, -25358, 0, -1968, 0, -25357, 0, -1967, 0, -25356, 0, -1966, 0, -25355, 0, -1965, 0, -25354, 0, -1964, 0, -25353, 0, -1963, 0, -25352, 0, -1962, 0, -25351, 0, -1961, 0, -25350, 0, -1960, 0, -25349, 0, -1959, 0, -25348, 0, -1958, 0, -25347, 0, -1957, 0, -25346, 0, -1956, 0, -25345, 0, -1955, 0, -25344, 0, -1954, 0, -25343, 0, -1953, 0, -25342, 0, -1952, 0, -25341, 0, -1951, 0, -25340, 0, -1950, 0, -25339, 0, -1949, 0, -25338, 0, -1948, 0, -25337, 0, -1947, 0, -25336, 0, -1946, 0, -25335, 0, -1945, 0, -25334, 0, -1944, 0, -25333, 0, -1943, 0, -25332, 0, -1942, 0, -25331, 0, -1941, 0, -25330, 0, -1940, 0, -25329, 0, -1939, 0, -25328, 0, -1938, 0, -25327, 0, -1937, 0, -25326, 0, -1936, 0, -25325, 0, -1935, 0, -25324, 0, -1934, 0, -25323, 0, -1933, 0, -25322, 0, -1932, 0, -25321, 0, -1931, 0, -25320, 0, -1930, 0, -25319, 0, -1929, 0, -25318, 0, -1928, 0, -25317, 0, -1927, 0, -25316, 0, -1926, 0, -25315, 0, -1925, 0, -25314, 0, -1924, 0, -25313, 0, -1923, 0, -25312, 0, -1922, 0, -25311, 0, -1920, 0, -25310, 0, -1919, 0, -25309, 0, -1918, 0, -25308, 0, -1917, 0, -25307, 0, -1916, 0, -25306, 0, -1915, 0, -25305, 0, -1914, 0, -25304, 0, -1913, 0, -25303, 0, -1912, 0, -25302, 0, -1911, 0, -25301, 0, -1910, 0, -25300, 0, -1909, 0, -25299, 0, -1908, 0, -25298, 0, -1907, 0, -25297, 0, -1906, 0, -25296, 0, -1905, 0, -25295, 0, -1904, 0, -25294, 0, -1903, 0, -25293, 0, -1902, 0, -25292, 0, -1901, 0, -25291, 0, -1900, 0, -25290, 0, -1899, 0, -25289, 0, -1898, 0, -25288, 0, -1897, 0, -25287, 0, -1896, 0, -25286, 0, -1895, 0, -25285, 0, -1894, 0, -25284, 0, -1893, 0, -25283, 0, -1892, 0, -25282, 0, -1891, 0, -25281, 0, -1890, 0, -25280, 0, -1889, 0, -25279, 0, -1888, 0, -25278, 0, -1887, 0, -7628, 0, -1886, 0, -7627, 0, -1885, 0, -7626, 0, -1884, 0, -7625, 0, -1883, 0, -7624, 0, -1882, 0, -7623, 0, -1881, 0, -7622, 0, -1880, 0, -7621, 0, -1879, 0, -7620, 0, -1878, 0, -7619, 0, -1877, 0, -7618, 0, -1876, 0, -7617, 0, -1875, 0, -7616, 0, -1874, 0, -7615, 0, -1873, 0, -7614, 0, -1872, 0, -7613, 0, -1871, 0, -7612, 0, -1870, 0, -7611, 0, -1869, 0, -7610, 0, -1868, 0, -7609, 0, -1867, 0, -7608, 0, -1866, 0, -7607, 0, -1865, 0, -7606, 0, -1864, 0, -7605, 0, -1863, 0, -7604, 0, -1862, 0, -7603, 0, -1861, 0, -7602, 0, -1860, 0, -7601, 0, -1859, 0, -7600, 0, -1858, 0, -7599, 0, -1857, 0, -7598, 0, -1856, 0, -7597, 0, -1855, 0, -7596, 0, -1854, 0, -7595, 0, -1853, 0, -7594, 0, -1852, 0, -7593, 0, -1851, 0, -7592, 0, -1850, 0, -7591, 0, -1849, 0, -7590, 0, -1848, 0, -7589, 0, -1847, 0, -7588, 0, -1846, 0, -7587, 0, -1845, 0, -7586, 0, -1844, 0, -7585, 0, -1843, 0, -7584, 0, -1842, 0, -7583, 0, -1841, 0, -7582, 0, -1840, 0, -7581, 0, -1839, 0, -7580, 0, -1838, 0, -7579, 0, -1837, 0, -7578, 0, -1836, 0, -7577, 0, -1835, 0, -7576, 0, -1834, 0, -7575, 0, -1833, 0, -7574, 0, -1832, 0, -7573, 0, -1831, 0, -7572, 0, -1830, 0, -7571, 0, -1829, 0, -7570, 0, -1828, 0, -7569, 0, -1827, 0, -7568, 0, -1826, 0, -7567, 0, -1825, 0, -7566, 0, -1824, 0, -7565, 0, -1823, 0, -7564, 0, -1822, 0, -7563, 0, -1821, 0, -7562, 0, -1820, 0, -7561, 0, -1819, 0, -7560, 0, -1818, 0, -7559, 0, -1817, 0, -7558, 0, -1816, 0, -7557, 0, -1815, 0, -7556, 0, -1814, 0, -7555, 0, -1813, 0, -7554, 0, -1812, 0, -7553, 0, -1811, 0, -7552, 0, -1810, 0, -7551, 0, -1809, 0, -7550, 0, -1808, 0, -7549, 0, -1807, 0, -7548, 0, -1806, 0, -7547, 0, -1805, 0, -7546, 0, -1804, 0, -7545, 0, -1803, 0, -7544, 0, -1802, 0, -7543, 0, -1801, 0, -7542, 0, -1800, 0, -7541, 0, -1799, 0, -7540, 0, -1798, 0, -7539, 0, -1797, 0, -7538, 0, -1796, 0, -7537, 0, -1795, 0, -7536, 0, -1794, 0, -7535, 0, -1728, 0, -25277, 0, -1727, 0, -25276, 0, -1726, 0, -25275, 0, -1725, 0, -25274, 0, -1724, 0, -25273, 0, -1723, 0, -25272, 0, -1722, 0, -25271, 0, -1721, 0, -25270, 0, -1720, 0, -25269, 0, -1719, 0, -25268, 0, -1718, 0, -25267, 0, -1717, 0, -25266, 0, -1716, 0, -25265, 0, -1715, 0, -25264, 0, -1714, 0, -25263, 0, -1713, 0, -25262, 0, -1712, 0, -25261, 0, -1711, 0, -25260, 0, -1710, 0, -25259, 0, -1709, 0, -25258, 0, -1708, 0, -25257, 0, -1707, 0, -25256, 0, -1706, 0, -25255, 0, -1705, 0, -25254, 0, -1704, 0, -25253, 0, -1703, 0, -25252, 0, -1702, 0, -25251, 0, -1701, 0, -25250, 0, -1700, 0, -25249, 0, -1699, 0, -25248, 0, -1698, 0, -25247, 0, -1697, 0, -25246, 0, -1696, 0, -25245, 0, -1695, 0, -25244, 0, -1694, 0, -25243, 0, -1693, 0, -25242, 0, -1692, 0, -25241, 0, -1691, 0, -25240, 0, -1690, 0, -25239, 0, -1689, 0, -25238, 0, -1688, 0, -25237, 0, -1687, 0, -25236, 0, -1686, 0, -25235, 0, -1685, 0, -25234, 0, -1684, 0, -25233, 0, -1683, 0, -25232, 0, -1682, 0, -25231, 0, -1681, 0, -25230, 0, -1680, 0, -25229, 0, -1679, 0, -25228, 0, -1678, 0, -25227, 0, -1677, 0, -25226, 0, -1676, 0, -25225, 0, -1675, 0, -25224, 0, -1674, 0, -25223, 0, -1673, 0, -25222, 0, -1672, 0, -25221, 0, -1671, 0, -25220, 0, -1670, 0, -25219, 0, -1669, 0, -25218, 0, -1668, 0, -25217, 0, -1667, 0, -25216, 0, -1666, 0, -25215, 0, -1664, 0, -25214, 0, -1663, 0, -25213, 0, -1662, 0, -25212, 0, -1661, 0, -25211, 0, -1660, 0, -25210, 0, -1659, 0, -25209, 0, -1658, 0, -25208, 0, -1657, 0, -25207, 0, -1656, 0, -25206, 0, -1655, 0, -25205, 0, -1654, 0, -25204, 0, -1653, 0, -25203, 0, -1652, 0, -25202, 0, -1651, 0, -25201, 0, -1650, 0, -25200, 0, -1649, 0, -25199, 0, -1648, 0, -25198, 0, -1647, 0, -25197, 0, -1646, 0, -25196, 0, -1645, 0, -25195, 0, -1644, 0, -25194, 0, -1643, 0, -25193, 0, -1642, 0, -25192, 0, -1641, 0, -25191, 0, -1640, 0, -25190, 0, -1639, 0, -25189, 0, -1638, 0, -25188, 0, -1637, 0, -25187, 0, -1636, 0, -25186, 0, -1635, 0, -25185, 0, -1634, 0, -25184, 0, -1633, 0, -25183, 0, -1632, 0, -25182, 0, -1631, 0, -7534, 0, -1630, 0, -7533, 0, -1629, 0, -7532, 0, -1628, 0, -7531, 0, -1627, 0, -7530, 0, -1626, 0, -7529, 0, -1625, 0, -7528, 0, -1624, 0, -7527, 0, -1623, 0, -7526, 0, -1622, 0, -7525, 0, -1621, 0, -7524, 0, -1620, 0, -7523, 0, -1619, 0, -7522, 0, -1618, 0, -7521, 0, -1617, 0, -7520, 0, -1616, 0, -7519, 0, -1615, 0, -7518, 0, -1614, 0, -7517, 0, -1613, 0, -7516, 0, -1612, 0, -7515, 0, -1611, 0, -7514, 0, -1610, 0, -7513, 0, -1609, 0, -7512, 0, -1608, 0, -7511, 0, -1607, 0, -7510, 0, -1606, 0, -7509, 0, -1605, 0, -7508, 0, -1604, 0, -7507, 0, -1603, 0, -7506, 0, -1602, 0, -7505, 0, -1601, 0, -7504, 0, -1600, 0, -7503, 0, -1599, 0, -7502, 0, -1598, 0, -7501, 0, -1597, 0, -7500, 0, -1596, 0, -7499, 0, -1595, 0, -7498, 0, -1594, 0, -7497, 0, -1593, 0, -7496, 0, -1592, 0, -7495, 0, -1591, 0, -7494, 0, -1590, 0, -7493, 0, -1589, 0, -7492, 0, -1588, 0, -7491, 0, -1587, 0, -7490, 0, -1586, 0, -7489, 0, -1585, 0, -7488, 0, -1584, 0, -7487, 0, -1583, 0, -7486, 0, -1582, 0, -7485, 0, -1581, 0, -7484, 0, -1580, 0, -7483, 0, -1579, 0, -7482, 0, -1578, 0, -7481, 0, -1577, 0, -7480, 0, -1576, 0, -7479, 0, -1575, 0, -7478, 0, -1574, 0, -7477, 0, -1573, 0, -7476, 0, -1572, 0, -7475, 0, -1571, 0, -7474, 0, -1570, 0, -7473, 0, -1569, 0, -7472, 0, -1568, 0, -7471, 0, -1567, 0, -7470, 0, -1566, 0, -7469, 0, -1565, 0, -7468, 0, -1564, 0, -7467, 0, -1563, 0, -7466, 0, -1562, 0, -7465, 0, -1561, 0, -7464, 0, -1560, 0, -7463, 0, -1559, 0, -7462, 0, -1558, 0, -7461, 0, -1557, 0, -7460, 0, -1556, 0, -7459, 0, -1555, 0, -7458, 0, -1554, 0, -7457, 0, -1553, 0, -7456, 0, -1552, 0, -7455, 0, -1551, 0, -7454, 0, -1550, 0, -7453, 0, -1549, 0, -7452, 0, -1548, 0, -7451, 0, -1547, 0, -7450, 0, -1546, 0, -7449, 0, -1545, 0, -7448, 0, -1544, 0, -7447, 0, -1543, 0, -7446, 0, -1542, 0, -7445, 0, -1541, 0, -7444, 0, -1540, 0, -7443, 0, -1539, 0, -7442, 0, -1538, 0, -7441, 0, -1472, 0, -25181, 0, -1471, 0, -25180, 0, -1470, 0, -25179, 0, -1469, 0, -25178, 0, -1468, 0, -25177, 0, -1467, 0, -25176, 0, -1466, 0, -25175, 0, -1465, 0, -25174, 0, -1464, 0, -25173, 0, -1463, 0, -25172, 0, -1462, 0, -25171, 0, -1461, 0, -25170, 0, -1460, 0, -25169, 0, -1459, 0, -25168, 0, -1458, 0, -25167, 0, -1457, 0, -25166, 0, -1456, 0, -25165, 0, -1455, 0, -25164, 0, -1454, 0, -25163, 0, -1453, 0, -25162, 0, -1452, 0, -25161, 0, -1451, 0, -25160, 0, -1450, 0, -25159, 0, -1449, 0, -25158, 0, -1448, 0, -25157, 0, -1447, 0, -25156, 0, -1446, 0, -25155, 0, -1445, 0, -25154, 0, -1444, 0, -25153, 0, -1443, 0, -25152, 0, -1442, 0, -25151, 0, -1441, 0, -25150, 0, -1440, 0, -25149, 0, -1439, 0, -25148, 0, -1438, 0, -25147, 0, -1437, 0, -25146, 0, -1436, 0, -25145, 0, -1435, 0, -25144, 0, -1434, 0, -25143, 0, -1433, 0, -25142, 0, -1432, 0, -25141, 0, -1431, 0, -25140, 0, -1430, 0, -25139, 0, -1429, 0, -25138, 0, -1428, 0, -25137, 0, -1427, 0, -25136, 0, -1426, 0, -25135, 0, -1425, 0, -25134, 0, -1424, 0, -25133, 0, -1423, 0, -25132, 0, -1422, 0, -25131, 0, -1421, 0, -25130, 0, -1420, 0, -25129, 0, -1419, 0, -25128, 0, -1418, 0, -25127, 0, -1417, 0, -25126, 0, -1416, 0, -25125, 0, -1415, 0, -25124, 0, -1414, 0, -25123, 0, -1413, 0, -25122, 0, -1412, 0, -25121, 0, -1411, 0, -25120, 0, -1410, 0, -25119, 0, -1408, 0, -25118, 0, -1407, 0, -25117, 0, -1406, 0, -25116, 0, -1405, 0, -25115, 0, -1404, 0, -25114, 0, -1403, 0, -25113, 0, -1402, 0, -25112, 0, -1401, 0, -25111, 0, -1400, 0, -25110, 0, -1399, 0, -25109, 0, -1398, 0, -25108, 0, -1397, 0, -25107, 0, -1396, 0, -25106, 0, -1395, 0, -25105, 0, -1394, 0, -25104, 0, -1393, 0, -25103, 0, -1392, 0, -25102, 0, -1391, 0, -25101, 0, -1390, 0, -25100, 0, -1389, 0, -25099, 0, -1388, 0, -25098, 0, -1387, 0, -25097, 0, -1386, 0, -25096, 0, -1385, 0, -25095, 0, -1384, 0, -25094, 0, -1383, 0, -25093, 0, -1382, 0, -25092, 0, -1381, 0, -25091, 0, -1380, 0, -25090, 0, -1379, 0, -25089, 0, -1378, 0, -25088, 0, -1377, 0, -25087, 0, -1376, 0, -25086, 0, -1375, 0, -7440, 0, -1374, 0, -7439, 0, -1373, 0, -7438, 0, -1372, 0, -7437, 0, -1371, 0, -7436, 0, -1370, 0, -7435, 0, -1369, 0, -7434, 0, -1368, 0, -7433, 0, -1367, 0, -7432, 0, -1366, 0, -7431, 0, -1365, 0, -7430, 0, -1364, 0, -7429, 0, -1363, 0, -7428, 0, -1362, 0, -7427, 0, -1361, 0, -7426, 0, -1360, 0, -7425, 0, -1359, 0, -7424, 0, -1358, 0, -7423, 0, -1357, 0, -7422, 0, -1356, 0, -7421, 0, -1355, 0, -7420, 0, -1354, 0, -7419, 0, -1353, 0, -7418, 0, -1352, 0, -7417, 0, -1351, 0, -7416, 0, -1350, 0, -7415, 0, -1349, 0, -7414, 0, -1348, 0, -7413, 0, -1347, 0, -7412, 0, -1346, 0, -7411, 0, -1345, 0, -7410, 0, -1344, 0, -7409, 0, -1343, 0, -7408, 0, -1342, 0, -7407, 0, -1341, 0, -7406, 0, -1340, 0, -7405, 0, -1339, 0, -7404, 0, -1338, 0, -7403, 0, -1337, 0, -7402, 0, -1336, 0, -7401, 0, -1335, 0, -7400, 0, -1334, 0, -7399, 0, -1333, 0, -7398, 0, -1332, 0, -7397, 0, -1331, 0, -7396, 0, -1330, 0, -7395, 0, -1329, 0, -7394, 0, -1328, 0, -7393, 0, -1327, 0, -7392, 0, -1326, 0, -7391, 0, -1325, 0, -7390, 0, -1324, 0, -7389, 0, -1323, 0, -7388, 0, -1322, 0, -7387, 0, -1321, 0, -7386, 0, -1320, 0, -7385, 0, -1319, 0, -7384, 0, -1318, 0, -7383, 0, -1317, 0, -7382, 0, -1316, 0, -7381, 0, -1315, 0, -7380, 0, -1314, 0, -7379, 0, -1313, 0, -7378, 0, -1312, 0, -7377, 0, -1311, 0, -7376, 0, -1310, 0, -7375, 0, -1309, 0, -7374, 0, -1308, 0, -7373, 0, -1307, 0, -7372, 0, -1306, 0, -7371, 0, -1305, 0, -7370, 0, -1304, 0, -7369, 0, -1303, 0, -7368, 0, -1302, 0, -7367, 0, -1301, 0, -7366, 0, -1300, 0, -7365, 0, -1299, 0, -7364, 0, -1298, 0, -7363, 0, -1297, 0, -7362, 0, -1296, 0, -7361, 0, -1295, 0, -7360, 0, -1294, 0, -7359, 0, -1293, 0, -7358, 0, -1292, 0, -7357, 0, -1291, 0, -7356, 0, -1290, 0, -7355, 0, -1289, 0, -7354, 0, -1288, 0, -7353, 0, -1287, 0, -7352, 0, -1286, 0, -7351, 0, -1285, 0, -7350, 0, -1284, 0, -7349, 0, -1283, 0, -7348, 0, -1282, 0, -7347, 0, -1216, 0, -25085, 0, -1215, 0, -25084, 0, -1214, 0, -25083, 0, -1213, 0, -25082, 0, -1212, 0, -25081, 0, -1211, 0, -25080, 0, -1210, 0, -25079, 0, -1209, 0, -25078, 0, -1208, 0, -25077, 0, -1207, 0, -25076, 0, -1206, 0, -25075, 0, -1205, 0, -25074, 0, -1204, 0, -25073, 0, -1203, 0, -25072, 0, -1202, 0, -25071, 0, -1201, 0, -25070, 0, -1200, 0, -25069, 0, -1199, 0, -25068, 0, -1198, 0, -25067, 0, -1197, 0, -25066, 0, -1196, 0, -25065, 0, -1195, 0, -25064, 0, -1194, 0, -25063, 0, -1193, 0, -25062, 0, -1192, 0, -25061, 0, -1191, 0, -25060, 0, -1190, 0, -25059, 0, -1189, 0, -25058, 0, -1188, 0, -25052, 0, -1187, 0, -25049, 0, -1186, 0, -25042, 0, -1185, 0, -25040, 0, -1184, 0, -25036, 0, -1183, 0, -25029, 0, -1182, 0, -25028, 0, -1181, 0, -25024, 0, -1180, 0, -25011, 0, -1179, 0, -25008, 0, -1178, 0, -25006, 0, -1177, 0, -25005, 0, -1176, 0, -25004, 0, -1175, 0, -25002, 0, -1174, 0, -24999, 0, -1173, 0, -24995, 0, -1172, 0, -24993, 0, -1171, 0, -24992, 0, -1170, 0, -24991, 0, -1169, 0, -24990, 0, -1168, 0, -24987, 0, -1167, 0, -24978, 0, -1166, 0, -24977, 0, -1165, 0, -24974, 0, -1164, 0, -24972, 0, -1163, 0, -24971, 0, -1162, 0, -24970, 0, -1161, 0, -24969, 0, -1160, 0, -24968, 0, -1159, 0, -24967, 0, -1158, 0, -24966, 0, -1157, 0, -24965, 0, -1156, 0, -24964, 0, -1155, 0, -24963, 0, -1154, 0, -24960, 0, -1152, 0, -24959, 0, -1151, 0, -24957, 0, -1150, 0, -24956, 0, -1149, 0, -24955, 0, -1148, 0, -24954, 0, -1147, 0, -24951, 0, -1146, 0, -24950, 0, -1145, 0, -24948, 0, -1144, 0, -24947, 0, -1143, 0, -24946, 0, -1142, 0, -24945, 0, -1141, 0, -24944, 0, -1140, 0, -24943, 0, -1139, 0, -24940, 0, -1138, 0, -24939, 0, -1137, 0, -24938, 0, -1136, 0, -24937, 0, -1135, 0, -24936, 0, -1134, 0, -24935, 0, -1133, 0, -24934, 0, -1132, 0, -24933, 0, -1131, 0, -24932, 0, -1130, 0, -24930, 0, -1129, 0, -24928, 0, -1128, 0, -24927, 0, -1127, 0, -24926, 0, -1126, 0, -24925, 0, -1125, 0, -24924, 0, -1124, 0, -24923, 0, -1123, 0, -24921, 0, -1122, 0, -24920, 0, -1121, 0, -24919, 0, -1120, 0, -24918, 0, -1119, 0, -7346, 0, -1118, 0, -7345, 0, -1117, 0, -7344, 0, -1116, 0, -7343, 0, -1115, 0, -7342, 0, -1114, 0, -7341, 0, -1113, 0, -7340, 0, -1112, 0, -7339, 0, -1111, 0, -7338, 0, -1110, 0, -7337, 0, -1109, 0, -7336, 0, -1108, 0, -7335, 0, -1107, 0, -7334, 0, -1106, 0, -7333, 0, -1105, 0, -7332, 0, -1104, 0, -7331, 0, -1103, 0, -7330, 0, -1102, 0, -7329, 0, -1101, 0, -7328, 0, -1100, 0, -7327, 0, -1099, 0, -7326, 0, -1098, 0, -7325, 0, -1097, 0, -7324, 0, -1096, 0, -7323, 0, -1095, 0, -7322, 0, -1094, 0, -7321, 0, -1093, 0, -7320, 0, -1092, 0, -7319, 0, -1091, 0, -7318, 0, -1090, 0, -7317, 0, -1089, 0, -7316, 0, -1088, 0, -7315, 0, -1087, 0, -7314, 0, -1086, 0, -7313, 0, -1085, 0, -7312, 0, -1084, 0, -7311, 0, -1083, 0, -7310, 0, -1082, 0, -7309, 0, -1081, 0, -7308, 0, -1080, 0, -7307, 0, -1079, 0, -7306, 0, -1078, 0, -7305, 0, -1077, 0, -7304, 0, -1076, 0, -7303, 0, -1075, 0, -7302, 0, -1074, 0, -7301, 0, -1073, 0, -7300, 0, -1072, 0, -7299, 0, -1071, 0, -7298, 0, -1070, 0, -7297, 0, -1069, 0, -7296, 0, -1068, 0, -7295, 0, -1067, 0, -7294, 0, -1066, 0, -7293, 0, -1065, 0, -7292, 0, -1064, 0, -7291, 0, -1063, 0, -7290, 0, -1062, 0, -7289, 0, -1061, 0, -7288, 0, -1060, 0, -7287, 0, -1059, 0, -7286, 0, -1058, 0, -7285, 0, -1057, 0, -7284, 0, -1056, 0, -7283, 0, -1055, 0, -7282, 0, -1054, 0, -7281, 0, -1053, 0, -7280, 0, -1052, 0, -7279, 0, -1051, 0, -7278, 0, -1050, 0, -7277, 0, -1049, 0, -7276, 0, -1048, 0, -7275, 0, -1047, 0, -7274, 0, -1046, 0, -7273, 0, -1045, 0, -7272, 0, -1044, 0, -7271, 0, -1043, 0, -7270, 0, -1042, 0, -7269, 0, -1041, 0, -7268, 0, -1040, 0, -7267, 0, -1039, 0, -7266, 0, -1038, 0, -7265, 0, -1037, 0, -7264, 0, -1036, 0, -7263, 0, -1035, 0, -7262, 0, -1034, 0, -7261, 0, -1033, 0, -7260, 0, -1032, 0, -7259, 0, -1031, 0, -7258, 0, -1030, 0, -7257, 0, -1029, 0, -7256, 0, -1028, 0, -7255, 0, -1027, 0, -7254, 0, -1026, 0, -7253, 0, -960, 0, -24917, 0, -959, 0, -24916, 0, -958, 0, -24915, 0, -957, 0, -24914, 0, -956, 0, -24913, 0, -955, 0, -24912, 0, -954, 0, -24911, 0, -953, 0, -24910, 0, -952, 0, -24909, 0, -951, 0, -24907, 0, -950, 0, -24906, 0, -949, 0, -24905, 0, -948, 0, -24903, 0, -947, 0, -24902, 0, -946, 0, -24900, 0, -945, 0, -24897, 0, -944, 0, -24896, 0, -943, 0, -24895, 0, -942, 0, -24894, 0, -941, 0, -24893, 0, -940, 0, -24891, 0, -939, 0, -24890, 0, -938, 0, -24889, 0, -937, 0, -24888, 0, -936, 0, -24886, 0, -935, 0, -24885, 0, -934, 0, -24884, 0, -933, 0, -24880, 0, -932, 0, -24878, 0, -931, 0, -24877, 0, -930, 0, -24875, 0, -929, 0, -24874, 0, -928, 0, -24873, 0, -927, 0, -24871, 0, -926, 0, -24870, 0, -925, 0, -24866, 0, -924, 0, -24863, 0, -923, 0, -24861, 0, -922, 0, -24860, 0, -921, 0, -24858, 0, -920, 0, -24856, 0, -919, 0, -24853, 0, -918, 0, -24852, 0, -917, 0, -24851, 0, -916, 0, -24850, 0, -915, 0, -24848, 0, -914, 0, -24847, 0, -913, 0, -24846, 0, -912, 0, -24845, 0, -911, 0, -24844, 0, -910, 0, -24843, 0, -909, 0, -24842, 0, -908, 0, -24841, 0, -907, 0, -24840, 0, -906, 0, -24838, 0, -905, 0, -24835, 0, -904, 0, -24833, 0, -903, 0, -24832, 0, -902, 0, -24831, 0, -901, 0, -24830, 0, -900, 0, -24829, 0, -899, 0, -24828, 0, -898, 0, -24827, 0, -896, 0, -24826, 0, -895, 0, -24825, 0, -894, 0, -24824, 0, -893, 0, -24823, 0, -892, 0, -24822, 0, -891, 0, -24820, 0, -890, 0, -24817, 0, -889, 0, -24815, 0, -888, 0, -24814, 0, -887, 0, -24812, 0, -886, 0, -24811, 0, -885, 0, -24810, 0, -884, 0, -24808, 0, -883, 0, -24806, 0, -882, 0, -24805, 0, -881, 0, -24804, 0, -880, 0, -24803, 0, -879, 0, -24802, 0, -878, 0, -24801, 0, -877, 0, -24799, 0, -876, 0, -24797, 0, -875, 0, -24796, 0, -874, 0, -24795, 0, -873, 0, -24794, 0, -872, 0, -24793, 0, -871, 0, -24792, 0, -870, 0, -24791, 0, -869, 0, -24790, 0, -868, 0, -24789, 0, -867, 0, -24787, 0, -866, 0, -24786, 0, -865, 0, -24784, 0, -864, 0, -24783, 0, -863, 0, -7252, 0, -862, 0, -7251, 0, -861, 0, -7250, 0, -860, 0, -7249, 0, -859, 0, -7248, 0, -858, 0, -7247, 0, -857, 0, -7246, 0, -856, 0, -7245, 0, -855, 0, -7244, 0, -854, 0, -7243, 0, -853, 0, -7242, 0, -852, 0, -7241, 0, -851, 0, -7240, 0, -850, 0, -7239, 0, -849, 0, -7238, 0, -848, 0, -7237, 0, -847, 0, -7236, 0, -846, 0, -7235, 0, -845, 0, -7234, 0, -844, 0, -7233, 0, -843, 0, -7232, 0, -842, 0, -7231, 0, -841, 0, -7230, 0, -840, 0, -7229, 0, -839, 0, -7228, 0, -838, 0, -7227, 0, -837, 0, -7226, 0, -836, 0, -7225, 0, -835, 0, -7224, 0, -834, 0, -7223, 0, -833, 0, -7222, 0, -832, 0, -7221, 0, -831, 0, -7220, 0, -830, 0, -7219, 0, -829, 0, -7218, 0, -828, 0, -7217, 0, -827, 0, -7216, 0, -826, 0, -7215, 0, -825, 0, -7214, 0, -824, 0, -7213, 0, -823, 0, -7212, 0, -822, 0, -7211, 0, -821, 0, -7210, 0, -820, 0, -7209, 0, -819, 0, -7208, 0, -818, 0, -7207, 0, -817, 0, -7206, 0, -816, 0, -7205, 0, -815, 0, -7204, 0, -814, 0, -7203, 0, -813, 0, -7202, 0, -812, 0, -7201, 0, -811, 0, -7200, 0, -810, 0, -7199, 0, -809, 0, -7198, 0, -808, 0, -7197, 0, -807, 0, -7196, 0, -806, 0, -7195, 0, -805, 0, -7194, 0, -804, 0, -7193, 0, -803, 0, -7192, 0, -802, 0, -7191, 0, -801, 0, -7190, 0, -800, 0, -7189, 0, -799, 0, -7188, 0, -798, 0, -7187, 0, -797, 0, -7186, 0, -796, 0, -7185, 0, -795, 0, -7184, 0, -794, 0, -7183, 0, -793, 0, -7182, 0, -792, 0, -7181, 0, -791, 0, -7180, 0, -790, 0, -7179, 0, -789, 0, -7178, 0, -788, 0, -7177, 0, -787, 0, -7176, 0, -786, 0, -7175, 0, -785, 0, -7174, 0, -784, 0, -7173, 0, -783, 0, -7172, 0, -782, 0, -7171, 0, -781, 0, -7170, 0, -780, 0, -7169, 0, -779, 0, -7168, 0, -778, 0, -7167, 0, -777, 0, -7166, 0, -776, 0, -7165, 0, -775, 0, -7164, 0, -774, 0, -7163, 0, -773, 0, -7162, 0, -772, 0, -7161, 0, -771, 0, -7160, 0, -770, 0, -7159, 0, -704, 0, -24782, 0, -703, 0, -24781, 0, -702, 0, -24780, 0, -701, 0, -24779, 0, -700, 0, -24778, 0, -699, 0, -24776, 0, -698, 0, -24774, 0, -697, 0, -24772, 0, -696, 0, -24769, 0, -695, 0, -24768, 0, -694, 0, -24767, 0, -693, 0, -24766, 0, -692, 0, -24765, 0, -691, 0, -24763, 0, -690, 0, -24762, 0, -689, 0, -24761, 0, -688, 0, -24760, 0, -687, 0, -24759, 0, -686, 0, -24758, 0, -685, 0, -24757, 0, -684, 0, -24756, 0, -683, 0, -24755, 0, -682, 0, -24754, 0, -681, 0, -24753, 0, -680, 0, -24750, 0, -679, 0, -24749, 0, -678, 0, -24748, 0, -677, 0, -24747, 0, -676, 0, -24746, 0, -675, 0, -24745, 0, -674, 0, -24744, 0, -673, 0, -24743, 0, -672, 0, -24742, 0, -671, 0, -24741, 0, -670, 0, -24740, 0, -669, 0, -24739, 0, -668, 0, -24738, 0, -667, 0, -24737, 0, -666, 0, -24736, 0, -665, 0, -24735, 0, -664, 0, -24734, 0, -663, 0, -24733, 0, -662, 0, -24732, 0, -661, 0, -24731, 0, -660, 0, -24730, 0, -659, 0, -24729, 0, -658, 0, -24728, 0, -657, 0, -24727, 0, -656, 0, -24726, 0, -655, 0, -24725, 0, -654, 0, -24724, 0, -653, 0, -24723, 0, -652, 0, -24722, 0, -651, 0, -24721, 0, -650, 0, -24720, 0, -649, 0, -24719, 0, -648, 0, -24718, 0, -647, 0, -24717, 0, -646, 0, -24716, 0, -645, 0, -24715, 0, -644, 0, -24714, 0, -643, 0, -24713, 0, -642, 0, -24712, 0, -640, 0, -24711, 0, -639, 0, -24710, 0, -638, 0, -24709, 0, -637, 0, -24708, 0, -636, 0, -24707, 0, -635, 0, -24706, 0, -634, 0, -24703, 0, -633, 0, -24702, 0, -632, 0, -24691, 0, -631, 0, -24690, 0, -630, 0, -24689, 0, -629, 0, -24688, 0, -628, 0, -24687, 0, -627, 0, -24686, 0, -626, 0, -24685, 0, -625, 0, -24684, 0, -624, 0, -24683, 0, -623, 0, -24682, 0, -622, 0, -24681, 0, -621, 0, -24680, 0, -620, 0, -24676, 0, -619, 0, -24675, 0, -618, 0, -24674, 0, -617, 0, -24671, 0, -616, 0, -24670, 0, -615, 0, -24669, 0, -614, 0, -24668, 0, -613, 0, -24667, 0, -612, 0, -1748, 0, -611, 0, -1671, 0, -610, 0, -1643, 0, -609, 0, -1561, 0, -608, 0, -1551, 0, -607, 0, -7158, 0, -606, 0, -7157, 0, -605, 0, -7156, 0, -604, 0, -7155, 0, -603, 0, -7154, 0, -602, 0, -7153, 0, -601, 0, -7152, 0, -600, 0, -7151, 0, -599, 0, -7150, 0, -598, 0, -7149, 0, -597, 0, -7148, 0, -596, 0, -7147, 0, -595, 0, -7146, 0, -594, 0, -7145, 0, -593, 0, -7144, 0, -592, 0, -7143, 0, -591, 0, -7142, 0, -590, 0, -7141, 0, -589, 0, -7140, 0, -588, 0, -7139, 0, -587, 0, -7138, 0, -586, 0, -7137, 0, -585, 0, -7136, 0, -584, 0, -7135, 0, -583, 0, -7134, 0, -582, 0, -7133, 0, -581, 0, -7132, 0, -580, 0, -7131, 0, -579, 0, -7130, 0, -578, 0, -7129, 0, -577, 0, -7128, 0, -576, 0, -7127, 0, -575, 0, -7126, 0, -574, 0, -7125, 0, -573, 0, -7124, 0, -572, 0, -7123, 0, -571, 0, -7122, 0, -570, 0, -7121, 0, -569, 0, -7120, 0, -568, 0, -7119, 0, -567, 0, -7118, 0, -566, 0, -7117, 0, -565, 0, -7116, 0, -564, 0, -7115, 0, -563, 0, -7114, 0, -562, 0, -7113, 0, -561, 0, -7112, 0, -560, 0, -7111, 0, -559, 0, -7110, 0, -558, 0, -7109, 0, -557, 0, -7108, 0, -556, 0, -7107, 0, -555, 0, -7106, 0, -554, 0, -7105, 0, -553, 0, -7104, 0, -552, 0, -7103, 0, -551, 0, -7102, 0, -550, 0, -7101, 0, -549, 0, -7100, 0, -548, 0, -7099, 0, -547, 0, -7098, 0, -546, 0, -7097, 0, -545, 0, -7096, 0, -544, 0, -7095, 0, -543, 0, -7094, 0, -542, 0, -7093, 0, -541, 0, -7092, 0, -540, 0, -7091, 0, -539, 0, -7090, 0, -538, 0, -7089, 0, -537, 0, -7088, 0, -536, 0, -7087, 0, -535, 0, -7086, 0, -534, 0, -7085, 0, -533, 0, -7084, 0, -532, 0, -7083, 0, -531, 0, -7082, 0, -530, 0, -7081, 0, -529, 0, -7080, 0, -528, 0, -7079, 0, -527, 0, -7078, 0, -526, 0, -7077, 0, -525, 0, -7076, 0, -524, 0, -7075, 0, -523, 0, -7074, 0, -522, 0, -7073, 0, -521, 0, -7072, 0, -520, 0, -7071, 0, -519, 0, -7070, 0, -518, 0, -7069, 0, -517, 0, -7068, 0, -516, 0, -7067, 0, -515, 0, -7066, 0, -514, 0, -7065, 0, -448, 0, -1524, 0, -447, 0, -1523, 0, -446, 0, -1522, 0, -445, 0, -1521, 0, -444, 0, -1519, 0, -443, 0, -1517, 0, -442, 0, -1516, 0, -441, 0, -1512, 0, -440, 0, -1505, 0, -439, 0, -1504, 0, -438, 0, -1503, 0, -437, 0, -1501, 0, -436, 0, -1500, 0, -435, 0, -1497, 0, -434, 0, -1496, 0, -433, 0, -1495, 0, -432, 0, -6123, 0, -431, 0, -6122, 0, -430, 0, -6121, 0, -429, 0, -6120, 0, -428, 0, -6119, 0, -427, 0, -6118, 0, -426, 0, -6117, 0, -425, 0, -6116, 0, -424, 0, -6115, 0, -423, 0, -6114, 0, -422, 0, -6113, 0, -421, 0, -6112, 0, -420, 0, -6111, 0, -419, 0, -6110, 0, -418, 0, -6109, 0, -417, 0, -6108, 0, -416, 0, -6107, 0, -415, 0, -6106, 0, -414, 0, -6105, 0, -413, 0, -6104, 0, -412, 0, -6103, 0, -411, 0, -6102, 0, -410, 0, -6101, 0, -409, 0, -6100, 0, -408, 0, -6099, 0, -407, 0, -6098, 0, -406, 0, -6097, 0, -405, 0, -6096, 0, -404, 0, -6095, 0, -403, 0, -6094, 0, -402, 0, -6093, 0, -401, 0, -6092, 0, -400, 0, -6091, 0, -399, 0, -6090, 0, -398, 0, -6089, 0, -397, 0, -6088, 0, -396, 0, -6087, 0, -395, 0, -6086, 0, -394, 0, -6085, 0, -393, 0, -6084, 0, -392, 0, -6083, 0, -391, 0, -6082, 0, -390, 0, -6081, 0, -389, 0, -6080, 0, -388, 0, -6079, 0, -387, 0, -6078, 0, -386, 0, -6077, 0, -384, 0, -6076, 0, -383, 0, -6075, 0, -382, 0, -6074, 0, -381, 0, -6073, 0, -380, 0, -6072, 0, -379, 0, -6071, 0, -378, 0, -6070, 0, -377, 0, -6069, 0, -376, 0, -6068, 0, -375, 0, -6067, 0, -374, 0, -6066, 0, -373, 0, -6065, 0, -372, 0, -6064, 0, -371, 0, -6063, 0, -370, 0, -6062, 0, -369, 0, -6061, 0, -368, 0, -6060, 0, -367, 0, -6059, 0, -366, 0, -6058, 0, -365, 0, -6057, 0, -364, 0, -6056, 0, -363, 0, -6055, 0, -362, 0, -6054, 0, -361, 0, -6053, 0, -360, 0, -6052, 0, -359, 0, -6051, 0, -358, 0, -6050, 0, -357, 0, -6049, 0, -356, 0, -6048, 0, -355, 0, -6047, 0, -354, 0, -6046, 0, -353, 0, -6045, 0, -352, 0, -6044, 0, -351, 0, -7064, 0, -350, 0, -7063, 0, -349, 0, -7062, 0, -348, 0, -7061, 0, -347, 0, -7060, 0, -346, 0, -7059, 0, -345, 0, -7058, 0, -344, 0, -7057, 0, -343, 0, -7056, 0, -342, 0, -7055, 0, -341, 0, -7054, 0, -340, 0, -7053, 0, -339, 0, -7052, 0, -338, 0, -7051, 0, -337, 0, -7050, 0, -336, 0, -7049, 0, -335, 0, -7048, 0, -334, 0, -7047, 0, -333, 0, -7046, 0, -332, 0, -7045, 0, -331, 0, -7044, 0, -330, 0, -7043, 0, -329, 0, -7042, 0, -328, 0, -7041, 0, -327, 0, -7040, 0, -326, 0, -7039, 0, -325, 0, -7038, 0, -324, 0, -7037, 0, -323, 0, -7036, 0, -322, 0, -7035, 0, -321, 0, -7034, 0, -320, 0, -7033, 0, -319, 0, -7032, 0, -318, 0, -7031, 0, -317, 0, -7030, 0, -316, 0, -7029, 0, -315, 0, -7028, 0, -314, 0, -7027, 0, -313, 0, -7026, 0, -312, 0, -7025, 0, -311, 0, -7024, 0, -310, 0, -7023, 0, -309, 0, -7022, 0, -308, 0, -7021, 0, -307, 0, -7020, 0, -306, 0, -7019, 0, -305, 0, -7018, 0, -304, 0, -7017, 0, -303, 0, -7016, 0, -302, 0, -7015, 0, -301, 0, -7014, 0, -300, 0, -7013, 0, -299, 0, -7012, 0, -298, 0, -7011, 0, -297, 0, -7010, 0, -296, 0, -7009, 0, -295, 0, -7008, 0, -294, 0, -7007, 0, -293, 0, -7006, 0, -292, 0, -7005, 0, -291, 0, -7004, 0, -290, 0, -7003, 0, -289, 0, -7002, 0, -288, 0, -7001, 0, -287, 0, -7000, 0, -286, 0, -6999, 0, -285, 0, -6998, 0, -284, 0, -6997, 0, -283, 0, -6996, 0, -282, 0, -6995, 0, -281, 0, -6994, 0, -280, 0, -6993, 0, -279, 0, -6992, 0, -278, 0, -6991, 0, -277, 0, -6990, 0, -276, 0, -6989, 0, -275, 0, -6988, 0, -274, 0, -6987, 0, -273, 0, -6986, 0, -272, 0, -6985, 0, -271, 0, -6984, 0, -270, 0, -6983, 0, -269, 0, -6982, 0, -268, 0, -6981, 0, -267, 0, -6980, 0, -266, 0, -6979, 0, -265, 0, -6978, 0, -264, 0, -6977, 0, -263, 0, -6976, 0, -262, 0, -6975, 0, -261, 0, -6974, 0, -260, 0, -6973, 0, -259, 0, -6972, 0, -258, 0, -6971, 0, -1, 0, -1, 0], ["i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0], ALLOC_STATIC);
_GBK_EUC_AddCodeSpaceRange_code_space_range1=allocate([0, 0, 128, 0, 0, 0], ["i16",0,"i16",0,"i16",0], ALLOC_STATIC);
_GBK_EUC_AddCodeSpaceRange_code_space_range2=allocate([-32448, 0, -258, 0, 0, 0], ["i16",0,"i16",0,"i16",0], ALLOC_STATIC);
STRING_TABLE.__str1080=allocate([69,84,101,110,45,66,53,45,72,0] /* ETen-B5-H\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str11081=allocate([69,84,101,110,45,66,53,45,86,0] /* ETen-B5-V\00 */, "i8", ALLOC_STATIC);
_CMAP_ARRAY_ETen_B5_H=allocate([32, 0, 126, 0, 13648, 0, -24256, 0, -24232, 0, 99, 0, -24231, 0, -24228, 0, 13743, 0, -24227, 0, -24194, 0, 128, 0, -24159, 0, -24075, 0, 162, 0, -24074, 0, -24074, 0, 248, 0, -24073, 0, -24073, 0, 247, 0, -24072, 0, -24066, 0, 249, 0, -24000, 0, -23938, 0, 256, 0, -23903, 0, -23810, 0, 319, 0, -23744, 0, -23682, 0, 413, 0, -23647, 0, -23621, 0, 476, 0, -23619, 0, -23617, 0, 503, 0, -23488, 0, -23426, 0, 595, 0, -23391, 0, -23298, 0, 658, 0, -23232, 0, -23170, 0, 752, 0, -23135, 0, -23042, 0, 815, 0, -22976, 0, -22914, 0, 909, 0, -22879, 0, -22786, 0, 972, 0, -22720, 0, -22658, 0, 1066, 0, -22623, 0, -22530, 0, 1129, 0, -22464, 0, -22402, 0, 1223, 0, -22367, 0, -22274, 0, 1286, 0, -22208, 0, -22146, 0, 1380, 0, -22111, 0, -22018, 0, 1443, 0, -21952, 0, -21890, 0, 1537, 0, -21855, 0, -21762, 0, 1600, 0, -21696, 0, -21634, 0, 1694, 0, -21599, 0, -21506, 0, 1757, 0, -21440, 0, -21378, 0, 1851, 0, -21343, 0, -21251, 0, 1914, 0, -21250, 0, -21250, 0, 2431, 0, -21184, 0, -21122, 0, 2007, 0, -21087, 0, -20994, 0, 2070, 0, -20928, 0, -20866, 0, 2164, 0, -20831, 0, -20738, 0, 2227, 0, -20672, 0, -20610, 0, 2321, 0, -20575, 0, -20529, 0, 2384, 0, -20528, 0, -20482, 0, 2432, 0, -20416, 0, -20354, 0, 2479, 0, -20319, 0, -20226, 0, 2542, 0, -20160, 0, -20098, 0, 2636, 0, -20063, 0, -19970, 0, 2699, 0, -19904, 0, -19842, 0, 2793, 0, -19807, 0, -19714, 0, 2856, 0, -19648, 0, -19586, 0, 2950, 0, -19551, 0, -19458, 0, 3013, 0, -19392, 0, -19330, 0, 3107, 0, -19295, 0, -19202, 0, 3170, 0, -19136, 0, -19074, 0, 3264, 0, -19039, 0, -18946, 0, 3327, 0, -18880, 0, -18818, 0, 3421, 0, -18783, 0, -18690, 0, 3484, 0, -18624, 0, -18562, 0, 3578, 0, -18527, 0, -18434, 0, 3641, 0, -18368, 0, -18306, 0, 3735, 0, -18271, 0, -18178, 0, 3798, 0, -18112, 0, -18050, 0, 3892, 0, -18015, 0, -17922, 0, 3955, 0, -17856, 0, -17794, 0, 4049, 0, -17759, 0, -17666, 0, 4112, 0, -17600, 0, -17538, 0, 4206, 0, -17503, 0, -17465, 0, 4269, 0, -17464, 0, -17410, 0, 4309, 0, -17344, 0, -17282, 0, 4364, 0, -17247, 0, -17154, 0, 4427, 0, -17088, 0, -17026, 0, 4521, 0, -16991, 0, -16898, 0, 4584, 0, -16832, 0, -16815, 0, 4678, 0, -16814, 0, -16814, 0, 4308, 0, -16813, 0, -16770, 0, 4696, 0, -16735, 0, -16642, 0, 4740, 0, -16576, 0, -16514, 0, 4834, 0, -16479, 0, -16386, 0, 4897, 0, -16320, 0, -16258, 0, 4991, 0, -16223, 0, -16130, 0, 5054, 0, -16064, 0, -16002, 0, 5148, 0, -15967, 0, -15958, 0, 5211, 0, -15957, 0, -15874, 0, 5222, 0, -15808, 0, -15746, 0, 5306, 0, -15711, 0, -15670, 0, 5369, 0, -15669, 0, -15669, 0, 5221, 0, -15668, 0, -15618, 0, 5411, 0, -15552, 0, -15520, 0, 5462, 0, -15519, 0, -15490, 0, 5496, 0, -15455, 0, -15432, 0, 5526, 0, -15431, 0, -15431, 0, 5551, 0, -15430, 0, -15430, 0, 5550, 0, -15429, 0, -15362, 0, 5552, 0, -15296, 0, -15275, 0, 5620, 0, -15274, 0, -15274, 0, 5495, 0, -15273, 0, -15234, 0, 5642, 0, -15199, 0, -15106, 0, 5682, 0, -15040, 0, -14978, 0, 5776, 0, -14943, 0, -14850, 0, 5839, 0, -14784, 0, -14722, 0, 5933, 0, -14687, 0, -14658, 0, 506, 0, -14657, 0, -14633, 0, 537, 0, -14632, 0, -14626, 0, 13747, 0, -14625, 0, -14625, 0, 6036, 0, -14624, 0, -14594, 0, 13754, 0, -14528, 0, -14466, 0, 13785, 0, -14431, 0, -14338, 0, 13848, 0, -14272, 0, -14210, 0, 13942, 0, -14175, 0, -14125, 0, 14005, 0, -14016, 0, -14007, 0, 5996, 0, -14006, 0, -14006, 0, 628, 0, -14005, 0, -13973, 0, 6006, 0, -13972, 0, -13954, 0, 6040, 0, -13919, 0, -13891, 0, 6059, 0, -13890, 0, -13890, 0, 6039, 0, -13889, 0, -13844, 0, 6088, 0, -13843, 0, -13826, 0, 6135, 0, -13760, 0, -13698, 0, 6153, 0, -13663, 0, -13578, 0, 6216, 0, -13577, 0, -13577, 0, 6134, 0, -13576, 0, -13570, 0, 6302, 0, -13504, 0, -13442, 0, 6309, 0, -13407, 0, -13314, 0, 6372, 0, -13248, 0, -13186, 0, 6466, 0, -13151, 0, -13058, 0, 6529, 0, -12992, 0, -12930, 0, 6623, 0, -12895, 0, -12802, 0, 6686, 0, -12736, 0, -12674, 0, 6780, 0, -12639, 0, -12546, 0, 6843, 0, -12480, 0, -12418, 0, 6937, 0, -12383, 0, -12290, 0, 7000, 0, -12224, 0, -12162, 0, 7094, 0, -12127, 0, -12034, 0, 7157, 0, -11968, 0, -11906, 0, 7251, 0, -11871, 0, -11778, 0, 7314, 0, -11712, 0, -11650, 0, 7408, 0, -11615, 0, -11522, 0, 7471, 0, -11456, 0, -11394, 0, 7565, 0, -11359, 0, -11266, 0, 7628, 0, -11200, 0, -11138, 0, 7722, 0, -11103, 0, -11010, 0, 7785, 0, -10944, 0, -10882, 0, 7879, 0, -10847, 0, -10754, 0, 7942, 0, -10688, 0, -10626, 0, 8036, 0, -10591, 0, -10549, 0, 8099, 0, -10548, 0, -10548, 0, 8788, 0, -10547, 0, -10498, 0, 8143, 0, -10432, 0, -10375, 0, 8193, 0, -10374, 0, -10374, 0, 8889, 0, -10373, 0, -10370, 0, 8251, 0, -10335, 0, -10242, 0, 8255, 0, -10176, 0, -10114, 0, 8349, 0, -10079, 0, -9986, 0, 8412, 0, -9920, 0, -9858, 0, 8506, 0, -9823, 0, -9730, 0, 8569, 0, -9664, 0, -9602, 0, 8663, 0, -9567, 0, -9506, 0, 8726, 0, -9505, 0, -9505, 0, 8142, 0, -9504, 0, -9474, 0, 8789, 0, -9408, 0, -9346, 0, 8820, 0, -9311, 0, -9306, 0, 8883, 0, -9305, 0, -9218, 0, 8890, 0, -9152, 0, -9090, 0, 8978, 0, -9055, 0, -8962, 0, 9041, 0, -8896, 0, -8834, 0, 9135, 0, -8799, 0, -8709, 0, 9198, 0, -8708, 0, -8708, 0, 9089, 0, -8707, 0, -8706, 0, 9289, 0, -8640, 0, -8578, 0, 9291, 0, -8543, 0, -8450, 0, 9354, 0, -8384, 0, -8322, 0, 9448, 0, -8287, 0, -8194, 0, 9511, 0, -8128, 0, -8066, 0, 9605, 0, -8031, 0, -7938, 0, 9668, 0, -7872, 0, -7810, 0, 9762, 0, -7775, 0, -7682, 0, 9825, 0, -7616, 0, -7554, 0, 9919, 0, -7519, 0, -7426, 0, 9982, 0, -7360, 0, -7298, 0, 10076, 0, -7263, 0, -7170, 0, 10139, 0, -7104, 0, -7042, 0, 10233, 0, -7007, 0, -6914, 0, 10296, 0, -6848, 0, -6786, 0, 10390, 0, -6751, 0, -6658, 0, 10453, 0, -6592, 0, -6530, 0, 10547, 0, -6495, 0, -6402, 0, 10610, 0, -6336, 0, -6274, 0, 10704, 0, -6239, 0, -6146, 0, 10767, 0, -6080, 0, -6018, 0, 10861, 0, -5983, 0, -5982, 0, 10924, 0, -5981, 0, -5890, 0, 10927, 0, -5824, 0, -5771, 0, 11019, 0, -5770, 0, -5762, 0, 11074, 0, -5727, 0, -5634, 0, 11083, 0, -5568, 0, -5506, 0, 11177, 0, -5471, 0, -5378, 0, 11240, 0, -5312, 0, -5286, 0, 11334, 0, -5285, 0, -5250, 0, 11362, 0, -5215, 0, -5136, 0, 11398, 0, -5135, 0, -5135, 0, 10926, 0, -5134, 0, -5122, 0, 11478, 0, -5056, 0, -4994, 0, 11491, 0, -4959, 0, -4899, 0, 11554, 0, -4898, 0, -4898, 0, 11073, 0, -4897, 0, -4866, 0, 11615, 0, -4800, 0, -4738, 0, 11647, 0, -4703, 0, -4695, 0, 11710, 0, -4694, 0, -4610, 0, 11720, 0, -4544, 0, -4482, 0, 11805, 0, -4447, 0, -4374, 0, 11868, 0, -4373, 0, -4373, 0, 12308, 0, -4372, 0, -4354, 0, 11942, 0, -4288, 0, -4226, 0, 11961, 0, -4191, 0, -4098, 0, 12024, 0, -4032, 0, -4011, 0, 12118, 0, -4010, 0, -4010, 0, 11719, 0, -4009, 0, -3970, 0, 12140, 0, -3935, 0, -3894, 0, 12180, 0, -3893, 0, -3893, 0, 11361, 0, -3892, 0, -3842, 0, 12222, 0, -3776, 0, -3742, 0, 12273, 0, -3741, 0, -3734, 0, 12309, 0, -3733, 0, -3733, 0, 12640, 0, -3732, 0, -3714, 0, 12317, 0, -3679, 0, -3586, 0, 12336, 0, -3520, 0, -3481, 0, 12430, 0, -3480, 0, -3480, 0, 12783, 0, -3479, 0, -3458, 0, 12470, 0, -3423, 0, -3390, 0, 12492, 0, -3389, 0, -3330, 0, 12527, 0, -3264, 0, -3212, 0, 12587, 0, -3211, 0, -3202, 0, 12641, 0, -3167, 0, -3074, 0, 12651, 0, -3008, 0, -2971, 0, 12745, 0, -2970, 0, -2946, 0, 12784, 0, -2911, 0, -2892, 0, 12809, 0, -2891, 0, -2891, 0, 12526, 0, -2890, 0, -2820, 0, 12829, 0, -2819, 0, -2818, 0, 12901, 0, -2752, 0, -2690, 0, 12903, 0, -2655, 0, -2562, 0, 12966, 0, -2496, 0, -2462, 0, 13060, 0, -2461, 0, -2461, 0, 12900, 0, -2460, 0, -2434, 0, 13095, 0, -2399, 0, -2306, 0, 13122, 0, -2240, 0, -2178, 0, 13216, 0, -2143, 0, -2050, 0, 13279, 0, -1984, 0, -1922, 0, 13373, 0, -1887, 0, -1794, 0, 13436, 0, -1728, 0, -1674, 0, 13530, 0, -1673, 0, -1666, 0, 13586, 0, -1631, 0, -1597, 0, 13594, 0, -1596, 0, -1596, 0, 13585, 0, -1595, 0, -1595, 0, 13629, 0, -1594, 0, -1594, 0, 13641, 0, -1593, 0, -1583, 0, 13630, 0, -1582, 0, -1579, 0, 13642, 0, -2143, 0, -2050, 0, 7609, 0, -1, 0, -1, 0, 0, 0], ["i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0], ALLOC_STATIC);
_CMAP_ARRAY_ETen_B5_V=allocate([-24245, 0, -24245, 0, 13646, 0, -24230, 0, -24230, 0, 13743, 0, -24228, 0, -24228, 0, 13745, 0, -24227, 0, -24226, 0, 130, 0, -24223, 0, -24222, 0, 134, 0, -24219, 0, -24218, 0, 138, 0, -24215, 0, -24214, 0, 142, 0, -24211, 0, -24210, 0, 146, 0, -24207, 0, -24206, 0, 150, 0, -24203, 0, -24202, 0, 154, 0, -24199, 0, -24198, 0, 158, 0, -24093, 0, -24093, 0, 13647, 0, -14620, 0, -14619, 0, 14097, 0, -1, 0, -1, 0, 0, 0], ["i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0], ALLOC_STATIC);
_ETen_B5_NOTDEF_RANGE=allocate([0, 0, 31, 0, 13648, 0], ["i16",0,"i16",0,"i16",0], ALLOC_STATIC);
_CP950_UNICODE_ARRAY=allocate([0, 0, 0, 0, 1, 0, 1, 0, 2, 0, 2, 0, 3, 0, 3, 0, 4, 0, 4, 0, 5, 0, 5, 0, 6, 0, 6, 0, 7, 0, 7, 0, 8, 0, 8, 0, 9, 0, 9, 0, 10, 0, 10, 0, 11, 0, 11, 0, 12, 0, 12, 0, 13, 0, 13, 0, 14, 0, 14, 0, 15, 0, 15, 0, 16, 0, 16, 0, 17, 0, 17, 0, 18, 0, 18, 0, 19, 0, 19, 0, 20, 0, 20, 0, 21, 0, 21, 0, 22, 0, 22, 0, 23, 0, 23, 0, 24, 0, 24, 0, 25, 0, 25, 0, 26, 0, 26, 0, 27, 0, 27, 0, 28, 0, 28, 0, 29, 0, 29, 0, 30, 0, 30, 0, 31, 0, 31, 0, 32, 0, 32, 0, 33, 0, 33, 0, 34, 0, 34, 0, 35, 0, 35, 0, 36, 0, 36, 0, 37, 0, 37, 0, 38, 0, 38, 0, 39, 0, 39, 0, 40, 0, 40, 0, 41, 0, 41, 0, 42, 0, 42, 0, 43, 0, 43, 0, 44, 0, 44, 0, 45, 0, 45, 0, 46, 0, 46, 0, 47, 0, 47, 0, 48, 0, 48, 0, 49, 0, 49, 0, 50, 0, 50, 0, 51, 0, 51, 0, 52, 0, 52, 0, 53, 0, 53, 0, 54, 0, 54, 0, 55, 0, 55, 0, 56, 0, 56, 0, 57, 0, 57, 0, 58, 0, 58, 0, 59, 0, 59, 0, 60, 0, 60, 0, 61, 0, 61, 0, 62, 0, 62, 0, 63, 0, 63, 0, 64, 0, 64, 0, 65, 0, 65, 0, 66, 0, 66, 0, 67, 0, 67, 0, 68, 0, 68, 0, 69, 0, 69, 0, 70, 0, 70, 0, 71, 0, 71, 0, 72, 0, 72, 0, 73, 0, 73, 0, 74, 0, 74, 0, 75, 0, 75, 0, 76, 0, 76, 0, 77, 0, 77, 0, 78, 0, 78, 0, 79, 0, 79, 0, 80, 0, 80, 0, 81, 0, 81, 0, 82, 0, 82, 0, 83, 0, 83, 0, 84, 0, 84, 0, 85, 0, 85, 0, 86, 0, 86, 0, 87, 0, 87, 0, 88, 0, 88, 0, 89, 0, 89, 0, 90, 0, 90, 0, 91, 0, 91, 0, 92, 0, 92, 0, 93, 0, 93, 0, 94, 0, 94, 0, 95, 0, 95, 0, 96, 0, 96, 0, 97, 0, 97, 0, 98, 0, 98, 0, 99, 0, 99, 0, 100, 0, 100, 0, 101, 0, 101, 0, 102, 0, 102, 0, 103, 0, 103, 0, 104, 0, 104, 0, 105, 0, 105, 0, 106, 0, 106, 0, 107, 0, 107, 0, 108, 0, 108, 0, 109, 0, 109, 0, 110, 0, 110, 0, 111, 0, 111, 0, 112, 0, 112, 0, 113, 0, 113, 0, 114, 0, 114, 0, 115, 0, 115, 0, 116, 0, 116, 0, 117, 0, 117, 0, 118, 0, 118, 0, 119, 0, 119, 0, 120, 0, 120, 0, 121, 0, 121, 0, 122, 0, 122, 0, 123, 0, 123, 0, 124, 0, 124, 0, 125, 0, 125, 0, 126, 0, 126, 0, 127, 0, 127, 0, 128, 0, 128, 0, 255, 0, -1800, 0, -24256, 0, 12288, 0, -24255, 0, -244, 0, -24254, 0, 12289, 0, -24253, 0, 12290, 0, -24252, 0, -242, 0, -24251, 0, 8231, 0, -24250, 0, -229, 0, -24249, 0, -230, 0, -24248, 0, -225, 0, -24247, 0, -255, 0, -24246, 0, -464, 0, -24245, 0, 8230, 0, -24244, 0, 8229, 0, -24243, 0, -432, 0, -24242, 0, -431, 0, -24241, 0, -430, 0, -24240, 0, 183, 0, -24239, 0, -428, 0, -24238, 0, -427, 0, -24237, 0, -426, 0, -24236, 0, -425, 0, -24235, 0, -164, 0, -24234, 0, 8211, 0, -24233, 0, -463, 0, -24232, 0, 8212, 0, -24231, 0, -461, 0, -24230, 0, 9588, 0, -24229, 0, -460, 0, -24228, 0, -433, 0, -24227, 0, -248, 0, -24226, 0, -247, 0, -24225, 0, -459, 0, -24224, 0, -458, 0, -24223, 0, -165, 0, -24222, 0, -163, 0, -24221, 0, -457, 0, -24220, 0, -456, 0, -24219, 0, 12308, 0, -24218, 0, 12309, 0, -24217, 0, -455, 0, -24216, 0, -454, 0, -24215, 0, 12304, 0, -24214, 0, 12305, 0, -24213, 0, -453, 0, -24212, 0, -452, 0, -24211, 0, 12298, 0, -24210, 0, 12299, 0, -24209, 0, -451, 0, -24208, 0, -450, 0, -24207, 0, 12296, 0, -24206, 0, 12297, 0, -24205, 0, -449, 0, -24204, 0, -448, 0, -24203, 0, 12300, 0, -24202, 0, 12301, 0, -24201, 0, -447, 0, -24200, 0, -446, 0, -24199, 0, 12302, 0, -24198, 0, 12303, 0, -24197, 0, -445, 0, -24196, 0, -444, 0, -24195, 0, -423, 0, -24194, 0, -422, 0, -24159, 0, -421, 0, -24158, 0, -420, 0, -24157, 0, -419, 0, -24156, 0, -418, 0, -24155, 0, 8216, 0, -24154, 0, 8217, 0, -24153, 0, 8220, 0, -24152, 0, 8221, 0, -24151, 0, 12317, 0, -24150, 0, 12318, 0, -24149, 0, 8245, 0, -24148, 0, 8242, 0, -24147, 0, -253, 0, -24146, 0, -250, 0, -24145, 0, -246, 0, -24144, 0, 8251, 0, -24143, 0, 167, 0, -24142, 0, 12291, 0, -24141, 0, 9675, 0, -24140, 0, 9679, 0, -24139, 0, 9651, 0, -24138, 0, 9650, 0, -24137, 0, 9678, 0, -24136, 0, 9734, 0, -24135, 0, 9733, 0, -24134, 0, 9671, 0, -24133, 0, 9670, 0, -24132, 0, 9633, 0, -24131, 0, 9632, 0, -24130, 0, 9661, 0, -24129, 0, 9660, 0, -24128, 0, 12963, 0, -24127, 0, 8453, 0, -24126, 0, 175, 0, -24125, 0, -29, 0, -24124, 0, -193, 0, -24123, 0, 717, 0, -24122, 0, -439, 0, -24121, 0, -438, 0, -24120, 0, -435, 0, -24119, 0, -434, 0, -24118, 0, -437, 0, -24117, 0, -436, 0, -24116, 0, -417, 0, -24115, 0, -416, 0, -24114, 0, -415, 0, -24113, 0, -245, 0, -24112, 0, -243, 0, -24111, 0, 215, 0, -24110, 0, 247, 0, -24109, 0, 177, 0, -24108, 0, 8730, 0, -24107, 0, -228, 0, -24106, 0, -226, 0, -24105, 0, -227, 0, -24104, 0, 8806, 0, -24103, 0, 8807, 0, -24102, 0, 8800, 0, -24101, 0, 8734, 0, -24100, 0, 8786, 0, -24099, 0, 8801, 0, -24098, 0, -414, 0, -24097, 0, -413, 0, -24096, 0, -412, 0, -24095, 0, -411, 0, -24094, 0, -410, 0, -24093, 0, 8764, 0, -24092, 0, 8745, 0, -24091, 0, 8746, 0, -24090, 0, 8869, 0, -24089, 0, 8736, 0, -24088, 0, 8735, 0, -24087, 0, 8895, 0, -24086, 0, 13266, 0, -24085, 0, 13265, 0, -24084, 0, 8747, 0, -24083, 0, 8750, 0, -24082, 0, 8757, 0, -24081, 0, 8756, 0, -24080, 0, 9792, 0, -24079, 0, 9794, 0, -24078, 0, 8853, 0, -24077, 0, 8857, 0, -24076, 0, 8593, 0, -24075, 0, 8595, 0, -24074, 0, 8592, 0, -24073, 0, 8594, 0, -24072, 0, 8598, 0, -24071, 0, 8599, 0, -24070, 0, 8601, 0, -24069, 0, 8600, 0, -24068, 0, 8741, 0, -24067, 0, 8739, 0, -24066, 0, -241, 0, -24000, 0, -196, 0, -23999, 0, 8725, 0, -23998, 0, -408, 0, -23997, 0, -252, 0, -23996, 0, -27, 0, -23995, 0, 12306, 0, -23994, 0, -32, 0, -23993, 0, -31, 0, -23992, 0, -251, 0, -23991, 0, -224, 0, -23990, 0, 8451, 0, -23989, 0, 8457, 0, -23988, 0, -407, 0, -23987, 0, -406, 0, -23986, 0, -405, 0, -23985, 0, 13269, 0, -23984, 0, 13212, 0, -23983, 0, 13213, 0, -23982, 0, 13214, 0, -23981, 0, 13262, 0, -23980, 0, 13217, 0, -23979, 0, 13198, 0, -23978, 0, 13199, 0, -23977, 0, 13252, 0, -23976, 0, 176, 0, -23975, 0, 20825, 0, -23974, 0, 20827, 0, -23973, 0, 20830, 0, -23972, 0, 20829, 0, -23971, 0, 20833, 0, -23970, 0, 20835, 0, -23969, 0, 21991, 0, -23968, 0, 29929, 0, -23967, 0, 31950, 0, -23966, 0, 9601, 0, -23965, 0, 9602, 0, -23964, 0, 9603, 0, -23963, 0, 9604, 0, -23962, 0, 9605, 0, -23961, 0, 9606, 0, -23960, 0, 9607, 0, -23959, 0, 9608, 0, -23958, 0, 9615, 0, -23957, 0, 9614, 0, -23956, 0, 9613, 0, -23955, 0, 9612, 0, -23954, 0, 9611, 0, -23953, 0, 9610, 0, -23952, 0, 9609, 0, -23951, 0, 9532, 0, -23950, 0, 9524, 0, -23949, 0, 9516, 0, -23948, 0, 9508, 0, -23947, 0, 9500, 0, -23946, 0, 9620, 0, -23945, 0, 9472, 0, -23944, 0, 9474, 0, -23943, 0, 9621, 0, -23942, 0, 9484, 0, -23941, 0, 9488, 0, -23940, 0, 9492, 0, -23939, 0, 9496, 0, -23938, 0, 9581, 0, -23903, 0, 9582, 0, -23902, 0, 9584, 0, -23901, 0, 9583, 0, -23900, 0, 9552, 0, -23899, 0, 9566, 0, -23898, 0, 9578, 0, -23897, 0, 9569, 0, -23896, 0, 9698, 0, -23895, 0, 9699, 0, -23894, 0, 9701, 0, -23893, 0, 9700, 0, -23892, 0, 9585, 0, -23891, 0, 9586, 0, -23890, 0, 9587, 0, -23889, 0, -240, 0, -23888, 0, -239, 0, -23887, 0, -238, 0, -23886, 0, -237, 0, -23885, 0, -236, 0, -23884, 0, -235, 0, -23883, 0, -234, 0, -23882, 0, -233, 0, -23881, 0, -232, 0, -23880, 0, -231, 0, -23879, 0, 8544, 0, -23878, 0, 8545, 0, -23877, 0, 8546, 0, -23876, 0, 8547, 0, -23875, 0, 8548, 0, -23874, 0, 8549, 0, -23873, 0, 8550, 0, -23872, 0, 8551, 0, -23871, 0, 8552, 0, -23870, 0, 8553, 0, -23869, 0, 12321, 0, -23868, 0, 12322, 0, -23867, 0, 12323, 0, -23866, 0, 12324, 0, -23865, 0, 12325, 0, -23864, 0, 12326, 0, -23863, 0, 12327, 0, -23862, 0, 12328, 0, -23861, 0, 12329, 0, -23860, 0, 21313, 0, -23859, 0, 21316, 0, -23858, 0, 21317, 0, -23857, 0, -223, 0, -23856, 0, -222, 0, -23855, 0, -221, 0, -23854, 0, -220, 0, -23853, 0, -219, 0, -23852, 0, -218, 0, -23851, 0, -217, 0, -23850, 0, -216, 0, -23849, 0, -215, 0, -23848, 0, -214, 0, -23847, 0, -213, 0, -23846, 0, -212, 0, -23845, 0, -211, 0, -23844, 0, -210, 0, -23843, 0, -209, 0, -23842, 0, -208, 0, -23841, 0, -207, 0, -23840, 0, -206, 0, -23839, 0, -205, 0, -23838, 0, -204, 0, -23837, 0, -203, 0, -23836, 0, -202, 0, -23835, 0, -201, 0, -23834, 0, -200, 0, -23833, 0, -199, 0, -23832, 0, -198, 0, -23831, 0, -191, 0, -23830, 0, -190, 0, -23829, 0, -189, 0, -23828, 0, -188, 0, -23827, 0, -187, 0, -23826, 0, -186, 0, -23825, 0, -185, 0, -23824, 0, -184, 0, -23823, 0, -183, 0, -23822, 0, -182, 0, -23821, 0, -181, 0, -23820, 0, -180, 0, -23819, 0, -179, 0, -23818, 0, -178, 0, -23817, 0, -177, 0, -23816, 0, -176, 0, -23815, 0, -175, 0, -23814, 0, -174, 0, -23813, 0, -173, 0, -23812, 0, -172, 0, -23811, 0, -171, 0, -23810, 0, -170, 0, -23744, 0, -169, 0, -23743, 0, -168, 0, -23742, 0, -167, 0, -23741, 0, -166, 0, -23740, 0, 913, 0, -23739, 0, 914, 0, -23738, 0, 915, 0, -23737, 0, 916, 0, -23736, 0, 917, 0, -23735, 0, 918, 0, -23734, 0, 919, 0, -23733, 0, 920, 0, -23732, 0, 921, 0, -23731, 0, 922, 0, -23730, 0, 923, 0, -23729, 0, 924, 0, -23728, 0, 925, 0, -23727, 0, 926, 0, -23726, 0, 927, 0, -23725, 0, 928, 0, -23724, 0, 929, 0, -23723, 0, 931, 0, -23722, 0, 932, 0, -23721, 0, 933, 0, -23720, 0, 934, 0, -23719, 0, 935, 0, -23718, 0, 936, 0, -23717, 0, 937, 0, -23716, 0, 945, 0, -23715, 0, 946, 0, -23714, 0, 947, 0, -23713, 0, 948, 0, -23712, 0, 949, 0, -23711, 0, 950, 0, -23710, 0, 951, 0, -23709, 0, 952, 0, -23708, 0, 953, 0, -23707, 0, 954, 0, -23706, 0, 955, 0, -23705, 0, 956, 0, -23704, 0, 957, 0, -23703, 0, 958, 0, -23702, 0, 959, 0, -23701, 0, 960, 0, -23700, 0, 961, 0, -23699, 0, 963, 0, -23698, 0, 964, 0, -23697, 0, 965, 0, -23696, 0, 966, 0, -23695, 0, 967, 0, -23694, 0, 968, 0, -23693, 0, 969, 0, -23692, 0, 12549, 0, -23691, 0, 12550, 0, -23690, 0, 12551, 0, -23689, 0, 12552, 0, -23688, 0, 12553, 0, -23687, 0, 12554, 0, -23686, 0, 12555, 0, -23685, 0, 12556, 0, -23684, 0, 12557, 0, -23683, 0, 12558, 0, -23682, 0, 12559, 0, -23647, 0, 12560, 0, -23646, 0, 12561, 0, -23645, 0, 12562, 0, -23644, 0, 12563, 0, -23643, 0, 12564, 0, -23642, 0, 12565, 0, -23641, 0, 12566, 0, -23640, 0, 12567, 0, -23639, 0, 12568, 0, -23638, 0, 12569, 0, -23637, 0, 12570, 0, -23636, 0, 12571, 0, -23635, 0, 12572, 0, -23634, 0, 12573, 0, -23633, 0, 12574, 0, -23632, 0, 12575, 0, -23631, 0, 12576, 0, -23630, 0, 12577, 0, -23629, 0, 12578, 0, -23628, 0, 12579, 0, -23627, 0, 12580, 0, -23626, 0, 12581, 0, -23625, 0, 12582, 0, -23624, 0, 12583, 0, -23623, 0, 12584, 0, -23622, 0, 12585, 0, -23621, 0, 729, 0, -23620, 0, 713, 0, -23619, 0, 714, 0, -23618, 0, 711, 0, -23617, 0, 715, 0, -23488, 0, 19968, 0, -23487, 0, 20057, 0, -23486, 0, 19969, 0, -23485, 0, 19971, 0, -23484, 0, 20035, 0, -23483, 0, 20061, 0, -23482, 0, 20102, 0, -23481, 0, 20108, 0, -23480, 0, 20154, 0, -23479, 0, 20799, 0, -23478, 0, 20837, 0, -23477, 0, 20843, 0, -23476, 0, 20960, 0, -23475, 0, 20992, 0, -23474, 0, 20993, 0, -23473, 0, 21147, 0, -23472, 0, 21269, 0, -23471, 0, 21313, 0, -23470, 0, 21340, 0, -23469, 0, 21448, 0, -23468, 0, 19977, 0, -23467, 0, 19979, 0, -23466, 0, 19976, 0, -23465, 0, 19978, 0, -23464, 0, 20011, 0, -23463, 0, 20024, 0, -23462, 0, 20961, 0, -23461, 0, 20037, 0, -23460, 0, 20040, 0, -23459, 0, 20063, 0, -23458, 0, 20062, 0, -23457, 0, 20110, 0, -23456, 0, 20129, 0, -23455, 0, 20800, 0, -23454, 0, 20995, 0, -23453, 0, 21242, 0, -23452, 0, 21315, 0, -23451, 0, 21449, 0, -23450, 0, 21475, 0, -23449, 0, 22303, 0, -23448, 0, 22763, 0, -23447, 0, 22805, 0, -23446, 0, 22823, 0, -23445, 0, 22899, 0, -23444, 0, 23376, 0, -23443, 0, 23377, 0, -23442, 0, 23379, 0, -23441, 0, 23544, 0, -23440, 0, 23567, 0, -23439, 0, 23586, 0, -23438, 0, 23608, 0, -23437, 0, 23665, 0, -23436, 0, 24029, 0, -23435, 0, 24037, 0, -23434, 0, 24049, 0, -23433, 0, 24050, 0, -23432, 0, 24051, 0, -23431, 0, 24062, 0, -23430, 0, 24178, 0, -23429, 0, 24318, 0, -23428, 0, 24331, 0, -23427, 0, 24339, 0, -23426, 0, 25165, 0, -23391, 0, 19985, 0, -23390, 0, 19984, 0, -23389, 0, 19981, 0, -23388, 0, 20013, 0, -23387, 0, 20016, 0, -23386, 0, 20025, 0, -23385, 0, 20043, 0, -23384, 0, 23609, 0, -23383, 0, 20104, 0, -23382, 0, 20113, 0, -23381, 0, 20117, 0, -23380, 0, 20114, 0, -23379, 0, 20116, 0, -23378, 0, 20130, 0, -23377, 0, 20161, 0, -23376, 0, 20160, 0, -23375, 0, 20163, 0, -23374, 0, 20166, 0, -23373, 0, 20167, 0, -23372, 0, 20173, 0, -23371, 0, 20170, 0, -23370, 0, 20171, 0, -23369, 0, 20164, 0, -23368, 0, 20803, 0, -23367, 0, 20801, 0, -23366, 0, 20839, 0, -23365, 0, 20845, 0, -23364, 0, 20846, 0, -23363, 0, 20844, 0, -23362, 0, 20887, 0, -23361, 0, 20982, 0, -23360, 0, 20998, 0, -23359, 0, 20999, 0, -23358, 0, 21000, 0, -23357, 0, 21243, 0, -23356, 0, 21246, 0, -23355, 0, 21247, 0, -23354, 0, 21270, 0, -23353, 0, 21305, 0, -23352, 0, 21320, 0, -23351, 0, 21319, 0, -23350, 0, 21317, 0, -23349, 0, 21342, 0, -23348, 0, 21380, 0, -23347, 0, 21451, 0, -23346, 0, 21450, 0, -23345, 0, 21453, 0, -23344, 0, 22764, 0, -23343, 0, 22825, 0, -23342, 0, 22827, 0, -23341, 0, 22826, 0, -23340, 0, 22829, 0, -23339, 0, 23380, 0, -23338, 0, 23569, 0, -23337, 0, 23588, 0, -23336, 0, 23610, 0, -23335, 0, 23663, 0, -23334, 0, 24052, 0, -23333, 0, 24187, 0, -23332, 0, 24319, 0, -23331, 0, 24340, 0, -23330, 0, 24341, 0, -23329, 0, 24515, 0, -23328, 0, 25096, 0, -23327, 0, 25142, 0, -23326, 0, 25163, 0, -23325, 0, 25166, 0, -23324, 0, 25903, 0, -23323, 0, 25991, 0, -23322, 0, 26007, 0, -23321, 0, 26020, 0, -23320, 0, 26041, 0, -23319, 0, 26085, 0, -23318, 0, 26352, 0, -23317, 0, 26376, 0, -23316, 0, 26408, 0, -23315, 0, 27424, 0, -23314, 0, 27490, 0, -23313, 0, 27513, 0, -23312, 0, 27595, 0, -23311, 0, 27604, 0, -23310, 0, 27611, 0, -23309, 0, 27663, 0, -23308, 0, 27700, 0, -23307, 0, 28779, 0, -23306, 0, 29226, 0, -23305, 0, 29238, 0, -23304, 0, 29243, 0, -23303, 0, 29255, 0, -23302, 0, 29273, 0, -23301, 0, 29275, 0, -23300, 0, 29356, 0, -23299, 0, 29579, 0, -23298, 0, 19993, 0, -23232, 0, 19990, 0, -23231, 0, 19989, 0, -23230, 0, 19988, 0, -23229, 0, 19992, 0, -23228, 0, 20027, 0, -23227, 0, 20045, 0, -23226, 0, 20047, 0, -23225, 0, 20046, 0, -23224, 0, 20197, 0, -23223, 0, 20184, 0, -23222, 0, 20180, 0, -23221, 0, 20181, 0, -23220, 0, 20182, 0, -23219, 0, 20183, 0, -23218, 0, 20195, 0, -23217, 0, 20196, 0, -23216, 0, 20185, 0, -23215, 0, 20190, 0, -23214, 0, 20805, 0, -23213, 0, 20804, 0, -23212, 0, 20873, 0, -23211, 0, 20874, 0, -23210, 0, 20908, 0, -23209, 0, 20985, 0, -23208, 0, 20986, 0, -23207, 0, 20984, 0, -23206, 0, 21002, 0, -23205, 0, 21152, 0, -23204, 0, 21151, 0, -23203, 0, 21253, 0, -23202, 0, 21254, 0, -23201, 0, 21271, 0, -23200, 0, 21277, 0, -23199, 0, 20191, 0, -23198, 0, 21322, 0, -23197, 0, 21321, 0, -23196, 0, 21345, 0, -23195, 0, 21344, 0, -23194, 0, 21359, 0, -23193, 0, 21358, 0, -23192, 0, 21435, 0, -23191, 0, 21487, 0, -23190, 0, 21476, 0, -23189, 0, 21491, 0, -23188, 0, 21484, 0, -23187, 0, 21486, 0, -23186, 0, 21481, 0, -23185, 0, 21480, 0, -23184, 0, 21500, 0, -23183, 0, 21496, 0, -23182, 0, 21493, 0, -23181, 0, 21483, 0, -23180, 0, 21478, 0, -23179, 0, 21482, 0, -23178, 0, 21490, 0, -23177, 0, 21489, 0, -23176, 0, 21488, 0, -23175, 0, 21477, 0, -23174, 0, 21485, 0, -23173, 0, 21499, 0, -23172, 0, 22235, 0, -23171, 0, 22234, 0, -23170, 0, 22806, 0, -23135, 0, 22830, 0, -23134, 0, 22833, 0, -23133, 0, 22900, 0, -23132, 0, 22902, 0, -23131, 0, 23381, 0, -23130, 0, 23427, 0, -23129, 0, 23612, 0, -23128, 0, 24040, 0, -23127, 0, 24039, 0, -23126, 0, 24038, 0, -23125, 0, 24066, 0, -23124, 0, 24067, 0, -23123, 0, 24179, 0, -23122, 0, 24188, 0, -23121, 0, 24321, 0, -23120, 0, 24344, 0, -23119, 0, 24343, 0, -23118, 0, 24517, 0, -23117, 0, 25098, 0, -23116, 0, 25171, 0, -23115, 0, 25172, 0, -23114, 0, 25170, 0, -23113, 0, 25169, 0, -23112, 0, 26021, 0, -23111, 0, 26086, 0, -23110, 0, 26414, 0, -23109, 0, 26412, 0, -23108, 0, 26410, 0, -23107, 0, 26411, 0, -23106, 0, 26413, 0, -23105, 0, 27491, 0, -23104, 0, 27597, 0, -23103, 0, 27665, 0, -23102, 0, 27664, 0, -23101, 0, 27704, 0, -23100, 0, 27713, 0, -23099, 0, 27712, 0, -23098, 0, 27710, 0, -23097, 0, 29359, 0, -23096, 0, 29572, 0, -23095, 0, 29577, 0, -23094, 0, 29916, 0, -23093, 0, 29926, 0, -23092, 0, 29976, 0, -23091, 0, 29983, 0, -23090, 0, 29992, 0, -23089, 0, 29993, 0, -23088, 0, 30000, 0, -23087, 0, 30001, 0, -23086, 0, 30002, 0, -23085, 0, 30003, 0, -23084, 0, 30091, 0, -23083, 0, 30333, 0, -23082, 0, 30382, 0, -23081, 0, 30399, 0, -23080, 0, 30446, 0, -23079, 0, 30683, 0, -23078, 0, 30690, 0, -23077, 0, 30707, 0, -23076, 0, 31034, 0, -23075, 0, 31166, 0, -23074, 0, 31348, 0, -23073, 0, 31435, 0, -23072, 0, 19998, 0, -23071, 0, 19999, 0, -23070, 0, 20050, 0, -23069, 0, 20051, 0, -23068, 0, 20073, 0, -23067, 0, 20121, 0, -23066, 0, 20132, 0, -23065, 0, 20134, 0, -23064, 0, 20133, 0, -23063, 0, 20223, 0, -23062, 0, 20233, 0, -23061, 0, 20249, 0, -23060, 0, 20234, 0, -23059, 0, 20245, 0, -23058, 0, 20237, 0, -23057, 0, 20240, 0, -23056, 0, 20241, 0, -23055, 0, 20239, 0, -23054, 0, 20210, 0, -23053, 0, 20214, 0, -23052, 0, 20219, 0, -23051, 0, 20208, 0, -23050, 0, 20211, 0, -23049, 0, 20221, 0, -23048, 0, 20225, 0, -23047, 0, 20235, 0, -23046, 0, 20809, 0, -23045, 0, 20807, 0, -23044, 0, 20806, 0, -23043, 0, 20808, 0, -23042, 0, 20840, 0, -22976, 0, 20849, 0, -22975, 0, 20877, 0, -22974, 0, 20912, 0, -22973, 0, 21015, 0, -22972, 0, 21009, 0, -22971, 0, 21010, 0, -22970, 0, 21006, 0, -22969, 0, 21014, 0, -22968, 0, 21155, 0, -22967, 0, 21256, 0, -22966, 0, 21281, 0, -22965, 0, 21280, 0, -22964, 0, 21360, 0, -22963, 0, 21361, 0, -22962, 0, 21513, 0, -22961, 0, 21519, 0, -22960, 0, 21516, 0, -22959, 0, 21514, 0, -22958, 0, 21520, 0, -22957, 0, 21505, 0, -22956, 0, 21515, 0, -22955, 0, 21508, 0, -22954, 0, 21521, 0, -22953, 0, 21517, 0, -22952, 0, 21512, 0, -22951, 0, 21507, 0, -22950, 0, 21518, 0, -22949, 0, 21510, 0, -22948, 0, 21522, 0, -22947, 0, 22240, 0, -22946, 0, 22238, 0, -22945, 0, 22237, 0, -22944, 0, 22323, 0, -22943, 0, 22320, 0, -22942, 0, 22312, 0, -22941, 0, 22317, 0, -22940, 0, 22316, 0, -22939, 0, 22319, 0, -22938, 0, 22313, 0, -22937, 0, 22809, 0, -22936, 0, 22810, 0, -22935, 0, 22839, 0, -22934, 0, 22840, 0, -22933, 0, 22916, 0, -22932, 0, 22904, 0, -22931, 0, 22915, 0, -22930, 0, 22909, 0, -22929, 0, 22905, 0, -22928, 0, 22914, 0, -22927, 0, 22913, 0, -22926, 0, 23383, 0, -22925, 0, 23384, 0, -22924, 0, 23431, 0, -22923, 0, 23432, 0, -22922, 0, 23429, 0, -22921, 0, 23433, 0, -22920, 0, 23546, 0, -22919, 0, 23574, 0, -22918, 0, 23673, 0, -22917, 0, 24030, 0, -22916, 0, 24070, 0, -22915, 0, 24182, 0, -22914, 0, 24180, 0, -22879, 0, 24335, 0, -22878, 0, 24347, 0, -22877, 0, 24537, 0, -22876, 0, 24534, 0, -22875, 0, 25102, 0, -22874, 0, 25100, 0, -22873, 0, 25101, 0, -22872, 0, 25104, 0, -22871, 0, 25187, 0, -22870, 0, 25179, 0, -22869, 0, 25176, 0, -22868, 0, 25910, 0, -22867, 0, 26089, 0, -22866, 0, 26088, 0, -22865, 0, 26092, 0, -22864, 0, 26093, 0, -22863, 0, 26354, 0, -22862, 0, 26355, 0, -22861, 0, 26377, 0, -22860, 0, 26429, 0, -22859, 0, 26420, 0, -22858, 0, 26417, 0, -22857, 0, 26421, 0, -22856, 0, 27425, 0, -22855, 0, 27492, 0, -22854, 0, 27515, 0, -22853, 0, 27670, 0, -22852, 0, 27741, 0, -22851, 0, 27735, 0, -22850, 0, 27737, 0, -22849, 0, 27743, 0, -22848, 0, 27744, 0, -22847, 0, 27728, 0, -22846, 0, 27733, 0, -22845, 0, 27745, 0, -22844, 0, 27739, 0, -22843, 0, 27725, 0, -22842, 0, 27726, 0, -22841, 0, 28784, 0, -22840, 0, 29279, 0, -22839, 0, 29277, 0, -22838, 0, 30334, 0, -22837, 0, 31481, 0, -22836, 0, 31859, 0, -22835, 0, 31992, 0, -22834, 0, 32566, 0, -22833, 0, 32650, 0, -22832, 0, 32701, 0, -22831, 0, -32767, 0, -22830, 0, -32765, 0, -22829, 0, -32756, 0, -22828, 0, -32750, 0, -22827, 0, -32717, 0, -22826, 0, -32641, 0, -22825, 0, -32631, 0, -22824, 0, -32629, 0, -22823, 0, -32628, 0, -22822, 0, -32285, 0, -22821, 0, -32278, 0, -22820, 0, -32269, 0, -22819, 0, -32260, 0, -22818, 0, -32244, 0, -22817, 0, -32229, 0, -22816, 0, -32225, 0, -22815, 0, -32146, 0, -22814, 0, -32142, 0, -22813, 0, -32130, 0, -22812, 0, -31125, 0, -22811, 0, -30656, 0, -22810, 0, -30644, 0, -22809, 0, -30621, 0, -22808, 0, -30337, 0, -22807, 0, -27103, 0, -22806, 0, 20018, 0, -22805, 0, 20136, 0, -22804, 0, 20301, 0, -22803, 0, 20303, 0, -22802, 0, 20295, 0, -22801, 0, 20311, 0, -22800, 0, 20318, 0, -22799, 0, 20276, 0, -22798, 0, 20315, 0, -22797, 0, 20309, 0, -22796, 0, 20272, 0, -22795, 0, 20304, 0, -22794, 0, 20305, 0, -22793, 0, 20285, 0, -22792, 0, 20282, 0, -22791, 0, 20280, 0, -22790, 0, 20291, 0, -22789, 0, 20308, 0, -22788, 0, 20284, 0, -22787, 0, 20294, 0, -22786, 0, 20323, 0, -22720, 0, 20316, 0, -22719, 0, 20320, 0, -22718, 0, 20271, 0, -22717, 0, 20302, 0, -22716, 0, 20278, 0, -22715, 0, 20313, 0, -22714, 0, 20317, 0, -22713, 0, 20296, 0, -22712, 0, 20314, 0, -22711, 0, 20812, 0, -22710, 0, 20811, 0, -22709, 0, 20813, 0, -22708, 0, 20853, 0, -22707, 0, 20918, 0, -22706, 0, 20919, 0, -22705, 0, 21029, 0, -22704, 0, 21028, 0, -22703, 0, 21033, 0, -22702, 0, 21034, 0, -22701, 0, 21032, 0, -22700, 0, 21163, 0, -22699, 0, 21161, 0, -22698, 0, 21162, 0, -22697, 0, 21164, 0, -22696, 0, 21283, 0, -22695, 0, 21363, 0, -22694, 0, 21365, 0, -22693, 0, 21533, 0, -22692, 0, 21549, 0, -22691, 0, 21534, 0, -22690, 0, 21566, 0, -22689, 0, 21542, 0, -22688, 0, 21582, 0, -22687, 0, 21543, 0, -22686, 0, 21574, 0, -22685, 0, 21571, 0, -22684, 0, 21555, 0, -22683, 0, 21576, 0, -22682, 0, 21570, 0, -22681, 0, 21531, 0, -22680, 0, 21545, 0, -22679, 0, 21578, 0, -22678, 0, 21561, 0, -22677, 0, 21563, 0, -22676, 0, 21560, 0, -22675, 0, 21550, 0, -22674, 0, 21557, 0, -22673, 0, 21558, 0, -22672, 0, 21536, 0, -22671, 0, 21564, 0, -22670, 0, 21568, 0, -22669, 0, 21553, 0, -22668, 0, 21547, 0, -22667, 0, 21535, 0, -22666, 0, 21548, 0, -22665, 0, 22250, 0, -22664, 0, 22256, 0, -22663, 0, 22244, 0, -22662, 0, 22251, 0, -22661, 0, 22346, 0, -22660, 0, 22353, 0, -22659, 0, 22336, 0, -22658, 0, 22349, 0, -22623, 0, 22343, 0, -22622, 0, 22350, 0, -22621, 0, 22334, 0, -22620, 0, 22352, 0, -22619, 0, 22351, 0, -22618, 0, 22331, 0, -22617, 0, 22767, 0, -22616, 0, 22846, 0, -22615, 0, 22941, 0, -22614, 0, 22930, 0, -22613, 0, 22952, 0, -22612, 0, 22942, 0, -22611, 0, 22947, 0, -22610, 0, 22937, 0, -22609, 0, 22934, 0, -22608, 0, 22925, 0, -22607, 0, 22948, 0, -22606, 0, 22931, 0, -22605, 0, 22922, 0, -22604, 0, 22949, 0, -22603, 0, 23389, 0, -22602, 0, 23388, 0, -22601, 0, 23386, 0, -22600, 0, 23387, 0, -22599, 0, 23436, 0, -22598, 0, 23435, 0, -22597, 0, 23439, 0, -22596, 0, 23596, 0, -22595, 0, 23616, 0, -22594, 0, 23617, 0, -22593, 0, 23615, 0, -22592, 0, 23614, 0, -22591, 0, 23696, 0, -22590, 0, 23697, 0, -22589, 0, 23700, 0, -22588, 0, 23692, 0, -22587, 0, 24043, 0, -22586, 0, 24076, 0, -22585, 0, 24207, 0, -22584, 0, 24199, 0, -22583, 0, 24202, 0, -22582, 0, 24311, 0, -22581, 0, 24324, 0, -22580, 0, 24351, 0, -22579, 0, 24420, 0, -22578, 0, 24418, 0, -22577, 0, 24439, 0, -22576, 0, 24441, 0, -22575, 0, 24536, 0, -22574, 0, 24524, 0, -22573, 0, 24535, 0, -22572, 0, 24525, 0, -22571, 0, 24561, 0, -22570, 0, 24555, 0, -22569, 0, 24568, 0, -22568, 0, 24554, 0, -22567, 0, 25106, 0, -22566, 0, 25105, 0, -22565, 0, 25220, 0, -22564, 0, 25239, 0, -22563, 0, 25238, 0, -22562, 0, 25216, 0, -22561, 0, 25206, 0, -22560, 0, 25225, 0, -22559, 0, 25197, 0, -22558, 0, 25226, 0, -22557, 0, 25212, 0, -22556, 0, 25214, 0, -22555, 0, 25209, 0, -22554, 0, 25203, 0, -22553, 0, 25234, 0, -22552, 0, 25199, 0, -22551, 0, 25240, 0, -22550, 0, 25198, 0, -22549, 0, 25237, 0, -22548, 0, 25235, 0, -22547, 0, 25233, 0, -22546, 0, 25222, 0, -22545, 0, 25913, 0, -22544, 0, 25915, 0, -22543, 0, 25912, 0, -22542, 0, 26097, 0, -22541, 0, 26356, 0, -22540, 0, 26463, 0, -22539, 0, 26446, 0, -22538, 0, 26447, 0, -22537, 0, 26448, 0, -22536, 0, 26449, 0, -22535, 0, 26460, 0, -22534, 0, 26454, 0, -22533, 0, 26462, 0, -22532, 0, 26441, 0, -22531, 0, 26438, 0, -22530, 0, 26464, 0, -22464, 0, 26451, 0, -22463, 0, 26455, 0, -22462, 0, 27493, 0, -22461, 0, 27599, 0, -22460, 0, 27714, 0, -22459, 0, 27742, 0, -22458, 0, 27801, 0, -22457, 0, 27777, 0, -22456, 0, 27784, 0, -22455, 0, 27785, 0, -22454, 0, 27781, 0, -22453, 0, 27803, 0, -22452, 0, 27754, 0, -22451, 0, 27770, 0, -22450, 0, 27792, 0, -22449, 0, 27760, 0, -22448, 0, 27788, 0, -22447, 0, 27752, 0, -22446, 0, 27798, 0, -22445, 0, 27794, 0, -22444, 0, 27773, 0, -22443, 0, 27779, 0, -22442, 0, 27762, 0, -22441, 0, 27774, 0, -22440, 0, 27764, 0, -22439, 0, 27782, 0, -22438, 0, 27766, 0, -22437, 0, 27789, 0, -22436, 0, 27796, 0, -22435, 0, 27800, 0, -22434, 0, 27778, 0, -22433, 0, 28790, 0, -22432, 0, 28796, 0, -22431, 0, 28797, 0, -22430, 0, 28792, 0, -22429, 0, 29282, 0, -22428, 0, 29281, 0, -22427, 0, 29280, 0, -22426, 0, 29380, 0, -22425, 0, 29378, 0, -22424, 0, 29590, 0, -22423, 0, 29996, 0, -22422, 0, 29995, 0, -22421, 0, 30007, 0, -22420, 0, 30008, 0, -22419, 0, 30338, 0, -22418, 0, 30447, 0, -22417, 0, 30691, 0, -22416, 0, 31169, 0, -22415, 0, 31168, 0, -22414, 0, 31167, 0, -22413, 0, 31350, 0, -22412, 0, 31995, 0, -22411, 0, 32597, 0, -22410, 0, -32618, 0, -22409, 0, -32621, 0, -22408, 0, -32611, 0, -22407, 0, -32616, 0, -22406, 0, -32613, 0, -22405, 0, -32614, 0, -22404, 0, -32590, 0, -22403, 0, -32145, 0, -22402, 0, -32110, 0, -22367, 0, -32117, 0, -22366, 0, -32115, 0, -22365, 0, -30325, 0, -22364, 0, -30254, 0, -22363, 0, -30208, 0, -22362, 0, -29641, 0, -22361, 0, -29626, 0, -22360, 0, -29611, 0, -22359, 0, -29539, 0, -22358, 0, -29340, 0, -22357, 0, -29328, 0, -22356, 0, -29261, 0, -22355, 0, -29013, 0, -22354, 0, -28982, 0, -22353, 0, -28773, 0, -22352, 0, -28752, 0, -22351, 0, -28734, 0, -22350, 0, -28730, 0, -22349, 0, -28731, 0, -22348, 0, -28732, 0, -22347, 0, 24033, 0, -22346, 0, -28527, 0, -22345, 0, -28510, 0, -22344, 0, -28502, 0, -22343, 0, -28506, 0, -22342, 0, -28509, 0, -22341, 0, -28343, 0, -22340, 0, -28218, 0, -22339, 0, -28212, 0, -22338, 0, -27086, 0, -22337, 0, -27090, 0, -22336, 0, -27087, 0, -22335, 0, -27094, 0, -22334, 0, -27092, 0, -22333, 0, 20006, 0, -22332, 0, 20054, 0, -22331, 0, 20083, 0, -22330, 0, 20107, 0, -22329, 0, 20123, 0, -22328, 0, 20126, 0, -22327, 0, 20139, 0, -22326, 0, 20140, 0, -22325, 0, 20335, 0, -22324, 0, 20381, 0, -22323, 0, 20365, 0, -22322, 0, 20339, 0, -22321, 0, 20351, 0, -22320, 0, 20332, 0, -22319, 0, 20379, 0, -22318, 0, 20363, 0, -22317, 0, 20358, 0, -22316, 0, 20355, 0, -22315, 0, 20336, 0, -22314, 0, 20341, 0, -22313, 0, 20360, 0, -22312, 0, 20329, 0, -22311, 0, 20347, 0, -22310, 0, 20374, 0, -22309, 0, 20350, 0, -22308, 0, 20367, 0, -22307, 0, 20369, 0, -22306, 0, 20346, 0, -22305, 0, 20820, 0, -22304, 0, 20818, 0, -22303, 0, 20821, 0, -22302, 0, 20841, 0, -22301, 0, 20855, 0, -22300, 0, 20854, 0, -22299, 0, 20856, 0, -22298, 0, 20925, 0, -22297, 0, 20989, 0, -22296, 0, 21051, 0, -22295, 0, 21048, 0, -22294, 0, 21047, 0, -22293, 0, 21050, 0, -22292, 0, 21040, 0, -22291, 0, 21038, 0, -22290, 0, 21046, 0, -22289, 0, 21057, 0, -22288, 0, 21182, 0, -22287, 0, 21179, 0, -22286, 0, 21330, 0, -22285, 0, 21332, 0, -22284, 0, 21331, 0, -22283, 0, 21329, 0, -22282, 0, 21350, 0, -22281, 0, 21367, 0, -22280, 0, 21368, 0, -22279, 0, 21369, 0, -22278, 0, 21462, 0, -22277, 0, 21460, 0, -22276, 0, 21463, 0, -22275, 0, 21619, 0, -22274, 0, 21621, 0, -22208, 0, 21654, 0, -22207, 0, 21624, 0, -22206, 0, 21653, 0, -22205, 0, 21632, 0, -22204, 0, 21627, 0, -22203, 0, 21623, 0, -22202, 0, 21636, 0, -22201, 0, 21650, 0, -22200, 0, 21638, 0, -22199, 0, 21628, 0, -22198, 0, 21648, 0, -22197, 0, 21617, 0, -22196, 0, 21622, 0, -22195, 0, 21644, 0, -22194, 0, 21658, 0, -22193, 0, 21602, 0, -22192, 0, 21608, 0, -22191, 0, 21643, 0, -22190, 0, 21629, 0, -22189, 0, 21646, 0, -22188, 0, 22266, 0, -22187, 0, 22403, 0, -22186, 0, 22391, 0, -22185, 0, 22378, 0, -22184, 0, 22377, 0, -22183, 0, 22369, 0, -22182, 0, 22374, 0, -22181, 0, 22372, 0, -22180, 0, 22396, 0, -22179, 0, 22812, 0, -22178, 0, 22857, 0, -22177, 0, 22855, 0, -22176, 0, 22856, 0, -22175, 0, 22852, 0, -22174, 0, 22868, 0, -22173, 0, 22974, 0, -22172, 0, 22971, 0, -22171, 0, 22996, 0, -22170, 0, 22969, 0, -22169, 0, 22958, 0, -22168, 0, 22993, 0, -22167, 0, 22982, 0, -22166, 0, 22992, 0, -22165, 0, 22989, 0, -22164, 0, 22987, 0, -22163, 0, 22995, 0, -22162, 0, 22986, 0, -22161, 0, 22959, 0, -22160, 0, 22963, 0, -22159, 0, 22994, 0, -22158, 0, 22981, 0, -22157, 0, 23391, 0, -22156, 0, 23396, 0, -22155, 0, 23395, 0, -22154, 0, 23447, 0, -22153, 0, 23450, 0, -22152, 0, 23448, 0, -22151, 0, 23452, 0, -22150, 0, 23449, 0, -22149, 0, 23451, 0, -22148, 0, 23578, 0, -22147, 0, 23624, 0, -22146, 0, 23621, 0, -22111, 0, 23622, 0, -22110, 0, 23735, 0, -22109, 0, 23713, 0, -22108, 0, 23736, 0, -22107, 0, 23721, 0, -22106, 0, 23723, 0, -22105, 0, 23729, 0, -22104, 0, 23731, 0, -22103, 0, 24088, 0, -22102, 0, 24090, 0, -22101, 0, 24086, 0, -22100, 0, 24085, 0, -22099, 0, 24091, 0, -22098, 0, 24081, 0, -22097, 0, 24184, 0, -22096, 0, 24218, 0, -22095, 0, 24215, 0, -22094, 0, 24220, 0, -22093, 0, 24213, 0, -22092, 0, 24214, 0, -22091, 0, 24310, 0, -22090, 0, 24358, 0, -22089, 0, 24359, 0, -22088, 0, 24361, 0, -22087, 0, 24448, 0, -22086, 0, 24449, 0, -22085, 0, 24447, 0, -22084, 0, 24444, 0, -22083, 0, 24541, 0, -22082, 0, 24544, 0, -22081, 0, 24573, 0, -22080, 0, 24565, 0, -22079, 0, 24575, 0, -22078, 0, 24591, 0, -22077, 0, 24596, 0, -22076, 0, 24623, 0, -22075, 0, 24629, 0, -22074, 0, 24598, 0, -22073, 0, 24618, 0, -22072, 0, 24597, 0, -22071, 0, 24609, 0, -22070, 0, 24615, 0, -22069, 0, 24617, 0, -22068, 0, 24619, 0, -22067, 0, 24603, 0, -22066, 0, 25110, 0, -22065, 0, 25109, 0, -22064, 0, 25151, 0, -22063, 0, 25150, 0, -22062, 0, 25152, 0, -22061, 0, 25215, 0, -22060, 0, 25289, 0, -22059, 0, 25292, 0, -22058, 0, 25284, 0, -22057, 0, 25279, 0, -22056, 0, 25282, 0, -22055, 0, 25273, 0, -22054, 0, 25298, 0, -22053, 0, 25307, 0, -22052, 0, 25259, 0, -22051, 0, 25299, 0, -22050, 0, 25300, 0, -22049, 0, 25291, 0, -22048, 0, 25288, 0, -22047, 0, 25256, 0, -22046, 0, 25277, 0, -22045, 0, 25276, 0, -22044, 0, 25296, 0, -22043, 0, 25305, 0, -22042, 0, 25287, 0, -22041, 0, 25293, 0, -22040, 0, 25269, 0, -22039, 0, 25306, 0, -22038, 0, 25265, 0, -22037, 0, 25304, 0, -22036, 0, 25302, 0, -22035, 0, 25303, 0, -22034, 0, 25286, 0, -22033, 0, 25260, 0, -22032, 0, 25294, 0, -22031, 0, 25918, 0, -22030, 0, 26023, 0, -22029, 0, 26044, 0, -22028, 0, 26106, 0, -22027, 0, 26132, 0, -22026, 0, 26131, 0, -22025, 0, 26124, 0, -22024, 0, 26118, 0, -22023, 0, 26114, 0, -22022, 0, 26126, 0, -22021, 0, 26112, 0, -22020, 0, 26127, 0, -22019, 0, 26133, 0, -22018, 0, 26122, 0, -21952, 0, 26119, 0, -21951, 0, 26381, 0, -21950, 0, 26379, 0, -21949, 0, 26477, 0, -21948, 0, 26507, 0, -21947, 0, 26517, 0, -21946, 0, 26481, 0, -21945, 0, 26524, 0, -21944, 0, 26483, 0, -21943, 0, 26487, 0, -21942, 0, 26503, 0, -21941, 0, 26525, 0, -21940, 0, 26519, 0, -21939, 0, 26479, 0, -21938, 0, 26480, 0, -21937, 0, 26495, 0, -21936, 0, 26505, 0, -21935, 0, 26494, 0, -21934, 0, 26512, 0, -21933, 0, 26485, 0, -21932, 0, 26522, 0, -21931, 0, 26515, 0, -21930, 0, 26492, 0, -21929, 0, 26474, 0, -21928, 0, 26482, 0, -21927, 0, 27427, 0, -21926, 0, 27494, 0, -21925, 0, 27495, 0, -21924, 0, 27519, 0, -21923, 0, 27667, 0, -21922, 0, 27675, 0, -21921, 0, 27875, 0, -21920, 0, 27880, 0, -21919, 0, 27891, 0, -21918, 0, 27825, 0, -21917, 0, 27852, 0, -21916, 0, 27877, 0, -21915, 0, 27827, 0, -21914, 0, 27837, 0, -21913, 0, 27838, 0, -21912, 0, 27836, 0, -21911, 0, 27874, 0, -21910, 0, 27819, 0, -21909, 0, 27861, 0, -21908, 0, 27859, 0, -21907, 0, 27832, 0, -21906, 0, 27844, 0, -21905, 0, 27833, 0, -21904, 0, 27841, 0, -21903, 0, 27822, 0, -21902, 0, 27863, 0, -21901, 0, 27845, 0, -21900, 0, 27889, 0, -21899, 0, 27839, 0, -21898, 0, 27835, 0, -21897, 0, 27873, 0, -21896, 0, 27867, 0, -21895, 0, 27850, 0, -21894, 0, 27820, 0, -21893, 0, 27887, 0, -21892, 0, 27868, 0, -21891, 0, 27862, 0, -21890, 0, 27872, 0, -21855, 0, 28821, 0, -21854, 0, 28814, 0, -21853, 0, 28818, 0, -21852, 0, 28810, 0, -21851, 0, 28825, 0, -21850, 0, 29228, 0, -21849, 0, 29229, 0, -21848, 0, 29240, 0, -21847, 0, 29256, 0, -21846, 0, 29287, 0, -21845, 0, 29289, 0, -21844, 0, 29376, 0, -21843, 0, 29390, 0, -21842, 0, 29401, 0, -21841, 0, 29399, 0, -21840, 0, 29392, 0, -21839, 0, 29609, 0, -21838, 0, 29608, 0, -21837, 0, 29599, 0, -21836, 0, 29611, 0, -21835, 0, 29605, 0, -21834, 0, 30013, 0, -21833, 0, 30109, 0, -21832, 0, 30105, 0, -21831, 0, 30106, 0, -21830, 0, 30340, 0, -21829, 0, 30402, 0, -21828, 0, 30450, 0, -21827, 0, 30452, 0, -21826, 0, 30693, 0, -21825, 0, 30717, 0, -21824, 0, 31038, 0, -21823, 0, 31040, 0, -21822, 0, 31041, 0, -21821, 0, 31177, 0, -21820, 0, 31176, 0, -21819, 0, 31354, 0, -21818, 0, 31353, 0, -21817, 0, 31482, 0, -21816, 0, 31998, 0, -21815, 0, 32596, 0, -21814, 0, 32652, 0, -21813, 0, 32651, 0, -21812, 0, -32763, 0, -21811, 0, -32582, 0, -21810, 0, -32603, 0, -21809, 0, -32606, 0, -21808, 0, -32591, 0, -21807, 0, -32607, 0, -21806, 0, -32597, 0, -21805, 0, -32599, 0, -21804, 0, -32588, 0, -21803, 0, -32598, 0, -21802, 0, -32593, 0, -21801, 0, -32283, 0, -21800, 0, -32258, 0, -21799, 0, -32243, 0, -21798, 0, -32077, 0, -21797, 0, -32099, 0, -21796, 0, -32103, 0, -21795, 0, -32083, 0, -21794, 0, -32067, 0, -21793, 0, -32097, 0, -21792, 0, -32071, 0, -21791, 0, -32079, 0, -21790, 0, -32084, 0, -21789, 0, -32091, 0, -21788, 0, -32081, 0, -21787, 0, -32072, 0, -21786, 0, -32093, 0, -21785, 0, -32080, 0, -21784, 0, -32066, 0, -21783, 0, -32073, 0, -21782, 0, -31154, 0, -21781, 0, -31119, 0, -21780, 0, 21021, 0, -21779, 0, -30616, 0, -21778, 0, -28981, 0, -21777, 0, -28722, 0, -21776, 0, -28716, 0, -21775, 0, -28719, 0, -21774, 0, -28491, 0, -21773, 0, -28488, 0, -21772, 0, -28495, 0, -21771, 0, -28490, 0, -21770, 0, -28217, 0, -21769, 0, -28207, 0, -21768, 0, -27273, 0, -21767, 0, -27264, 0, -21766, 0, -27108, 0, -21765, 0, -27072, 0, -21764, 0, -27073, 0, -21763, 0, -27077, 0, -21762, 0, -27068, 0, -21696, 0, -27070, 0, -21695, 0, -26951, 0, -21694, 0, -26904, 0, -21693, 0, -26798, 0, -21692, 0, -26786, 0, -21691, 0, 20127, 0, -21690, 0, 20141, 0, -21689, 0, 20142, 0, -21688, 0, 20449, 0, -21687, 0, 20405, 0, -21686, 0, 20399, 0, -21685, 0, 20415, 0, -21684, 0, 20448, 0, -21683, 0, 20433, 0, -21682, 0, 20431, 0, -21681, 0, 20445, 0, -21680, 0, 20419, 0, -21679, 0, 20406, 0, -21678, 0, 20440, 0, -21677, 0, 20447, 0, -21676, 0, 20426, 0, -21675, 0, 20439, 0, -21674, 0, 20398, 0, -21673, 0, 20432, 0, -21672, 0, 20420, 0, -21671, 0, 20418, 0, -21670, 0, 20442, 0, -21669, 0, 20430, 0, -21668, 0, 20446, 0, -21667, 0, 20407, 0, -21666, 0, 20823, 0, -21665, 0, 20882, 0, -21664, 0, 20881, 0, -21663, 0, 20896, 0, -21662, 0, 21070, 0, -21661, 0, 21059, 0, -21660, 0, 21066, 0, -21659, 0, 21069, 0, -21658, 0, 21068, 0, -21657, 0, 21067, 0, -21656, 0, 21063, 0, -21655, 0, 21191, 0, -21654, 0, 21193, 0, -21653, 0, 21187, 0, -21652, 0, 21185, 0, -21651, 0, 21261, 0, -21650, 0, 21335, 0, -21649, 0, 21371, 0, -21648, 0, 21402, 0, -21647, 0, 21467, 0, -21646, 0, 21676, 0, -21645, 0, 21696, 0, -21644, 0, 21672, 0, -21643, 0, 21710, 0, -21642, 0, 21705, 0, -21641, 0, 21688, 0, -21640, 0, 21670, 0, -21639, 0, 21683, 0, -21638, 0, 21703, 0, -21637, 0, 21698, 0, -21636, 0, 21693, 0, -21635, 0, 21674, 0, -21634, 0, 21697, 0, -21599, 0, 21700, 0, -21598, 0, 21704, 0, -21597, 0, 21679, 0, -21596, 0, 21675, 0, -21595, 0, 21681, 0, -21594, 0, 21691, 0, -21593, 0, 21673, 0, -21592, 0, 21671, 0, -21591, 0, 21695, 0, -21590, 0, 22271, 0, -21589, 0, 22402, 0, -21588, 0, 22411, 0, -21587, 0, 22432, 0, -21586, 0, 22435, 0, -21585, 0, 22434, 0, -21584, 0, 22478, 0, -21583, 0, 22446, 0, -21582, 0, 22419, 0, -21581, 0, 22869, 0, -21580, 0, 22865, 0, -21579, 0, 22863, 0, -21578, 0, 22862, 0, -21577, 0, 22864, 0, -21576, 0, 23004, 0, -21575, 0, 23000, 0, -21574, 0, 23039, 0, -21573, 0, 23011, 0, -21572, 0, 23016, 0, -21571, 0, 23043, 0, -21570, 0, 23013, 0, -21569, 0, 23018, 0, -21568, 0, 23002, 0, -21567, 0, 23014, 0, -21566, 0, 23041, 0, -21565, 0, 23035, 0, -21564, 0, 23401, 0, -21563, 0, 23459, 0, -21562, 0, 23462, 0, -21561, 0, 23460, 0, -21560, 0, 23458, 0, -21559, 0, 23461, 0, -21558, 0, 23553, 0, -21557, 0, 23630, 0, -21556, 0, 23631, 0, -21555, 0, 23629, 0, -21554, 0, 23627, 0, -21553, 0, 23769, 0, -21552, 0, 23762, 0, -21551, 0, 24055, 0, -21550, 0, 24093, 0, -21549, 0, 24101, 0, -21548, 0, 24095, 0, -21547, 0, 24189, 0, -21546, 0, 24224, 0, -21545, 0, 24230, 0, -21544, 0, 24314, 0, -21543, 0, 24328, 0, -21542, 0, 24365, 0, -21541, 0, 24421, 0, -21540, 0, 24456, 0, -21539, 0, 24453, 0, -21538, 0, 24458, 0, -21537, 0, 24459, 0, -21536, 0, 24455, 0, -21535, 0, 24460, 0, -21534, 0, 24457, 0, -21533, 0, 24594, 0, -21532, 0, 24605, 0, -21531, 0, 24608, 0, -21530, 0, 24613, 0, -21529, 0, 24590, 0, -21528, 0, 24616, 0, -21527, 0, 24653, 0, -21526, 0, 24688, 0, -21525, 0, 24680, 0, -21524, 0, 24674, 0, -21523, 0, 24646, 0, -21522, 0, 24643, 0, -21521, 0, 24684, 0, -21520, 0, 24683, 0, -21519, 0, 24682, 0, -21518, 0, 24676, 0, -21517, 0, 25153, 0, -21516, 0, 25308, 0, -21515, 0, 25366, 0, -21514, 0, 25353, 0, -21513, 0, 25340, 0, -21512, 0, 25325, 0, -21511, 0, 25345, 0, -21510, 0, 25326, 0, -21509, 0, 25341, 0, -21508, 0, 25351, 0, -21507, 0, 25329, 0, -21506, 0, 25335, 0, -21440, 0, 25327, 0, -21439, 0, 25324, 0, -21438, 0, 25342, 0, -21437, 0, 25332, 0, -21436, 0, 25361, 0, -21435, 0, 25346, 0, -21434, 0, 25919, 0, -21433, 0, 25925, 0, -21432, 0, 26027, 0, -21431, 0, 26045, 0, -21430, 0, 26082, 0, -21429, 0, 26149, 0, -21428, 0, 26157, 0, -21427, 0, 26144, 0, -21426, 0, 26151, 0, -21425, 0, 26159, 0, -21424, 0, 26143, 0, -21423, 0, 26152, 0, -21422, 0, 26161, 0, -21421, 0, 26148, 0, -21420, 0, 26359, 0, -21419, 0, 26623, 0, -21418, 0, 26579, 0, -21417, 0, 26609, 0, -21416, 0, 26580, 0, -21415, 0, 26576, 0, -21414, 0, 26604, 0, -21413, 0, 26550, 0, -21412, 0, 26543, 0, -21411, 0, 26613, 0, -21410, 0, 26601, 0, -21409, 0, 26607, 0, -21408, 0, 26564, 0, -21407, 0, 26577, 0, -21406, 0, 26548, 0, -21405, 0, 26586, 0, -21404, 0, 26597, 0, -21403, 0, 26552, 0, -21402, 0, 26575, 0, -21401, 0, 26590, 0, -21400, 0, 26611, 0, -21399, 0, 26544, 0, -21398, 0, 26585, 0, -21397, 0, 26594, 0, -21396, 0, 26589, 0, -21395, 0, 26578, 0, -21394, 0, 27498, 0, -21393, 0, 27523, 0, -21392, 0, 27526, 0, -21391, 0, 27573, 0, -21390, 0, 27602, 0, -21389, 0, 27607, 0, -21388, 0, 27679, 0, -21387, 0, 27849, 0, -21386, 0, 27915, 0, -21385, 0, 27954, 0, -21384, 0, 27946, 0, -21383, 0, 27969, 0, -21382, 0, 27941, 0, -21381, 0, 27916, 0, -21380, 0, 27953, 0, -21379, 0, 27934, 0, -21378, 0, 27927, 0, -21343, 0, 27963, 0, -21342, 0, 27965, 0, -21341, 0, 27966, 0, -21340, 0, 27958, 0, -21339, 0, 27931, 0, -21338, 0, 27893, 0, -21337, 0, 27961, 0, -21336, 0, 27943, 0, -21335, 0, 27960, 0, -21334, 0, 27945, 0, -21333, 0, 27950, 0, -21332, 0, 27957, 0, -21331, 0, 27918, 0, -21330, 0, 27947, 0, -21329, 0, 28843, 0, -21328, 0, 28858, 0, -21327, 0, 28851, 0, -21326, 0, 28844, 0, -21325, 0, 28847, 0, -21324, 0, 28845, 0, -21323, 0, 28856, 0, -21322, 0, 28846, 0, -21321, 0, 28836, 0, -21320, 0, 29232, 0, -21319, 0, 29298, 0, -21318, 0, 29295, 0, -21317, 0, 29300, 0, -21316, 0, 29417, 0, -21315, 0, 29408, 0, -21314, 0, 29409, 0, -21313, 0, 29623, 0, -21312, 0, 29642, 0, -21311, 0, 29627, 0, -21310, 0, 29618, 0, -21309, 0, 29645, 0, -21308, 0, 29632, 0, -21307, 0, 29619, 0, -21306, 0, 29978, 0, -21305, 0, 29997, 0, -21304, 0, 30031, 0, -21303, 0, 30028, 0, -21302, 0, 30030, 0, -21301, 0, 30027, 0, -21300, 0, 30123, 0, -21299, 0, 30116, 0, -21298, 0, 30117, 0, -21297, 0, 30114, 0, -21296, 0, 30115, 0, -21295, 0, 30328, 0, -21294, 0, 30342, 0, -21293, 0, 30343, 0, -21292, 0, 30344, 0, -21291, 0, 30408, 0, -21290, 0, 30406, 0, -21289, 0, 30403, 0, -21288, 0, 30405, 0, -21287, 0, 30465, 0, -21286, 0, 30457, 0, -21285, 0, 30456, 0, -21284, 0, 30473, 0, -21283, 0, 30475, 0, -21282, 0, 30462, 0, -21281, 0, 30460, 0, -21280, 0, 30471, 0, -21279, 0, 30684, 0, -21278, 0, 30722, 0, -21277, 0, 30740, 0, -21276, 0, 30732, 0, -21275, 0, 30733, 0, -21274, 0, 31046, 0, -21273, 0, 31049, 0, -21272, 0, 31048, 0, -21271, 0, 31047, 0, -21270, 0, 31161, 0, -21269, 0, 31162, 0, -21268, 0, 31185, 0, -21267, 0, 31186, 0, -21266, 0, 31179, 0, -21265, 0, 31359, 0, -21264, 0, 31361, 0, -21263, 0, 31487, 0, -21262, 0, 31485, 0, -21261, 0, 31869, 0, -21260, 0, 32002, 0, -21259, 0, 32005, 0, -21258, 0, 32000, 0, -21257, 0, 32009, 0, -21256, 0, 32007, 0, -21255, 0, 32004, 0, -21254, 0, 32006, 0, -21253, 0, 32568, 0, -21252, 0, 32654, 0, -21251, 0, 32703, 0, -21250, 0, -32764, 0, -21184, 0, -32752, 0, -21183, 0, -32755, 0, -21182, 0, -32751, 0, -21181, 0, -32714, 0, -21180, 0, -32554, 0, -21179, 0, -32539, 0, -21178, 0, -32550, 0, -21177, 0, -32573, 0, -21176, 0, -32572, 0, -21175, 0, -32564, 0, -21174, 0, -32543, 0, -21173, 0, -32549, 0, -21172, 0, -32562, 0, -21171, 0, -32546, 0, -21170, 0, -32540, 0, -21169, 0, -32547, 0, -21168, 0, -32268, 0, -21167, 0, -32222, 0, -21166, 0, -32025, 0, -21165, 0, -31997, 0, -21164, 0, -31995, 0, -21163, 0, -32029, 0, -21162, 0, -32037, 0, -21161, 0, -32026, 0, -21160, 0, -31996, 0, -21159, 0, -32027, 0, -21158, 0, -31998, 0, -21157, 0, -31991, 0, -21156, 0, -32046, 0, -21155, 0, -32041, 0, -21154, 0, -32015, 0, -21153, 0, -31999, 0, -21152, 0, -32036, 0, -21151, 0, -32044, 0, -21150, 0, -32047, 0, -21149, 0, -32034, 0, -21148, 0, -32045, 0, -21147, 0, -32033, 0, -21146, 0, -32017, 0, -21145, 0, -31994, 0, -21144, 0, -31152, 0, -21143, 0, -31111, 0, -21142, 0, -31109, 0, -21141, 0, -31110, 0, -21140, 0, -30643, 0, -21139, 0, -30613, 0, -21138, 0, -30335, 0, -21137, 0, -30252, 0, -21136, 0, -30200, 0, -21135, 0, -30206, 0, -21134, 0, -30205, 0, -21133, 0, -29538, 0, -21132, 0, -29536, 0, -21131, 0, -29324, 0, -21130, 0, -29325, 0, -21129, 0, -29260, 0, -21128, 0, -28979, 0, -21127, 0, -28980, 0, -21126, 0, -28688, 0, -21125, 0, -28698, 0, -21124, 0, -28702, 0, -21123, 0, -28694, 0, -21122, 0, -28699, 0, -21087, 0, -28691, 0, -21086, 0, -28693, 0, -21085, 0, -28700, 0, -21084, 0, -28696, 0, -21083, 0, -28470, 0, -21082, 0, -28466, 0, -21081, 0, -28479, 0, -21080, 0, -28477, 0, -21079, 0, -28341, 0, -21078, 0, -28342, 0, -21077, 0, -28211, 0, -21076, 0, -27262, 0, -21075, 0, -27056, 0, -21074, 0, -27061, 0, -21073, 0, -27060, 0, -21072, 0, -27059, 0, -21071, 0, -26782, 0, -21070, 0, -26775, 0, -21069, 0, -26677, 0, -21068, 0, -26643, 0, -21067, 0, -26637, 0, -21066, 0, -26623, 0, -21065, 0, -26456, 0, -21064, 0, -26405, 0, -21063, 0, -26401, 0, -21062, 0, -26218, 0, -21061, 0, -26215, 0, -21060, 0, 20056, 0, -21059, 0, 20147, 0, -21058, 0, 20492, 0, -21057, 0, 20493, 0, -21056, 0, 20515, 0, -21055, 0, 20463, 0, -21054, 0, 20518, 0, -21053, 0, 20517, 0, -21052, 0, 20472, 0, -21051, 0, 20521, 0, -21050, 0, 20502, 0, -21049, 0, 20486, 0, -21048, 0, 20540, 0, -21047, 0, 20511, 0, -21046, 0, 20506, 0, -21045, 0, 20498, 0, -21044, 0, 20497, 0, -21043, 0, 20474, 0, -21042, 0, 20480, 0, -21041, 0, 20500, 0, -21040, 0, 20520, 0, -21039, 0, 20465, 0, -21038, 0, 20513, 0, -21037, 0, 20491, 0, -21036, 0, 20505, 0, -21035, 0, 20504, 0, -21034, 0, 20467, 0, -21033, 0, 20462, 0, -21032, 0, 20525, 0, -21031, 0, 20522, 0, -21030, 0, 20478, 0, -21029, 0, 20523, 0, -21028, 0, 20489, 0, -21027, 0, 20860, 0, -21026, 0, 20900, 0, -21025, 0, 20901, 0, -21024, 0, 20898, 0, -21023, 0, 20941, 0, -21022, 0, 20940, 0, -21021, 0, 20934, 0, -21020, 0, 20939, 0, -21019, 0, 21078, 0, -21018, 0, 21084, 0, -21017, 0, 21076, 0, -21016, 0, 21083, 0, -21015, 0, 21085, 0, -21014, 0, 21290, 0, -21013, 0, 21375, 0, -21012, 0, 21407, 0, -21011, 0, 21405, 0, -21010, 0, 21471, 0, -21009, 0, 21736, 0, -21008, 0, 21776, 0, -21007, 0, 21761, 0, -21006, 0, 21815, 0, -21005, 0, 21756, 0, -21004, 0, 21733, 0, -21003, 0, 21746, 0, -21002, 0, 21766, 0, -21001, 0, 21754, 0, -21000, 0, 21780, 0, -20999, 0, 21737, 0, -20998, 0, 21741, 0, -20997, 0, 21729, 0, -20996, 0, 21769, 0, -20995, 0, 21742, 0, -20994, 0, 21738, 0, -20928, 0, 21734, 0, -20927, 0, 21799, 0, -20926, 0, 21767, 0, -20925, 0, 21757, 0, -20924, 0, 21775, 0, -20923, 0, 22275, 0, -20922, 0, 22276, 0, -20921, 0, 22466, 0, -20920, 0, 22484, 0, -20919, 0, 22475, 0, -20918, 0, 22467, 0, -20917, 0, 22537, 0, -20916, 0, 22799, 0, -20915, 0, 22871, 0, -20914, 0, 22872, 0, -20913, 0, 22874, 0, -20912, 0, 23057, 0, -20911, 0, 23064, 0, -20910, 0, 23068, 0, -20909, 0, 23071, 0, -20908, 0, 23067, 0, -20907, 0, 23059, 0, -20906, 0, 23020, 0, -20905, 0, 23072, 0, -20904, 0, 23075, 0, -20903, 0, 23081, 0, -20902, 0, 23077, 0, -20901, 0, 23052, 0, -20900, 0, 23049, 0, -20899, 0, 23403, 0, -20898, 0, 23640, 0, -20897, 0, 23472, 0, -20896, 0, 23475, 0, -20895, 0, 23478, 0, -20894, 0, 23476, 0, -20893, 0, 23470, 0, -20892, 0, 23477, 0, -20891, 0, 23481, 0, -20890, 0, 23480, 0, -20889, 0, 23556, 0, -20888, 0, 23633, 0, -20887, 0, 23637, 0, -20886, 0, 23632, 0, -20885, 0, 23789, 0, -20884, 0, 23805, 0, -20883, 0, 23803, 0, -20882, 0, 23786, 0, -20881, 0, 23784, 0, -20880, 0, 23792, 0, -20879, 0, 23798, 0, -20878, 0, 23809, 0, -20877, 0, 23796, 0, -20876, 0, 24046, 0, -20875, 0, 24109, 0, -20874, 0, 24107, 0, -20873, 0, 24235, 0, -20872, 0, 24237, 0, -20871, 0, 24231, 0, -20870, 0, 24369, 0, -20869, 0, 24466, 0, -20868, 0, 24465, 0, -20867, 0, 24464, 0, -20866, 0, 24665, 0, -20831, 0, 24675, 0, -20830, 0, 24677, 0, -20829, 0, 24656, 0, -20828, 0, 24661, 0, -20827, 0, 24685, 0, -20826, 0, 24681, 0, -20825, 0, 24687, 0, -20824, 0, 24708, 0, -20823, 0, 24735, 0, -20822, 0, 24730, 0, -20821, 0, 24717, 0, -20820, 0, 24724, 0, -20819, 0, 24716, 0, -20818, 0, 24709, 0, -20817, 0, 24726, 0, -20816, 0, 25159, 0, -20815, 0, 25331, 0, -20814, 0, 25352, 0, -20813, 0, 25343, 0, -20812, 0, 25422, 0, -20811, 0, 25406, 0, -20810, 0, 25391, 0, -20809, 0, 25429, 0, -20808, 0, 25410, 0, -20807, 0, 25414, 0, -20806, 0, 25423, 0, -20805, 0, 25417, 0, -20804, 0, 25402, 0, -20803, 0, 25424, 0, -20802, 0, 25405, 0, -20801, 0, 25386, 0, -20800, 0, 25387, 0, -20799, 0, 25384, 0, -20798, 0, 25421, 0, -20797, 0, 25420, 0, -20796, 0, 25928, 0, -20795, 0, 25929, 0, -20794, 0, 26009, 0, -20793, 0, 26049, 0, -20792, 0, 26053, 0, -20791, 0, 26178, 0, -20790, 0, 26185, 0, -20789, 0, 26191, 0, -20788, 0, 26179, 0, -20787, 0, 26194, 0, -20786, 0, 26188, 0, -20785, 0, 26181, 0, -20784, 0, 26177, 0, -20783, 0, 26360, 0, -20782, 0, 26388, 0, -20781, 0, 26389, 0, -20780, 0, 26391, 0, -20779, 0, 26657, 0, -20778, 0, 26680, 0, -20777, 0, 26696, 0, -20776, 0, 26694, 0, -20775, 0, 26707, 0, -20774, 0, 26681, 0, -20773, 0, 26690, 0, -20772, 0, 26708, 0, -20771, 0, 26665, 0, -20770, 0, 26803, 0, -20769, 0, 26647, 0, -20768, 0, 26700, 0, -20767, 0, 26705, 0, -20766, 0, 26685, 0, -20765, 0, 26612, 0, -20764, 0, 26704, 0, -20763, 0, 26688, 0, -20762, 0, 26684, 0, -20761, 0, 26691, 0, -20760, 0, 26666, 0, -20759, 0, 26693, 0, -20758, 0, 26643, 0, -20757, 0, 26648, 0, -20756, 0, 26689, 0, -20755, 0, 27530, 0, -20754, 0, 27529, 0, -20753, 0, 27575, 0, -20752, 0, 27683, 0, -20751, 0, 27687, 0, -20750, 0, 27688, 0, -20749, 0, 27686, 0, -20748, 0, 27684, 0, -20747, 0, 27888, 0, -20746, 0, 28010, 0, -20745, 0, 28053, 0, -20744, 0, 28040, 0, -20743, 0, 28039, 0, -20742, 0, 28006, 0, -20741, 0, 28024, 0, -20740, 0, 28023, 0, -20739, 0, 27993, 0, -20738, 0, 28051, 0, -20672, 0, 28012, 0, -20671, 0, 28041, 0, -20670, 0, 28014, 0, -20669, 0, 27994, 0, -20668, 0, 28020, 0, -20667, 0, 28009, 0, -20666, 0, 28044, 0, -20665, 0, 28042, 0, -20664, 0, 28025, 0, -20663, 0, 28037, 0, -20662, 0, 28005, 0, -20661, 0, 28052, 0, -20660, 0, 28874, 0, -20659, 0, 28888, 0, -20658, 0, 28900, 0, -20657, 0, 28889, 0, -20656, 0, 28872, 0, -20655, 0, 28879, 0, -20654, 0, 29241, 0, -20653, 0, 29305, 0, -20652, 0, 29436, 0, -20651, 0, 29433, 0, -20650, 0, 29437, 0, -20649, 0, 29432, 0, -20648, 0, 29431, 0, -20647, 0, 29574, 0, -20646, 0, 29677, 0, -20645, 0, 29705, 0, -20644, 0, 29678, 0, -20643, 0, 29664, 0, -20642, 0, 29674, 0, -20641, 0, 29662, 0, -20640, 0, 30036, 0, -20639, 0, 30045, 0, -20638, 0, 30044, 0, -20637, 0, 30042, 0, -20636, 0, 30041, 0, -20635, 0, 30142, 0, -20634, 0, 30149, 0, -20633, 0, 30151, 0, -20632, 0, 30130, 0, -20631, 0, 30131, 0, -20630, 0, 30141, 0, -20629, 0, 30140, 0, -20628, 0, 30137, 0, -20627, 0, 30146, 0, -20626, 0, 30136, 0, -20625, 0, 30347, 0, -20624, 0, 30384, 0, -20623, 0, 30410, 0, -20622, 0, 30413, 0, -20621, 0, 30414, 0, -20620, 0, 30505, 0, -20619, 0, 30495, 0, -20618, 0, 30496, 0, -20617, 0, 30504, 0, -20616, 0, 30697, 0, -20615, 0, 30768, 0, -20614, 0, 30759, 0, -20613, 0, 30776, 0, -20612, 0, 30749, 0, -20611, 0, 30772, 0, -20610, 0, 30775, 0, -20575, 0, 30757, 0, -20574, 0, 30765, 0, -20573, 0, 30752, 0, -20572, 0, 30751, 0, -20571, 0, 30770, 0, -20570, 0, 31061, 0, -20569, 0, 31056, 0, -20568, 0, 31072, 0, -20567, 0, 31071, 0, -20566, 0, 31062, 0, -20565, 0, 31070, 0, -20564, 0, 31069, 0, -20563, 0, 31063, 0, -20562, 0, 31066, 0, -20561, 0, 31204, 0, -20560, 0, 31203, 0, -20559, 0, 31207, 0, -20558, 0, 31199, 0, -20557, 0, 31206, 0, -20556, 0, 31209, 0, -20555, 0, 31192, 0, -20554, 0, 31364, 0, -20553, 0, 31368, 0, -20552, 0, 31449, 0, -20551, 0, 31494, 0, -20550, 0, 31505, 0, -20549, 0, 31881, 0, -20548, 0, 32033, 0, -20547, 0, 32023, 0, -20546, 0, 32011, 0, -20545, 0, 32010, 0, -20544, 0, 32032, 0, -20543, 0, 32034, 0, -20542, 0, 32020, 0, -20541, 0, 32016, 0, -20540, 0, 32021, 0, -20539, 0, 32026, 0, -20538, 0, 32028, 0, -20537, 0, 32013, 0, -20536, 0, 32025, 0, -20535, 0, 32027, 0, -20534, 0, 32570, 0, -20533, 0, 32607, 0, -20532, 0, 32660, 0, -20531, 0, 32709, 0, -20530, 0, 32705, 0, -20529, 0, -32762, 0, -20528, 0, -32744, 0, -20527, 0, -32747, 0, -20526, 0, -32743, 0, -20525, 0, -32745, 0, -20524, 0, -32707, 0, -20523, 0, -32705, 0, -20522, 0, -32527, 0, -20521, 0, -32510, 0, -20520, 0, -32528, 0, -20519, 0, -32507, 0, -20518, 0, -32531, 0, -20517, 0, -32524, 0, -20516, 0, -32506, 0, -20515, 0, -32520, 0, -20514, 0, -32525, 0, -20513, 0, -32504, 0, -20512, 0, -32515, 0, -20511, 0, -32502, 0, -20510, 0, -32516, 0, -20509, 0, -32529, 0, -20508, 0, -32275, 0, -20507, 0, -32276, 0, -20506, 0, -32256, 0, -20505, 0, -32240, 0, -20504, 0, -32214, 0, -20503, 0, -32213, 0, -20502, 0, -32216, 0, -20501, 0, -32212, 0, -20500, 0, -32069, 0, -20499, 0, -31957, 0, -20498, 0, -31918, 0, -20497, 0, -31916, 0, -20496, 0, -31926, 0, -20495, 0, -31944, 0, -20494, 0, -31920, 0, -20493, 0, -31927, 0, -20492, 0, -31947, 0, -20491, 0, -31948, 0, -20490, 0, -31921, 0, -20489, 0, -31950, 0, -20488, 0, -31943, 0, -20487, 0, -31946, 0, -20486, 0, -31977, 0, -20485, 0, -31936, 0, -20484, 0, -31951, 0, -20483, 0, -31960, 0, -20482, 0, -31933, 0, -20416, 0, -31148, 0, -20415, 0, -31094, 0, -20414, 0, -31062, 0, -20413, 0, -31085, 0, -20412, 0, -31068, 0, -20411, 0, -31063, 0, -20410, 0, -31092, 0, -20409, 0, -31069, 0, -20408, 0, -31076, 0, -20407, 0, -30608, 0, -20406, 0, -30601, 0, -20405, 0, -30591, 0, -20404, 0, -30590, 0, -20403, 0, -30595, 0, -20402, 0, -30599, 0, -20401, 0, -30184, 0, -20400, 0, -30192, 0, -20399, 0, -30194, 0, -20398, 0, -30196, 0, -20397, 0, -30187, 0, -20396, 0, -30198, 0, -20395, 0, -30185, 0, -20394, 0, -30189, 0, -20393, 0, -30186, 0, -20392, 0, -30193, 0, -20391, 0, -30191, 0, -20390, 0, -29624, 0, -20389, 0, -29574, 0, -20388, 0, -29575, 0, -20387, 0, -29535, 0, -20386, 0, -29534, 0, -20385, 0, -29321, 0, -20384, 0, -29012, 0, -20383, 0, -28974, 0, -20382, 0, -28972, 0, -20381, 0, -28977, 0, -20380, 0, -28751, 0, -20379, 0, -28671, 0, -20378, 0, -28666, 0, -20377, 0, -28681, 0, -20376, 0, -28672, 0, -20375, 0, -28678, 0, -20374, 0, -28684, 0, -20373, 0, -28669, 0, -20372, 0, -28675, 0, -20371, 0, -28667, 0, -20370, 0, -28680, 0, -20369, 0, -28523, 0, -20368, 0, -28447, 0, -20367, 0, -28451, 0, -20366, 0, -28446, 0, -20365, 0, -28334, 0, -20364, 0, -28339, 0, -20363, 0, -28340, 0, -20362, 0, -28200, 0, -20361, 0, -28195, 0, -20360, 0, -28201, 0, -20359, 0, -28196, 0, -20358, 0, -28199, 0, -20357, 0, -27261, 0, -20356, 0, -27038, 0, -20355, 0, -27037, 0, -20354, 0, -27039, 0, -20319, 0, -27045, 0, -20318, 0, -27043, 0, -20317, 0, -27036, 0, -20316, 0, -27048, 0, -20315, 0, -27042, 0, -20314, 0, -26949, 0, -20313, 0, -26398, 0, -20312, 0, -26196, 0, -20311, 0, -25944, 0, -20310, 0, -25896, 0, -20309, 0, -25819, 0, -20308, 0, -25806, 0, -20307, 0, -25796, 0, -20306, 0, 20094, 0, -20305, 0, 20602, 0, -20304, 0, 20605, 0, -20303, 0, 20572, 0, -20302, 0, 20551, 0, -20301, 0, 20547, 0, -20300, 0, 20556, 0, -20299, 0, 20570, 0, -20298, 0, 20553, 0, -20297, 0, 20581, 0, -20296, 0, 20598, 0, -20295, 0, 20558, 0, -20294, 0, 20565, 0, -20293, 0, 20597, 0, -20292, 0, 20596, 0, -20291, 0, 20599, 0, -20290, 0, 20559, 0, -20289, 0, 20495, 0, -20288, 0, 20591, 0, -20287, 0, 20589, 0, -20286, 0, 20828, 0, -20285, 0, 20885, 0, -20284, 0, 20976, 0, -20283, 0, 21098, 0, -20282, 0, 21103, 0, -20281, 0, 21202, 0, -20280, 0, 21209, 0, -20279, 0, 21208, 0, -20278, 0, 21205, 0, -20277, 0, 21264, 0, -20276, 0, 21263, 0, -20275, 0, 21273, 0, -20274, 0, 21311, 0, -20273, 0, 21312, 0, -20272, 0, 21310, 0, -20271, 0, 21443, 0, -20270, 0, 26364, 0, -20269, 0, 21830, 0, -20268, 0, 21866, 0, -20267, 0, 21862, 0, -20266, 0, 21828, 0, -20265, 0, 21854, 0, -20264, 0, 21857, 0, -20263, 0, 21827, 0, -20262, 0, 21834, 0, -20261, 0, 21809, 0, -20260, 0, 21846, 0, -20259, 0, 21839, 0, -20258, 0, 21845, 0, -20257, 0, 21807, 0, -20256, 0, 21860, 0, -20255, 0, 21816, 0, -20254, 0, 21806, 0, -20253, 0, 21852, 0, -20252, 0, 21804, 0, -20251, 0, 21859, 0, -20250, 0, 21811, 0, -20249, 0, 21825, 0, -20248, 0, 21847, 0, -20247, 0, 22280, 0, -20246, 0, 22283, 0, -20245, 0, 22281, 0, -20244, 0, 22495, 0, -20243, 0, 22533, 0, -20242, 0, 22538, 0, -20241, 0, 22534, 0, -20240, 0, 22496, 0, -20239, 0, 22500, 0, -20238, 0, 22522, 0, -20237, 0, 22530, 0, -20236, 0, 22581, 0, -20235, 0, 22519, 0, -20234, 0, 22521, 0, -20233, 0, 22816, 0, -20232, 0, 22882, 0, -20231, 0, 23094, 0, -20230, 0, 23105, 0, -20229, 0, 23113, 0, -20228, 0, 23142, 0, -20227, 0, 23146, 0, -20226, 0, 23104, 0, -20160, 0, 23100, 0, -20159, 0, 23138, 0, -20158, 0, 23130, 0, -20157, 0, 23110, 0, -20156, 0, 23114, 0, -20155, 0, 23408, 0, -20154, 0, 23495, 0, -20153, 0, 23493, 0, -20152, 0, 23492, 0, -20151, 0, 23490, 0, -20150, 0, 23487, 0, -20149, 0, 23494, 0, -20148, 0, 23561, 0, -20147, 0, 23560, 0, -20146, 0, 23559, 0, -20145, 0, 23648, 0, -20144, 0, 23644, 0, -20143, 0, 23645, 0, -20142, 0, 23815, 0, -20141, 0, 23814, 0, -20140, 0, 23822, 0, -20139, 0, 23835, 0, -20138, 0, 23830, 0, -20137, 0, 23842, 0, -20136, 0, 23825, 0, -20135, 0, 23849, 0, -20134, 0, 23828, 0, -20133, 0, 23833, 0, -20132, 0, 23844, 0, -20131, 0, 23847, 0, -20130, 0, 23831, 0, -20129, 0, 24034, 0, -20128, 0, 24120, 0, -20127, 0, 24118, 0, -20126, 0, 24115, 0, -20125, 0, 24119, 0, -20124, 0, 24247, 0, -20123, 0, 24248, 0, -20122, 0, 24246, 0, -20121, 0, 24245, 0, -20120, 0, 24254, 0, -20119, 0, 24373, 0, -20118, 0, 24375, 0, -20117, 0, 24407, 0, -20116, 0, 24428, 0, -20115, 0, 24425, 0, -20114, 0, 24427, 0, -20113, 0, 24471, 0, -20112, 0, 24473, 0, -20111, 0, 24478, 0, -20110, 0, 24472, 0, -20109, 0, 24481, 0, -20108, 0, 24480, 0, -20107, 0, 24476, 0, -20106, 0, 24703, 0, -20105, 0, 24739, 0, -20104, 0, 24713, 0, -20103, 0, 24736, 0, -20102, 0, 24744, 0, -20101, 0, 24779, 0, -20100, 0, 24756, 0, -20099, 0, 24806, 0, -20098, 0, 24765, 0, -20063, 0, 24773, 0, -20062, 0, 24763, 0, -20061, 0, 24757, 0, -20060, 0, 24796, 0, -20059, 0, 24764, 0, -20058, 0, 24792, 0, -20057, 0, 24789, 0, -20056, 0, 24774, 0, -20055, 0, 24799, 0, -20054, 0, 24760, 0, -20053, 0, 24794, 0, -20052, 0, 24775, 0, -20051, 0, 25114, 0, -20050, 0, 25115, 0, -20049, 0, 25160, 0, -20048, 0, 25504, 0, -20047, 0, 25511, 0, -20046, 0, 25458, 0, -20045, 0, 25494, 0, -20044, 0, 25506, 0, -20043, 0, 25509, 0, -20042, 0, 25463, 0, -20041, 0, 25447, 0, -20040, 0, 25496, 0, -20039, 0, 25514, 0, -20038, 0, 25457, 0, -20037, 0, 25513, 0, -20036, 0, 25481, 0, -20035, 0, 25475, 0, -20034, 0, 25499, 0, -20033, 0, 25451, 0, -20032, 0, 25512, 0, -20031, 0, 25476, 0, -20030, 0, 25480, 0, -20029, 0, 25497, 0, -20028, 0, 25505, 0, -20027, 0, 25516, 0, -20026, 0, 25490, 0, -20025, 0, 25487, 0, -20024, 0, 25472, 0, -20023, 0, 25467, 0, -20022, 0, 25449, 0, -20021, 0, 25448, 0, -20020, 0, 25466, 0, -20019, 0, 25949, 0, -20018, 0, 25942, 0, -20017, 0, 25937, 0, -20016, 0, 25945, 0, -20015, 0, 25943, 0, -20014, 0, 21855, 0, -20013, 0, 25935, 0, -20012, 0, 25944, 0, -20011, 0, 25941, 0, -20010, 0, 25940, 0, -20009, 0, 26012, 0, -20008, 0, 26011, 0, -20007, 0, 26028, 0, -20006, 0, 26063, 0, -20005, 0, 26059, 0, -20004, 0, 26060, 0, -20003, 0, 26062, 0, -20002, 0, 26205, 0, -20001, 0, 26202, 0, -20000, 0, 26212, 0, -19999, 0, 26216, 0, -19998, 0, 26214, 0, -19997, 0, 26206, 0, -19996, 0, 26361, 0, -19995, 0, 21207, 0, -19994, 0, 26395, 0, -19993, 0, 26753, 0, -19992, 0, 26799, 0, -19991, 0, 26786, 0, -19990, 0, 26771, 0, -19989, 0, 26805, 0, -19988, 0, 26751, 0, -19987, 0, 26742, 0, -19986, 0, 26801, 0, -19985, 0, 26791, 0, -19984, 0, 26775, 0, -19983, 0, 26800, 0, -19982, 0, 26755, 0, -19981, 0, 26820, 0, -19980, 0, 26797, 0, -19979, 0, 26758, 0, -19978, 0, 26757, 0, -19977, 0, 26772, 0, -19976, 0, 26781, 0, -19975, 0, 26792, 0, -19974, 0, 26783, 0, -19973, 0, 26785, 0, -19972, 0, 26754, 0, -19971, 0, 27442, 0, -19970, 0, 27578, 0, -19904, 0, 27627, 0, -19903, 0, 27628, 0, -19902, 0, 27691, 0, -19901, 0, 28046, 0, -19900, 0, 28092, 0, -19899, 0, 28147, 0, -19898, 0, 28121, 0, -19897, 0, 28082, 0, -19896, 0, 28129, 0, -19895, 0, 28108, 0, -19894, 0, 28132, 0, -19893, 0, 28155, 0, -19892, 0, 28154, 0, -19891, 0, 28165, 0, -19890, 0, 28103, 0, -19889, 0, 28107, 0, -19888, 0, 28079, 0, -19887, 0, 28113, 0, -19886, 0, 28078, 0, -19885, 0, 28126, 0, -19884, 0, 28153, 0, -19883, 0, 28088, 0, -19882, 0, 28151, 0, -19881, 0, 28149, 0, -19880, 0, 28101, 0, -19879, 0, 28114, 0, -19878, 0, 28186, 0, -19877, 0, 28085, 0, -19876, 0, 28122, 0, -19875, 0, 28139, 0, -19874, 0, 28120, 0, -19873, 0, 28138, 0, -19872, 0, 28145, 0, -19871, 0, 28142, 0, -19870, 0, 28136, 0, -19869, 0, 28102, 0, -19868, 0, 28100, 0, -19867, 0, 28074, 0, -19866, 0, 28140, 0, -19865, 0, 28095, 0, -19864, 0, 28134, 0, -19863, 0, 28921, 0, -19862, 0, 28937, 0, -19861, 0, 28938, 0, -19860, 0, 28925, 0, -19859, 0, 28911, 0, -19858, 0, 29245, 0, -19857, 0, 29309, 0, -19856, 0, 29313, 0, -19855, 0, 29468, 0, -19854, 0, 29467, 0, -19853, 0, 29462, 0, -19852, 0, 29459, 0, -19851, 0, 29465, 0, -19850, 0, 29575, 0, -19849, 0, 29701, 0, -19848, 0, 29706, 0, -19847, 0, 29699, 0, -19846, 0, 29702, 0, -19845, 0, 29694, 0, -19844, 0, 29709, 0, -19843, 0, 29920, 0, -19842, 0, 29942, 0, -19807, 0, 29943, 0, -19806, 0, 29980, 0, -19805, 0, 29986, 0, -19804, 0, 30053, 0, -19803, 0, 30054, 0, -19802, 0, 30050, 0, -19801, 0, 30064, 0, -19800, 0, 30095, 0, -19799, 0, 30164, 0, -19798, 0, 30165, 0, -19797, 0, 30133, 0, -19796, 0, 30154, 0, -19795, 0, 30157, 0, -19794, 0, 30350, 0, -19793, 0, 30420, 0, -19792, 0, 30418, 0, -19791, 0, 30427, 0, -19790, 0, 30519, 0, -19789, 0, 30526, 0, -19788, 0, 30524, 0, -19787, 0, 30518, 0, -19786, 0, 30520, 0, -19785, 0, 30522, 0, -19784, 0, 30827, 0, -19783, 0, 30787, 0, -19782, 0, 30798, 0, -19781, 0, 31077, 0, -19780, 0, 31080, 0, -19779, 0, 31085, 0, -19778, 0, 31227, 0, -19777, 0, 31378, 0, -19776, 0, 31381, 0, -19775, 0, 31520, 0, -19774, 0, 31528, 0, -19773, 0, 31515, 0, -19772, 0, 31532, 0, -19771, 0, 31526, 0, -19770, 0, 31513, 0, -19769, 0, 31518, 0, -19768, 0, 31534, 0, -19767, 0, 31890, 0, -19766, 0, 31895, 0, -19765, 0, 31893, 0, -19764, 0, 32070, 0, -19763, 0, 32067, 0, -19762, 0, 32113, 0, -19761, 0, 32046, 0, -19760, 0, 32057, 0, -19759, 0, 32060, 0, -19758, 0, 32064, 0, -19757, 0, 32048, 0, -19756, 0, 32051, 0, -19755, 0, 32068, 0, -19754, 0, 32047, 0, -19753, 0, 32066, 0, -19752, 0, 32050, 0, -19751, 0, 32049, 0, -19750, 0, 32573, 0, -19749, 0, 32670, 0, -19748, 0, 32666, 0, -19747, 0, 32716, 0, -19746, 0, 32718, 0, -19745, 0, 32722, 0, -19744, 0, -32740, 0, -19743, 0, -32694, 0, -19742, 0, -32698, 0, -19741, 0, -32465, 0, -19740, 0, -32490, 0, -19739, 0, -32477, 0, -19738, 0, -32469, 0, -19737, 0, -32471, 0, -19736, 0, -32464, 0, -19735, 0, -32476, 0, -19734, 0, -32254, 0, -19733, 0, -32203, 0, -19732, 0, -32201, 0, -19731, 0, -32202, 0, -19730, 0, -32199, 0, -19729, 0, -31858, 0, -19728, 0, -31842, 0, -19727, 0, -31848, 0, -19726, 0, -31880, 0, -19725, 0, -31838, 0, -19724, 0, -31850, 0, -19723, 0, -31811, 0, -19722, 0, -31829, 0, -19721, 0, -31854, 0, -19720, 0, -31862, 0, -19719, 0, -31853, 0, -19718, 0, -31863, 0, -19717, 0, -31840, 0, -19716, 0, -31881, 0, -19715, 0, -31877, 0, -19714, 0, -31876, 0, -19648, 0, -31866, 0, -19647, 0, -31833, 0, -19646, 0, -31147, 0, -19645, 0, 24426, 0, -19644, 0, -31033, 0, -19643, 0, -31040, 0, -19642, 0, -31050, 0, -19641, 0, -31036, 0, -19640, 0, -31051, 0, -19639, 0, -31034, 0, -19638, 0, -31029, 0, -19637, 0, -31055, 0, -19636, 0, -31057, 0, -19635, 0, -31031, 0, -19634, 0, -30637, 0, -19633, 0, -30562, 0, -19632, 0, -30584, 0, -19631, 0, -30549, 0, -19630, 0, -30574, 0, -19629, 0, -30570, 0, -19628, 0, -30579, 0, -19627, 0, -30581, 0, -19626, 0, -30317, 0, -19625, 0, -30321, 0, -19624, 0, -30166, 0, -19623, 0, -30179, 0, -19622, 0, -30173, 0, -19621, 0, -30171, 0, -19620, 0, -30159, 0, -19619, 0, -30163, 0, -19618, 0, -30177, 0, -19617, 0, -30181, 0, -19616, 0, -30174, 0, -19615, 0, -29623, 0, -19614, 0, -29606, 0, -19613, 0, -29527, 0, -19612, 0, -29524, 0, -19611, 0, -29525, 0, -19610, 0, -29528, 0, -19609, 0, -29526, 0, -19608, 0, -29529, 0, -19607, 0, -29337, 0, -19606, 0, -29338, 0, -19605, 0, -29250, 0, -19604, 0, -29254, 0, -19603, 0, -28965, 0, -19602, 0, -28961, 0, -19601, 0, -28647, 0, -19600, 0, -28659, 0, -19599, 0, -28646, 0, -19598, 0, -28649, 0, -19597, 0, -28637, 0, -19596, 0, -28641, 0, -19595, 0, -28643, 0, -19594, 0, -28656, 0, -19593, 0, -28651, 0, -19592, 0, -28642, 0, -19591, 0, -28640, 0, -19590, 0, -28657, 0, -19589, 0, -28638, 0, -19588, 0, -28650, 0, -19587, 0, -28645, 0, -19586, 0, -28652, 0, -19551, 0, -28440, 0, -19550, 0, -28435, 0, -19549, 0, -28419, 0, -19548, 0, -28329, 0, -19547, 0, -28210, 0, -19546, 0, -28171, 0, -19545, 0, -28186, 0, -19544, 0, -28189, 0, -19543, 0, -28185, 0, -19542, 0, -28179, 0, -19541, 0, -28183, 0, -19540, 0, -27255, 0, -19539, 0, -27030, 0, -19538, 0, -27019, 0, -19537, 0, -27021, 0, -19536, 0, -27016, 0, -19535, 0, -27024, 0, -19534, 0, -27020, 0, -19533, 0, -27018, 0, -19532, 0, -27017, 0, -19531, 0, -27028, 0, -19530, 0, -26944, 0, -19529, 0, -26902, 0, -19528, 0, -26903, 0, -19527, 0, 31456, 0, -19526, 0, 31455, 0, -19525, 0, -26622, 0, -19524, 0, -26621, 0, -19523, 0, -25766, 0, -19522, 0, -25371, 0, -19521, 0, -24971, 0, -19520, 0, -24961, 0, -19519, 0, -24923, 0, -19518, 0, -24901, 0, -19517, 0, 20642, 0, -19516, 0, 20621, 0, -19515, 0, 20613, 0, -19514, 0, 20633, 0, -19513, 0, 20625, 0, -19512, 0, 20608, 0, -19511, 0, 20630, 0, -19510, 0, 20632, 0, -19509, 0, 20634, 0, -19508, 0, 26368, 0, -19507, 0, 20977, 0, -19506, 0, 21106, 0, -19505, 0, 21108, 0, -19504, 0, 21109, 0, -19503, 0, 21097, 0, -19502, 0, 21214, 0, -19501, 0, 21213, 0, -19500, 0, 21211, 0, -19499, 0, 21338, 0, -19498, 0, 21413, 0, -19497, 0, 21883, 0, -19496, 0, 21888, 0, -19495, 0, 21927, 0, -19494, 0, 21884, 0, -19493, 0, 21898, 0, -19492, 0, 21917, 0, -19491, 0, 21912, 0, -19490, 0, 21890, 0, -19489, 0, 21916, 0, -19488, 0, 21930, 0, -19487, 0, 21908, 0, -19486, 0, 21895, 0, -19485, 0, 21899, 0, -19484, 0, 21891, 0, -19483, 0, 21939, 0, -19482, 0, 21934, 0, -19481, 0, 21919, 0, -19480, 0, 21822, 0, -19479, 0, 21938, 0, -19478, 0, 21914, 0, -19477, 0, 21947, 0, -19476, 0, 21932, 0, -19475, 0, 21937, 0, -19474, 0, 21886, 0, -19473, 0, 21897, 0, -19472, 0, 21931, 0, -19471, 0, 21913, 0, -19470, 0, 22285, 0, -19469, 0, 22575, 0, -19468, 0, 22570, 0, -19467, 0, 22580, 0, -19466, 0, 22564, 0, -19465, 0, 22576, 0, -19464, 0, 22577, 0, -19463, 0, 22561, 0, -19462, 0, 22557, 0, -19461, 0, 22560, 0, -19460, 0, 22777, 0, -19459, 0, 22778, 0, -19458, 0, 22880, 0, -19392, 0, 23159, 0, -19391, 0, 23194, 0, -19390, 0, 23167, 0, -19389, 0, 23186, 0, -19388, 0, 23195, 0, -19387, 0, 23207, 0, -19386, 0, 23411, 0, -19385, 0, 23409, 0, -19384, 0, 23506, 0, -19383, 0, 23500, 0, -19382, 0, 23507, 0, -19381, 0, 23504, 0, -19380, 0, 23562, 0, -19379, 0, 23563, 0, -19378, 0, 23601, 0, -19377, 0, 23884, 0, -19376, 0, 23888, 0, -19375, 0, 23860, 0, -19374, 0, 23879, 0, -19373, 0, 24061, 0, -19372, 0, 24133, 0, -19371, 0, 24125, 0, -19370, 0, 24128, 0, -19369, 0, 24131, 0, -19368, 0, 24190, 0, -19367, 0, 24266, 0, -19366, 0, 24257, 0, -19365, 0, 24258, 0, -19364, 0, 24260, 0, -19363, 0, 24380, 0, -19362, 0, 24429, 0, -19361, 0, 24489, 0, -19360, 0, 24490, 0, -19359, 0, 24488, 0, -19358, 0, 24785, 0, -19357, 0, 24801, 0, -19356, 0, 24754, 0, -19355, 0, 24758, 0, -19354, 0, 24800, 0, -19353, 0, 24860, 0, -19352, 0, 24867, 0, -19351, 0, 24826, 0, -19350, 0, 24853, 0, -19349, 0, 24816, 0, -19348, 0, 24827, 0, -19347, 0, 24820, 0, -19346, 0, 24936, 0, -19345, 0, 24817, 0, -19344, 0, 24846, 0, -19343, 0, 24822, 0, -19342, 0, 24841, 0, -19341, 0, 24832, 0, -19340, 0, 24850, 0, -19339, 0, 25119, 0, -19338, 0, 25161, 0, -19337, 0, 25507, 0, -19336, 0, 25484, 0, -19335, 0, 25551, 0, -19334, 0, 25536, 0, -19333, 0, 25577, 0, -19332, 0, 25545, 0, -19331, 0, 25542, 0, -19330, 0, 25549, 0, -19295, 0, 25554, 0, -19294, 0, 25571, 0, -19293, 0, 25552, 0, -19292, 0, 25569, 0, -19291, 0, 25558, 0, -19290, 0, 25581, 0, -19289, 0, 25582, 0, -19288, 0, 25462, 0, -19287, 0, 25588, 0, -19286, 0, 25578, 0, -19285, 0, 25563, 0, -19284, 0, 25682, 0, -19283, 0, 25562, 0, -19282, 0, 25593, 0, -19281, 0, 25950, 0, -19280, 0, 25958, 0, -19279, 0, 25954, 0, -19278, 0, 25955, 0, -19277, 0, 26001, 0, -19276, 0, 26000, 0, -19275, 0, 26031, 0, -19274, 0, 26222, 0, -19273, 0, 26224, 0, -19272, 0, 26228, 0, -19271, 0, 26230, 0, -19270, 0, 26223, 0, -19269, 0, 26257, 0, -19268, 0, 26234, 0, -19267, 0, 26238, 0, -19266, 0, 26231, 0, -19265, 0, 26366, 0, -19264, 0, 26367, 0, -19263, 0, 26399, 0, -19262, 0, 26397, 0, -19261, 0, 26874, 0, -19260, 0, 26837, 0, -19259, 0, 26848, 0, -19258, 0, 26840, 0, -19257, 0, 26839, 0, -19256, 0, 26885, 0, -19255, 0, 26847, 0, -19254, 0, 26869, 0, -19253, 0, 26862, 0, -19252, 0, 26855, 0, -19251, 0, 26873, 0, -19250, 0, 26834, 0, -19249, 0, 26866, 0, -19248, 0, 26851, 0, -19247, 0, 26827, 0, -19246, 0, 26829, 0, -19245, 0, 26893, 0, -19244, 0, 26898, 0, -19243, 0, 26894, 0, -19242, 0, 26825, 0, -19241, 0, 26842, 0, -19240, 0, 26990, 0, -19239, 0, 26875, 0, -19238, 0, 27454, 0, -19237, 0, 27450, 0, -19236, 0, 27453, 0, -19235, 0, 27544, 0, -19234, 0, 27542, 0, -19233, 0, 27580, 0, -19232, 0, 27631, 0, -19231, 0, 27694, 0, -19230, 0, 27695, 0, -19229, 0, 27692, 0, -19228, 0, 28207, 0, -19227, 0, 28216, 0, -19226, 0, 28244, 0, -19225, 0, 28193, 0, -19224, 0, 28210, 0, -19223, 0, 28263, 0, -19222, 0, 28234, 0, -19221, 0, 28192, 0, -19220, 0, 28197, 0, -19219, 0, 28195, 0, -19218, 0, 28187, 0, -19217, 0, 28251, 0, -19216, 0, 28248, 0, -19215, 0, 28196, 0, -19214, 0, 28246, 0, -19213, 0, 28270, 0, -19212, 0, 28205, 0, -19211, 0, 28198, 0, -19210, 0, 28271, 0, -19209, 0, 28212, 0, -19208, 0, 28237, 0, -19207, 0, 28218, 0, -19206, 0, 28204, 0, -19205, 0, 28227, 0, -19204, 0, 28189, 0, -19203, 0, 28222, 0, -19202, 0, 28363, 0, -19136, 0, 28297, 0, -19135, 0, 28185, 0, -19134, 0, 28238, 0, -19133, 0, 28259, 0, -19132, 0, 28228, 0, -19131, 0, 28274, 0, -19130, 0, 28265, 0, -19129, 0, 28255, 0, -19128, 0, 28953, 0, -19127, 0, 28954, 0, -19126, 0, 28966, 0, -19125, 0, 28976, 0, -19124, 0, 28961, 0, -19123, 0, 28982, 0, -19122, 0, 29038, 0, -19121, 0, 28956, 0, -19120, 0, 29260, 0, -19119, 0, 29316, 0, -19118, 0, 29312, 0, -19117, 0, 29494, 0, -19116, 0, 29477, 0, -19115, 0, 29492, 0, -19114, 0, 29481, 0, -19113, 0, 29754, 0, -19112, 0, 29738, 0, -19111, 0, 29747, 0, -19110, 0, 29730, 0, -19109, 0, 29733, 0, -19108, 0, 29749, 0, -19107, 0, 29750, 0, -19106, 0, 29748, 0, -19105, 0, 29743, 0, -19104, 0, 29723, 0, -19103, 0, 29734, 0, -19102, 0, 29736, 0, -19101, 0, 29989, 0, -19100, 0, 29990, 0, -19099, 0, 30059, 0, -19098, 0, 30058, 0, -19097, 0, 30178, 0, -19096, 0, 30171, 0, -19095, 0, 30179, 0, -19094, 0, 30169, 0, -19093, 0, 30168, 0, -19092, 0, 30174, 0, -19091, 0, 30176, 0, -19090, 0, 30331, 0, -19089, 0, 30332, 0, -19088, 0, 30358, 0, -19087, 0, 30355, 0, -19086, 0, 30388, 0, -19085, 0, 30428, 0, -19084, 0, 30543, 0, -19083, 0, 30701, 0, -19082, 0, 30813, 0, -19081, 0, 30828, 0, -19080, 0, 30831, 0, -19079, 0, 31245, 0, -19078, 0, 31240, 0, -19077, 0, 31243, 0, -19076, 0, 31237, 0, -19075, 0, 31232, 0, -19074, 0, 31384, 0, -19039, 0, 31383, 0, -19038, 0, 31382, 0, -19037, 0, 31461, 0, -19036, 0, 31459, 0, -19035, 0, 31561, 0, -19034, 0, 31574, 0, -19033, 0, 31558, 0, -19032, 0, 31568, 0, -19031, 0, 31570, 0, -19030, 0, 31572, 0, -19029, 0, 31565, 0, -19028, 0, 31563, 0, -19027, 0, 31567, 0, -19026, 0, 31569, 0, -19025, 0, 31903, 0, -19024, 0, 31909, 0, -19023, 0, 32094, 0, -19022, 0, 32080, 0, -19021, 0, 32104, 0, -19020, 0, 32085, 0, -19019, 0, 32043, 0, -19018, 0, 32110, 0, -19017, 0, 32114, 0, -19016, 0, 32097, 0, -19015, 0, 32102, 0, -19014, 0, 32098, 0, -19013, 0, 32112, 0, -19012, 0, 32115, 0, -19011, 0, 21892, 0, -19010, 0, 32724, 0, -19009, 0, 32725, 0, -19008, 0, -32757, 0, -19007, 0, -32686, 0, -19006, 0, -32635, 0, -19005, 0, -32427, 0, -19004, 0, -32428, 0, -19003, 0, -32437, 0, -19002, 0, -32431, 0, -19001, 0, -32434, 0, -19000, 0, -32455, 0, -18999, 0, -32442, 0, -18998, 0, -32450, 0, -18997, 0, -32436, 0, -18996, 0, -32429, 0, -18995, 0, -32396, 0, -18994, 0, -32238, 0, -18993, 0, -32228, 0, -18992, 0, -31767, 0, -18991, 0, -31741, 0, -18990, 0, -31752, 0, -18989, 0, -31731, 0, -18988, 0, -31776, 0, -18987, 0, -31803, 0, -18986, 0, -31733, 0, -18985, 0, -31807, 0, -18984, 0, -31761, 0, -18983, 0, -31759, 0, -18982, 0, -31756, 0, -18981, 0, -31657, 0, -18980, 0, -31734, 0, -18979, 0, -31760, 0, -18978, 0, -31732, 0, -18977, 0, -31796, 0, -18976, 0, -31747, 0, -18975, 0, -31758, 0, -18974, 0, -31798, 0, -18973, 0, -31688, 0, -18972, 0, -31730, 0, -18971, 0, -31740, 0, -18970, 0, -31780, 0, -18969, 0, -31737, 0, -18968, 0, -31788, 0, -18967, 0, -31777, 0, -18966, 0, -31141, 0, -18965, 0, -31009, 0, -18964, 0, -31015, 0, -18963, 0, -30995, 0, -18962, 0, -31020, 0, -18961, 0, -31013, 0, -18960, 0, -31004, 0, -18959, 0, -31024, 0, -18958, 0, -31010, 0, -18957, 0, -30633, 0, -18956, 0, -30527, 0, -18955, 0, -30526, 0, -18954, 0, -30543, 0, -18953, 0, -30333, 0, -18952, 0, -30314, 0, -18951, 0, -30149, 0, -18950, 0, -30112, 0, -18949, 0, -30123, 0, -18948, 0, -30114, 0, -18947, 0, -30148, 0, -18946, 0, -30143, 0, -18880, 0, -30124, 0, -18879, 0, -30117, 0, -18878, 0, -30128, 0, -18877, 0, -30138, 0, -18876, 0, -30156, 0, -18875, 0, -30150, 0, -18874, 0, -30154, 0, -18873, 0, -30122, 0, -18872, 0, -29599, 0, -18871, 0, -29566, 0, -18870, 0, -29521, 0, -18869, 0, -29508, 0, -18868, 0, -29517, 0, -18867, 0, -29507, 0, -18866, 0, -29503, 0, -18865, 0, -29509, 0, -18864, 0, -29504, 0, -18863, 0, -29516, 0, -18862, 0, -29513, 0, -18861, 0, -29514, 0, -18860, 0, -29505, 0, -18859, 0, -29512, 0, -18858, 0, -29302, 0, -18857, 0, -29307, 0, -18856, 0, -29311, 0, -18855, 0, -29234, 0, -18854, 0, -29219, 0, -18853, 0, -29237, 0, -18852, 0, -29222, 0, -18851, 0, -29231, 0, -18850, 0, -29236, 0, -18849, 0, -29221, 0, -18848, 0, -29242, 0, -18847, 0, -28933, 0, -18846, 0, -28936, 0, -18845, 0, -28932, 0, -18844, 0, -28772, 0, -18843, 0, -28626, 0, -18842, 0, -28619, 0, -18841, 0, -28623, 0, -18840, 0, -28616, 0, -18839, 0, -28622, 0, -18838, 0, -28618, 0, -18837, 0, -28414, 0, -18836, 0, -28427, 0, -18835, 0, -28407, 0, -18834, 0, -28418, 0, -18833, 0, -28317, 0, -18832, 0, -28315, 0, -18831, 0, -28209, 0, -18830, 0, -28140, 0, -18829, 0, -28139, 0, -18828, 0, -28125, 0, -18827, 0, -28151, 0, -18826, 0, -28130, 0, -18825, 0, -28147, 0, -18824, 0, -28144, 0, -18823, 0, -28153, 0, -18822, 0, -28143, 0, -18821, 0, -27244, 0, -18820, 0, -27249, 0, -18819, 0, -27253, 0, -18818, 0, -27247, 0, -18783, 0, -27245, 0, -18782, 0, -27246, 0, -18781, 0, -27250, 0, -18780, 0, -26998, 0, -18779, 0, -26994, 0, -18778, 0, -26997, 0, -18777, 0, -27011, 0, -18776, 0, -27003, 0, -18775, 0, -27002, 0, -18774, 0, -26995, 0, -18773, 0, -27022, 0, -18772, 0, -27004, 0, -18771, 0, -26943, 0, -18770, 0, -26939, 0, -18769, 0, -26940, 0, -18768, 0, -26938, 0, -18767, 0, -26937, 0, -18766, 0, -26897, 0, -18765, 0, -26894, 0, -18764, 0, -26676, 0, -18763, 0, -26619, 0, -18762, 0, -26618, 0, -18761, 0, -26616, 0, -18760, 0, -26393, 0, -18759, 0, -26390, 0, -18758, 0, -26385, 0, -18757, 0, -26391, 0, -18756, 0, -26382, 0, -18755, 0, -26387, 0, -18754, 0, -26194, 0, -18753, 0, -26195, 0, -18752, 0, -24893, 0, -18751, 0, -24883, 0, -18750, 0, -24879, 0, -18749, 0, 20098, 0, -18748, 0, 20653, 0, -18747, 0, 20661, 0, -18746, 0, 20658, 0, -18745, 0, 20659, 0, -18744, 0, 20677, 0, -18743, 0, 20670, 0, -18742, 0, 20652, 0, -18741, 0, 20663, 0, -18740, 0, 20667, 0, -18739, 0, 20655, 0, -18738, 0, 20679, 0, -18737, 0, 21119, 0, -18736, 0, 21111, 0, -18735, 0, 21117, 0, -18734, 0, 21215, 0, -18733, 0, 21222, 0, -18732, 0, 21220, 0, -18731, 0, 21218, 0, -18730, 0, 21219, 0, -18729, 0, 21295, 0, -18728, 0, 21983, 0, -18727, 0, 21992, 0, -18726, 0, 21971, 0, -18725, 0, 21990, 0, -18724, 0, 21966, 0, -18723, 0, 21980, 0, -18722, 0, 21959, 0, -18721, 0, 21969, 0, -18720, 0, 21987, 0, -18719, 0, 21988, 0, -18718, 0, 21999, 0, -18717, 0, 21978, 0, -18716, 0, 21985, 0, -18715, 0, 21957, 0, -18714, 0, 21958, 0, -18713, 0, 21989, 0, -18712, 0, 21961, 0, -18711, 0, 22290, 0, -18710, 0, 22291, 0, -18709, 0, 22622, 0, -18708, 0, 22609, 0, -18707, 0, 22616, 0, -18706, 0, 22615, 0, -18705, 0, 22618, 0, -18704, 0, 22612, 0, -18703, 0, 22635, 0, -18702, 0, 22604, 0, -18701, 0, 22637, 0, -18700, 0, 22602, 0, -18699, 0, 22626, 0, -18698, 0, 22610, 0, -18697, 0, 22603, 0, -18696, 0, 22887, 0, -18695, 0, 23233, 0, -18694, 0, 23241, 0, -18693, 0, 23244, 0, -18692, 0, 23230, 0, -18691, 0, 23229, 0, -18690, 0, 23228, 0, -18624, 0, 23219, 0, -18623, 0, 23234, 0, -18622, 0, 23218, 0, -18621, 0, 23913, 0, -18620, 0, 23919, 0, -18619, 0, 24140, 0, -18618, 0, 24185, 0, -18617, 0, 24265, 0, -18616, 0, 24264, 0, -18615, 0, 24338, 0, -18614, 0, 24409, 0, -18613, 0, 24492, 0, -18612, 0, 24494, 0, -18611, 0, 24858, 0, -18610, 0, 24847, 0, -18609, 0, 24904, 0, -18608, 0, 24863, 0, -18607, 0, 24819, 0, -18606, 0, 24859, 0, -18605, 0, 24825, 0, -18604, 0, 24833, 0, -18603, 0, 24840, 0, -18602, 0, 24910, 0, -18601, 0, 24908, 0, -18600, 0, 24900, 0, -18599, 0, 24909, 0, -18598, 0, 24894, 0, -18597, 0, 24884, 0, -18596, 0, 24871, 0, -18595, 0, 24845, 0, -18594, 0, 24838, 0, -18593, 0, 24887, 0, -18592, 0, 25121, 0, -18591, 0, 25122, 0, -18590, 0, 25619, 0, -18589, 0, 25662, 0, -18588, 0, 25630, 0, -18587, 0, 25642, 0, -18586, 0, 25645, 0, -18585, 0, 25661, 0, -18584, 0, 25644, 0, -18583, 0, 25615, 0, -18582, 0, 25628, 0, -18581, 0, 25620, 0, -18580, 0, 25613, 0, -18579, 0, 25654, 0, -18578, 0, 25622, 0, -18577, 0, 25623, 0, -18576, 0, 25606, 0, -18575, 0, 25964, 0, -18574, 0, 26015, 0, -18573, 0, 26032, 0, -18572, 0, 26263, 0, -18571, 0, 26249, 0, -18570, 0, 26247, 0, -18569, 0, 26248, 0, -18568, 0, 26262, 0, -18567, 0, 26244, 0, -18566, 0, 26264, 0, -18565, 0, 26253, 0, -18564, 0, 26371, 0, -18563, 0, 27028, 0, -18562, 0, 26989, 0, -18527, 0, 26970, 0, -18526, 0, 26999, 0, -18525, 0, 26976, 0, -18524, 0, 26964, 0, -18523, 0, 26997, 0, -18522, 0, 26928, 0, -18521, 0, 27010, 0, -18520, 0, 26954, 0, -18519, 0, 26984, 0, -18518, 0, 26987, 0, -18517, 0, 26974, 0, -18516, 0, 26963, 0, -18515, 0, 27001, 0, -18514, 0, 27014, 0, -18513, 0, 26973, 0, -18512, 0, 26979, 0, -18511, 0, 26971, 0, -18510, 0, 27463, 0, -18509, 0, 27506, 0, -18508, 0, 27584, 0, -18507, 0, 27583, 0, -18506, 0, 27603, 0, -18505, 0, 27645, 0, -18504, 0, 28322, 0, -18503, 0, 28335, 0, -18502, 0, 28371, 0, -18501, 0, 28342, 0, -18500, 0, 28354, 0, -18499, 0, 28304, 0, -18498, 0, 28317, 0, -18497, 0, 28359, 0, -18496, 0, 28357, 0, -18495, 0, 28325, 0, -18494, 0, 28312, 0, -18493, 0, 28348, 0, -18492, 0, 28346, 0, -18491, 0, 28331, 0, -18490, 0, 28369, 0, -18489, 0, 28310, 0, -18488, 0, 28316, 0, -18487, 0, 28356, 0, -18486, 0, 28372, 0, -18485, 0, 28330, 0, -18484, 0, 28327, 0, -18483, 0, 28340, 0, -18482, 0, 29006, 0, -18481, 0, 29017, 0, -18480, 0, 29033, 0, -18479, 0, 29028, 0, -18478, 0, 29001, 0, -18477, 0, 29031, 0, -18476, 0, 29020, 0, -18475, 0, 29036, 0, -18474, 0, 29030, 0, -18473, 0, 29004, 0, -18472, 0, 29029, 0, -18471, 0, 29022, 0, -18470, 0, 28998, 0, -18469, 0, 29032, 0, -18468, 0, 29014, 0, -18467, 0, 29242, 0, -18466, 0, 29266, 0, -18465, 0, 29495, 0, -18464, 0, 29509, 0, -18463, 0, 29503, 0, -18462, 0, 29502, 0, -18461, 0, 29807, 0, -18460, 0, 29786, 0, -18459, 0, 29781, 0, -18458, 0, 29791, 0, -18457, 0, 29790, 0, -18456, 0, 29761, 0, -18455, 0, 29759, 0, -18454, 0, 29785, 0, -18453, 0, 29787, 0, -18452, 0, 29788, 0, -18451, 0, 30070, 0, -18450, 0, 30072, 0, -18449, 0, 30208, 0, -18448, 0, 30192, 0, -18447, 0, 30209, 0, -18446, 0, 30194, 0, -18445, 0, 30193, 0, -18444, 0, 30202, 0, -18443, 0, 30207, 0, -18442, 0, 30196, 0, -18441, 0, 30195, 0, -18440, 0, 30430, 0, -18439, 0, 30431, 0, -18438, 0, 30555, 0, -18437, 0, 30571, 0, -18436, 0, 30566, 0, -18435, 0, 30558, 0, -18434, 0, 30563, 0, -18368, 0, 30585, 0, -18367, 0, 30570, 0, -18366, 0, 30572, 0, -18365, 0, 30556, 0, -18364, 0, 30565, 0, -18363, 0, 30568, 0, -18362, 0, 30562, 0, -18361, 0, 30702, 0, -18360, 0, 30862, 0, -18359, 0, 30896, 0, -18358, 0, 30871, 0, -18357, 0, 30872, 0, -18356, 0, 30860, 0, -18355, 0, 30857, 0, -18354, 0, 30844, 0, -18353, 0, 30865, 0, -18352, 0, 30867, 0, -18351, 0, 30847, 0, -18350, 0, 31098, 0, -18349, 0, 31103, 0, -18348, 0, 31105, 0, -18347, 0, -31700, 0, -18346, 0, 31165, 0, -18345, 0, 31260, 0, -18344, 0, 31258, 0, -18343, 0, 31264, 0, -18342, 0, 31252, 0, -18341, 0, 31263, 0, -18340, 0, 31262, 0, -18339, 0, 31391, 0, -18338, 0, 31392, 0, -18337, 0, 31607, 0, -18336, 0, 31680, 0, -18335, 0, 31584, 0, -18334, 0, 31598, 0, -18333, 0, 31591, 0, -18332, 0, 31921, 0, -18331, 0, 31923, 0, -18330, 0, 31925, 0, -18329, 0, 32147, 0, -18328, 0, 32121, 0, -18327, 0, 32145, 0, -18326, 0, 32129, 0, -18325, 0, 32143, 0, -18324, 0, 32091, 0, -18323, 0, 32622, 0, -18322, 0, 32617, 0, -18321, 0, 32618, 0, -18320, 0, 32626, 0, -18319, 0, 32681, 0, -18318, 0, 32680, 0, -18317, 0, 32676, 0, -18316, 0, -32682, 0, -18315, 0, -32680, 0, -18314, 0, -32634, 0, -18313, 0, -32636, 0, -18312, 0, -32399, 0, -18311, 0, -32400, 0, -18310, 0, -32392, 0, -18309, 0, -32411, 0, -18308, 0, -32402, 0, -18307, 0, -32397, 0, -18306, 0, -32405, 0, -18271, 0, -32391, 0, -18270, 0, -32390, 0, -18269, 0, -32410, 0, -18268, 0, -32251, 0, -18267, 0, -32185, 0, -18266, 0, -31614, 0, -18265, 0, -31625, 0, -18264, 0, -31683, 0, -18263, 0, -31695, 0, -18262, 0, -31627, 0, -18261, 0, -31642, 0, -18260, 0, -31637, 0, -18259, 0, -31671, 0, -18258, 0, -31636, 0, -18257, 0, -31653, 0, -18256, 0, -31684, 0, -18255, 0, -31691, 0, -18254, 0, -31647, 0, -18253, 0, -31645, 0, -18252, 0, -31639, 0, -18251, 0, -31635, 0, -18250, 0, -31674, 0, -18249, 0, -31138, 0, -18248, 0, -31140, 0, -18247, 0, -31137, 0, -18246, 0, -30983, 0, -18245, 0, -30957, 0, -18244, 0, -30968, 0, -18243, 0, -30969, 0, -18242, 0, -30976, 0, -18241, 0, -30978, 0, -18240, 0, -30981, 0, -18239, 0, -30974, 0, -18238, 0, -30973, 0, -18237, 0, -30970, 0, -18236, 0, -30966, 0, -18235, 0, -30631, 0, -18234, 0, -30497, 0, -18233, 0, -30508, 0, -18232, 0, -30503, 0, -18231, 0, -30500, 0, -18230, 0, -30504, 0, -18229, 0, -30499, 0, -18228, 0, -30495, 0, -18227, 0, -30518, 0, -18226, 0, -30507, 0, -18225, 0, -30510, 0, -18224, 0, -30308, 0, -18223, 0, -30237, 0, -18222, 0, -30101, 0, -18221, 0, -30094, 0, -18220, 0, -30093, 0, -18219, 0, -30106, 0, -18218, 0, -30103, 0, -18217, 0, -30096, 0, -18216, 0, -30073, 0, -18215, 0, -30084, 0, -18214, 0, -30109, 0, -18213, 0, -30048, 0, -18212, 0, -30095, 0, -18211, 0, -30075, 0, -18210, 0, -30099, 0, -18209, 0, -30110, 0, -18208, 0, -30098, 0, -18207, 0, -30100, 0, -18206, 0, -30087, 0, -18205, 0, -30085, 0, -18204, 0, -30146, 0, -18203, 0, -30104, 0, -18202, 0, -29598, 0, -18201, 0, -29558, 0, -18200, 0, -29559, 0, -18199, 0, -29494, 0, -18198, 0, -29497, 0, -18197, 0, -29496, 0, -18196, 0, -29500, 0, -18195, 0, -29518, 0, -18194, 0, -29501, 0, -18193, 0, -29502, 0, -18192, 0, -29499, 0, -18191, 0, -29215, 0, -18190, 0, -29217, 0, -18189, 0, -29208, 0, -18188, 0, -29201, 0, -18187, 0, -29197, 0, -18186, 0, -29190, 0, -18185, 0, -29206, 0, -18184, 0, -29212, 0, -18183, 0, -29210, 0, -18182, 0, -29006, 0, -18181, 0, -28925, 0, -18180, 0, -28919, 0, -18179, 0, -28930, 0, -18178, 0, -28918, 0, -18112, 0, -28769, 0, -18111, 0, -28750, 0, -18110, 0, -28597, 0, -18109, 0, -28598, 0, -18108, 0, -28589, 0, -18107, 0, -28606, 0, -18106, 0, -28588, 0, -18105, 0, -28612, 0, -18104, 0, -28587, 0, -18103, 0, -28592, 0, -18102, 0, -28601, 0, -18101, 0, -28593, 0, -18100, 0, -28594, 0, -18099, 0, -28595, 0, -18098, 0, -28591, 0, -18097, 0, -28610, 0, -18096, 0, -28607, 0, -18095, 0, -28398, 0, -18094, 0, -28393, 0, -18093, 0, -28308, 0, -18092, 0, -28310, 0, -18091, 0, -28311, 0, -18090, 0, -28215, 0, -18089, 0, -28105, 0, -18088, 0, -28073, 0, -18087, 0, -28104, 0, -18086, 0, -28099, 0, -18085, 0, -28096, 0, -18084, 0, -28098, 0, -18083, 0, -28069, 0, -18082, 0, -28085, 0, -18081, 0, -28060, 0, -18080, 0, -28079, 0, -18079, 0, -28108, 0, -18078, 0, -28087, 0, -18077, 0, -28083, 0, -18076, 0, -28091, 0, -18075, 0, -28103, 0, -18074, 0, -28097, 0, -18073, 0, -28070, 0, -18072, 0, -27240, 0, -18071, 0, -26984, 0, -18070, 0, -26988, 0, -18069, 0, -26987, 0, -18068, 0, -26931, 0, -18067, 0, -26933, 0, -18066, 0, -26935, 0, -18065, 0, -26934, 0, -18064, 0, -26889, 0, -18063, 0, -26885, 0, -18062, 0, -26887, 0, -18061, 0, -26890, 0, -18060, 0, -26794, 0, -18059, 0, -26764, 0, -18058, 0, -26762, 0, -18057, 0, -26608, 0, -18056, 0, -26607, 0, -18055, 0, -26605, 0, -18054, 0, -26614, 0, -18053, 0, -26606, 0, -18052, 0, -26612, 0, -18051, 0, -26372, 0, -18050, 0, -26380, 0, -18015, 0, -26371, 0, -18014, 0, -26370, 0, -18013, 0, -26189, 0, -18012, 0, -26191, 0, -18011, 0, -26188, 0, -18010, 0, -25887, 0, -18009, 0, -25367, 0, -18008, 0, -24958, 0, -18007, 0, -24818, 0, -18006, 0, -24813, 0, -18005, 0, -24800, 0, -18004, 0, 20711, 0, -18003, 0, 20718, 0, -18002, 0, 20709, 0, -18001, 0, 20694, 0, -18000, 0, 20717, 0, -17999, 0, 20698, 0, -17998, 0, 20693, 0, -17997, 0, 20687, 0, -17996, 0, 20689, 0, -17995, 0, 20721, 0, -17994, 0, 20686, 0, -17993, 0, 20713, 0, -17992, 0, 20834, 0, -17991, 0, 20979, 0, -17990, 0, 21123, 0, -17989, 0, 21122, 0, -17988, 0, 21297, 0, -17987, 0, 21421, 0, -17986, 0, 22014, 0, -17985, 0, 22016, 0, -17984, 0, 22043, 0, -17983, 0, 22039, 0, -17982, 0, 22013, 0, -17981, 0, 22036, 0, -17980, 0, 22022, 0, -17979, 0, 22025, 0, -17978, 0, 22029, 0, -17977, 0, 22030, 0, -17976, 0, 22007, 0, -17975, 0, 22038, 0, -17974, 0, 22047, 0, -17973, 0, 22024, 0, -17972, 0, 22032, 0, -17971, 0, 22006, 0, -17970, 0, 22296, 0, -17969, 0, 22294, 0, -17968, 0, 22645, 0, -17967, 0, 22654, 0, -17966, 0, 22659, 0, -17965, 0, 22675, 0, -17964, 0, 22666, 0, -17963, 0, 22649, 0, -17962, 0, 22661, 0, -17961, 0, 22653, 0, -17960, 0, 22781, 0, -17959, 0, 22821, 0, -17958, 0, 22818, 0, -17957, 0, 22820, 0, -17956, 0, 22890, 0, -17955, 0, 22889, 0, -17954, 0, 23265, 0, -17953, 0, 23270, 0, -17952, 0, 23273, 0, -17951, 0, 23255, 0, -17950, 0, 23254, 0, -17949, 0, 23256, 0, -17948, 0, 23267, 0, -17947, 0, 23413, 0, -17946, 0, 23518, 0, -17945, 0, 23527, 0, -17944, 0, 23521, 0, -17943, 0, 23525, 0, -17942, 0, 23526, 0, -17941, 0, 23528, 0, -17940, 0, 23522, 0, -17939, 0, 23524, 0, -17938, 0, 23519, 0, -17937, 0, 23565, 0, -17936, 0, 23650, 0, -17935, 0, 23940, 0, -17934, 0, 23943, 0, -17933, 0, 24155, 0, -17932, 0, 24163, 0, -17931, 0, 24149, 0, -17930, 0, 24151, 0, -17929, 0, 24148, 0, -17928, 0, 24275, 0, -17927, 0, 24278, 0, -17926, 0, 24330, 0, -17925, 0, 24390, 0, -17924, 0, 24432, 0, -17923, 0, 24505, 0, -17922, 0, 24903, 0, -17856, 0, 24895, 0, -17855, 0, 24907, 0, -17854, 0, 24951, 0, -17853, 0, 24930, 0, -17852, 0, 24931, 0, -17851, 0, 24927, 0, -17850, 0, 24922, 0, -17849, 0, 24920, 0, -17848, 0, 24949, 0, -17847, 0, 25130, 0, -17846, 0, 25735, 0, -17845, 0, 25688, 0, -17844, 0, 25684, 0, -17843, 0, 25764, 0, -17842, 0, 25720, 0, -17841, 0, 25695, 0, -17840, 0, 25722, 0, -17839, 0, 25681, 0, -17838, 0, 25703, 0, -17837, 0, 25652, 0, -17836, 0, 25709, 0, -17835, 0, 25723, 0, -17834, 0, 25970, 0, -17833, 0, 26017, 0, -17832, 0, 26071, 0, -17831, 0, 26070, 0, -17830, 0, 26274, 0, -17829, 0, 26280, 0, -17828, 0, 26269, 0, -17827, 0, 27036, 0, -17826, 0, 27048, 0, -17825, 0, 27029, 0, -17824, 0, 27073, 0, -17823, 0, 27054, 0, -17822, 0, 27091, 0, -17821, 0, 27083, 0, -17820, 0, 27035, 0, -17819, 0, 27063, 0, -17818, 0, 27067, 0, -17817, 0, 27051, 0, -17816, 0, 27060, 0, -17815, 0, 27088, 0, -17814, 0, 27085, 0, -17813, 0, 27053, 0, -17812, 0, 27084, 0, -17811, 0, 27046, 0, -17810, 0, 27075, 0, -17809, 0, 27043, 0, -17808, 0, 27465, 0, -17807, 0, 27468, 0, -17806, 0, 27699, 0, -17805, 0, 28467, 0, -17804, 0, 28436, 0, -17803, 0, 28414, 0, -17802, 0, 28435, 0, -17801, 0, 28404, 0, -17800, 0, 28457, 0, -17799, 0, 28478, 0, -17798, 0, 28448, 0, -17797, 0, 28460, 0, -17796, 0, 28431, 0, -17795, 0, 28418, 0, -17794, 0, 28450, 0, -17759, 0, 28415, 0, -17758, 0, 28399, 0, -17757, 0, 28422, 0, -17756, 0, 28465, 0, -17755, 0, 28472, 0, -17754, 0, 28466, 0, -17753, 0, 28451, 0, -17752, 0, 28437, 0, -17751, 0, 28459, 0, -17750, 0, 28463, 0, -17749, 0, 28552, 0, -17748, 0, 28458, 0, -17747, 0, 28396, 0, -17746, 0, 28417, 0, -17745, 0, 28402, 0, -17744, 0, 28364, 0, -17743, 0, 28407, 0, -17742, 0, 29076, 0, -17741, 0, 29081, 0, -17740, 0, 29053, 0, -17739, 0, 29066, 0, -17738, 0, 29060, 0, -17737, 0, 29074, 0, -17736, 0, 29246, 0, -17735, 0, 29330, 0, -17734, 0, 29334, 0, -17733, 0, 29508, 0, -17732, 0, 29520, 0, -17731, 0, 29796, 0, -17730, 0, 29795, 0, -17729, 0, 29802, 0, -17728, 0, 29808, 0, -17727, 0, 29805, 0, -17726, 0, 29956, 0, -17725, 0, 30097, 0, -17724, 0, 30247, 0, -17723, 0, 30221, 0, -17722, 0, 30219, 0, -17721, 0, 30217, 0, -17720, 0, 30227, 0, -17719, 0, 30433, 0, -17718, 0, 30435, 0, -17717, 0, 30596, 0, -17716, 0, 30589, 0, -17715, 0, 30591, 0, -17714, 0, 30561, 0, -17713, 0, 30913, 0, -17712, 0, 30879, 0, -17711, 0, 30887, 0, -17710, 0, 30899, 0, -17709, 0, 30889, 0, -17708, 0, 30883, 0, -17707, 0, 31118, 0, -17706, 0, 31119, 0, -17705, 0, 31117, 0, -17704, 0, 31278, 0, -17703, 0, 31281, 0, -17702, 0, 31402, 0, -17701, 0, 31401, 0, -17700, 0, 31469, 0, -17699, 0, 31471, 0, -17698, 0, 31649, 0, -17697, 0, 31637, 0, -17696, 0, 31627, 0, -17695, 0, 31605, 0, -17694, 0, 31639, 0, -17693, 0, 31645, 0, -17692, 0, 31636, 0, -17691, 0, 31631, 0, -17690, 0, 31672, 0, -17689, 0, 31623, 0, -17688, 0, 31620, 0, -17687, 0, 31929, 0, -17686, 0, 31933, 0, -17685, 0, 31934, 0, -17684, 0, 32187, 0, -17683, 0, 32176, 0, -17682, 0, 32156, 0, -17681, 0, 32189, 0, -17680, 0, 32190, 0, -17679, 0, 32160, 0, -17678, 0, 32202, 0, -17677, 0, 32180, 0, -17676, 0, 32178, 0, -17675, 0, 32177, 0, -17674, 0, 32186, 0, -17673, 0, 32162, 0, -17672, 0, 32191, 0, -17671, 0, 32181, 0, -17670, 0, 32184, 0, -17669, 0, 32173, 0, -17668, 0, 32210, 0, -17667, 0, 32199, 0, -17666, 0, 32172, 0, -17600, 0, 32624, 0, -17599, 0, 32736, 0, -17598, 0, 32737, 0, -17597, 0, 32735, 0, -17596, 0, -32674, 0, -17595, 0, -32678, 0, -17594, 0, -32633, 0, -17593, 0, -32432, 0, -17592, 0, -32384, 0, -17591, 0, -32369, 0, -17590, 0, -32376, 0, -17589, 0, -32374, 0, -17588, 0, -32385, 0, -17587, 0, -32382, 0, -17586, 0, -32281, 0, -17585, 0, -32262, 0, -17584, 0, -32249, 0, -17583, 0, -32236, 0, -17582, 0, -32226, 0, -17581, 0, -32181, 0, -17580, 0, -31543, 0, -17579, 0, -31553, 0, -17578, 0, -31546, 0, -17577, 0, -31548, 0, -17576, 0, -31591, 0, -17575, 0, -31586, 0, -17574, 0, -31566, 0, -17573, 0, -31588, 0, -17572, 0, -31541, 0, -17571, 0, -31560, 0, -17570, 0, -31552, 0, -17569, 0, -31533, 0, -17568, 0, -31600, 0, -17567, 0, -31556, 0, -17566, 0, -31535, 0, -17565, 0, -31542, 0, -17564, 0, -30913, 0, -17563, 0, -30948, 0, -17562, 0, -30917, 0, -17561, 0, -30942, 0, -17560, 0, -30939, 0, -17559, 0, -30924, 0, -17558, 0, -30952, 0, -17557, 0, -30891, 0, -17556, 0, -30921, 0, -17555, 0, -30935, 0, -17554, 0, -30477, 0, -17553, 0, -30462, 0, -17552, 0, -30476, 0, -17551, 0, -30471, 0, -17550, 0, -30472, 0, -17549, 0, -30467, 0, -17548, 0, -30488, 0, -17547, 0, -30438, 0, -17546, 0, -30481, 0, -17545, 0, -30042, 0, -17544, 0, -30068, 0, -17543, 0, -30050, 0, -17542, 0, -30045, 0, -17541, 0, -30067, 0, -17540, 0, -30047, 0, -17539, 0, -30061, 0, -17538, 0, -30044, 0, -17503, 0, -30038, 0, -17502, 0, -30043, 0, -17501, 0, -30040, 0, -17500, 0, -30056, 0, -17499, 0, -30063, 0, -17498, 0, -30054, 0, -17497, 0, -30041, 0, -17496, 0, -29590, 0, -17495, 0, -29555, 0, -17494, 0, -29556, 0, -17493, 0, -29485, 0, -17492, 0, -29487, 0, -17491, 0, -29486, 0, -17490, 0, -29333, 0, -17489, 0, -29287, 0, -17488, 0, -29291, 0, -17487, 0, -29188, 0, -17486, 0, -28908, 0, -17485, 0, -28910, 0, -17484, 0, -28907, 0, -17483, 0, -28909, 0, -17482, 0, -28765, 0, -17481, 0, -28576, 0, -17480, 0, -28584, 0, -17479, 0, -28580, 0, -17478, 0, -28573, 0, -17477, 0, -28583, 0, -17476, 0, -28578, 0, -17475, 0, -28574, 0, -17474, 0, -28579, 0, -17473, 0, -28581, 0, -17472, 0, -28391, 0, -17471, 0, -28392, 0, -17470, 0, -28386, 0, -17469, 0, -28299, 0, -17468, 0, -28296, 0, -17467, 0, -28297, 0, -17466, 0, -28300, 0, -17465, 0, -28040, 0, -17464, 0, -28032, 0, -17463, 0, -28027, 0, -17462, 0, -28008, 0, -17461, 0, -28010, 0, -17460, 0, -28037, 0, -17459, 0, -28013, 0, -17458, 0, -28004, 0, -17457, 0, -27992, 0, -17456, 0, -28036, 0, -17455, 0, -28015, 0, -17454, 0, -27231, 0, -17453, 0, -27224, 0, -17452, 0, -27223, 0, -17451, 0, -27229, 0, -17450, 0, -27227, 0, -17449, 0, -27228, 0, -17448, 0, -26983, 0, -17447, 0, -26980, 0, -17446, 0, -26981, 0, -17445, 0, -26932, 0, -17444, 0, -26926, 0, -17443, 0, -26880, 0, -17442, 0, -26756, 0, -17441, 0, -26747, 0, -17440, 0, -26634, 0, -17439, 0, -26601, 0, -17438, 0, -26600, 0, -17437, 0, -26449, 0, -17436, 0, -26447, 0, -17435, 0, -26365, 0, -17434, 0, -26363, 0, -17433, 0, -26356, 0, -17432, 0, -26359, 0, -17431, 0, -26175, 0, -17430, 0, -25937, 0, -17429, 0, -25936, 0, -17428, 0, -25882, 0, -17427, 0, -25791, 0, -17426, 0, -25790, 0, -17425, 0, -25356, 0, -17424, 0, -25354, 0, -17423, 0, -25357, 0, -17422, 0, -24900, 0, -17421, 0, -24773, 0, -17420, 0, -24758, 0, -17419, 0, 20740, 0, -17418, 0, 20736, 0, -17417, 0, 20731, 0, -17416, 0, 20725, 0, -17415, 0, 20729, 0, -17414, 0, 20738, 0, -17413, 0, 20744, 0, -17412, 0, 20745, 0, -17411, 0, 20741, 0, -17410, 0, 20956, 0, -17344, 0, 21127, 0, -17343, 0, 21128, 0, -17342, 0, 21129, 0, -17341, 0, 21133, 0, -17340, 0, 21130, 0, -17339, 0, 21232, 0, -17338, 0, 21426, 0, -17337, 0, 22062, 0, -17336, 0, 22075, 0, -17335, 0, 22073, 0, -17334, 0, 22066, 0, -17333, 0, 22079, 0, -17332, 0, 22068, 0, -17331, 0, 22057, 0, -17330, 0, 22099, 0, -17329, 0, 22094, 0, -17328, 0, 22103, 0, -17327, 0, 22132, 0, -17326, 0, 22070, 0, -17325, 0, 22063, 0, -17324, 0, 22064, 0, -17323, 0, 22656, 0, -17322, 0, 22687, 0, -17321, 0, 22686, 0, -17320, 0, 22707, 0, -17319, 0, 22684, 0, -17318, 0, 22702, 0, -17317, 0, 22697, 0, -17316, 0, 22694, 0, -17315, 0, 22893, 0, -17314, 0, 23305, 0, -17313, 0, 23291, 0, -17312, 0, 23307, 0, -17311, 0, 23285, 0, -17310, 0, 23308, 0, -17309, 0, 23304, 0, -17308, 0, 23534, 0, -17307, 0, 23532, 0, -17306, 0, 23529, 0, -17305, 0, 23531, 0, -17304, 0, 23652, 0, -17303, 0, 23653, 0, -17302, 0, 23965, 0, -17301, 0, 23956, 0, -17300, 0, 24162, 0, -17299, 0, 24159, 0, -17298, 0, 24161, 0, -17297, 0, 24290, 0, -17296, 0, 24282, 0, -17295, 0, 24287, 0, -17294, 0, 24285, 0, -17293, 0, 24291, 0, -17292, 0, 24288, 0, -17291, 0, 24392, 0, -17290, 0, 24433, 0, -17289, 0, 24503, 0, -17288, 0, 24501, 0, -17287, 0, 24950, 0, -17286, 0, 24935, 0, -17285, 0, 24942, 0, -17284, 0, 24925, 0, -17283, 0, 24917, 0, -17282, 0, 24962, 0, -17247, 0, 24956, 0, -17246, 0, 24944, 0, -17245, 0, 24939, 0, -17244, 0, 24958, 0, -17243, 0, 24999, 0, -17242, 0, 24976, 0, -17241, 0, 25003, 0, -17240, 0, 24974, 0, -17239, 0, 25004, 0, -17238, 0, 24986, 0, -17237, 0, 24996, 0, -17236, 0, 24980, 0, -17235, 0, 25006, 0, -17234, 0, 25134, 0, -17233, 0, 25705, 0, -17232, 0, 25711, 0, -17231, 0, 25721, 0, -17230, 0, 25758, 0, -17229, 0, 25778, 0, -17228, 0, 25736, 0, -17227, 0, 25744, 0, -17226, 0, 25776, 0, -17225, 0, 25765, 0, -17224, 0, 25747, 0, -17223, 0, 25749, 0, -17222, 0, 25769, 0, -17221, 0, 25746, 0, -17220, 0, 25774, 0, -17219, 0, 25773, 0, -17218, 0, 25771, 0, -17217, 0, 25754, 0, -17216, 0, 25772, 0, -17215, 0, 25753, 0, -17214, 0, 25762, 0, -17213, 0, 25779, 0, -17212, 0, 25973, 0, -17211, 0, 25975, 0, -17210, 0, 25976, 0, -17209, 0, 26286, 0, -17208, 0, 26283, 0, -17207, 0, 26292, 0, -17206, 0, 26289, 0, -17205, 0, 27171, 0, -17204, 0, 27167, 0, -17203, 0, 27112, 0, -17202, 0, 27137, 0, -17201, 0, 27166, 0, -17200, 0, 27161, 0, -17199, 0, 27133, 0, -17198, 0, 27169, 0, -17197, 0, 27155, 0, -17196, 0, 27146, 0, -17195, 0, 27123, 0, -17194, 0, 27138, 0, -17193, 0, 27141, 0, -17192, 0, 27117, 0, -17191, 0, 27153, 0, -17190, 0, 27472, 0, -17189, 0, 27470, 0, -17188, 0, 27556, 0, -17187, 0, 27589, 0, -17186, 0, 27590, 0, -17185, 0, 28479, 0, -17184, 0, 28540, 0, -17183, 0, 28548, 0, -17182, 0, 28497, 0, -17181, 0, 28518, 0, -17180, 0, 28500, 0, -17179, 0, 28550, 0, -17178, 0, 28525, 0, -17177, 0, 28507, 0, -17176, 0, 28536, 0, -17175, 0, 28526, 0, -17174, 0, 28558, 0, -17173, 0, 28538, 0, -17172, 0, 28528, 0, -17171, 0, 28516, 0, -17170, 0, 28567, 0, -17169, 0, 28504, 0, -17168, 0, 28373, 0, -17167, 0, 28527, 0, -17166, 0, 28512, 0, -17165, 0, 28511, 0, -17164, 0, 29087, 0, -17163, 0, 29100, 0, -17162, 0, 29105, 0, -17161, 0, 29096, 0, -17160, 0, 29270, 0, -17159, 0, 29339, 0, -17158, 0, 29518, 0, -17157, 0, 29527, 0, -17156, 0, 29801, 0, -17155, 0, 29835, 0, -17154, 0, 29827, 0, -17088, 0, 29822, 0, -17087, 0, 29824, 0, -17086, 0, 30079, 0, -17085, 0, 30240, 0, -17084, 0, 30249, 0, -17083, 0, 30239, 0, -17082, 0, 30244, 0, -17081, 0, 30246, 0, -17080, 0, 30241, 0, -17079, 0, 30242, 0, -17078, 0, 30362, 0, -17077, 0, 30394, 0, -17076, 0, 30436, 0, -17075, 0, 30606, 0, -17074, 0, 30599, 0, -17073, 0, 30604, 0, -17072, 0, 30609, 0, -17071, 0, 30603, 0, -17070, 0, 30923, 0, -17069, 0, 30917, 0, -17068, 0, 30906, 0, -17067, 0, 30922, 0, -17066, 0, 30910, 0, -17065, 0, 30933, 0, -17064, 0, 30908, 0, -17063, 0, 30928, 0, -17062, 0, 31295, 0, -17061, 0, 31292, 0, -17060, 0, 31296, 0, -17059, 0, 31293, 0, -17058, 0, 31287, 0, -17057, 0, 31291, 0, -17056, 0, 31407, 0, -17055, 0, 31406, 0, -17054, 0, 31661, 0, -17053, 0, 31665, 0, -17052, 0, 31684, 0, -17051, 0, 31668, 0, -17050, 0, 31686, 0, -17049, 0, 31687, 0, -17048, 0, 31681, 0, -17047, 0, 31648, 0, -17046, 0, 31692, 0, -17045, 0, 31946, 0, -17044, 0, 32224, 0, -17043, 0, 32244, 0, -17042, 0, 32239, 0, -17041, 0, 32251, 0, -17040, 0, 32216, 0, -17039, 0, 32236, 0, -17038, 0, 32221, 0, -17037, 0, 32232, 0, -17036, 0, 32227, 0, -17035, 0, 32218, 0, -17034, 0, 32222, 0, -17033, 0, 32233, 0, -17032, 0, 32158, 0, -17031, 0, 32217, 0, -17030, 0, 32242, 0, -17029, 0, 32249, 0, -17028, 0, 32629, 0, -17027, 0, 32631, 0, -17026, 0, 32687, 0, -16991, 0, 32745, 0, -16990, 0, -32730, 0, -16989, 0, -32357, 0, -16988, 0, -32356, 0, -16987, 0, -32355, 0, -16986, 0, -32352, 0, -16985, 0, -32358, 0, -16984, 0, -32360, 0, -16983, 0, -31465, 0, -16982, 0, -31427, 0, -16981, 0, -31462, 0, -16980, 0, -31506, 0, -16979, 0, -31444, 0, -16978, 0, -31443, 0, -16977, 0, -31469, 0, -16976, 0, -31471, 0, -16975, 0, -31453, 0, -16974, 0, -31455, 0, -16973, 0, -31468, 0, -16972, 0, -31508, 0, -16971, 0, -31451, 0, -16970, 0, -31489, 0, -16969, 0, -31482, 0, -16968, 0, -30846, 0, -16967, 0, -30860, 0, -16966, 0, -30858, 0, -16965, 0, -30880, 0, -16964, 0, -30874, 0, -16963, 0, -30856, 0, -16962, 0, -30872, 0, -16961, 0, -30887, 0, -16960, 0, -30889, 0, -16959, 0, -30900, 0, -16958, 0, -30893, 0, -16957, 0, -30629, 0, -16956, 0, -30627, 0, -16955, 0, -30448, 0, -16954, 0, -30457, 0, -16953, 0, -30446, 0, -16952, 0, -30445, 0, -16951, 0, -30443, 0, -16950, 0, -30454, 0, -16949, 0, -30020, 0, -16948, 0, -29998, 0, -16947, 0, -30009, 0, -16946, 0, -30012, 0, -16945, 0, -30059, 0, -16944, 0, -30005, 0, -16943, 0, -29960, 0, -16942, 0, -30030, 0, -16941, 0, -30007, 0, -16940, 0, -30014, 0, -16939, 0, -30017, 0, -16938, 0, -30032, 0, -16937, 0, -29994, 0, -16936, 0, -30003, 0, -16935, 0, -30026, 0, -16934, 0, -30023, 0, -16933, 0, -29989, 0, -16932, 0, -29620, 0, -16931, 0, -29618, 0, -16930, 0, -29588, 0, -16929, 0, -29472, 0, -16928, 0, -29474, 0, -16927, 0, -29466, 0, -16926, 0, -29468, 0, -16925, 0, -29460, 0, -16924, 0, -29459, 0, -16923, 0, -29470, 0, -16922, 0, -29469, 0, -16921, 0, -29476, 0, -16920, 0, -29462, 0, -16919, 0, -29471, 0, -16918, 0, -29331, 0, -16917, 0, -29281, 0, -16916, 0, -29277, 0, -16915, 0, -29141, 0, -16914, 0, -29168, 0, -16913, 0, -29155, 0, -16912, 0, -29150, 0, -16911, 0, -29169, 0, -16910, 0, -29143, 0, -16909, 0, -29153, 0, -16908, 0, -29151, 0, -16907, 0, -29154, 0, -16906, 0, -28998, 0, -16905, 0, -28899, 0, -16904, 0, -28901, 0, -16903, 0, -28897, 0, -16902, 0, -28887, 0, -16901, 0, -28890, 0, -16900, 0, -28886, 0, -16899, 0, -28900, 0, -16898, 0, -28898, 0, -16832, 0, -28891, 0, -16831, 0, -28567, 0, -16830, 0, -28562, 0, -16829, 0, -28568, 0, -16828, 0, -28563, 0, -16827, 0, -28553, 0, -16826, 0, -28368, 0, -16825, 0, -28371, 0, -16824, 0, -28377, 0, -16823, 0, -28367, 0, -16822, 0, -28281, 0, -16821, 0, -28279, 0, -16820, 0, -28277, 0, -16819, 0, -28285, 0, -16818, 0, -27963, 0, -16817, 0, -27973, 0, -16816, 0, -27977, 0, -16815, 0, -27926, 0, -16814, 0, -27988, 0, -16813, 0, -27932, 0, -16812, 0, -27967, 0, -16811, 0, -27981, 0, -16810, 0, -27972, 0, -16809, 0, -27950, 0, -16808, 0, -27961, 0, -16807, 0, -27920, 0, -16806, 0, -27982, 0, -16805, 0, -27219, 0, -16804, 0, -27215, 0, -16803, 0, -26876, 0, -16802, 0, -26874, 0, -16801, 0, -26873, 0, -16800, 0, -26871, 0, -16799, 0, -26784, 0, -16798, 0, -26739, 0, -16797, 0, -26741, 0, -16796, 0, -26737, 0, -16795, 0, -26591, 0, -16794, 0, -26581, 0, -16793, 0, -26596, 0, -16792, 0, -26445, 0, -16791, 0, -26358, 0, -16790, 0, -26349, 0, -16789, 0, -26350, 0, -16788, 0, -26344, 0, -16787, 0, -26147, 0, -16786, 0, -26160, 0, -16785, 0, -26145, 0, -16784, 0, -26149, 0, -16783, 0, -26159, 0, -16782, 0, -26155, 0, -16781, 0, -26158, 0, -16780, 0, -26151, 0, -16779, 0, -25929, 0, -16778, 0, -25874, 0, -16777, 0, -25873, 0, -16776, 0, -25817, 0, -16775, 0, -25787, 0, -16774, 0, -25788, 0, -16773, 0, -25737, 0, -16772, 0, -25745, 0, -16771, 0, -25338, 0, -16770, 0, -25335, 0, -16735, 0, -25341, 0, -16734, 0, -24919, 0, -16733, 0, -24898, 0, -16732, 0, -24882, 0, -16731, 0, 22696, 0, -16730, 0, -24750, 0, -16729, 0, 20754, 0, -16728, 0, 20760, 0, -16727, 0, 20756, 0, -16726, 0, 20752, 0, -16725, 0, 20757, 0, -16724, 0, 20864, 0, -16723, 0, 20906, 0, -16722, 0, 20957, 0, -16721, 0, 21137, 0, -16720, 0, 21139, 0, -16719, 0, 21235, 0, -16718, 0, 22105, 0, -16717, 0, 22123, 0, -16716, 0, 22137, 0, -16715, 0, 22121, 0, -16714, 0, 22116, 0, -16713, 0, 22136, 0, -16712, 0, 22122, 0, -16711, 0, 22120, 0, -16710, 0, 22117, 0, -16709, 0, 22129, 0, -16708, 0, 22127, 0, -16707, 0, 22124, 0, -16706, 0, 22114, 0, -16705, 0, 22134, 0, -16704, 0, 22721, 0, -16703, 0, 22718, 0, -16702, 0, 22727, 0, -16701, 0, 22725, 0, -16700, 0, 22894, 0, -16699, 0, 23325, 0, -16698, 0, 23348, 0, -16697, 0, 23416, 0, -16696, 0, 23536, 0, -16695, 0, 23566, 0, -16694, 0, 24394, 0, -16693, 0, 25010, 0, -16692, 0, 24977, 0, -16691, 0, 25001, 0, -16690, 0, 24970, 0, -16689, 0, 25037, 0, -16688, 0, 25014, 0, -16687, 0, 25022, 0, -16686, 0, 25034, 0, -16685, 0, 25032, 0, -16684, 0, 25136, 0, -16683, 0, 25797, 0, -16682, 0, 25793, 0, -16681, 0, 25803, 0, -16680, 0, 25787, 0, -16679, 0, 25788, 0, -16678, 0, 25818, 0, -16677, 0, 25796, 0, -16676, 0, 25799, 0, -16675, 0, 25794, 0, -16674, 0, 25805, 0, -16673, 0, 25791, 0, -16672, 0, 25810, 0, -16671, 0, 25812, 0, -16670, 0, 25790, 0, -16669, 0, 25972, 0, -16668, 0, 26310, 0, -16667, 0, 26313, 0, -16666, 0, 26297, 0, -16665, 0, 26308, 0, -16664, 0, 26311, 0, -16663, 0, 26296, 0, -16662, 0, 27197, 0, -16661, 0, 27192, 0, -16660, 0, 27194, 0, -16659, 0, 27225, 0, -16658, 0, 27243, 0, -16657, 0, 27224, 0, -16656, 0, 27193, 0, -16655, 0, 27204, 0, -16654, 0, 27234, 0, -16653, 0, 27233, 0, -16652, 0, 27211, 0, -16651, 0, 27207, 0, -16650, 0, 27189, 0, -16649, 0, 27231, 0, -16648, 0, 27208, 0, -16647, 0, 27481, 0, -16646, 0, 27511, 0, -16645, 0, 27653, 0, -16644, 0, 28610, 0, -16643, 0, 28593, 0, -16642, 0, 28577, 0, -16576, 0, 28611, 0, -16575, 0, 28580, 0, -16574, 0, 28609, 0, -16573, 0, 28583, 0, -16572, 0, 28595, 0, -16571, 0, 28608, 0, -16570, 0, 28601, 0, -16569, 0, 28598, 0, -16568, 0, 28582, 0, -16567, 0, 28576, 0, -16566, 0, 28596, 0, -16565, 0, 29118, 0, -16564, 0, 29129, 0, -16563, 0, 29136, 0, -16562, 0, 29138, 0, -16561, 0, 29128, 0, -16560, 0, 29141, 0, -16559, 0, 29113, 0, -16558, 0, 29134, 0, -16557, 0, 29145, 0, -16556, 0, 29148, 0, -16555, 0, 29123, 0, -16554, 0, 29124, 0, -16553, 0, 29544, 0, -16552, 0, 29852, 0, -16551, 0, 29859, 0, -16550, 0, 29848, 0, -16549, 0, 29855, 0, -16548, 0, 29854, 0, -16547, 0, 29922, 0, -16546, 0, 29964, 0, -16545, 0, 29965, 0, -16544, 0, 30260, 0, -16543, 0, 30264, 0, -16542, 0, 30266, 0, -16541, 0, 30439, 0, -16540, 0, 30437, 0, -16539, 0, 30624, 0, -16538, 0, 30622, 0, -16537, 0, 30623, 0, -16536, 0, 30629, 0, -16535, 0, 30952, 0, -16534, 0, 30938, 0, -16533, 0, 30956, 0, -16532, 0, 30951, 0, -16531, 0, 31142, 0, -16530, 0, 31309, 0, -16529, 0, 31310, 0, -16528, 0, 31302, 0, -16527, 0, 31308, 0, -16526, 0, 31307, 0, -16525, 0, 31418, 0, -16524, 0, 31705, 0, -16523, 0, 31761, 0, -16522, 0, 31689, 0, -16521, 0, 31716, 0, -16520, 0, 31707, 0, -16519, 0, 31713, 0, -16518, 0, 31721, 0, -16517, 0, 31718, 0, -16516, 0, 31957, 0, -16515, 0, 31958, 0, -16514, 0, 32266, 0, -16479, 0, 32273, 0, -16478, 0, 32264, 0, -16477, 0, 32283, 0, -16476, 0, 32291, 0, -16475, 0, 32286, 0, -16474, 0, 32285, 0, -16473, 0, 32265, 0, -16472, 0, 32272, 0, -16471, 0, 32633, 0, -16470, 0, 32690, 0, -16469, 0, 32752, 0, -16468, 0, 32753, 0, -16467, 0, 32750, 0, -16466, 0, -32728, 0, -16465, 0, -32333, 0, -16464, 0, -32343, 0, -16463, 0, -32344, 0, -16462, 0, -32261, 0, -16461, 0, -32248, 0, -16460, 0, -32168, 0, -16459, 0, -32167, 0, -16458, 0, -31414, 0, -16457, 0, -31399, 0, -16456, 0, -31416, 0, -16455, 0, -31384, 0, -16454, 0, -31383, 0, -16453, 0, -31421, 0, -16452, 0, -31415, 0, -16451, 0, -31379, 0, -16450, 0, -31382, 0, -16449, 0, -31394, 0, -16448, 0, -30845, 0, -16447, 0, -30817, 0, -16446, 0, -30818, 0, -16445, 0, -30814, 0, -16444, 0, -30835, 0, -16443, 0, -30623, 0, -16442, 0, -30422, 0, -16441, 0, -30414, 0, -16440, 0, -30427, 0, -16439, 0, -30421, 0, -16438, 0, -30431, 0, -16437, 0, -30294, 0, -16436, 0, -30298, 0, -16435, 0, -29978, 0, -16434, 0, -29958, 0, -16433, 0, -29973, 0, -16432, 0, -29967, 0, -16431, 0, -29952, 0, -16430, 0, -29988, 0, -16429, 0, -29977, 0, -16428, 0, -29970, 0, -16427, 0, -29954, 0, -16426, 0, -29951, 0, -16425, 0, -29950, 0, -16424, 0, -29961, 0, -16423, 0, -29971, 0, -16422, 0, -29965, 0, -16421, 0, -29962, 0, -16420, 0, -29956, 0, -16419, 0, -29589, 0, -16418, 0, -29587, 0, -16417, 0, -29549, 0, -16416, 0, -29452, 0, -16415, 0, -29116, 0, -16414, 0, -29135, 0, -16413, 0, -29132, 0, -16412, 0, -29118, 0, -16411, 0, -29127, 0, -16410, 0, -29131, 0, -16409, 0, -28869, 0, -16408, 0, -28881, 0, -16407, 0, -28872, 0, -16406, 0, -28877, 0, -16405, 0, -28760, 0, -16404, 0, -28762, 0, -16403, 0, -28555, 0, -16402, 0, -28556, 0, -16401, 0, -28552, 0, -16400, 0, -28558, 0, -16399, 0, -28548, 0, -16398, 0, -28550, 0, -16397, 0, -28364, 0, -16396, 0, -28270, 0, -16395, 0, -27872, 0, -16394, 0, -27850, 0, -16393, 0, -27912, 0, -16392, 0, -27853, 0, -16391, 0, -27857, 0, -16390, 0, -27870, 0, -16389, 0, -27908, 0, -16388, 0, -27861, 0, -16387, 0, -27900, 0, -16386, 0, -27878, 0, -16320, 0, -27888, 0, -16319, 0, -27866, 0, -16318, 0, -27871, 0, -16317, 0, -27883, 0, -16316, 0, -27858, 0, -16315, 0, -27879, 0, -16314, 0, -27205, 0, -16313, 0, -26969, 0, -16312, 0, -26968, 0, -16311, 0, -26966, 0, -16310, 0, -26923, 0, -16309, 0, -26866, 0, -16308, 0, -26863, 0, -16307, 0, -26858, 0, -16306, 0, -26867, 0, -16305, 0, -26861, 0, -16304, 0, -26865, 0, -16303, 0, -26789, 0, -16302, 0, -26788, 0, -16301, 0, -26778, 0, -16300, 0, -26728, 0, -16299, 0, -26576, 0, -16298, 0, -26568, 0, -16297, 0, -26565, 0, -16296, 0, -26569, 0, -16295, 0, -26579, 0, -16294, 0, -26567, 0, -16293, 0, -26588, 0, -16292, 0, -26352, 0, -16291, 0, -26328, 0, -16290, 0, -26338, 0, -16289, 0, -26341, 0, -16288, 0, -26335, 0, -16287, 0, -26342, 0, -16286, 0, -26131, 0, -16285, 0, -26142, 0, -16284, 0, -26127, 0, -16283, 0, -25928, 0, -16282, 0, -25924, 0, -16281, 0, -25861, 0, -16280, 0, -25875, 0, -16279, 0, -25816, 0, -16278, 0, -25711, 0, -16277, 0, -25323, 0, -16276, 0, -25309, 0, -16275, 0, -25306, 0, -16274, 0, -25304, 0, -16273, 0, -25326, 0, -16272, 0, -25317, 0, -16271, 0, -24872, 0, -16270, 0, -24876, 0, -16269, 0, -24691, 0, -16268, 0, -24676, 0, -16267, 0, 20778, 0, -16266, 0, 20767, 0, -16265, 0, 20769, 0, -16264, 0, 20786, 0, -16263, 0, 21237, 0, -16262, 0, 22158, 0, -16261, 0, 22144, 0, -16260, 0, 22160, 0, -16259, 0, 22149, 0, -16258, 0, 22151, 0, -16223, 0, 22159, 0, -16222, 0, 22741, 0, -16221, 0, 22739, 0, -16220, 0, 22737, 0, -16219, 0, 22734, 0, -16218, 0, 23344, 0, -16217, 0, 23338, 0, -16216, 0, 23332, 0, -16215, 0, 23418, 0, -16214, 0, 23607, 0, -16213, 0, 23656, 0, -16212, 0, 23996, 0, -16211, 0, 23994, 0, -16210, 0, 23997, 0, -16209, 0, 23992, 0, -16208, 0, 24171, 0, -16207, 0, 24396, 0, -16206, 0, 24509, 0, -16205, 0, 25033, 0, -16204, 0, 25026, 0, -16203, 0, 25031, 0, -16202, 0, 25062, 0, -16201, 0, 25035, 0, -16200, 0, 25138, 0, -16199, 0, 25140, 0, -16198, 0, 25806, 0, -16197, 0, 25802, 0, -16196, 0, 25816, 0, -16195, 0, 25824, 0, -16194, 0, 25840, 0, -16193, 0, 25830, 0, -16192, 0, 25836, 0, -16191, 0, 25841, 0, -16190, 0, 25826, 0, -16189, 0, 25837, 0, -16188, 0, 25986, 0, -16187, 0, 25987, 0, -16186, 0, 26329, 0, -16185, 0, 26326, 0, -16184, 0, 27264, 0, -16183, 0, 27284, 0, -16182, 0, 27268, 0, -16181, 0, 27298, 0, -16180, 0, 27292, 0, -16179, 0, 27355, 0, -16178, 0, 27299, 0, -16177, 0, 27262, 0, -16176, 0, 27287, 0, -16175, 0, 27280, 0, -16174, 0, 27296, 0, -16173, 0, 27484, 0, -16172, 0, 27566, 0, -16171, 0, 27610, 0, -16170, 0, 27656, 0, -16169, 0, 28632, 0, -16168, 0, 28657, 0, -16167, 0, 28639, 0, -16166, 0, 28640, 0, -16165, 0, 28635, 0, -16164, 0, 28644, 0, -16163, 0, 28651, 0, -16162, 0, 28655, 0, -16161, 0, 28544, 0, -16160, 0, 28652, 0, -16159, 0, 28641, 0, -16158, 0, 28649, 0, -16157, 0, 28629, 0, -16156, 0, 28654, 0, -16155, 0, 28656, 0, -16154, 0, 29159, 0, -16153, 0, 29151, 0, -16152, 0, 29166, 0, -16151, 0, 29158, 0, -16150, 0, 29157, 0, -16149, 0, 29165, 0, -16148, 0, 29164, 0, -16147, 0, 29172, 0, -16146, 0, 29152, 0, -16145, 0, 29237, 0, -16144, 0, 29254, 0, -16143, 0, 29552, 0, -16142, 0, 29554, 0, -16141, 0, 29865, 0, -16140, 0, 29872, 0, -16139, 0, 29862, 0, -16138, 0, 29864, 0, -16137, 0, 30278, 0, -16136, 0, 30274, 0, -16135, 0, 30284, 0, -16134, 0, 30442, 0, -16133, 0, 30643, 0, -16132, 0, 30634, 0, -16131, 0, 30640, 0, -16130, 0, 30636, 0, -16064, 0, 30631, 0, -16063, 0, 30637, 0, -16062, 0, 30703, 0, -16061, 0, 30967, 0, -16060, 0, 30970, 0, -16059, 0, 30964, 0, -16058, 0, 30959, 0, -16057, 0, 30977, 0, -16056, 0, 31143, 0, -16055, 0, 31146, 0, -16054, 0, 31319, 0, -16053, 0, 31423, 0, -16052, 0, 31751, 0, -16051, 0, 31757, 0, -16050, 0, 31742, 0, -16049, 0, 31735, 0, -16048, 0, 31756, 0, -16047, 0, 31712, 0, -16046, 0, 31968, 0, -16045, 0, 31964, 0, -16044, 0, 31966, 0, -16043, 0, 31970, 0, -16042, 0, 31967, 0, -16041, 0, 31961, 0, -16040, 0, 31965, 0, -16039, 0, 32302, 0, -16038, 0, 32318, 0, -16037, 0, 32326, 0, -16036, 0, 32311, 0, -16035, 0, 32306, 0, -16034, 0, 32323, 0, -16033, 0, 32299, 0, -16032, 0, 32317, 0, -16031, 0, 32305, 0, -16030, 0, 32325, 0, -16029, 0, 32321, 0, -16028, 0, 32308, 0, -16027, 0, 32313, 0, -16026, 0, 32328, 0, -16025, 0, 32309, 0, -16024, 0, 32319, 0, -16023, 0, 32303, 0, -16022, 0, 32580, 0, -16021, 0, 32755, 0, -16020, 0, 32764, 0, -16019, 0, -32655, 0, -16018, 0, -32654, 0, -16017, 0, -32656, 0, -16016, 0, -32657, 0, -16015, 0, -32653, 0, -16014, 0, -32314, 0, -16013, 0, -32317, 0, -16012, 0, -32326, 0, -16011, 0, -32318, 0, -16010, 0, -32320, 0, -16009, 0, -32321, 0, -16008, 0, -32323, 0, -16007, 0, -32311, 0, -16006, 0, -32322, 0, -16005, 0, -32280, 0, -16004, 0, -32247, 0, -16003, 0, -32143, 0, -16002, 0, -31318, 0, -15967, 0, -31356, 0, -15966, 0, -31362, 0, -15965, 0, -31332, 0, -15964, 0, -31343, 0, -15963, 0, -31340, 0, -15962, 0, -31313, 0, -15961, 0, -31333, 0, -15960, 0, -31353, 0, -15959, 0, -31320, 0, -15958, 0, -31350, 0, -15957, 0, -31129, 0, -15956, 0, -30784, 0, -15955, 0, -30767, 0, -15954, 0, -30797, 0, -15953, 0, -30766, 0, -15952, 0, -30778, 0, -15951, 0, -30805, 0, -15950, 0, -30789, 0, -15949, 0, -30790, 0, -15948, 0, -30776, 0, -15947, 0, -30773, 0, -15946, 0, -30405, 0, -15945, 0, -30410, 0, -15944, 0, -30396, 0, -15943, 0, -30408, 0, -15942, 0, -30403, 0, -15941, 0, -30292, 0, -15940, 0, -29938, 0, -15939, 0, -29929, 0, -15938, 0, -29927, 0, -15937, 0, -29925, 0, -15936, 0, -29942, 0, -15935, 0, -29920, 0, -15934, 0, -29923, 0, -15933, 0, -29948, 0, -15932, 0, -29936, 0, -15931, 0, -29631, 0, -15930, 0, -29633, 0, -15929, 0, -29581, 0, -15928, 0, -29446, 0, -15927, 0, -29443, 0, -15926, 0, -29444, 0, -15925, 0, -29448, 0, -15924, 0, -29445, 0, -15923, 0, -29272, 0, -15922, 0, -29111, 0, -15921, 0, -29109, 0, -15920, 0, -29112, 0, -15919, 0, -29110, 0, -15918, 0, -28860, 0, -15917, 0, -28866, 0, -15916, 0, -28862, 0, -15915, 0, -28859, 0, -15914, 0, -28865, 0, -15913, 0, -28545, 0, -15912, 0, -28547, 0, -15911, 0, -28540, 0, -15910, 0, -28543, 0, -15909, 0, -28542, 0, -15908, 0, -28544, 0, -15907, 0, -28359, 0, -15906, 0, -28253, 0, -15905, 0, -28258, 0, -15904, 0, -28260, 0, -15903, 0, -27827, 0, -15902, 0, -27774, 0, -15901, 0, -27864, 0, -15900, 0, -27787, 0, -15899, 0, -27830, 0, -15898, 0, -27803, 0, -15897, 0, -27829, 0, -15896, 0, -27880, 0, -15895, 0, -27778, 0, -15894, 0, -27796, 0, -15893, 0, -27813, 0, -15892, 0, -27792, 0, -15891, 0, -27814, 0, -15890, 0, -27820, 0, -15889, 0, -27190, 0, -15888, 0, -27189, 0, -15887, 0, -27188, 0, -15886, 0, -27192, 0, -15885, 0, -27194, 0, -15884, 0, -26959, 0, -15883, 0, -26952, 0, -15882, 0, -26922, 0, -15881, 0, -26852, 0, -15880, 0, -26850, 0, -15879, 0, -26720, 0, -15878, 0, -26669, 0, -15877, 0, -26554, 0, -15876, 0, -26442, 0, -15875, 0, -26315, 0, -15874, 0, -26111, 0, -15808, 0, -26113, 0, -15807, 0, -25682, 0, -15806, 0, -25685, 0, -15805, 0, -25686, 0, -15804, 0, -25683, 0, -15803, 0, -25285, 0, -15802, 0, -25281, 0, -15801, 0, -24949, 0, -15800, 0, -24881, 0, -15799, 0, -24866, 0, -15798, 0, -24868, 0, -15797, 0, -24867, 0, -15796, 0, -24869, 0, -15795, 0, -24770, 0, -15794, 0, -24757, 0, -15793, 0, 21474, 0, -15792, 0, 22165, 0, -15791, 0, 22190, 0, -15790, 0, 22745, 0, -15789, 0, 22744, 0, -15788, 0, 23352, 0, -15787, 0, 24413, 0, -15786, 0, 25059, 0, -15785, 0, 25139, 0, -15784, 0, 25844, 0, -15783, 0, 25842, 0, -15782, 0, 25854, 0, -15781, 0, 25862, 0, -15780, 0, 25850, 0, -15779, 0, 25851, 0, -15778, 0, 25847, 0, -15777, 0, 26039, 0, -15776, 0, 26332, 0, -15775, 0, 26406, 0, -15774, 0, 27315, 0, -15773, 0, 27308, 0, -15772, 0, 27331, 0, -15771, 0, 27323, 0, -15770, 0, 27320, 0, -15769, 0, 27330, 0, -15768, 0, 27310, 0, -15767, 0, 27311, 0, -15766, 0, 27487, 0, -15765, 0, 27512, 0, -15764, 0, 27567, 0, -15763, 0, 28681, 0, -15762, 0, 28683, 0, -15761, 0, 28670, 0, -15760, 0, 28678, 0, -15759, 0, 28666, 0, -15758, 0, 28689, 0, -15757, 0, 28687, 0, -15756, 0, 29179, 0, -15755, 0, 29180, 0, -15754, 0, 29182, 0, -15753, 0, 29176, 0, -15752, 0, 29559, 0, -15751, 0, 29557, 0, -15750, 0, 29863, 0, -15749, 0, 29887, 0, -15748, 0, 29973, 0, -15747, 0, 30294, 0, -15746, 0, 30296, 0, -15711, 0, 30290, 0, -15710, 0, 30653, 0, -15709, 0, 30655, 0, -15708, 0, 30651, 0, -15707, 0, 30652, 0, -15706, 0, 30990, 0, -15705, 0, 31150, 0, -15704, 0, 31329, 0, -15703, 0, 31330, 0, -15702, 0, 31328, 0, -15701, 0, 31428, 0, -15700, 0, 31429, 0, -15699, 0, 31787, 0, -15698, 0, 31783, 0, -15697, 0, 31786, 0, -15696, 0, 31774, 0, -15695, 0, 31779, 0, -15694, 0, 31777, 0, -15693, 0, 31975, 0, -15692, 0, 32340, 0, -15691, 0, 32341, 0, -15690, 0, 32350, 0, -15689, 0, 32346, 0, -15688, 0, 32353, 0, -15687, 0, 32338, 0, -15686, 0, 32345, 0, -15685, 0, 32584, 0, -15684, 0, 32761, 0, -15683, 0, 32763, 0, -15682, 0, -32649, 0, -15681, 0, -32650, 0, -15680, 0, -32307, 0, -15679, 0, -32305, 0, -15678, 0, -32246, 0, -15677, 0, -31281, 0, -15676, 0, -31319, 0, -15675, 0, -31283, 0, -15674, 0, -31280, 0, -15673, 0, -31287, 0, -15672, 0, -31312, 0, -15671, 0, -31302, 0, -15670, 0, -31303, 0, -15669, 0, -31322, 0, -15668, 0, -30737, 0, -15667, 0, -30740, 0, -15666, 0, -30734, 0, -15665, 0, -30752, 0, -15664, 0, -30330, 0, -15663, 0, -30286, 0, -15662, 0, -30220, 0, -15661, 0, -29912, 0, -15660, 0, -29895, 0, -15659, 0, -29908, 0, -15658, 0, -29909, 0, -15657, 0, -29616, 0, -15656, 0, -29435, 0, -15655, 0, -29095, 0, -15654, 0, -29085, 0, -15653, 0, -29082, 0, -15652, 0, -29084, 0, -15651, 0, -29089, 0, -15650, 0, -29099, 0, -15649, 0, -28992, 0, -15648, 0, -28855, 0, -15647, 0, -28851, 0, -15646, 0, -28537, 0, -15645, 0, -28541, 0, -15644, 0, -28536, 0, -15643, 0, -28245, 0, -15642, 0, -28244, 0, -15641, 0, -28208, 0, -15640, 0, -27756, 0, -15639, 0, -27766, 0, -15638, 0, -27754, 0, -15637, 0, -27742, 0, -15636, 0, -27725, 0, -15635, 0, -27730, 0, -15634, 0, -27732, 0, -15633, 0, -27728, 0, -15632, 0, -27752, 0, -15631, 0, -27750, 0, -15630, 0, -27753, 0, -15629, 0, -27180, 0, -15628, 0, -27178, 0, -15627, 0, -27184, 0, -15626, 0, -27179, 0, -15625, 0, -26910, 0, -15624, 0, -26916, 0, -15623, 0, -26919, 0, -15622, 0, -26917, 0, -15621, 0, -26914, 0, -15620, 0, -26844, 0, -15619, 0, -26717, 0, -15618, 0, -26714, 0, -15552, 0, -26707, 0, -15551, 0, -26631, 0, -15550, 0, -26547, 0, -15549, 0, -26545, 0, -15548, 0, -26548, 0, -15547, 0, -26546, 0, -15546, 0, -26541, 0, -15545, 0, -26438, 0, -15544, 0, -26306, 0, -15543, 0, -26305, 0, -15542, 0, -26307, 0, -15541, 0, -26322, 0, -15540, 0, -26203, 0, -15539, 0, -26098, 0, -15538, 0, -25919, 0, -15537, 0, -25853, 0, -15536, 0, -25850, 0, -15535, 0, -25777, 0, -15534, 0, -25778, 0, -15533, 0, -25779, 0, -15532, 0, -25654, 0, -15531, 0, -25655, 0, -15530, 0, -25603, 0, -15529, 0, -25656, 0, -15528, 0, -25664, 0, -15527, 0, -25263, 0, -15526, 0, -25251, 0, -15525, 0, -25248, 0, -15524, 0, -24864, 0, -15523, 0, -24811, 0, -15522, 0, -24788, 0, -15521, 0, 20787, 0, -15520, 0, 22181, 0, -15519, 0, 22750, 0, -15518, 0, 22751, 0, -15517, 0, 22754, 0, -15516, 0, 23541, 0, -15515, 0, -24688, 0, -15514, 0, 24300, 0, -15513, 0, 25074, 0, -15512, 0, 25079, 0, -15511, 0, 25078, 0, -15510, 0, 25077, 0, -15509, 0, 25856, 0, -15508, 0, 25871, 0, -15507, 0, 26336, 0, -15506, 0, 26333, 0, -15505, 0, 27365, 0, -15504, 0, 27357, 0, -15503, 0, 27354, 0, -15502, 0, 27347, 0, -15501, 0, 28699, 0, -15500, 0, 28703, 0, -15499, 0, 28712, 0, -15498, 0, 28698, 0, -15497, 0, 28701, 0, -15496, 0, 28693, 0, -15495, 0, 28696, 0, -15494, 0, 29190, 0, -15493, 0, 29197, 0, -15492, 0, 29272, 0, -15491, 0, 29346, 0, -15490, 0, 29560, 0, -15455, 0, 29562, 0, -15454, 0, 29885, 0, -15453, 0, 29898, 0, -15452, 0, 29923, 0, -15451, 0, 30087, 0, -15450, 0, 30086, 0, -15449, 0, 30303, 0, -15448, 0, 30305, 0, -15447, 0, 30663, 0, -15446, 0, 31001, 0, -15445, 0, 31153, 0, -15444, 0, 31339, 0, -15443, 0, 31337, 0, -15442, 0, 31806, 0, -15441, 0, 31807, 0, -15440, 0, 31800, 0, -15439, 0, 31805, 0, -15438, 0, 31799, 0, -15437, 0, 31808, 0, -15436, 0, 32363, 0, -15435, 0, 32365, 0, -15434, 0, 32377, 0, -15433, 0, 32361, 0, -15432, 0, 32362, 0, -15431, 0, 32645, 0, -15430, 0, 32371, 0, -15429, 0, 32694, 0, -15428, 0, 32697, 0, -15427, 0, 32696, 0, -15426, 0, -32296, 0, -15425, 0, -31255, 0, -15424, 0, -31267, 0, -15423, 0, -31254, 0, -15422, 0, -31275, 0, -15421, 0, -31260, 0, -15420, 0, -31259, 0, -15419, 0, -31241, 0, -15418, 0, -30725, 0, -15417, 0, -30715, 0, -15416, 0, -30707, 0, -15415, 0, -30727, 0, -15414, 0, -30722, 0, -15413, 0, -30368, 0, -15412, 0, -30369, 0, -15411, 0, -30378, 0, -15410, 0, -30370, 0, -15409, 0, -29887, 0, -15408, 0, -29860, 0, -15407, 0, -29864, 0, -15406, 0, -29879, 0, -15405, 0, -29862, 0, -15404, 0, -29874, 0, -15403, 0, -29873, 0, -15402, 0, -29882, 0, -15401, 0, -29863, 0, -15400, 0, -29432, 0, -15399, 0, -29430, 0, -15398, 0, -29060, 0, -15397, 0, -29070, 0, -15396, 0, -29049, 0, -15395, 0, -29066, 0, -15394, 0, -29076, 0, -15393, 0, -29062, 0, -15392, 0, -29068, 0, -15391, 0, -28844, 0, -15390, 0, -28850, 0, -15389, 0, -28755, 0, -15388, 0, -28534, 0, -15387, 0, -28533, 0, -15386, 0, -28239, 0, -15385, 0, -28242, 0, -15384, 0, -27679, 0, -15383, 0, -27695, 0, -15382, 0, -27681, 0, -15381, 0, -27709, 0, -15380, 0, -27704, 0, -15379, 0, -27684, 0, -15378, 0, -27683, 0, -15377, 0, -27690, 0, -15376, 0, -27678, 0, -15375, 0, -27699, 0, -15374, 0, -27688, 0, -15373, 0, -27676, 0, -15372, 0, -27689, 0, -15371, 0, -27672, 0, -15370, 0, -27172, 0, -15369, 0, -26956, 0, -15368, 0, -26909, 0, -15367, 0, -26838, 0, -15366, 0, -26841, 0, -15365, 0, -26783, 0, -15364, 0, -26660, 0, -15363, 0, -26629, 0, -15362, 0, -26530, 0, -15296, 0, -26536, 0, -15295, 0, -26533, 0, -15294, 0, -26436, 0, -15293, 0, -26299, 0, -15292, 0, -26295, 0, -15291, 0, -26090, 0, -15290, 0, -26087, 0, -15289, 0, -25843, 0, -15288, 0, -25624, 0, -15287, 0, -25625, 0, -15286, 0, -25642, 0, -15285, 0, -25637, 0, -15284, 0, -25207, 0, -15283, 0, -25247, 0, -15282, 0, -25230, 0, -15281, 0, -25238, 0, -15280, 0, -25236, 0, -15279, 0, -24942, 0, -15278, 0, -24937, 0, -15277, 0, -24941, 0, -15276, 0, -24908, 0, -15275, 0, 21240, 0, -15274, 0, 22184, 0, -15273, 0, 22199, 0, -15272, 0, 22198, 0, -15271, 0, 22196, 0, -15270, 0, 22204, 0, -15269, 0, 22756, 0, -15268, 0, 23360, 0, -15267, 0, 23363, 0, -15266, 0, 23421, 0, -15265, 0, 23542, 0, -15264, 0, 24009, 0, -15263, 0, 25080, 0, -15262, 0, 25082, 0, -15261, 0, 25880, 0, -15260, 0, 25876, 0, -15259, 0, 25881, 0, -15258, 0, 26342, 0, -15257, 0, 26407, 0, -15256, 0, 27372, 0, -15255, 0, 28734, 0, -15254, 0, 28720, 0, -15253, 0, 28722, 0, -15252, 0, 29200, 0, -15251, 0, 29563, 0, -15250, 0, 29903, 0, -15249, 0, 30306, 0, -15248, 0, 30309, 0, -15247, 0, 31014, 0, -15246, 0, 31018, 0, -15245, 0, 31020, 0, -15244, 0, 31019, 0, -15243, 0, 31431, 0, -15242, 0, 31478, 0, -15241, 0, 31820, 0, -15240, 0, 31811, 0, -15239, 0, 31821, 0, -15238, 0, 31983, 0, -15237, 0, 31984, 0, -15236, 0, -28754, 0, -15235, 0, 32381, 0, -15234, 0, 32380, 0, -15199, 0, 32386, 0, -15198, 0, 32588, 0, -15197, 0, -32768, 0, -15196, 0, -32294, 0, -15195, 0, -32154, 0, -15194, 0, -31237, 0, -15193, 0, -31239, 0, -15192, 0, -31215, 0, -15191, 0, -31238, 0, -15190, 0, -31226, 0, -15189, 0, -31221, 0, -15188, 0, -31225, 0, -15187, 0, -31222, 0, -15186, 0, -30700, 0, -15185, 0, -30699, 0, -15184, 0, -30364, 0, -15183, 0, -30278, 0, -15182, 0, -30216, 0, -15181, 0, -29840, 0, -15180, 0, -29844, 0, -15179, 0, -29850, 0, -15178, 0, -29841, 0, -15177, 0, -29857, 0, -15176, 0, -29845, 0, -15175, 0, -29425, 0, -15174, 0, -29427, 0, -15173, 0, -29047, 0, -15172, 0, -29055, 0, -15171, 0, -29051, 0, -15170, 0, -29054, 0, -15169, 0, -28236, 0, -15168, 0, -28213, 0, -15167, 0, -27624, 0, -15166, 0, -27645, 0, -15165, 0, -27651, 0, -15164, 0, -27167, 0, -15163, 0, -26832, 0, -15162, 0, -26428, 0, -15161, 0, -26286, 0, -15160, 0, -26287, 0, -15159, 0, -26200, 0, -15158, 0, -26069, 0, -15157, 0, -26064, 0, -15156, 0, -26057, 0, -15155, 0, -26059, 0, -15154, 0, -25581, 0, -15153, 0, -25587, 0, -15152, 0, -24967, 0, -15151, 0, -24907, 0, -15150, 0, -24856, 0, -15149, 0, -24785, 0, -15148, 0, -24737, 0, -15147, 0, -24733, 0, -15146, 0, -24735, 0, -15145, 0, 20791, 0, -15144, 0, 20792, 0, -15143, 0, 22209, 0, -15142, 0, 22208, 0, -15141, 0, 22210, 0, -15140, 0, 22804, 0, -15139, 0, 23660, 0, -15138, 0, 24013, 0, -15137, 0, 25084, 0, -15136, 0, 25086, 0, -15135, 0, 25885, 0, -15134, 0, 25884, 0, -15133, 0, 26005, 0, -15132, 0, 26345, 0, -15131, 0, 27387, 0, -15130, 0, 27396, 0, -15129, 0, 27386, 0, -15128, 0, 27570, 0, -15127, 0, 28748, 0, -15126, 0, 29211, 0, -15125, 0, 29351, 0, -15124, 0, 29910, 0, -15123, 0, 29908, 0, -15122, 0, 30313, 0, -15121, 0, 30675, 0, -15120, 0, 31824, 0, -15119, 0, 32399, 0, -15118, 0, 32396, 0, -15117, 0, 32700, 0, -15116, 0, -31209, 0, -15115, 0, -31187, 0, -15114, 0, -31206, 0, -15113, 0, -30685, 0, -15112, 0, -30686, 0, -15111, 0, -30687, 0, -15110, 0, -30689, 0, -15109, 0, -30358, 0, -15108, 0, -30356, 0, -15107, 0, -30275, 0, -15106, 0, -29836, 0, -15040, 0, -29833, 0, -15039, 0, -29827, 0, -15038, 0, -29421, 0, -15037, 0, -29046, 0, -15036, 0, -29043, 0, -15035, 0, -29045, 0, -15034, 0, -28833, 0, -15033, 0, -28753, 0, -15032, 0, -28230, 0, -15031, 0, -27602, 0, -15030, 0, -27597, 0, -15029, 0, -27595, 0, -15028, 0, -27590, 0, -15027, 0, -27592, 0, -15026, 0, -27598, 0, -15025, 0, -27605, 0, -15024, 0, -27166, 0, -15023, 0, -26824, 0, -15022, 0, -26823, 0, -15021, 0, -26830, 0, -15020, 0, -26625, 0, -15019, 0, -26521, 0, -15018, 0, -26523, 0, -15017, 0, -26281, 0, -15016, 0, -26043, 0, -15015, 0, -26045, 0, -15014, 0, -26048, 0, -15013, 0, -26050, 0, -15012, 0, -25905, 0, -15011, 0, -25772, 0, -15010, 0, -25775, 0, -15009, 0, -25555, 0, -15008, 0, -25563, 0, -15007, 0, -25169, 0, -15006, 0, -25164, 0, -15005, 0, -25150, 0, -15004, 0, -25160, 0, -15003, 0, -24931, 0, -15002, 0, -24849, 0, -15001, 0, -24807, 0, -15000, 0, -24740, 0, -14999, 0, -24730, 0, -14998, 0, -24729, 0, -14997, 0, 20796, 0, -14996, 0, 20795, 0, -14995, 0, 22216, 0, -14994, 0, 22218, 0, -14993, 0, 22217, 0, -14992, 0, 23423, 0, -14991, 0, 24020, 0, -14990, 0, 24018, 0, -14989, 0, 24398, 0, -14988, 0, 25087, 0, -14987, 0, 25892, 0, -14986, 0, 27402, 0, -14985, 0, 27489, 0, -14984, 0, 28753, 0, -14983, 0, 28760, 0, -14982, 0, 29568, 0, -14981, 0, 29924, 0, -14980, 0, 30090, 0, -14979, 0, 30318, 0, -14978, 0, 30316, 0, -14943, 0, 31155, 0, -14942, 0, 31840, 0, -14941, 0, 31839, 0, -14940, 0, -32642, 0, -14939, 0, -32643, 0, -14938, 0, -32289, 0, -14937, 0, -30350, 0, -14936, 0, -30353, 0, -14935, 0, -30212, 0, -14934, 0, -29824, 0, -14933, 0, -29418, 0, -14932, 0, -29417, 0, -14931, 0, -29039, 0, -14930, 0, -29037, 0, -14929, 0, -28831, 0, -14928, 0, -28344, 0, -14927, 0, -27580, 0, -14926, 0, -27567, 0, -14925, 0, -27566, 0, -14924, 0, -26819, 0, -14923, 0, -26818, 0, -14922, 0, -26685, 0, -14921, 0, -26687, 0, -14920, 0, -26517, 0, -14919, 0, -26283, 0, -14918, 0, -26027, 0, -14917, 0, -26035, 0, -14916, 0, -25902, 0, -14915, 0, -25830, 0, -14914, 0, -25527, 0, -14913, 0, -25551, 0, -14912, 0, -25538, 0, -14911, 0, -25541, 0, -14910, 0, -25133, 0, -14909, 0, -25129, 0, -14908, 0, -24780, 0, -14907, 0, -24724, 0, -14906, 0, -24726, 0, -14905, 0, -24684, 0, -14904, 0, 22220, 0, -14903, 0, 24022, 0, -14902, 0, 25088, 0, -14901, 0, 25891, 0, -14900, 0, 25899, 0, -14899, 0, 25898, 0, -14898, 0, 26348, 0, -14897, 0, 27408, 0, -14896, 0, 29914, 0, -14895, 0, 31434, 0, -14894, 0, 31844, 0, -14893, 0, 31843, 0, -14892, 0, 31845, 0, -14891, 0, 32403, 0, -14890, 0, 32406, 0, -14889, 0, 32404, 0, -14888, 0, -32286, 0, -14887, 0, -31176, 0, -14886, 0, -31169, 0, -14885, 0, -30671, 0, -14884, 0, -29814, 0, -14883, 0, -28528, 0, -14882, 0, -28529, 0, -14881, 0, -27549, 0, -14880, 0, -27552, 0, -14879, 0, -27548, 0, -14878, 0, -26776, 0, -14877, 0, -26513, 0, -14876, 0, -26276, 0, -14875, 0, -26022, 0, -14874, 0, -26021, 0, -14873, 0, -26025, 0, -14872, 0, -25901, 0, -14871, 0, -25900, 0, -14870, 0, -25903, 0, -14869, 0, -25516, 0, -14868, 0, -25513, 0, -14867, 0, -25514, 0, -14866, 0, -25115, 0, -14865, 0, -24929, 0, -14864, 0, -24844, 0, -14863, 0, 22225, 0, -14862, 0, 22761, 0, -14861, 0, 25900, 0, -14860, 0, 28766, 0, -14859, 0, 30321, 0, -14858, 0, 30322, 0, -14857, 0, 30679, 0, -14856, 0, 32592, 0, -14855, 0, 32648, 0, -14854, 0, -30666, 0, -14853, 0, -30663, 0, -14852, 0, -30622, 0, -14851, 0, -29805, 0, -14850, 0, -29806, 0, -14784, 0, -29802, 0, -14783, 0, -32137, 0, -14782, 0, -29413, 0, -14781, 0, -28224, 0, -14780, 0, -27542, 0, -14779, 0, -26814, 0, -14778, 0, -26808, 0, -14777, 0, -26812, 0, -14776, 0, -26682, 0, -14775, 0, -26512, 0, -14774, 0, -26017, 0, -14773, 0, -25822, 0, -14772, 0, -25768, 0, -14771, 0, -25505, 0, -14770, 0, -25095, 0, -14769, 0, -25094, 0, -14768, 0, -24964, 0, -14767, 0, -24963, 0, -14766, 0, -24825, 0, -14765, 0, -24713, 0, -14764, 0, -24718, 0, -14763, 0, 24307, 0, -14762, 0, 27414, 0, -14761, 0, 28771, 0, -14760, 0, 31852, 0, -14759, 0, 31854, 0, -14758, 0, -30661, 0, -14757, 0, -30272, 0, -14756, 0, -29023, 0, -14755, 0, -28223, 0, -14754, 0, -27534, 0, -14753, 0, -27536, 0, -14752, 0, -26511, 0, -14751, 0, -26274, 0, -14750, 0, -25898, 0, -14749, 0, -25821, 0, -14748, 0, -24884, 0, -14747, 0, 28772, 0, -14746, 0, 30682, 0, -14745, 0, -29798, 0, -14744, 0, -27529, 0, -14743, 0, -26679, 0, -14742, 0, -26014, 0, -14741, 0, -26011, 0, -14740, 0, 32412, 0, -14739, 0, -29796, 0, -14738, 0, -29014, 0, -14737, 0, -28219, 0, -14736, 0, -27523, 0, -14735, 0, -27522, 0, -14734, 0, -27524, 0, -14733, 0, -25481, 0, -14732, 0, -25480, 0, -14731, 0, -24841, 0, -14730, 0, -29612, 0, -14729, 0, -27521, 0, -14728, 0, -25062, 0, -14727, 0, 29224, 0, -14726, 0, -26006, 0, -14725, 0, -25807, 0, -14724, 0, -25061, 0, -14723, 0, -25058, 0, -14722, 0, 31858, 0, -14687, 0, 9312, 0, -14686, 0, 9313, 0, -14685, 0, 9314, 0, -14684, 0, 9315, 0, -14683, 0, 9316, 0, -14682, 0, 9317, 0, -14681, 0, 9318, 0, -14680, 0, 9319, 0, -14679, 0, 9320, 0, -14678, 0, 9321, 0, -14677, 0, 9332, 0, -14676, 0, 9333, 0, -14675, 0, 9334, 0, -14674, 0, 9335, 0, -14673, 0, 9336, 0, -14672, 0, 9337, 0, -14671, 0, 9338, 0, -14670, 0, 9339, 0, -14669, 0, 9340, 0, -14668, 0, 9341, 0, -14667, 0, 8560, 0, -14666, 0, 8561, 0, -14665, 0, 8562, 0, -14664, 0, 8563, 0, -14663, 0, 8564, 0, -14662, 0, 8565, 0, -14661, 0, 8566, 0, -14660, 0, 8567, 0, -14659, 0, 8568, 0, -14658, 0, 8569, 0, -14657, 0, 20022, 0, -14656, 0, 20031, 0, -14655, 0, 20101, 0, -14654, 0, 20128, 0, -14653, 0, 20866, 0, -14652, 0, 20886, 0, -14651, 0, 20907, 0, -14650, 0, 21241, 0, -14649, 0, 21304, 0, -14648, 0, 21353, 0, -14647, 0, 21430, 0, -14646, 0, 22786, 0, -14645, 0, 23424, 0, -14644, 0, 24027, 0, -14643, 0, 24186, 0, -14642, 0, 24191, 0, -14641, 0, 24308, 0, -14640, 0, 24400, 0, -14639, 0, 24417, 0, -14638, 0, 25908, 0, -14637, 0, 26080, 0, -14636, 0, 30098, 0, -14635, 0, 30326, 0, -14634, 0, -28747, 0, -14633, 0, -26954, 0, -14632, 0, -2328, 0, -14631, 0, -2327, 0, -14630, 0, -2326, 0, -14629, 0, -2325, 0, -14628, 0, -2324, 0, -14627, 0, -2323, 0, -14626, 0, -2322, 0, -14625, 0, 20189, 0, -14624, 0, 12293, 0, -14623, 0, 12294, 0, -14622, 0, 12295, 0, -14621, 0, 12540, 0, -14620, 0, -197, 0, -14619, 0, -195, 0, -14618, 0, -2314, 0, -14617, 0, 12353, 0, -14616, 0, 12354, 0, -14615, 0, 12355, 0, -14614, 0, 12356, 0, -14613, 0, 12357, 0, -14612, 0, 12358, 0, -14611, 0, 12359, 0, -14610, 0, 12360, 0, -14609, 0, 12361, 0, -14608, 0, 12362, 0, -14607, 0, 12363, 0, -14606, 0, 12364, 0, -14605, 0, 12365, 0, -14604, 0, 12366, 0, -14603, 0, 12367, 0, -14602, 0, 12368, 0, -14601, 0, 12369, 0, -14600, 0, 12370, 0, -14599, 0, 12371, 0, -14598, 0, 12372, 0, -14597, 0, 12373, 0, -14596, 0, 12374, 0, -14595, 0, 12375, 0, -14594, 0, 12376, 0, -14528, 0, 12377, 0, -14527, 0, 12378, 0, -14526, 0, 12379, 0, -14525, 0, 12380, 0, -14524, 0, 12381, 0, -14523, 0, 12382, 0, -14522, 0, 12383, 0, -14521, 0, 12384, 0, -14520, 0, 12385, 0, -14519, 0, 12386, 0, -14518, 0, 12387, 0, -14517, 0, 12388, 0, -14516, 0, 12389, 0, -14515, 0, 12390, 0, -14514, 0, 12391, 0, -14513, 0, 12392, 0, -14512, 0, 12393, 0, -14511, 0, 12394, 0, -14510, 0, 12395, 0, -14509, 0, 12396, 0, -14508, 0, 12397, 0, -14507, 0, 12398, 0, -14506, 0, 12399, 0, -14505, 0, 12400, 0, -14504, 0, 12401, 0, -14503, 0, 12402, 0, -14502, 0, 12403, 0, -14501, 0, 12404, 0, -14500, 0, 12405, 0, -14499, 0, 12406, 0, -14498, 0, 12407, 0, -14497, 0, 12408, 0, -14496, 0, 12409, 0, -14495, 0, 12410, 0, -14494, 0, 12411, 0, -14493, 0, 12412, 0, -14492, 0, 12413, 0, -14491, 0, 12414, 0, -14490, 0, 12415, 0, -14489, 0, 12416, 0, -14488, 0, 12417, 0, -14487, 0, 12418, 0, -14486, 0, 12419, 0, -14485, 0, 12420, 0, -14484, 0, 12421, 0, -14483, 0, 12422, 0, -14482, 0, 12423, 0, -14481, 0, 12424, 0, -14480, 0, 12425, 0, -14479, 0, 12426, 0, -14478, 0, 12427, 0, -14477, 0, 12428, 0, -14476, 0, 12429, 0, -14475, 0, 12430, 0, -14474, 0, 12431, 0, -14473, 0, 12432, 0, -14472, 0, 12433, 0, -14471, 0, 12434, 0, -14470, 0, 12435, 0, -14469, 0, 12449, 0, -14468, 0, 12450, 0, -14467, 0, 12451, 0, -14466, 0, 12452, 0, -14431, 0, 12453, 0, -14430, 0, 12454, 0, -14429, 0, 12455, 0, -14428, 0, 12456, 0, -14427, 0, 12457, 0, -14426, 0, 12458, 0, -14425, 0, 12459, 0, -14424, 0, 12460, 0, -14423, 0, 12461, 0, -14422, 0, 12462, 0, -14421, 0, 12463, 0, -14420, 0, 12464, 0, -14419, 0, 12465, 0, -14418, 0, 12466, 0, -14417, 0, 12467, 0, -14416, 0, 12468, 0, -14415, 0, 12469, 0, -14414, 0, 12470, 0, -14413, 0, 12471, 0, -14412, 0, 12472, 0, -14411, 0, 12473, 0, -14410, 0, 12474, 0, -14409, 0, 12475, 0, -14408, 0, 12476, 0, -14407, 0, 12477, 0, -14406, 0, 12478, 0, -14405, 0, 12479, 0, -14404, 0, 12480, 0, -14403, 0, 12481, 0, -14402, 0, 12482, 0, -14401, 0, 12483, 0, -14400, 0, 12484, 0, -14399, 0, 12485, 0, -14398, 0, 12486, 0, -14397, 0, 12487, 0, -14396, 0, 12488, 0, -14395, 0, 12489, 0, -14394, 0, 12490, 0, -14393, 0, 12491, 0, -14392, 0, 12492, 0, -14391, 0, 12493, 0, -14390, 0, 12494, 0, -14389, 0, 12495, 0, -14388, 0, 12496, 0, -14387, 0, 12497, 0, -14386, 0, 12498, 0, -14385, 0, 12499, 0, -14384, 0, 12500, 0, -14383, 0, 12501, 0, -14382, 0, 12502, 0, -14381, 0, 12503, 0, -14380, 0, 12504, 0, -14379, 0, 12505, 0, -14378, 0, 12506, 0, -14377, 0, 12507, 0, -14376, 0, 12508, 0, -14375, 0, 12509, 0, -14374, 0, 12510, 0, -14373, 0, 12511, 0, -14372, 0, 12512, 0, -14371, 0, 12513, 0, -14370, 0, 12514, 0, -14369, 0, 12515, 0, -14368, 0, 12516, 0, -14367, 0, 12517, 0, -14366, 0, 12518, 0, -14365, 0, 12519, 0, -14364, 0, 12520, 0, -14363, 0, 12521, 0, -14362, 0, 12522, 0, -14361, 0, 12523, 0, -14360, 0, 12524, 0, -14359, 0, 12525, 0, -14358, 0, 12526, 0, -14357, 0, 12527, 0, -14356, 0, 12528, 0, -14355, 0, 12529, 0, -14354, 0, 12530, 0, -14353, 0, 12531, 0, -14352, 0, 12532, 0, -14351, 0, 12533, 0, -14350, 0, 12534, 0, -14349, 0, 1040, 0, -14348, 0, 1041, 0, -14347, 0, 1042, 0, -14346, 0, 1043, 0, -14345, 0, 1044, 0, -14344, 0, 1045, 0, -14343, 0, 1025, 0, -14342, 0, 1046, 0, -14341, 0, 1047, 0, -14340, 0, 1048, 0, -14339, 0, 1049, 0, -14338, 0, 1050, 0, -14272, 0, 1051, 0, -14271, 0, 1052, 0, -14270, 0, 1053, 0, -14269, 0, 1054, 0, -14268, 0, 1055, 0, -14267, 0, 1056, 0, -14266, 0, 1057, 0, -14265, 0, 1058, 0, -14264, 0, 1059, 0, -14263, 0, 1060, 0, -14262, 0, 1061, 0, -14261, 0, 1062, 0, -14260, 0, 1063, 0, -14259, 0, 1064, 0, -14258, 0, 1065, 0, -14257, 0, 1066, 0, -14256, 0, 1067, 0, -14255, 0, 1068, 0, -14254, 0, 1069, 0, -14253, 0, 1070, 0, -14252, 0, 1071, 0, -14251, 0, 1072, 0, -14250, 0, 1073, 0, -14249, 0, 1074, 0, -14248, 0, 1075, 0, -14247, 0, 1076, 0, -14246, 0, 1077, 0, -14245, 0, 1105, 0, -14244, 0, 1078, 0, -14243, 0, 1079, 0, -14242, 0, 1080, 0, -14241, 0, 1081, 0, -14240, 0, 1082, 0, -14239, 0, 1083, 0, -14238, 0, 1084, 0, -14237, 0, 1085, 0, -14236, 0, 1086, 0, -14235, 0, 1087, 0, -14234, 0, 1088, 0, -14233, 0, 1089, 0, -14232, 0, 1090, 0, -14231, 0, 1091, 0, -14230, 0, 1092, 0, -14229, 0, 1093, 0, -14228, 0, 1094, 0, -14227, 0, 1095, 0, -14226, 0, 1096, 0, -14225, 0, 1097, 0, -14224, 0, 1098, 0, -14223, 0, 1099, 0, -14222, 0, 1100, 0, -14221, 0, 1101, 0, -14220, 0, 1102, 0, -14219, 0, 1103, 0, -14218, 0, 8679, 0, -14217, 0, 8632, 0, -14216, 0, 8633, 0, -14215, 0, 20033, 0, -14214, 0, -2074, 0, -14213, 0, 20058, 0, -14212, 0, -2072, 0, -14211, 0, 20994, 0, -14210, 0, -2070, 0, -14175, 0, -2069, 0, -14174, 0, 20872, 0, -14173, 0, -2067, 0, -14172, 0, -2066, 0, -14171, 0, -2065, 0, -14170, 0, -2064, 0, -14169, 0, -2063, 0, -14168, 0, -2062, 0, -14167, 0, -2061, 0, -14166, 0, -2060, 0, -14165, 0, -2059, 0, -14164, 0, -2058, 0, -14163, 0, -2057, 0, -14162, 0, -2056, 0, -14161, 0, -2055, 0, -14160, 0, -2054, 0, -14159, 0, -2053, 0, -14158, 0, -2052, 0, -14157, 0, -2051, 0, -14156, 0, -2050, 0, -14155, 0, -2049, 0, -14154, 0, -2048, 0, -14153, 0, -2047, 0, -14152, 0, -2046, 0, -14151, 0, -2045, 0, -14150, 0, -2044, 0, -14149, 0, -2043, 0, -14148, 0, -2042, 0, -14147, 0, -2041, 0, -14146, 0, -2040, 0, -14145, 0, -2039, 0, -14144, 0, -2038, 0, -14143, 0, -2037, 0, -14142, 0, -2036, 0, -14141, 0, -2035, 0, -14140, 0, -2034, 0, -14139, 0, -2033, 0, -14138, 0, -2032, 0, -14137, 0, -2031, 0, -14136, 0, -2030, 0, -14135, 0, -2029, 0, -14134, 0, -2028, 0, -14133, 0, -2027, 0, -14132, 0, -2026, 0, -14131, 0, 172, 0, -14130, 0, -28, 0, -14129, 0, -249, 0, -14128, 0, -254, 0, -14127, 0, 12849, 0, -14126, 0, 8470, 0, -14125, 0, 8481, 0, -14124, 0, -2018, 0, -14123, 0, -2017, 0, -14122, 0, -2016, 0, -14121, 0, -2015, 0, -14120, 0, -2014, 0, -14119, 0, -2013, 0, -14118, 0, -2012, 0, -14117, 0, -2011, 0, -14116, 0, -2010, 0, -14115, 0, -2009, 0, -14114, 0, -2008, 0, -14113, 0, -2007, 0, -14112, 0, -2006, 0, -14111, 0, -2005, 0, -14110, 0, -2004, 0, -14109, 0, -2003, 0, -14108, 0, -2002, 0, -14107, 0, -2001, 0, -14106, 0, -2000, 0, -14105, 0, -1999, 0, -14104, 0, -1998, 0, -14103, 0, -1997, 0, -14102, 0, -1996, 0, -14101, 0, -1995, 0, -14100, 0, -1994, 0, -14099, 0, -1993, 0, -14098, 0, -1992, 0, -14097, 0, -1991, 0, -14096, 0, -1990, 0, -14095, 0, -1989, 0, -14094, 0, -1988, 0, -14093, 0, -1987, 0, -14092, 0, -1986, 0, -14091, 0, -1985, 0, -14090, 0, -1984, 0, -14089, 0, -1983, 0, -14088, 0, -1982, 0, -14087, 0, -1981, 0, -14086, 0, -1980, 0, -14085, 0, -1979, 0, -14084, 0, -1978, 0, -14083, 0, -1977, 0, -14082, 0, -1976, 0, -14016, 0, 20034, 0, -14015, 0, 20060, 0, -14014, 0, 20981, 0, -14013, 0, 21274, 0, -14012, 0, 21378, 0, -14011, 0, 19975, 0, -14010, 0, 19980, 0, -14009, 0, 20039, 0, -14008, 0, 20109, 0, -14007, 0, 22231, 0, -14006, 0, -1524, 0, -14005, 0, 23662, 0, -14004, 0, 24435, 0, -14003, 0, 19983, 0, -14002, 0, 20871, 0, -14001, 0, 19982, 0, -14000, 0, 20014, 0, -13999, 0, 20115, 0, -13998, 0, 20162, 0, -13997, 0, 20169, 0, -13996, 0, 20168, 0, -13995, 0, 20888, 0, -13994, 0, 21244, 0, -13993, 0, 21356, 0, -13992, 0, 21433, 0, -13991, 0, 22304, 0, -13990, 0, 22787, 0, -13989, 0, 22828, 0, -13988, 0, 23568, 0, -13987, 0, 24063, 0, -13986, 0, 26081, 0, -13985, 0, 27571, 0, -13984, 0, 27596, 0, -13983, 0, 27668, 0, -13982, 0, 29247, 0, -13981, 0, 20017, 0, -13980, 0, 20028, 0, -13979, 0, 20200, 0, -13978, 0, 20188, 0, -13977, 0, 20201, 0, -13976, 0, 20193, 0, -13975, 0, 20189, 0, -13974, 0, 20186, 0, -13973, 0, 21004, 0, -13972, 0, 21276, 0, -13971, 0, 21324, 0, -13970, 0, 22306, 0, -13969, 0, 22307, 0, -13968, 0, 22807, 0, -13967, 0, 22831, 0, -13966, 0, 23425, 0, -13965, 0, 23428, 0, -13964, 0, 23570, 0, -13963, 0, 23611, 0, -13962, 0, 23668, 0, -13961, 0, 23667, 0, -13960, 0, 24068, 0, -13959, 0, 24192, 0, -13958, 0, 24194, 0, -13957, 0, 24521, 0, -13956, 0, 25097, 0, -13955, 0, 25168, 0, -13954, 0, 27669, 0, -13919, 0, 27702, 0, -13918, 0, 27715, 0, -13917, 0, 27711, 0, -13916, 0, 27707, 0, -13915, 0, 29358, 0, -13914, 0, 29360, 0, -13913, 0, 29578, 0, -13912, 0, 31160, 0, -13911, 0, -32630, 0, -13910, 0, -27106, 0, -13909, 0, 20238, 0, -13908, 0, 20248, 0, -13907, 0, 20268, 0, -13906, 0, 20213, 0, -13905, 0, 20244, 0, -13904, 0, 20209, 0, -13903, 0, 20224, 0, -13902, 0, 20215, 0, -13901, 0, 20232, 0, -13900, 0, 20253, 0, -13899, 0, 20226, 0, -13898, 0, 20229, 0, -13897, 0, 20258, 0, -13896, 0, 20243, 0, -13895, 0, 20228, 0, -13894, 0, 20212, 0, -13893, 0, 20242, 0, -13892, 0, 20913, 0, -13891, 0, 21011, 0, -13890, 0, 21001, 0, -13889, 0, 21008, 0, -13888, 0, 21158, 0, -13887, 0, 21282, 0, -13886, 0, 21279, 0, -13885, 0, 21325, 0, -13884, 0, 21386, 0, -13883, 0, 21511, 0, -13882, 0, 22241, 0, -13881, 0, 22239, 0, -13880, 0, 22318, 0, -13879, 0, 22314, 0, -13878, 0, 22324, 0, -13877, 0, 22844, 0, -13876, 0, 22912, 0, -13875, 0, 22908, 0, -13874, 0, 22917, 0, -13873, 0, 22907, 0, -13872, 0, 22910, 0, -13871, 0, 22903, 0, -13870, 0, 22911, 0, -13869, 0, 23382, 0, -13868, 0, 23573, 0, -13867, 0, 23589, 0, -13866, 0, 23676, 0, -13865, 0, 23674, 0, -13864, 0, 23675, 0, -13863, 0, 23678, 0, -13862, 0, 24031, 0, -13861, 0, 24181, 0, -13860, 0, 24196, 0, -13859, 0, 24322, 0, -13858, 0, 24346, 0, -13857, 0, 24436, 0, -13856, 0, 24533, 0, -13855, 0, 24532, 0, -13854, 0, 24527, 0, -13853, 0, 25180, 0, -13852, 0, 25182, 0, -13851, 0, 25188, 0, -13850, 0, 25185, 0, -13849, 0, 25190, 0, -13848, 0, 25186, 0, -13847, 0, 25177, 0, -13846, 0, 25184, 0, -13845, 0, 25178, 0, -13844, 0, 25189, 0, -13843, 0, 26095, 0, -13842, 0, 26094, 0, -13841, 0, 26430, 0, -13840, 0, 26425, 0, -13839, 0, 26424, 0, -13838, 0, 26427, 0, -13837, 0, 26426, 0, -13836, 0, 26431, 0, -13835, 0, 26428, 0, -13834, 0, 26419, 0, -13833, 0, 27672, 0, -13832, 0, 27718, 0, -13831, 0, 27730, 0, -13830, 0, 27740, 0, -13829, 0, 27727, 0, -13828, 0, 27722, 0, -13827, 0, 27732, 0, -13826, 0, 27723, 0, -13760, 0, 27724, 0, -13759, 0, 28785, 0, -13758, 0, 29278, 0, -13757, 0, 29364, 0, -13756, 0, 29365, 0, -13755, 0, 29582, 0, -13754, 0, 29994, 0, -13753, 0, 30335, 0, -13752, 0, 31349, 0, -13751, 0, 32593, 0, -13750, 0, -32136, 0, -13749, 0, -32132, 0, -13748, 0, -32128, 0, -13747, 0, -32131, 0, -13746, 0, -32129, 0, -13745, 0, -31155, 0, -13744, 0, -30338, 0, -13743, 0, -28519, 0, -13742, 0, -28521, 0, -13741, 0, -28520, 0, -13740, 0, -28517, 0, -13739, 0, -28524, 0, -13738, 0, -27102, 0, -13737, 0, -27100, 0, -13736, 0, -27104, 0, -13735, 0, -27101, 0, -13734, 0, 20310, 0, -13733, 0, 20283, 0, -13732, 0, 20322, 0, -13731, 0, 20297, 0, -13730, 0, 20307, 0, -13729, 0, 20324, 0, -13728, 0, 20286, 0, -13727, 0, 20327, 0, -13726, 0, 20306, 0, -13725, 0, 20319, 0, -13724, 0, 20289, 0, -13723, 0, 20312, 0, -13722, 0, 20269, 0, -13721, 0, 20275, 0, -13720, 0, 20287, 0, -13719, 0, 20321, 0, -13718, 0, 20879, 0, -13717, 0, 20921, 0, -13716, 0, 21020, 0, -13715, 0, 21022, 0, -13714, 0, 21025, 0, -13713, 0, 21165, 0, -13712, 0, 21166, 0, -13711, 0, 21257, 0, -13710, 0, 21347, 0, -13709, 0, 21362, 0, -13708, 0, 21390, 0, -13707, 0, 21391, 0, -13706, 0, 21552, 0, -13705, 0, 21559, 0, -13704, 0, 21546, 0, -13703, 0, 21588, 0, -13702, 0, 21573, 0, -13701, 0, 21529, 0, -13700, 0, 21532, 0, -13699, 0, 21541, 0, -13698, 0, 21528, 0, -13663, 0, 21565, 0, -13662, 0, 21583, 0, -13661, 0, 21569, 0, -13660, 0, 21544, 0, -13659, 0, 21540, 0, -13658, 0, 21575, 0, -13657, 0, 22254, 0, -13656, 0, 22247, 0, -13655, 0, 22245, 0, -13654, 0, 22337, 0, -13653, 0, 22341, 0, -13652, 0, 22348, 0, -13651, 0, 22345, 0, -13650, 0, 22347, 0, -13649, 0, 22354, 0, -13648, 0, 22790, 0, -13647, 0, 22848, 0, -13646, 0, 22950, 0, -13645, 0, 22936, 0, -13644, 0, 22944, 0, -13643, 0, 22935, 0, -13642, 0, 22926, 0, -13641, 0, 22946, 0, -13640, 0, 22928, 0, -13639, 0, 22927, 0, -13638, 0, 22951, 0, -13637, 0, 22945, 0, -13636, 0, 23438, 0, -13635, 0, 23442, 0, -13634, 0, 23592, 0, -13633, 0, 23594, 0, -13632, 0, 23693, 0, -13631, 0, 23695, 0, -13630, 0, 23688, 0, -13629, 0, 23691, 0, -13628, 0, 23689, 0, -13627, 0, 23698, 0, -13626, 0, 23690, 0, -13625, 0, 23686, 0, -13624, 0, 23699, 0, -13623, 0, 23701, 0, -13622, 0, 24032, 0, -13621, 0, 24074, 0, -13620, 0, 24078, 0, -13619, 0, 24203, 0, -13618, 0, 24201, 0, -13617, 0, 24204, 0, -13616, 0, 24200, 0, -13615, 0, 24205, 0, -13614, 0, 24325, 0, -13613, 0, 24349, 0, -13612, 0, 24440, 0, -13611, 0, 24438, 0, -13610, 0, 24530, 0, -13609, 0, 24529, 0, -13608, 0, 24528, 0, -13607, 0, 24557, 0, -13606, 0, 24552, 0, -13605, 0, 24558, 0, -13604, 0, 24563, 0, -13603, 0, 24545, 0, -13602, 0, 24548, 0, -13601, 0, 24547, 0, -13600, 0, 24570, 0, -13599, 0, 24559, 0, -13598, 0, 24567, 0, -13597, 0, 24571, 0, -13596, 0, 24576, 0, -13595, 0, 24564, 0, -13594, 0, 25146, 0, -13593, 0, 25219, 0, -13592, 0, 25228, 0, -13591, 0, 25230, 0, -13590, 0, 25231, 0, -13589, 0, 25236, 0, -13588, 0, 25223, 0, -13587, 0, 25201, 0, -13586, 0, 25211, 0, -13585, 0, 25210, 0, -13584, 0, 25200, 0, -13583, 0, 25217, 0, -13582, 0, 25224, 0, -13581, 0, 25207, 0, -13580, 0, 25213, 0, -13579, 0, 25202, 0, -13578, 0, 25204, 0, -13577, 0, 25911, 0, -13576, 0, 26096, 0, -13575, 0, 26100, 0, -13574, 0, 26099, 0, -13573, 0, 26098, 0, -13572, 0, 26101, 0, -13571, 0, 26437, 0, -13570, 0, 26439, 0, -13504, 0, 26457, 0, -13503, 0, 26453, 0, -13502, 0, 26444, 0, -13501, 0, 26440, 0, -13500, 0, 26461, 0, -13499, 0, 26445, 0, -13498, 0, 26458, 0, -13497, 0, 26443, 0, -13496, 0, 27600, 0, -13495, 0, 27673, 0, -13494, 0, 27674, 0, -13493, 0, 27768, 0, -13492, 0, 27751, 0, -13491, 0, 27755, 0, -13490, 0, 27780, 0, -13489, 0, 27787, 0, -13488, 0, 27791, 0, -13487, 0, 27761, 0, -13486, 0, 27759, 0, -13485, 0, 27753, 0, -13484, 0, 27802, 0, -13483, 0, 27757, 0, -13482, 0, 27783, 0, -13481, 0, 27797, 0, -13480, 0, 27804, 0, -13479, 0, 27750, 0, -13478, 0, 27763, 0, -13477, 0, 27749, 0, -13476, 0, 27771, 0, -13475, 0, 27790, 0, -13474, 0, 28788, 0, -13473, 0, 28794, 0, -13472, 0, 29283, 0, -13471, 0, 29375, 0, -13470, 0, 29373, 0, -13469, 0, 29379, 0, -13468, 0, 29382, 0, -13467, 0, 29377, 0, -13466, 0, 29370, 0, -13465, 0, 29381, 0, -13464, 0, 29589, 0, -13463, 0, 29591, 0, -13462, 0, 29587, 0, -13461, 0, 29588, 0, -13460, 0, 29586, 0, -13459, 0, 30010, 0, -13458, 0, 30009, 0, -13457, 0, 30100, 0, -13456, 0, 30101, 0, -13455, 0, 30337, 0, -13454, 0, 31037, 0, -13453, 0, -32716, 0, -13452, 0, -32619, 0, -13451, 0, -32615, 0, -13450, 0, -32624, 0, -13449, 0, -32622, 0, -13448, 0, -32612, 0, -13447, 0, -32112, 0, -13446, 0, -32113, 0, -13445, 0, -32123, 0, -13444, 0, -32114, 0, -13443, 0, -32111, 0, -13442, 0, -32109, 0, -13407, 0, -32118, 0, -13406, 0, -32125, 0, -13405, 0, -32124, 0, -13404, 0, -29576, 0, -13403, 0, -28727, 0, -13402, 0, -28737, 0, -13401, 0, -28513, 0, -13400, 0, -28511, 0, -13399, 0, -28507, 0, -13398, 0, -28514, 0, -13397, 0, -28505, 0, -13396, 0, -28512, 0, -13395, 0, -27088, 0, -13394, 0, -27096, 0, -13393, 0, -27089, 0, -13392, 0, -27091, 0, -13391, 0, 20019, 0, -13390, 0, 20376, 0, -13389, 0, 20348, 0, -13388, 0, 20357, 0, -13387, 0, 20349, 0, -13386, 0, 20352, 0, -13385, 0, 20359, 0, -13384, 0, 20342, 0, -13383, 0, 20340, 0, -13382, 0, 20361, 0, -13381, 0, 20356, 0, -13380, 0, 20343, 0, -13379, 0, 20300, 0, -13378, 0, 20375, 0, -13377, 0, 20330, 0, -13376, 0, 20378, 0, -13375, 0, 20345, 0, -13374, 0, 20353, 0, -13373, 0, 20344, 0, -13372, 0, 20368, 0, -13371, 0, 20380, 0, -13370, 0, 20372, 0, -13369, 0, 20382, 0, -13368, 0, 20370, 0, -13367, 0, 20354, 0, -13366, 0, 20373, 0, -13365, 0, 20331, 0, -13364, 0, 20334, 0, -13363, 0, 20894, 0, -13362, 0, 20924, 0, -13361, 0, 20926, 0, -13360, 0, 21045, 0, -13359, 0, 21042, 0, -13358, 0, 21043, 0, -13357, 0, 21062, 0, -13356, 0, 21041, 0, -13355, 0, 21180, 0, -13354, 0, 21258, 0, -13353, 0, 21259, 0, -13352, 0, 21308, 0, -13351, 0, 21394, 0, -13350, 0, 21396, 0, -13349, 0, 21639, 0, -13348, 0, 21631, 0, -13347, 0, 21633, 0, -13346, 0, 21649, 0, -13345, 0, 21634, 0, -13344, 0, 21640, 0, -13343, 0, 21611, 0, -13342, 0, 21626, 0, -13341, 0, 21630, 0, -13340, 0, 21605, 0, -13339, 0, 21612, 0, -13338, 0, 21620, 0, -13337, 0, 21606, 0, -13336, 0, 21645, 0, -13335, 0, 21615, 0, -13334, 0, 21601, 0, -13333, 0, 21600, 0, -13332, 0, 21656, 0, -13331, 0, 21603, 0, -13330, 0, 21607, 0, -13329, 0, 21604, 0, -13328, 0, 22263, 0, -13327, 0, 22265, 0, -13326, 0, 22383, 0, -13325, 0, 22386, 0, -13324, 0, 22381, 0, -13323, 0, 22379, 0, -13322, 0, 22385, 0, -13321, 0, 22384, 0, -13320, 0, 22390, 0, -13319, 0, 22400, 0, -13318, 0, 22389, 0, -13317, 0, 22395, 0, -13316, 0, 22387, 0, -13315, 0, 22388, 0, -13314, 0, 22370, 0, -13248, 0, 22376, 0, -13247, 0, 22397, 0, -13246, 0, 22796, 0, -13245, 0, 22853, 0, -13244, 0, 22965, 0, -13243, 0, 22970, 0, -13242, 0, 22991, 0, -13241, 0, 22990, 0, -13240, 0, 22962, 0, -13239, 0, 22988, 0, -13238, 0, 22977, 0, -13237, 0, 22966, 0, -13236, 0, 22972, 0, -13235, 0, 22979, 0, -13234, 0, 22998, 0, -13233, 0, 22961, 0, -13232, 0, 22973, 0, -13231, 0, 22976, 0, -13230, 0, 22984, 0, -13229, 0, 22964, 0, -13228, 0, 22983, 0, -13227, 0, 23394, 0, -13226, 0, 23397, 0, -13225, 0, 23443, 0, -13224, 0, 23445, 0, -13223, 0, 23620, 0, -13222, 0, 23623, 0, -13221, 0, 23726, 0, -13220, 0, 23716, 0, -13219, 0, 23712, 0, -13218, 0, 23733, 0, -13217, 0, 23727, 0, -13216, 0, 23720, 0, -13215, 0, 23724, 0, -13214, 0, 23711, 0, -13213, 0, 23715, 0, -13212, 0, 23725, 0, -13211, 0, 23714, 0, -13210, 0, 23722, 0, -13209, 0, 23719, 0, -13208, 0, 23709, 0, -13207, 0, 23717, 0, -13206, 0, 23734, 0, -13205, 0, 23728, 0, -13204, 0, 23718, 0, -13203, 0, 24087, 0, -13202, 0, 24084, 0, -13201, 0, 24089, 0, -13200, 0, 24360, 0, -13199, 0, 24354, 0, -13198, 0, 24355, 0, -13197, 0, 24356, 0, -13196, 0, 24404, 0, -13195, 0, 24450, 0, -13194, 0, 24446, 0, -13193, 0, 24445, 0, -13192, 0, 24542, 0, -13191, 0, 24549, 0, -13190, 0, 24621, 0, -13189, 0, 24614, 0, -13188, 0, 24601, 0, -13187, 0, 24626, 0, -13186, 0, 24587, 0, -13151, 0, 24628, 0, -13150, 0, 24586, 0, -13149, 0, 24599, 0, -13148, 0, 24627, 0, -13147, 0, 24602, 0, -13146, 0, 24606, 0, -13145, 0, 24620, 0, -13144, 0, 24610, 0, -13143, 0, 24589, 0, -13142, 0, 24592, 0, -13141, 0, 24622, 0, -13140, 0, 24595, 0, -13139, 0, 24593, 0, -13138, 0, 24588, 0, -13137, 0, 24585, 0, -13136, 0, 24604, 0, -13135, 0, 25108, 0, -13134, 0, 25149, 0, -13133, 0, 25261, 0, -13132, 0, 25268, 0, -13131, 0, 25297, 0, -13130, 0, 25278, 0, -13129, 0, 25258, 0, -13128, 0, 25270, 0, -13127, 0, 25290, 0, -13126, 0, 25262, 0, -13125, 0, 25267, 0, -13124, 0, 25263, 0, -13123, 0, 25275, 0, -13122, 0, 25257, 0, -13121, 0, 25264, 0, -13120, 0, 25272, 0, -13119, 0, 25917, 0, -13118, 0, 26024, 0, -13117, 0, 26043, 0, -13116, 0, 26121, 0, -13115, 0, 26108, 0, -13114, 0, 26116, 0, -13113, 0, 26130, 0, -13112, 0, 26120, 0, -13111, 0, 26107, 0, -13110, 0, 26115, 0, -13109, 0, 26123, 0, -13108, 0, 26125, 0, -13107, 0, 26117, 0, -13106, 0, 26109, 0, -13105, 0, 26129, 0, -13104, 0, 26128, 0, -13103, 0, 26358, 0, -13102, 0, 26378, 0, -13101, 0, 26501, 0, -13100, 0, 26476, 0, -13099, 0, 26510, 0, -13098, 0, 26514, 0, -13097, 0, 26486, 0, -13096, 0, 26491, 0, -13095, 0, 26520, 0, -13094, 0, 26502, 0, -13093, 0, 26500, 0, -13092, 0, 26484, 0, -13091, 0, 26509, 0, -13090, 0, 26508, 0, -13089, 0, 26490, 0, -13088, 0, 26527, 0, -13087, 0, 26513, 0, -13086, 0, 26521, 0, -13085, 0, 26499, 0, -13084, 0, 26493, 0, -13083, 0, 26497, 0, -13082, 0, 26488, 0, -13081, 0, 26489, 0, -13080, 0, 26516, 0, -13079, 0, 27429, 0, -13078, 0, 27520, 0, -13077, 0, 27518, 0, -13076, 0, 27614, 0, -13075, 0, 27677, 0, -13074, 0, 27795, 0, -13073, 0, 27884, 0, -13072, 0, 27883, 0, -13071, 0, 27886, 0, -13070, 0, 27865, 0, -13069, 0, 27830, 0, -13068, 0, 27860, 0, -13067, 0, 27821, 0, -13066, 0, 27879, 0, -13065, 0, 27831, 0, -13064, 0, 27856, 0, -13063, 0, 27842, 0, -13062, 0, 27834, 0, -13061, 0, 27843, 0, -13060, 0, 27846, 0, -13059, 0, 27885, 0, -13058, 0, 27890, 0, -12992, 0, 27858, 0, -12991, 0, 27869, 0, -12990, 0, 27828, 0, -12989, 0, 27786, 0, -12988, 0, 27805, 0, -12987, 0, 27776, 0, -12986, 0, 27870, 0, -12985, 0, 27840, 0, -12984, 0, 27952, 0, -12983, 0, 27853, 0, -12982, 0, 27847, 0, -12981, 0, 27824, 0, -12980, 0, 27897, 0, -12979, 0, 27855, 0, -12978, 0, 27881, 0, -12977, 0, 27857, 0, -12976, 0, 28820, 0, -12975, 0, 28824, 0, -12974, 0, 28805, 0, -12973, 0, 28819, 0, -12972, 0, 28806, 0, -12971, 0, 28804, 0, -12970, 0, 28817, 0, -12969, 0, 28822, 0, -12968, 0, 28802, 0, -12967, 0, 28826, 0, -12966, 0, 28803, 0, -12965, 0, 29290, 0, -12964, 0, 29398, 0, -12963, 0, 29387, 0, -12962, 0, 29400, 0, -12961, 0, 29385, 0, -12960, 0, 29404, 0, -12959, 0, 29394, 0, -12958, 0, 29396, 0, -12957, 0, 29402, 0, -12956, 0, 29388, 0, -12955, 0, 29393, 0, -12954, 0, 29604, 0, -12953, 0, 29601, 0, -12952, 0, 29613, 0, -12951, 0, 29606, 0, -12950, 0, 29602, 0, -12949, 0, 29600, 0, -12948, 0, 29612, 0, -12947, 0, 29597, 0, -12946, 0, 29917, 0, -12945, 0, 29928, 0, -12944, 0, 30015, 0, -12943, 0, 30016, 0, -12942, 0, 30014, 0, -12941, 0, 30092, 0, -12940, 0, 30104, 0, -12939, 0, 30383, 0, -12938, 0, 30451, 0, -12937, 0, 30449, 0, -12936, 0, 30448, 0, -12935, 0, 30453, 0, -12934, 0, 30712, 0, -12933, 0, 30716, 0, -12932, 0, 30713, 0, -12931, 0, 30715, 0, -12930, 0, 30714, 0, -12895, 0, 30711, 0, -12894, 0, 31042, 0, -12893, 0, 31039, 0, -12892, 0, 31173, 0, -12891, 0, 31352, 0, -12890, 0, 31355, 0, -12889, 0, 31483, 0, -12888, 0, 31861, 0, -12887, 0, 31997, 0, -12886, 0, -32715, 0, -12885, 0, -32625, 0, -12884, 0, -32594, 0, -12883, 0, -32605, 0, -12882, 0, -32584, 0, -12881, 0, -32587, 0, -12880, 0, -32595, 0, -12879, 0, -32224, 0, -12878, 0, -32096, 0, -12877, 0, -32064, 0, -12876, 0, -32085, 0, -12875, 0, -32102, 0, -12874, 0, -32104, 0, -12873, 0, -32101, 0, -12872, 0, -32075, 0, -12871, 0, -32089, 0, -12870, 0, -32082, 0, -12869, 0, -32068, 0, -12868, 0, -32098, 0, -12867, 0, -32070, 0, -12866, 0, -32076, 0, -12865, 0, -32088, 0, -12864, 0, -32095, 0, -12863, 0, -32087, 0, -12862, 0, -32062, 0, -12861, 0, -32092, 0, -12860, 0, -32061, 0, -12859, 0, -32074, 0, -12858, 0, -32094, 0, -12857, 0, -31120, 0, -12856, 0, -31121, 0, -12855, 0, -31123, 0, -12854, 0, -31122, 0, -12853, 0, -29610, 0, -12852, 0, -28718, 0, -12851, 0, -28725, 0, -12850, 0, -28717, 0, -12849, 0, -28723, 0, -12848, 0, -28714, 0, -12847, 0, -28715, 0, -12846, 0, -28713, 0, -12845, 0, -28494, 0, -12844, 0, -28492, 0, -12843, 0, -28497, 0, -12842, 0, -28493, 0, -12841, 0, -28496, 0, -12840, 0, -27079, 0, -12839, 0, -27075, 0, -12838, 0, -27076, 0, -12837, 0, -27078, 0, -12836, 0, -27069, 0, -12835, 0, 20429, 0, -12834, 0, 20421, 0, -12833, 0, 20435, 0, -12832, 0, 20402, 0, -12831, 0, 20425, 0, -12830, 0, 20427, 0, -12829, 0, 20417, 0, -12828, 0, 20436, 0, -12827, 0, 20444, 0, -12826, 0, 20441, 0, -12825, 0, 20411, 0, -12824, 0, 20403, 0, -12823, 0, 20443, 0, -12822, 0, 20423, 0, -12821, 0, 20438, 0, -12820, 0, 20410, 0, -12819, 0, 20416, 0, -12818, 0, 20409, 0, -12817, 0, 20460, 0, -12816, 0, 21060, 0, -12815, 0, 21065, 0, -12814, 0, 21184, 0, -12813, 0, 21186, 0, -12812, 0, 21309, 0, -12811, 0, 21372, 0, -12810, 0, 21399, 0, -12809, 0, 21398, 0, -12808, 0, 21401, 0, -12807, 0, 21400, 0, -12806, 0, 21690, 0, -12805, 0, 21665, 0, -12804, 0, 21677, 0, -12803, 0, 21669, 0, -12802, 0, 21711, 0, -12736, 0, 21699, 0, -12735, 0, -31987, 0, -12734, 0, 21687, 0, -12733, 0, 21678, 0, -12732, 0, 21718, 0, -12731, 0, 21686, 0, -12730, 0, 21701, 0, -12729, 0, 21702, 0, -12728, 0, 21664, 0, -12727, 0, 21616, 0, -12726, 0, 21692, 0, -12725, 0, 21666, 0, -12724, 0, 21694, 0, -12723, 0, 21618, 0, -12722, 0, 21726, 0, -12721, 0, 21680, 0, -12720, 0, 22453, 0, -12719, 0, 22430, 0, -12718, 0, 22431, 0, -12717, 0, 22436, 0, -12716, 0, 22412, 0, -12715, 0, 22423, 0, -12714, 0, 22429, 0, -12713, 0, 22427, 0, -12712, 0, 22420, 0, -12711, 0, 22424, 0, -12710, 0, 22415, 0, -12709, 0, 22425, 0, -12708, 0, 22437, 0, -12707, 0, 22426, 0, -12706, 0, 22421, 0, -12705, 0, 22772, 0, -12704, 0, 22797, 0, -12703, 0, 22867, 0, -12702, 0, 23009, 0, -12701, 0, 23006, 0, -12700, 0, 23022, 0, -12699, 0, 23040, 0, -12698, 0, 23025, 0, -12697, 0, 23005, 0, -12696, 0, 23034, 0, -12695, 0, 23037, 0, -12694, 0, 23036, 0, -12693, 0, 23030, 0, -12692, 0, 23012, 0, -12691, 0, 23026, 0, -12690, 0, 23031, 0, -12689, 0, 23003, 0, -12688, 0, 23017, 0, -12687, 0, 23027, 0, -12686, 0, 23029, 0, -12685, 0, 23008, 0, -12684, 0, 23038, 0, -12683, 0, 23028, 0, -12682, 0, 23021, 0, -12681, 0, 23464, 0, -12680, 0, 23628, 0, -12679, 0, 23760, 0, -12678, 0, 23768, 0, -12677, 0, 23756, 0, -12676, 0, 23767, 0, -12675, 0, 23755, 0, -12674, 0, 23771, 0, -12639, 0, 23774, 0, -12638, 0, 23770, 0, -12637, 0, 23753, 0, -12636, 0, 23751, 0, -12635, 0, 23754, 0, -12634, 0, 23766, 0, -12633, 0, 23763, 0, -12632, 0, 23764, 0, -12631, 0, 23759, 0, -12630, 0, 23752, 0, -12629, 0, 23750, 0, -12628, 0, 23758, 0, -12627, 0, 23775, 0, -12626, 0, 23800, 0, -12625, 0, 24057, 0, -12624, 0, 24097, 0, -12623, 0, 24098, 0, -12622, 0, 24099, 0, -12621, 0, 24096, 0, -12620, 0, 24100, 0, -12619, 0, 24240, 0, -12618, 0, 24228, 0, -12617, 0, 24226, 0, -12616, 0, 24219, 0, -12615, 0, 24227, 0, -12614, 0, 24229, 0, -12613, 0, 24327, 0, -12612, 0, 24366, 0, -12611, 0, 24406, 0, -12610, 0, 24454, 0, -12609, 0, 24631, 0, -12608, 0, 24633, 0, -12607, 0, 24660, 0, -12606, 0, 24690, 0, -12605, 0, 24670, 0, -12604, 0, 24645, 0, -12603, 0, 24659, 0, -12602, 0, 24647, 0, -12601, 0, 24649, 0, -12600, 0, 24667, 0, -12599, 0, 24652, 0, -12598, 0, 24640, 0, -12597, 0, 24642, 0, -12596, 0, 24671, 0, -12595, 0, 24612, 0, -12594, 0, 24644, 0, -12593, 0, 24664, 0, -12592, 0, 24678, 0, -12591, 0, 24686, 0, -12590, 0, 25154, 0, -12589, 0, 25155, 0, -12588, 0, 25295, 0, -12587, 0, 25357, 0, -12586, 0, 25355, 0, -12585, 0, 25333, 0, -12584, 0, 25358, 0, -12583, 0, 25347, 0, -12582, 0, 25323, 0, -12581, 0, 25337, 0, -12580, 0, 25359, 0, -12579, 0, 25356, 0, -12578, 0, 25336, 0, -12577, 0, 25334, 0, -12576, 0, 25344, 0, -12575, 0, 25363, 0, -12574, 0, 25364, 0, -12573, 0, 25338, 0, -12572, 0, 25365, 0, -12571, 0, 25339, 0, -12570, 0, 25328, 0, -12569, 0, 25921, 0, -12568, 0, 25923, 0, -12567, 0, 26026, 0, -12566, 0, 26047, 0, -12565, 0, 26166, 0, -12564, 0, 26145, 0, -12563, 0, 26162, 0, -12562, 0, 26165, 0, -12561, 0, 26140, 0, -12560, 0, 26150, 0, -12559, 0, 26146, 0, -12558, 0, 26163, 0, -12557, 0, 26155, 0, -12556, 0, 26170, 0, -12555, 0, 26141, 0, -12554, 0, 26164, 0, -12553, 0, 26169, 0, -12552, 0, 26158, 0, -12551, 0, 26383, 0, -12550, 0, 26384, 0, -12549, 0, 26561, 0, -12548, 0, 26610, 0, -12547, 0, 26568, 0, -12546, 0, 26554, 0, -12480, 0, 26588, 0, -12479, 0, 26555, 0, -12478, 0, 26616, 0, -12477, 0, 26584, 0, -12476, 0, 26560, 0, -12475, 0, 26551, 0, -12474, 0, 26565, 0, -12473, 0, 26603, 0, -12472, 0, 26596, 0, -12471, 0, 26591, 0, -12470, 0, 26549, 0, -12469, 0, 26573, 0, -12468, 0, 26547, 0, -12467, 0, 26615, 0, -12466, 0, 26614, 0, -12465, 0, 26606, 0, -12464, 0, 26595, 0, -12463, 0, 26562, 0, -12462, 0, 26553, 0, -12461, 0, 26574, 0, -12460, 0, 26599, 0, -12459, 0, 26608, 0, -12458, 0, 26546, 0, -12457, 0, 26620, 0, -12456, 0, 26566, 0, -12455, 0, 26605, 0, -12454, 0, 26572, 0, -12453, 0, 26542, 0, -12452, 0, 26598, 0, -12451, 0, 26587, 0, -12450, 0, 26618, 0, -12449, 0, 26569, 0, -12448, 0, 26570, 0, -12447, 0, 26563, 0, -12446, 0, 26602, 0, -12445, 0, 26571, 0, -12444, 0, 27432, 0, -12443, 0, 27522, 0, -12442, 0, 27524, 0, -12441, 0, 27574, 0, -12440, 0, 27606, 0, -12439, 0, 27608, 0, -12438, 0, 27616, 0, -12437, 0, 27680, 0, -12436, 0, 27681, 0, -12435, 0, 27944, 0, -12434, 0, 27956, 0, -12433, 0, 27949, 0, -12432, 0, 27935, 0, -12431, 0, 27964, 0, -12430, 0, 27967, 0, -12429, 0, 27922, 0, -12428, 0, 27914, 0, -12427, 0, 27866, 0, -12426, 0, 27955, 0, -12425, 0, 27908, 0, -12424, 0, 27929, 0, -12423, 0, 27962, 0, -12422, 0, 27930, 0, -12421, 0, 27921, 0, -12420, 0, 27904, 0, -12419, 0, 27933, 0, -12418, 0, 27970, 0, -12383, 0, 27905, 0, -12382, 0, 27928, 0, -12381, 0, 27959, 0, -12380, 0, 27907, 0, -12379, 0, 27919, 0, -12378, 0, 27968, 0, -12377, 0, 27911, 0, -12376, 0, 27936, 0, -12375, 0, 27948, 0, -12374, 0, 27912, 0, -12373, 0, 27938, 0, -12372, 0, 27913, 0, -12371, 0, 27920, 0, -12370, 0, 28855, 0, -12369, 0, 28831, 0, -12368, 0, 28862, 0, -12367, 0, 28849, 0, -12366, 0, 28848, 0, -12365, 0, 28833, 0, -12364, 0, 28852, 0, -12363, 0, 28853, 0, -12362, 0, 28841, 0, -12361, 0, 29249, 0, -12360, 0, 29257, 0, -12359, 0, 29258, 0, -12358, 0, 29292, 0, -12357, 0, 29296, 0, -12356, 0, 29299, 0, -12355, 0, 29294, 0, -12354, 0, 29386, 0, -12353, 0, 29412, 0, -12352, 0, 29416, 0, -12351, 0, 29419, 0, -12350, 0, 29407, 0, -12349, 0, 29418, 0, -12348, 0, 29414, 0, -12347, 0, 29411, 0, -12346, 0, 29573, 0, -12345, 0, 29644, 0, -12344, 0, 29634, 0, -12343, 0, 29640, 0, -12342, 0, 29637, 0, -12341, 0, 29625, 0, -12340, 0, 29622, 0, -12339, 0, 29621, 0, -12338, 0, 29620, 0, -12337, 0, 29675, 0, -12336, 0, 29631, 0, -12335, 0, 29639, 0, -12334, 0, 29630, 0, -12333, 0, 29635, 0, -12332, 0, 29638, 0, -12331, 0, 29624, 0, -12330, 0, 29643, 0, -12329, 0, 29932, 0, -12328, 0, 29934, 0, -12327, 0, 29998, 0, -12326, 0, 30023, 0, -12325, 0, 30024, 0, -12324, 0, 30119, 0, -12323, 0, 30122, 0, -12322, 0, 30329, 0, -12321, 0, 30404, 0, -12320, 0, 30472, 0, -12319, 0, 30467, 0, -12318, 0, 30468, 0, -12317, 0, 30469, 0, -12316, 0, 30474, 0, -12315, 0, 30455, 0, -12314, 0, 30459, 0, -12313, 0, 30458, 0, -12312, 0, 30695, 0, -12311, 0, 30696, 0, -12310, 0, 30726, 0, -12309, 0, 30737, 0, -12308, 0, 30738, 0, -12307, 0, 30725, 0, -12306, 0, 30736, 0, -12305, 0, 30735, 0, -12304, 0, 30734, 0, -12303, 0, 30729, 0, -12302, 0, 30723, 0, -12301, 0, 30739, 0, -12300, 0, 31050, 0, -12299, 0, 31052, 0, -12298, 0, 31051, 0, -12297, 0, 31045, 0, -12296, 0, 31044, 0, -12295, 0, 31189, 0, -12294, 0, 31181, 0, -12293, 0, 31183, 0, -12292, 0, 31190, 0, -12291, 0, 31182, 0, -12290, 0, 31360, 0, -12224, 0, 31358, 0, -12223, 0, 31441, 0, -12222, 0, 31488, 0, -12221, 0, 31489, 0, -12220, 0, 31866, 0, -12219, 0, 31864, 0, -12218, 0, 31865, 0, -12217, 0, 31871, 0, -12216, 0, 31872, 0, -12215, 0, 31873, 0, -12214, 0, 32003, 0, -12213, 0, 32008, 0, -12212, 0, 32001, 0, -12211, 0, 32600, 0, -12210, 0, 32657, 0, -12209, 0, 32653, 0, -12208, 0, 32702, 0, -12207, 0, -32761, 0, -12206, 0, -32754, 0, -12205, 0, -32753, 0, -12204, 0, -32748, 0, -12203, 0, -32713, 0, -12202, 0, -32552, 0, -12201, 0, -32569, 0, -12200, 0, -32544, 0, -12199, 0, -32559, 0, -12198, 0, -32568, 0, -12197, 0, -32574, 0, -12196, 0, -32560, 0, -12195, 0, -32571, 0, -12194, 0, -32541, 0, -12193, 0, -32551, 0, -12192, 0, -32548, 0, -12191, 0, -32566, 0, -12190, 0, -32555, 0, -12189, 0, -32567, 0, -12188, 0, -32561, 0, -12187, 0, -32553, 0, -12186, 0, -32538, 0, -12185, 0, -32563, 0, -12184, 0, -32257, 0, -12183, 0, -32223, 0, -12182, 0, -32108, 0, -12181, 0, -32039, 0, -12180, 0, -32002, 0, -12179, 0, -32007, 0, -12178, 0, -31993, 0, -12177, 0, -32024, 0, -12176, 0, -32000, 0, -12175, 0, -32043, 0, -12174, 0, -31942, 0, -12173, 0, -32021, 0, -12172, 0, -32042, 0, -12171, 0, -32012, 0, -12170, 0, -32020, 0, -12169, 0, -32031, 0, -12168, 0, -32014, 0, -12167, 0, -32011, 0, -12166, 0, -31988, 0, -12165, 0, -32005, 0, -12164, 0, -32010, 0, -12163, 0, -32016, 0, -12162, 0, -32022, 0, -12127, 0, -32028, 0, -12126, 0, -32032, 0, -12125, 0, -32006, 0, -12124, 0, -32013, 0, -12123, 0, -32019, 0, -12122, 0, -31113, 0, -12121, 0, -31116, 0, -12120, 0, -31108, 0, -12119, 0, -31117, 0, -12118, 0, -30655, 0, -12117, 0, -30642, 0, -12116, 0, -30617, 0, -12115, 0, -30614, 0, -12114, 0, -30615, 0, -12113, 0, -30253, 0, -12112, 0, -30204, 0, -12111, 0, -30201, 0, -12110, 0, -29326, 0, -12109, 0, -28701, 0, -12108, 0, -28703, 0, -12107, 0, -28690, 0, -12106, 0, -28704, 0, -12105, 0, -28431, 0, -12104, 0, -28483, 0, -12103, 0, -28481, 0, -12102, 0, -28459, 0, -12101, 0, -28475, 0, -12100, 0, -28482, 0, -12099, 0, -28473, 0, -12098, 0, -28469, 0, -12097, 0, -28472, 0, -12096, 0, -28204, 0, -12095, 0, -28205, 0, -12094, 0, -27052, 0, -12093, 0, -27057, 0, -12092, 0, -27055, 0, -12091, 0, -27053, 0, -12090, 0, -27062, 0, -12089, 0, -27058, 0, -12088, 0, 20510, 0, -12087, 0, 20485, 0, -12086, 0, 20487, 0, -12085, 0, 20499, 0, -12084, 0, 20514, 0, -12083, 0, 20528, 0, -12082, 0, 20507, 0, -12081, 0, 20469, 0, -12080, 0, 20468, 0, -12079, 0, 20531, 0, -12078, 0, 20535, 0, -12077, 0, 20524, 0, -12076, 0, 20470, 0, -12075, 0, 20471, 0, -12074, 0, 20503, 0, -12073, 0, 20508, 0, -12072, 0, 20512, 0, -12071, 0, 20519, 0, -12070, 0, 20533, 0, -12069, 0, 20527, 0, -12068, 0, 20529, 0, -12067, 0, 20494, 0, -12066, 0, 20826, 0, -12065, 0, 20884, 0, -12064, 0, 20883, 0, -12063, 0, 20938, 0, -12062, 0, 20932, 0, -12061, 0, 20933, 0, -12060, 0, 20936, 0, -12059, 0, 20942, 0, -12058, 0, 21089, 0, -12057, 0, 21082, 0, -12056, 0, 21074, 0, -12055, 0, 21086, 0, -12054, 0, 21087, 0, -12053, 0, 21077, 0, -12052, 0, 21090, 0, -12051, 0, 21197, 0, -12050, 0, 21262, 0, -12049, 0, 21406, 0, -12048, 0, 21798, 0, -12047, 0, 21730, 0, -12046, 0, 21783, 0, -12045, 0, 21778, 0, -12044, 0, 21735, 0, -12043, 0, 21747, 0, -12042, 0, 21732, 0, -12041, 0, 21786, 0, -12040, 0, 21759, 0, -12039, 0, 21764, 0, -12038, 0, 21768, 0, -12037, 0, 21739, 0, -12036, 0, 21777, 0, -12035, 0, 21765, 0, -12034, 0, 21745, 0, -11968, 0, 21770, 0, -11967, 0, 21755, 0, -11966, 0, 21751, 0, -11965, 0, 21752, 0, -11964, 0, 21728, 0, -11963, 0, 21774, 0, -11962, 0, 21763, 0, -11961, 0, 21771, 0, -11960, 0, 22273, 0, -11959, 0, 22274, 0, -11958, 0, 22476, 0, -11957, 0, 22578, 0, -11956, 0, 22485, 0, -11955, 0, 22482, 0, -11954, 0, 22458, 0, -11953, 0, 22470, 0, -11952, 0, 22461, 0, -11951, 0, 22460, 0, -11950, 0, 22456, 0, -11949, 0, 22454, 0, -11948, 0, 22463, 0, -11947, 0, 22471, 0, -11946, 0, 22480, 0, -11945, 0, 22457, 0, -11944, 0, 22465, 0, -11943, 0, 22798, 0, -11942, 0, 22858, 0, -11941, 0, 23065, 0, -11940, 0, 23062, 0, -11939, 0, 23085, 0, -11938, 0, 23086, 0, -11937, 0, 23061, 0, -11936, 0, 23055, 0, -11935, 0, 23063, 0, -11934, 0, 23050, 0, -11933, 0, 23070, 0, -11932, 0, 23091, 0, -11931, 0, 23404, 0, -11930, 0, 23463, 0, -11929, 0, 23469, 0, -11928, 0, 23468, 0, -11927, 0, 23555, 0, -11926, 0, 23638, 0, -11925, 0, 23636, 0, -11924, 0, 23788, 0, -11923, 0, 23807, 0, -11922, 0, 23790, 0, -11921, 0, 23793, 0, -11920, 0, 23799, 0, -11919, 0, 23808, 0, -11918, 0, 23801, 0, -11917, 0, 24105, 0, -11916, 0, 24104, 0, -11915, 0, 24232, 0, -11914, 0, 24238, 0, -11913, 0, 24234, 0, -11912, 0, 24236, 0, -11911, 0, 24371, 0, -11910, 0, 24368, 0, -11909, 0, 24423, 0, -11908, 0, 24669, 0, -11907, 0, 24666, 0, -11906, 0, 24679, 0, -11871, 0, 24641, 0, -11870, 0, 24738, 0, -11869, 0, 24712, 0, -11868, 0, 24704, 0, -11867, 0, 24722, 0, -11866, 0, 24705, 0, -11865, 0, 24733, 0, -11864, 0, 24707, 0, -11863, 0, 24725, 0, -11862, 0, 24731, 0, -11861, 0, 24727, 0, -11860, 0, 24711, 0, -11859, 0, 24732, 0, -11858, 0, 24718, 0, -11857, 0, 25113, 0, -11856, 0, 25158, 0, -11855, 0, 25330, 0, -11854, 0, 25360, 0, -11853, 0, 25430, 0, -11852, 0, 25388, 0, -11851, 0, 25412, 0, -11850, 0, 25413, 0, -11849, 0, 25398, 0, -11848, 0, 25411, 0, -11847, 0, 25572, 0, -11846, 0, 25401, 0, -11845, 0, 25419, 0, -11844, 0, 25418, 0, -11843, 0, 25404, 0, -11842, 0, 25385, 0, -11841, 0, 25409, 0, -11840, 0, 25396, 0, -11839, 0, 25432, 0, -11838, 0, 25428, 0, -11837, 0, 25433, 0, -11836, 0, 25389, 0, -11835, 0, 25415, 0, -11834, 0, 25395, 0, -11833, 0, 25434, 0, -11832, 0, 25425, 0, -11831, 0, 25400, 0, -11830, 0, 25431, 0, -11829, 0, 25408, 0, -11828, 0, 25416, 0, -11827, 0, 25930, 0, -11826, 0, 25926, 0, -11825, 0, 26054, 0, -11824, 0, 26051, 0, -11823, 0, 26052, 0, -11822, 0, 26050, 0, -11821, 0, 26186, 0, -11820, 0, 26207, 0, -11819, 0, 26183, 0, -11818, 0, 26193, 0, -11817, 0, 26386, 0, -11816, 0, 26387, 0, -11815, 0, 26655, 0, -11814, 0, 26650, 0, -11813, 0, 26697, 0, -11812, 0, 26674, 0, -11811, 0, 26675, 0, -11810, 0, 26683, 0, -11809, 0, 26699, 0, -11808, 0, 26703, 0, -11807, 0, 26646, 0, -11806, 0, 26673, 0, -11805, 0, 26652, 0, -11804, 0, 26677, 0, -11803, 0, 26667, 0, -11802, 0, 26669, 0, -11801, 0, 26671, 0, -11800, 0, 26702, 0, -11799, 0, 26692, 0, -11798, 0, 26676, 0, -11797, 0, 26653, 0, -11796, 0, 26642, 0, -11795, 0, 26644, 0, -11794, 0, 26662, 0, -11793, 0, 26664, 0, -11792, 0, 26670, 0, -11791, 0, 26701, 0, -11790, 0, 26682, 0, -11789, 0, 26661, 0, -11788, 0, 26656, 0, -11787, 0, 27436, 0, -11786, 0, 27439, 0, -11785, 0, 27437, 0, -11784, 0, 27441, 0, -11783, 0, 27444, 0, -11782, 0, 27501, 0, -11781, 0, -32638, 0, -11780, 0, 27528, 0, -11779, 0, 27622, 0, -11778, 0, 27620, 0, -11712, 0, 27624, 0, -11711, 0, 27619, 0, -11710, 0, 27618, 0, -11709, 0, 27623, 0, -11708, 0, 27685, 0, -11707, 0, 28026, 0, -11706, 0, 28003, 0, -11705, 0, 28004, 0, -11704, 0, 28022, 0, -11703, 0, 27917, 0, -11702, 0, 28001, 0, -11701, 0, 28050, 0, -11700, 0, 27992, 0, -11699, 0, 28002, 0, -11698, 0, 28013, 0, -11697, 0, 28015, 0, -11696, 0, 28049, 0, -11695, 0, 28045, 0, -11694, 0, 28143, 0, -11693, 0, 28031, 0, -11692, 0, 28038, 0, -11691, 0, 27998, 0, -11690, 0, 28007, 0, -11689, 0, 28000, 0, -11688, 0, 28055, 0, -11687, 0, 28016, 0, -11686, 0, 28028, 0, -11685, 0, 27999, 0, -11684, 0, 28034, 0, -11683, 0, 28056, 0, -11682, 0, 27951, 0, -11681, 0, 28008, 0, -11680, 0, 28043, 0, -11679, 0, 28030, 0, -11678, 0, 28032, 0, -11677, 0, 28036, 0, -11676, 0, 27926, 0, -11675, 0, 28035, 0, -11674, 0, 28027, 0, -11673, 0, 28029, 0, -11672, 0, 28021, 0, -11671, 0, 28048, 0, -11670, 0, 28892, 0, -11669, 0, 28883, 0, -11668, 0, 28881, 0, -11667, 0, 28893, 0, -11666, 0, 28875, 0, -11665, 0, 32569, 0, -11664, 0, 28898, 0, -11663, 0, 28887, 0, -11662, 0, 28882, 0, -11661, 0, 28894, 0, -11660, 0, 28896, 0, -11659, 0, 28884, 0, -11658, 0, 28877, 0, -11657, 0, 28869, 0, -11656, 0, 28870, 0, -11655, 0, 28871, 0, -11654, 0, 28890, 0, -11653, 0, 28878, 0, -11652, 0, 28897, 0, -11651, 0, 29250, 0, -11650, 0, 29304, 0, -11615, 0, 29303, 0, -11614, 0, 29302, 0, -11613, 0, 29440, 0, -11612, 0, 29434, 0, -11611, 0, 29428, 0, -11610, 0, 29438, 0, -11609, 0, 29430, 0, -11608, 0, 29427, 0, -11607, 0, 29435, 0, -11606, 0, 29441, 0, -11605, 0, 29651, 0, -11604, 0, 29657, 0, -11603, 0, 29669, 0, -11602, 0, 29654, 0, -11601, 0, 29628, 0, -11600, 0, 29671, 0, -11599, 0, 29667, 0, -11598, 0, 29673, 0, -11597, 0, 29660, 0, -11596, 0, 29650, 0, -11595, 0, 29659, 0, -11594, 0, 29652, 0, -11593, 0, 29661, 0, -11592, 0, 29658, 0, -11591, 0, 29655, 0, -11590, 0, 29656, 0, -11589, 0, 29672, 0, -11588, 0, 29918, 0, -11587, 0, 29919, 0, -11586, 0, 29940, 0, -11585, 0, 29941, 0, -11584, 0, 29985, 0, -11583, 0, 30043, 0, -11582, 0, 30047, 0, -11581, 0, 30128, 0, -11580, 0, 30145, 0, -11579, 0, 30139, 0, -11578, 0, 30148, 0, -11577, 0, 30144, 0, -11576, 0, 30143, 0, -11575, 0, 30134, 0, -11574, 0, 30138, 0, -11573, 0, 30346, 0, -11572, 0, 30409, 0, -11571, 0, 30493, 0, -11570, 0, 30491, 0, -11569, 0, 30480, 0, -11568, 0, 30483, 0, -11567, 0, 30482, 0, -11566, 0, 30499, 0, -11565, 0, 30481, 0, -11564, 0, 30485, 0, -11563, 0, 30489, 0, -11562, 0, 30490, 0, -11561, 0, 30498, 0, -11560, 0, 30503, 0, -11559, 0, 30755, 0, -11558, 0, 30764, 0, -11557, 0, 30754, 0, -11556, 0, 30773, 0, -11555, 0, 30767, 0, -11554, 0, 30760, 0, -11553, 0, 30766, 0, -11552, 0, 30763, 0, -11551, 0, 30753, 0, -11550, 0, 30761, 0, -11549, 0, 30771, 0, -11548, 0, 30762, 0, -11547, 0, 30769, 0, -11546, 0, 31060, 0, -11545, 0, 31067, 0, -11544, 0, 31055, 0, -11543, 0, 31068, 0, -11542, 0, 31059, 0, -11541, 0, 31058, 0, -11540, 0, 31057, 0, -11539, 0, 31211, 0, -11538, 0, 31212, 0, -11537, 0, 31200, 0, -11536, 0, 31214, 0, -11535, 0, 31213, 0, -11534, 0, 31210, 0, -11533, 0, 31196, 0, -11532, 0, 31198, 0, -11531, 0, 31197, 0, -11530, 0, 31366, 0, -11529, 0, 31369, 0, -11528, 0, 31365, 0, -11527, 0, 31371, 0, -11526, 0, 31372, 0, -11525, 0, 31370, 0, -11524, 0, 31367, 0, -11523, 0, 31448, 0, -11522, 0, 31504, 0, -11456, 0, 31492, 0, -11455, 0, 31507, 0, -11454, 0, 31493, 0, -11453, 0, 31503, 0, -11452, 0, 31496, 0, -11451, 0, 31498, 0, -11450, 0, 31502, 0, -11449, 0, 31497, 0, -11448, 0, 31506, 0, -11447, 0, 31876, 0, -11446, 0, 31889, 0, -11445, 0, 31882, 0, -11444, 0, 31884, 0, -11443, 0, 31880, 0, -11442, 0, 31885, 0, -11441, 0, 31877, 0, -11440, 0, 32030, 0, -11439, 0, 32029, 0, -11438, 0, 32017, 0, -11437, 0, 32014, 0, -11436, 0, 32024, 0, -11435, 0, 32022, 0, -11434, 0, 32019, 0, -11433, 0, 32031, 0, -11432, 0, 32018, 0, -11431, 0, 32015, 0, -11430, 0, 32012, 0, -11429, 0, 32604, 0, -11428, 0, 32609, 0, -11427, 0, 32606, 0, -11426, 0, 32608, 0, -11425, 0, 32605, 0, -11424, 0, 32603, 0, -11423, 0, 32662, 0, -11422, 0, 32658, 0, -11421, 0, 32707, 0, -11420, 0, 32706, 0, -11419, 0, 32704, 0, -11418, 0, -32746, 0, -11417, 0, -32706, 0, -11416, 0, -32711, 0, -11415, 0, -32518, 0, -11414, 0, -32526, 0, -11413, 0, -32519, 0, -11412, 0, -32523, 0, -11411, 0, -32511, 0, -11410, 0, -32517, 0, -11409, 0, -32512, 0, -11408, 0, -32255, 0, -11407, 0, -32209, 0, -11406, 0, -32219, 0, -11405, 0, -31949, 0, -11404, 0, -31955, 0, -11403, 0, -31932, 0, -11402, 0, -31975, 0, -11401, 0, -31919, 0, -11400, 0, -31963, 0, -11399, 0, -31914, 0, -11398, 0, -31937, 0, -11397, 0, -31935, 0, -11396, 0, -31962, 0, -11395, 0, -31972, 0, -11394, 0, -31966, 0, -11359, 0, -31934, 0, -11358, 0, -31922, 0, -11357, 0, -31973, 0, -11356, 0, -31958, 0, -11355, 0, -31992, 0, -11354, 0, -31940, 0, -11353, 0, -31923, 0, -11352, 0, -31978, 0, -11351, 0, -31964, 0, -11350, 0, -31968, 0, -11349, 0, -31945, 0, -11348, 0, -31953, 0, -11347, 0, -31959, 0, -11346, 0, -31929, 0, -11345, 0, -31931, 0, -11344, 0, -31924, 0, -11343, 0, -31917, 0, -11342, 0, -31970, 0, -11341, 0, -31956, 0, -11340, 0, -31925, 0, -11339, 0, -31961, 0, -11338, 0, -31928, 0, -11337, 0, -31149, 0, -11336, 0, -31150, 0, -11335, 0, -31070, 0, -11334, 0, -31064, 0, -11333, 0, -31082, 0, -11332, 0, -31091, 0, -11331, 0, -31087, 0, -11330, 0, -31074, 0, -11329, 0, -31097, 0, -11328, 0, -31081, 0, -11327, 0, -31098, 0, -11326, 0, -31093, 0, -11325, 0, -31078, 0, -11324, 0, -31099, 0, -11323, 0, -31067, 0, -11322, 0, -31079, 0, -11321, 0, -31071, 0, -11320, 0, -31065, 0, -11319, 0, -31083, 0, -11318, 0, -31080, 0, -11317, 0, -31090, 0, -11316, 0, -31075, 0, -11315, 0, -31088, 0, -11314, 0, -31084, 0, -11313, 0, -30653, 0, -11312, 0, -30652, 0, -11311, 0, -30611, 0, -11310, 0, -30603, 0, -11309, 0, -30602, 0, -11308, 0, -30606, 0, -11307, 0, -30592, 0, -11306, 0, -30607, 0, -11305, 0, -30593, 0, -11304, 0, -30609, 0, -11303, 0, -30589, 0, -11302, 0, -30594, 0, -11301, 0, -30604, 0, -11300, 0, -30596, 0, -11299, 0, -30190, 0, -11298, 0, -29625, 0, -11297, 0, -29609, 0, -11296, 0, -29573, 0, -11295, 0, -29532, 0, -11294, 0, -29533, 0, -11293, 0, -29322, 0, -11292, 0, -29320, 0, -11291, 0, -29259, 0, -11290, 0, -29257, 0, -11289, 0, -29258, 0, -11288, 0, -28975, 0, -11287, 0, -28973, 0, -11286, 0, -28674, 0, -11285, 0, -28683, 0, -11284, 0, -28670, 0, -11283, 0, -28673, 0, -11282, 0, -28677, 0, -11281, 0, -28668, 0, -11280, 0, -28676, 0, -11279, 0, -28682, 0, -11278, 0, -28458, 0, -11277, 0, -28448, 0, -11276, 0, -28455, 0, -11275, 0, -28454, 0, -11274, 0, -28445, 0, -11273, 0, -28449, 0, -11272, 0, -28443, 0, -11271, 0, -28456, 0, -11270, 0, -28453, 0, -11269, 0, -28457, 0, -11268, 0, -28452, 0, -11267, 0, -28444, 0, -11266, 0, -28336, 0, -11200, 0, -28338, 0, -11199, 0, -28337, 0, -11198, 0, -28203, 0, -11197, 0, -28190, 0, -11196, 0, -28198, 0, -11195, 0, -27044, 0, -11194, 0, -27041, 0, -11193, 0, -26948, 0, -11192, 0, -26397, 0, -11191, 0, -25889, 0, -11190, 0, -25809, 0, -11189, 0, 20095, 0, -11188, 0, 20592, 0, -11187, 0, 20586, 0, -11186, 0, 20577, 0, -11185, 0, 20574, 0, -11184, 0, 20576, 0, -11183, 0, 20563, 0, -11182, 0, 20555, 0, -11181, 0, 20573, 0, -11180, 0, 20594, 0, -11179, 0, 20552, 0, -11178, 0, 20557, 0, -11177, 0, 20545, 0, -11176, 0, 20571, 0, -11175, 0, 20554, 0, -11174, 0, 20578, 0, -11173, 0, 20501, 0, -11172, 0, 20549, 0, -11171, 0, 20575, 0, -11170, 0, 20585, 0, -11169, 0, 20587, 0, -11168, 0, 20579, 0, -11167, 0, 20580, 0, -11166, 0, 20550, 0, -11165, 0, 20544, 0, -11164, 0, 20590, 0, -11163, 0, 20595, 0, -11162, 0, 20567, 0, -11161, 0, 20561, 0, -11160, 0, 20944, 0, -11159, 0, 21099, 0, -11158, 0, 21101, 0, -11157, 0, 21100, 0, -11156, 0, 21102, 0, -11155, 0, 21206, 0, -11154, 0, 21203, 0, -11153, 0, 21293, 0, -11152, 0, 21404, 0, -11151, 0, 21877, 0, -11150, 0, 21878, 0, -11149, 0, 21820, 0, -11148, 0, 21837, 0, -11147, 0, 21840, 0, -11146, 0, 21812, 0, -11145, 0, 21802, 0, -11144, 0, 21841, 0, -11143, 0, 21858, 0, -11142, 0, 21814, 0, -11141, 0, 21813, 0, -11140, 0, 21808, 0, -11139, 0, 21842, 0, -11138, 0, 21829, 0, -11103, 0, 21772, 0, -11102, 0, 21810, 0, -11101, 0, 21861, 0, -11100, 0, 21838, 0, -11099, 0, 21817, 0, -11098, 0, 21832, 0, -11097, 0, 21805, 0, -11096, 0, 21819, 0, -11095, 0, 21824, 0, -11094, 0, 21835, 0, -11093, 0, 22282, 0, -11092, 0, 22279, 0, -11091, 0, 22523, 0, -11090, 0, 22548, 0, -11089, 0, 22498, 0, -11088, 0, 22518, 0, -11087, 0, 22492, 0, -11086, 0, 22516, 0, -11085, 0, 22528, 0, -11084, 0, 22509, 0, -11083, 0, 22525, 0, -11082, 0, 22536, 0, -11081, 0, 22520, 0, -11080, 0, 22539, 0, -11079, 0, 22515, 0, -11078, 0, 22479, 0, -11077, 0, 22535, 0, -11076, 0, 22510, 0, -11075, 0, 22499, 0, -11074, 0, 22514, 0, -11073, 0, 22501, 0, -11072, 0, 22508, 0, -11071, 0, 22497, 0, -11070, 0, 22542, 0, -11069, 0, 22524, 0, -11068, 0, 22544, 0, -11067, 0, 22503, 0, -11066, 0, 22529, 0, -11065, 0, 22540, 0, -11064, 0, 22513, 0, -11063, 0, 22505, 0, -11062, 0, 22512, 0, -11061, 0, 22541, 0, -11060, 0, 22532, 0, -11059, 0, 22876, 0, -11058, 0, 23136, 0, -11057, 0, 23128, 0, -11056, 0, 23125, 0, -11055, 0, 23143, 0, -11054, 0, 23134, 0, -11053, 0, 23096, 0, -11052, 0, 23093, 0, -11051, 0, 23149, 0, -11050, 0, 23120, 0, -11049, 0, 23135, 0, -11048, 0, 23141, 0, -11047, 0, 23148, 0, -11046, 0, 23123, 0, -11045, 0, 23140, 0, -11044, 0, 23127, 0, -11043, 0, 23107, 0, -11042, 0, 23133, 0, -11041, 0, 23122, 0, -11040, 0, 23108, 0, -11039, 0, 23131, 0, -11038, 0, 23112, 0, -11037, 0, 23182, 0, -11036, 0, 23102, 0, -11035, 0, 23117, 0, -11034, 0, 23097, 0, -11033, 0, 23116, 0, -11032, 0, 23152, 0, -11031, 0, 23145, 0, -11030, 0, 23111, 0, -11029, 0, 23121, 0, -11028, 0, 23126, 0, -11027, 0, 23106, 0, -11026, 0, 23132, 0, -11025, 0, 23410, 0, -11024, 0, 23406, 0, -11023, 0, 23489, 0, -11022, 0, 23488, 0, -11021, 0, 23641, 0, -11020, 0, 23838, 0, -11019, 0, 23819, 0, -11018, 0, 23837, 0, -11017, 0, 23834, 0, -11016, 0, 23840, 0, -11015, 0, 23820, 0, -11014, 0, 23848, 0, -11013, 0, 23821, 0, -11012, 0, 23846, 0, -11011, 0, 23845, 0, -11010, 0, 23823, 0, -10944, 0, 23856, 0, -10943, 0, 23826, 0, -10942, 0, 23843, 0, -10941, 0, 23839, 0, -10940, 0, 23854, 0, -10939, 0, 24126, 0, -10938, 0, 24116, 0, -10937, 0, 24241, 0, -10936, 0, 24244, 0, -10935, 0, 24249, 0, -10934, 0, 24242, 0, -10933, 0, 24243, 0, -10932, 0, 24374, 0, -10931, 0, 24376, 0, -10930, 0, 24475, 0, -10929, 0, 24470, 0, -10928, 0, 24479, 0, -10927, 0, 24714, 0, -10926, 0, 24720, 0, -10925, 0, 24710, 0, -10924, 0, 24766, 0, -10923, 0, 24752, 0, -10922, 0, 24762, 0, -10921, 0, 24787, 0, -10920, 0, 24788, 0, -10919, 0, 24783, 0, -10918, 0, 24804, 0, -10917, 0, 24793, 0, -10916, 0, 24797, 0, -10915, 0, 24776, 0, -10914, 0, 24753, 0, -10913, 0, 24795, 0, -10912, 0, 24759, 0, -10911, 0, 24778, 0, -10910, 0, 24767, 0, -10909, 0, 24771, 0, -10908, 0, 24781, 0, -10907, 0, 24768, 0, -10906, 0, 25394, 0, -10905, 0, 25445, 0, -10904, 0, 25482, 0, -10903, 0, 25474, 0, -10902, 0, 25469, 0, -10901, 0, 25533, 0, -10900, 0, 25502, 0, -10899, 0, 25517, 0, -10898, 0, 25501, 0, -10897, 0, 25495, 0, -10896, 0, 25515, 0, -10895, 0, 25486, 0, -10894, 0, 25455, 0, -10893, 0, 25479, 0, -10892, 0, 25488, 0, -10891, 0, 25454, 0, -10890, 0, 25519, 0, -10889, 0, 25461, 0, -10888, 0, 25500, 0, -10887, 0, 25453, 0, -10886, 0, 25518, 0, -10885, 0, 25468, 0, -10884, 0, 25508, 0, -10883, 0, 25403, 0, -10882, 0, 25503, 0, -10847, 0, 25464, 0, -10846, 0, 25477, 0, -10845, 0, 25473, 0, -10844, 0, 25489, 0, -10843, 0, 25485, 0, -10842, 0, 25456, 0, -10841, 0, 25939, 0, -10840, 0, 26061, 0, -10839, 0, 26213, 0, -10838, 0, 26209, 0, -10837, 0, 26203, 0, -10836, 0, 26201, 0, -10835, 0, 26204, 0, -10834, 0, 26210, 0, -10833, 0, 26392, 0, -10832, 0, 26745, 0, -10831, 0, 26759, 0, -10830, 0, 26768, 0, -10829, 0, 26780, 0, -10828, 0, 26733, 0, -10827, 0, 26734, 0, -10826, 0, 26798, 0, -10825, 0, 26795, 0, -10824, 0, 26966, 0, -10823, 0, 26735, 0, -10822, 0, 26787, 0, -10821, 0, 26796, 0, -10820, 0, 26793, 0, -10819, 0, 26741, 0, -10818, 0, 26740, 0, -10817, 0, 26802, 0, -10816, 0, 26767, 0, -10815, 0, 26743, 0, -10814, 0, 26770, 0, -10813, 0, 26748, 0, -10812, 0, 26731, 0, -10811, 0, 26738, 0, -10810, 0, 26794, 0, -10809, 0, 26752, 0, -10808, 0, 26737, 0, -10807, 0, 26750, 0, -10806, 0, 26779, 0, -10805, 0, 26774, 0, -10804, 0, 26763, 0, -10803, 0, 26784, 0, -10802, 0, 26761, 0, -10801, 0, 26788, 0, -10800, 0, 26744, 0, -10799, 0, 26747, 0, -10798, 0, 26769, 0, -10797, 0, 26764, 0, -10796, 0, 26762, 0, -10795, 0, 26749, 0, -10794, 0, 27446, 0, -10793, 0, 27443, 0, -10792, 0, 27447, 0, -10791, 0, 27448, 0, -10790, 0, 27537, 0, -10789, 0, 27535, 0, -10788, 0, 27533, 0, -10787, 0, 27534, 0, -10786, 0, 27532, 0, -10785, 0, 27690, 0, -10784, 0, 28096, 0, -10783, 0, 28075, 0, -10782, 0, 28084, 0, -10781, 0, 28083, 0, -10780, 0, 28276, 0, -10779, 0, 28076, 0, -10778, 0, 28137, 0, -10777, 0, 28130, 0, -10776, 0, 28087, 0, -10775, 0, 28150, 0, -10774, 0, 28116, 0, -10773, 0, 28160, 0, -10772, 0, 28104, 0, -10771, 0, 28128, 0, -10770, 0, 28127, 0, -10769, 0, 28118, 0, -10768, 0, 28094, 0, -10767, 0, 28133, 0, -10766, 0, 28124, 0, -10765, 0, 28125, 0, -10764, 0, 28123, 0, -10763, 0, 28148, 0, -10762, 0, 28106, 0, -10761, 0, 28093, 0, -10760, 0, 28141, 0, -10759, 0, 28144, 0, -10758, 0, 28090, 0, -10757, 0, 28117, 0, -10756, 0, 28098, 0, -10755, 0, 28111, 0, -10754, 0, 28105, 0, -10688, 0, 28112, 0, -10687, 0, 28146, 0, -10686, 0, 28115, 0, -10685, 0, 28157, 0, -10684, 0, 28119, 0, -10683, 0, 28109, 0, -10682, 0, 28131, 0, -10681, 0, 28091, 0, -10680, 0, 28922, 0, -10679, 0, 28941, 0, -10678, 0, 28919, 0, -10677, 0, 28951, 0, -10676, 0, 28916, 0, -10675, 0, 28940, 0, -10674, 0, 28912, 0, -10673, 0, 28932, 0, -10672, 0, 28915, 0, -10671, 0, 28944, 0, -10670, 0, 28924, 0, -10669, 0, 28927, 0, -10668, 0, 28934, 0, -10667, 0, 28947, 0, -10666, 0, 28928, 0, -10665, 0, 28920, 0, -10664, 0, 28918, 0, -10663, 0, 28939, 0, -10662, 0, 28930, 0, -10661, 0, 28942, 0, -10660, 0, 29310, 0, -10659, 0, 29307, 0, -10658, 0, 29308, 0, -10657, 0, 29311, 0, -10656, 0, 29469, 0, -10655, 0, 29463, 0, -10654, 0, 29447, 0, -10653, 0, 29457, 0, -10652, 0, 29464, 0, -10651, 0, 29450, 0, -10650, 0, 29448, 0, -10649, 0, 29439, 0, -10648, 0, 29455, 0, -10647, 0, 29470, 0, -10646, 0, 29576, 0, -10645, 0, 29686, 0, -10644, 0, 29688, 0, -10643, 0, 29685, 0, -10642, 0, 29700, 0, -10641, 0, 29697, 0, -10640, 0, 29693, 0, -10639, 0, 29703, 0, -10638, 0, 29696, 0, -10637, 0, 29690, 0, -10636, 0, 29692, 0, -10635, 0, 29695, 0, -10634, 0, 29708, 0, -10633, 0, 29707, 0, -10632, 0, 29684, 0, -10631, 0, 29704, 0, -10630, 0, 30052, 0, -10629, 0, 30051, 0, -10628, 0, 30158, 0, -10627, 0, 30162, 0, -10626, 0, 30159, 0, -10591, 0, 30155, 0, -10590, 0, 30156, 0, -10589, 0, 30161, 0, -10588, 0, 30160, 0, -10587, 0, 30351, 0, -10586, 0, 30345, 0, -10585, 0, 30419, 0, -10584, 0, 30521, 0, -10583, 0, 30511, 0, -10582, 0, 30509, 0, -10581, 0, 30513, 0, -10580, 0, 30514, 0, -10579, 0, 30516, 0, -10578, 0, 30515, 0, -10577, 0, 30525, 0, -10576, 0, 30501, 0, -10575, 0, 30523, 0, -10574, 0, 30517, 0, -10573, 0, 30792, 0, -10572, 0, 30802, 0, -10571, 0, 30793, 0, -10570, 0, 30797, 0, -10569, 0, 30794, 0, -10568, 0, 30796, 0, -10567, 0, 30758, 0, -10566, 0, 30789, 0, -10565, 0, 30800, 0, -10564, 0, 31076, 0, -10563, 0, 31079, 0, -10562, 0, 31081, 0, -10561, 0, 31082, 0, -10560, 0, 31075, 0, -10559, 0, 31083, 0, -10558, 0, 31073, 0, -10557, 0, 31163, 0, -10556, 0, 31226, 0, -10555, 0, 31224, 0, -10554, 0, 31222, 0, -10553, 0, 31223, 0, -10552, 0, 31375, 0, -10551, 0, 31380, 0, -10550, 0, 31376, 0, -10549, 0, 31541, 0, -10548, 0, 31559, 0, -10547, 0, 31540, 0, -10546, 0, 31525, 0, -10545, 0, 31536, 0, -10544, 0, 31522, 0, -10543, 0, 31524, 0, -10542, 0, 31539, 0, -10541, 0, 31512, 0, -10540, 0, 31530, 0, -10539, 0, 31517, 0, -10538, 0, 31537, 0, -10537, 0, 31531, 0, -10536, 0, 31533, 0, -10535, 0, 31535, 0, -10534, 0, 31538, 0, -10533, 0, 31544, 0, -10532, 0, 31514, 0, -10531, 0, 31523, 0, -10530, 0, 31892, 0, -10529, 0, 31896, 0, -10528, 0, 31894, 0, -10527, 0, 31907, 0, -10526, 0, 32053, 0, -10525, 0, 32061, 0, -10524, 0, 32056, 0, -10523, 0, 32054, 0, -10522, 0, 32058, 0, -10521, 0, 32069, 0, -10520, 0, 32044, 0, -10519, 0, 32041, 0, -10518, 0, 32065, 0, -10517, 0, 32071, 0, -10516, 0, 32062, 0, -10515, 0, 32063, 0, -10514, 0, 32074, 0, -10513, 0, 32059, 0, -10512, 0, 32040, 0, -10511, 0, 32611, 0, -10510, 0, 32661, 0, -10509, 0, 32668, 0, -10508, 0, 32669, 0, -10507, 0, 32667, 0, -10506, 0, 32714, 0, -10505, 0, 32715, 0, -10504, 0, 32717, 0, -10503, 0, 32720, 0, -10502, 0, 32721, 0, -10501, 0, 32711, 0, -10500, 0, 32719, 0, -10499, 0, 32713, 0, -10498, 0, -32737, 0, -10432, 0, -32738, 0, -10431, 0, -32741, 0, -10430, 0, -32697, 0, -10429, 0, -32701, 0, -10428, 0, -32696, 0, -10427, 0, -32488, 0, -10426, 0, -32475, 0, -10425, 0, -32487, 0, -10424, 0, -32485, 0, -10423, 0, -32467, 0, -10422, 0, -32481, 0, -10421, 0, -32468, 0, -10420, 0, -32482, 0, -10419, 0, -32479, 0, -10418, 0, -32491, 0, -10417, 0, -32473, 0, -10416, 0, -32483, 0, -10415, 0, -32478, 0, -10414, 0, -32239, 0, -10413, 0, -32200, 0, -10412, 0, -32205, 0, -10411, 0, -32198, 0, -10410, 0, -32204, 0, -10409, 0, -32206, 0, -10408, 0, -32140, 0, -10407, 0, -31856, 0, -10406, 0, -31837, 0, -10405, 0, -31832, 0, -10404, 0, -31859, 0, -10403, 0, -31878, 0, -10402, 0, -31885, 0, -10401, 0, -31836, 0, -10400, 0, -31884, 0, -10399, 0, -31857, 0, -10398, 0, -31871, 0, -10397, 0, -31851, 0, -10396, 0, -31847, 0, -10395, 0, -31883, 0, -10394, 0, -31852, 0, -10393, 0, -31831, 0, -10392, 0, -31875, 0, -10391, 0, -31869, 0, -10390, 0, -31860, 0, -10389, 0, -31843, 0, -10388, 0, -31845, 0, -10387, 0, -31830, 0, -10386, 0, -31861, 0, -10385, 0, -31874, 0, -10384, 0, -31835, 0, -10383, 0, -31825, 0, -10382, 0, -31864, 0, -10381, 0, -31849, 0, -10380, 0, -31824, 0, -10379, 0, -31873, 0, -10378, 0, -31834, 0, -10377, 0, -31865, 0, -10376, 0, -31826, 0, -10375, 0, -31882, 0, -10374, 0, -31846, 0, -10373, 0, -31143, 0, -10372, 0, -31146, 0, -10371, 0, -31041, 0, -10370, 0, -31049, 0, -10335, 0, -31038, 0, -10334, 0, -31039, 0, -10333, 0, -31035, 0, -10332, 0, -31046, 0, -10331, 0, -31056, 0, -10330, 0, -31032, 0, -10329, 0, -31047, 0, -10328, 0, -31053, 0, -10327, 0, -31048, 0, -10326, 0, -31028, 0, -10325, 0, -31052, 0, -10324, 0, -31045, 0, -10323, 0, -31044, 0, -10322, 0, -31037, 0, -10321, 0, -31043, 0, -10320, 0, -31042, 0, -10319, 0, -30638, 0, -10318, 0, -30583, 0, -10317, 0, -30571, 0, -10316, 0, -30552, 0, -10315, 0, -30558, 0, -10314, 0, -30550, 0, -10313, 0, -30566, 0, -10312, 0, -30575, 0, -10311, 0, -30559, 0, -10310, 0, -30561, 0, -10309, 0, -30568, 0, -10308, 0, -30553, 0, -10307, 0, -30567, 0, -10306, 0, -30565, 0, -10305, 0, -30569, 0, -10304, 0, -30556, 0, -10303, 0, -30548, 0, -10302, 0, -30580, 0, -10301, 0, -30573, 0, -10300, 0, -30578, 0, -10299, 0, -30334, 0, -10298, 0, -30250, 0, -10297, 0, -30247, 0, -10296, 0, -30251, 0, -10295, 0, -30160, 0, -10294, 0, -30169, 0, -10293, 0, -30164, 0, -10292, 0, -30178, 0, -10291, 0, -29639, 0, -10290, 0, -29637, 0, -10289, 0, -29604, 0, -10288, 0, -29603, 0, -10287, 0, -29571, 0, -10286, 0, -29531, 0, -10285, 0, -29315, 0, -10284, 0, -29317, 0, -10283, 0, -29319, 0, -10282, 0, -29252, 0, -10281, 0, -29246, 0, -10280, 0, -29255, 0, -10279, 0, -29249, 0, -10278, 0, -29247, 0, -10277, 0, -28968, 0, -10276, 0, -28962, 0, -10275, 0, -28963, 0, -10274, 0, -28964, 0, -10273, 0, -28969, 0, -10272, 0, -28960, 0, -10271, 0, -28959, 0, -10270, 0, -28636, 0, -10269, 0, -28661, 0, -10268, 0, -28655, 0, -10267, 0, -28644, 0, -10266, 0, -28660, 0, -10265, 0, -28639, 0, -10264, 0, -28433, 0, -10263, 0, -28438, 0, -10262, 0, -28432, 0, -10261, 0, -28428, 0, -10260, 0, -28430, 0, -10259, 0, -28429, 0, -10258, 0, -28460, 0, -10257, 0, -28437, 0, -10256, 0, -28436, 0, -10255, 0, -28439, 0, -10254, 0, -28330, 0, -10253, 0, -28328, 0, -10252, 0, -28326, 0, -10251, 0, -28333, 0, -10250, 0, -28331, 0, -10249, 0, -28180, 0, -10248, 0, -28172, 0, -10247, 0, -28175, 0, -10246, 0, -28173, 0, -10245, 0, -28168, 0, -10244, 0, -28188, 0, -10243, 0, -28167, 0, -10242, 0, -28182, 0, -10176, 0, -28181, 0, -10175, 0, -28169, 0, -10174, 0, -28184, 0, -10173, 0, -28178, 0, -10172, 0, -27270, 0, -10171, 0, -27258, 0, -10170, 0, -27256, 0, -10169, 0, -27012, 0, -10168, 0, -27027, 0, -10167, 0, -27029, 0, -10166, 0, -27023, 0, -10165, 0, -27025, 0, -10164, 0, -26945, 0, -10163, 0, -26774, 0, -10162, 0, -26620, 0, -10161, 0, -26395, 0, -10160, 0, -26217, 0, -10159, 0, 20635, 0, -10158, 0, 20629, 0, -10157, 0, 20628, 0, -10156, 0, 20638, 0, -10155, 0, 20619, 0, -10154, 0, 20643, 0, -10153, 0, 20611, 0, -10152, 0, 20620, 0, -10151, 0, 20622, 0, -10150, 0, 20637, 0, -10149, 0, 20584, 0, -10148, 0, 20636, 0, -10147, 0, 20626, 0, -10146, 0, 20610, 0, -10145, 0, 20615, 0, -10144, 0, 20831, 0, -10143, 0, 20948, 0, -10142, 0, 21266, 0, -10141, 0, 21265, 0, -10140, 0, 21412, 0, -10139, 0, 21415, 0, -10138, 0, 21905, 0, -10137, 0, 21928, 0, -10136, 0, 21925, 0, -10135, 0, 21933, 0, -10134, 0, 21879, 0, -10133, 0, 22085, 0, -10132, 0, 21922, 0, -10131, 0, 21907, 0, -10130, 0, 21896, 0, -10129, 0, 21903, 0, -10128, 0, 21941, 0, -10127, 0, 21889, 0, -10126, 0, 21923, 0, -10125, 0, 21906, 0, -10124, 0, 21924, 0, -10123, 0, 21885, 0, -10122, 0, 21900, 0, -10121, 0, 21926, 0, -10120, 0, 21887, 0, -10119, 0, 21909, 0, -10118, 0, 21921, 0, -10117, 0, 21902, 0, -10116, 0, 22284, 0, -10115, 0, 22569, 0, -10114, 0, 22583, 0, -10079, 0, 22553, 0, -10078, 0, 22558, 0, -10077, 0, 22567, 0, -10076, 0, 22563, 0, -10075, 0, 22568, 0, -10074, 0, 22517, 0, -10073, 0, 22600, 0, -10072, 0, 22565, 0, -10071, 0, 22556, 0, -10070, 0, 22555, 0, -10069, 0, 22579, 0, -10068, 0, 22591, 0, -10067, 0, 22582, 0, -10066, 0, 22574, 0, -10065, 0, 22585, 0, -10064, 0, 22584, 0, -10063, 0, 22573, 0, -10062, 0, 22572, 0, -10061, 0, 22587, 0, -10060, 0, 22881, 0, -10059, 0, 23215, 0, -10058, 0, 23188, 0, -10057, 0, 23199, 0, -10056, 0, 23162, 0, -10055, 0, 23202, 0, -10054, 0, 23198, 0, -10053, 0, 23160, 0, -10052, 0, 23206, 0, -10051, 0, 23164, 0, -10050, 0, 23205, 0, -10049, 0, 23212, 0, -10048, 0, 23189, 0, -10047, 0, 23214, 0, -10046, 0, 23095, 0, -10045, 0, 23172, 0, -10044, 0, 23178, 0, -10043, 0, 23191, 0, -10042, 0, 23171, 0, -10041, 0, 23179, 0, -10040, 0, 23209, 0, -10039, 0, 23163, 0, -10038, 0, 23165, 0, -10037, 0, 23180, 0, -10036, 0, 23196, 0, -10035, 0, 23183, 0, -10034, 0, 23187, 0, -10033, 0, 23197, 0, -10032, 0, 23530, 0, -10031, 0, 23501, 0, -10030, 0, 23499, 0, -10029, 0, 23508, 0, -10028, 0, 23505, 0, -10027, 0, 23498, 0, -10026, 0, 23502, 0, -10025, 0, 23564, 0, -10024, 0, 23600, 0, -10023, 0, 23863, 0, -10022, 0, 23875, 0, -10021, 0, 23915, 0, -10020, 0, 23873, 0, -10019, 0, 23883, 0, -10018, 0, 23871, 0, -10017, 0, 23861, 0, -10016, 0, 23889, 0, -10015, 0, 23886, 0, -10014, 0, 23893, 0, -10013, 0, 23859, 0, -10012, 0, 23866, 0, -10011, 0, 23890, 0, -10010, 0, 23869, 0, -10009, 0, 23857, 0, -10008, 0, 23897, 0, -10007, 0, 23874, 0, -10006, 0, 23865, 0, -10005, 0, 23881, 0, -10004, 0, 23864, 0, -10003, 0, 23868, 0, -10002, 0, 23858, 0, -10001, 0, 23862, 0, -10000, 0, 23872, 0, -9999, 0, 23877, 0, -9998, 0, 24132, 0, -9997, 0, 24129, 0, -9996, 0, 24408, 0, -9995, 0, 24486, 0, -9994, 0, 24485, 0, -9993, 0, 24491, 0, -9992, 0, 24777, 0, -9991, 0, 24761, 0, -9990, 0, 24780, 0, -9989, 0, 24802, 0, -9988, 0, 24782, 0, -9987, 0, 24772, 0, -9986, 0, 24852, 0, -9920, 0, 24818, 0, -9919, 0, 24842, 0, -9918, 0, 24854, 0, -9917, 0, 24837, 0, -9916, 0, 24821, 0, -9915, 0, 24851, 0, -9914, 0, 24824, 0, -9913, 0, 24828, 0, -9912, 0, 24830, 0, -9911, 0, 24769, 0, -9910, 0, 24835, 0, -9909, 0, 24856, 0, -9908, 0, 24861, 0, -9907, 0, 24848, 0, -9906, 0, 24831, 0, -9905, 0, 24836, 0, -9904, 0, 24843, 0, -9903, 0, 25162, 0, -9902, 0, 25492, 0, -9901, 0, 25521, 0, -9900, 0, 25520, 0, -9899, 0, 25550, 0, -9898, 0, 25573, 0, -9897, 0, 25576, 0, -9896, 0, 25583, 0, -9895, 0, 25539, 0, -9894, 0, 25757, 0, -9893, 0, 25587, 0, -9892, 0, 25546, 0, -9891, 0, 25568, 0, -9890, 0, 25590, 0, -9889, 0, 25557, 0, -9888, 0, 25586, 0, -9887, 0, 25589, 0, -9886, 0, 25697, 0, -9885, 0, 25567, 0, -9884, 0, 25534, 0, -9883, 0, 25565, 0, -9882, 0, 25564, 0, -9881, 0, 25540, 0, -9880, 0, 25560, 0, -9879, 0, 25555, 0, -9878, 0, 25538, 0, -9877, 0, 25543, 0, -9876, 0, 25548, 0, -9875, 0, 25547, 0, -9874, 0, 25544, 0, -9873, 0, 25584, 0, -9872, 0, 25559, 0, -9871, 0, 25561, 0, -9870, 0, 25906, 0, -9869, 0, 25959, 0, -9868, 0, 25962, 0, -9867, 0, 25956, 0, -9866, 0, 25948, 0, -9865, 0, 25960, 0, -9864, 0, 25957, 0, -9863, 0, 25996, 0, -9862, 0, 26013, 0, -9861, 0, 26014, 0, -9860, 0, 26030, 0, -9859, 0, 26064, 0, -9858, 0, 26066, 0, -9823, 0, 26236, 0, -9822, 0, 26220, 0, -9821, 0, 26235, 0, -9820, 0, 26240, 0, -9819, 0, 26225, 0, -9818, 0, 26233, 0, -9817, 0, 26218, 0, -9816, 0, 26226, 0, -9815, 0, 26369, 0, -9814, 0, 26892, 0, -9813, 0, 26835, 0, -9812, 0, 26884, 0, -9811, 0, 26844, 0, -9810, 0, 26922, 0, -9809, 0, 26860, 0, -9808, 0, 26858, 0, -9807, 0, 26865, 0, -9806, 0, 26895, 0, -9805, 0, 26838, 0, -9804, 0, 26871, 0, -9803, 0, 26859, 0, -9802, 0, 26852, 0, -9801, 0, 26870, 0, -9800, 0, 26899, 0, -9799, 0, 26896, 0, -9798, 0, 26867, 0, -9797, 0, 26849, 0, -9796, 0, 26887, 0, -9795, 0, 26828, 0, -9794, 0, 26888, 0, -9793, 0, 26992, 0, -9792, 0, 26804, 0, -9791, 0, 26897, 0, -9790, 0, 26863, 0, -9789, 0, 26822, 0, -9788, 0, 26900, 0, -9787, 0, 26872, 0, -9786, 0, 26832, 0, -9785, 0, 26877, 0, -9784, 0, 26876, 0, -9783, 0, 26856, 0, -9782, 0, 26891, 0, -9781, 0, 26890, 0, -9780, 0, 26903, 0, -9779, 0, 26830, 0, -9778, 0, 26824, 0, -9777, 0, 26845, 0, -9776, 0, 26846, 0, -9775, 0, 26854, 0, -9774, 0, 26868, 0, -9773, 0, 26833, 0, -9772, 0, 26886, 0, -9771, 0, 26836, 0, -9770, 0, 26857, 0, -9769, 0, 26901, 0, -9768, 0, 26917, 0, -9767, 0, 26823, 0, -9766, 0, 27449, 0, -9765, 0, 27451, 0, -9764, 0, 27455, 0, -9763, 0, 27452, 0, -9762, 0, 27540, 0, -9761, 0, 27543, 0, -9760, 0, 27545, 0, -9759, 0, 27541, 0, -9758, 0, 27581, 0, -9757, 0, 27632, 0, -9756, 0, 27634, 0, -9755, 0, 27635, 0, -9754, 0, 27696, 0, -9753, 0, 28156, 0, -9752, 0, 28230, 0, -9751, 0, 28231, 0, -9750, 0, 28191, 0, -9749, 0, 28233, 0, -9748, 0, 28296, 0, -9747, 0, 28220, 0, -9746, 0, 28221, 0, -9745, 0, 28229, 0, -9744, 0, 28258, 0, -9743, 0, 28203, 0, -9742, 0, 28223, 0, -9741, 0, 28225, 0, -9740, 0, 28253, 0, -9739, 0, 28275, 0, -9738, 0, 28188, 0, -9737, 0, 28211, 0, -9736, 0, 28235, 0, -9735, 0, 28224, 0, -9734, 0, 28241, 0, -9733, 0, 28219, 0, -9732, 0, 28163, 0, -9731, 0, 28206, 0, -9730, 0, 28254, 0, -9664, 0, 28264, 0, -9663, 0, 28252, 0, -9662, 0, 28257, 0, -9661, 0, 28209, 0, -9660, 0, 28200, 0, -9659, 0, 28256, 0, -9658, 0, 28273, 0, -9657, 0, 28267, 0, -9656, 0, 28217, 0, -9655, 0, 28194, 0, -9654, 0, 28208, 0, -9653, 0, 28243, 0, -9652, 0, 28261, 0, -9651, 0, 28199, 0, -9650, 0, 28280, 0, -9649, 0, 28260, 0, -9648, 0, 28279, 0, -9647, 0, 28245, 0, -9646, 0, 28281, 0, -9645, 0, 28242, 0, -9644, 0, 28262, 0, -9643, 0, 28213, 0, -9642, 0, 28214, 0, -9641, 0, 28250, 0, -9640, 0, 28960, 0, -9639, 0, 28958, 0, -9638, 0, 28975, 0, -9637, 0, 28923, 0, -9636, 0, 28974, 0, -9635, 0, 28977, 0, -9634, 0, 28963, 0, -9633, 0, 28965, 0, -9632, 0, 28962, 0, -9631, 0, 28978, 0, -9630, 0, 28959, 0, -9629, 0, 28968, 0, -9628, 0, 28986, 0, -9627, 0, 28955, 0, -9626, 0, 29259, 0, -9625, 0, 29274, 0, -9624, 0, 29320, 0, -9623, 0, 29321, 0, -9622, 0, 29318, 0, -9621, 0, 29317, 0, -9620, 0, 29323, 0, -9619, 0, 29458, 0, -9618, 0, 29451, 0, -9617, 0, 29488, 0, -9616, 0, 29474, 0, -9615, 0, 29489, 0, -9614, 0, 29491, 0, -9613, 0, 29479, 0, -9612, 0, 29490, 0, -9611, 0, 29485, 0, -9610, 0, 29478, 0, -9609, 0, 29475, 0, -9608, 0, 29493, 0, -9607, 0, 29452, 0, -9606, 0, 29742, 0, -9605, 0, 29740, 0, -9604, 0, 29744, 0, -9603, 0, 29739, 0, -9602, 0, 29718, 0, -9567, 0, 29722, 0, -9566, 0, 29729, 0, -9565, 0, 29741, 0, -9564, 0, 29745, 0, -9563, 0, 29732, 0, -9562, 0, 29731, 0, -9561, 0, 29725, 0, -9560, 0, 29737, 0, -9559, 0, 29728, 0, -9558, 0, 29746, 0, -9557, 0, 29947, 0, -9556, 0, 29999, 0, -9555, 0, 30063, 0, -9554, 0, 30060, 0, -9553, 0, 30183, 0, -9552, 0, 30170, 0, -9551, 0, 30177, 0, -9550, 0, 30182, 0, -9549, 0, 30173, 0, -9548, 0, 30175, 0, -9547, 0, 30180, 0, -9546, 0, 30167, 0, -9545, 0, 30357, 0, -9544, 0, 30354, 0, -9543, 0, 30426, 0, -9542, 0, 30534, 0, -9541, 0, 30535, 0, -9540, 0, 30532, 0, -9539, 0, 30541, 0, -9538, 0, 30533, 0, -9537, 0, 30538, 0, -9536, 0, 30542, 0, -9535, 0, 30539, 0, -9534, 0, 30540, 0, -9533, 0, 30686, 0, -9532, 0, 30700, 0, -9531, 0, 30816, 0, -9530, 0, 30820, 0, -9529, 0, 30821, 0, -9528, 0, 30812, 0, -9527, 0, 30829, 0, -9526, 0, 30833, 0, -9525, 0, 30826, 0, -9524, 0, 30830, 0, -9523, 0, 30832, 0, -9522, 0, 30825, 0, -9521, 0, 30824, 0, -9520, 0, 30814, 0, -9519, 0, 30818, 0, -9518, 0, 31092, 0, -9517, 0, 31091, 0, -9516, 0, 31090, 0, -9515, 0, 31088, 0, -9514, 0, 31234, 0, -9513, 0, 31242, 0, -9512, 0, 31235, 0, -9511, 0, 31244, 0, -9510, 0, 31236, 0, -9509, 0, 31385, 0, -9508, 0, 31462, 0, -9507, 0, 31460, 0, -9506, 0, 31562, 0, -9505, 0, 31547, 0, -9504, 0, 31556, 0, -9503, 0, 31560, 0, -9502, 0, 31564, 0, -9501, 0, 31566, 0, -9500, 0, 31552, 0, -9499, 0, 31576, 0, -9498, 0, 31557, 0, -9497, 0, 31906, 0, -9496, 0, 31902, 0, -9495, 0, 31912, 0, -9494, 0, 31905, 0, -9493, 0, 32088, 0, -9492, 0, 32111, 0, -9491, 0, 32099, 0, -9490, 0, 32083, 0, -9489, 0, 32086, 0, -9488, 0, 32103, 0, -9487, 0, 32106, 0, -9486, 0, 32079, 0, -9485, 0, 32109, 0, -9484, 0, 32092, 0, -9483, 0, 32107, 0, -9482, 0, 32082, 0, -9481, 0, 32084, 0, -9480, 0, 32105, 0, -9479, 0, 32081, 0, -9478, 0, 32095, 0, -9477, 0, 32078, 0, -9476, 0, 32574, 0, -9475, 0, 32575, 0, -9474, 0, 32613, 0, -9408, 0, 32614, 0, -9407, 0, 32674, 0, -9406, 0, 32672, 0, -9405, 0, 32673, 0, -9404, 0, 32727, 0, -9403, 0, -32687, 0, -9402, 0, -32689, 0, -9401, 0, -32688, 0, -9400, 0, -32514, 0, -9399, 0, -32556, 0, -9398, 0, -32445, 0, -9397, 0, -32438, 0, -9396, 0, -32430, 0, -9395, 0, -32433, 0, -9394, 0, -32441, 0, -9393, 0, -32451, 0, -9392, 0, -32435, 0, -9391, 0, -32454, 0, -9390, 0, -32282, 0, -9389, 0, -32274, 0, -9388, 0, -32265, 0, -9387, 0, -32264, 0, -9386, 0, -32263, 0, -9385, 0, -32252, 0, -9384, 0, -32196, 0, -9383, 0, -32195, 0, -9382, 0, -32193, 0, -9381, 0, -32139, 0, -9380, 0, -31941, 0, -9379, 0, -31793, 0, -9378, 0, -31751, 0, -9377, 0, -31709, 0, -9376, 0, -31808, 0, -9375, 0, -31768, 0, -9374, 0, -31726, 0, -9373, 0, -31769, 0, -9372, 0, -31772, 0, -9371, 0, -31748, 0, -9370, 0, -31754, 0, -9369, 0, -31728, 0, -9368, 0, -31802, 0, -9367, 0, -31800, 0, -9366, 0, -31765, 0, -9365, 0, -31773, 0, -9364, 0, -31809, 0, -9363, 0, -31743, 0, -9362, 0, -31779, 0, -9361, 0, -31771, 0, -9360, 0, -31784, 0, -9359, 0, -31745, 0, -9358, 0, -31775, 0, -9357, 0, -31797, 0, -9356, 0, -31794, 0, -9355, 0, -31786, 0, -9354, 0, -31755, 0, -9353, 0, -31799, 0, -9352, 0, -31735, 0, -9351, 0, -31729, 0, -9350, 0, -31778, 0, -9349, 0, -31727, 0, -9348, 0, -31738, 0, -9347, 0, -31806, 0, -9346, 0, -31757, 0, -9311, 0, -31787, 0, -9310, 0, -31750, 0, -9309, 0, -31801, 0, -9308, 0, -31791, 0, -9307, 0, -31766, 0, -9306, 0, -31725, 0, -9305, 0, -31805, 0, -9304, 0, -31764, 0, -9303, 0, -31762, 0, -9302, 0, -31804, 0, -9301, 0, -31749, 0, -9300, 0, -31785, 0, -9299, 0, -31774, 0, -9298, 0, -31717, 0, -9297, 0, -31781, 0, -9296, 0, -31746, 0, -9295, 0, -31016, 0, -9294, 0, -31006, 0, -9293, 0, -31002, 0, -9292, 0, -31021, 0, -9291, 0, -31005, 0, -9290, 0, -31014, 0, -9289, 0, -30998, 0, -9288, 0, -31011, 0, -9287, 0, -30997, 0, -9286, 0, -31012, 0, -9285, 0, -30996, 0, -9284, 0, -30999, 0, -9283, 0, -31017, 0, -9282, 0, -31000, 0, -9281, 0, -31023, 0, -9280, 0, -30648, 0, -9279, 0, -30634, 0, -9278, 0, -30635, 0, -9277, 0, -30534, 0, -9276, 0, -30505, 0, -9275, 0, -30535, 0, -9274, 0, -30536, 0, -9273, 0, -30528, 0, -9272, 0, -30530, 0, -9271, 0, -30538, 0, -9270, 0, -30532, 0, -9269, 0, -30537, 0, -9268, 0, -30531, 0, -9267, 0, -30542, 0, -9266, 0, -30463, 0, -9265, 0, -30519, 0, -9264, 0, -30315, 0, -9263, 0, -30312, 0, -9262, 0, -30313, 0, -9261, 0, -30243, 0, -9260, 0, -30246, 0, -9259, 0, -30245, 0, -9258, 0, -30130, 0, -9257, 0, -30131, 0, -9256, 0, -30151, 0, -9255, 0, -30119, 0, -9254, 0, -30144, 0, -9253, 0, -30121, 0, -9252, 0, -30120, 0, -9251, 0, -30140, 0, -9250, 0, -30139, 0, -9249, 0, -30126, 0, -9248, 0, -30136, 0, -9247, 0, -30127, 0, -9246, 0, -30134, 0, -9245, 0, -30132, 0, -9244, 0, -30129, 0, -9243, 0, -29601, 0, -9242, 0, -29567, 0, -9241, 0, -29568, 0, -9240, 0, -29510, 0, -9239, 0, -29506, 0, -9238, 0, -29520, 0, -9237, 0, -29511, 0, -9236, 0, -29515, 0, -9235, 0, -29308, 0, -9234, 0, -29312, 0, -9233, 0, -29303, 0, -9232, 0, -29224, 0, -9231, 0, -29229, 0, -9230, 0, -29235, 0, -9229, 0, -29241, 0, -9228, 0, -29226, 0, -9227, 0, -29220, 0, -9226, 0, -29233, 0, -9225, 0, -29227, 0, -9224, 0, -29223, 0, -9223, 0, -29240, 0, -9222, 0, -29225, 0, -9221, 0, -29243, 0, -9220, 0, -28945, 0, -9219, 0, -28937, 0, -9218, 0, -28934, 0, -9152, 0, -28935, 0, -9151, 0, -28954, 0, -9150, 0, -28946, 0, -9149, 0, -28955, 0, -9148, 0, -28939, 0, -9147, 0, -28953, 0, -9146, 0, -28952, 0, -9145, 0, -28938, 0, -9144, 0, -28949, 0, -9143, 0, -28943, 0, -9142, 0, -28948, 0, -9141, 0, -28940, 0, -9140, 0, -28951, 0, -9139, 0, -28627, 0, -9138, 0, -28620, 0, -9137, 0, -28625, 0, -9136, 0, -28410, 0, -9135, 0, -28372, 0, -9134, 0, -28412, 0, -9133, 0, -28417, 0, -9132, 0, -28420, 0, -9131, 0, -28408, 0, -9130, 0, -28423, 0, -9129, 0, -28421, 0, -9128, 0, -28415, 0, -9127, 0, -28416, 0, -9126, 0, -28409, 0, -9125, 0, -28411, 0, -9124, 0, -28413, 0, -9123, 0, -28319, 0, -9122, 0, -28316, 0, -9121, 0, -28321, 0, -9120, 0, -28318, 0, -9119, 0, -28320, 0, -9118, 0, -28159, 0, -9117, 0, -28150, 0, -9116, 0, -28123, 0, -9115, 0, -28157, 0, -9114, 0, -28134, 0, -9113, 0, -28122, 0, -9112, 0, -28145, 0, -9111, 0, -28148, 0, -9110, 0, -28160, 0, -9109, 0, -28142, 0, -9108, 0, -28161, 0, -9107, 0, -28163, 0, -9106, 0, -28154, 0, -9105, 0, -28156, 0, -9104, 0, -28121, 0, -9103, 0, -28158, 0, -9102, 0, -28132, 0, -9101, 0, -28124, 0, -9100, 0, -28135, 0, -9099, 0, -28137, 0, -9098, 0, -28155, 0, -9097, 0, -28138, 0, -9096, 0, -27269, 0, -9095, 0, -27251, 0, -9094, 0, -27252, 0, -9093, 0, -27248, 0, -9092, 0, -27001, 0, -9091, 0, -27010, 0, -9090, 0, -27000, 0, -9055, 0, -26999, 0, -9054, 0, -27005, 0, -9053, 0, -27008, 0, -9052, 0, -26942, 0, -9051, 0, -26936, 0, -9050, 0, -26941, 0, -9049, 0, -26895, 0, -9048, 0, -26896, 0, -9047, 0, -26772, 0, -9046, 0, -26768, 0, -9045, 0, -26770, 0, -9044, 0, -26617, 0, -9043, 0, -26455, 0, -9042, 0, -26389, 0, -9041, 0, -25370, 0, -9040, 0, -24839, 0, -9039, 0, 20099, 0, -9038, 0, 20100, 0, -9037, 0, 20150, 0, -9036, 0, 20669, 0, -9035, 0, 20671, 0, -9034, 0, 20678, 0, -9033, 0, 20654, 0, -9032, 0, 20676, 0, -9031, 0, 20682, 0, -9030, 0, 20660, 0, -9029, 0, 20680, 0, -9028, 0, 20674, 0, -9027, 0, 20656, 0, -9026, 0, 20673, 0, -9025, 0, 20666, 0, -9024, 0, 20657, 0, -9023, 0, 20683, 0, -9022, 0, 20681, 0, -9021, 0, 20662, 0, -9020, 0, 20664, 0, -9019, 0, 20951, 0, -9018, 0, 21114, 0, -9017, 0, 21112, 0, -9016, 0, 21115, 0, -9015, 0, 21116, 0, -9014, 0, 21955, 0, -9013, 0, 21979, 0, -9012, 0, 21964, 0, -9011, 0, 21968, 0, -9010, 0, 21963, 0, -9009, 0, 21962, 0, -9008, 0, 21981, 0, -9007, 0, 21952, 0, -9006, 0, 21972, 0, -9005, 0, 21956, 0, -9004, 0, 21993, 0, -9003, 0, 21951, 0, -9002, 0, 21970, 0, -9001, 0, 21901, 0, -9000, 0, 21967, 0, -8999, 0, 21973, 0, -8998, 0, 21986, 0, -8997, 0, 21974, 0, -8996, 0, 21960, 0, -8995, 0, 22002, 0, -8994, 0, 21965, 0, -8993, 0, 21977, 0, -8992, 0, 21954, 0, -8991, 0, 22292, 0, -8990, 0, 22611, 0, -8989, 0, 22632, 0, -8988, 0, 22628, 0, -8987, 0, 22607, 0, -8986, 0, 22605, 0, -8985, 0, 22601, 0, -8984, 0, 22639, 0, -8983, 0, 22613, 0, -8982, 0, 22606, 0, -8981, 0, 22621, 0, -8980, 0, 22617, 0, -8979, 0, 22629, 0, -8978, 0, 22619, 0, -8977, 0, 22589, 0, -8976, 0, 22627, 0, -8975, 0, 22641, 0, -8974, 0, 22780, 0, -8973, 0, 23239, 0, -8972, 0, 23236, 0, -8971, 0, 23243, 0, -8970, 0, 23226, 0, -8969, 0, 23224, 0, -8968, 0, 23217, 0, -8967, 0, 23221, 0, -8966, 0, 23216, 0, -8965, 0, 23231, 0, -8964, 0, 23240, 0, -8963, 0, 23227, 0, -8962, 0, 23238, 0, -8896, 0, 23223, 0, -8895, 0, 23232, 0, -8894, 0, 23242, 0, -8893, 0, 23220, 0, -8892, 0, 23222, 0, -8891, 0, 23245, 0, -8890, 0, 23225, 0, -8889, 0, 23184, 0, -8888, 0, 23510, 0, -8887, 0, 23512, 0, -8886, 0, 23513, 0, -8885, 0, 23583, 0, -8884, 0, 23603, 0, -8883, 0, 23921, 0, -8882, 0, 23907, 0, -8881, 0, 23882, 0, -8880, 0, 23909, 0, -8879, 0, 23922, 0, -8878, 0, 23916, 0, -8877, 0, 23902, 0, -8876, 0, 23912, 0, -8875, 0, 23911, 0, -8874, 0, 23906, 0, -8873, 0, 24048, 0, -8872, 0, 24143, 0, -8871, 0, 24142, 0, -8870, 0, 24138, 0, -8869, 0, 24141, 0, -8868, 0, 24139, 0, -8867, 0, 24261, 0, -8866, 0, 24268, 0, -8865, 0, 24262, 0, -8864, 0, 24267, 0, -8863, 0, 24263, 0, -8862, 0, 24384, 0, -8861, 0, 24495, 0, -8860, 0, 24493, 0, -8859, 0, 24823, 0, -8858, 0, 24905, 0, -8857, 0, 24906, 0, -8856, 0, 24875, 0, -8855, 0, 24901, 0, -8854, 0, 24886, 0, -8853, 0, 24882, 0, -8852, 0, 24878, 0, -8851, 0, 24902, 0, -8850, 0, 24879, 0, -8849, 0, 24911, 0, -8848, 0, 24873, 0, -8847, 0, 24896, 0, -8846, 0, 25120, 0, -8845, 0, -28312, 0, -8844, 0, 25123, 0, -8843, 0, 25125, 0, -8842, 0, 25124, 0, -8841, 0, 25541, 0, -8840, 0, 25585, 0, -8839, 0, 25579, 0, -8838, 0, 25616, 0, -8837, 0, 25618, 0, -8836, 0, 25609, 0, -8835, 0, 25632, 0, -8834, 0, 25636, 0, -8799, 0, 25651, 0, -8798, 0, 25667, 0, -8797, 0, 25631, 0, -8796, 0, 25621, 0, -8795, 0, 25624, 0, -8794, 0, 25657, 0, -8793, 0, 25655, 0, -8792, 0, 25634, 0, -8791, 0, 25635, 0, -8790, 0, 25612, 0, -8789, 0, 25638, 0, -8788, 0, 25648, 0, -8787, 0, 25640, 0, -8786, 0, 25665, 0, -8785, 0, 25653, 0, -8784, 0, 25647, 0, -8783, 0, 25610, 0, -8782, 0, 25626, 0, -8781, 0, 25664, 0, -8780, 0, 25637, 0, -8779, 0, 25639, 0, -8778, 0, 25611, 0, -8777, 0, 25575, 0, -8776, 0, 25627, 0, -8775, 0, 25646, 0, -8774, 0, 25633, 0, -8773, 0, 25614, 0, -8772, 0, 25967, 0, -8771, 0, 26002, 0, -8770, 0, 26067, 0, -8769, 0, 26246, 0, -8768, 0, 26252, 0, -8767, 0, 26261, 0, -8766, 0, 26256, 0, -8765, 0, 26251, 0, -8764, 0, 26250, 0, -8763, 0, 26265, 0, -8762, 0, 26260, 0, -8761, 0, 26232, 0, -8760, 0, 26400, 0, -8759, 0, 26982, 0, -8758, 0, 26975, 0, -8757, 0, 26936, 0, -8756, 0, 26958, 0, -8755, 0, 26978, 0, -8754, 0, 26993, 0, -8753, 0, 26943, 0, -8752, 0, 26949, 0, -8751, 0, 26986, 0, -8750, 0, 26937, 0, -8749, 0, 26946, 0, -8748, 0, 26967, 0, -8747, 0, 26969, 0, -8746, 0, 27002, 0, -8745, 0, 26952, 0, -8744, 0, 26953, 0, -8743, 0, 26933, 0, -8742, 0, 26988, 0, -8741, 0, 26931, 0, -8740, 0, 26941, 0, -8739, 0, 26981, 0, -8738, 0, 26864, 0, -8737, 0, 27000, 0, -8736, 0, 26932, 0, -8735, 0, 26985, 0, -8734, 0, 26944, 0, -8733, 0, 26991, 0, -8732, 0, 26948, 0, -8731, 0, 26998, 0, -8730, 0, 26968, 0, -8729, 0, 26945, 0, -8728, 0, 26996, 0, -8727, 0, 26956, 0, -8726, 0, 26939, 0, -8725, 0, 26955, 0, -8724, 0, 26935, 0, -8723, 0, 26972, 0, -8722, 0, 26959, 0, -8721, 0, 26961, 0, -8720, 0, 26930, 0, -8719, 0, 26962, 0, -8718, 0, 26927, 0, -8717, 0, 27003, 0, -8716, 0, 26940, 0, -8715, 0, 27462, 0, -8714, 0, 27461, 0, -8713, 0, 27459, 0, -8712, 0, 27458, 0, -8711, 0, 27464, 0, -8710, 0, 27457, 0, -8709, 0, 27547, 0, -8708, 0, -1523, 0, -8707, 0, 27643, 0, -8706, 0, 27644, 0, -8640, 0, 27641, 0, -8639, 0, 27639, 0, -8638, 0, 27640, 0, -8637, 0, 28315, 0, -8636, 0, 28374, 0, -8635, 0, 28360, 0, -8634, 0, 28303, 0, -8633, 0, 28352, 0, -8632, 0, 28319, 0, -8631, 0, 28307, 0, -8630, 0, 28308, 0, -8629, 0, 28320, 0, -8628, 0, 28337, 0, -8627, 0, 28345, 0, -8626, 0, 28358, 0, -8625, 0, 28370, 0, -8624, 0, 28349, 0, -8623, 0, 28353, 0, -8622, 0, 28318, 0, -8621, 0, 28361, 0, -8620, 0, 28343, 0, -8619, 0, 28336, 0, -8618, 0, 28365, 0, -8617, 0, 28326, 0, -8616, 0, 28367, 0, -8615, 0, 28338, 0, -8614, 0, 28350, 0, -8613, 0, 28355, 0, -8612, 0, 28380, 0, -8611, 0, 28376, 0, -8610, 0, 28313, 0, -8609, 0, 28306, 0, -8608, 0, 28302, 0, -8607, 0, 28301, 0, -8606, 0, 28324, 0, -8605, 0, 28321, 0, -8604, 0, 28351, 0, -8603, 0, 28339, 0, -8602, 0, 28368, 0, -8601, 0, 28362, 0, -8600, 0, 28311, 0, -8599, 0, 28334, 0, -8598, 0, 28323, 0, -8597, 0, 28999, 0, -8596, 0, 29012, 0, -8595, 0, 29010, 0, -8594, 0, 29027, 0, -8593, 0, 29024, 0, -8592, 0, 28993, 0, -8591, 0, 29021, 0, -8590, 0, 29026, 0, -8589, 0, 29042, 0, -8588, 0, 29048, 0, -8587, 0, 29034, 0, -8586, 0, 29025, 0, -8585, 0, 28994, 0, -8584, 0, 29016, 0, -8583, 0, 28995, 0, -8582, 0, 29003, 0, -8581, 0, 29040, 0, -8580, 0, 29023, 0, -8579, 0, 29008, 0, -8578, 0, 29011, 0, -8543, 0, 28996, 0, -8542, 0, 29005, 0, -8541, 0, 29018, 0, -8540, 0, 29263, 0, -8539, 0, 29325, 0, -8538, 0, 29324, 0, -8537, 0, 29329, 0, -8536, 0, 29328, 0, -8535, 0, 29326, 0, -8534, 0, 29500, 0, -8533, 0, 29506, 0, -8532, 0, 29499, 0, -8531, 0, 29498, 0, -8530, 0, 29504, 0, -8529, 0, 29514, 0, -8528, 0, 29513, 0, -8527, 0, 29764, 0, -8526, 0, 29770, 0, -8525, 0, 29771, 0, -8524, 0, 29778, 0, -8523, 0, 29777, 0, -8522, 0, 29783, 0, -8521, 0, 29760, 0, -8520, 0, 29775, 0, -8519, 0, 29776, 0, -8518, 0, 29774, 0, -8517, 0, 29762, 0, -8516, 0, 29766, 0, -8515, 0, 29773, 0, -8514, 0, 29780, 0, -8513, 0, 29921, 0, -8512, 0, 29951, 0, -8511, 0, 29950, 0, -8510, 0, 29949, 0, -8509, 0, 29981, 0, -8508, 0, 30073, 0, -8507, 0, 30071, 0, -8506, 0, 27011, 0, -8505, 0, 30191, 0, -8504, 0, 30223, 0, -8503, 0, 30211, 0, -8502, 0, 30199, 0, -8501, 0, 30206, 0, -8500, 0, 30204, 0, -8499, 0, 30201, 0, -8498, 0, 30200, 0, -8497, 0, 30224, 0, -8496, 0, 30203, 0, -8495, 0, 30198, 0, -8494, 0, 30189, 0, -8493, 0, 30197, 0, -8492, 0, 30205, 0, -8491, 0, 30361, 0, -8490, 0, 30389, 0, -8489, 0, 30429, 0, -8488, 0, 30549, 0, -8487, 0, 30559, 0, -8486, 0, 30560, 0, -8485, 0, 30546, 0, -8484, 0, 30550, 0, -8483, 0, 30554, 0, -8482, 0, 30569, 0, -8481, 0, 30567, 0, -8480, 0, 30548, 0, -8479, 0, 30553, 0, -8478, 0, 30573, 0, -8477, 0, 30688, 0, -8476, 0, 30855, 0, -8475, 0, 30874, 0, -8474, 0, 30868, 0, -8473, 0, 30863, 0, -8472, 0, 30852, 0, -8471, 0, 30869, 0, -8470, 0, 30853, 0, -8469, 0, 30854, 0, -8468, 0, 30881, 0, -8467, 0, 30851, 0, -8466, 0, 30841, 0, -8465, 0, 30873, 0, -8464, 0, 30848, 0, -8463, 0, 30870, 0, -8462, 0, 30843, 0, -8461, 0, 31100, 0, -8460, 0, 31106, 0, -8459, 0, 31101, 0, -8458, 0, 31097, 0, -8457, 0, 31249, 0, -8456, 0, 31256, 0, -8455, 0, 31257, 0, -8454, 0, 31250, 0, -8453, 0, 31255, 0, -8452, 0, 31253, 0, -8451, 0, 31266, 0, -8450, 0, 31251, 0, -8384, 0, 31259, 0, -8383, 0, 31248, 0, -8382, 0, 31395, 0, -8381, 0, 31394, 0, -8380, 0, 31390, 0, -8379, 0, 31467, 0, -8378, 0, 31590, 0, -8377, 0, 31588, 0, -8376, 0, 31597, 0, -8375, 0, 31604, 0, -8374, 0, 31593, 0, -8373, 0, 31602, 0, -8372, 0, 31589, 0, -8371, 0, 31603, 0, -8370, 0, 31601, 0, -8369, 0, 31600, 0, -8368, 0, 31585, 0, -8367, 0, 31608, 0, -8366, 0, 31606, 0, -8365, 0, 31587, 0, -8364, 0, 31922, 0, -8363, 0, 31924, 0, -8362, 0, 31919, 0, -8361, 0, 32136, 0, -8360, 0, 32134, 0, -8359, 0, 32128, 0, -8358, 0, 32141, 0, -8357, 0, 32127, 0, -8356, 0, 32133, 0, -8355, 0, 32122, 0, -8354, 0, 32142, 0, -8353, 0, 32123, 0, -8352, 0, 32131, 0, -8351, 0, 32124, 0, -8350, 0, 32140, 0, -8349, 0, 32148, 0, -8348, 0, 32132, 0, -8347, 0, 32125, 0, -8346, 0, 32146, 0, -8345, 0, 32621, 0, -8344, 0, 32619, 0, -8343, 0, 32615, 0, -8342, 0, 32616, 0, -8341, 0, 32620, 0, -8340, 0, 32678, 0, -8339, 0, 32677, 0, -8338, 0, 32679, 0, -8337, 0, 32731, 0, -8336, 0, 32732, 0, -8335, 0, -32735, 0, -8334, 0, -32412, 0, -8333, 0, -32416, 0, -8332, 0, -32393, 0, -8331, 0, -32420, 0, -8330, 0, -32407, 0, -8329, 0, -32421, 0, -8328, 0, -32414, 0, -8327, 0, -32398, 0, -8326, 0, 26401, 0, -8325, 0, -32418, 0, -8324, 0, -32394, 0, -8323, 0, -32409, 0, -8322, 0, -32401, 0, -8287, 0, -32444, 0, -8286, 0, -32415, 0, -8285, 0, -32227, 0, -8284, 0, -32183, 0, -8283, 0, -32188, 0, -8282, 0, -32192, 0, -8281, 0, -32190, 0, -8280, 0, -32187, 0, -8279, 0, -31503, 0, -8278, 0, -31681, 0, -8277, 0, -31658, 0, -8276, 0, -31626, 0, -8275, 0, -31623, 0, -8274, 0, -31601, 0, -8273, 0, -31603, 0, -8272, 0, -31643, 0, -8271, 0, -31663, 0, -8270, 0, -31680, 0, -8269, 0, -31610, 0, -8268, 0, -31641, 0, -8267, 0, -31696, 0, -8266, 0, -31667, 0, -8265, 0, -31619, 0, -8264, 0, -31654, 0, -8263, 0, -31655, 0, -8262, 0, -31628, 0, -8261, 0, -31629, 0, -8260, 0, -31651, 0, -8259, 0, -31481, 0, -8258, 0, -31650, 0, -8257, 0, -31689, 0, -8256, 0, -31686, 0, -8255, 0, -31692, 0, -8254, 0, -31622, 0, -8253, 0, -31677, 0, -8252, 0, -31624, 0, -8251, 0, -31694, 0, -8250, 0, -31675, 0, -8249, 0, -31703, 0, -8248, 0, -31783, 0, -8247, 0, -31669, 0, -8246, 0, -31697, 0, -8245, 0, -31678, 0, -8244, 0, -31699, 0, -8243, 0, -31649, 0, -8242, 0, -31632, 0, -8241, 0, -31687, 0, -8240, 0, -31666, 0, -8239, 0, -31668, 0, -8238, 0, -31662, 0, -8237, 0, -31633, 0, -8236, 0, -31547, 0, -8235, 0, -31602, 0, -8234, 0, -31685, 0, -8233, 0, -31673, 0, -8232, 0, -31690, 0, -8231, 0, -31693, 0, -8230, 0, -31640, 0, -8229, 0, -31618, 0, -8228, 0, -31676, 0, -8227, 0, -31701, 0, -8226, 0, -31648, 0, -8225, 0, -31660, 0, -8224, 0, -31634, 0, -8223, 0, -31664, 0, -8222, 0, -30965, 0, -8221, 0, -30972, 0, -8220, 0, -30985, 0, -8219, 0, -30964, 0, -8218, 0, -30982, 0, -8217, 0, -31018, 0, -8216, 0, -30987, 0, -8215, 0, -30899, 0, -8214, 0, -30984, 0, -8213, 0, -30962, 0, -8212, 0, -30967, 0, -8211, 0, -30975, 0, -8210, 0, -30986, 0, -8209, 0, -30963, 0, -8208, 0, -30971, 0, -8207, 0, -30506, 0, -8206, 0, -30517, 0, -8205, 0, -30515, 0, -8204, 0, -30514, 0, -8203, 0, -30498, 0, -8202, 0, -30501, 0, -8201, 0, -30502, 0, -8200, 0, -30516, 0, -8199, 0, -30512, 0, -8198, 0, -30331, 0, -8197, 0, -30309, 0, -8196, 0, -30241, 0, -8195, 0, -30235, 0, -8194, 0, -30236, 0, -8128, 0, -30239, 0, -8127, 0, -30240, 0, -8126, 0, -30238, 0, -8125, 0, -30244, 0, -8124, 0, -30234, 0, -8123, 0, -30090, 0, -8122, 0, -30074, 0, -8121, 0, -30081, 0, -8120, 0, -30111, 0, -8119, 0, -30145, 0, -8118, 0, -30089, 0, -8117, 0, -30078, 0, -8116, 0, -30076, 0, -8115, 0, -30091, 0, -8114, 0, -30077, 0, -8113, 0, -30079, 0, -8112, 0, -30092, 0, -8111, 0, -30086, 0, -8110, 0, -29636, 0, -8109, 0, -29621, 0, -8108, 0, -29622, 0, -8107, 0, -29595, 0, -8106, 0, -29596, 0, -8105, 0, -29594, 0, -8104, 0, -29562, 0, -8103, 0, -29564, 0, -8102, 0, -29563, 0, -8101, 0, -29492, 0, -8100, 0, -29336, 0, -8099, 0, -29335, 0, -8098, 0, -29295, 0, -8097, 0, -29300, 0, -8096, 0, -29298, 0, -8095, 0, -29297, 0, -8094, 0, -29299, 0, -8093, 0, -29293, 0, -8092, 0, -29292, 0, -8091, 0, -29296, 0, -8090, 0, -29294, 0, -8089, 0, -29200, 0, -8088, 0, -29216, 0, -8087, 0, -29204, 0, -8086, 0, -29199, 0, -8085, 0, -29202, 0, -8084, 0, -29232, 0, -8083, 0, -29207, 0, -8082, 0, -29213, 0, -8081, 0, -29214, 0, -8080, 0, -29209, 0, -8079, 0, -29198, 0, -8078, 0, -29205, 0, -8077, 0, -29196, 0, -8076, 0, -28922, 0, -8075, 0, -28929, 0, -8074, 0, -28927, 0, -8073, 0, -28928, 0, -8072, 0, -28923, 0, -8071, 0, -28921, 0, -8070, 0, -28920, 0, -8069, 0, -28926, 0, -8068, 0, -28917, 0, -8067, 0, -28590, 0, -8066, 0, -28609, 0, -8031, 0, -28604, 0, -8030, 0, -28599, 0, -8029, 0, -28611, 0, -8028, 0, -28400, 0, -8027, 0, -28403, 0, -8026, 0, -28401, 0, -8025, 0, -28399, 0, -8024, 0, -28394, 0, -8023, 0, -28396, 0, -8022, 0, -28405, 0, -8021, 0, -28402, 0, -8020, 0, -28306, 0, -8019, 0, -28305, 0, -8018, 0, -28088, 0, -8017, 0, -28078, 0, -8016, 0, -28112, 0, -8015, 0, -28102, 0, -8014, 0, -28058, 0, -8013, 0, -28109, 0, -8012, 0, -28059, 0, -8011, 0, -28066, 0, -8010, 0, -28029, 0, -8009, 0, -28114, 0, -8008, 0, -28086, 0, -8007, 0, -28090, 0, -8006, 0, -28051, 0, -8005, 0, -28052, 0, -8004, 0, -28081, 0, -8003, 0, -28064, 0, -8002, 0, -28057, 0, -8001, 0, -28049, 0, -8000, 0, -28106, 0, -7999, 0, -28063, 0, -7998, 0, -28048, 0, -7997, 0, -28111, 0, -7996, 0, -28076, 0, -7995, 0, -28061, 0, -7994, 0, -28080, 0, -7993, 0, -28046, 0, -7992, 0, -28082, 0, -7991, 0, -28077, 0, -7990, 0, -28084, 0, -7989, 0, -28074, 0, -7988, 0, -28110, 0, -7987, 0, -27233, 0, -7986, 0, -27236, 0, -7985, 0, -27234, 0, -7984, 0, -27237, 0, -7983, 0, -26990, 0, -7982, 0, -26989, 0, -7981, 0, -26991, 0, -7980, 0, -26985, 0, -7979, 0, -26930, 0, -7978, 0, -26886, 0, -7977, 0, -26883, 0, -7976, 0, -26888, 0, -7975, 0, -26891, 0, -7974, 0, -26765, 0, -7973, 0, -26761, 0, -7972, 0, -26760, 0, -7971, 0, -26766, 0, -7970, 0, -26609, 0, -7969, 0, -26611, 0, -7968, 0, -26610, 0, -7967, 0, -26452, 0, -7966, 0, -26378, 0, -7965, 0, -26375, 0, -7964, 0, -26193, 0, -7963, 0, -26190, 0, -7962, 0, -26192, 0, -7961, 0, -26187, 0, -7960, 0, -25939, 0, -7959, 0, -25941, 0, -7958, 0, -25765, 0, -7957, 0, -25366, 0, -7956, 0, -25363, 0, -7955, 0, -25369, 0, -7954, 0, -24960, 0, -7953, 0, -24835, 0, -7952, 0, 20710, 0, -7951, 0, 20692, 0, -7950, 0, 20695, 0, -7949, 0, 20712, 0, -7948, 0, 20723, 0, -7947, 0, 20699, 0, -7946, 0, 20714, 0, -7945, 0, 20701, 0, -7944, 0, 20708, 0, -7943, 0, 20691, 0, -7942, 0, 20716, 0, -7941, 0, 20720, 0, -7940, 0, 20719, 0, -7939, 0, 20707, 0, -7938, 0, 20704, 0, -7872, 0, 20952, 0, -7871, 0, 21120, 0, -7870, 0, 21121, 0, -7869, 0, 21225, 0, -7868, 0, 21227, 0, -7867, 0, 21296, 0, -7866, 0, 21420, 0, -7865, 0, 22055, 0, -7864, 0, 22037, 0, -7863, 0, 22028, 0, -7862, 0, 22034, 0, -7861, 0, 22012, 0, -7860, 0, 22031, 0, -7859, 0, 22044, 0, -7858, 0, 22017, 0, -7857, 0, 22035, 0, -7856, 0, 22018, 0, -7855, 0, 22010, 0, -7854, 0, 22045, 0, -7853, 0, 22020, 0, -7852, 0, 22015, 0, -7851, 0, 22009, 0, -7850, 0, 22665, 0, -7849, 0, 22652, 0, -7848, 0, 22672, 0, -7847, 0, 22680, 0, -7846, 0, 22662, 0, -7845, 0, 22657, 0, -7844, 0, 22655, 0, -7843, 0, 22644, 0, -7842, 0, 22667, 0, -7841, 0, 22650, 0, -7840, 0, 22663, 0, -7839, 0, 22673, 0, -7838, 0, 22670, 0, -7837, 0, 22646, 0, -7836, 0, 22658, 0, -7835, 0, 22664, 0, -7834, 0, 22651, 0, -7833, 0, 22676, 0, -7832, 0, 22671, 0, -7831, 0, 22782, 0, -7830, 0, 22891, 0, -7829, 0, 23260, 0, -7828, 0, 23278, 0, -7827, 0, 23269, 0, -7826, 0, 23253, 0, -7825, 0, 23274, 0, -7824, 0, 23258, 0, -7823, 0, 23277, 0, -7822, 0, 23275, 0, -7821, 0, 23283, 0, -7820, 0, 23266, 0, -7819, 0, 23264, 0, -7818, 0, 23259, 0, -7817, 0, 23276, 0, -7816, 0, 23262, 0, -7815, 0, 23261, 0, -7814, 0, 23257, 0, -7813, 0, 23272, 0, -7812, 0, 23263, 0, -7811, 0, 23415, 0, -7810, 0, 23520, 0, -7775, 0, 23523, 0, -7774, 0, 23651, 0, -7773, 0, 23938, 0, -7772, 0, 23936, 0, -7771, 0, 23933, 0, -7770, 0, 23942, 0, -7769, 0, 23930, 0, -7768, 0, 23937, 0, -7767, 0, 23927, 0, -7766, 0, 23946, 0, -7765, 0, 23945, 0, -7764, 0, 23944, 0, -7763, 0, 23934, 0, -7762, 0, 23932, 0, -7761, 0, 23949, 0, -7760, 0, 23929, 0, -7759, 0, 23935, 0, -7758, 0, 24152, 0, -7757, 0, 24153, 0, -7756, 0, 24147, 0, -7755, 0, 24280, 0, -7754, 0, 24273, 0, -7753, 0, 24279, 0, -7752, 0, 24270, 0, -7751, 0, 24284, 0, -7750, 0, 24277, 0, -7749, 0, 24281, 0, -7748, 0, 24274, 0, -7747, 0, 24276, 0, -7746, 0, 24388, 0, -7745, 0, 24387, 0, -7744, 0, 24431, 0, -7743, 0, 24502, 0, -7742, 0, 24876, 0, -7741, 0, 24872, 0, -7740, 0, 24897, 0, -7739, 0, 24926, 0, -7738, 0, 24945, 0, -7737, 0, 24947, 0, -7736, 0, 24914, 0, -7735, 0, 24915, 0, -7734, 0, 24946, 0, -7733, 0, 24940, 0, -7732, 0, 24960, 0, -7731, 0, 24948, 0, -7730, 0, 24916, 0, -7729, 0, 24954, 0, -7728, 0, 24923, 0, -7727, 0, 24933, 0, -7726, 0, 24891, 0, -7725, 0, 24938, 0, -7724, 0, 24929, 0, -7723, 0, 24918, 0, -7722, 0, 25129, 0, -7721, 0, 25127, 0, -7720, 0, 25131, 0, -7719, 0, 25643, 0, -7718, 0, 25677, 0, -7717, 0, 25691, 0, -7716, 0, 25693, 0, -7715, 0, 25716, 0, -7714, 0, 25718, 0, -7713, 0, 25714, 0, -7712, 0, 25715, 0, -7711, 0, 25725, 0, -7710, 0, 25717, 0, -7709, 0, 25702, 0, -7708, 0, 25766, 0, -7707, 0, 25678, 0, -7706, 0, 25730, 0, -7705, 0, 25694, 0, -7704, 0, 25692, 0, -7703, 0, 25675, 0, -7702, 0, 25683, 0, -7701, 0, 25696, 0, -7700, 0, 25680, 0, -7699, 0, 25727, 0, -7698, 0, 25663, 0, -7697, 0, 25708, 0, -7696, 0, 25707, 0, -7695, 0, 25689, 0, -7694, 0, 25701, 0, -7693, 0, 25719, 0, -7692, 0, 25971, 0, -7691, 0, 26016, 0, -7690, 0, 26273, 0, -7689, 0, 26272, 0, -7688, 0, 26271, 0, -7687, 0, 26373, 0, -7686, 0, 26372, 0, -7685, 0, 26402, 0, -7684, 0, 27057, 0, -7683, 0, 27062, 0, -7682, 0, 27081, 0, -7616, 0, 27040, 0, -7615, 0, 27086, 0, -7614, 0, 27030, 0, -7613, 0, 27056, 0, -7612, 0, 27052, 0, -7611, 0, 27068, 0, -7610, 0, 27025, 0, -7609, 0, 27033, 0, -7608, 0, 27022, 0, -7607, 0, 27047, 0, -7606, 0, 27021, 0, -7605, 0, 27049, 0, -7604, 0, 27070, 0, -7603, 0, 27055, 0, -7602, 0, 27071, 0, -7601, 0, 27076, 0, -7600, 0, 27069, 0, -7599, 0, 27044, 0, -7598, 0, 27092, 0, -7597, 0, 27065, 0, -7596, 0, 27082, 0, -7595, 0, 27034, 0, -7594, 0, 27087, 0, -7593, 0, 27059, 0, -7592, 0, 27027, 0, -7591, 0, 27050, 0, -7590, 0, 27041, 0, -7589, 0, 27038, 0, -7588, 0, 27097, 0, -7587, 0, 27031, 0, -7586, 0, 27024, 0, -7585, 0, 27074, 0, -7584, 0, 27061, 0, -7583, 0, 27045, 0, -7582, 0, 27078, 0, -7581, 0, 27466, 0, -7580, 0, 27469, 0, -7579, 0, 27467, 0, -7578, 0, 27550, 0, -7577, 0, 27551, 0, -7576, 0, 27552, 0, -7575, 0, 27587, 0, -7574, 0, 27588, 0, -7573, 0, 27646, 0, -7572, 0, 28366, 0, -7571, 0, 28405, 0, -7570, 0, 28401, 0, -7569, 0, 28419, 0, -7568, 0, 28453, 0, -7567, 0, 28408, 0, -7566, 0, 28471, 0, -7565, 0, 28411, 0, -7564, 0, 28462, 0, -7563, 0, 28425, 0, -7562, 0, 28494, 0, -7561, 0, 28441, 0, -7560, 0, 28442, 0, -7559, 0, 28455, 0, -7558, 0, 28440, 0, -7557, 0, 28475, 0, -7556, 0, 28434, 0, -7555, 0, 28397, 0, -7554, 0, 28426, 0, -7519, 0, 28470, 0, -7518, 0, 28531, 0, -7517, 0, 28409, 0, -7516, 0, 28398, 0, -7515, 0, 28461, 0, -7514, 0, 28480, 0, -7513, 0, 28464, 0, -7512, 0, 28476, 0, -7511, 0, 28469, 0, -7510, 0, 28395, 0, -7509, 0, 28423, 0, -7508, 0, 28430, 0, -7507, 0, 28483, 0, -7506, 0, 28421, 0, -7505, 0, 28413, 0, -7504, 0, 28406, 0, -7503, 0, 28473, 0, -7502, 0, 28444, 0, -7501, 0, 28412, 0, -7500, 0, 28474, 0, -7499, 0, 28447, 0, -7498, 0, 28429, 0, -7497, 0, 28446, 0, -7496, 0, 28424, 0, -7495, 0, 28449, 0, -7494, 0, 29063, 0, -7493, 0, 29072, 0, -7492, 0, 29065, 0, -7491, 0, 29056, 0, -7490, 0, 29061, 0, -7489, 0, 29058, 0, -7488, 0, 29071, 0, -7487, 0, 29051, 0, -7486, 0, 29062, 0, -7485, 0, 29057, 0, -7484, 0, 29079, 0, -7483, 0, 29252, 0, -7482, 0, 29267, 0, -7481, 0, 29335, 0, -7480, 0, 29333, 0, -7479, 0, 29331, 0, -7478, 0, 29507, 0, -7477, 0, 29517, 0, -7476, 0, 29521, 0, -7475, 0, 29516, 0, -7474, 0, 29794, 0, -7473, 0, 29811, 0, -7472, 0, 29809, 0, -7471, 0, 29813, 0, -7470, 0, 29810, 0, -7469, 0, 29799, 0, -7468, 0, 29806, 0, -7467, 0, 29952, 0, -7466, 0, 29954, 0, -7465, 0, 29955, 0, -7464, 0, 30077, 0, -7463, 0, 30096, 0, -7462, 0, 30230, 0, -7461, 0, 30216, 0, -7460, 0, 30220, 0, -7459, 0, 30229, 0, -7458, 0, 30225, 0, -7457, 0, 30218, 0, -7456, 0, 30228, 0, -7455, 0, 30392, 0, -7454, 0, 30593, 0, -7453, 0, 30588, 0, -7452, 0, 30597, 0, -7451, 0, 30594, 0, -7450, 0, 30574, 0, -7449, 0, 30592, 0, -7448, 0, 30575, 0, -7447, 0, 30590, 0, -7446, 0, 30595, 0, -7445, 0, 30898, 0, -7444, 0, 30890, 0, -7443, 0, 30900, 0, -7442, 0, 30893, 0, -7441, 0, 30888, 0, -7440, 0, 30846, 0, -7439, 0, 30891, 0, -7438, 0, 30878, 0, -7437, 0, 30885, 0, -7436, 0, 30880, 0, -7435, 0, 30892, 0, -7434, 0, 30882, 0, -7433, 0, 30884, 0, -7432, 0, 31128, 0, -7431, 0, 31114, 0, -7430, 0, 31115, 0, -7429, 0, 31126, 0, -7428, 0, 31125, 0, -7427, 0, 31124, 0, -7426, 0, 31123, 0, -7360, 0, 31127, 0, -7359, 0, 31112, 0, -7358, 0, 31122, 0, -7357, 0, 31120, 0, -7356, 0, 31275, 0, -7355, 0, 31306, 0, -7354, 0, 31280, 0, -7353, 0, 31279, 0, -7352, 0, 31272, 0, -7351, 0, 31270, 0, -7350, 0, 31400, 0, -7349, 0, 31403, 0, -7348, 0, 31404, 0, -7347, 0, 31470, 0, -7346, 0, 31624, 0, -7345, 0, 31644, 0, -7344, 0, 31626, 0, -7343, 0, 31633, 0, -7342, 0, 31632, 0, -7341, 0, 31638, 0, -7340, 0, 31629, 0, -7339, 0, 31628, 0, -7338, 0, 31643, 0, -7337, 0, 31630, 0, -7336, 0, 31621, 0, -7335, 0, 31640, 0, -7334, 0, 21124, 0, -7333, 0, 31641, 0, -7332, 0, 31652, 0, -7331, 0, 31618, 0, -7330, 0, 31931, 0, -7329, 0, 31935, 0, -7328, 0, 31932, 0, -7327, 0, 31930, 0, -7326, 0, 32167, 0, -7325, 0, 32183, 0, -7324, 0, 32194, 0, -7323, 0, 32163, 0, -7322, 0, 32170, 0, -7321, 0, 32193, 0, -7320, 0, 32192, 0, -7319, 0, 32197, 0, -7318, 0, 32157, 0, -7317, 0, 32206, 0, -7316, 0, 32196, 0, -7315, 0, 32198, 0, -7314, 0, 32203, 0, -7313, 0, 32204, 0, -7312, 0, 32175, 0, -7311, 0, 32185, 0, -7310, 0, 32150, 0, -7309, 0, 32188, 0, -7308, 0, 32159, 0, -7307, 0, 32166, 0, -7306, 0, 32174, 0, -7305, 0, 32169, 0, -7304, 0, 32161, 0, -7303, 0, 32201, 0, -7302, 0, 32627, 0, -7301, 0, 32738, 0, -7300, 0, 32739, 0, -7299, 0, 32741, 0, -7298, 0, 32734, 0, -7263, 0, -32732, 0, -7262, 0, -32675, 0, -7261, 0, -32676, 0, -7260, 0, -32375, 0, -7259, 0, -32378, 0, -7258, 0, -32381, 0, -7257, 0, -32377, 0, -7256, 0, -32371, 0, -7255, 0, -32372, 0, -7254, 0, -32373, 0, -7253, 0, -32235, 0, -7252, 0, -31593, 0, -7251, 0, -31580, 0, -7250, 0, -31583, 0, -7249, 0, -31585, 0, -7248, 0, -31558, 0, -7247, 0, -31538, 0, -7246, 0, -31550, 0, -7245, 0, -31572, 0, -7244, 0, -31570, 0, -7243, 0, -31573, 0, -7242, 0, -31559, 0, -7241, 0, -31564, 0, -7240, 0, -31551, 0, -7239, 0, -31539, 0, -7238, 0, -31574, 0, -7237, 0, -31590, 0, -7236, 0, -31567, 0, -7235, 0, -31536, 0, -7234, 0, -31587, 0, -7233, 0, -31577, 0, -7232, 0, -31557, 0, -7231, 0, -31582, 0, -7230, 0, -31596, 0, -7229, 0, -31545, 0, -7228, 0, -31540, 0, -7227, 0, -31589, 0, -7226, 0, -31575, 0, -7225, 0, -31569, 0, -7224, 0, -31576, 0, -7223, 0, -31530, 0, -7222, 0, -31592, 0, -7221, 0, -31562, 0, -7220, 0, -31537, 0, -7219, 0, -31584, 0, -7218, 0, -31529, 0, -7217, 0, -31532, 0, -7216, 0, -31534, 0, -7215, 0, -31525, 0, -7214, 0, -31568, 0, -7213, 0, -31599, 0, -7212, 0, -31135, 0, -7211, 0, -30925, 0, -7210, 0, -30941, 0, -7209, 0, -30936, 0, -7208, 0, -30869, 0, -7207, 0, -30912, 0, -7206, 0, -30930, 0, -7205, 0, -30946, 0, -7204, 0, -30943, 0, -7203, 0, -30951, 0, -7202, 0, -30949, 0, -7201, 0, -30909, 0, -7200, 0, -30932, 0, -7199, 0, -30911, 0, -7198, 0, -30914, 0, -7197, 0, -30906, 0, -7196, 0, -30944, 0, -7195, 0, -30926, 0, -7194, 0, -30934, 0, -7193, 0, -30931, 0, -7192, 0, -30916, 0, -7191, 0, -30958, 0, -7190, 0, -30918, 0, -7189, 0, -30927, 0, -7188, 0, -30923, 0, -7187, 0, -30910, 0, -7186, 0, -30938, 0, -7185, 0, -30937, 0, -7184, 0, -30920, 0, -7183, 0, -30940, 0, -7182, 0, -30950, 0, -7181, 0, -30928, 0, -7180, 0, -30959, 0, -7179, 0, -30473, 0, -7178, 0, -30489, 0, -7177, 0, -30479, 0, -7176, 0, -30478, 0, -7175, 0, -30470, 0, -7174, 0, -30466, 0, -7173, 0, -30482, 0, -7172, 0, -30468, 0, -7171, 0, -30474, 0, -7170, 0, -30469, 0, -7104, 0, -30480, 0, -7103, 0, -30484, 0, -7102, 0, -30485, 0, -7101, 0, -30307, 0, -7100, 0, -30303, 0, -7099, 0, -30305, 0, -7098, 0, -30306, 0, -7097, 0, -30231, 0, -7096, 0, -30229, 0, -7095, 0, -30232, 0, -7094, 0, -30037, 0, -7093, 0, -30055, 0, -7092, 0, -30069, 0, -7091, 0, -30062, 0, -7090, 0, -30065, 0, -7089, 0, -30058, 0, -7088, 0, -29635, 0, -7087, 0, -29592, 0, -7086, 0, -29591, 0, -7085, 0, -29483, 0, -7084, 0, -29489, 0, -7083, 0, -29481, 0, -7082, 0, -29290, 0, -7081, 0, -29175, 0, -7080, 0, -29182, 0, -7079, 0, -29185, 0, -7078, 0, -29171, 0, -7077, 0, -29187, 0, -7076, 0, -29174, 0, -7075, 0, -29181, 0, -7074, 0, -29177, 0, -7073, 0, -29178, 0, -7072, 0, -29179, 0, -7071, 0, -29186, 0, -7070, 0, -29184, 0, -7069, 0, -29180, 0, -7068, 0, -28912, 0, -7067, 0, -28911, 0, -7066, 0, -28914, 0, -7065, 0, -28915, 0, -7064, 0, -28381, 0, -7063, 0, -28388, 0, -7062, 0, -28384, 0, -7061, 0, -28382, 0, -7060, 0, -28385, 0, -7059, 0, -28387, 0, -7058, 0, -28390, 0, -7057, 0, -28380, 0, -7056, 0, -28383, 0, -7055, 0, -28389, 0, -7054, 0, -28294, 0, -7053, 0, -28302, 0, -7052, 0, -28295, 0, -7051, 0, -28301, 0, -7050, 0, -27995, 0, -7049, 0, -27996, 0, -7048, 0, -28042, 0, -7047, 0, -28005, 0, -7046, 0, -28038, 0, -7045, 0, -28000, 0, -7044, 0, -28012, 0, -7043, 0, -27990, 0, -7042, 0, -28019, 0, -7007, 0, -27994, 0, -7006, 0, -28006, 0, -7005, 0, -27989, 0, -7004, 0, -28039, 0, -7003, 0, -28009, 0, -7002, 0, -28033, 0, -7001, 0, -27997, 0, -7000, 0, -27922, 0, -6999, 0, -28018, 0, -6998, 0, -28030, 0, -6997, 0, -28011, 0, -6996, 0, -27998, 0, -6995, 0, -28035, 0, -6994, 0, -28024, 0, -6993, 0, -27999, 0, -6992, 0, -28022, 0, -6991, 0, -28026, 0, -6990, 0, -28020, 0, -6989, 0, -28007, 0, -6988, 0, -27993, 0, -6987, 0, -28034, 0, -6986, 0, -28025, 0, -6985, 0, -27991, 0, -6984, 0, -28003, 0, -6983, 0, -28021, 0, -6982, 0, -28115, 0, -6981, 0, -26978, 0, -6980, 0, -26975, 0, -6979, 0, -26881, 0, -6978, 0, -26792, 0, -6977, 0, -26755, 0, -6976, 0, -26758, 0, -6975, 0, -26754, 0, -6974, 0, -26749, 0, -6973, 0, -26752, 0, -6972, 0, -26750, 0, -6971, 0, -26757, 0, -6970, 0, -26748, 0, -6969, 0, -26751, 0, -6968, 0, -26753, 0, -6967, 0, -26674, 0, -6966, 0, -26675, 0, -6965, 0, -26602, 0, -6964, 0, -26451, 0, -6963, 0, -26450, 0, -6962, 0, -26366, 0, -6961, 0, -26368, 0, -6960, 0, -26361, 0, -6959, 0, -26211, 0, -6958, 0, -26212, 0, -6957, 0, -26173, 0, -6956, 0, -26183, 0, -6955, 0, -26181, 0, -6954, 0, -26182, 0, -6953, 0, -26174, 0, -6952, 0, -26179, 0, -6951, 0, -26169, 0, -6950, 0, -25935, 0, -6949, 0, -25885, 0, -6948, 0, -25881, 0, -6947, 0, -25794, 0, -6946, 0, -25793, 0, -6945, 0, -25760, 0, -6944, 0, -25759, 0, -6943, 0, -25761, 0, -6942, 0, -25359, 0, -6941, 0, -25358, 0, -6940, 0, -25355, 0, -6939, 0, -24921, 0, -6938, 0, 20735, 0, -6937, 0, 20739, 0, -6936, 0, 20784, 0, -6935, 0, 20728, 0, -6934, 0, 20742, 0, -6933, 0, 20743, 0, -6932, 0, 20726, 0, -6931, 0, 20734, 0, -6930, 0, 20747, 0, -6929, 0, 20748, 0, -6928, 0, 20733, 0, -6927, 0, 20746, 0, -6926, 0, 21131, 0, -6925, 0, 21132, 0, -6924, 0, 21233, 0, -6923, 0, 21231, 0, -6922, 0, 22088, 0, -6921, 0, 22082, 0, -6920, 0, 22092, 0, -6919, 0, 22069, 0, -6918, 0, 22081, 0, -6917, 0, 22090, 0, -6916, 0, 22089, 0, -6915, 0, 22086, 0, -6914, 0, 22104, 0, -6848, 0, 22106, 0, -6847, 0, 22080, 0, -6846, 0, 22067, 0, -6845, 0, 22077, 0, -6844, 0, 22060, 0, -6843, 0, 22078, 0, -6842, 0, 22072, 0, -6841, 0, 22058, 0, -6840, 0, 22074, 0, -6839, 0, 22298, 0, -6838, 0, 22699, 0, -6837, 0, 22685, 0, -6836, 0, 22705, 0, -6835, 0, 22688, 0, -6834, 0, 22691, 0, -6833, 0, 22703, 0, -6832, 0, 22700, 0, -6831, 0, 22693, 0, -6830, 0, 22689, 0, -6829, 0, 22783, 0, -6828, 0, 23295, 0, -6827, 0, 23284, 0, -6826, 0, 23293, 0, -6825, 0, 23287, 0, -6824, 0, 23286, 0, -6823, 0, 23299, 0, -6822, 0, 23288, 0, -6821, 0, 23298, 0, -6820, 0, 23289, 0, -6819, 0, 23297, 0, -6818, 0, 23303, 0, -6817, 0, 23301, 0, -6816, 0, 23311, 0, -6815, 0, 23655, 0, -6814, 0, 23961, 0, -6813, 0, 23959, 0, -6812, 0, 23967, 0, -6811, 0, 23954, 0, -6810, 0, 23970, 0, -6809, 0, 23955, 0, -6808, 0, 23957, 0, -6807, 0, 23968, 0, -6806, 0, 23964, 0, -6805, 0, 23969, 0, -6804, 0, 23962, 0, -6803, 0, 23966, 0, -6802, 0, 24169, 0, -6801, 0, 24157, 0, -6800, 0, 24160, 0, -6799, 0, 24156, 0, -6798, 0, 32243, 0, -6797, 0, 24283, 0, -6796, 0, 24286, 0, -6795, 0, 24289, 0, -6794, 0, 24393, 0, -6793, 0, 24498, 0, -6792, 0, 24971, 0, -6791, 0, 24963, 0, -6790, 0, 24953, 0, -6789, 0, 25009, 0, -6788, 0, 25008, 0, -6787, 0, 24994, 0, -6786, 0, 24969, 0, -6751, 0, 24987, 0, -6750, 0, 24979, 0, -6749, 0, 25007, 0, -6748, 0, 25005, 0, -6747, 0, 24991, 0, -6746, 0, 24978, 0, -6745, 0, 25002, 0, -6744, 0, 24993, 0, -6743, 0, 24973, 0, -6742, 0, 24934, 0, -6741, 0, 25011, 0, -6740, 0, 25133, 0, -6739, 0, 25710, 0, -6738, 0, 25712, 0, -6737, 0, 25750, 0, -6736, 0, 25760, 0, -6735, 0, 25733, 0, -6734, 0, 25751, 0, -6733, 0, 25756, 0, -6732, 0, 25743, 0, -6731, 0, 25739, 0, -6730, 0, 25738, 0, -6729, 0, 25740, 0, -6728, 0, 25763, 0, -6727, 0, 25759, 0, -6726, 0, 25704, 0, -6725, 0, 25777, 0, -6724, 0, 25752, 0, -6723, 0, 25974, 0, -6722, 0, 25978, 0, -6721, 0, 25977, 0, -6720, 0, 25979, 0, -6719, 0, 26034, 0, -6718, 0, 26035, 0, -6717, 0, 26293, 0, -6716, 0, 26288, 0, -6715, 0, 26281, 0, -6714, 0, 26290, 0, -6713, 0, 26295, 0, -6712, 0, 26282, 0, -6711, 0, 26287, 0, -6710, 0, 27136, 0, -6709, 0, 27142, 0, -6708, 0, 27159, 0, -6707, 0, 27109, 0, -6706, 0, 27128, 0, -6705, 0, 27157, 0, -6704, 0, 27121, 0, -6703, 0, 27108, 0, -6702, 0, 27168, 0, -6701, 0, 27135, 0, -6700, 0, 27116, 0, -6699, 0, 27106, 0, -6698, 0, 27163, 0, -6697, 0, 27165, 0, -6696, 0, 27134, 0, -6695, 0, 27175, 0, -6694, 0, 27122, 0, -6693, 0, 27118, 0, -6692, 0, 27156, 0, -6691, 0, 27127, 0, -6690, 0, 27111, 0, -6689, 0, 27200, 0, -6688, 0, 27144, 0, -6687, 0, 27110, 0, -6686, 0, 27131, 0, -6685, 0, 27149, 0, -6684, 0, 27132, 0, -6683, 0, 27115, 0, -6682, 0, 27145, 0, -6681, 0, 27140, 0, -6680, 0, 27160, 0, -6679, 0, 27173, 0, -6678, 0, 27151, 0, -6677, 0, 27126, 0, -6676, 0, 27174, 0, -6675, 0, 27143, 0, -6674, 0, 27124, 0, -6673, 0, 27158, 0, -6672, 0, 27473, 0, -6671, 0, 27557, 0, -6670, 0, 27555, 0, -6669, 0, 27554, 0, -6668, 0, 27558, 0, -6667, 0, 27649, 0, -6666, 0, 27648, 0, -6665, 0, 27647, 0, -6664, 0, 27650, 0, -6663, 0, 28481, 0, -6662, 0, 28454, 0, -6661, 0, 28542, 0, -6660, 0, 28551, 0, -6659, 0, 28614, 0, -6658, 0, 28562, 0, -6592, 0, 28557, 0, -6591, 0, 28553, 0, -6590, 0, 28556, 0, -6589, 0, 28514, 0, -6588, 0, 28495, 0, -6587, 0, 28549, 0, -6586, 0, 28506, 0, -6585, 0, 28566, 0, -6584, 0, 28534, 0, -6583, 0, 28524, 0, -6582, 0, 28546, 0, -6581, 0, 28501, 0, -6580, 0, 28530, 0, -6579, 0, 28498, 0, -6578, 0, 28496, 0, -6577, 0, 28503, 0, -6576, 0, 28564, 0, -6575, 0, 28563, 0, -6574, 0, 28509, 0, -6573, 0, 28416, 0, -6572, 0, 28513, 0, -6571, 0, 28523, 0, -6570, 0, 28541, 0, -6569, 0, 28519, 0, -6568, 0, 28560, 0, -6567, 0, 28499, 0, -6566, 0, 28555, 0, -6565, 0, 28521, 0, -6564, 0, 28543, 0, -6563, 0, 28565, 0, -6562, 0, 28515, 0, -6561, 0, 28535, 0, -6560, 0, 28522, 0, -6559, 0, 28539, 0, -6558, 0, 29106, 0, -6557, 0, 29103, 0, -6556, 0, 29083, 0, -6555, 0, 29104, 0, -6554, 0, 29088, 0, -6553, 0, 29082, 0, -6552, 0, 29097, 0, -6551, 0, 29109, 0, -6550, 0, 29085, 0, -6549, 0, 29093, 0, -6548, 0, 29086, 0, -6547, 0, 29092, 0, -6546, 0, 29089, 0, -6545, 0, 29098, 0, -6544, 0, 29084, 0, -6543, 0, 29095, 0, -6542, 0, 29107, 0, -6541, 0, 29336, 0, -6540, 0, 29338, 0, -6539, 0, 29528, 0, -6538, 0, 29522, 0, -6537, 0, 29534, 0, -6536, 0, 29535, 0, -6535, 0, 29536, 0, -6534, 0, 29533, 0, -6533, 0, 29531, 0, -6532, 0, 29537, 0, -6531, 0, 29530, 0, -6530, 0, 29529, 0, -6495, 0, 29538, 0, -6494, 0, 29831, 0, -6493, 0, 29833, 0, -6492, 0, 29834, 0, -6491, 0, 29830, 0, -6490, 0, 29825, 0, -6489, 0, 29821, 0, -6488, 0, 29829, 0, -6487, 0, 29832, 0, -6486, 0, 29820, 0, -6485, 0, 29817, 0, -6484, 0, 29960, 0, -6483, 0, 29959, 0, -6482, 0, 30078, 0, -6481, 0, 30245, 0, -6480, 0, 30238, 0, -6479, 0, 30233, 0, -6478, 0, 30237, 0, -6477, 0, 30236, 0, -6476, 0, 30243, 0, -6475, 0, 30234, 0, -6474, 0, 30248, 0, -6473, 0, 30235, 0, -6472, 0, 30364, 0, -6471, 0, 30365, 0, -6470, 0, 30366, 0, -6469, 0, 30363, 0, -6468, 0, 30605, 0, -6467, 0, 30607, 0, -6466, 0, 30601, 0, -6465, 0, 30600, 0, -6464, 0, 30925, 0, -6463, 0, 30907, 0, -6462, 0, 30927, 0, -6461, 0, 30924, 0, -6460, 0, 30929, 0, -6459, 0, 30926, 0, -6458, 0, 30932, 0, -6457, 0, 30920, 0, -6456, 0, 30915, 0, -6455, 0, 30916, 0, -6454, 0, 30921, 0, -6453, 0, 31130, 0, -6452, 0, 31137, 0, -6451, 0, 31136, 0, -6450, 0, 31132, 0, -6449, 0, 31138, 0, -6448, 0, 31131, 0, -6447, 0, 27510, 0, -6446, 0, 31289, 0, -6445, 0, 31410, 0, -6444, 0, 31412, 0, -6443, 0, 31411, 0, -6442, 0, 31671, 0, -6441, 0, 31691, 0, -6440, 0, 31678, 0, -6439, 0, 31660, 0, -6438, 0, 31694, 0, -6437, 0, 31663, 0, -6436, 0, 31673, 0, -6435, 0, 31690, 0, -6434, 0, 31669, 0, -6433, 0, 31941, 0, -6432, 0, 31944, 0, -6431, 0, 31948, 0, -6430, 0, 31947, 0, -6429, 0, 32247, 0, -6428, 0, 32219, 0, -6427, 0, 32234, 0, -6426, 0, 32231, 0, -6425, 0, 32215, 0, -6424, 0, 32225, 0, -6423, 0, 32259, 0, -6422, 0, 32250, 0, -6421, 0, 32230, 0, -6420, 0, 32246, 0, -6419, 0, 32241, 0, -6418, 0, 32240, 0, -6417, 0, 32238, 0, -6416, 0, 32223, 0, -6415, 0, 32630, 0, -6414, 0, 32684, 0, -6413, 0, 32688, 0, -6412, 0, 32685, 0, -6411, 0, 32749, 0, -6410, 0, 32747, 0, -6409, 0, 32746, 0, -6408, 0, 32748, 0, -6407, 0, 32742, 0, -6406, 0, 32744, 0, -6405, 0, -32668, 0, -6404, 0, -32665, 0, -6403, 0, -32349, 0, -6402, 0, -32353, 0, -6336, 0, -32354, 0, -6335, 0, -32363, 0, -6334, 0, -32350, 0, -6333, 0, -32359, 0, -6332, 0, -32361, 0, -6331, 0, -32234, 0, -6330, 0, -32177, 0, -6329, 0, -32173, 0, -6328, 0, -32174, 0, -6327, 0, -32176, 0, -6326, 0, -32178, 0, -6325, 0, -32175, 0, -6324, 0, -31452, 0, -6323, 0, -31429, 0, -6322, 0, -31473, 0, -6321, 0, -31488, 0, -6320, 0, -31447, 0, -6319, 0, -31474, 0, -6318, 0, -31479, 0, -6317, 0, -31475, 0, -6316, 0, -31457, 0, -6315, 0, -31478, 0, -6314, 0, -31449, 0, -6313, 0, -31460, 0, -6312, 0, -31493, 0, -6311, 0, -31445, 0, -6310, 0, -31494, 0, -6309, 0, -31480, 0, -6308, 0, -31476, 0, -6307, 0, -31500, 0, -6306, 0, -31446, 0, -6305, 0, -31502, 0, -6304, 0, -31467, 0, -6303, 0, -31497, 0, -6302, 0, -31509, 0, -6301, 0, -31501, 0, -6300, 0, -31492, 0, -6299, 0, -31470, 0, -6298, 0, -31510, 0, -6297, 0, -31511, 0, -6296, 0, -31466, 0, -6295, 0, -31490, 0, -6294, 0, -31448, 0, -6293, 0, -31459, 0, -6292, 0, -31442, 0, -6291, 0, -31486, 0, -6290, 0, -31491, 0, -6289, 0, -31458, 0, -6288, 0, -31498, 0, -6287, 0, -31439, 0, -6286, 0, -31450, 0, -6285, 0, -31513, 0, -6284, 0, -31512, 0, -6283, 0, -31504, 0, -6282, 0, -31505, 0, -6281, 0, -31495, 0, -6280, 0, -31464, 0, -6279, 0, -31456, 0, -6278, 0, -31440, 0, -6277, 0, -31477, 0, -6276, 0, -31463, 0, -6275, 0, -31441, 0, -6274, 0, -31134, 0, -6239, 0, -30890, 0, -6238, 0, -30877, 0, -6237, 0, -30876, 0, -6236, 0, -30857, 0, -6235, 0, -30751, 0, -6234, 0, -30861, 0, -6233, 0, -30888, 0, -6232, 0, -30892, 0, -6231, 0, -30885, 0, -6230, 0, -30894, 0, -6229, 0, -30879, 0, -6228, 0, -30886, 0, -6227, 0, -30895, 0, -6226, 0, -30882, 0, -6225, 0, -30867, 0, -6224, 0, -30870, 0, -6223, 0, -30896, 0, -6222, 0, -30898, 0, -6221, 0, -30881, 0, -6220, 0, -30883, 0, -6219, 0, -30865, 0, -6218, 0, -30868, 0, -6217, 0, -30854, 0, -6216, 0, -30866, 0, -6215, 0, -30884, 0, -6214, 0, -30875, 0, -6213, 0, -30897, 0, -6212, 0, -30853, 0, -6211, 0, -30859, 0, -6210, 0, -30878, 0, -6209, 0, -30873, 0, -6208, 0, -30871, 0, -6207, 0, -30630, 0, -6206, 0, -30459, 0, -6205, 0, -30452, 0, -6204, 0, -30444, 0, -6203, 0, -30453, 0, -6202, 0, -30441, 0, -6201, 0, -30440, 0, -6200, 0, -30439, 0, -6199, 0, -30458, 0, -6198, 0, -30442, 0, -6197, 0, -30447, 0, -6196, 0, -30450, 0, -6195, 0, -30455, 0, -6194, 0, -30302, 0, -6193, 0, -30300, 0, -6192, 0, -30301, 0, -6191, 0, -30227, 0, -6190, 0, -30224, 0, -6189, 0, -30228, 0, -6188, 0, -30001, 0, -6187, 0, -30010, 0, -6186, 0, -30024, 0, -6185, 0, -29997, 0, -6184, 0, -29999, 0, -6183, 0, -29996, 0, -6182, 0, -29995, 0, -6181, 0, -30021, 0, -6180, 0, -29993, 0, -6179, 0, -30018, 0, -6178, 0, -30016, 0, -6177, 0, -30011, 0, -6176, 0, -29992, 0, -6175, 0, -30013, 0, -6174, 0, -30022, 0, -6173, 0, -30019, 0, -6172, 0, -29991, 0, -6171, 0, -29634, 0, -6170, 0, -29619, 0, -6169, 0, -29553, 0, -6168, 0, -29467, 0, -6167, 0, -29473, 0, -6166, 0, -29479, 0, -6165, 0, -29464, 0, -6164, 0, -29478, 0, -6163, 0, -29475, 0, -6162, 0, -29465, 0, -6161, 0, -29280, 0, -6160, 0, -29284, 0, -6159, 0, -29279, 0, -6158, 0, -29285, 0, -6157, 0, -29152, 0, -6156, 0, -29149, 0, -6155, 0, -29147, 0, -6154, 0, -29148, 0, -6153, 0, -29138, 0, -6152, 0, -29163, 0, -6151, 0, -29157, 0, -6150, 0, -29162, 0, -6149, 0, -29167, 0, -6148, 0, -29159, 0, -6147, 0, -29146, 0, -6146, 0, -29145, 0, -6080, 0, -29164, 0, -6079, 0, -29166, 0, -6078, 0, -29160, 0, -6077, 0, -29165, 0, -6076, 0, -29156, 0, -6075, 0, -29161, 0, -6074, 0, -29158, 0, -6073, 0, -28884, 0, -6072, 0, -28892, 0, -6071, 0, -28904, 0, -6070, 0, -28902, 0, -6069, 0, -28896, 0, -6068, 0, -28893, 0, -6067, 0, -28906, 0, -6066, 0, -28905, 0, -6065, 0, -28557, 0, -6064, 0, -28560, 0, -6063, 0, -28561, 0, -6062, 0, -28569, 0, -6061, 0, -28565, 0, -6060, 0, -28369, 0, -6059, 0, -28373, 0, -6058, 0, -28375, 0, -6057, 0, -28374, 0, -6056, 0, -28366, 0, -6055, 0, -28378, 0, -6054, 0, -28370, 0, -6053, 0, -28283, 0, -6052, 0, -28282, 0, -6051, 0, -28278, 0, -6050, 0, -28287, 0, -6049, 0, -28286, 0, -6048, 0, -28284, 0, -6047, 0, -28288, 0, -6046, 0, -27952, 0, -6045, 0, -27965, 0, -6044, 0, -27964, 0, -6043, 0, -27968, 0, -6042, 0, -27943, 0, -6041, 0, -27978, 0, -6040, 0, -27953, 0, -6039, 0, -27919, 0, -6038, 0, -27937, 0, -6037, 0, -27944, 0, -6036, 0, -27927, 0, -6035, 0, -27945, 0, -6034, 0, -27939, 0, -6033, 0, -27956, 0, -6032, 0, -27921, 0, -6031, 0, -27966, 0, -6030, 0, -27928, 0, -6029, 0, -27958, 0, -6028, 0, -27960, 0, -6027, 0, -27954, 0, -6026, 0, -27930, 0, -6025, 0, -27955, 0, -6024, 0, -27947, 0, -6023, 0, -27959, 0, -6022, 0, -27936, 0, -6021, 0, -27938, 0, -6020, 0, -27929, 0, -6019, 0, -27951, 0, -6018, 0, -27949, 0, -5983, 0, -27979, 0, -5982, 0, -27935, 0, -5981, 0, -27962, 0, -5980, 0, -27980, 0, -5979, 0, -27268, 0, -5978, 0, -27220, 0, -5977, 0, -27221, 0, -5976, 0, -27218, 0, -5975, 0, -27216, 0, -5974, 0, -26972, 0, -5973, 0, -26974, 0, -5972, 0, -26925, 0, -5971, 0, -26875, 0, -5970, 0, -26872, 0, -5969, 0, -26878, 0, -5968, 0, -26790, 0, -5967, 0, -26742, 0, -5966, 0, -26738, 0, -5965, 0, -26744, 0, -5964, 0, -26672, 0, -5963, 0, -26673, 0, -5962, 0, -26594, 0, -5961, 0, -26595, 0, -5960, 0, -26586, 0, -5959, 0, -26583, 0, -5958, 0, -26584, 0, -5957, 0, -26592, 0, -5956, 0, -26597, 0, -5955, 0, -26585, 0, -5954, 0, -26446, 0, -5953, 0, -26360, 0, -5952, 0, -26374, 0, -5951, 0, -26351, 0, -5950, 0, -26348, 0, -5949, 0, -26346, 0, -5948, 0, -26345, 0, -5947, 0, -26347, 0, -5946, 0, -26148, 0, -5945, 0, -26163, 0, -5944, 0, -26161, 0, -5943, 0, -26157, 0, -5942, 0, -26156, 0, -5941, 0, -26162, 0, -5940, 0, -26167, 0, -5939, 0, -26154, 0, -5938, 0, -26152, 0, -5937, 0, -26165, 0, -5936, 0, -26153, 0, -5935, 0, -26164, 0, -5934, 0, -25933, 0, -5933, 0, -25876, 0, -5932, 0, -25877, 0, -5931, 0, -25869, 0, -5930, 0, -25870, 0, -5929, 0, -25871, 0, -5928, 0, -25786, 0, -5927, 0, -25789, 0, -5926, 0, -25753, 0, -5925, 0, -25740, 0, -5924, 0, -25743, 0, -5923, 0, -25754, 0, -5922, 0, -25738, 0, -5921, 0, -25739, 0, -5920, 0, -25744, 0, -5919, 0, -25752, 0, -5918, 0, -25756, 0, -5917, 0, -25748, 0, -5916, 0, -25348, 0, -5915, 0, -25350, 0, -5914, 0, -25347, 0, -5913, 0, -25345, 0, -5912, 0, -25353, 0, -5911, 0, -25337, 0, -5910, 0, -25344, 0, -5909, 0, -25351, 0, -5908, 0, -25349, 0, -5907, 0, -25336, 0, -5906, 0, -25339, 0, -5905, 0, -25340, 0, -5904, 0, -24957, 0, -5903, 0, -24877, 0, -5902, 0, -24817, 0, -5901, 0, -24816, 0, -5900, 0, 20764, 0, -5899, 0, 20755, 0, -5898, 0, 20759, 0, -5897, 0, 20762, 0, -5896, 0, 20753, 0, -5895, 0, 20958, 0, -5894, 0, 21300, 0, -5893, 0, 21473, 0, -5892, 0, 22128, 0, -5891, 0, 22112, 0, -5890, 0, 22126, 0, -5824, 0, 22131, 0, -5823, 0, 22118, 0, -5822, 0, 22115, 0, -5821, 0, 22125, 0, -5820, 0, 22130, 0, -5819, 0, 22110, 0, -5818, 0, 22135, 0, -5817, 0, 22300, 0, -5816, 0, 22299, 0, -5815, 0, 22728, 0, -5814, 0, 22717, 0, -5813, 0, 22729, 0, -5812, 0, 22719, 0, -5811, 0, 22714, 0, -5810, 0, 22722, 0, -5809, 0, 22716, 0, -5808, 0, 22726, 0, -5807, 0, 23319, 0, -5806, 0, 23321, 0, -5805, 0, 23323, 0, -5804, 0, 23329, 0, -5803, 0, 23316, 0, -5802, 0, 23315, 0, -5801, 0, 23312, 0, -5800, 0, 23318, 0, -5799, 0, 23336, 0, -5798, 0, 23322, 0, -5797, 0, 23328, 0, -5796, 0, 23326, 0, -5795, 0, 23535, 0, -5794, 0, 23980, 0, -5793, 0, 23985, 0, -5792, 0, 23977, 0, -5791, 0, 23975, 0, -5790, 0, 23989, 0, -5789, 0, 23984, 0, -5788, 0, 23982, 0, -5787, 0, 23978, 0, -5786, 0, 23976, 0, -5785, 0, 23986, 0, -5784, 0, 23981, 0, -5783, 0, 23983, 0, -5782, 0, 23988, 0, -5781, 0, 24167, 0, -5780, 0, 24168, 0, -5779, 0, 24166, 0, -5778, 0, 24175, 0, -5777, 0, 24297, 0, -5776, 0, 24295, 0, -5775, 0, 24294, 0, -5774, 0, 24296, 0, -5773, 0, 24293, 0, -5772, 0, 24395, 0, -5771, 0, 24508, 0, -5770, 0, 24989, 0, -5769, 0, 25000, 0, -5768, 0, 24982, 0, -5767, 0, 25029, 0, -5766, 0, 25012, 0, -5765, 0, 25030, 0, -5764, 0, 25025, 0, -5763, 0, 25036, 0, -5762, 0, 25018, 0, -5727, 0, 25023, 0, -5726, 0, 25016, 0, -5725, 0, 24972, 0, -5724, 0, 25815, 0, -5723, 0, 25814, 0, -5722, 0, 25808, 0, -5721, 0, 25807, 0, -5720, 0, 25801, 0, -5719, 0, 25789, 0, -5718, 0, 25737, 0, -5717, 0, 25795, 0, -5716, 0, 25819, 0, -5715, 0, 25843, 0, -5714, 0, 25817, 0, -5713, 0, 25907, 0, -5712, 0, 25983, 0, -5711, 0, 25980, 0, -5710, 0, 26018, 0, -5709, 0, 26312, 0, -5708, 0, 26302, 0, -5707, 0, 26304, 0, -5706, 0, 26314, 0, -5705, 0, 26315, 0, -5704, 0, 26319, 0, -5703, 0, 26301, 0, -5702, 0, 26299, 0, -5701, 0, 26298, 0, -5700, 0, 26316, 0, -5699, 0, 26403, 0, -5698, 0, 27188, 0, -5697, 0, 27238, 0, -5696, 0, 27209, 0, -5695, 0, 27239, 0, -5694, 0, 27186, 0, -5693, 0, 27240, 0, -5692, 0, 27198, 0, -5691, 0, 27229, 0, -5690, 0, 27245, 0, -5689, 0, 27254, 0, -5688, 0, 27227, 0, -5687, 0, 27217, 0, -5686, 0, 27176, 0, -5685, 0, 27226, 0, -5684, 0, 27195, 0, -5683, 0, 27199, 0, -5682, 0, 27201, 0, -5681, 0, 27242, 0, -5680, 0, 27236, 0, -5679, 0, 27216, 0, -5678, 0, 27215, 0, -5677, 0, 27220, 0, -5676, 0, 27247, 0, -5675, 0, 27241, 0, -5674, 0, 27232, 0, -5673, 0, 27196, 0, -5672, 0, 27230, 0, -5671, 0, 27222, 0, -5670, 0, 27221, 0, -5669, 0, 27213, 0, -5668, 0, 27214, 0, -5667, 0, 27206, 0, -5666, 0, 27477, 0, -5665, 0, 27476, 0, -5664, 0, 27478, 0, -5663, 0, 27559, 0, -5662, 0, 27562, 0, -5661, 0, 27563, 0, -5660, 0, 27592, 0, -5659, 0, 27591, 0, -5658, 0, 27652, 0, -5657, 0, 27651, 0, -5656, 0, 27654, 0, -5655, 0, 28589, 0, -5654, 0, 28619, 0, -5653, 0, 28579, 0, -5652, 0, 28615, 0, -5651, 0, 28604, 0, -5650, 0, 28622, 0, -5649, 0, 28616, 0, -5648, 0, 28510, 0, -5647, 0, 28612, 0, -5646, 0, 28605, 0, -5645, 0, 28574, 0, -5644, 0, 28618, 0, -5643, 0, 28584, 0, -5642, 0, 28676, 0, -5641, 0, 28581, 0, -5640, 0, 28590, 0, -5639, 0, 28602, 0, -5638, 0, 28588, 0, -5637, 0, 28586, 0, -5636, 0, 28623, 0, -5635, 0, 28607, 0, -5634, 0, 28600, 0, -5568, 0, 28578, 0, -5567, 0, 28617, 0, -5566, 0, 28587, 0, -5565, 0, 28621, 0, -5564, 0, 28591, 0, -5563, 0, 28594, 0, -5562, 0, 28592, 0, -5561, 0, 29125, 0, -5560, 0, 29122, 0, -5559, 0, 29119, 0, -5558, 0, 29112, 0, -5557, 0, 29142, 0, -5556, 0, 29120, 0, -5555, 0, 29121, 0, -5554, 0, 29131, 0, -5553, 0, 29140, 0, -5552, 0, 29130, 0, -5551, 0, 29127, 0, -5550, 0, 29135, 0, -5549, 0, 29117, 0, -5548, 0, 29144, 0, -5547, 0, 29116, 0, -5546, 0, 29126, 0, -5545, 0, 29146, 0, -5544, 0, 29147, 0, -5543, 0, 29341, 0, -5542, 0, 29342, 0, -5541, 0, 29545, 0, -5540, 0, 29542, 0, -5539, 0, 29543, 0, -5538, 0, 29548, 0, -5537, 0, 29541, 0, -5536, 0, 29547, 0, -5535, 0, 29546, 0, -5534, 0, 29823, 0, -5533, 0, 29850, 0, -5532, 0, 29856, 0, -5531, 0, 29844, 0, -5530, 0, 29842, 0, -5529, 0, 29845, 0, -5528, 0, 29857, 0, -5527, 0, 29963, 0, -5526, 0, 30080, 0, -5525, 0, 30255, 0, -5524, 0, 30253, 0, -5523, 0, 30257, 0, -5522, 0, 30269, 0, -5521, 0, 30259, 0, -5520, 0, 30268, 0, -5519, 0, 30261, 0, -5518, 0, 30258, 0, -5517, 0, 30256, 0, -5516, 0, 30395, 0, -5515, 0, 30438, 0, -5514, 0, 30618, 0, -5513, 0, 30621, 0, -5512, 0, 30625, 0, -5511, 0, 30620, 0, -5510, 0, 30619, 0, -5509, 0, 30626, 0, -5508, 0, 30627, 0, -5507, 0, 30613, 0, -5506, 0, 30617, 0, -5471, 0, 30615, 0, -5470, 0, 30941, 0, -5469, 0, 30953, 0, -5468, 0, 30949, 0, -5467, 0, 30954, 0, -5466, 0, 30942, 0, -5465, 0, 30947, 0, -5464, 0, 30939, 0, -5463, 0, 30945, 0, -5462, 0, 30946, 0, -5461, 0, 30957, 0, -5460, 0, 30943, 0, -5459, 0, 30944, 0, -5458, 0, 31140, 0, -5457, 0, 31300, 0, -5456, 0, 31304, 0, -5455, 0, 31303, 0, -5454, 0, 31414, 0, -5453, 0, 31416, 0, -5452, 0, 31413, 0, -5451, 0, 31409, 0, -5450, 0, 31415, 0, -5449, 0, 31710, 0, -5448, 0, 31715, 0, -5447, 0, 31719, 0, -5446, 0, 31709, 0, -5445, 0, 31701, 0, -5444, 0, 31717, 0, -5443, 0, 31706, 0, -5442, 0, 31720, 0, -5441, 0, 31737, 0, -5440, 0, 31700, 0, -5439, 0, 31722, 0, -5438, 0, 31714, 0, -5437, 0, 31708, 0, -5436, 0, 31723, 0, -5435, 0, 31704, 0, -5434, 0, 31711, 0, -5433, 0, 31954, 0, -5432, 0, 31956, 0, -5431, 0, 31959, 0, -5430, 0, 31952, 0, -5429, 0, 31953, 0, -5428, 0, 32274, 0, -5427, 0, 32289, 0, -5426, 0, 32279, 0, -5425, 0, 32268, 0, -5424, 0, 32287, 0, -5423, 0, 32288, 0, -5422, 0, 32275, 0, -5421, 0, 32270, 0, -5420, 0, 32284, 0, -5419, 0, 32277, 0, -5418, 0, 32282, 0, -5417, 0, 32290, 0, -5416, 0, 32267, 0, -5415, 0, 32271, 0, -5414, 0, 32278, 0, -5413, 0, 32269, 0, -5412, 0, 32276, 0, -5411, 0, 32293, 0, -5410, 0, 32292, 0, -5409, 0, 32579, 0, -5408, 0, 32635, 0, -5407, 0, 32636, 0, -5406, 0, 32634, 0, -5405, 0, 32689, 0, -5404, 0, 32751, 0, -5403, 0, -32726, 0, -5402, 0, -32727, 0, -5401, 0, -32660, 0, -5400, 0, -32335, 0, -5399, 0, -32346, 0, -5398, 0, -32338, 0, -5397, 0, -32327, 0, -5396, 0, -32331, 0, -5395, 0, -32341, 0, -5394, 0, -32336, 0, -5393, 0, -32340, 0, -5392, 0, -32332, 0, -5391, 0, -32334, 0, -5390, 0, -32329, 0, -5389, 0, -32345, 0, -5388, 0, -32270, 0, -5387, 0, -32171, 0, -5386, 0, -32170, 0, -5385, 0, -32169, 0, -5384, 0, -31402, 0, -5383, 0, -31419, 0, -5382, 0, -31381, 0, -5381, 0, -31411, 0, -5380, 0, -31405, 0, -5379, 0, -31391, 0, -5378, 0, -31400, 0, -5312, 0, -31424, 0, -5311, 0, -31418, 0, -5310, 0, -31388, 0, -5309, 0, -31423, 0, -5308, 0, -31390, 0, -5307, 0, -31420, 0, -5306, 0, -31407, 0, -5305, 0, -31417, 0, -5304, 0, -31389, 0, -5303, 0, -31426, 0, -5302, 0, -31397, 0, -5301, 0, -31375, 0, -5300, 0, -31410, 0, -5299, 0, -31378, 0, -5298, 0, -31371, 0, -5297, 0, -31403, 0, -5296, 0, -31385, 0, -5295, 0, -31392, 0, -5294, 0, -31348, 0, -5293, 0, -31386, 0, -5292, 0, -31395, 0, -5291, 0, -31404, 0, -5290, 0, -31387, 0, -5289, 0, -31380, 0, -5288, 0, -31133, 0, -5287, 0, -31131, 0, -5286, 0, -31132, 0, -5285, 0, -30821, 0, -5284, 0, -30833, 0, -5283, 0, -30825, 0, -5282, 0, -30829, 0, -5281, 0, -30830, 0, -5280, 0, -30840, 0, -5279, 0, -30847, 0, -5278, 0, -30826, 0, -5277, 0, -30824, 0, -5276, 0, -30855, 0, -5275, 0, -30841, 0, -5274, 0, -30813, 0, -5273, 0, -30843, 0, -5272, 0, -30832, 0, -5271, 0, -30831, 0, -5270, 0, -30819, 0, -5269, 0, -30844, 0, -5268, 0, -30828, 0, -5267, 0, -30820, 0, -5266, 0, -30822, 0, -5265, 0, -30839, 0, -5264, 0, -30434, 0, -5263, 0, -30426, 0, -5262, 0, -30416, 0, -5261, 0, -30419, 0, -5260, 0, -30418, 0, -5259, 0, -30425, 0, -5258, 0, -30415, 0, -5257, 0, -30430, 0, -5256, 0, -30423, 0, -5255, 0, -30429, 0, -5254, 0, -30417, 0, -5253, 0, -30420, 0, -5252, 0, -30433, 0, -5251, 0, -30223, 0, -5250, 0, -29984, 0, -5215, 0, -29982, 0, -5214, 0, -29966, 0, -5213, 0, -29964, 0, -5212, 0, -29963, 0, -5211, 0, -29987, 0, -5210, 0, -29932, 0, -5209, 0, -29980, 0, -5208, 0, -29985, 0, -5207, 0, -29968, 0, -5206, 0, -30008, 0, -5205, 0, -29986, 0, -5204, 0, -29983, 0, -5203, 0, -29976, 0, -5202, 0, -29953, 0, -5201, 0, -29969, 0, -5200, 0, -29957, 0, -5199, 0, -29551, 0, -5198, 0, -29550, 0, -5197, 0, -29552, 0, -5196, 0, -29451, 0, -5195, 0, -29458, 0, -5194, 0, -29455, 0, -5193, 0, -29456, 0, -5192, 0, -29453, 0, -5191, 0, -29332, 0, -5190, 0, -29330, 0, -5189, 0, -29275, 0, -5188, 0, -29273, 0, -5187, 0, -29133, 0, -5186, 0, -29122, 0, -5185, 0, -29128, 0, -5184, 0, -29120, 0, -5183, 0, -29115, 0, -5182, 0, -29130, 0, -5181, 0, -29124, 0, -5180, 0, -29123, 0, -5179, 0, -29119, 0, -5178, 0, -29136, 0, -5177, 0, -29121, 0, -5176, 0, -28995, 0, -5175, 0, -28874, 0, -5174, 0, -28882, 0, -5173, 0, -28875, 0, -5172, 0, -28878, 0, -5171, 0, -28871, 0, -5170, 0, -28873, 0, -5169, 0, -28876, 0, -5168, 0, -28554, 0, -5167, 0, -28551, 0, -5166, 0, -28549, 0, -5165, 0, -28538, 0, -5164, 0, -28422, 0, -5163, 0, -28365, 0, -5162, 0, -28363, 0, -5161, 0, -28362, 0, -5160, 0, -28269, 0, -5159, 0, -28272, 0, -5158, 0, -28271, 0, -5157, 0, -28275, 0, -5156, 0, -28273, 0, -5155, 0, -27865, 0, -5154, 0, -27874, 0, -5153, 0, -27896, 0, -5152, 0, -27873, 0, -5151, 0, -27898, 0, -5150, 0, -27889, 0, -5149, 0, -27782, 0, -5148, 0, -27848, 0, -5147, 0, -27844, 0, -5146, 0, -27877, 0, -5145, 0, -27869, 0, -5144, 0, -27886, 0, -5143, 0, -27903, 0, -5142, 0, -27834, 0, -5141, 0, -27859, 0, -5140, 0, -27890, 0, -5139, 0, -27891, 0, -5138, 0, -27957, 0, -5137, 0, -27875, 0, -5136, 0, -27910, 0, -5135, 0, -27867, 0, -5134, 0, -27885, 0, -5133, 0, -27911, 0, -5132, 0, -27913, 0, -5131, 0, -27852, 0, -5130, 0, -27902, 0, -5129, 0, -27868, 0, -5128, 0, -27905, 0, -5127, 0, -27863, 0, -5126, 0, -27847, 0, -5125, 0, -27851, 0, -5124, 0, -27862, 0, -5123, 0, -27884, 0, -5122, 0, -27892, 0, -5056, 0, -27893, 0, -5055, 0, -27906, 0, -5054, 0, -27895, 0, -5053, 0, -27904, 0, -5052, 0, -27909, 0, -5051, 0, -27882, 0, -5050, 0, -27204, 0, -5049, 0, -27187, 0, -5048, 0, -27202, 0, -5047, 0, -27207, 0, -5046, 0, -27206, 0, -5045, 0, -27210, 0, -5044, 0, -27201, 0, -5043, 0, -27211, 0, -5042, 0, -27203, 0, -5041, 0, -26967, 0, -5040, 0, -26924, 0, -5039, 0, -26869, 0, -5038, 0, -26862, 0, -5037, 0, -26864, 0, -5036, 0, -26727, 0, -5035, 0, -26729, 0, -5034, 0, -26732, 0, -5033, 0, -26640, 0, -5032, 0, -26632, 0, -5031, 0, -26571, 0, -5030, 0, -26577, 0, -5029, 0, -26574, 0, -5028, 0, -26332, 0, -5027, 0, -26337, 0, -5026, 0, -26329, 0, -5025, 0, -26327, 0, -5024, 0, -26210, 0, -5023, 0, -26130, 0, -5022, 0, -26132, 0, -5021, 0, -26139, 0, -5020, 0, -26140, 0, -5019, 0, -26128, 0, -5018, 0, -26141, 0, -5017, 0, -26134, 0, -5016, 0, -26135, 0, -5015, 0, -26137, 0, -5014, 0, -25927, 0, -5013, 0, -25921, 0, -5012, 0, -25932, 0, -5011, 0, -25925, 0, -5010, 0, -25866, 0, -5009, 0, -25862, 0, -5008, 0, -25863, 0, -5007, 0, -25865, 0, -5006, 0, -25805, 0, -5005, 0, -25728, 0, -5004, 0, -25723, 0, -5003, 0, -25721, 0, -5002, 0, -25732, 0, -5001, 0, -25730, 0, -5000, 0, -25733, 0, -4999, 0, -25726, 0, -4998, 0, -25709, 0, -4997, 0, -25710, 0, -4996, 0, -25712, 0, -4995, 0, -25734, 0, -4994, 0, -25707, 0, -4959, 0, -25731, 0, -4958, 0, -25720, 0, -4957, 0, -25307, 0, -4956, 0, -25321, 0, -4955, 0, -25312, 0, -4954, 0, -25314, 0, -4953, 0, -25324, 0, -4952, 0, -25303, 0, -4951, 0, -25315, 0, -4950, 0, -25320, 0, -4949, 0, -25310, 0, -4948, 0, -25328, 0, -4947, 0, -25319, 0, -4946, 0, -25313, 0, -4945, 0, -24952, 0, -4944, 0, -24954, 0, -4943, 0, -24953, 0, -4942, 0, -24914, 0, -4941, 0, -24915, 0, -4940, 0, -24875, 0, -4939, 0, -24874, 0, -4938, 0, -24838, 0, -4937, 0, -24814, 0, -4936, 0, -24771, 0, -4935, 0, 20774, 0, -4934, 0, 20773, 0, -4933, 0, 20770, 0, -4932, 0, 20772, 0, -4931, 0, 20768, 0, -4930, 0, 20777, 0, -4929, 0, 21236, 0, -4928, 0, 22163, 0, -4927, 0, 22156, 0, -4926, 0, 22157, 0, -4925, 0, 22150, 0, -4924, 0, 22148, 0, -4923, 0, 22147, 0, -4922, 0, 22142, 0, -4921, 0, 22146, 0, -4920, 0, 22143, 0, -4919, 0, 22145, 0, -4918, 0, 22742, 0, -4917, 0, 22740, 0, -4916, 0, 22735, 0, -4915, 0, 22738, 0, -4914, 0, 23341, 0, -4913, 0, 23333, 0, -4912, 0, 23346, 0, -4911, 0, 23331, 0, -4910, 0, 23340, 0, -4909, 0, 23335, 0, -4908, 0, 23334, 0, -4907, 0, 23343, 0, -4906, 0, 23342, 0, -4905, 0, 23419, 0, -4904, 0, 23537, 0, -4903, 0, 23538, 0, -4902, 0, 23991, 0, -4901, 0, 24172, 0, -4900, 0, 24170, 0, -4899, 0, 24510, 0, -4898, 0, 24507, 0, -4897, 0, 25027, 0, -4896, 0, 25013, 0, -4895, 0, 25020, 0, -4894, 0, 25063, 0, -4893, 0, 25056, 0, -4892, 0, 25061, 0, -4891, 0, 25060, 0, -4890, 0, 25064, 0, -4889, 0, 25054, 0, -4888, 0, 25839, 0, -4887, 0, 25833, 0, -4886, 0, 25827, 0, -4885, 0, 25835, 0, -4884, 0, 25828, 0, -4883, 0, 25832, 0, -4882, 0, 25985, 0, -4881, 0, 25984, 0, -4880, 0, 26038, 0, -4879, 0, 26074, 0, -4878, 0, 26322, 0, -4877, 0, 27277, 0, -4876, 0, 27286, 0, -4875, 0, 27265, 0, -4874, 0, 27301, 0, -4873, 0, 27273, 0, -4872, 0, 27295, 0, -4871, 0, 27291, 0, -4870, 0, 27297, 0, -4869, 0, 27294, 0, -4868, 0, 27271, 0, -4867, 0, 27283, 0, -4866, 0, 27278, 0, -4800, 0, 27285, 0, -4799, 0, 27267, 0, -4798, 0, 27304, 0, -4797, 0, 27300, 0, -4796, 0, 27281, 0, -4795, 0, 27263, 0, -4794, 0, 27302, 0, -4793, 0, 27290, 0, -4792, 0, 27269, 0, -4791, 0, 27276, 0, -4790, 0, 27282, 0, -4789, 0, 27483, 0, -4788, 0, 27565, 0, -4787, 0, 27657, 0, -4786, 0, 28620, 0, -4785, 0, 28585, 0, -4784, 0, 28660, 0, -4783, 0, 28628, 0, -4782, 0, 28643, 0, -4781, 0, 28636, 0, -4780, 0, 28653, 0, -4779, 0, 28647, 0, -4778, 0, 28646, 0, -4777, 0, 28638, 0, -4776, 0, 28658, 0, -4775, 0, 28637, 0, -4774, 0, 28642, 0, -4773, 0, 28648, 0, -4772, 0, 29153, 0, -4771, 0, 29169, 0, -4770, 0, 29160, 0, -4769, 0, 29170, 0, -4768, 0, 29156, 0, -4767, 0, 29168, 0, -4766, 0, 29154, 0, -4765, 0, 29555, 0, -4764, 0, 29550, 0, -4763, 0, 29551, 0, -4762, 0, 29847, 0, -4761, 0, 29874, 0, -4760, 0, 29867, 0, -4759, 0, 29840, 0, -4758, 0, 29866, 0, -4757, 0, 29869, 0, -4756, 0, 29873, 0, -4755, 0, 29861, 0, -4754, 0, 29871, 0, -4753, 0, 29968, 0, -4752, 0, 29969, 0, -4751, 0, 29970, 0, -4750, 0, 29967, 0, -4749, 0, 30084, 0, -4748, 0, 30275, 0, -4747, 0, 30280, 0, -4746, 0, 30281, 0, -4745, 0, 30279, 0, -4744, 0, 30372, 0, -4743, 0, 30441, 0, -4742, 0, 30645, 0, -4741, 0, 30635, 0, -4740, 0, 30642, 0, -4739, 0, 30647, 0, -4738, 0, 30646, 0, -4703, 0, 30644, 0, -4702, 0, 30641, 0, -4701, 0, 30632, 0, -4700, 0, 30704, 0, -4699, 0, 30963, 0, -4698, 0, 30973, 0, -4697, 0, 30978, 0, -4696, 0, 30971, 0, -4695, 0, 30972, 0, -4694, 0, 30962, 0, -4693, 0, 30981, 0, -4692, 0, 30969, 0, -4691, 0, 30974, 0, -4690, 0, 30980, 0, -4689, 0, 31147, 0, -4688, 0, 31144, 0, -4687, 0, 31324, 0, -4686, 0, 31323, 0, -4685, 0, 31318, 0, -4684, 0, 31320, 0, -4683, 0, 31316, 0, -4682, 0, 31322, 0, -4681, 0, 31422, 0, -4680, 0, 31424, 0, -4679, 0, 31425, 0, -4678, 0, 31749, 0, -4677, 0, 31759, 0, -4676, 0, 31730, 0, -4675, 0, 31744, 0, -4674, 0, 31743, 0, -4673, 0, 31739, 0, -4672, 0, 31758, 0, -4671, 0, 31732, 0, -4670, 0, 31755, 0, -4669, 0, 31731, 0, -4668, 0, 31746, 0, -4667, 0, 31753, 0, -4666, 0, 31747, 0, -4665, 0, 31745, 0, -4664, 0, 31736, 0, -4663, 0, 31741, 0, -4662, 0, 31750, 0, -4661, 0, 31728, 0, -4660, 0, 31729, 0, -4659, 0, 31760, 0, -4658, 0, 31754, 0, -4657, 0, 31976, 0, -4656, 0, 32301, 0, -4655, 0, 32316, 0, -4654, 0, 32322, 0, -4653, 0, 32307, 0, -4652, 0, -26552, 0, -4651, 0, 32312, 0, -4650, 0, 32298, 0, -4649, 0, 32329, 0, -4648, 0, 32320, 0, -4647, 0, 32327, 0, -4646, 0, 32297, 0, -4645, 0, 32332, 0, -4644, 0, 32304, 0, -4643, 0, 32315, 0, -4642, 0, 32310, 0, -4641, 0, 32324, 0, -4640, 0, 32314, 0, -4639, 0, 32581, 0, -4638, 0, 32639, 0, -4637, 0, 32638, 0, -4636, 0, 32637, 0, -4635, 0, 32756, 0, -4634, 0, 32754, 0, -4633, 0, -32724, 0, -4632, 0, -32325, 0, -4631, 0, -32316, 0, -4630, 0, -32308, 0, -4629, 0, -32310, 0, -4628, 0, -32315, 0, -4627, 0, -32313, 0, -4626, 0, -32324, 0, -4625, 0, -32279, 0, -4624, 0, -32165, 0, -4623, 0, -32166, 0, -4622, 0, -32164, 0, -4621, 0, -31357, 0, -4620, 0, -31360, 0, -4619, 0, -31345, 0, -4618, 0, -31321, 0, -4617, 0, -31339, 0, -4616, 0, -31328, 0, -4615, 0, -31349, 0, -4614, 0, -31325, 0, -4613, 0, -31365, 0, -4612, 0, -31324, 0, -4611, 0, -31334, 0, -4610, 0, -31330, 0, -4544, 0, -31369, 0, -4543, 0, -31364, 0, -4542, 0, -31351, 0, -4541, 0, -31327, 0, -4540, 0, -31366, 0, -4539, 0, -31368, 0, -4538, 0, -31401, 0, -4537, 0, -31346, 0, -4536, 0, -31338, 0, -4535, 0, -31354, 0, -4534, 0, -31347, 0, -4533, 0, -31335, 0, -4532, 0, -31331, 0, -4531, 0, -31359, 0, -4530, 0, -31326, 0, -4529, 0, -31358, 0, -4528, 0, -31352, 0, -4527, 0, -31355, 0, -4526, 0, -31367, 0, -4525, 0, -31370, 0, -4524, 0, -31336, 0, -4523, 0, -31344, 0, -4522, 0, -31329, 0, -4521, 0, -31128, 0, -4520, 0, -30786, 0, -4519, 0, -30806, 0, -4518, 0, -30803, 0, -4517, 0, -30779, 0, -4516, 0, -30800, 0, -4515, 0, -30804, 0, -4514, 0, -30791, 0, -4513, 0, -30795, 0, -4512, 0, -30788, 0, -4511, 0, -30802, 0, -4510, 0, -30775, 0, -4509, 0, -30781, 0, -4508, 0, -30782, 0, -4507, 0, -30772, 0, -4506, 0, -30793, 0, -4505, 0, -30801, 0, -4504, 0, -30780, 0, -4503, 0, -30774, 0, -4502, 0, -30796, 0, -4501, 0, -30794, 0, -4500, 0, -30785, 0, -4499, 0, -30792, 0, -4498, 0, -30787, 0, -4497, 0, -30754, 0, -4496, 0, -30798, 0, -4495, 0, -30411, 0, -4494, 0, -30413, 0, -4493, 0, -30404, 0, -4492, 0, -30402, 0, -4491, 0, -30399, 0, -4490, 0, -30382, 0, -4489, 0, -30409, 0, -4488, 0, -30398, 0, -4487, 0, -30291, 0, -4486, 0, -30289, 0, -4485, 0, -30290, 0, -4484, 0, -30222, 0, -4483, 0, -30221, 0, -4482, 0, -29922, 0, -4447, 0, -29928, 0, -4446, 0, -29930, 0, -4445, 0, -29935, 0, -4444, 0, -29947, 0, -4443, 0, -29941, 0, -4442, 0, -29918, 0, -4441, 0, -29937, 0, -4440, 0, -29934, 0, -4439, 0, -29931, 0, -4438, 0, -29945, 0, -4437, 0, -29939, 0, -4436, 0, -29944, 0, -4435, 0, -29946, 0, -4434, 0, -29924, 0, -4433, 0, -29933, 0, -4432, 0, -29926, 0, -4431, 0, -29617, 0, -4430, 0, -29584, 0, -4429, 0, -29582, 0, -4428, 0, -29583, 0, -4427, 0, -29585, 0, -4426, 0, -29547, 0, -4425, 0, -29548, 0, -4424, 0, -29447, 0, -4423, 0, -29329, 0, -4422, 0, -29106, 0, -4421, 0, -29107, 0, -4420, 0, -29101, 0, -4419, 0, -29104, 0, -4418, 0, -29108, 0, -4417, 0, -29113, 0, -4416, 0, -28861, 0, -4415, 0, -28864, 0, -4414, 0, -28539, 0, -4413, 0, -28546, 0, -4412, 0, -28360, 0, -4411, 0, -28262, 0, -4410, 0, -28254, 0, -4409, 0, -28261, 0, -4408, 0, -28263, 0, -4407, 0, -28257, 0, -4406, 0, -28255, 0, -4405, 0, -28259, 0, -4404, 0, -28256, 0, -4403, 0, -27743, 0, -4402, 0, -27773, 0, -4401, 0, -27729, 0, -4400, 0, -27804, 0, -4399, 0, -27818, 0, -4398, 0, -27833, 0, -4397, 0, -27780, 0, -4396, 0, -27816, 0, -4395, 0, -27812, 0, -4394, 0, -27786, 0, -4393, 0, -27831, 0, -4392, 0, -27824, 0, -4391, 0, -27823, 0, -4390, 0, -27808, 0, -4389, 0, -27795, 0, -4388, 0, -27761, 0, -4387, 0, -27828, 0, -4386, 0, -27798, 0, -4385, 0, -27783, 0, -4384, 0, -27817, 0, -4383, 0, -27819, 0, -4382, 0, -27822, 0, -4381, 0, -27825, 0, -4380, 0, -27791, 0, -4379, 0, -27785, 0, -4378, 0, -27781, 0, -4377, 0, -27807, 0, -4376, 0, -27810, 0, -4375, 0, -27805, 0, -4374, 0, -27801, 0, -4373, 0, -27776, 0, -4372, 0, -27826, 0, -4371, 0, -27815, 0, -4370, 0, -27193, 0, -4369, 0, -27200, 0, -4368, 0, -27191, 0, -4367, 0, -27197, 0, -4366, 0, -27195, 0, -4365, 0, -27209, 0, -4364, 0, -26962, 0, -4363, 0, -26960, 0, -4362, 0, -26964, 0, -4361, 0, -26848, 0, -4360, 0, -26849, 0, -4359, 0, -26856, 0, -4358, 0, -26851, 0, -4357, 0, -26855, 0, -4356, 0, -26726, 0, -4355, 0, -26719, 0, -4354, 0, -26724, 0, -4288, 0, -26722, 0, -4287, 0, -26723, 0, -4286, 0, -26667, 0, -4285, 0, -26668, 0, -4284, 0, -26639, 0, -4283, 0, -26559, 0, -4282, 0, -26556, 0, -4281, 0, -26550, 0, -4280, 0, -26551, 0, -4279, 0, -26555, 0, -4278, 0, -26557, 0, -4277, 0, -26331, 0, -4276, 0, -26325, 0, -4275, 0, -26324, 0, -4274, 0, -26326, 0, -4273, 0, -26317, 0, -4272, 0, -26318, 0, -4271, 0, -26321, 0, -4270, 0, -26323, 0, -4269, 0, -26319, 0, -4268, 0, -26320, 0, -4267, 0, -26216, 0, -4266, 0, -26205, 0, -4265, 0, -26207, 0, -4264, 0, -26110, 0, -4263, 0, -26118, 0, -4262, 0, -26124, 0, -4261, 0, -26121, 0, -4260, 0, -26119, 0, -4259, 0, -26120, 0, -4258, 0, -26122, 0, -4257, 0, -26117, 0, -4256, 0, -26115, 0, -4255, 0, -26114, 0, -4254, 0, -26116, 0, -4253, 0, -26109, 0, -4252, 0, -25922, 0, -4251, 0, -25858, 0, -4250, 0, -25859, 0, -4249, 0, -25855, 0, -4248, 0, -25860, 0, -4247, 0, -25784, 0, -4246, 0, -25702, 0, -4245, 0, -25688, 0, -4244, 0, -25698, 0, -4243, 0, -25701, 0, -4242, 0, -25690, 0, -4241, 0, -25695, 0, -4240, 0, -25691, 0, -4239, 0, -25692, 0, -4238, 0, -25722, 0, -4237, 0, -25694, 0, -4236, 0, -25696, 0, -4235, 0, -25681, 0, -4234, 0, -25293, 0, -4233, 0, -25279, 0, -4232, 0, -25241, 0, -4231, 0, -25290, 0, -4230, 0, -25298, 0, -4229, 0, -25297, 0, -4228, 0, -25295, 0, -4227, 0, -25288, 0, -4226, 0, -25296, 0, -4191, 0, -25275, 0, -4190, 0, -25278, 0, -4189, 0, -25277, 0, -4188, 0, -25282, 0, -4187, 0, -25289, 0, -4186, 0, -25280, 0, -4185, 0, -25283, 0, -4184, 0, 32757, 0, -4183, 0, -25299, 0, -4182, 0, -24950, 0, -4181, 0, -24951, 0, -4180, 0, -24947, 0, -4179, 0, -24912, 0, -4178, 0, -24888, 0, -4177, 0, -24870, 0, -4176, 0, -24837, 0, -4175, 0, -24833, 0, -4174, 0, -24796, 0, -4173, 0, -24797, 0, -4172, 0, -24798, 0, -4171, 0, -24748, 0, -4170, 0, -24672, 0, -4169, 0, 20785, 0, -4168, 0, 20781, 0, -4167, 0, 20782, 0, -4166, 0, 22168, 0, -4165, 0, 22172, 0, -4164, 0, 22167, 0, -4163, 0, 22170, 0, -4162, 0, 22173, 0, -4161, 0, 22169, 0, -4160, 0, 22896, 0, -4159, 0, 23356, 0, -4158, 0, 23657, 0, -4157, 0, 23658, 0, -4156, 0, 24000, 0, -4155, 0, 24173, 0, -4154, 0, 24174, 0, -4153, 0, 25048, 0, -4152, 0, 25055, 0, -4151, 0, 25069, 0, -4150, 0, 25070, 0, -4149, 0, 25073, 0, -4148, 0, 25066, 0, -4147, 0, 25072, 0, -4146, 0, 25067, 0, -4145, 0, 25046, 0, -4144, 0, 25065, 0, -4143, 0, 25855, 0, -4142, 0, 25860, 0, -4141, 0, 25853, 0, -4140, 0, 25848, 0, -4139, 0, 25857, 0, -4138, 0, 25859, 0, -4137, 0, 25852, 0, -4136, 0, 26004, 0, -4135, 0, 26075, 0, -4134, 0, 26330, 0, -4133, 0, 26331, 0, -4132, 0, 26328, 0, -4131, 0, 27333, 0, -4130, 0, 27321, 0, -4129, 0, 27325, 0, -4128, 0, 27361, 0, -4127, 0, 27334, 0, -4126, 0, 27322, 0, -4125, 0, 27318, 0, -4124, 0, 27319, 0, -4123, 0, 27335, 0, -4122, 0, 27316, 0, -4121, 0, 27309, 0, -4120, 0, 27486, 0, -4119, 0, 27593, 0, -4118, 0, 27659, 0, -4117, 0, 28679, 0, -4116, 0, 28684, 0, -4115, 0, 28685, 0, -4114, 0, 28673, 0, -4113, 0, 28677, 0, -4112, 0, 28692, 0, -4111, 0, 28686, 0, -4110, 0, 28671, 0, -4109, 0, 28672, 0, -4108, 0, 28667, 0, -4107, 0, 28710, 0, -4106, 0, 28668, 0, -4105, 0, 28663, 0, -4104, 0, 28682, 0, -4103, 0, 29185, 0, -4102, 0, 29183, 0, -4101, 0, 29177, 0, -4100, 0, 29187, 0, -4099, 0, 29181, 0, -4098, 0, 29558, 0, -4032, 0, 29880, 0, -4031, 0, 29888, 0, -4030, 0, 29877, 0, -4029, 0, 29889, 0, -4028, 0, 29886, 0, -4027, 0, 29878, 0, -4026, 0, 29883, 0, -4025, 0, 29890, 0, -4024, 0, 29972, 0, -4023, 0, 29971, 0, -4022, 0, 30300, 0, -4021, 0, 30308, 0, -4020, 0, 30297, 0, -4019, 0, 30288, 0, -4018, 0, 30291, 0, -4017, 0, 30295, 0, -4016, 0, 30298, 0, -4015, 0, 30374, 0, -4014, 0, 30397, 0, -4013, 0, 30444, 0, -4012, 0, 30658, 0, -4011, 0, 30650, 0, -4010, 0, 30975, 0, -4009, 0, 30988, 0, -4008, 0, 30995, 0, -4007, 0, 30996, 0, -4006, 0, 30985, 0, -4005, 0, 30992, 0, -4004, 0, 30994, 0, -4003, 0, 30993, 0, -4002, 0, 31149, 0, -4001, 0, 31148, 0, -4000, 0, 31327, 0, -3999, 0, 31772, 0, -3998, 0, 31785, 0, -3997, 0, 31769, 0, -3996, 0, 31776, 0, -3995, 0, 31775, 0, -3994, 0, 31789, 0, -3993, 0, 31773, 0, -3992, 0, 31782, 0, -3991, 0, 31784, 0, -3990, 0, 31778, 0, -3989, 0, 31781, 0, -3988, 0, 31792, 0, -3987, 0, 32348, 0, -3986, 0, 32336, 0, -3985, 0, 32342, 0, -3984, 0, 32355, 0, -3983, 0, 32344, 0, -3982, 0, 32354, 0, -3981, 0, 32351, 0, -3980, 0, 32337, 0, -3979, 0, 32352, 0, -3978, 0, 32343, 0, -3977, 0, 32339, 0, -3976, 0, 32693, 0, -3975, 0, 32691, 0, -3974, 0, 32759, 0, -3973, 0, 32760, 0, -3972, 0, -32651, 0, -3971, 0, -32303, 0, -3970, 0, -32302, 0, -3935, 0, -32304, 0, -3934, 0, -32161, 0, -3933, 0, -32162, 0, -3932, 0, -31308, 0, -3931, 0, -31290, 0, -3930, 0, -31296, 0, -3929, 0, -31293, 0, -3928, 0, -31294, 0, -3927, 0, -31309, 0, -3926, 0, -31307, 0, -3925, 0, -31299, 0, -3924, 0, -31289, 0, -3923, 0, -31292, 0, -3922, 0, -31297, 0, -3921, 0, -31285, 0, -3920, 0, -31282, 0, -3919, 0, -31288, 0, -3918, 0, -31291, 0, -3917, 0, -31311, 0, -3916, 0, -31306, 0, -3915, 0, -31278, 0, -3914, 0, -31196, 0, -3913, 0, -31304, 0, -3912, 0, -31305, 0, -3911, 0, -31298, 0, -3910, 0, -31127, 0, -3909, 0, -30745, 0, -3908, 0, -30746, 0, -3907, 0, -30750, 0, -3906, 0, -30757, 0, -3905, 0, -30741, 0, -3904, 0, -30742, 0, -3903, 0, -30747, 0, -3902, 0, -30753, 0, -3901, 0, -30733, 0, -3900, 0, -30748, 0, -3899, 0, -30764, 0, -3898, 0, -30756, 0, -3897, 0, -30765, 0, -3896, 0, -30739, 0, -3895, 0, -30760, 0, -3894, 0, -30749, 0, -3893, 0, -30812, 0, -3892, 0, -30761, 0, -3891, 0, -30759, 0, -3890, 0, -30719, 0, -3889, 0, -30732, 0, -3888, 0, -30744, 0, -3887, 0, -30755, 0, -3886, 0, -30381, 0, -3885, 0, -30389, 0, -3884, 0, -30385, 0, -3883, 0, -30388, 0, -3882, 0, -30394, 0, -3881, 0, -30384, 0, -3880, 0, -30383, 0, -3879, 0, -30391, 0, -3878, 0, -29910, 0, -3877, 0, -29913, 0, -3876, 0, -29917, 0, -3875, 0, -29901, 0, -3874, 0, -29904, 0, -3873, 0, -29899, 0, -3872, 0, -29881, 0, -3871, 0, -29905, 0, -3870, 0, -29892, 0, -3869, 0, -29890, 0, -3868, 0, -29903, 0, -3867, 0, -29915, 0, -3866, 0, -29897, 0, -3865, 0, -29914, 0, -3864, 0, -29898, 0, -3863, 0, -29906, 0, -3862, 0, -29916, 0, -3861, 0, -29893, 0, -3860, 0, -29891, 0, -3859, 0, -29894, 0, -3858, 0, -29630, 0, -3857, 0, -29579, 0, -3856, 0, -29543, 0, -3855, 0, -29544, 0, -3854, 0, -29545, 0, -3853, 0, -29442, 0, -3852, 0, -29436, 0, -3851, 0, -29438, 0, -3850, 0, -29440, 0, -3849, 0, -29092, 0, -3848, 0, -29086, 0, -3847, 0, -29088, 0, -3846, 0, -29097, 0, -3845, 0, -29098, 0, -3844, 0, -29090, 0, -3843, 0, -29083, 0, -3842, 0, -29081, 0, -3776, 0, -29093, 0, -3775, 0, -29094, 0, -3774, 0, -29087, 0, -3773, 0, -29091, 0, -3772, 0, -29079, 0, -3771, 0, -29100, 0, -3770, 0, -28858, 0, -3769, 0, -28857, 0, -3768, 0, -28856, 0, -3767, 0, -28853, 0, -3766, 0, -28376, 0, -3765, 0, -28358, 0, -3764, 0, -28357, 0, -3763, 0, -28354, 0, -3762, 0, -28248, 0, -3761, 0, -28251, 0, -3760, 0, -28249, 0, -3759, 0, -28241, 0, -3758, 0, -28246, 0, -3757, 0, -27723, 0, -3756, 0, -27764, 0, -3755, 0, -27758, 0, -3754, 0, -27721, 0, -3753, 0, -27749, 0, -3752, 0, -27747, 0, -3751, 0, -27767, 0, -3750, 0, -27737, 0, -3749, 0, -27762, 0, -3748, 0, -27734, 0, -3747, 0, -27746, 0, -3746, 0, -27738, 0, -3745, 0, -27755, 0, -3744, 0, -27768, 0, -3743, 0, -27751, 0, -3742, 0, -27745, 0, -3741, 0, -27763, 0, -3740, 0, -27727, 0, -3739, 0, -27759, 0, -3738, 0, -27726, 0, -3737, 0, -27740, 0, -3736, 0, -27736, 0, -3735, 0, -27724, 0, -3734, 0, -27741, 0, -3733, 0, -27739, 0, -3732, 0, -27182, 0, -3731, 0, -27181, 0, -3730, 0, -27183, 0, -3729, 0, -26957, 0, -3728, 0, -26921, 0, -3727, 0, -26918, 0, -3726, 0, 24002, 0, -3725, 0, -26913, 0, -3724, 0, -26920, 0, -3723, 0, -26915, 0, -3722, 0, -26845, 0, -3721, 0, -26846, 0, -3720, 0, -26843, 0, -3719, 0, -26708, 0, -3718, 0, -26706, 0, -3717, 0, -26712, 0, -3716, 0, -26709, 0, -3715, 0, -26716, 0, -3714, 0, -26710, 0, -3679, 0, -26718, 0, -3678, 0, -26715, 0, -3677, 0, -26665, 0, -3676, 0, -26663, 0, -3675, 0, -26666, 0, -3674, 0, -26664, 0, -3673, 0, -26630, 0, -3672, 0, -26544, 0, -3671, 0, -26543, 0, -3670, 0, -26542, 0, -3669, 0, -26440, 0, -3668, 0, -26303, 0, -3667, 0, -26308, 0, -3666, 0, -26310, 0, -3665, 0, -26097, 0, -3664, 0, -26101, 0, -3663, 0, -26103, 0, -3662, 0, -26099, 0, -3661, 0, -26108, 0, -3660, 0, -26095, 0, -3659, 0, -26102, 0, -3658, 0, -26107, 0, -3657, 0, -26105, 0, -3656, 0, -26106, 0, -3655, 0, -25920, 0, -3654, 0, -25892, 0, -3653, 0, -25848, 0, -3652, 0, -25852, 0, -3651, 0, -25851, 0, -3650, 0, -25815, 0, -3649, 0, -25803, 0, -3648, 0, -25782, 0, -3647, 0, -25780, 0, -3646, 0, -25781, 0, -3645, 0, -25657, 0, -3644, 0, -25658, 0, -3643, 0, -25661, 0, -3642, 0, -25665, 0, -3641, 0, -25663, 0, -3640, 0, -25675, 0, -3639, 0, -25672, 0, -3638, 0, -25645, 0, -3637, 0, -25674, 0, -3636, 0, -25660, 0, -3635, 0, -25671, 0, -3634, 0, -25667, 0, -3633, 0, -25252, 0, -3632, 0, -25261, 0, -3631, 0, -25265, 0, -3630, 0, -25270, 0, -3629, 0, -25253, 0, -3628, 0, -25269, 0, -3627, 0, -25255, 0, -3626, 0, -25258, 0, -3625, 0, -25268, 0, -3624, 0, -25257, 0, -3623, 0, -25262, 0, -3622, 0, -25260, 0, -3621, 0, -25249, 0, -3620, 0, -25256, 0, -3619, 0, -25254, 0, -3618, 0, -24946, 0, -3617, 0, -24948, 0, -3616, 0, -24865, 0, -3615, 0, -24831, 0, -3614, 0, -24832, 0, -3613, 0, -24810, 0, -3612, 0, -24795, 0, -3611, 0, -24789, 0, -3610, 0, -24790, 0, -3609, 0, -24791, 0, -3608, 0, -24792, 0, -3607, 0, -24756, 0, -3606, 0, -24747, 0, -3605, 0, 20788, 0, -3604, 0, 20789, 0, -3603, 0, 21142, 0, -3602, 0, 21239, 0, -3601, 0, 21428, 0, -3600, 0, 22187, 0, -3599, 0, 22189, 0, -3598, 0, 22182, 0, -3597, 0, 22183, 0, -3596, 0, 22186, 0, -3595, 0, 22188, 0, -3594, 0, 22746, 0, -3593, 0, 22749, 0, -3592, 0, 22747, 0, -3591, 0, 22802, 0, -3590, 0, 23357, 0, -3589, 0, 23358, 0, -3588, 0, 23359, 0, -3587, 0, 24003, 0, -3586, 0, 24176, 0, -3520, 0, 24511, 0, -3519, 0, 25083, 0, -3518, 0, 25863, 0, -3517, 0, 25872, 0, -3516, 0, 25869, 0, -3515, 0, 25865, 0, -3514, 0, 25868, 0, -3513, 0, 25870, 0, -3512, 0, 25988, 0, -3511, 0, 26078, 0, -3510, 0, 26077, 0, -3509, 0, 26334, 0, -3508, 0, 27367, 0, -3507, 0, 27360, 0, -3506, 0, 27340, 0, -3505, 0, 27345, 0, -3504, 0, 27353, 0, -3503, 0, 27339, 0, -3502, 0, 27359, 0, -3501, 0, 27356, 0, -3500, 0, 27344, 0, -3499, 0, 27371, 0, -3498, 0, 27343, 0, -3497, 0, 27341, 0, -3496, 0, 27358, 0, -3495, 0, 27488, 0, -3494, 0, 27568, 0, -3493, 0, 27660, 0, -3492, 0, 28697, 0, -3491, 0, 28711, 0, -3490, 0, 28704, 0, -3489, 0, 28694, 0, -3488, 0, 28715, 0, -3487, 0, 28705, 0, -3486, 0, 28706, 0, -3485, 0, 28707, 0, -3484, 0, 28713, 0, -3483, 0, 28695, 0, -3482, 0, 28708, 0, -3481, 0, 28700, 0, -3480, 0, 28714, 0, -3479, 0, 29196, 0, -3478, 0, 29194, 0, -3477, 0, 29191, 0, -3476, 0, 29186, 0, -3475, 0, 29189, 0, -3474, 0, 29349, 0, -3473, 0, 29350, 0, -3472, 0, 29348, 0, -3471, 0, 29347, 0, -3470, 0, 29345, 0, -3469, 0, 29899, 0, -3468, 0, 29893, 0, -3467, 0, 29879, 0, -3466, 0, 29891, 0, -3465, 0, 29974, 0, -3464, 0, 30304, 0, -3463, 0, 30665, 0, -3462, 0, 30666, 0, -3461, 0, 30660, 0, -3460, 0, 30705, 0, -3459, 0, 31005, 0, -3458, 0, 31003, 0, -3423, 0, 31009, 0, -3422, 0, 31004, 0, -3421, 0, 30999, 0, -3420, 0, 31006, 0, -3419, 0, 31152, 0, -3418, 0, 31335, 0, -3417, 0, 31336, 0, -3416, 0, 31795, 0, -3415, 0, 31804, 0, -3414, 0, 31801, 0, -3413, 0, 31788, 0, -3412, 0, 31803, 0, -3411, 0, 31980, 0, -3410, 0, 31978, 0, -3409, 0, 32374, 0, -3408, 0, 32373, 0, -3407, 0, 32376, 0, -3406, 0, 32368, 0, -3405, 0, 32375, 0, -3404, 0, 32367, 0, -3403, 0, 32378, 0, -3402, 0, 32370, 0, -3401, 0, 32372, 0, -3400, 0, 32360, 0, -3399, 0, 32587, 0, -3398, 0, 32586, 0, -3397, 0, 32643, 0, -3396, 0, 32646, 0, -3395, 0, 32695, 0, -3394, 0, 32765, 0, -3393, 0, 32766, 0, -3392, 0, -32648, 0, -3391, 0, -32297, 0, -3390, 0, -32299, 0, -3389, 0, -32156, 0, -3388, 0, -32159, 0, -3387, 0, -32157, 0, -3386, 0, -31253, 0, -3385, 0, -31247, 0, -3384, 0, -31251, 0, -3383, 0, -31271, 0, -3382, 0, -31263, 0, -3381, 0, -31256, 0, -3380, 0, -31270, 0, -3379, 0, -31273, 0, -3378, 0, -31252, 0, -3377, 0, -31246, 0, -3376, 0, -31240, 0, -3375, 0, -31272, 0, -3374, 0, -31265, 0, -3373, 0, -31261, 0, -3372, 0, -31268, 0, -3371, 0, -31279, 0, -3370, 0, -31248, 0, -3369, 0, -31258, 0, -3368, 0, -31249, 0, -3367, 0, -31266, 0, -3366, 0, -31262, 0, -3365, 0, -30720, 0, -3364, 0, -30726, 0, -3363, 0, -30717, 0, -3362, 0, -30730, 0, -3361, 0, -30729, 0, -3360, 0, -30711, 0, -3359, 0, -30708, 0, -3358, 0, -30709, 0, -3357, 0, -30714, 0, -3356, 0, -30724, 0, -3355, 0, -30712, 0, -3354, 0, -30721, 0, -3353, 0, -30710, 0, -3352, 0, -30718, 0, -3351, 0, -30366, 0, -3350, 0, -30374, 0, -3349, 0, -30373, 0, -3348, 0, -30377, 0, -3347, 0, -30367, 0, -3346, 0, -30372, 0, -3345, 0, -30376, 0, -3344, 0, -30371, 0, -3343, 0, -30375, 0, -3342, 0, -30328, 0, -3341, 0, -30281, 0, -3340, 0, -30282, 0, -3339, 0, -30218, 0, -3338, 0, -29872, 0, -3337, 0, -29880, 0, -3336, 0, -29878, 0, -3335, 0, -29888, 0, -3334, 0, -29869, 0, -3333, 0, -29866, 0, -3332, 0, -29868, 0, -3331, 0, -29877, 0, -3330, 0, -29867, 0, -3264, 0, -29871, 0, -3263, 0, -29886, 0, -3262, 0, -29870, 0, -3261, 0, -29865, 0, -3260, 0, -29629, 0, -3259, 0, -29577, 0, -3258, 0, -29578, 0, -3257, 0, -29542, 0, -3256, 0, -29434, 0, -3255, 0, -29433, 0, -3254, 0, -29431, 0, -3253, 0, -29268, 0, -3252, 0, -29270, 0, -3251, 0, -29267, 0, -3250, 0, -29269, 0, -3249, 0, -29075, 0, -3248, 0, -29064, 0, -3247, 0, -29069, 0, -3246, 0, -29078, 0, -3245, 0, -29073, 0, -3244, 0, -29061, 0, -3243, 0, -28990, 0, -3242, 0, -28846, 0, -3241, 0, -28847, 0, -3240, 0, -28849, 0, -3239, 0, -28848, 0, -3238, 0, -28845, 0, -3237, 0, -28748, 0, -3236, 0, -28352, 0, -3235, 0, -28353, 0, -3234, 0, -28240, 0, -3233, 0, -28243, 0, -3232, 0, -27682, 0, -3231, 0, -27705, 0, -3230, 0, -27697, 0, -3229, 0, -27710, 0, -3228, 0, -27686, 0, -3227, 0, -27696, 0, -3226, 0, -27655, 0, -3225, 0, -27668, 0, -3224, 0, -27700, 0, -3223, 0, -27687, 0, -3222, 0, -27735, 0, -3221, 0, -27674, 0, -3220, 0, -27702, 0, -3219, 0, -27692, 0, -3218, 0, -27666, 0, -3217, 0, -27677, 0, -3216, 0, -27691, 0, -3215, 0, -27708, 0, -3214, 0, -27698, 0, -3213, 0, -27712, 0, -3212, 0, -27694, 0, -3211, 0, -27673, 0, -3210, 0, -27267, 0, -3209, 0, -27174, 0, -3208, 0, -27173, 0, -3207, 0, -26911, 0, -3206, 0, -26839, 0, -3205, 0, -26837, 0, -3204, 0, -26836, 0, -3203, 0, -26840, 0, -3202, 0, -26842, 0, -3167, 0, -26701, 0, -3166, 0, -26697, 0, -3165, 0, -26698, 0, -3164, 0, -26659, 0, -3163, 0, -26658, 0, -3162, 0, -26657, 0, -3161, 0, -26532, 0, -3160, 0, -26535, 0, -3159, 0, -26531, 0, -3158, 0, -26537, 0, -3157, 0, -26433, 0, -3156, 0, -26435, 0, -3155, 0, -26437, 0, -3154, 0, -26434, 0, -3153, 0, -26296, 0, -3152, 0, -26297, 0, -3151, 0, -26301, 0, -3150, 0, -26202, 0, -3149, 0, -26201, 0, -3148, 0, -26086, 0, -3147, 0, -26091, 0, -3146, 0, -26075, 0, -3145, 0, -26083, 0, -3144, 0, -26076, 0, -3143, 0, -26085, 0, -3142, 0, -26078, 0, -3141, 0, -26080, 0, -3140, 0, -26073, 0, -3139, 0, -26077, 0, -3138, 0, -26082, 0, -3137, 0, -26084, 0, -3136, 0, -26092, 0, -3135, 0, -25918, 0, -3134, 0, -25845, 0, -3133, 0, -25846, 0, -3132, 0, -25842, 0, -3131, 0, -25844, 0, -3130, 0, -25801, 0, -3129, 0, -25622, 0, -3128, 0, -25621, 0, -3127, 0, -25632, 0, -3126, 0, -25634, 0, -3125, 0, -25628, 0, -3124, 0, -25626, 0, -3123, 0, -25630, 0, -3122, 0, -25616, 0, -3121, 0, -25644, 0, -3120, 0, -25641, 0, -3119, 0, -25620, 0, -3118, 0, -25636, 0, -3117, 0, -25639, 0, -3116, 0, -25627, 0, -3115, 0, -25643, 0, -3114, 0, -25631, 0, -3113, 0, -25638, 0, -3112, 0, -25225, 0, -3111, 0, -25215, 0, -3110, 0, -25206, 0, -3109, 0, -25212, 0, -3108, 0, -25208, 0, -3107, 0, -25231, 0, -3106, 0, -25216, 0, -3105, 0, -25224, 0, -3104, 0, -25210, 0, -3103, 0, -25205, 0, -3102, 0, -25204, 0, -3101, 0, -25219, 0, -3100, 0, -25237, 0, -3099, 0, -25228, 0, -3098, 0, -25227, 0, -3097, 0, -25232, 0, -3096, 0, -25239, 0, -3095, 0, -25211, 0, -3094, 0, -25229, 0, -3093, 0, -25221, 0, -3092, 0, -25214, 0, -3091, 0, -25233, 0, -3090, 0, -25223, 0, -3089, 0, -25217, 0, -3088, 0, -25209, 0, -3087, 0, -25240, 0, -3086, 0, -24940, 0, -3085, 0, -24943, 0, -3084, 0, -24896, 0, -3083, 0, -24836, 0, -3082, 0, -24787, 0, -3081, 0, -24768, 0, -3080, 0, -24767, 0, -3079, 0, -24755, 0, -3078, 0, -24746, 0, -3077, 0, -24745, 0, -3076, 0, -24744, 0, -3075, 0, 21303, 0, -3074, 0, 22194, 0, -3008, 0, 22197, 0, -3007, 0, 22195, 0, -3006, 0, 22755, 0, -3005, 0, 23365, 0, -3004, 0, 24006, 0, -3003, 0, 24007, 0, -3002, 0, 24302, 0, -3001, 0, 24303, 0, -3000, 0, 24512, 0, -2999, 0, 24513, 0, -2998, 0, 25081, 0, -2997, 0, 25879, 0, -2996, 0, 25878, 0, -2995, 0, 25877, 0, -2994, 0, 25875, 0, -2993, 0, 26079, 0, -2992, 0, 26344, 0, -2991, 0, 26339, 0, -2990, 0, 26340, 0, -2989, 0, 27379, 0, -2988, 0, 27376, 0, -2987, 0, 27370, 0, -2986, 0, 27368, 0, -2985, 0, 27385, 0, -2984, 0, 27377, 0, -2983, 0, 27374, 0, -2982, 0, 27375, 0, -2981, 0, 28732, 0, -2980, 0, 28725, 0, -2979, 0, 28719, 0, -2978, 0, 28727, 0, -2977, 0, 28724, 0, -2976, 0, 28721, 0, -2975, 0, 28738, 0, -2974, 0, 28728, 0, -2973, 0, 28735, 0, -2972, 0, 28730, 0, -2971, 0, 28729, 0, -2970, 0, 28736, 0, -2969, 0, 28731, 0, -2968, 0, 28723, 0, -2967, 0, 28737, 0, -2966, 0, 29203, 0, -2965, 0, 29204, 0, -2964, 0, 29352, 0, -2963, 0, 29565, 0, -2962, 0, 29564, 0, -2961, 0, 29882, 0, -2960, 0, 30379, 0, -2959, 0, 30378, 0, -2958, 0, 30398, 0, -2957, 0, 30445, 0, -2956, 0, 30668, 0, -2955, 0, 30670, 0, -2954, 0, 30671, 0, -2953, 0, 30669, 0, -2952, 0, 30706, 0, -2951, 0, 31013, 0, -2950, 0, 31011, 0, -2949, 0, 31015, 0, -2948, 0, 31016, 0, -2947, 0, 31012, 0, -2946, 0, 31017, 0, -2911, 0, 31154, 0, -2910, 0, 31342, 0, -2909, 0, 31340, 0, -2908, 0, 31341, 0, -2907, 0, 31479, 0, -2906, 0, 31817, 0, -2905, 0, 31816, 0, -2904, 0, 31818, 0, -2903, 0, 31815, 0, -2902, 0, 31813, 0, -2901, 0, 31982, 0, -2900, 0, 32379, 0, -2899, 0, 32382, 0, -2898, 0, 32385, 0, -2897, 0, 32384, 0, -2896, 0, 32698, 0, -2895, 0, 32767, 0, -2894, 0, -32647, 0, -2893, 0, -32293, 0, -2892, 0, -32295, 0, -2891, 0, -32245, 0, -2890, 0, -32152, 0, -2889, 0, -32151, 0, -2888, 0, -31198, 0, -2887, 0, -31233, 0, -2886, 0, -31231, 0, -2885, 0, -31234, 0, -2884, 0, -31205, 0, -2883, 0, -31232, 0, -2882, 0, -31242, 0, -2881, 0, -31228, 0, -2880, 0, -31223, 0, -2879, 0, -31227, 0, -2878, 0, -31220, 0, -2877, 0, -31235, 0, -2876, 0, -30695, 0, -2875, 0, -30704, 0, -2874, 0, -30703, 0, -2873, 0, -30697, 0, -2872, 0, -30701, 0, -2871, 0, -30698, 0, -2870, 0, -30365, 0, -2869, 0, -30362, 0, -2868, 0, -30279, 0, -2867, 0, -30217, 0, -2866, 0, -29856, 0, -2865, 0, -29846, 0, -2864, 0, -29859, 0, -2863, 0, -29848, 0, -2862, 0, -29853, 0, -2861, 0, -29851, 0, -2860, 0, -29849, 0, -2859, 0, -29843, 0, -2858, 0, -29266, 0, -2857, 0, -29050, 0, -2856, 0, -29048, 0, -2855, 0, -29052, 0, -2854, 0, -28839, 0, -2853, 0, -28842, 0, -2852, 0, -28841, 0, -2851, 0, -28843, 0, -2850, 0, -28840, 0, -2849, 0, -28838, 0, -2848, 0, -28531, 0, -2847, 0, -28349, 0, -2846, 0, -28351, 0, -2845, 0, -28233, 0, -2844, 0, -28235, 0, -2843, 0, -28238, 0, -2842, 0, -28237, 0, -2841, 0, -27637, 0, -2840, 0, -27629, 0, -2839, 0, -27653, 0, -2838, 0, -27616, 0, -2837, 0, -27633, 0, -2836, 0, -27628, 0, -2835, 0, -27650, 0, -2834, 0, -27627, 0, -2833, 0, -27632, 0, -2832, 0, -27608, 0, -2831, 0, -27623, 0, -2830, 0, -27635, 0, -2829, 0, -27659, 0, -2828, 0, -27648, 0, -2827, 0, -27657, 0, -2826, 0, -27641, 0, -2825, 0, -27634, 0, -2824, 0, -27626, 0, -2823, 0, -27630, 0, -2822, 0, -27654, 0, -2821, 0, -27639, 0, -2820, 0, -27656, 0, -2819, 0, -27638, 0, -2818, 0, -27649, 0, -2752, 0, -27652, 0, -2751, 0, -27636, 0, -2750, 0, -27658, 0, -2749, 0, -27631, 0, -2748, 0, -27642, 0, -2747, 0, -27170, 0, -2746, 0, -27168, 0, -2745, 0, -27169, 0, -2744, 0, -26834, 0, -2743, 0, -26833, 0, -2742, 0, -26695, 0, -2741, 0, -26693, 0, -2740, 0, -26627, 0, -2739, 0, -26626, 0, -2738, 0, -26528, 0, -2737, 0, -26526, 0, -2736, 0, -26525, 0, -2735, 0, -26529, 0, -2734, 0, -26431, 0, -2733, 0, -26430, 0, -2732, 0, -26288, 0, -2731, 0, -26290, 0, -2730, 0, -26279, 0, -2729, 0, -26292, 0, -2728, 0, -26293, 0, -2727, 0, -26285, 0, -2726, 0, -26062, 0, -2725, 0, -26060, 0, -2724, 0, -26063, 0, -2723, 0, -26068, 0, -2722, 0, -26070, 0, -2721, 0, -26058, 0, -2720, 0, -26071, 0, -2719, 0, -26066, 0, -2718, 0, -26056, 0, -2717, 0, -26067, 0, -2716, 0, -25913, 0, -2715, 0, -25910, 0, -2714, 0, -25914, 0, -2713, 0, -25840, 0, -2712, 0, -25838, 0, -2711, 0, -25839, 0, -2710, 0, -25589, 0, -2709, 0, -25592, 0, -2708, 0, -25609, 0, -2707, 0, -25595, 0, -2706, 0, -25582, 0, -2705, 0, -25608, 0, -2704, 0, -25536, 0, -2703, 0, -25593, 0, -2702, 0, -25586, 0, -2701, 0, -25594, 0, -2700, 0, -25577, 0, -2699, 0, -25580, 0, -2698, 0, -25591, 0, -2697, 0, -25185, 0, -2696, 0, -25191, 0, -2695, 0, -25180, 0, -2694, 0, -25187, 0, -2693, 0, -25198, 0, -2692, 0, -25192, 0, -2691, 0, -25200, 0, -2690, 0, -25189, 0, -2655, 0, -25184, 0, -2654, 0, -25196, 0, -2653, 0, -25188, 0, -2652, 0, -25174, 0, -2651, 0, -25193, 0, -2650, 0, -25183, 0, -2649, 0, -25190, 0, -2648, 0, -25182, 0, -2647, 0, -25176, 0, -2646, 0, -25186, 0, -2645, 0, -25181, 0, -2644, 0, -25153, 0, -2643, 0, -25175, 0, -2642, 0, -25194, 0, -2641, 0, -25178, 0, -2640, 0, -25177, 0, -2639, 0, -24935, 0, -2638, 0, -24933, 0, -2637, 0, -24934, 0, -2636, 0, -24859, 0, -2635, 0, -24860, 0, -2634, 0, -24857, 0, -2633, 0, -24858, 0, -2632, 0, -24784, 0, -2631, 0, -24786, 0, -2630, 0, -24741, 0, -2629, 0, -24736, 0, -2628, 0, -24738, 0, -2627, 0, -24739, 0, -2626, 0, -24743, 0, -2625, 0, -24687, 0, -2624, 0, 20794, 0, -2623, 0, 20793, 0, -2622, 0, 21144, 0, -2621, 0, 21143, 0, -2620, 0, 22211, 0, -2619, 0, 22205, 0, -2618, 0, 22206, 0, -2617, 0, 23368, 0, -2616, 0, 23367, 0, -2615, 0, 24011, 0, -2614, 0, 24015, 0, -2613, 0, 24305, 0, -2612, 0, 25085, 0, -2611, 0, 25883, 0, -2610, 0, 27394, 0, -2609, 0, 27388, 0, -2608, 0, 27395, 0, -2607, 0, 27384, 0, -2606, 0, 27392, 0, -2605, 0, 28739, 0, -2604, 0, 28740, 0, -2603, 0, 28746, 0, -2602, 0, 28744, 0, -2601, 0, 28745, 0, -2600, 0, 28741, 0, -2599, 0, 28742, 0, -2598, 0, 29213, 0, -2597, 0, 29210, 0, -2596, 0, 29209, 0, -2595, 0, 29566, 0, -2594, 0, 29975, 0, -2593, 0, 30314, 0, -2592, 0, 30672, 0, -2591, 0, 31021, 0, -2590, 0, 31025, 0, -2589, 0, 31023, 0, -2588, 0, 31828, 0, -2587, 0, 31827, 0, -2586, 0, 31986, 0, -2585, 0, 32394, 0, -2584, 0, 32391, 0, -2583, 0, 32392, 0, -2582, 0, 32395, 0, -2581, 0, 32390, 0, -2580, 0, 32397, 0, -2579, 0, 32589, 0, -2578, 0, 32699, 0, -2577, 0, -32720, 0, -2576, 0, -32291, 0, -2575, 0, -31208, 0, -2574, 0, -31190, 0, -2573, 0, -31194, 0, -2572, 0, -31201, 0, -2571, 0, -31197, 0, -2570, 0, -31204, 0, -2569, 0, -31207, 0, -2568, 0, -31193, 0, -2567, 0, -31186, 0, -2566, 0, -31199, 0, -2565, 0, -31200, 0, -2564, 0, -31191, 0, -2563, 0, -31202, 0, -2562, 0, -31195, 0, -2496, 0, -30679, 0, -2495, 0, -30691, 0, -2494, 0, -30693, 0, -2493, 0, -30688, 0, -2492, 0, -30684, 0, -2491, 0, -30692, 0, -2490, 0, -30677, 0, -2489, 0, -30646, 0, -2488, 0, -30355, 0, -2487, 0, -30359, 0, -2486, 0, -30354, 0, -2485, 0, -30357, 0, -2484, 0, -30214, 0, -2483, 0, -29831, 0, -2482, 0, -29832, 0, -2481, 0, -29883, 0, -2480, 0, -29830, 0, -2479, 0, -29829, 0, -2478, 0, -29424, 0, -2477, 0, -29420, 0, -2476, 0, -29265, 0, -2475, 0, -29042, 0, -2474, 0, -29044, 0, -2473, 0, -28834, 0, -2472, 0, -28837, 0, -2471, 0, -28835, 0, -2470, 0, -28346, 0, -2469, 0, -28348, 0, -2468, 0, -28347, 0, -2467, 0, -28231, 0, -2466, 0, -27585, 0, -2465, 0, -27589, 0, -2464, 0, -27594, 0, -2463, 0, -27607, 0, -2462, 0, -27587, 0, -2461, 0, -27588, 0, -2460, 0, -27600, 0, -2459, 0, -27591, 0, -2458, 0, -27606, 0, -2457, 0, -27593, 0, -2456, 0, -27604, 0, -2455, 0, -27584, 0, -2454, 0, -27599, 0, -2453, 0, -27163, 0, -2452, 0, -27164, 0, -2451, 0, -27165, 0, -2450, 0, -26827, 0, -2449, 0, -26822, 0, -2448, 0, -26689, 0, -2447, 0, -26655, 0, -2446, 0, -26524, 0, -2445, 0, -26423, 0, -2444, 0, -26426, 0, -2443, 0, -26432, 0, -2442, 0, -26280, 0, -2441, 0, -26282, 0, -2440, 0, -26055, 0, -2439, 0, -26051, 0, -2438, 0, -26042, 0, -2437, 0, -26044, 0, -2436, 0, -26046, 0, -2435, 0, -26047, 0, -2434, 0, -26054, 0, -2399, 0, -26049, 0, -2398, 0, -25907, 0, -2397, 0, -25835, 0, -2396, 0, -25833, 0, -2395, 0, -25832, 0, -2394, 0, -25834, 0, -2393, 0, -25798, 0, -2392, 0, -25774, 0, -2391, 0, -25557, 0, -2390, 0, -25571, 0, -2389, 0, -25572, 0, -2388, 0, -25556, 0, -2387, 0, -25565, 0, -2386, 0, -25560, 0, -2385, 0, -25559, 0, -2384, 0, -25564, 0, -2383, 0, -25567, 0, -2382, 0, -25161, 0, -2381, 0, -25162, 0, -2380, 0, -25156, 0, -2379, 0, -25151, 0, -2378, 0, -25145, 0, -2377, 0, -25142, 0, -2376, 0, -25137, 0, -2375, 0, -25154, 0, -2374, 0, -25147, 0, -2373, 0, -25149, 0, -2372, 0, -25157, 0, -2371, 0, -25163, 0, -2370, 0, -25138, 0, -2369, 0, -25159, 0, -2368, 0, -25158, 0, -2367, 0, -25172, 0, -2366, 0, -25144, 0, -2365, 0, -25167, 0, -2364, 0, -25171, 0, -2363, 0, -25140, 0, -2362, 0, -25165, 0, -2361, 0, -25139, 0, -2360, 0, -25166, 0, -2359, 0, -24966, 0, -2358, 0, -24932, 0, -2357, 0, -24853, 0, -2356, 0, -24850, 0, -2355, 0, -24851, 0, -2354, 0, -24805, 0, -2353, 0, -24808, 0, -2352, 0, -24806, 0, -2351, 0, -24783, 0, -2350, 0, -24754, 0, -2349, 0, -24731, 0, -2348, 0, -24732, 0, -2347, 0, -24686, 0, -2346, 0, 20153, 0, -2345, 0, 22214, 0, -2344, 0, 22213, 0, -2343, 0, 22219, 0, -2342, 0, 22897, 0, -2341, 0, 23371, 0, -2340, 0, 23372, 0, -2339, 0, 24021, 0, -2338, 0, 24017, 0, -2337, 0, 24306, 0, -2336, 0, 25889, 0, -2335, 0, 25888, 0, -2334, 0, 25894, 0, -2333, 0, 25890, 0, -2332, 0, 27403, 0, -2331, 0, 27400, 0, -2330, 0, 27401, 0, -2329, 0, 27661, 0, -2328, 0, 28757, 0, -2327, 0, 28758, 0, -2326, 0, 28759, 0, -2325, 0, 28754, 0, -2324, 0, 29214, 0, -2323, 0, 29215, 0, -2322, 0, 29353, 0, -2321, 0, 29567, 0, -2320, 0, 29912, 0, -2319, 0, 29909, 0, -2318, 0, 29913, 0, -2317, 0, 29911, 0, -2316, 0, 30317, 0, -2315, 0, 30381, 0, -2314, 0, 31029, 0, -2313, 0, 31156, 0, -2312, 0, 31344, 0, -2311, 0, 31345, 0, -2310, 0, 31831, 0, -2309, 0, 31836, 0, -2308, 0, 31833, 0, -2307, 0, 31835, 0, -2306, 0, 31834, 0, -2240, 0, 31988, 0, -2239, 0, 31985, 0, -2238, 0, 32401, 0, -2237, 0, 32591, 0, -2236, 0, 32647, 0, -2235, 0, -32290, 0, -2234, 0, -32149, 0, -2233, 0, -31180, 0, -2232, 0, -31179, 0, -2231, 0, -31181, 0, -2230, 0, -31188, 0, -2229, 0, -31182, 0, -2228, 0, -31178, 0, -2227, 0, -30676, 0, -2226, 0, -30680, 0, -2225, 0, -30682, 0, -2224, 0, -30678, 0, -2223, 0, -30683, 0, -2222, 0, -30351, 0, -2221, 0, -30273, 0, -2220, 0, -30274, 0, -2219, 0, -30213, 0, -2218, 0, -29826, 0, -2217, 0, -29820, 0, -2216, 0, -29822, 0, -2215, 0, -29818, 0, -2214, 0, -29819, 0, -2213, 0, -29825, 0, -2212, 0, -29419, 0, -2211, 0, -29035, 0, -2210, 0, -29036, 0, -2209, 0, -29030, 0, -2208, 0, -29038, 0, -2207, 0, -29040, 0, -2206, 0, -29034, 0, -2205, 0, -29033, 0, -2204, 0, -28832, 0, -2203, 0, -28830, 0, -2202, 0, -28345, 0, -2201, 0, -27572, 0, -2200, 0, -27568, 0, -2199, 0, -27574, 0, -2198, 0, -27573, 0, -2197, 0, -27569, 0, -2196, 0, -27577, 0, -2195, 0, -27579, 0, -2194, 0, -27576, 0, -2193, 0, -27575, 0, -2192, 0, -27578, 0, -2191, 0, -26817, 0, -2190, 0, -26653, 0, -2189, 0, -26518, 0, -2188, 0, -26519, 0, -2187, 0, -26421, 0, -2186, 0, -26284, 0, -2185, 0, -26277, 0, -2184, 0, -26034, 0, -2183, 0, -26029, 0, -2182, 0, -26028, 0, -2181, 0, -26036, 0, -2180, 0, -26033, 0, -2179, 0, -26040, 0, -2178, 0, -26038, 0, -2143, 0, -26039, 0, -2142, 0, -26030, 0, -2141, 0, -26032, 0, -2140, 0, -25904, 0, -2139, 0, -25831, 0, -2138, 0, -25813, 0, -2137, 0, -25797, 0, -2136, 0, -25770, 0, -2135, 0, -25771, 0, -2134, 0, -25530, 0, -2133, 0, -25528, 0, -2132, 0, -25537, 0, -2131, 0, -25532, 0, -2130, 0, -25543, 0, -2129, 0, -25549, 0, -2128, 0, -25535, 0, -2127, 0, -25540, 0, -2126, 0, -25545, 0, -2125, 0, -25548, 0, -2124, 0, -25550, 0, -2123, 0, -25539, 0, -2122, 0, -25546, 0, -2121, 0, -25125, 0, -2120, 0, -25134, 0, -2119, 0, -25122, 0, -2118, 0, -25126, 0, -2117, 0, -25141, 0, -2116, 0, -25136, 0, -2115, 0, -25124, 0, -2114, 0, -25135, 0, -2113, 0, -25121, 0, -2112, 0, -25111, 0, -2111, 0, -25127, 0, -2110, 0, -25128, 0, -2109, 0, -25130, 0, -2108, 0, -25099, 0, -2107, 0, -25131, 0, -2106, 0, -25123, 0, -2105, 0, -24906, 0, -2104, 0, -24848, 0, -2103, 0, -24779, 0, -2102, 0, -24781, 0, -2101, 0, -24782, 0, -2100, 0, -24766, 0, -2099, 0, -24725, 0, -2098, 0, -24683, 0, -2097, 0, -24670, 0, -2096, 0, 20797, 0, -2095, 0, 21145, 0, -2094, 0, 22760, 0, -2093, 0, 22759, 0, -2092, 0, 22898, 0, -2091, 0, 23373, 0, -2090, 0, 24024, 0, -2089, 0, -30673, 0, -2088, 0, 24399, 0, -2087, 0, 25089, 0, -2086, 0, 25091, 0, -2085, 0, 25092, 0, -2084, 0, 25897, 0, -2083, 0, 25893, 0, -2082, 0, 26006, 0, -2081, 0, 26347, 0, -2080, 0, 27409, 0, -2079, 0, 27410, 0, -2078, 0, 27407, 0, -2077, 0, 27594, 0, -2076, 0, 28763, 0, -2075, 0, 28762, 0, -2074, 0, 29218, 0, -2073, 0, 29570, 0, -2072, 0, 29569, 0, -2071, 0, 29571, 0, -2070, 0, 30320, 0, -2069, 0, 30676, 0, -2068, 0, 31847, 0, -2067, 0, 31846, 0, -2066, 0, 32405, 0, -2065, 0, -32148, 0, -2064, 0, -31174, 0, -2063, 0, -31168, 0, -2062, 0, -31175, 0, -2061, 0, -31172, 0, -2060, 0, -31183, 0, -2059, 0, -31173, 0, -2058, 0, -31170, 0, -2057, 0, -30672, 0, -2056, 0, -30670, 0, -2055, 0, -30674, 0, -2054, 0, -30669, 0, -2053, 0, -30346, 0, -2052, 0, -30348, 0, -2051, 0, -30349, 0, -2050, 0, -30210, 0, -1984, 0, -29812, 0, -1983, 0, -29810, 0, -1982, 0, -29813, 0, -1981, 0, -29816, 0, -1980, 0, -29627, 0, -1979, 0, -29415, 0, -1978, 0, -29032, 0, -1977, 0, -28828, 0, -1976, 0, -28829, 0, -1975, 0, -28228, 0, -1974, 0, -27550, 0, -1973, 0, -27563, 0, -1972, 0, -27555, 0, -1971, 0, -27561, 0, -1970, 0, -27554, 0, -1969, 0, -26684, 0, -1968, 0, -26683, 0, -1967, 0, -26624, 0, -1966, 0, -26026, 0, -1965, 0, -26023, 0, -1964, 0, -25826, 0, -1963, 0, -25825, 0, -1962, 0, -25824, 0, -1961, 0, -25518, 0, -1960, 0, -25512, 0, -1959, 0, -25520, 0, -1958, 0, -25526, 0, -1957, 0, -25523, 0, -1956, 0, -25525, 0, -1955, 0, -25515, 0, -1954, 0, -25511, 0, -1953, 0, -25524, 0, -1952, 0, -25522, 0, -1951, 0, -25093, 0, -1950, 0, -25097, 0, -1949, 0, -25105, 0, -1948, 0, -25117, 0, -1947, 0, -25109, 0, -1946, 0, -25096, 0, -1945, 0, -25116, 0, -1944, 0, -25098, 0, -1943, 0, -25119, 0, -1942, 0, -25106, 0, -1941, 0, -25114, 0, -1940, 0, -25102, 0, -1939, 0, -25104, 0, -1938, 0, -25118, 0, -1937, 0, -25108, 0, -1936, 0, -25100, 0, -1935, 0, -25101, 0, -1934, 0, -25112, 0, -1933, 0, -25107, 0, -1932, 0, -24894, 0, -1931, 0, -24880, 0, -1930, 0, -24846, 0, -1929, 0, -24845, 0, -1928, 0, -24826, 0, -1927, 0, -24804, 0, -1926, 0, -24776, 0, -1925, 0, -24777, 0, -1924, 0, -24778, 0, -1923, 0, -24765, 0, -1922, 0, -24753, 0, -1887, 0, -24719, 0, -1886, 0, -24720, 0, -1885, 0, -24722, 0, -1884, 0, -24721, 0, -1883, 0, 22227, 0, -1882, 0, 22221, 0, -1881, 0, 23374, 0, -1880, 0, 23661, 0, -1879, 0, 25901, 0, -1878, 0, 26349, 0, -1877, 0, 26350, 0, -1876, 0, 27411, 0, -1875, 0, 28767, 0, -1874, 0, 28769, 0, -1873, 0, 28765, 0, -1872, 0, 28768, 0, -1871, 0, 29219, 0, -1870, 0, 29915, 0, -1869, 0, 29925, 0, -1868, 0, 30677, 0, -1867, 0, 31032, 0, -1866, 0, 31159, 0, -1865, 0, 31158, 0, -1864, 0, 31850, 0, -1863, 0, 32407, 0, -1862, 0, 32649, 0, -1861, 0, -32147, 0, -1860, 0, -31165, 0, -1859, 0, -30664, 0, -1858, 0, -30665, 0, -1857, 0, -30667, 0, -1856, 0, -30645, 0, -1855, 0, -29804, 0, -1854, 0, -29803, 0, -1853, 0, -29026, 0, -1852, 0, -29025, 0, -1851, 0, -29024, 0, -1850, 0, -29027, 0, -1849, 0, -28226, 0, -1848, 0, -28227, 0, -1847, 0, -28222, 0, -1846, 0, -27541, 0, -1845, 0, -27544, 0, -1844, 0, -27543, 0, -1843, 0, -26907, 0, -1842, 0, -26810, 0, -1841, 0, -26813, 0, -1840, 0, -26809, 0, -1839, 0, -26681, 0, -1838, 0, -26651, 0, -1837, 0, -26018, 0, -1836, 0, -25899, 0, -1835, 0, -25767, 0, -1834, 0, -25501, 0, -1833, 0, -25497, 0, -1832, 0, -25498, 0, -1831, 0, -25502, 0, -1830, 0, -25506, 0, -1829, 0, -25504, 0, -1828, 0, -25086, 0, -1827, 0, -25090, 0, -1826, 0, -25081, 0, -1825, 0, -25085, 0, -1824, 0, -25082, 0, -1823, 0, -25083, 0, -1822, 0, -25088, 0, -1821, 0, -25087, 0, -1820, 0, -25079, 0, -1819, 0, -25089, 0, -1818, 0, -25091, 0, -1817, 0, -25084, 0, -1816, 0, -24928, 0, -1815, 0, -24802, 0, -1814, 0, -24762, 0, -1813, 0, -24716, 0, -1812, 0, -24715, 0, -1811, 0, -24714, 0, -1810, 0, 22228, 0, -1809, 0, 25902, 0, -1808, 0, 26040, 0, -1807, 0, 27416, 0, -1806, 0, 27417, 0, -1805, 0, 27415, 0, -1804, 0, 27418, 0, -1803, 0, 28770, 0, -1802, 0, 29222, 0, -1801, 0, 29354, 0, -1800, 0, 30680, 0, -1799, 0, 30681, 0, -1798, 0, 31033, 0, -1797, 0, 31849, 0, -1796, 0, 31851, 0, -1795, 0, 31990, 0, -1794, 0, 32410, 0, -1728, 0, 32408, 0, -1727, 0, 32411, 0, -1726, 0, 32409, 0, -1725, 0, -32288, 0, -1724, 0, -32287, 0, -1723, 0, -31162, 0, -1722, 0, -31161, 0, -1721, 0, -31160, 0, -1720, 0, -30343, 0, -1719, 0, -30342, 0, -1718, 0, -30340, 0, -1717, 0, -30341, 0, -1716, 0, -30209, 0, -1715, 0, -29800, 0, -1714, 0, -29799, 0, -1713, 0, -29019, 0, -1712, 0, -29020, 0, -1711, 0, -29021, 0, -1710, 0, -27538, 0, -1709, 0, -27539, 0, -1708, 0, -27537, 0, -1707, 0, -27535, 0, -1706, 0, -27533, 0, -1705, 0, -26807, 0, -1704, 0, -26510, 0, -1703, 0, -26273, 0, -1702, 0, -25496, 0, -1701, 0, -25490, 0, -1700, 0, -25491, 0, -1699, 0, -25077, 0, -1698, 0, -25075, 0, -1697, 0, -25072, 0, -1696, 0, -25073, 0, -1695, 0, -25070, 0, -1694, 0, -25071, 0, -1693, 0, -24927, 0, -1692, 0, -24843, 0, -1691, 0, -24823, 0, -1690, 0, -24761, 0, -1689, 0, -24712, 0, -1688, 0, -24709, 0, -1687, 0, -24710, 0, -1686, 0, -24711, 0, -1685, 0, 22302, 0, -1684, 0, 28774, 0, -1683, 0, 31855, 0, -1682, 0, -30660, 0, -1681, 0, -29262, 0, -1680, 0, -29018, 0, -1679, 0, -28221, 0, -1678, 0, -27532, 0, -1677, 0, -27528, 0, -1676, 0, -27530, 0, -1675, 0, -27531, 0, -1674, 0, -26016, 0, -1673, 0, -25484, 0, -1672, 0, -25485, 0, -1671, 0, -25487, 0, -1670, 0, -25483, 0, -1669, 0, -25068, 0, -1668, 0, -25069, 0, -1667, 0, -24842, 0, -1666, 0, -24822, 0, -1631, 0, -24668, 0, -1630, 0, 28776, 0, -1629, 0, 28773, 0, -1628, 0, 31991, 0, -1627, 0, -31126, 0, -1626, 0, -30658, 0, -1625, 0, -30659, 0, -1624, 0, -30657, 0, -1623, 0, -29794, 0, -1622, 0, -29540, 0, -1621, 0, -29015, 0, -1620, 0, -28983, 0, -1619, 0, -26805, 0, -1618, 0, -26509, 0, -1617, 0, -26508, 0, -1616, 0, -26420, 0, -1615, 0, -26271, 0, -1614, 0, -26197, 0, -1613, 0, -26012, 0, -1612, 0, -26010, 0, -1611, 0, -26009, 0, -1610, 0, -25820, 0, -1609, 0, -25067, 0, -1608, 0, -25065, 0, -1607, 0, -24760, 0, -1606, 0, 25095, 0, -1605, 0, 27422, 0, -1604, 0, 29223, 0, -1603, 0, -31156, 0, -1602, 0, -29016, 0, -1601, 0, -27518, 0, -1600, 0, -27520, 0, -1599, 0, -27519, 0, -1598, 0, -26007, 0, -1597, 0, -26008, 0, -1596, 0, -25810, 0, -1595, 0, -25063, 0, -1594, 0, 29225, 0, -1593, 0, -31157, 0, -1592, 0, -29793, 0, -1591, 0, -27517, 0, -1590, 0, -25479, 0, -1589, 0, -24905, 0, -1588, 0, 30325, 0, -1587, 0, -26005, 0, -1586, 0, -25478, 0, -1585, 0, -25059, 0, -1584, 0, 28777, 0, -1583, 0, 28778, 0, -1582, 0, -24924, 0, -1581, 0, -24706, 0, -1580, 0, -24759, 0, -1579, 0, -24680, 0, -1578, 0, 30849, 0, -1577, 0, -27975, 0, -1576, 0, -30513, 0, -1575, 0, 22715, 0, -1574, 0, 24658, 0, -1573, 0, 31911, 0, -1572, 0, 23290, 0, -1571, 0, 9556, 0, -1570, 0, 9574, 0, -1569, 0, 9559, 0, -1568, 0, 9568, 0, -1567, 0, 9580, 0, -1566, 0, 9571, 0, -1565, 0, 9562, 0, -1564, 0, 9577, 0, -1563, 0, 9565, 0, -1562, 0, 9554, 0, -1561, 0, 9572, 0, -1560, 0, 9557, 0, -1559, 0, 9566, 0, -1558, 0, 9578, 0, -1557, 0, 9569, 0, -1556, 0, 9560, 0, -1555, 0, 9575, 0, -1554, 0, 9563, 0, -1553, 0, 9555, 0, -1552, 0, 9573, 0, -1551, 0, 9558, 0, -1550, 0, 9567, 0, -1549, 0, 9579, 0, -1548, 0, 9570, 0, -1547, 0, 9561, 0, -1546, 0, 9576, 0, -1545, 0, 9564, 0, -1544, 0, 9553, 0, -1543, 0, 9552, 0, -1542, 0, 9581, 0, -1541, 0, 9582, 0, -1540, 0, 9584, 0, -1539, 0, 9583, 0, -1538, 0, 9619, 0, -1472, 0, -8192, 0, -1471, 0, -8191, 0, -1470, 0, -8190, 0, -1469, 0, -8189, 0, -1468, 0, -8188, 0, -1467, 0, -8187, 0, -1466, 0, -8186, 0, -1465, 0, -8185, 0, -1464, 0, -8184, 0, -1463, 0, -8183, 0, -1462, 0, -8182, 0, -1461, 0, -8181, 0, -1460, 0, -8180, 0, -1459, 0, -8179, 0, -1458, 0, -8178, 0, -1457, 0, -8177, 0, -1456, 0, -8176, 0, -1455, 0, -8175, 0, -1454, 0, -8174, 0, -1453, 0, -8173, 0, -1452, 0, -8172, 0, -1451, 0, -8171, 0, -1450, 0, -8170, 0, -1449, 0, -8169, 0, -1448, 0, -8168, 0, -1447, 0, -8167, 0, -1446, 0, -8166, 0, -1445, 0, -8165, 0, -1444, 0, -8164, 0, -1443, 0, -8163, 0, -1442, 0, -8162, 0, -1441, 0, -8161, 0, -1440, 0, -8160, 0, -1439, 0, -8159, 0, -1438, 0, -8158, 0, -1437, 0, -8157, 0, -1436, 0, -8156, 0, -1435, 0, -8155, 0, -1434, 0, -8154, 0, -1433, 0, -8153, 0, -1432, 0, -8152, 0, -1431, 0, -8151, 0, -1430, 0, -8150, 0, -1429, 0, -8149, 0, -1428, 0, -8148, 0, -1427, 0, -8147, 0, -1426, 0, -8146, 0, -1425, 0, -8145, 0, -1424, 0, -8144, 0, -1423, 0, -8143, 0, -1422, 0, -8142, 0, -1421, 0, -8141, 0, -1420, 0, -8140, 0, -1419, 0, -8139, 0, -1418, 0, -8138, 0, -1417, 0, -8137, 0, -1416, 0, -8136, 0, -1415, 0, -8135, 0, -1414, 0, -8134, 0, -1413, 0, -8133, 0, -1412, 0, -8132, 0, -1411, 0, -8131, 0, -1410, 0, -8130, 0, -1375, 0, -8129, 0, -1374, 0, -8128, 0, -1373, 0, -8127, 0, -1372, 0, -8126, 0, -1371, 0, -8125, 0, -1370, 0, -8124, 0, -1369, 0, -8123, 0, -1368, 0, -8122, 0, -1367, 0, -8121, 0, -1366, 0, -8120, 0, -1365, 0, -8119, 0, -1364, 0, -8118, 0, -1363, 0, -8117, 0, -1362, 0, -8116, 0, -1361, 0, -8115, 0, -1360, 0, -8114, 0, -1359, 0, -8113, 0, -1358, 0, -8112, 0, -1357, 0, -8111, 0, -1356, 0, -8110, 0, -1355, 0, -8109, 0, -1354, 0, -8108, 0, -1353, 0, -8107, 0, -1352, 0, -8106, 0, -1351, 0, -8105, 0, -1350, 0, -8104, 0, -1349, 0, -8103, 0, -1348, 0, -8102, 0, -1347, 0, -8101, 0, -1346, 0, -8100, 0, -1345, 0, -8099, 0, -1344, 0, -8098, 0, -1343, 0, -8097, 0, -1342, 0, -8096, 0, -1341, 0, -8095, 0, -1340, 0, -8094, 0, -1339, 0, -8093, 0, -1338, 0, -8092, 0, -1337, 0, -8091, 0, -1336, 0, -8090, 0, -1335, 0, -8089, 0, -1334, 0, -8088, 0, -1333, 0, -8087, 0, -1332, 0, -8086, 0, -1331, 0, -8085, 0, -1330, 0, -8084, 0, -1329, 0, -8083, 0, -1328, 0, -8082, 0, -1327, 0, -8081, 0, -1326, 0, -8080, 0, -1325, 0, -8079, 0, -1324, 0, -8078, 0, -1323, 0, -8077, 0, -1322, 0, -8076, 0, -1321, 0, -8075, 0, -1320, 0, -8074, 0, -1319, 0, -8073, 0, -1318, 0, -8072, 0, -1317, 0, -8071, 0, -1316, 0, -8070, 0, -1315, 0, -8069, 0, -1314, 0, -8068, 0, -1313, 0, -8067, 0, -1312, 0, -8066, 0, -1311, 0, -8065, 0, -1310, 0, -8064, 0, -1309, 0, -8063, 0, -1308, 0, -8062, 0, -1307, 0, -8061, 0, -1306, 0, -8060, 0, -1305, 0, -8059, 0, -1304, 0, -8058, 0, -1303, 0, -8057, 0, -1302, 0, -8056, 0, -1301, 0, -8055, 0, -1300, 0, -8054, 0, -1299, 0, -8053, 0, -1298, 0, -8052, 0, -1297, 0, -8051, 0, -1296, 0, -8050, 0, -1295, 0, -8049, 0, -1294, 0, -8048, 0, -1293, 0, -8047, 0, -1292, 0, -8046, 0, -1291, 0, -8045, 0, -1290, 0, -8044, 0, -1289, 0, -8043, 0, -1288, 0, -8042, 0, -1287, 0, -8041, 0, -1286, 0, -8040, 0, -1285, 0, -8039, 0, -1284, 0, -8038, 0, -1283, 0, -8037, 0, -1282, 0, -8036, 0, -1216, 0, -8035, 0, -1215, 0, -8034, 0, -1214, 0, -8033, 0, -1213, 0, -8032, 0, -1212, 0, -8031, 0, -1211, 0, -8030, 0, -1210, 0, -8029, 0, -1209, 0, -8028, 0, -1208, 0, -8027, 0, -1207, 0, -8026, 0, -1206, 0, -8025, 0, -1205, 0, -8024, 0, -1204, 0, -8023, 0, -1203, 0, -8022, 0, -1202, 0, -8021, 0, -1201, 0, -8020, 0, -1200, 0, -8019, 0, -1199, 0, -8018, 0, -1198, 0, -8017, 0, -1197, 0, -8016, 0, -1196, 0, -8015, 0, -1195, 0, -8014, 0, -1194, 0, -8013, 0, -1193, 0, -8012, 0, -1192, 0, -8011, 0, -1191, 0, -8010, 0, -1190, 0, -8009, 0, -1189, 0, -8008, 0, -1188, 0, -8007, 0, -1187, 0, -8006, 0, -1186, 0, -8005, 0, -1185, 0, -8004, 0, -1184, 0, -8003, 0, -1183, 0, -8002, 0, -1182, 0, -8001, 0, -1181, 0, -8000, 0, -1180, 0, -7999, 0, -1179, 0, -7998, 0, -1178, 0, -7997, 0, -1177, 0, -7996, 0, -1176, 0, -7995, 0, -1175, 0, -7994, 0, -1174, 0, -7993, 0, -1173, 0, -7992, 0, -1172, 0, -7991, 0, -1171, 0, -7990, 0, -1170, 0, -7989, 0, -1169, 0, -7988, 0, -1168, 0, -7987, 0, -1167, 0, -7986, 0, -1166, 0, -7985, 0, -1165, 0, -7984, 0, -1164, 0, -7983, 0, -1163, 0, -7982, 0, -1162, 0, -7981, 0, -1161, 0, -7980, 0, -1160, 0, -7979, 0, -1159, 0, -7978, 0, -1158, 0, -7977, 0, -1157, 0, -7976, 0, -1156, 0, -7975, 0, -1155, 0, -7974, 0, -1154, 0, -7973, 0, -1119, 0, -7972, 0, -1118, 0, -7971, 0, -1117, 0, -7970, 0, -1116, 0, -7969, 0, -1115, 0, -7968, 0, -1114, 0, -7967, 0, -1113, 0, -7966, 0, -1112, 0, -7965, 0, -1111, 0, -7964, 0, -1110, 0, -7963, 0, -1109, 0, -7962, 0, -1108, 0, -7961, 0, -1107, 0, -7960, 0, -1106, 0, -7959, 0, -1105, 0, -7958, 0, -1104, 0, -7957, 0, -1103, 0, -7956, 0, -1102, 0, -7955, 0, -1101, 0, -7954, 0, -1100, 0, -7953, 0, -1099, 0, -7952, 0, -1098, 0, -7951, 0, -1097, 0, -7950, 0, -1096, 0, -7949, 0, -1095, 0, -7948, 0, -1094, 0, -7947, 0, -1093, 0, -7946, 0, -1092, 0, -7945, 0, -1091, 0, -7944, 0, -1090, 0, -7943, 0, -1089, 0, -7942, 0, -1088, 0, -7941, 0, -1087, 0, -7940, 0, -1086, 0, -7939, 0, -1085, 0, -7938, 0, -1084, 0, -7937, 0, -1083, 0, -7936, 0, -1082, 0, -7935, 0, -1081, 0, -7934, 0, -1080, 0, -7933, 0, -1079, 0, -7932, 0, -1078, 0, -7931, 0, -1077, 0, -7930, 0, -1076, 0, -7929, 0, -1075, 0, -7928, 0, -1074, 0, -7927, 0, -1073, 0, -7926, 0, -1072, 0, -7925, 0, -1071, 0, -7924, 0, -1070, 0, -7923, 0, -1069, 0, -7922, 0, -1068, 0, -7921, 0, -1067, 0, -7920, 0, -1066, 0, -7919, 0, -1065, 0, -7918, 0, -1064, 0, -7917, 0, -1063, 0, -7916, 0, -1062, 0, -7915, 0, -1061, 0, -7914, 0, -1060, 0, -7913, 0, -1059, 0, -7912, 0, -1058, 0, -7911, 0, -1057, 0, -7910, 0, -1056, 0, -7909, 0, -1055, 0, -7908, 0, -1054, 0, -7907, 0, -1053, 0, -7906, 0, -1052, 0, -7905, 0, -1051, 0, -7904, 0, -1050, 0, -7903, 0, -1049, 0, -7902, 0, -1048, 0, -7901, 0, -1047, 0, -7900, 0, -1046, 0, -7899, 0, -1045, 0, -7898, 0, -1044, 0, -7897, 0, -1043, 0, -7896, 0, -1042, 0, -7895, 0, -1041, 0, -7894, 0, -1040, 0, -7893, 0, -1039, 0, -7892, 0, -1038, 0, -7891, 0, -1037, 0, -7890, 0, -1036, 0, -7889, 0, -1035, 0, -7888, 0, -1034, 0, -7887, 0, -1033, 0, -7886, 0, -1032, 0, -7885, 0, -1031, 0, -7884, 0, -1030, 0, -7883, 0, -1029, 0, -7882, 0, -1028, 0, -7881, 0, -1027, 0, -7880, 0, -1026, 0, -7879, 0, -960, 0, -7878, 0, -959, 0, -7877, 0, -958, 0, -7876, 0, -957, 0, -7875, 0, -956, 0, -7874, 0, -955, 0, -7873, 0, -954, 0, -7872, 0, -953, 0, -7871, 0, -952, 0, -7870, 0, -951, 0, -7869, 0, -950, 0, -7868, 0, -949, 0, -7867, 0, -948, 0, -7866, 0, -947, 0, -7865, 0, -946, 0, -7864, 0, -945, 0, -7863, 0, -944, 0, -7862, 0, -943, 0, -7861, 0, -942, 0, -7860, 0, -941, 0, -7859, 0, -940, 0, -7858, 0, -939, 0, -7857, 0, -938, 0, -7856, 0, -937, 0, -7855, 0, -936, 0, -7854, 0, -935, 0, -7853, 0, -934, 0, -7852, 0, -933, 0, -7851, 0, -932, 0, -7850, 0, -931, 0, -7849, 0, -930, 0, -7848, 0, -929, 0, -7847, 0, -928, 0, -7846, 0, -927, 0, -7845, 0, -926, 0, -7844, 0, -925, 0, -7843, 0, -924, 0, -7842, 0, -923, 0, -7841, 0, -922, 0, -7840, 0, -921, 0, -7839, 0, -920, 0, -7838, 0, -919, 0, -7837, 0, -918, 0, -7836, 0, -917, 0, -7835, 0, -916, 0, -7834, 0, -915, 0, -7833, 0, -914, 0, -7832, 0, -913, 0, -7831, 0, -912, 0, -7830, 0, -911, 0, -7829, 0, -910, 0, -7828, 0, -909, 0, -7827, 0, -908, 0, -7826, 0, -907, 0, -7825, 0, -906, 0, -7824, 0, -905, 0, -7823, 0, -904, 0, -7822, 0, -903, 0, -7821, 0, -902, 0, -7820, 0, -901, 0, -7819, 0, -900, 0, -7818, 0, -899, 0, -7817, 0, -898, 0, -7816, 0, -863, 0, -7815, 0, -862, 0, -7814, 0, -861, 0, -7813, 0, -860, 0, -7812, 0, -859, 0, -7811, 0, -858, 0, -7810, 0, -857, 0, -7809, 0, -856, 0, -7808, 0, -855, 0, -7807, 0, -854, 0, -7806, 0, -853, 0, -7805, 0, -852, 0, -7804, 0, -851, 0, -7803, 0, -850, 0, -7802, 0, -849, 0, -7801, 0, -848, 0, -7800, 0, -847, 0, -7799, 0, -846, 0, -7798, 0, -845, 0, -7797, 0, -844, 0, -7796, 0, -843, 0, -7795, 0, -842, 0, -7794, 0, -841, 0, -7793, 0, -840, 0, -7792, 0, -839, 0, -7791, 0, -838, 0, -7790, 0, -837, 0, -7789, 0, -836, 0, -7788, 0, -835, 0, -7787, 0, -834, 0, -7786, 0, -833, 0, -7785, 0, -832, 0, -7784, 0, -831, 0, -7783, 0, -830, 0, -7782, 0, -829, 0, -7781, 0, -828, 0, -7780, 0, -827, 0, -7779, 0, -826, 0, -7778, 0, -825, 0, -7777, 0, -824, 0, -7776, 0, -823, 0, -7775, 0, -822, 0, -7774, 0, -821, 0, -7773, 0, -820, 0, -7772, 0, -819, 0, -7771, 0, -818, 0, -7770, 0, -817, 0, -7769, 0, -816, 0, -7768, 0, -815, 0, -7767, 0, -814, 0, -7766, 0, -813, 0, -7765, 0, -812, 0, -7764, 0, -811, 0, -7763, 0, -810, 0, -7762, 0, -809, 0, -7761, 0, -808, 0, -7760, 0, -807, 0, -7759, 0, -806, 0, -7758, 0, -805, 0, -7757, 0, -804, 0, -7756, 0, -803, 0, -7755, 0, -802, 0, -7754, 0, -801, 0, -7753, 0, -800, 0, -7752, 0, -799, 0, -7751, 0, -798, 0, -7750, 0, -797, 0, -7749, 0, -796, 0, -7748, 0, -795, 0, -7747, 0, -794, 0, -7746, 0, -793, 0, -7745, 0, -792, 0, -7744, 0, -791, 0, -7743, 0, -790, 0, -7742, 0, -789, 0, -7741, 0, -788, 0, -7740, 0, -787, 0, -7739, 0, -786, 0, -7738, 0, -785, 0, -7737, 0, -784, 0, -7736, 0, -783, 0, -7735, 0, -782, 0, -7734, 0, -781, 0, -7733, 0, -780, 0, -7732, 0, -779, 0, -7731, 0, -778, 0, -7730, 0, -777, 0, -7729, 0, -776, 0, -7728, 0, -775, 0, -7727, 0, -774, 0, -7726, 0, -773, 0, -7725, 0, -772, 0, -7724, 0, -771, 0, -7723, 0, -770, 0, -7722, 0, -704, 0, -7721, 0, -703, 0, -7720, 0, -702, 0, -7719, 0, -701, 0, -7718, 0, -700, 0, -7717, 0, -699, 0, -7716, 0, -698, 0, -7715, 0, -697, 0, -7714, 0, -696, 0, -7713, 0, -695, 0, -7712, 0, -694, 0, -7711, 0, -693, 0, -7710, 0, -692, 0, -7709, 0, -691, 0, -7708, 0, -690, 0, -7707, 0, -689, 0, -7706, 0, -688, 0, -7705, 0, -687, 0, -7704, 0, -686, 0, -7703, 0, -685, 0, -7702, 0, -684, 0, -7701, 0, -683, 0, -7700, 0, -682, 0, -7699, 0, -681, 0, -7698, 0, -680, 0, -7697, 0, -679, 0, -7696, 0, -678, 0, -7695, 0, -677, 0, -7694, 0, -676, 0, -7693, 0, -675, 0, -7692, 0, -674, 0, -7691, 0, -673, 0, -7690, 0, -672, 0, -7689, 0, -671, 0, -7688, 0, -670, 0, -7687, 0, -669, 0, -7686, 0, -668, 0, -7685, 0, -667, 0, -7684, 0, -666, 0, -7683, 0, -665, 0, -7682, 0, -664, 0, -7681, 0, -663, 0, -7680, 0, -662, 0, -7679, 0, -661, 0, -7678, 0, -660, 0, -7677, 0, -659, 0, -7676, 0, -658, 0, -7675, 0, -657, 0, -7674, 0, -656, 0, -7673, 0, -655, 0, -7672, 0, -654, 0, -7671, 0, -653, 0, -7670, 0, -652, 0, -7669, 0, -651, 0, -7668, 0, -650, 0, -7667, 0, -649, 0, -7666, 0, -648, 0, -7665, 0, -647, 0, -7664, 0, -646, 0, -7663, 0, -645, 0, -7662, 0, -644, 0, -7661, 0, -643, 0, -7660, 0, -642, 0, -7659, 0, -607, 0, -7658, 0, -606, 0, -7657, 0, -605, 0, -7656, 0, -604, 0, -7655, 0, -603, 0, -7654, 0, -602, 0, -7653, 0, -601, 0, -7652, 0, -600, 0, -7651, 0, -599, 0, -7650, 0, -598, 0, -7649, 0, -597, 0, -7648, 0, -596, 0, -7647, 0, -595, 0, -7646, 0, -594, 0, -7645, 0, -593, 0, -7644, 0, -592, 0, -7643, 0, -591, 0, -7642, 0, -590, 0, -7641, 0, -589, 0, -7640, 0, -588, 0, -7639, 0, -587, 0, -7638, 0, -586, 0, -7637, 0, -585, 0, -7636, 0, -584, 0, -7635, 0, -583, 0, -7634, 0, -582, 0, -7633, 0, -581, 0, -7632, 0, -580, 0, -7631, 0, -579, 0, -7630, 0, -578, 0, -7629, 0, -577, 0, -7628, 0, -576, 0, -7627, 0, -575, 0, -7626, 0, -574, 0, -7625, 0, -573, 0, -7624, 0, -572, 0, -7623, 0, -571, 0, -7622, 0, -570, 0, -7621, 0, -569, 0, -7620, 0, -568, 0, -7619, 0, -567, 0, -7618, 0, -566, 0, -7617, 0, -565, 0, -7616, 0, -564, 0, -7615, 0, -563, 0, -7614, 0, -562, 0, -7613, 0, -561, 0, -7612, 0, -560, 0, -7611, 0, -559, 0, -7610, 0, -558, 0, -7609, 0, -557, 0, -7608, 0, -556, 0, -7607, 0, -555, 0, -7606, 0, -554, 0, -7605, 0, -553, 0, -7604, 0, -552, 0, -7603, 0, -551, 0, -7602, 0, -550, 0, -7601, 0, -549, 0, -7600, 0, -548, 0, -7599, 0, -547, 0, -7598, 0, -546, 0, -7597, 0, -545, 0, -7596, 0, -544, 0, -7595, 0, -543, 0, -7594, 0, -542, 0, -7593, 0, -541, 0, -7592, 0, -540, 0, -7591, 0, -539, 0, -7590, 0, -538, 0, -7589, 0, -537, 0, -7588, 0, -536, 0, -7587, 0, -535, 0, -7586, 0, -534, 0, -7585, 0, -533, 0, -7584, 0, -532, 0, -7583, 0, -531, 0, -7582, 0, -530, 0, -7581, 0, -529, 0, -7580, 0, -528, 0, -7579, 0, -527, 0, -7578, 0, -526, 0, -7577, 0, -525, 0, -7576, 0, -524, 0, -7575, 0, -523, 0, -7574, 0, -522, 0, -7573, 0, -521, 0, -7572, 0, -520, 0, -7571, 0, -519, 0, -7570, 0, -518, 0, -7569, 0, -517, 0, -7568, 0, -516, 0, -7567, 0, -515, 0, -7566, 0, -514, 0, -7565, 0, -448, 0, -7564, 0, -447, 0, -7563, 0, -446, 0, -7562, 0, -445, 0, -7561, 0, -444, 0, -7560, 0, -443, 0, -7559, 0, -442, 0, -7558, 0, -441, 0, -7557, 0, -440, 0, -7556, 0, -439, 0, -7555, 0, -438, 0, -7554, 0, -437, 0, -7553, 0, -436, 0, -7552, 0, -435, 0, -7551, 0, -434, 0, -7550, 0, -433, 0, -7549, 0, -432, 0, -7548, 0, -431, 0, -7547, 0, -430, 0, -7546, 0, -429, 0, -7545, 0, -428, 0, -7544, 0, -427, 0, -7543, 0, -426, 0, -7542, 0, -425, 0, -7541, 0, -424, 0, -7540, 0, -423, 0, -7539, 0, -422, 0, -7538, 0, -421, 0, -7537, 0, -420, 0, -7536, 0, -419, 0, -7535, 0, -418, 0, -7534, 0, -417, 0, -7533, 0, -416, 0, -7532, 0, -415, 0, -7531, 0, -414, 0, -7530, 0, -413, 0, -7529, 0, -412, 0, -7528, 0, -411, 0, -7527, 0, -410, 0, -7526, 0, -409, 0, -7525, 0, -408, 0, -7524, 0, -407, 0, -7523, 0, -406, 0, -7522, 0, -405, 0, -7521, 0, -404, 0, -7520, 0, -403, 0, -7519, 0, -402, 0, -7518, 0, -401, 0, -7517, 0, -400, 0, -7516, 0, -399, 0, -7515, 0, -398, 0, -7514, 0, -397, 0, -7513, 0, -396, 0, -7512, 0, -395, 0, -7511, 0, -394, 0, -7510, 0, -393, 0, -7509, 0, -392, 0, -7508, 0, -391, 0, -7507, 0, -390, 0, -7506, 0, -389, 0, -7505, 0, -388, 0, -7504, 0, -387, 0, -7503, 0, -386, 0, -7502, 0, -351, 0, -7501, 0, -350, 0, -7500, 0, -349, 0, -7499, 0, -348, 0, -7498, 0, -347, 0, -7497, 0, -346, 0, -7496, 0, -345, 0, -7495, 0, -344, 0, -7494, 0, -343, 0, -7493, 0, -342, 0, -7492, 0, -341, 0, -7491, 0, -340, 0, -7490, 0, -339, 0, -7489, 0, -338, 0, -7488, 0, -337, 0, -7487, 0, -336, 0, -7486, 0, -335, 0, -7485, 0, -334, 0, -7484, 0, -333, 0, -7483, 0, -332, 0, -7482, 0, -331, 0, -7481, 0, -330, 0, -7480, 0, -329, 0, -7479, 0, -328, 0, -7478, 0, -327, 0, -7477, 0, -326, 0, -7476, 0, -325, 0, -7475, 0, -324, 0, -7474, 0, -323, 0, -7473, 0, -322, 0, -7472, 0, -321, 0, -7471, 0, -320, 0, -7470, 0, -319, 0, -7469, 0, -318, 0, -7468, 0, -317, 0, -7467, 0, -316, 0, -7466, 0, -315, 0, -7465, 0, -314, 0, -7464, 0, -313, 0, -7463, 0, -312, 0, -7462, 0, -311, 0, -7461, 0, -310, 0, -7460, 0, -309, 0, -7459, 0, -308, 0, -7458, 0, -307, 0, -7457, 0, -306, 0, -7456, 0, -305, 0, -7455, 0, -304, 0, -7454, 0, -303, 0, -7453, 0, -302, 0, -7452, 0, -301, 0, -7451, 0, -300, 0, -7450, 0, -299, 0, -7449, 0, -298, 0, -7448, 0, -297, 0, -7447, 0, -296, 0, -7446, 0, -295, 0, -7445, 0, -294, 0, -7444, 0, -293, 0, -7443, 0, -292, 0, -7442, 0, -291, 0, -7441, 0, -290, 0, -7440, 0, -289, 0, -7439, 0, -288, 0, -7438, 0, -287, 0, -7437, 0, -286, 0, -7436, 0, -285, 0, -7435, 0, -284, 0, -7434, 0, -283, 0, -7433, 0, -282, 0, -7432, 0, -281, 0, -7431, 0, -280, 0, -7430, 0, -279, 0, -7429, 0, -278, 0, -7428, 0, -277, 0, -7427, 0, -276, 0, -7426, 0, -275, 0, -7425, 0, -274, 0, -7424, 0, -273, 0, -7423, 0, -272, 0, -7422, 0, -271, 0, -7421, 0, -270, 0, -7420, 0, -269, 0, -7419, 0, -268, 0, -7418, 0, -267, 0, -7417, 0, -266, 0, -7416, 0, -265, 0, -7415, 0, -264, 0, -7414, 0, -263, 0, -7413, 0, -262, 0, -7412, 0, -261, 0, -7411, 0, -260, 0, -7410, 0, -259, 0, -7409, 0, -258, 0, -7408, 0, -1, 0, -1, 0], ["i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0], ALLOC_STATIC);
STRING_TABLE.__str21082=allocate([65,100,111,98,101,0] /* Adobe\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str31083=allocate([67,78,83,49,0] /* CNS1\00 */, "i8", ALLOC_STATIC);
_ETen_B5_AddCodeSpaceRange_code_space_range1=allocate([0, 0, 128, 0, 0, 0], ["i16",0,"i16",0,"i16",0], ALLOC_STATIC);
_ETen_B5_AddCodeSpaceRange_code_space_range2=allocate([-24256, 0, -258, 0, 0, 0], ["i16",0,"i16",0,"i16",0], ALLOC_STATIC);
STRING_TABLE.__str1085=allocate([57,48,109,115,45,82,75,83,74,45,72,0] /* 90ms-RKSJ-H\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str11086=allocate([57,48,109,115,45,82,75,83,74,45,86,0] /* 90ms-RKSJ-V\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str21087=allocate([57,48,109,115,112,45,82,75,83,74,45,72,0] /* 90msp-RKSJ-H\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str31088=allocate([69,85,67,45,72,0] /* EUC-H\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str41089=allocate([69,85,67,45,86,0] /* EUC-V\00 */, "i8", ALLOC_STATIC);
_CMAP_ARRAY_EUC_H=allocate([32, 0, 126, 0, 231, 0, -29024, 0, -28961, 0, 326, 0, -24159, 0, -24066, 0, 633, 0, -23903, 0, -23890, 0, 727, 0, -23878, 0, -23871, 0, 741, 0, -23862, 0, -23856, 0, 749, 0, -23844, 0, -23830, 0, 756, 0, -23822, 0, -23815, 0, 771, 0, -23810, 0, -23810, 0, 779, 0, -23632, 0, -23623, 0, 780, 0, -23615, 0, -23590, 0, 790, 0, -23583, 0, -23558, 0, 816, 0, -23391, 0, -23309, 0, 842, 0, -23135, 0, -23050, 0, 925, 0, -22879, 0, -22856, 0, 1011, 0, -22847, 0, -22824, 0, 1035, 0, -22623, 0, -22591, 0, 1059, 0, -22575, 0, -22543, 0, 1092, 0, -22367, 0, -22367, 0, 7479, 0, -22366, 0, -22366, 0, 7481, 0, -22365, 0, -22365, 0, 7491, 0, -22364, 0, -22364, 0, 7495, 0, -22363, 0, -22363, 0, 7503, 0, -22362, 0, -22362, 0, 7499, 0, -22361, 0, -22361, 0, 7507, 0, -22360, 0, -22360, 0, 7523, 0, -22359, 0, -22359, 0, 7515, 0, -22358, 0, -22358, 0, 7531, 0, -22357, 0, -22357, 0, 7539, 0, -22356, 0, -22356, 0, 7480, 0, -22355, 0, -22355, 0, 7482, 0, -22354, 0, -22354, 0, 7494, 0, -22353, 0, -22353, 0, 7498, 0, -22352, 0, -22352, 0, 7506, 0, -22351, 0, -22351, 0, 7502, 0, -22350, 0, -22350, 0, 7514, 0, -22349, 0, -22349, 0, 7530, 0, -22348, 0, -22348, 0, 7522, 0, -22347, 0, -22347, 0, 7538, 0, -22346, 0, -22346, 0, 7554, 0, -22345, 0, -22345, 0, 7511, 0, -22344, 0, -22344, 0, 7526, 0, -22343, 0, -22343, 0, 7519, 0, -22342, 0, -22342, 0, 7534, 0, -22341, 0, -22341, 0, 7542, 0, -22340, 0, -22340, 0, 7508, 0, -22339, 0, -22339, 0, 7527, 0, -22338, 0, -22338, 0, 7516, 0, -22337, 0, -22337, 0, 7535, 0, -22336, 0, -22336, 0, 7545, 0, -20319, 0, -20226, 0, 1125, 0, -20063, 0, -19970, 0, 1219, 0, -19807, 0, -19714, 0, 1313, 0, -19551, 0, -19458, 0, 1407, 0, -19295, 0, -19202, 0, 1501, 0, -19039, 0, -18946, 0, 1595, 0, -18783, 0, -18690, 0, 1689, 0, -18527, 0, -18434, 0, 1783, 0, -18271, 0, -18178, 0, 1877, 0, -18015, 0, -17922, 0, 1971, 0, -17759, 0, -17666, 0, 2065, 0, -17503, 0, -17410, 0, 2159, 0, -17247, 0, -17154, 0, 2253, 0, -16991, 0, -16898, 0, 2347, 0, -16735, 0, -16642, 0, 2441, 0, -16479, 0, -16386, 0, 2535, 0, -16223, 0, -16130, 0, 2629, 0, -15967, 0, -15874, 0, 2723, 0, -15711, 0, -15618, 0, 2817, 0, -15455, 0, -15362, 0, 2911, 0, -15199, 0, -15106, 0, 3005, 0, -14943, 0, -14850, 0, 3099, 0, -14687, 0, -14594, 0, 3193, 0, -14431, 0, -14338, 0, 3287, 0, -14175, 0, -14082, 0, 3381, 0, -13919, 0, -13826, 0, 3475, 0, -13663, 0, -13570, 0, 3569, 0, -13407, 0, -13314, 0, 3663, 0, -13151, 0, -13058, 0, 3757, 0, -12895, 0, -12802, 0, 3851, 0, -12639, 0, -12546, 0, 3945, 0, -12383, 0, -12333, 0, 4039, 0, -12127, 0, -12034, 0, 4090, 0, -11871, 0, -11778, 0, 4184, 0, -11615, 0, -11522, 0, 4278, 0, -11359, 0, -11266, 0, 4372, 0, -11103, 0, -11010, 0, 4466, 0, -10847, 0, -10754, 0, 4560, 0, -10591, 0, -10498, 0, 4654, 0, -10335, 0, -10242, 0, 4748, 0, -10079, 0, -9986, 0, 4842, 0, -9823, 0, -9730, 0, 4936, 0, -9567, 0, -9474, 0, 5030, 0, -9311, 0, -9218, 0, 5124, 0, -9055, 0, -8962, 0, 5218, 0, -8799, 0, -8706, 0, 5312, 0, -8543, 0, -8450, 0, 5406, 0, -8287, 0, -8194, 0, 5500, 0, -8031, 0, -7938, 0, 5594, 0, -7775, 0, -7682, 0, 5688, 0, -7519, 0, -7426, 0, 5782, 0, -7263, 0, -7170, 0, 5876, 0, -7007, 0, -6914, 0, 5970, 0, -6751, 0, -6658, 0, 6064, 0, -6495, 0, -6402, 0, 6158, 0, -6239, 0, -6146, 0, 6252, 0, -5983, 0, -5890, 0, 6346, 0, -5727, 0, -5634, 0, 6440, 0, -5471, 0, -5378, 0, 6534, 0, -5215, 0, -5122, 0, 6628, 0, -4959, 0, -4866, 0, 6722, 0, -4703, 0, -4610, 0, 6816, 0, -4447, 0, -4354, 0, 6910, 0, -4191, 0, -4098, 0, 7004, 0, -3935, 0, -3842, 0, 7098, 0, -3679, 0, -3586, 0, 7192, 0, -3423, 0, -3330, 0, 7286, 0, -3167, 0, -3074, 0, 7380, 0, -2911, 0, -2908, 0, 7474, 0, -2907, 0, -2906, 0, 8284, 0, -1, 0, -1, 0, 0, 0], ["i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0], ALLOC_STATIC);
_CMAP_ARRAY_EUC_V=allocate([-24158, 0, -24157, 0, 30855, 0, -24143, 0, -24142, 0, 30857, 0, -24132, 0, -24130, 0, 30865, 0, -24127, 0, -24123, 0, 30868, 0, -24118, 0, -24101, 0, 30873, 0, -24095, 0, -24095, 0, 30999, 0, -23391, 0, -23391, 0, 31000, 0, -23389, 0, -23389, 0, 31001, 0, -23387, 0, -23387, 0, 31008, 0, -23385, 0, -23385, 0, 31009, 0, -23383, 0, -23383, 0, 31010, 0, -23357, 0, -23357, 0, 31011, 0, -23325, 0, -23325, 0, 31012, 0, -23323, 0, -23323, 0, 31013, 0, -23321, 0, -23321, 0, 31014, 0, -23314, 0, -23314, 0, 31015, 0, -23135, 0, -23135, 0, 31016, 0, -23133, 0, -23133, 0, 31017, 0, -23131, 0, -23131, 0, 31024, 0, -23129, 0, -23129, 0, 31025, 0, -23127, 0, -23127, 0, 31026, 0, -23101, 0, -23101, 0, 31027, 0, -23069, 0, -23069, 0, 31028, 0, -23067, 0, -23067, 0, 31029, 0, -23065, 0, -23065, 0, 31030, 0, -23058, 0, -23058, 0, 31031, 0, -23051, 0, -23050, 0, 31032, 0, -1, 0, -1, 0, 0, 0], ["i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0], ALLOC_STATIC);
_EUC_NOTDEF_RANGE=allocate([0, 0, 31, 0, 231, 0], ["i16",0,"i16",0,"i16",0], ALLOC_STATIC);
_EUC_UNICODE_ARRAY=allocate([0, 0, 0, 0, 1, 0, 1, 0, 2, 0, 2, 0, 3, 0, 3, 0, 4, 0, 4, 0, 5, 0, 5, 0, 6, 0, 6, 0, 7, 0, 7, 0, 8, 0, 8, 0, 9, 0, 9, 0, 10, 0, 10, 0, 11, 0, 11, 0, 12, 0, 12, 0, 13, 0, 13, 0, 14, 0, 14, 0, 15, 0, 15, 0, 16, 0, 16, 0, 17, 0, 17, 0, 18, 0, 18, 0, 19, 0, 19, 0, 20, 0, 20, 0, 21, 0, 21, 0, 22, 0, 22, 0, 23, 0, 23, 0, 24, 0, 24, 0, 25, 0, 25, 0, 26, 0, 26, 0, 27, 0, 27, 0, 28, 0, 28, 0, 29, 0, 29, 0, 30, 0, 30, 0, 31, 0, 31, 0, 32, 0, 32, 0, 33, 0, 33, 0, 34, 0, 34, 0, 35, 0, 35, 0, 36, 0, 36, 0, 37, 0, 37, 0, 38, 0, 38, 0, 39, 0, 39, 0, 40, 0, 40, 0, 41, 0, 41, 0, 42, 0, 42, 0, 43, 0, 43, 0, 44, 0, 44, 0, 45, 0, 45, 0, 46, 0, 46, 0, 47, 0, 47, 0, 48, 0, 48, 0, 49, 0, 49, 0, 50, 0, 50, 0, 51, 0, 51, 0, 52, 0, 52, 0, 53, 0, 53, 0, 54, 0, 54, 0, 55, 0, 55, 0, 56, 0, 56, 0, 57, 0, 57, 0, 58, 0, 58, 0, 59, 0, 59, 0, 60, 0, 60, 0, 61, 0, 61, 0, 62, 0, 62, 0, 63, 0, 63, 0, 64, 0, 64, 0, 65, 0, 65, 0, 66, 0, 66, 0, 67, 0, 67, 0, 68, 0, 68, 0, 69, 0, 69, 0, 70, 0, 70, 0, 71, 0, 71, 0, 72, 0, 72, 0, 73, 0, 73, 0, 74, 0, 74, 0, 75, 0, 75, 0, 76, 0, 76, 0, 77, 0, 77, 0, 78, 0, 78, 0, 79, 0, 79, 0, 80, 0, 80, 0, 81, 0, 81, 0, 82, 0, 82, 0, 83, 0, 83, 0, 84, 0, 84, 0, 85, 0, 85, 0, 86, 0, 86, 0, 87, 0, 87, 0, 88, 0, 88, 0, 89, 0, 89, 0, 90, 0, 90, 0, 91, 0, 91, 0, 92, 0, 92, 0, 93, 0, 93, 0, 94, 0, 94, 0, 95, 0, 95, 0, 96, 0, 96, 0, 97, 0, 97, 0, 98, 0, 98, 0, 99, 0, 99, 0, 100, 0, 100, 0, 101, 0, 101, 0, 102, 0, 102, 0, 103, 0, 103, 0, 104, 0, 104, 0, 105, 0, 105, 0, 106, 0, 106, 0, 107, 0, 107, 0, 108, 0, 108, 0, 109, 0, 109, 0, 110, 0, 110, 0, 111, 0, 111, 0, 112, 0, 112, 0, 113, 0, 113, 0, 114, 0, 114, 0, 115, 0, 115, 0, 116, 0, 116, 0, 117, 0, 117, 0, 118, 0, 118, 0, 119, 0, 119, 0, 120, 0, 120, 0, 121, 0, 121, 0, 122, 0, 122, 0, 123, 0, 123, 0, 124, 0, 124, 0, 125, 0, 125, 0, 126, 0, 126, 0, 127, 0, 127, 0, 128, 0, 128, 0, 129, 0, 129, 0, 130, 0, 130, 0, 131, 0, 131, 0, 132, 0, 132, 0, 133, 0, 133, 0, 134, 0, 134, 0, 135, 0, 135, 0, 136, 0, 136, 0, 137, 0, 137, 0, 138, 0, 138, 0, 139, 0, 139, 0, 140, 0, 140, 0, 141, 0, 141, 0, 142, 0, 142, 0, 143, 0, 143, 0, 144, 0, 144, 0, 145, 0, 145, 0, 146, 0, 146, 0, 147, 0, 147, 0, 148, 0, 148, 0, 149, 0, 149, 0, 150, 0, 150, 0, 151, 0, 151, 0, 152, 0, 152, 0, 153, 0, 153, 0, 154, 0, 154, 0, 155, 0, 155, 0, 156, 0, 156, 0, 157, 0, 157, 0, 158, 0, 158, 0, 159, 0, 159, 0, -24159, 0, 12288, 0, -24158, 0, 12289, 0, -24157, 0, 12290, 0, -24156, 0, -244, 0, -24155, 0, -242, 0, -24154, 0, 12539, 0, -24153, 0, -230, 0, -24152, 0, -229, 0, -24151, 0, -225, 0, -24150, 0, -255, 0, -24149, 0, 12443, 0, -24148, 0, 12444, 0, -24147, 0, 180, 0, -24146, 0, -192, 0, -24145, 0, 168, 0, -24144, 0, -194, 0, -24143, 0, 8254, 0, -24142, 0, -193, 0, -24141, 0, 12541, 0, -24140, 0, 12542, 0, -24139, 0, 12445, 0, -24138, 0, 12446, 0, -24137, 0, 12291, 0, -24136, 0, 20189, 0, -24135, 0, 12293, 0, -24134, 0, 12294, 0, -24133, 0, 12295, 0, -24132, 0, 12540, 0, -24131, 0, 8212, 0, -24130, 0, 8208, 0, -24129, 0, -241, 0, -24128, 0, -196, 0, -24127, 0, 12316, 0, -24126, 0, 8214, 0, -24125, 0, -164, 0, -24124, 0, 8230, 0, -24123, 0, 8229, 0, -24122, 0, 8216, 0, -24121, 0, 8217, 0, -24120, 0, 8220, 0, -24119, 0, 8221, 0, -24118, 0, -248, 0, -24117, 0, -247, 0, -24116, 0, 12308, 0, -24115, 0, 12309, 0, -24114, 0, -197, 0, -24113, 0, -195, 0, -24112, 0, -165, 0, -24111, 0, -163, 0, -24110, 0, 12296, 0, -24109, 0, 12297, 0, -24108, 0, 12298, 0, -24107, 0, 12299, 0, -24106, 0, 12300, 0, -24105, 0, 12301, 0, -24104, 0, 12302, 0, -24103, 0, 12303, 0, -24102, 0, 12304, 0, -24101, 0, 12305, 0, -24100, 0, -245, 0, -24099, 0, 8722, 0, -24098, 0, 177, 0, -24097, 0, 215, 0, -24096, 0, 247, 0, -24095, 0, -227, 0, -24094, 0, 8800, 0, -24093, 0, -228, 0, -24092, 0, -226, 0, -24091, 0, 8806, 0, -24090, 0, 8807, 0, -24089, 0, 8734, 0, -24088, 0, 8756, 0, -24087, 0, 9794, 0, -24086, 0, 9792, 0, -24085, 0, 176, 0, -24084, 0, 8242, 0, -24083, 0, 8243, 0, -24082, 0, 8451, 0, -24081, 0, 165, 0, -24080, 0, -252, 0, -24079, 0, 162, 0, -24078, 0, 163, 0, -24077, 0, -251, 0, -24076, 0, -253, 0, -24075, 0, -250, 0, -24074, 0, -246, 0, -24073, 0, -224, 0, -24072, 0, 167, 0, -24071, 0, 9734, 0, -24070, 0, 9733, 0, -24069, 0, 9675, 0, -24068, 0, 9679, 0, -24067, 0, 9678, 0, -24066, 0, 9671, 0, -23903, 0, 9670, 0, -23902, 0, 9633, 0, -23901, 0, 9632, 0, -23900, 0, 9651, 0, -23899, 0, 9650, 0, -23898, 0, 9661, 0, -23897, 0, 9660, 0, -23896, 0, 8251, 0, -23895, 0, 12306, 0, -23894, 0, 8594, 0, -23893, 0, 8592, 0, -23892, 0, 8593, 0, -23891, 0, 8595, 0, -23890, 0, 12307, 0, -23889, 0, -249, 0, -23878, 0, 8712, 0, -23877, 0, 8715, 0, -23876, 0, 8838, 0, -23875, 0, 8839, 0, -23874, 0, 8834, 0, -23873, 0, 8835, 0, -23872, 0, 8746, 0, -23871, 0, 8745, 0, -23862, 0, 8743, 0, -23861, 0, 8744, 0, -23860, 0, 172, 0, -23859, 0, 8658, 0, -23858, 0, 8660, 0, -23857, 0, 8704, 0, -23856, 0, 8707, 0, -23844, 0, 8736, 0, -23843, 0, 8869, 0, -23842, 0, 8978, 0, -23841, 0, 8706, 0, -23840, 0, 8711, 0, -23839, 0, 8801, 0, -23838, 0, 8786, 0, -23837, 0, 8810, 0, -23836, 0, 8811, 0, -23835, 0, 8730, 0, -23834, 0, 8765, 0, -23833, 0, 8733, 0, -23832, 0, 8757, 0, -23831, 0, 8747, 0, -23830, 0, 8748, 0, -23822, 0, 8491, 0, -23821, 0, 8240, 0, -23820, 0, 9839, 0, -23819, 0, 9837, 0, -23818, 0, 9834, 0, -23817, 0, 8224, 0, -23816, 0, 8225, 0, -23815, 0, 182, 0, -23810, 0, 9711, 0, -23632, 0, -240, 0, -23631, 0, -239, 0, -23630, 0, -238, 0, -23629, 0, -237, 0, -23628, 0, -236, 0, -23627, 0, -235, 0, -23626, 0, -234, 0, -23625, 0, -233, 0, -23624, 0, -232, 0, -23623, 0, -231, 0, -23615, 0, -223, 0, -23614, 0, -222, 0, -23613, 0, -221, 0, -23612, 0, -220, 0, -23611, 0, -219, 0, -23610, 0, -218, 0, -23609, 0, -217, 0, -23608, 0, -216, 0, -23607, 0, -215, 0, -23606, 0, -214, 0, -23605, 0, -213, 0, -23604, 0, -212, 0, -23603, 0, -211, 0, -23602, 0, -210, 0, -23601, 0, -209, 0, -23600, 0, -208, 0, -23599, 0, -207, 0, -23598, 0, -206, 0, -23597, 0, -205, 0, -23596, 0, -204, 0, -23595, 0, -203, 0, -23594, 0, -202, 0, -23593, 0, -201, 0, -23592, 0, -200, 0, -23591, 0, -199, 0, -23590, 0, -198, 0, -23583, 0, -191, 0, -23582, 0, -190, 0, -23581, 0, -189, 0, -23580, 0, -188, 0, -23579, 0, -187, 0, -23578, 0, -186, 0, -23577, 0, -185, 0, -23576, 0, -184, 0, -23575, 0, -183, 0, -23574, 0, -182, 0, -23573, 0, -181, 0, -23572, 0, -180, 0, -23571, 0, -179, 0, -23570, 0, -178, 0, -23569, 0, -177, 0, -23568, 0, -176, 0, -23567, 0, -175, 0, -23566, 0, -174, 0, -23565, 0, -173, 0, -23564, 0, -172, 0, -23563, 0, -171, 0, -23562, 0, -170, 0, -23561, 0, -169, 0, -23560, 0, -168, 0, -23559, 0, -167, 0, -23558, 0, -166, 0, -23391, 0, 12353, 0, -23390, 0, 12354, 0, -23389, 0, 12355, 0, -23388, 0, 12356, 0, -23387, 0, 12357, 0, -23386, 0, 12358, 0, -23385, 0, 12359, 0, -23384, 0, 12360, 0, -23383, 0, 12361, 0, -23382, 0, 12362, 0, -23381, 0, 12363, 0, -23380, 0, 12364, 0, -23379, 0, 12365, 0, -23378, 0, 12366, 0, -23377, 0, 12367, 0, -23376, 0, 12368, 0, -23375, 0, 12369, 0, -23374, 0, 12370, 0, -23373, 0, 12371, 0, -23372, 0, 12372, 0, -23371, 0, 12373, 0, -23370, 0, 12374, 0, -23369, 0, 12375, 0, -23368, 0, 12376, 0, -23367, 0, 12377, 0, -23366, 0, 12378, 0, -23365, 0, 12379, 0, -23364, 0, 12380, 0, -23363, 0, 12381, 0, -23362, 0, 12382, 0, -23361, 0, 12383, 0, -23360, 0, 12384, 0, -23359, 0, 12385, 0, -23358, 0, 12386, 0, -23357, 0, 12387, 0, -23356, 0, 12388, 0, -23355, 0, 12389, 0, -23354, 0, 12390, 0, -23353, 0, 12391, 0, -23352, 0, 12392, 0, -23351, 0, 12393, 0, -23350, 0, 12394, 0, -23349, 0, 12395, 0, -23348, 0, 12396, 0, -23347, 0, 12397, 0, -23346, 0, 12398, 0, -23345, 0, 12399, 0, -23344, 0, 12400, 0, -23343, 0, 12401, 0, -23342, 0, 12402, 0, -23341, 0, 12403, 0, -23340, 0, 12404, 0, -23339, 0, 12405, 0, -23338, 0, 12406, 0, -23337, 0, 12407, 0, -23336, 0, 12408, 0, -23335, 0, 12409, 0, -23334, 0, 12410, 0, -23333, 0, 12411, 0, -23332, 0, 12412, 0, -23331, 0, 12413, 0, -23330, 0, 12414, 0, -23329, 0, 12415, 0, -23328, 0, 12416, 0, -23327, 0, 12417, 0, -23326, 0, 12418, 0, -23325, 0, 12419, 0, -23324, 0, 12420, 0, -23323, 0, 12421, 0, -23322, 0, 12422, 0, -23321, 0, 12423, 0, -23320, 0, 12424, 0, -23319, 0, 12425, 0, -23318, 0, 12426, 0, -23317, 0, 12427, 0, -23316, 0, 12428, 0, -23315, 0, 12429, 0, -23314, 0, 12430, 0, -23313, 0, 12431, 0, -23312, 0, 12432, 0, -23311, 0, 12433, 0, -23310, 0, 12434, 0, -23309, 0, 12435, 0, -23135, 0, 12449, 0, -23134, 0, 12450, 0, -23133, 0, 12451, 0, -23132, 0, 12452, 0, -23131, 0, 12453, 0, -23130, 0, 12454, 0, -23129, 0, 12455, 0, -23128, 0, 12456, 0, -23127, 0, 12457, 0, -23126, 0, 12458, 0, -23125, 0, 12459, 0, -23124, 0, 12460, 0, -23123, 0, 12461, 0, -23122, 0, 12462, 0, -23121, 0, 12463, 0, -23120, 0, 12464, 0, -23119, 0, 12465, 0, -23118, 0, 12466, 0, -23117, 0, 12467, 0, -23116, 0, 12468, 0, -23115, 0, 12469, 0, -23114, 0, 12470, 0, -23113, 0, 12471, 0, -23112, 0, 12472, 0, -23111, 0, 12473, 0, -23110, 0, 12474, 0, -23109, 0, 12475, 0, -23108, 0, 12476, 0, -23107, 0, 12477, 0, -23106, 0, 12478, 0, -23105, 0, 12479, 0, -23104, 0, 12480, 0, -23103, 0, 12481, 0, -23102, 0, 12482, 0, -23101, 0, 12483, 0, -23100, 0, 12484, 0, -23099, 0, 12485, 0, -23098, 0, 12486, 0, -23097, 0, 12487, 0, -23096, 0, 12488, 0, -23095, 0, 12489, 0, -23094, 0, 12490, 0, -23093, 0, 12491, 0, -23092, 0, 12492, 0, -23091, 0, 12493, 0, -23090, 0, 12494, 0, -23089, 0, 12495, 0, -23088, 0, 12496, 0, -23087, 0, 12497, 0, -23086, 0, 12498, 0, -23085, 0, 12499, 0, -23084, 0, 12500, 0, -23083, 0, 12501, 0, -23082, 0, 12502, 0, -23081, 0, 12503, 0, -23080, 0, 12504, 0, -23079, 0, 12505, 0, -23078, 0, 12506, 0, -23077, 0, 12507, 0, -23076, 0, 12508, 0, -23075, 0, 12509, 0, -23074, 0, 12510, 0, -23073, 0, 12511, 0, -23072, 0, 12512, 0, -23071, 0, 12513, 0, -23070, 0, 12514, 0, -23069, 0, 12515, 0, -23068, 0, 12516, 0, -23067, 0, 12517, 0, -23066, 0, 12518, 0, -23065, 0, 12519, 0, -23064, 0, 12520, 0, -23063, 0, 12521, 0, -23062, 0, 12522, 0, -23061, 0, 12523, 0, -23060, 0, 12524, 0, -23059, 0, 12525, 0, -23058, 0, 12526, 0, -23057, 0, 12527, 0, -23056, 0, 12528, 0, -23055, 0, 12529, 0, -23054, 0, 12530, 0, -23053, 0, 12531, 0, -23052, 0, 12532, 0, -23051, 0, 12533, 0, -23050, 0, 12534, 0, -22879, 0, 913, 0, -22878, 0, 914, 0, -22877, 0, 915, 0, -22876, 0, 916, 0, -22875, 0, 917, 0, -22874, 0, 918, 0, -22873, 0, 919, 0, -22872, 0, 920, 0, -22871, 0, 921, 0, -22870, 0, 922, 0, -22869, 0, 923, 0, -22868, 0, 924, 0, -22867, 0, 925, 0, -22866, 0, 926, 0, -22865, 0, 927, 0, -22864, 0, 928, 0, -22863, 0, 929, 0, -22862, 0, 931, 0, -22861, 0, 932, 0, -22860, 0, 933, 0, -22859, 0, 934, 0, -22858, 0, 935, 0, -22857, 0, 936, 0, -22856, 0, 937, 0, -22847, 0, 945, 0, -22846, 0, 946, 0, -22845, 0, 947, 0, -22844, 0, 948, 0, -22843, 0, 949, 0, -22842, 0, 950, 0, -22841, 0, 951, 0, -22840, 0, 952, 0, -22839, 0, 953, 0, -22838, 0, 954, 0, -22837, 0, 955, 0, -22836, 0, 956, 0, -22835, 0, 957, 0, -22834, 0, 958, 0, -22833, 0, 959, 0, -22832, 0, 960, 0, -22831, 0, 961, 0, -22830, 0, 963, 0, -22829, 0, 964, 0, -22828, 0, 965, 0, -22827, 0, 966, 0, -22826, 0, 967, 0, -22825, 0, 968, 0, -22824, 0, 969, 0, -22623, 0, 1040, 0, -22622, 0, 1041, 0, -22621, 0, 1042, 0, -22620, 0, 1043, 0, -22619, 0, 1044, 0, -22618, 0, 1045, 0, -22617, 0, 1025, 0, -22616, 0, 1046, 0, -22615, 0, 1047, 0, -22614, 0, 1048, 0, -22613, 0, 1049, 0, -22612, 0, 1050, 0, -22611, 0, 1051, 0, -22610, 0, 1052, 0, -22609, 0, 1053, 0, -22608, 0, 1054, 0, -22607, 0, 1055, 0, -22606, 0, 1056, 0, -22605, 0, 1057, 0, -22604, 0, 1058, 0, -22603, 0, 1059, 0, -22602, 0, 1060, 0, -22601, 0, 1061, 0, -22600, 0, 1062, 0, -22599, 0, 1063, 0, -22598, 0, 1064, 0, -22597, 0, 1065, 0, -22596, 0, 1066, 0, -22595, 0, 1067, 0, -22594, 0, 1068, 0, -22593, 0, 1069, 0, -22592, 0, 1070, 0, -22591, 0, 1071, 0, -22575, 0, 1072, 0, -22574, 0, 1073, 0, -22573, 0, 1074, 0, -22572, 0, 1075, 0, -22571, 0, 1076, 0, -22570, 0, 1077, 0, -22569, 0, 1105, 0, -22568, 0, 1078, 0, -22567, 0, 1079, 0, -22566, 0, 1080, 0, -22565, 0, 1081, 0, -22564, 0, 1082, 0, -22563, 0, 1083, 0, -22562, 0, 1084, 0, -22561, 0, 1085, 0, -22560, 0, 1086, 0, -22559, 0, 1087, 0, -22558, 0, 1088, 0, -22557, 0, 1089, 0, -22556, 0, 1090, 0, -22555, 0, 1091, 0, -22554, 0, 1092, 0, -22553, 0, 1093, 0, -22552, 0, 1094, 0, -22551, 0, 1095, 0, -22550, 0, 1096, 0, -22549, 0, 1097, 0, -22548, 0, 1098, 0, -22547, 0, 1099, 0, -22546, 0, 1100, 0, -22545, 0, 1101, 0, -22544, 0, 1102, 0, -22543, 0, 1103, 0, -22367, 0, 9472, 0, -22366, 0, 9474, 0, -22365, 0, 9484, 0, -22364, 0, 9488, 0, -22363, 0, 9496, 0, -22362, 0, 9492, 0, -22361, 0, 9500, 0, -22360, 0, 9516, 0, -22359, 0, 9508, 0, -22358, 0, 9524, 0, -22357, 0, 9532, 0, -22356, 0, 9473, 0, -22355, 0, 9475, 0, -22354, 0, 9487, 0, -22353, 0, 9491, 0, -22352, 0, 9499, 0, -22351, 0, 9495, 0, -22350, 0, 9507, 0, -22349, 0, 9523, 0, -22348, 0, 9515, 0, -22347, 0, 9531, 0, -22346, 0, 9547, 0, -22345, 0, 9504, 0, -22344, 0, 9519, 0, -22343, 0, 9512, 0, -22342, 0, 9527, 0, -22341, 0, 9535, 0, -22340, 0, 9501, 0, -22339, 0, 9520, 0, -22338, 0, 9509, 0, -22337, 0, 9528, 0, -22336, 0, 9538, 0, -20319, 0, 20124, 0, -20318, 0, 21782, 0, -20317, 0, 23043, 0, -20316, 0, -27073, 0, -20315, 0, 21696, 0, -20314, 0, 24859, 0, -20313, 0, 25384, 0, -20312, 0, 23030, 0, -20311, 0, -28638, 0, -20310, 0, -31627, 0, -20309, 0, -31972, 0, -20308, 0, 31312, 0, -20307, 0, 24746, 0, -20306, 0, 25569, 0, -20305, 0, 28197, 0, -20304, 0, 26093, 0, -20303, 0, -31642, 0, -20302, 0, -32090, 0, -20301, 0, -25611, 0, -20300, 0, 26771, 0, -20299, 0, 22311, 0, -20298, 0, 26017, 0, -20297, 0, 25201, 0, -20296, 0, 23451, 0, -20295, 0, 22992, 0, -20294, 0, -31109, 0, -20293, 0, -26380, 0, -20292, 0, 32098, 0, -20291, 0, 32190, 0, -20290, 0, -25714, 0, -20289, 0, 25110, 0, -20288, 0, 31903, 0, -20287, 0, -30537, 0, -20286, 0, 23433, 0, -20285, 0, 24245, 0, -20284, 0, 25353, 0, -20283, 0, 26263, 0, -20282, 0, 26696, 0, -20281, 0, -27193, 0, -20280, 0, -26739, 0, -20279, 0, 26447, 0, -20278, 0, 20197, 0, -20277, 0, 20234, 0, -20276, 0, 20301, 0, -20275, 0, 20381, 0, -20274, 0, 20553, 0, -20273, 0, 22258, 0, -20272, 0, 22839, 0, -20271, 0, 22996, 0, -20270, 0, 23041, 0, -20269, 0, 23561, 0, -20268, 0, 24799, 0, -20267, 0, 24847, 0, -20266, 0, 24944, 0, -20265, 0, 26131, 0, -20264, 0, 26885, 0, -20263, 0, 28858, 0, -20262, 0, 30031, 0, -20261, 0, 30064, 0, -20260, 0, 31227, 0, -20259, 0, 32173, 0, -20258, 0, 32239, 0, -20257, 0, -32573, 0, -20256, 0, -31730, 0, -20255, 0, -30621, 0, -20254, 0, -29950, 0, -20253, 0, -28587, 0, -20252, 0, -28550, 0, -20251, 0, 21307, 0, -20250, 0, 20117, 0, -20249, 0, 20133, 0, -20248, 0, 22495, 0, -20247, 0, -32590, 0, -20246, 0, -28479, 0, -20245, 0, 30959, 0, -20244, 0, 19968, 0, -20243, 0, 22769, 0, -20242, 0, 28322, 0, -20241, 0, -28616, 0, -20240, 0, 31282, 0, -20239, 0, -31960, 0, -20238, 0, -32117, 0, -20237, 0, -25553, 0, -20236, 0, 20801, 0, -20235, 0, 21360, 0, -20234, 0, 21693, 0, -20233, 0, 21729, 0, -20232, 0, 22240, 0, -20231, 0, 23035, 0, -20230, 0, 24341, 0, -20229, 0, -26382, 0, -20228, 0, 28139, 0, -20227, 0, -32540, 0, -20226, 0, -31443, 0, -20063, 0, -27038, 0, -20062, 0, -27024, 0, -20061, 0, -26976, 0, -20060, 0, -26629, 0, -20059, 0, 21515, 0, -20058, 0, 21491, 0, -20057, 0, 23431, 0, -20056, 0, 28879, 0, -20055, 0, 32701, 0, -20054, 0, -28734, 0, -20053, 0, -26904, 0, -20052, 0, 21359, 0, -20051, 0, -25252, 0, -20050, 0, 31418, 0, -20049, 0, 19985, 0, -20048, 0, 30867, 0, -20047, 0, -32260, 0, -20046, 0, 28198, 0, -20045, 0, 22040, 0, -20044, 0, 21764, 0, -20043, 0, 27421, 0, -20042, 0, -31462, 0, -20041, 0, -25541, 0, -20040, 0, 23013, 0, -20039, 0, 21417, 0, -20038, 0, 28006, 0, -20037, 0, 29916, 0, -20036, 0, -27249, 0, -20035, 0, 22082, 0, -20034, 0, 20113, 0, -20033, 0, -28597, 0, -20032, 0, -26894, 0, -20031, 0, -31921, 0, -20030, 0, -26356, 0, -20029, 0, 21473, 0, -20028, 0, 21942, 0, -20027, 0, 23344, 0, -20026, 0, 24433, 0, -20025, 0, 26144, 0, -20024, 0, 26355, 0, -20023, 0, 26628, 0, -20022, 0, 27704, 0, -20021, 0, 27891, 0, -20020, 0, 27945, 0, -20019, 0, 29787, 0, -20018, 0, 30408, 0, -20017, 0, 31310, 0, -20016, 0, -26572, 0, -20015, 0, -32015, 0, -20014, 0, -30629, 0, -20013, 0, -30112, 0, -20012, 0, -27923, 0, -20011, 0, 28082, 0, -20010, 0, 30123, 0, -20009, 0, 30410, 0, -20008, 0, -26171, 0, -20007, 0, 24742, 0, -20006, 0, -29951, 0, -20005, 0, -29302, 0, -20004, 0, -27214, 0, -20003, 0, 27022, 0, -20002, 0, 21421, 0, -20001, 0, 20870, 0, -20000, 0, 22290, 0, -19999, 0, 22576, 0, -19998, 0, 22852, 0, -19997, 0, 23476, 0, -19996, 0, 24310, 0, -19995, 0, 24616, 0, -19994, 0, 25513, 0, -19993, 0, 25588, 0, -19992, 0, 27839, 0, -19991, 0, 28436, 0, -19990, 0, 28814, 0, -19989, 0, 28948, 0, -19988, 0, 29017, 0, -19987, 0, 29141, 0, -19986, 0, 29503, 0, -19985, 0, 32257, 0, -19984, 0, -32138, 0, -19983, 0, -32047, 0, -19982, 0, -31337, 0, -19981, 0, -28576, 0, -19980, 0, -28069, 0, -19979, 0, -25317, 0, -19978, 0, 22633, 0, -19977, 0, 26044, 0, -19976, 0, 27738, 0, -19975, 0, 29989, 0, -19974, 0, 20985, 0, -19973, 0, 22830, 0, -19972, 0, 22885, 0, -19971, 0, 24448, 0, -19970, 0, 24540, 0, -19807, 0, 25276, 0, -19806, 0, 26106, 0, -19805, 0, 27178, 0, -19804, 0, 27431, 0, -19803, 0, 27572, 0, -19802, 0, 29579, 0, -19801, 0, 32705, 0, -19800, 0, -30378, 0, -19799, 0, -25300, 0, -19798, 0, -25330, 0, -19797, 0, -24892, 0, -19796, 0, 23713, 0, -19795, 0, 27798, 0, -19794, 0, -31877, 0, -19793, 0, 20740, 0, -19792, 0, 23627, 0, -19791, 0, 25014, 0, -19790, 0, -32314, 0, -19789, 0, 26742, 0, -19788, 0, 29281, 0, -19787, 0, 20057, 0, -19786, 0, 20474, 0, -19785, 0, 21368, 0, -19784, 0, 24681, 0, -19783, 0, 28201, 0, -19782, 0, 31311, 0, -19781, 0, -26637, 0, -19780, 0, 19979, 0, -19779, 0, 21270, 0, -19778, 0, 20206, 0, -19777, 0, 20309, 0, -19776, 0, 20285, 0, -19775, 0, 20385, 0, -19774, 0, 20339, 0, -19773, 0, 21152, 0, -19772, 0, 21487, 0, -19771, 0, 22025, 0, -19770, 0, 22799, 0, -19769, 0, 23233, 0, -19768, 0, 23478, 0, -19767, 0, 23521, 0, -19766, 0, 31185, 0, -19765, 0, 26247, 0, -19764, 0, 26524, 0, -19763, 0, 26550, 0, -19762, 0, 27468, 0, -19761, 0, 27827, 0, -19760, 0, 28779, 0, -19759, 0, 29634, 0, -19758, 0, 31117, 0, -19757, 0, 31166, 0, -19756, 0, 31292, 0, -19755, 0, 31623, 0, -19754, 0, -32079, 0, -19753, 0, -32037, 0, -19752, 0, -31996, 0, -19751, 0, -31881, 0, -19750, 0, -31761, 0, -19749, 0, -31789, 0, -19748, 0, -30874, 0, -19747, 0, -30030, 0, -19746, 0, 22057, 0, -19745, 0, -29528, 0, -19744, 0, -28698, 0, -19743, 0, -28594, 0, -19742, 0, -26850, 0, -19741, 0, -31094, 0, -19740, 0, 20420, 0, -19739, 0, 23784, 0, -19738, 0, 25105, 0, -19737, 0, 29273, 0, -19736, 0, 30011, 0, -19735, 0, -32283, 0, -19734, 0, -32067, 0, -19733, 0, -30978, 0, -19732, 0, -29504, 0, -19731, 0, -26939, 0, -19730, 0, -26349, 0, -19729, 0, -26155, 0, -19728, 0, 20171, 0, -19727, 0, 20250, 0, -19726, 0, -30237, 0, -19725, 0, 22238, 0, -19724, 0, 22602, 0, -19723, 0, 22730, 0, -19722, 0, 24315, 0, -19721, 0, 24555, 0, -19720, 0, 24618, 0, -19719, 0, 24724, 0, -19718, 0, 24674, 0, -19717, 0, 25040, 0, -19716, 0, 25106, 0, -19715, 0, 25296, 0, -19714, 0, 25913, 0, -19551, 0, -25791, 0, -19550, 0, 26214, 0, -19549, 0, 26800, 0, -19548, 0, 28023, 0, -19547, 0, 28784, 0, -19546, 0, 30028, 0, -19545, 0, 30342, 0, -19544, 0, 32117, 0, -19543, 0, -32091, 0, -19542, 0, -30727, 0, -19541, 0, -27253, 0, -19540, 0, -26994, 0, -19539, 0, -29539, 0, -19538, 0, 20977, 0, -19537, 0, 21182, 0, -19536, 0, 22806, 0, -19535, 0, 21683, 0, -19534, 0, 23475, 0, -19533, 0, 23830, 0, -19532, 0, 24936, 0, -19531, 0, 27010, 0, -19530, 0, 28079, 0, -19529, 0, 30861, 0, -19528, 0, -31541, 0, -19527, 0, -30633, 0, -19526, 0, -30094, 0, -19525, 0, -27737, 0, -19524, 0, -25928, 0, -19523, 0, 28012, 0, -19522, 0, -26200, 0, -19521, 0, -31015, 0, -19520, 0, 22435, 0, -19519, 0, 26623, 0, -19518, 0, -31026, 0, -19517, 0, -28146, 0, -19516, 0, 21123, 0, -19515, 0, 22151, 0, -19514, 0, 21508, 0, -19513, 0, 24275, 0, -19512, 0, 25313, 0, -19511, 0, 25785, 0, -19510, 0, 26684, 0, -19509, 0, 26680, 0, -19508, 0, 27579, 0, -19507, 0, 29554, 0, -19506, 0, 30906, 0, -19505, 0, 31339, 0, -19504, 0, -30310, 0, -19503, 0, -30254, 0, -19502, 0, -29333, 0, -19501, 0, -28925, 0, -19500, 0, -28435, 0, -19499, 0, -27229, 0, -19498, 0, -26988, 0, -19497, 0, -26775, 0, -19496, 0, 23398, 0, -19495, 0, 23731, 0, -19494, 0, 27005, 0, -19493, 0, -26547, 0, -19492, 0, -26546, 0, -19491, 0, 25499, 0, -19490, 0, 31520, 0, -19489, 0, 27179, 0, -19488, 0, 27263, 0, -19487, 0, 26806, 0, -19486, 0, -25587, 0, -19485, 0, 28511, 0, -19484, 0, 21106, 0, -19483, 0, 21917, 0, -19482, 0, 24688, 0, -19481, 0, 25324, 0, -19480, 0, 27963, 0, -19479, 0, 28167, 0, -19478, 0, 28369, 0, -19477, 0, -31653, 0, -19476, 0, -30448, 0, -19475, 0, -28860, 0, -19474, 0, 19988, 0, -19473, 0, -25543, 0, -19472, 0, 21494, 0, -19471, 0, 26907, 0, -19470, 0, 27194, 0, -19469, 0, -26748, 0, -19468, 0, 26666, 0, -19467, 0, 20828, 0, -19466, 0, 31427, 0, -19465, 0, -31566, 0, -19464, 0, -28196, 0, -19463, 0, -27764, 0, -19462, 0, 22107, 0, -19461, 0, -25304, 0, -19460, 0, 26658, 0, -19459, 0, -31995, 0, -19458, 0, -31695, 0, -19295, 0, 31909, 0, -19294, 0, 21000, 0, -19293, 0, -32059, 0, -19292, 0, 29926, 0, -19291, 0, 20094, 0, -19290, 0, 20355, 0, -19289, 0, 20896, 0, -19288, 0, 23506, 0, -19287, 0, 21002, 0, -19286, 0, 21208, 0, -19285, 0, 21223, 0, -19284, 0, 24059, 0, -19283, 0, 21914, 0, -19282, 0, 22570, 0, -19281, 0, 23014, 0, -19280, 0, 23436, 0, -19279, 0, 23448, 0, -19278, 0, 23515, 0, -19277, 0, 24178, 0, -19276, 0, 24185, 0, -19275, 0, 24739, 0, -19274, 0, 24863, 0, -19273, 0, 24931, 0, -19272, 0, 25022, 0, -19271, 0, 25563, 0, -19270, 0, 25954, 0, -19269, 0, 26577, 0, -19268, 0, 26707, 0, -19267, 0, 26874, 0, -19266, 0, 27454, 0, -19265, 0, 27475, 0, -19264, 0, 27735, 0, -19263, 0, 28450, 0, -19262, 0, 28567, 0, -19261, 0, 28485, 0, -19260, 0, 29872, 0, -19259, 0, 29976, 0, -19258, 0, 30435, 0, -19257, 0, 30475, 0, -19256, 0, 31487, 0, -19255, 0, 31649, 0, -19254, 0, 31777, 0, -19253, 0, 32233, 0, -19252, 0, 32566, 0, -19251, 0, 32752, 0, -19250, 0, -32611, 0, -19249, 0, -32154, 0, -19248, 0, -31842, 0, -19247, 0, -30285, 0, -19246, 0, -30004, 0, -19245, 0, -29525, 0, -19244, 0, -28540, 0, -19243, 0, -27567, 0, -19242, 0, -27245, 0, -19241, 0, -27247, 0, -19240, 0, -27230, 0, -19239, 0, -27035, 0, -19238, 0, -26669, 0, -19237, 0, -26328, 0, -19236, 0, -32232, 0, -19235, 0, 20024, 0, -19234, 0, 21547, 0, -19233, 0, 23736, 0, -19232, 0, 24012, 0, -19231, 0, 29609, 0, -19230, 0, 30284, 0, -19229, 0, 30524, 0, -19228, 0, 23721, 0, -19227, 0, 32747, 0, -19226, 0, -29429, 0, -19225, 0, -26943, 0, -19224, 0, -26607, 0, -19223, 0, -26540, 0, -19222, 0, -26536, 0, -19221, 0, 20225, 0, -19220, 0, 20238, 0, -19219, 0, 21361, 0, -19218, 0, 21916, 0, -19217, 0, 22120, 0, -19216, 0, 22522, 0, -19215, 0, 22855, 0, -19214, 0, 23305, 0, -19213, 0, 23492, 0, -19212, 0, 23696, 0, -19211, 0, 24076, 0, -19210, 0, 24190, 0, -19209, 0, 24524, 0, -19208, 0, 25582, 0, -19207, 0, 26426, 0, -19206, 0, 26071, 0, -19205, 0, 26082, 0, -19204, 0, 26399, 0, -19203, 0, 26827, 0, -19202, 0, 26820, 0, -19039, 0, 27231, 0, -19038, 0, 24112, 0, -19037, 0, 27589, 0, -19036, 0, 27671, 0, -19035, 0, 27773, 0, -19034, 0, 30079, 0, -19033, 0, 31048, 0, -19032, 0, 23395, 0, -19031, 0, 31232, 0, -19030, 0, 32000, 0, -19029, 0, 24509, 0, -19028, 0, -30321, 0, -19027, 0, -30184, 0, -19026, 0, -29516, 0, -19025, 0, -29321, 0, -19024, 0, -28980, 0, -19023, 0, -28899, 0, -19022, 0, -26398, 0, -19021, 0, -26098, 0, -19020, 0, -25796, 0, -19019, 0, 20096, 0, -19018, 0, 20605, 0, -19017, 0, 20736, 0, -19016, 0, 22931, 0, -19015, 0, 23452, 0, -19014, 0, 25135, 0, -19013, 0, 25216, 0, -19012, 0, 25836, 0, -19011, 0, 27450, 0, -19010, 0, 29344, 0, -19009, 0, 30097, 0, -19008, 0, 31047, 0, -19007, 0, 32681, 0, -19006, 0, -30725, 0, -19005, 0, -30020, 0, -19004, 0, -29840, 0, -19003, 0, 25516, 0, -19002, 0, -31798, 0, -19001, 0, -26720, 0, -19000, 0, 21513, 0, -18999, 0, 21507, 0, -18998, 0, 21931, 0, -18997, 0, 26708, 0, -18996, 0, 27224, 0, -18995, 0, -30096, 0, -18994, 0, 30759, 0, -18993, 0, 26485, 0, -18992, 0, -24883, 0, -18991, 0, 21364, 0, -18990, 0, 23458, 0, -18989, 0, -32486, 0, -18988, 0, -31152, 0, -18987, 0, -28666, 0, -18986, 0, 19992, 0, -18985, 0, 20037, 0, -18984, 0, 20167, 0, -18983, 0, 20241, 0, -18982, 0, 21450, 0, -18981, 0, 21560, 0, -18980, 0, 23470, 0, -18979, 0, 24339, 0, -18978, 0, 24613, 0, -18977, 0, 25937, 0, -18976, 0, 26429, 0, -18975, 0, 27714, 0, -18974, 0, 27762, 0, -18973, 0, 27875, 0, -18972, 0, 28792, 0, -18971, 0, 29699, 0, -18970, 0, 31350, 0, -18969, 0, 31406, 0, -18968, 0, 31496, 0, -18967, 0, 32026, 0, -18966, 0, 31998, 0, -18965, 0, 32102, 0, -18964, 0, 26087, 0, -18963, 0, 29275, 0, -18962, 0, 21435, 0, -18961, 0, 23621, 0, -18960, 0, 24040, 0, -18959, 0, 25298, 0, -18958, 0, 25312, 0, -18957, 0, 25369, 0, -18956, 0, 28192, 0, -18955, 0, -31142, 0, -18954, 0, -30159, 0, -18953, 0, -29219, 0, -18952, 0, -27912, 0, -18951, 0, 28417, 0, -18950, 0, 31142, 0, -18949, 0, -25766, 0, -18948, 0, 20136, 0, -18947, 0, 20139, 0, -18946, 0, 20140, 0, -18783, 0, 20379, 0, -18782, 0, 20384, 0, -18781, 0, 20689, 0, -18780, 0, 20807, 0, -18779, 0, 31478, 0, -18778, 0, 20849, 0, -18777, 0, 20982, 0, -18776, 0, 21332, 0, -18775, 0, 21281, 0, -18774, 0, 21375, 0, -18773, 0, 21483, 0, -18772, 0, 21932, 0, -18771, 0, 22659, 0, -18770, 0, 23777, 0, -18769, 0, 24375, 0, -18768, 0, 24394, 0, -18767, 0, 24623, 0, -18766, 0, 24656, 0, -18765, 0, 24685, 0, -18764, 0, 25375, 0, -18763, 0, 25945, 0, -18762, 0, 27211, 0, -18761, 0, 27841, 0, -18760, 0, 29378, 0, -18759, 0, 29421, 0, -18758, 0, 30703, 0, -18757, 0, -32520, 0, -18756, 0, -32507, 0, -18755, 0, -32248, 0, -18754, 0, -31410, 0, -18753, 0, -28425, 0, -18752, 0, -27679, 0, -18751, 0, -26625, 0, -18750, 0, -26281, 0, -18749, 0, -26022, 0, -18748, 0, 20208, 0, -18747, 0, 20957, 0, -18746, 0, 23597, 0, -18745, 0, 26241, 0, -18744, 0, 26989, 0, -18743, 0, 23616, 0, -18742, 0, 26354, 0, -18741, 0, 26997, 0, -18740, 0, 29577, 0, -18739, 0, 26704, 0, -18738, 0, 31873, 0, -18737, 0, 20677, 0, -18736, 0, 21220, 0, -18735, 0, 22343, 0, -18734, 0, 24062, 0, -18733, 0, -27866, 0, -18732, 0, 26020, 0, -18731, 0, 27427, 0, -18730, 0, 27453, 0, -18729, 0, 29748, 0, -18728, 0, 31105, 0, -18727, 0, 31165, 0, -18726, 0, 31563, 0, -18725, 0, 32202, 0, -18724, 0, -32071, 0, -18723, 0, -31796, 0, -18722, 0, -30593, 0, -18721, 0, -30369, 0, -18720, 0, -29895, 0, -18719, 0, -28719, 0, -18718, 0, -28207, 0, -18717, 0, 21535, 0, -18716, 0, -28032, 0, -18715, 0, 20061, 0, -18714, 0, 20534, 0, -18713, 0, 21477, 0, -18712, 0, 21306, 0, -18711, 0, 29399, 0, -18710, 0, 29590, 0, -18709, 0, 30697, 0, -18708, 0, -32026, 0, -18707, 0, -29009, 0, -18706, 0, -26170, 0, -18705, 0, -26168, 0, -18704, 0, -26158, 0, -18703, 0, 20855, 0, -18702, 0, 24858, 0, -18701, 0, -31138, 0, -18700, 0, 21936, 0, -18699, 0, 31354, 0, -18698, 0, 20598, 0, -18697, 0, 23507, 0, -18696, 0, -28601, 0, -18695, 0, -27003, 0, -18694, 0, 20018, 0, -18693, 0, 27355, 0, -18692, 0, -28185, 0, -18691, 0, 23633, 0, -18690, 0, 23624, 0, -18527, 0, 25496, 0, -18526, 0, 31391, 0, -18525, 0, 27795, 0, -18524, 0, -26764, 0, -18523, 0, -28831, 0, -18522, 0, 31402, 0, -18521, 0, 29066, 0, -18520, 0, -27000, 0, -18519, 0, 31874, 0, -18518, 0, 26647, 0, -18517, 0, 32368, 0, -18516, 0, 26705, 0, -18515, 0, -27796, 0, -18514, 0, 21234, 0, -18513, 0, 21531, 0, -18512, 0, -31317, 0, -18511, 0, -30189, 0, -18510, 0, 32676, 0, -18509, 0, -28979, 0, -18508, 0, -28447, 0, -18507, 0, 21350, 0, -18506, 0, -30584, 0, -18505, 0, 31041, 0, -18504, 0, 20418, 0, -18503, 0, 20670, 0, -18502, 0, 21009, 0, -18501, 0, 20804, 0, -18500, 0, 21843, 0, -18499, 0, 22317, 0, -18498, 0, 29674, 0, -18497, 0, 22411, 0, -18496, 0, 22865, 0, -18495, 0, 24418, 0, -18494, 0, 24452, 0, -18493, 0, 24693, 0, -18492, 0, 24950, 0, -18491, 0, 24935, 0, -18490, 0, 25001, 0, -18489, 0, 25522, 0, -18488, 0, 25658, 0, -18487, 0, 25964, 0, -18486, 0, 26223, 0, -18485, 0, 26690, 0, -18484, 0, 28179, 0, -18483, 0, 30054, 0, -18482, 0, 31293, 0, -18481, 0, 31995, 0, -18480, 0, 32076, 0, -18479, 0, 32153, 0, -18478, 0, 32331, 0, -18477, 0, 32619, 0, -18476, 0, -31986, 0, -18475, 0, -31926, 0, -18474, 0, -31027, 0, -18473, 0, -30200, 0, -18472, 0, -30109, 0, -18471, 0, -29850, 0, -18470, 0, -28931, 0, -18469, 0, -26598, 0, -18468, 0, -25201, 0, -18467, 0, -32072, 0, -18466, 0, -28722, 0, -18465, 0, -25624, 0, -18464, 0, 21127, 0, -18463, 0, 25119, 0, -18462, 0, 25731, 0, -18461, 0, 28608, 0, -18460, 0, -26983, 0, -18459, 0, 26689, 0, -18458, 0, 20625, 0, -18457, 0, 27424, 0, -18456, 0, 27770, 0, -18455, 0, 28500, 0, -18454, 0, 31348, 0, -18453, 0, 32080, 0, -18452, 0, -30656, 0, -18451, 0, -30173, 0, -18450, 0, 26376, 0, -18449, 0, 20214, 0, -18448, 0, 20537, 0, -18447, 0, 20518, 0, -18446, 0, 20581, 0, -18445, 0, 20860, 0, -18444, 0, 21048, 0, -18443, 0, 21091, 0, -18442, 0, 21927, 0, -18441, 0, 22287, 0, -18440, 0, 22533, 0, -18439, 0, 23244, 0, -18438, 0, 24314, 0, -18437, 0, 25010, 0, -18436, 0, 25080, 0, -18435, 0, 25331, 0, -18434, 0, 25458, 0, -18271, 0, 26908, 0, -18270, 0, 27177, 0, -18269, 0, 29309, 0, -18268, 0, 29356, 0, -18267, 0, 29486, 0, -18266, 0, 30740, 0, -18265, 0, 30831, 0, -18264, 0, 32121, 0, -18263, 0, 30476, 0, -18262, 0, -32599, 0, -18261, 0, -30325, 0, -18260, 0, -29927, 0, -18259, 0, -29470, 0, -18258, 0, -28974, 0, -18257, 0, -28573, 0, -18256, 0, -27787, 0, -18255, 0, -27014, 0, -18254, 0, -26539, 0, -18253, 0, -26093, 0, -18252, 0, -24968, 0, -18251, 0, 20803, 0, -18250, 0, 21407, 0, -18249, 0, 21427, 0, -18248, 0, 24187, 0, -18247, 0, 24358, 0, -18246, 0, 28187, 0, -18245, 0, 28304, 0, -18244, 0, 29572, 0, -18243, 0, 29694, 0, -18242, 0, 32067, 0, -18241, 0, -32201, 0, -18240, 0, -30208, 0, -18239, 0, -29958, 0, -18238, 0, -27056, 0, -18237, 0, 20046, 0, -18236, 0, 20491, 0, -18235, 0, 21476, 0, -18234, 0, 21628, 0, -18233, 0, 22266, 0, -18232, 0, 22993, 0, -18231, 0, 23396, 0, -18230, 0, 24049, 0, -18229, 0, 24235, 0, -18228, 0, 24359, 0, -18227, 0, 25144, 0, -18226, 0, 25925, 0, -18225, 0, 26543, 0, -18224, 0, 28246, 0, -18223, 0, 29392, 0, -18222, 0, 31946, 0, -18221, 0, -30540, 0, -18220, 0, -32607, 0, -18219, 0, -32543, 0, -18218, 0, -31760, 0, -18217, 0, -31154, 0, -18216, 0, -30073, 0, -18215, 0, -29208, 0, -18214, 0, -28105, 0, -18213, 0, -26937, 0, -18212, 0, -26521, 0, -18211, 0, -24813, 0, -18210, 0, 20116, 0, -18209, 0, 20114, 0, -18208, 0, 20237, 0, -18207, 0, 21320, 0, -18206, 0, 21577, 0, -18205, 0, 21566, 0, -18204, 0, 23087, 0, -18203, 0, 24460, 0, -18202, 0, 24481, 0, -18201, 0, 24735, 0, -18200, 0, 26791, 0, -18199, 0, 27278, 0, -18198, 0, 29786, 0, -18197, 0, 30849, 0, -18196, 0, -30050, 0, -18195, 0, -30044, 0, -18194, 0, -29833, 0, -18193, 0, -28272, 0, -18192, 0, 20062, 0, -18191, 0, -25655, 0, -18190, 0, 20132, 0, -18189, 0, 20348, 0, -18188, 0, 20399, 0, -18187, 0, 20505, 0, -18186, 0, 20502, 0, -18185, 0, 20809, 0, -18184, 0, 20844, 0, -18183, 0, 21151, 0, -18182, 0, 21177, 0, -18181, 0, 21246, 0, -18180, 0, 21402, 0, -18179, 0, 21475, 0, -18178, 0, 21521, 0, -18015, 0, 21518, 0, -18014, 0, 21897, 0, -18013, 0, 22353, 0, -18012, 0, 22434, 0, -18011, 0, 22909, 0, -18010, 0, 23380, 0, -18009, 0, 23389, 0, -18008, 0, 23439, 0, -18007, 0, 24037, 0, -18006, 0, 24039, 0, -18005, 0, 24055, 0, -18004, 0, 24184, 0, -18003, 0, 24195, 0, -18002, 0, 24218, 0, -18001, 0, 24247, 0, -18000, 0, 24344, 0, -17999, 0, 24658, 0, -17998, 0, 24908, 0, -17997, 0, 25239, 0, -17996, 0, 25304, 0, -17995, 0, 25511, 0, -17994, 0, 25915, 0, -17993, 0, 26114, 0, -17992, 0, 26179, 0, -17991, 0, 26356, 0, -17990, 0, 26477, 0, -17989, 0, 26657, 0, -17988, 0, 26775, 0, -17987, 0, 27083, 0, -17986, 0, 27743, 0, -17985, 0, 27946, 0, -17984, 0, 28009, 0, -17983, 0, 28207, 0, -17982, 0, 28317, 0, -17981, 0, 30002, 0, -17980, 0, 30343, 0, -17979, 0, 30828, 0, -17978, 0, 31295, 0, -17977, 0, 31968, 0, -17976, 0, 32005, 0, -17975, 0, 32024, 0, -17974, 0, 32094, 0, -17973, 0, 32177, 0, -17972, 0, -32747, 0, -17971, 0, -32765, 0, -17970, 0, -32593, 0, -17969, 0, -32591, 0, -17968, 0, -32428, 0, -17967, 0, -32369, 0, -17966, 0, -32214, 0, -17965, 0, -31918, 0, -17964, 0, -30644, 0, -17963, 0, -30623, 0, -17962, 0, -29925, 0, -17961, 0, -29534, 0, -17960, 0, -29444, 0, -17959, 0, -28470, 0, -17958, 0, -28299, 0, -17957, 0, -28047, 0, -17956, 0, 30783, 0, -17955, 0, -27908, 0, -17954, 0, -27228, 0, -17953, 0, -27059, 0, -17952, 0, -26619, 0, -17951, 0, -26215, 0, -17950, 0, -25896, 0, -17949, 0, -25285, 0, -17948, 0, 21083, 0, -17947, 0, 21163, 0, -17946, 0, 21495, 0, -17945, 0, 21512, 0, -17944, 0, 22741, 0, -17943, 0, 25335, 0, -17942, 0, 28640, 0, -17941, 0, -29590, 0, -17940, 0, -28833, 0, -17939, 0, -24903, 0, -17938, 0, 20811, 0, -17937, 0, 21051, 0, -17936, 0, 21578, 0, -17935, 0, 22269, 0, -17934, 0, 31296, 0, -17933, 0, -28297, 0, -17932, 0, -25248, 0, -17931, 0, -24878, 0, -17930, 0, 29508, 0, -17929, 0, 28425, 0, -17928, 0, -32400, 0, -17927, 0, 29969, 0, -17926, 0, 24573, 0, -17925, 0, 24794, 0, -17924, 0, -25944, 0, -17923, 0, 29403, 0, -17922, 0, -28740, 0, -17759, 0, 27492, 0, -17758, 0, -26621, 0, -17757, 0, 20170, 0, -17756, 0, 22256, 0, -17755, 0, 22372, 0, -17754, 0, 22718, 0, -17753, 0, 23130, 0, -17752, 0, 24680, 0, -17751, 0, 25031, 0, -17750, 0, 26127, 0, -17749, 0, 26118, 0, -17748, 0, 26681, 0, -17747, 0, 26801, 0, -17746, 0, 28151, 0, -17745, 0, 30165, 0, -17744, 0, 32058, 0, -17743, 0, -32146, 0, -17742, 0, -25790, 0, -17741, 0, 20123, 0, -17740, 0, 20304, 0, -17739, 0, 21449, 0, -17738, 0, 21766, 0, -17737, 0, 23919, 0, -17736, 0, 24038, 0, -17735, 0, 24046, 0, -17734, 0, 26619, 0, -17733, 0, 27801, 0, -17732, 0, 29811, 0, -17731, 0, 30722, 0, -17730, 0, -30128, 0, -17729, 0, -27754, 0, -17728, 0, -30497, 0, -17727, 0, 22352, 0, -17726, 0, 24231, 0, -17725, 0, 25387, 0, -17724, 0, 20661, 0, -17723, 0, 20652, 0, -17722, 0, 20877, 0, -17721, 0, 26368, 0, -17720, 0, 21705, 0, -17719, 0, 22622, 0, -17718, 0, 22971, 0, -17717, 0, 23472, 0, -17716, 0, 24425, 0, -17715, 0, 25165, 0, -17714, 0, 25505, 0, -17713, 0, 26685, 0, -17712, 0, 27507, 0, -17711, 0, 28168, 0, -17710, 0, 28797, 0, -17709, 0, -28217, 0, -17708, 0, 29312, 0, -17707, 0, 30741, 0, -17706, 0, 30758, 0, -17705, 0, 31085, 0, -17704, 0, 25998, 0, -17703, 0, 32048, 0, -17702, 0, -31780, 0, -17701, 0, -30527, 0, -17700, 0, -28919, 0, -17699, 0, -26981, 0, -17698, 0, 21092, 0, -17697, 0, 22312, 0, -17696, 0, 26448, 0, -17695, 0, 32618, 0, -17694, 0, -29535, 0, -17693, 0, 20916, 0, -17692, 0, 22338, 0, -17691, 0, -27094, 0, -17690, 0, 22586, 0, -17689, 0, 27018, 0, -17688, 0, -32588, 0, -17687, 0, 21682, 0, -17686, 0, 23822, 0, -17685, 0, 22524, 0, -17684, 0, 30869, 0, -17683, 0, -25094, 0, -17682, 0, 20316, 0, -17681, 0, 21066, 0, -17680, 0, 21643, 0, -17679, 0, 25662, 0, -17678, 0, 26152, 0, -17677, 0, 26388, 0, -17676, 0, 26613, 0, -17675, 0, 31364, 0, -17674, 0, 31574, 0, -17673, 0, 32034, 0, -17672, 0, -27857, 0, -17671, 0, 26716, 0, -17670, 0, -25683, 0, -17669, 0, 31545, 0, -17668, 0, 21273, 0, -17667, 0, 20874, 0, -17666, 0, 21047, 0, -17503, 0, 23519, 0, -17502, 0, 25334, 0, -17501, 0, 25774, 0, -17500, 0, 25830, 0, -17499, 0, 26413, 0, -17498, 0, 27578, 0, -17497, 0, -31319, 0, -17496, 0, -26927, 0, -17495, 0, 30352, 0, -17494, 0, -25642, 0, -17493, 0, 25420, 0, -17492, 0, -27898, 0, -17491, 0, -25685, 0, -17490, 0, 30399, 0, -17489, 0, 26194, 0, -17488, 0, 19977, 0, -17487, 0, 20632, 0, -17486, 0, 21442, 0, -17485, 0, 23665, 0, -17484, 0, 24808, 0, -17483, 0, 25746, 0, -17482, 0, 25955, 0, -17481, 0, 26719, 0, -17480, 0, 29158, 0, -17479, 0, 29642, 0, -17478, 0, 29987, 0, -17477, 0, 31639, 0, -17476, 0, 32386, 0, -17475, 0, -31083, 0, -17474, 0, -29821, 0, -17473, 0, -29477, 0, -17472, 0, -28296, 0, -17471, 0, -26352, 0, -17470, 0, 26028, 0, -17469, 0, 26283, 0, -17468, 0, 27531, 0, -17467, 0, 20181, 0, -17466, 0, 20180, 0, -17465, 0, 20282, 0, -17464, 0, 20351, 0, -17463, 0, 21050, 0, -17462, 0, 21496, 0, -17461, 0, 21490, 0, -17460, 0, 21987, 0, -17459, 0, 22235, 0, -17458, 0, 22763, 0, -17457, 0, 22987, 0, -17456, 0, 22985, 0, -17455, 0, 23039, 0, -17454, 0, 23376, 0, -17453, 0, 23629, 0, -17452, 0, 24066, 0, -17451, 0, 24107, 0, -17450, 0, 24535, 0, -17449, 0, 24605, 0, -17448, 0, 25351, 0, -17447, 0, 25903, 0, -17446, 0, 23388, 0, -17445, 0, 26031, 0, -17444, 0, 26045, 0, -17443, 0, 26088, 0, -17442, 0, 26525, 0, -17441, 0, 27490, 0, -17440, 0, 27515, 0, -17439, 0, 27663, 0, -17438, 0, 29509, 0, -17437, 0, 31049, 0, -17436, 0, 31169, 0, -17435, 0, 31992, 0, -17434, 0, 32025, 0, -17433, 0, 32043, 0, -17432, 0, -32606, 0, -17431, 0, -32510, 0, -17430, 0, -32269, 0, -17429, 0, -30314, 0, -17428, 0, -30114, 0, -17427, 0, -30103, 0, -17426, 0, -30106, 0, -17425, 0, -30068, 0, -17424, 0, -29970, 0, -17423, 0, -29497, 0, -17422, 0, -29476, 0, -17421, 0, -26932, 0, -17420, 0, -26372, 0, -17419, 0, 27503, 0, -17418, 0, 20107, 0, -17417, 0, 20284, 0, -17416, 0, 20365, 0, -17415, 0, 20816, 0, -17414, 0, 23383, 0, -17413, 0, 23546, 0, -17412, 0, 24904, 0, -17411, 0, 25345, 0, -17410, 0, 26178, 0, -17247, 0, 27425, 0, -17246, 0, 28363, 0, -17245, 0, 27835, 0, -17244, 0, 29246, 0, -17243, 0, 29885, 0, -17242, 0, 30164, 0, -17241, 0, 30913, 0, -17240, 0, 31034, 0, -17239, 0, -32756, 0, -17238, 0, -32717, 0, -17237, 0, -32278, 0, -17236, 0, -31596, 0, -17235, 0, -28770, 0, -17234, 0, 27728, 0, -17233, 0, -24961, 0, -17232, 0, 24335, 0, -17231, 0, -29864, 0, -17230, 0, -25301, 0, -17229, 0, 31482, 0, -17228, 0, -28936, 0, -17227, 0, 23437, 0, -17226, 0, -26901, 0, -17225, 0, 19971, 0, -17224, 0, 21489, 0, -17223, 0, 22519, 0, -17222, 0, 22833, 0, -17221, 0, 23241, 0, -17220, 0, 23460, 0, -17219, 0, 24713, 0, -17218, 0, 28287, 0, -17217, 0, 28422, 0, -17216, 0, 30142, 0, -17215, 0, -29462, 0, -17214, 0, 23455, 0, -17213, 0, -31488, 0, -17212, 0, 31712, 0, -17211, 0, 20594, 0, -17210, 0, 26612, 0, -17209, 0, -32099, 0, -17208, 0, 23649, 0, -17207, 0, -31414, 0, -17206, 0, 32286, 0, -17205, 0, -32242, 0, -17204, 0, 20889, 0, -17203, 0, 23556, 0, -17202, 0, 25448, 0, -17201, 0, -29338, 0, -17200, 0, 26012, 0, -17199, 0, 29038, 0, -17198, 0, 31038, 0, -17197, 0, 32023, 0, -17196, 0, -32763, 0, -17195, 0, -29923, 0, -17194, 0, -28982, 0, -17193, 0, -28562, 0, -17192, 0, -31033, 0, -17191, 0, -28502, 0, -17190, 0, 20511, 0, -17189, 0, 21242, 0, -17188, 0, 23610, 0, -17187, 0, 26451, 0, -17186, 0, 28796, 0, -17185, 0, 29237, 0, -17184, 0, -28340, 0, -17183, 0, -28216, 0, -17182, 0, -27861, 0, -17181, 0, -32027, 0, -17180, 0, 23490, 0, -17179, 0, 24369, 0, -17178, 0, 24825, 0, -17177, 0, 20027, 0, -17176, 0, 21462, 0, -17175, 0, 23432, 0, -17174, 0, 25163, 0, -17173, 0, 26417, 0, -17172, 0, 27530, 0, -17171, 0, 29417, 0, -17170, 0, 29664, 0, -17169, 0, 31278, 0, -17168, 0, -32405, 0, -17167, 0, -29277, 0, -17166, 0, -28334, 0, -17165, 0, -26218, 0, -17164, 0, 20754, 0, -17163, 0, 21463, 0, -17162, 0, 21610, 0, -17161, 0, 23551, 0, -17160, 0, 25480, 0, -17159, 0, 27193, 0, -17158, 0, 32172, 0, -17157, 0, -26880, 0, -17156, 0, 22234, 0, -17155, 0, 21454, 0, -17154, 0, 21608, 0, -16991, 0, 23447, 0, -16990, 0, 23601, 0, -16989, 0, 24030, 0, -16988, 0, 20462, 0, -16987, 0, 24833, 0, -16986, 0, 25342, 0, -16985, 0, 27954, 0, -16984, 0, 31168, 0, -16983, 0, 31179, 0, -16982, 0, 32066, 0, -16981, 0, 32333, 0, -16980, 0, 32722, 0, -16979, 0, -32275, 0, -16978, 0, -32225, 0, -16977, 0, -31600, 0, -16976, 0, -30650, 0, -16975, 0, -30350, 0, -16974, 0, -29808, 0, -16973, 0, -29068, 0, -16972, 0, -28881, 0, -16971, 0, -28623, 0, -16970, 0, -28341, 0, -16969, 0, -28308, 0, -16968, 0, -26938, 0, -16967, 0, -28260, 0, -16966, 0, 20160, 0, -16965, 0, 20303, 0, -16964, 0, 20805, 0, -16963, 0, 21313, 0, -16962, 0, 24467, 0, -16961, 0, 25102, 0, -16960, 0, 26580, 0, -16959, 0, 27713, 0, -16958, 0, 28171, 0, -16957, 0, 29539, 0, -16956, 0, 32294, 0, -16955, 0, -28211, 0, -16954, 0, -28029, 0, -16953, 0, 21460, 0, -16952, 0, 22809, 0, -16951, 0, 23487, 0, -16950, 0, 28113, 0, -16949, 0, 31069, 0, -16948, 0, 32302, 0, -16947, 0, 31899, 0, -16946, 0, 22654, 0, -16945, 0, 29087, 0, -16944, 0, 20986, 0, -16943, 0, -30637, 0, -16942, 0, -28688, 0, -16941, 0, 20426, 0, -16940, 0, 23803, 0, -16939, 0, 26149, 0, -16938, 0, 30636, 0, -16937, 0, 31459, 0, -16936, 0, -32228, 0, -16935, 0, -26113, 0, -16934, 0, 20934, 0, -16933, 0, 24490, 0, -16932, 0, 26092, 0, -16931, 0, 26991, 0, -16930, 0, 27529, 0, -16929, 0, 28147, 0, -16928, 0, 28310, 0, -16927, 0, 28516, 0, -16926, 0, 30462, 0, -16925, 0, 32020, 0, -16924, 0, 24033, 0, -16923, 0, -28555, 0, -16922, 0, -28281, 0, -16921, 0, -26618, 0, -16920, 0, 20966, 0, -16919, 0, 21021, 0, -16918, 0, 25152, 0, -16917, 0, 26257, 0, -16916, 0, 26329, 0, -16915, 0, 28186, 0, -16914, 0, 24246, 0, -16913, 0, 32210, 0, -16912, 0, 32626, 0, -16911, 0, 26360, 0, -16910, 0, -31313, 0, -16909, 0, -31241, 0, -16908, 0, -29960, 0, -16907, 0, 21161, 0, -16906, 0, 21465, 0, -16905, 0, 22899, 0, -16904, 0, 24207, 0, -16903, 0, 24464, 0, -16902, 0, 24661, 0, -16901, 0, -27932, 0, -16900, 0, -27036, 0, -16899, 0, 20663, 0, -16898, 0, 20767, 0, -16735, 0, 21213, 0, -16734, 0, 21280, 0, -16733, 0, 21319, 0, -16732, 0, 21484, 0, -16731, 0, 21736, 0, -16730, 0, 21830, 0, -16729, 0, 21809, 0, -16728, 0, 22039, 0, -16727, 0, 22888, 0, -16726, 0, 22974, 0, -16725, 0, 23100, 0, -16724, 0, 23477, 0, -16723, 0, 23558, 0, -16722, 0, 23567, 0, -16721, 0, 23569, 0, -16720, 0, 23578, 0, -16719, 0, 24196, 0, -16718, 0, 24202, 0, -16717, 0, 24288, 0, -16716, 0, 24432, 0, -16715, 0, 25215, 0, -16714, 0, 25220, 0, -16713, 0, 25307, 0, -16712, 0, 25484, 0, -16711, 0, 25463, 0, -16710, 0, 26119, 0, -16709, 0, 26124, 0, -16708, 0, 26157, 0, -16707, 0, 26230, 0, -16706, 0, 26494, 0, -16705, 0, 26786, 0, -16704, 0, 27167, 0, -16703, 0, 27189, 0, -16702, 0, 27836, 0, -16701, 0, 28040, 0, -16700, 0, 28169, 0, -16699, 0, 28248, 0, -16698, 0, 28988, 0, -16697, 0, 28966, 0, -16696, 0, 29031, 0, -16695, 0, 30151, 0, -16694, 0, 30465, 0, -16693, 0, 30813, 0, -16692, 0, 30977, 0, -16691, 0, 31077, 0, -16690, 0, 31216, 0, -16689, 0, 31456, 0, -16688, 0, 31505, 0, -16687, 0, 31911, 0, -16686, 0, 32057, 0, -16685, 0, -32618, 0, -16684, 0, -31786, 0, -16683, 0, -31605, 0, -16682, 0, -31415, 0, -16681, 0, -30627, 0, -16680, 0, -30477, 0, -16679, 0, -30177, 0, -16678, 0, -30148, 0, -16677, 0, -30124, 0, -16676, 0, -30093, 0, -16675, 0, -29599, 0, -16674, 0, -29474, 0, -16673, 0, -28252, 0, -16672, 0, -28058, 0, -16671, 0, -27778, 0, -16670, 0, -27624, 0, -16669, 0, -26980, 0, -16668, 0, -26728, 0, -16667, 0, 19978, 0, -16666, 0, 19976, 0, -16665, 0, 19998, 0, -16664, 0, 20055, 0, -16663, 0, 20887, 0, -16662, 0, 21104, 0, -16661, 0, 22478, 0, -16660, 0, 22580, 0, -16659, 0, 22732, 0, -16658, 0, 23330, 0, -16657, 0, 24120, 0, -16656, 0, 24773, 0, -16655, 0, 25854, 0, -16654, 0, 26465, 0, -16653, 0, 26454, 0, -16652, 0, 27972, 0, -16651, 0, 29366, 0, -16650, 0, 30067, 0, -16649, 0, 31331, 0, -16648, 0, -31560, 0, -16647, 0, -29838, 0, -16646, 0, -28232, 0, -16645, 0, -27872, 0, -16644, 0, 22065, 0, -16643, 0, 22516, 0, -16642, 0, -26370, 0, -16479, 0, 25325, 0, -16478, 0, 26893, 0, -16477, 0, 27542, 0, -16476, 0, 29165, 0, -16475, 0, 32340, 0, -16474, 0, -32649, 0, -16473, 0, -32142, 0, -16472, 0, -30234, 0, -16471, 0, -26401, 0, -16470, 0, -30891, 0, -16469, 0, -28751, 0, -16468, 0, 23611, 0, -16467, 0, 20280, 0, -16466, 0, 20449, 0, -16465, 0, 20405, 0, -16464, 0, 21767, 0, -16463, 0, 23072, 0, -16462, 0, 23517, 0, -16461, 0, 23529, 0, -16460, 0, 24515, 0, -16459, 0, 24910, 0, -16458, 0, 25391, 0, -16457, 0, 26032, 0, -16456, 0, 26187, 0, -16455, 0, 26862, 0, -16454, 0, 27035, 0, -16453, 0, 28024, 0, -16452, 0, 28145, 0, -16451, 0, 30003, 0, -16450, 0, 30137, 0, -16449, 0, 30495, 0, -16448, 0, 31070, 0, -16447, 0, 31206, 0, -16446, 0, 32051, 0, -16445, 0, -32285, 0, -16444, 0, -32081, 0, -16443, 0, -31318, 0, -16442, 0, -30294, 0, -16441, 0, -30150, 0, -16440, 0, -29013, 0, -16439, 0, -28773, 0, -16438, 0, -28622, 0, -16437, 0, -28195, 0, -16436, 0, -26873, 0, -16435, 0, 20154, 0, -16434, 0, 20161, 0, -16433, 0, 20995, 0, -16432, 0, 22645, 0, -16431, 0, 22764, 0, -16430, 0, 23563, 0, -16429, 0, 29978, 0, -16428, 0, 23613, 0, -16427, 0, -32434, 0, -16426, 0, -30198, 0, -16425, 0, -28731, 0, -16424, 0, -27037, 0, -16423, 0, -26771, 0, -16422, 0, 31525, 0, -16421, 0, -30001, 0, -16420, 0, -26616, 0, -16419, 0, -28318, 0, -16418, 0, 22259, 0, -16417, 0, 21416, 0, -16416, 0, -28649, 0, -16415, 0, 21561, 0, -16414, 0, 22402, 0, -16413, 0, 24101, 0, -16412, 0, 25512, 0, -16411, 0, 27700, 0, -16410, 0, 28810, 0, -16409, 0, 30561, 0, -16408, 0, 31883, 0, -16407, 0, 32736, 0, -16406, 0, -30608, 0, -16405, 0, -28606, 0, -16404, 0, -28332, 0, -16403, 0, -27888, 0, -16402, 0, -27880, 0, -16401, 0, -26993, 0, -16400, 0, 29790, 0, -16399, 0, -25916, 0, -16398, 0, 23815, 0, -16397, 0, 23913, 0, -16396, 0, 25968, 0, -16395, 0, 26530, 0, -16394, 0, -29272, 0, -16393, 0, -26917, 0, -16392, 0, 25454, 0, -16391, 0, 26441, 0, -16390, 0, 26905, 0, -16389, 0, -31803, 0, -16388, 0, -26601, 0, -16387, 0, -26944, 0, -16386, 0, -30466, 0, -16223, 0, 28548, 0, -16222, 0, 25722, 0, -16221, 0, 23544, 0, -16220, 0, 19990, 0, -16219, 0, 28716, 0, -16218, 0, 30045, 0, -16217, 0, 26159, 0, -16216, 0, 20932, 0, -16215, 0, 21046, 0, -16214, 0, 21218, 0, -16213, 0, 22995, 0, -16212, 0, 24449, 0, -16211, 0, 24615, 0, -16210, 0, 25104, 0, -16209, 0, 25919, 0, -16208, 0, 25972, 0, -16207, 0, 26143, 0, -16206, 0, 26228, 0, -16205, 0, 26866, 0, -16204, 0, 26646, 0, -16203, 0, 27491, 0, -16202, 0, 28165, 0, -16201, 0, 29298, 0, -16200, 0, 29983, 0, -16199, 0, 30427, 0, -16198, 0, 31934, 0, -16197, 0, -32682, 0, -16196, 0, 22768, 0, -16195, 0, -30467, 0, -16194, 0, -30337, 0, -16193, 0, -30048, 0, -16192, 0, -30061, 0, -16191, 0, -30005, 0, -16190, 0, -28643, 0, -16189, 0, -28270, 0, -16188, 0, -26798, 0, -16187, 0, -26791, 0, -16186, 0, 25993, 0, -16185, 0, 31246, 0, -16184, 0, -32506, 0, -16183, 0, -26949, 0, -16182, 0, 24109, 0, -16181, 0, 24796, 0, -16180, 0, 25114, 0, -16179, 0, 26021, 0, -16178, 0, 26132, 0, -16177, 0, 26512, 0, -16176, 0, 30707, 0, -16175, 0, 31309, 0, -16174, 0, 31821, 0, -16173, 0, 32318, 0, -16172, 0, -32502, 0, -16171, 0, -29524, 0, -16170, 0, -29340, 0, -16169, 0, -29215, 0, -16168, 0, -29089, 0, -16167, 0, 30889, 0, -16166, 0, 20999, 0, -16165, 0, 25305, 0, -16164, 0, 25509, 0, -16163, 0, 25666, 0, -16162, 0, 25240, 0, -16161, 0, -30163, 0, -16160, 0, 31363, 0, -16159, 0, 31680, 0, -16158, 0, -30036, 0, -16157, 0, -26902, 0, -16156, 0, 32118, 0, -16155, 0, -32244, 0, -16154, 0, -30903, 0, -16153, 0, 20185, 0, -16152, 0, 20808, 0, -16151, 0, 21315, 0, -16150, 0, 21344, 0, -16149, 0, 23459, 0, -16148, 0, 23554, 0, -16147, 0, 23574, 0, -16146, 0, 24029, 0, -16145, 0, 25126, 0, -16144, 0, 25159, 0, -16143, 0, 25776, 0, -16142, 0, 26643, 0, -16141, 0, 26676, 0, -16140, 0, 27849, 0, -16139, 0, 27973, 0, -16138, 0, 27927, 0, -16137, 0, 26579, 0, -16136, 0, 28508, 0, -16135, 0, 29006, 0, -16134, 0, 29053, 0, -16133, 0, 26059, 0, -16132, 0, 31359, 0, -16131, 0, 31661, 0, -16130, 0, 32218, 0, -15967, 0, 32330, 0, -15966, 0, 32680, 0, -15965, 0, -32390, 0, -15964, 0, -32229, 0, -15963, 0, -32199, 0, -15962, 0, -31322, 0, -15961, 0, -30098, 0, -15960, 0, -29490, 0, -15959, 0, -29195, 0, -15958, 0, -28552, 0, -15957, 0, -28553, 0, -15956, 0, -27987, 0, -15955, 0, -28015, 0, -15954, 0, -27261, 0, -15953, 0, -25682, 0, -15952, 0, 21069, 0, -15951, 0, 21892, 0, -15950, 0, 28472, 0, -15949, 0, 28982, 0, -15948, 0, 20840, 0, -15947, 0, 31109, 0, -15946, 0, 32341, 0, -15945, 0, -32333, 0, -15944, 0, 31950, 0, -15943, 0, 22092, 0, -15942, 0, 22609, 0, -15941, 0, 23720, 0, -15940, 0, 25514, 0, -15939, 0, 26366, 0, -15938, 0, 26365, 0, -15937, 0, 26970, 0, -15936, 0, 29401, 0, -15935, 0, 30095, 0, -15934, 0, 30094, 0, -15933, 0, 30990, 0, -15932, 0, 31062, 0, -15931, 0, 31199, 0, -15930, 0, 31895, 0, -15929, 0, 32032, 0, -15928, 0, 32068, 0, -15927, 0, -31225, 0, -15926, 0, -30156, 0, -15925, 0, -27077, 0, -15924, 0, -28575, 0, -15923, 0, -24800, 0, -15922, 0, 20711, 0, -15921, 0, 21109, 0, -15920, 0, 21452, 0, -15919, 0, 21474, 0, -15918, 0, 20489, 0, -15917, 0, 21930, 0, -15916, 0, 22766, 0, -15915, 0, 22863, 0, -15914, 0, 29245, 0, -15913, 0, 23435, 0, -15912, 0, 23652, 0, -15911, 0, 21277, 0, -15910, 0, 24803, 0, -15909, 0, 24819, 0, -15908, 0, 25436, 0, -15907, 0, 25475, 0, -15906, 0, 25407, 0, -15905, 0, 25531, 0, -15904, 0, 25805, 0, -15903, 0, 26089, 0, -15902, 0, 26361, 0, -15901, 0, 24035, 0, -15900, 0, 27085, 0, -15899, 0, 27133, 0, -15898, 0, 28437, 0, -15897, 0, 29157, 0, -15896, 0, 20105, 0, -15895, 0, 30185, 0, -15894, 0, 30456, 0, -15893, 0, 31379, 0, -15892, 0, 31967, 0, -15891, 0, 32207, 0, -15890, 0, 32156, 0, -15889, 0, -32671, 0, -15888, 0, -31927, 0, -15887, 0, -31912, 0, -15886, 0, -31636, 0, -15885, 0, -31556, 0, -15884, 0, -31237, 0, -15883, 0, -30523, 0, -15882, 0, -29328, 0, -15881, 0, -28671, 0, -15880, 0, -28563, 0, -15879, 0, -27753, 0, -15878, 0, -26852, 0, -15877, 0, -26094, 0, -15876, 0, 20687, 0, -15875, 0, 22679, 0, -15874, 0, 24974, 0, -15711, 0, -32301, 0, -15710, 0, -31435, 0, -15709, 0, -29432, 0, -15708, 0, -28640, 0, -15707, 0, 20419, 0, -15706, 0, 20596, 0, -15705, 0, 21063, 0, -15704, 0, 21363, 0, -15703, 0, 24687, 0, -15702, 0, 25417, 0, -15701, 0, 26463, 0, -15700, 0, 28204, 0, -15699, 0, -29261, 0, -15698, 0, -28641, 0, -15697, 0, 20439, 0, -15696, 0, 23646, 0, -15695, 0, -29494, 0, -15694, 0, 26063, 0, -15693, 0, 32154, 0, -15692, 0, 21330, 0, -15691, 0, -30570, 0, -15690, 0, 20854, 0, -15689, 0, 25539, 0, -15688, 0, 23384, 0, -15687, 0, 23403, 0, -15686, 0, 23562, 0, -15685, 0, 25613, 0, -15684, 0, 26449, 0, -15683, 0, -28580, 0, -15682, 0, 20182, 0, -15681, 0, 22810, 0, -15680, 0, 22826, 0, -15679, 0, 27760, 0, -15678, 0, -30127, 0, -15677, 0, 21822, 0, -15676, 0, 22549, 0, -15675, 0, 22949, 0, -15674, 0, 24816, 0, -15673, 0, 25171, 0, -15672, 0, 26561, 0, -15671, 0, -32203, 0, -15670, 0, 26965, 0, -15669, 0, -27072, 0, -15668, 0, -26172, 0, -15667, 0, -26072, 0, -15666, 0, 20307, 0, -15665, 0, 22534, 0, -15664, 0, 23550, 0, -15663, 0, -32752, 0, -15662, 0, 23729, 0, -15661, 0, 24111, 0, -15660, 0, 24453, 0, -15659, 0, 24608, 0, -15658, 0, 24907, 0, -15657, 0, 25140, 0, -15656, 0, 26367, 0, -15655, 0, 27888, 0, -15654, 0, 28382, 0, -15653, 0, -32562, 0, -15652, 0, -32385, 0, -15651, 0, -32044, 0, -15650, 0, -30581, 0, -15649, 0, -29512, 0, -15648, 0, -28672, 0, -15647, 0, -28626, 0, -15646, 0, -26998, 0, -15645, 0, -24869, 0, -15644, 0, -25637, 0, -15643, 0, 20195, 0, -15642, 0, 21488, 0, -15641, 0, 22823, 0, -15640, 0, 31532, 0, -15639, 0, -28275, 0, -15638, 0, -26548, 0, -15637, 0, -25095, 0, -15636, 0, 28381, 0, -15635, 0, 28711, 0, -15634, 0, 21331, 0, -15633, 0, 21828, 0, -15632, 0, 23429, 0, -15631, 0, 25176, 0, -15630, 0, 25246, 0, -15629, 0, 25299, 0, -15628, 0, 27810, 0, -15627, 0, 28655, 0, -15626, 0, 29730, 0, -15625, 0, -30185, 0, -15624, 0, -27592, 0, -15623, 0, 28609, 0, -15622, 0, -29954, 0, -15621, 0, -31944, 0, -15620, 0, 20967, 0, -15619, 0, -30984, 0, -15618, 0, 21482, 0, -15455, 0, 21481, 0, -15454, 0, 20294, 0, -15453, 0, -28588, 0, -15452, 0, -28752, 0, -15451, 0, 22890, 0, -15450, 0, -32463, 0, -15449, 0, 24061, 0, -15448, 0, 31466, 0, -15447, 0, -28737, 0, -15446, 0, 26842, 0, -15445, 0, -29641, 0, -15444, 0, 29432, 0, -15443, 0, -25528, 0, -15442, 0, 27197, 0, -15441, 0, -30032, 0, -15440, 0, 20025, 0, -15439, 0, 21336, 0, -15438, 0, 22022, 0, -15437, 0, 22374, 0, -15436, 0, 25285, 0, -15435, 0, 25506, 0, -15434, 0, 26086, 0, -15433, 0, 27470, 0, -15432, 0, 28129, 0, -15431, 0, 28251, 0, -15430, 0, 28845, 0, -15429, 0, 30701, 0, -15428, 0, 31471, 0, -15427, 0, 31658, 0, -15426, 0, 32187, 0, -15425, 0, -32707, 0, -15424, 0, -32570, 0, -15423, 0, -31029, 0, -15422, 0, -30059, 0, -15421, 0, -27813, 0, -15420, 0, 22243, 0, -15419, 0, 22727, 0, -15418, 0, 24382, 0, -15417, 0, 26029, 0, -15416, 0, 26262, 0, -15415, 0, 27264, 0, -15414, 0, 27573, 0, -15413, 0, 30007, 0, -15412, 0, -30009, 0, -15411, 0, 20516, 0, -15410, 0, 30693, 0, -15409, 0, 22320, 0, -15408, 0, 24347, 0, -15407, 0, 24677, 0, -15406, 0, 26234, 0, -15405, 0, 27744, 0, -15404, 0, 30196, 0, -15403, 0, 31258, 0, -15402, 0, 32622, 0, -15401, 0, -32268, 0, -15400, 0, -30952, 0, -15399, 0, -28603, 0, -15398, 0, -26189, 0, -15397, 0, 31689, 0, -15396, 0, 30044, 0, -15395, 0, 31481, 0, -15394, 0, 31569, 0, -15393, 0, -31548, 0, -15392, 0, -28656, 0, -15391, 0, 31209, 0, -15390, 0, 31378, 0, -15389, 0, -31946, 0, -15388, 0, 23265, 0, -15387, 0, 30528, 0, -15386, 0, 20013, 0, -15385, 0, 20210, 0, -15384, 0, 23449, 0, -15383, 0, 24544, 0, -15382, 0, 25277, 0, -15381, 0, 26172, 0, -15380, 0, 26609, 0, -15379, 0, 27880, 0, -15378, 0, -31125, 0, -15377, 0, -30601, 0, -15376, 0, -30149, 0, -15375, 0, -28338, 0, -15374, 0, -27917, 0, -15373, 0, -26160, 0, -15372, 0, 27159, 0, -15371, 0, 28710, 0, -15370, 0, 29482, 0, -15369, 0, -32025, 0, -15368, 0, -31657, 0, -15367, 0, -29521, 0, -15366, 0, 19969, 0, -15365, 0, 20806, 0, -15364, 0, 20939, 0, -15363, 0, 21899, 0, -15362, 0, 23541, 0, -15199, 0, 24086, 0, -15198, 0, 24115, 0, -15197, 0, 24193, 0, -15196, 0, 24340, 0, -15195, 0, 24373, 0, -15194, 0, 24427, 0, -15193, 0, 24500, 0, -15192, 0, 25074, 0, -15191, 0, 25361, 0, -15190, 0, 26274, 0, -15189, 0, 26397, 0, -15188, 0, 28526, 0, -15187, 0, 29266, 0, -15186, 0, 30010, 0, -15185, 0, 30522, 0, -15184, 0, -32652, 0, -15183, 0, -32455, 0, -15182, 0, -32392, 0, -15181, 0, -30858, 0, -15180, 0, -30017, 0, -15179, 0, -29988, 0, -15178, 0, -29307, 0, -15177, 0, -29197, 0, -15176, 0, -28006, 0, -15175, 0, -27273, 0, -15174, 0, -26622, 0, -15173, 0, -25371, 0, -15172, 0, 21189, 0, -15171, 0, 25431, 0, -15170, 0, 30452, 0, -15169, 0, 26389, 0, -15168, 0, 27784, 0, -15167, 0, 29645, 0, -15166, 0, -29501, 0, -15165, 0, -27730, 0, -15164, 0, -27021, 0, -15163, 0, 27941, 0, -15162, 0, 22684, 0, -15161, 0, 26894, 0, -15160, 0, 27084, 0, -15159, 0, -28675, 0, -15158, 0, -27750, 0, -15157, 0, 30171, 0, -15156, 0, -28646, 0, -15155, 0, 22618, 0, -15154, 0, 26626, 0, -15153, 0, 25524, 0, -15152, 0, 27131, 0, -15151, 0, 20291, 0, -15150, 0, 28460, 0, -15149, 0, 26584, 0, -15148, 0, -28741, 0, -15147, 0, -31450, 0, -15146, 0, 32180, 0, -15145, 0, -27820, 0, -15144, 0, 26943, 0, -15143, 0, 28528, 0, -15142, 0, 22378, 0, -15141, 0, 22775, 0, -15140, 0, 23340, 0, -15139, 0, 32044, 0, -15138, 0, 29226, 0, -15137, 0, 21514, 0, -15136, 0, -28189, 0, -15135, 0, -25164, 0, -15134, 0, 20141, 0, -15133, 0, 20302, 0, -15132, 0, 20572, 0, -15131, 0, 20597, 0, -15130, 0, 21059, 0, -15129, 0, -29538, 0, -15128, 0, 21576, 0, -15127, 0, 22564, 0, -15126, 0, 23450, 0, -15125, 0, 24093, 0, -15124, 0, 24213, 0, -15123, 0, 24237, 0, -15122, 0, 24311, 0, -15121, 0, 24351, 0, -15120, 0, 24716, 0, -15119, 0, 25269, 0, -15118, 0, 25402, 0, -15117, 0, 25552, 0, -15116, 0, 26799, 0, -15115, 0, 27712, 0, -15114, 0, 30855, 0, -15113, 0, 31118, 0, -15112, 0, 31243, 0, -15111, 0, 32224, 0, -15110, 0, -32185, 0, -15109, 0, -30206, 0, -15108, 0, -29978, 0, -15107, 0, -29116, 0, -15106, 0, -28653, 0, -14943, 0, -28488, 0, -14942, 0, -28371, 0, -14941, 0, -28200, 0, -14940, 0, -24818, 0, -14939, 0, 27877, 0, -14938, 0, 25688, 0, -14937, 0, 25826, 0, -14936, 0, 25973, 0, -14935, 0, 28404, 0, -14934, 0, 30340, 0, -14933, 0, 31515, 0, -14932, 0, -28567, 0, -14931, 0, -27695, 0, -14930, 0, 28346, 0, -14929, 0, 21746, 0, -14928, 0, 24505, 0, -14927, 0, 25764, 0, -14926, 0, -28851, 0, -14925, 0, -28691, 0, -14924, 0, -28092, 0, -14923, 0, 20856, 0, -14922, 0, 22635, 0, -14921, 0, 22825, 0, -14920, 0, 23637, 0, -14919, 0, 24215, 0, -14918, 0, 28155, 0, -14917, 0, 32399, 0, -14916, 0, 29980, 0, -14915, 0, -29508, 0, -14914, 0, -28958, 0, -14913, 0, -26533, 0, -14912, 0, 28857, 0, -14911, 0, 20253, 0, -14910, 0, 27583, 0, -14909, 0, 28593, 0, -14908, 0, 30000, 0, -14907, 0, -26885, 0, -14906, 0, 20814, 0, -14905, 0, 21520, 0, -14904, 0, 22581, 0, -14903, 0, 22615, 0, -14902, 0, 22956, 0, -14901, 0, 23648, 0, -14900, 0, 24466, 0, -14899, 0, 26007, 0, -14898, 0, 26460, 0, -14897, 0, 28193, 0, -14896, 0, 30331, 0, -14895, 0, -31777, 0, -14894, 0, -29459, 0, -14893, 0, -28652, 0, -14892, 0, -28419, 0, -14891, 0, -27827, 0, -14890, 0, 30757, 0, -14889, 0, 30778, 0, -14888, 0, 21162, 0, -14887, 0, 24230, 0, -14886, 0, 22303, 0, -14885, 0, 22900, 0, -14884, 0, 24594, 0, -14883, 0, 20498, 0, -14882, 0, 20826, 0, -14881, 0, 20908, 0, -14880, 0, 20941, 0, -14879, 0, 20992, 0, -14878, 0, 21776, 0, -14877, 0, 22612, 0, -14876, 0, 22616, 0, -14875, 0, 22871, 0, -14874, 0, 23445, 0, -14873, 0, 23798, 0, -14872, 0, 23947, 0, -14871, 0, 24764, 0, -14870, 0, 25237, 0, -14869, 0, 25645, 0, -14868, 0, 26481, 0, -14867, 0, 26691, 0, -14866, 0, 26812, 0, -14865, 0, 26847, 0, -14864, 0, 30423, 0, -14863, 0, 28120, 0, -14862, 0, 28271, 0, -14861, 0, 28059, 0, -14860, 0, 28783, 0, -14859, 0, 29128, 0, -14858, 0, 24403, 0, -14857, 0, 30168, 0, -14856, 0, 31095, 0, -14855, 0, 31561, 0, -14854, 0, 31572, 0, -14853, 0, 31570, 0, -14852, 0, 31958, 0, -14851, 0, 32113, 0, -14850, 0, 21040, 0, -14687, 0, -31645, 0, -14686, 0, -31383, 0, -14685, 0, -31260, 0, -14684, 0, -30194, 0, -14683, 0, -29948, 0, -14682, 0, -29626, 0, -14681, 0, -29169, 0, -14680, 0, -28669, 0, -14679, 0, -28657, 0, -14678, 0, -27623, 0, -14677, 0, -27018, 0, -14676, 0, -26579, 0, -14675, 0, -26064, 0, -14674, 0, -27176, 0, -14673, 0, 20685, 0, -14672, 0, 21205, 0, -14671, 0, 21516, 0, -14670, 0, 22530, 0, -14669, 0, 23566, 0, -14668, 0, 24999, 0, -14667, 0, 25758, 0, -14666, 0, 27934, 0, -14665, 0, 30643, 0, -14664, 0, 31461, 0, -14663, 0, -32524, 0, -14662, 0, -31740, 0, -14661, 0, -28589, 0, -14660, 0, -28027, 0, -14659, 0, 23776, 0, -14658, 0, -25337, 0, -14657, 0, 21311, 0, -14656, 0, 24471, 0, -14655, 0, 24499, 0, -14654, 0, 28060, 0, -14653, 0, 29305, 0, -14652, 0, 30563, 0, -14651, 0, 31167, 0, -14650, 0, 31716, 0, -14649, 0, 27602, 0, -14648, 0, 29420, 0, -14647, 0, -30035, 0, -14646, 0, 26627, 0, -14645, 0, 27233, 0, -14644, 0, 20984, 0, -14643, 0, 31361, 0, -14642, 0, 26932, 0, -14641, 0, 23626, 0, -14640, 0, -25354, 0, -14639, 0, -32021, 0, -14638, 0, 23493, 0, -14637, 0, -28343, 0, -14636, 0, 28702, 0, -14635, 0, 22136, 0, -14634, 0, 23663, 0, -14633, 0, 24775, 0, -14632, 0, 25958, 0, -14631, 0, 27788, 0, -14630, 0, -29606, 0, -14629, 0, -28607, 0, -14628, 0, -26605, 0, -14627, 0, 21585, 0, -14626, 0, 26311, 0, -14625, 0, -28147, 0, -14624, 0, 22856, 0, -14623, 0, -28509, 0, -14622, 0, 20869, 0, -14621, 0, 20045, 0, -14620, 0, 20970, 0, -14619, 0, -31335, 0, -14618, 0, -29938, 0, -14617, 0, 28760, 0, -14616, 0, 25466, 0, -14615, 0, -27829, 0, -14614, 0, 26978, 0, -14613, 0, -26188, 0, -14612, 0, 32260, 0, -14611, 0, 30071, 0, -14610, 0, 21335, 0, -14609, 0, 26976, 0, -14608, 0, -28961, 0, -14607, 0, -26909, 0, -14606, 0, 27741, 0, -14605, 0, 20108, 0, -14604, 0, 23612, 0, -14603, 0, 24336, 0, -14602, 0, -28695, 0, -14601, 0, 21250, 0, -14600, 0, -29487, 0, -14599, 0, -32631, 0, -14598, 0, -31111, 0, -14597, 0, 24319, 0, -14596, 0, 26085, 0, -14595, 0, 20083, 0, -14594, 0, 20837, 0, -14431, 0, 22914, 0, -14430, 0, 23615, 0, -14429, 0, -26642, 0, -14428, 0, 20219, 0, -14427, 0, 22922, 0, -14426, 0, 24525, 0, -14425, 0, -30067, 0, -14424, 0, 28641, 0, -14423, 0, 31152, 0, -14422, 0, 31074, 0, -14421, 0, 23527, 0, -14420, 0, -31631, 0, -14419, 0, 29483, 0, -14418, 0, 29105, 0, -14417, 0, 24180, 0, -14416, 0, 24565, 0, -14415, 0, 25467, 0, -14414, 0, 25754, 0, -14413, 0, 29123, 0, -14412, 0, 31896, 0, -14411, 0, 20035, 0, -14410, 0, 24316, 0, -14409, 0, 20043, 0, -14408, 0, 22492, 0, -14407, 0, 22178, 0, -14406, 0, 24745, 0, -14405, 0, 28611, 0, -14404, 0, 32013, 0, -14403, 0, -32515, 0, -14402, 0, -32461, 0, -14401, 0, -32321, 0, -14400, 0, -28750, 0, -14399, 0, -30313, 0, -14398, 0, -31068, 0, -14397, 0, 24052, 0, -14396, 0, 25226, 0, -14395, 0, 25773, 0, -14394, 0, -30329, 0, -14393, 0, 26487, 0, -14392, 0, 27874, 0, -14391, 0, 27966, 0, -14390, 0, 29750, 0, -14389, 0, 30772, 0, -14388, 0, 23110, 0, -14387, 0, 32629, 0, -14386, 0, -32083, 0, -14385, 0, -26196, 0, -14384, 0, 20467, 0, -14383, 0, 24259, 0, -14382, 0, 25309, 0, -14381, 0, 25490, 0, -14380, 0, 25943, 0, -14379, 0, 26479, 0, -14378, 0, 30403, 0, -14377, 0, 29260, 0, -14376, 0, -32564, 0, -14375, 0, -32582, 0, -14374, 0, -28887, 0, -14373, 0, -28339, 0, -14372, 0, 20493, 0, -14371, 0, 22521, 0, -14370, 0, 23186, 0, -14369, 0, 26757, 0, -14368, 0, 26995, 0, -14367, 0, 29028, 0, -14366, 0, 29437, 0, -14365, 0, -29513, 0, -14364, 0, 22770, 0, -14363, 0, -29472, 0, -14362, 0, -27030, 0, -14361, 0, -28647, 0, -14360, 0, -30849, 0, -14359, 0, 31204, 0, -14358, 0, 30695, 0, -14357, 0, -31703, 0, -14356, 0, 20271, 0, -14355, 0, 21093, 0, -14354, 0, 21338, 0, -14353, 0, 25293, 0, -14352, 0, 26575, 0, -14351, 0, 27850, 0, -14350, 0, 30333, 0, -14349, 0, 31636, 0, -14348, 0, 31893, 0, -14347, 0, -32202, 0, -14346, 0, -31356, 0, -14345, 0, -28693, 0, -14344, 0, 26333, 0, -14343, 0, 28448, 0, -14342, 0, 29190, 0, -14341, 0, 32283, 0, -14340, 0, -31829, 0, -14339, 0, -26175, 0, -14338, 0, -24922, 0, -14175, 0, 20989, 0, -14174, 0, 31665, 0, -14173, 0, 30834, 0, -14172, 0, 31672, 0, -14171, 0, -32633, 0, -14170, 0, 31560, 0, -14169, 0, 27368, 0, -14168, 0, 24161, 0, -14167, 0, -32628, 0, -14166, 0, 30033, 0, -14165, 0, 30048, 0, -14164, 0, 20843, 0, -14163, 0, -28062, 0, -14162, 0, 28300, 0, -14161, 0, 30330, 0, -14160, 0, -28265, 0, -14159, 0, -25878, 0, -14158, 0, 20240, 0, -14157, 0, 32624, 0, -14156, 0, 25244, 0, -14155, 0, 31567, 0, -14154, 0, -27227, 0, -14153, 0, -25367, 0, -14152, 0, 22138, 0, -14151, 0, 22617, 0, -14150, 0, -31004, 0, -14149, 0, -26948, 0, -14148, 0, 20276, 0, -14147, 0, 21028, 0, -14146, 0, 21322, 0, -14145, 0, 21453, 0, -14144, 0, 21467, 0, -14143, 0, 24070, 0, -14142, 0, 25644, 0, -14141, 0, 26001, 0, -14140, 0, 26495, 0, -14139, 0, 27710, 0, -14138, 0, 27726, 0, -14137, 0, 29256, 0, -14136, 0, 29359, 0, -14135, 0, 29677, 0, -14134, 0, 30036, 0, -14133, 0, 32321, 0, -14132, 0, -32212, 0, -14131, 0, -31255, 0, -14130, 0, -29527, 0, -14129, 0, 31684, 0, -14128, 0, -28218, 0, -14127, 0, 29033, 0, -14126, 0, -26606, 0, -14125, 0, -26385, 0, -14124, 0, 25405, 0, -14123, 0, 26217, 0, -14122, 0, 30058, 0, -14121, 0, 30436, 0, -14120, 0, 30928, 0, -14119, 0, -31421, 0, -14118, 0, -30994, 0, -14117, 0, 21290, 0, -14116, 0, 21329, 0, -14115, 0, 21542, 0, -14114, 0, 22915, 0, -14113, 0, 24199, 0, -14112, 0, 24444, 0, -14111, 0, 24754, 0, -14110, 0, 25161, 0, -14109, 0, 25209, 0, -14108, 0, 25259, 0, -14107, 0, 26000, 0, -14106, 0, 27604, 0, -14105, 0, 27852, 0, -14104, 0, 30130, 0, -14103, 0, 30382, 0, -14102, 0, 30865, 0, -14101, 0, 31192, 0, -14100, 0, 32203, 0, -14099, 0, 32631, 0, -14098, 0, -32603, 0, -14097, 0, -30549, 0, -14096, 0, -30023, 0, -14095, 0, -29509, 0, -14094, 0, -28545, 0, -14093, 0, -26786, 0, -14092, 0, -26405, 0, -14091, 0, 27147, 0, -14090, 0, 31800, 0, -14089, 0, 20633, 0, -14088, 0, 23614, 0, -14087, 0, 24494, 0, -14086, 0, 26503, 0, -14085, 0, 27608, 0, -14084, 0, 29749, 0, -14083, 0, 30473, 0, -14082, 0, 32654, 0, -13919, 0, -24773, 0, -13918, 0, 26570, 0, -13917, 0, 31255, 0, -13916, 0, 21305, 0, -13915, 0, 30091, 0, -13914, 0, -25875, 0, -13913, 0, 24422, 0, -13912, 0, -32355, 0, -13911, 0, -31759, 0, -13910, 0, -32616, 0, -13909, 0, 24380, 0, -13908, 0, 24517, 0, -13907, 0, 30050, 0, -13906, 0, 31558, 0, -13905, 0, -28612, 0, -13904, 0, 26727, 0, -13903, 0, 23019, 0, -13902, 0, 23195, 0, -13901, 0, 32016, 0, -13900, 0, 30334, 0, -13899, 0, -29908, 0, -13898, 0, 20469, 0, -13897, 0, 24426, 0, -13896, 0, 27161, 0, -13895, 0, 27703, 0, -13894, 0, 28418, 0, -13893, 0, 29922, 0, -13892, 0, 31080, 0, -13891, 0, -30616, 0, -13890, 0, -30123, 0, -13889, 0, -29575, 0, -13888, 0, 24287, 0, -13887, 0, 25551, 0, -13886, 0, 30149, 0, -13885, 0, 31186, 0, -13884, 0, -32041, 0, -13883, 0, -27864, 0, -13882, 0, -27918, 0, -13881, 0, -31588, 0, -13880, 0, -30995, 0, -13879, 0, -25555, 0, -13878, 0, 21697, 0, -13877, 0, 24428, 0, -13876, 0, 25996, 0, -13875, 0, 27996, 0, -13874, 0, 28693, 0, -13873, 0, -29529, 0, -13872, 0, -29485, 0, -13871, 0, -26565, 0, -13870, 0, 25935, 0, -13869, 0, 29942, 0, -13868, 0, 19981, 0, -13867, 0, 20184, 0, -13866, 0, 22496, 0, -13865, 0, 22827, 0, -13864, 0, 23142, 0, -13863, 0, 23500, 0, -13862, 0, 20904, 0, -13861, 0, 24067, 0, -13860, 0, 24220, 0, -13859, 0, 24598, 0, -13858, 0, 25206, 0, -13857, 0, 25975, 0, -13856, 0, 26023, 0, -13855, 0, 26222, 0, -13854, 0, 28014, 0, -13853, 0, 29238, 0, -13852, 0, 31526, 0, -13851, 0, -32432, 0, -13850, 0, -32358, 0, -13849, 0, -32103, 0, -13848, 0, -29860, 0, -13847, 0, -29536, 0, -13846, 0, -29466, 0, -13845, 0, -29324, 0, -13844, 0, -27108, 0, -13843, 0, -27068, 0, -13842, 0, 20398, 0, -13841, 0, 25771, 0, -13840, 0, 27494, 0, -13839, 0, -32226, 0, -13838, 0, -31647, 0, -13837, 0, -31382, 0, -13836, 0, -28440, 0, -13835, 0, 23553, 0, -13834, 0, 26963, 0, -13833, 0, -26456, 0, -13832, 0, -31622, 0, -13831, 0, -31401, 0, -13830, 0, 20239, 0, -13829, 0, 21103, 0, -13828, 0, 24489, 0, -13827, 0, 24133, 0, -13826, 0, 26381, 0, -13663, 0, 31119, 0, -13662, 0, -32391, 0, -13661, 0, -30457, 0, -13660, 0, -30330, 0, -13659, 0, 28149, 0, -13658, 0, 24343, 0, -13657, 0, 25173, 0, -13656, 0, 27832, 0, -13655, 0, 20175, 0, -13654, 0, 29289, 0, -13653, 0, -25710, 0, -13652, 0, 20998, 0, -13651, 0, 21563, 0, -13650, 0, 22132, 0, -13649, 0, 22707, 0, -13648, 0, 24996, 0, -13647, 0, 25198, 0, -13646, 0, 28954, 0, -13645, 0, 22894, 0, -13644, 0, 31881, 0, -13643, 0, 31966, 0, -13642, 0, 32027, 0, -13641, 0, -26896, 0, -13640, 0, 25991, 0, -13639, 0, -32674, 0, -13638, 0, 19993, 0, -13637, 0, 20341, 0, -13636, 0, 20853, 0, -13635, 0, 22592, 0, -13634, 0, 24163, 0, -13633, 0, 24179, 0, -13632, 0, 24330, 0, -13631, 0, 26564, 0, -13630, 0, 20006, 0, -13629, 0, -31427, 0, -13628, 0, -27255, 0, -13627, 0, -27045, 0, -13626, 0, 31859, 0, -13625, 0, -26623, 0, -13624, 0, 20731, 0, -13623, 0, 22721, 0, -13622, 0, 30294, 0, -13621, 0, 30887, 0, -13620, 0, 21029, 0, -13619, 0, 30629, 0, -13618, 0, -31471, 0, -13617, 0, 31622, 0, -13616, 0, 20559, 0, -13615, 0, 22793, 0, -13614, 0, 29255, 0, -13613, 0, 31687, 0, -13612, 0, 32232, 0, -13611, 0, -28742, 0, -13610, 0, -28716, 0, -13609, 0, -28595, 0, -13608, 0, 20415, 0, -13607, 0, 21193, 0, -13606, 0, 23081, 0, -13605, 0, 24321, 0, -13604, 0, -26707, 0, -13603, 0, 20445, 0, -13602, 0, -32233, 0, -13601, 0, -27926, 0, -13600, 0, 22275, 0, -13599, 0, 25429, 0, -13598, 0, 27497, 0, -13597, 0, 29995, 0, -13596, 0, -30500, 0, -13595, 0, -28908, 0, -13594, 0, 31298, 0, -13593, 0, 21215, 0, -13592, 0, 22675, 0, -13591, 0, 24917, 0, -13590, 0, 25098, 0, -13589, 0, 26286, 0, -13588, 0, 27597, 0, -13587, 0, 31807, 0, -13586, 0, -31767, 0, -13585, 0, 20515, 0, -13584, 0, 20472, 0, -13583, 0, 21253, 0, -13582, 0, 21574, 0, -13581, 0, 22577, 0, -13580, 0, 22857, 0, -13579, 0, 23453, 0, -13578, 0, 23792, 0, -13577, 0, 23791, 0, -13576, 0, 23849, 0, -13575, 0, 24214, 0, -13574, 0, 25265, 0, -13573, 0, 25447, 0, -13572, 0, 25918, 0, -13571, 0, 26041, 0, -13570, 0, 26379, 0, -13407, 0, 27861, 0, -13406, 0, 27873, 0, -13405, 0, 28921, 0, -13404, 0, 30770, 0, -13403, 0, 32299, 0, -13402, 0, -32546, 0, -13401, 0, -32077, 0, -13400, 0, -31732, 0, -13399, 0, -31508, 0, -13398, 0, -30974, 0, -13397, 0, -30446, 0, -13396, 0, -30166, 0, -13395, 0, -29622, 0, -13394, 0, -28506, 0, -13393, 0, -27950, 0, -13392, 0, -26371, 0, -13391, 0, -25357, 0, -13390, 0, -25236, 0, -13389, 0, 20047, 0, -13388, 0, 20129, 0, -13387, 0, 20621, 0, -13386, 0, 21078, 0, -13385, 0, 22346, 0, -13384, 0, 22952, 0, -13383, 0, 24125, 0, -13382, 0, 24536, 0, -13381, 0, 24537, 0, -13380, 0, 25151, 0, -13379, 0, 26292, 0, -13378, 0, 26395, 0, -13377, 0, 26576, 0, -13376, 0, 26834, 0, -13375, 0, 20882, 0, -13374, 0, 32033, 0, -13373, 0, -32598, 0, -13372, 0, -32344, 0, -13371, 0, -29952, 0, -13370, 0, -29556, 0, -13369, 0, -29505, 0, -13368, 0, -28034, 0, -13367, 0, -27086, 0, -13366, 0, 21536, 0, -13365, 0, -26580, 0, -13364, 0, 21271, 0, -13363, 0, 20693, 0, -13362, 0, 21340, 0, -13361, 0, 22696, 0, -13360, 0, 25778, 0, -13359, 0, 26420, 0, -13358, 0, 29287, 0, -13357, 0, 30566, 0, -13356, 0, 31302, 0, -13355, 0, -28186, 0, -13354, 0, 21187, 0, -13353, 0, 27809, 0, -13352, 0, 27526, 0, -13351, 0, 22528, 0, -13350, 0, 24140, 0, -13349, 0, 22868, 0, -13348, 0, 26412, 0, -13347, 0, 32763, 0, -13346, 0, 20961, 0, -13345, 0, 30406, 0, -13344, 0, 25705, 0, -13343, 0, 30952, 0, -13342, 0, -25772, 0, -13341, 0, -24901, 0, -13340, 0, 22475, 0, -13339, 0, 22969, 0, -13338, 0, 26151, 0, -13337, 0, 26522, 0, -13336, 0, 27598, 0, -13335, 0, 21737, 0, -13334, 0, 27097, 0, -13333, 0, 24149, 0, -13332, 0, -32356, 0, -13331, 0, 26517, 0, -13330, 0, -25686, 0, -13329, 0, 26622, 0, -13328, 0, -25518, 0, -13327, 0, 26717, 0, -13326, 0, 20134, 0, -13325, 0, 20451, 0, -13324, 0, 21448, 0, -13323, 0, 25273, 0, -13322, 0, 26411, 0, -13321, 0, 27819, 0, -13320, 0, -28732, 0, -13319, 0, 20397, 0, -13318, 0, 32365, 0, -13317, 0, -24897, 0, -13316, 0, 19975, 0, -13315, 0, 24930, 0, -13314, 0, 28288, 0, -13151, 0, 28459, 0, -13150, 0, -31469, 0, -13149, 0, 21619, 0, -13148, 0, 26410, 0, -13147, 0, -25787, 0, -13146, 0, 24051, 0, -13145, 0, 31637, 0, -13144, 0, 23724, 0, -13143, 0, 23494, 0, -13142, 0, -30948, 0, -13141, 0, 28234, 0, -13140, 0, -31535, 0, -13139, 0, 31252, 0, -13138, 0, -32504, 0, -13137, 0, 22937, 0, -13136, 0, 31885, 0, -13135, 0, 27665, 0, -13134, 0, 30496, 0, -13133, 0, 21209, 0, -13132, 0, 22818, 0, -13131, 0, 28961, 0, -13130, 0, 29279, 0, -13129, 0, 30683, 0, -13128, 0, -26841, 0, -13127, 0, -25247, 0, -13126, 0, 26891, 0, -13125, 0, 23167, 0, -13124, 0, 23064, 0, -13123, 0, 20901, 0, -13122, 0, 21517, 0, -13121, 0, 21629, 0, -13120, 0, 26126, 0, -13119, 0, 30431, 0, -13118, 0, -28681, 0, -13117, 0, -28008, 0, -13116, 0, -25356, 0, -13115, 0, 23018, 0, -13114, 0, 29277, 0, -13113, 0, 28357, 0, -13112, 0, 20813, 0, -13111, 0, 26825, 0, -13110, 0, 32191, 0, -13109, 0, 32236, 0, -13108, 0, -26782, 0, -13107, 0, -24902, 0, -13106, 0, 25720, 0, -13105, 0, 27169, 0, -13104, 0, -31998, 0, -13103, 0, 22916, 0, -13102, 0, 23391, 0, -13101, 0, 27611, 0, -13100, 0, 29467, 0, -13099, 0, 30450, 0, -13098, 0, 32178, 0, -13097, 0, -32745, 0, -13096, 0, -31591, 0, -13095, 0, 20786, 0, -13094, 0, 26408, 0, -13093, 0, -24871, 0, -13092, 0, 30446, 0, -13091, 0, 26466, 0, -13090, 0, 21247, 0, -13089, 0, -26363, 0, -13088, 0, 23588, 0, -13087, 0, 25147, 0, -13086, 0, 31870, 0, -13085, 0, -29520, 0, -13084, 0, 21839, 0, -13083, 0, 24758, 0, -13082, 0, 32011, 0, -13081, 0, -27264, 0, -13080, 0, 21249, 0, -13079, 0, 20063, 0, -13078, 0, 20918, 0, -13077, 0, 22812, 0, -13076, 0, 29242, 0, -13075, 0, -32714, 0, -13074, 0, -28210, 0, -13073, 0, 24357, 0, -13072, 0, 30690, 0, -13071, 0, 21380, 0, -13070, 0, 24441, 0, -13069, 0, 32004, 0, -13068, 0, -31316, 0, -13067, 0, -30157, 0, -13066, 0, -29043, 0, -13065, 0, -26794, 0, -13064, 0, 26611, 0, -13063, 0, -31314, 0, -13062, 0, -27565, 0, -13061, 0, 24841, 0, -13060, 0, 24840, 0, -13059, 0, 27833, 0, -13058, 0, 30290, 0, -12895, 0, -29971, 0, -12894, 0, -28872, 0, -12893, 0, 21807, 0, -12892, 0, 20305, 0, -12891, 0, 20778, 0, -12890, 0, 21191, 0, -12889, 0, 21451, 0, -12888, 0, 23461, 0, -12887, 0, 24189, 0, -12886, 0, 24736, 0, -12885, 0, 24962, 0, -12884, 0, 25558, 0, -12883, 0, 26377, 0, -12882, 0, 26586, 0, -12881, 0, 28263, 0, -12880, 0, 28044, 0, -12879, 0, 29494, 0, -12878, 0, 29495, 0, -12877, 0, 30001, 0, -12876, 0, 31056, 0, -12875, 0, -30507, 0, -12874, 0, -30056, 0, -12873, 0, -28598, 0, -12872, 0, -28527, 0, -12871, 0, -28427, 0, -12870, 0, -26940, 0, -12869, 0, -30835, 0, -12868, 0, 22805, 0, -12867, 0, 20104, 0, -12866, 0, 20313, 0, -12865, 0, 19982, 0, -12864, 0, -30071, 0, -12863, 0, -28865, 0, -12862, 0, -26608, 0, -12861, 0, 20653, 0, -12860, 0, 24188, 0, -12859, 0, 22934, 0, -12858, 0, 23481, 0, -12857, 0, 24248, 0, -12856, 0, 25562, 0, -12855, 0, 25594, 0, -12854, 0, 25793, 0, -12853, 0, 26332, 0, -12852, 0, 26954, 0, -12851, 0, 27096, 0, -12850, 0, 27915, 0, -12849, 0, 28342, 0, -12848, 0, 29076, 0, -12847, 0, 29992, 0, -12846, 0, 31407, 0, -12845, 0, 32650, 0, -12844, 0, -32768, 0, -12843, 0, -31671, 0, -12842, 0, -31543, 0, -12841, 0, -30335, 0, -12840, 0, -29919, 0, -12839, 0, -29174, 0, -12838, 0, -28571, 0, -12837, 0, -27011, 0, -12836, 0, -26358, 0, -12835, 0, 24958, 0, -12834, 0, 25233, 0, -12833, 0, 27442, 0, -12832, 0, 27779, 0, -12831, 0, 28020, 0, -12830, 0, 32716, 0, -12829, 0, 32764, 0, -12828, 0, 28096, 0, -12827, 0, 32645, 0, -12826, 0, -30790, 0, -12825, 0, -30472, 0, -12824, 0, 26469, 0, -12823, 0, -31823, 0, -12822, 0, -26564, 0, -12821, 0, -26889, 0, -12820, 0, 27931, 0, -12819, 0, 32097, 0, -12818, 0, -31683, 0, -12817, 0, -28310, 0, -12816, 0, 20081, 0, -12815, 0, 21365, 0, -12814, 0, 23888, 0, -12813, 0, 27396, 0, -12812, 0, 28651, 0, -12811, 0, -31283, 0, -12810, 0, -31187, 0, -12809, 0, -30297, 0, -12808, 0, 21033, 0, -12807, 0, 21519, 0, -12806, 0, 23653, 0, -12805, 0, 26446, 0, -12804, 0, 26792, 0, -12803, 0, 29702, 0, -12802, 0, 29827, 0, -12639, 0, 30178, 0, -12638, 0, -30513, 0, -12637, 0, -30495, 0, -12636, 0, -28212, 0, -12635, 0, -26910, 0, -12634, 0, -27016, 0, -12633, 0, 24459, 0, -12632, 0, 29575, 0, -12631, 0, 31435, 0, -12630, 0, -31666, 0, -12629, 0, 25504, 0, -12628, 0, 30053, 0, -12627, 0, 21129, 0, -12626, 0, 27969, 0, -12625, 0, 28316, 0, -12624, 0, 29705, 0, -12623, 0, 30041, 0, -12622, 0, 30827, 0, -12621, 0, 31890, 0, -12620, 0, -27002, 0, -12619, 0, 31452, 0, -12618, 0, -24691, 0, -12617, 0, 20406, 0, -12616, 0, 24942, 0, -12615, 0, 26053, 0, -12614, 0, -31140, 0, -12613, 0, 20102, 0, -12612, 0, 20142, 0, -12611, 0, 20698, 0, -12610, 0, 20001, 0, -12609, 0, 20940, 0, -12608, 0, 23534, 0, -12607, 0, 26009, 0, -12606, 0, 26753, 0, -12605, 0, 28092, 0, -12604, 0, 29471, 0, -12603, 0, 30274, 0, -12602, 0, 30637, 0, -12601, 0, 31260, 0, -12600, 0, 31975, 0, -12599, 0, -32145, 0, -12598, 0, -29998, 0, -12597, 0, -28548, 0, -12596, 0, -28209, 0, -12595, 0, -27019, 0, -12594, 0, -26600, 0, -12593, 0, 21147, 0, -12592, 0, 32209, 0, -12591, 0, 20523, 0, -12590, 0, 21400, 0, -12589, 0, 26519, 0, -12588, 0, 28107, 0, -12587, 0, 29136, 0, -12586, 0, 29747, 0, -12585, 0, -32280, 0, -12584, 0, -28886, 0, -12583, 0, -26973, 0, -12582, 0, -25513, 0, -12581, 0, -24929, 0, -12580, 0, 29792, 0, -12579, 0, 22593, 0, -12578, 0, 28057, 0, -12577, 0, 32047, 0, -12576, 0, -26530, 0, -12575, 0, 20196, 0, -12574, 0, 20278, 0, -12573, 0, 20363, 0, -12572, 0, 20919, 0, -12571, 0, 21169, 0, -12570, 0, 23994, 0, -12569, 0, 24604, 0, -12568, 0, 29618, 0, -12567, 0, 31036, 0, -12566, 0, -32045, 0, -12565, 0, -28108, 0, -12564, 0, -26953, 0, -12563, 0, -26890, 0, -12562, 0, -26870, 0, -12561, 0, -24937, 0, -12560, 0, -24734, 0, -12559, 0, 26278, 0, -12558, 0, 27508, 0, -12557, 0, 21015, 0, -12556, 0, 21155, 0, -12555, 0, 28872, 0, -12554, 0, -30526, 0, -12553, 0, 24265, 0, -12552, 0, 24651, 0, -12551, 0, 24976, 0, -12550, 0, 28451, 0, -12549, 0, 29001, 0, -12548, 0, 31806, 0, -12547, 0, 32244, 0, -12546, 0, -32657, 0, -12383, 0, -31506, 0, -12382, 0, -28637, 0, -12381, 0, -27860, 0, -12380, 0, 21570, 0, -12379, 0, -25745, 0, -12378, 0, 27347, 0, -12377, 0, 28809, 0, -12376, 0, -29502, 0, -12375, 0, -29201, 0, -12374, 0, -26830, 0, -12373, 0, 21172, 0, -12372, 0, 23105, 0, -12371, 0, 24266, 0, -12370, 0, 24324, 0, -12369, 0, 26391, 0, -12368, 0, 27004, 0, -12367, 0, 27028, 0, -12366, 0, 28010, 0, -12365, 0, 28431, 0, -12364, 0, 29282, 0, -12363, 0, 29436, 0, -12362, 0, 31725, 0, -12361, 0, -32767, 0, -12360, 0, -32642, 0, -12359, 0, -30901, 0, -12358, 0, -28466, 0, -12357, 0, 20845, 0, -12356, 0, -24941, 0, -12355, 0, 31108, 0, -12354, 0, -32629, 0, -12353, 0, -27854, 0, -12352, 0, -29994, 0, -12351, 0, 20525, 0, -12350, 0, 21644, 0, -12349, 0, -30095, 0, -12348, 0, 27498, 0, -12347, 0, -29500, 0, -12346, 0, -32505, 0, -12345, 0, 24785, 0, -12344, 0, 26528, 0, -12343, 0, -25102, 0, -12342, 0, 20121, 0, -12341, 0, 20120, 0, -12340, 0, -25584, 0, -12339, 0, -30101, 0, -12338, 0, -31295, 0, -12337, 0, -31384, 0, -12336, 0, 26880, 0, -12335, 0, 28286, 0, -12334, 0, 30871, 0, -12333, 0, -32427, 0, -12127, 0, 24332, 0, -12126, 0, 19984, 0, -12125, 0, 19989, 0, -12124, 0, 20010, 0, -12123, 0, 20017, 0, -12122, 0, 20022, 0, -12121, 0, 20028, 0, -12120, 0, 20031, 0, -12119, 0, 20034, 0, -12118, 0, 20054, 0, -12117, 0, 20056, 0, -12116, 0, 20098, 0, -12115, 0, 20101, 0, -12114, 0, -29589, 0, -12113, 0, 20106, 0, -12112, 0, -32238, 0, -12111, 0, 24333, 0, -12110, 0, 20110, 0, -12109, 0, 20126, 0, -12108, 0, 20127, 0, -12107, 0, 20128, 0, -12106, 0, 20130, 0, -12105, 0, 20144, 0, -12104, 0, 20147, 0, -12103, 0, 20150, 0, -12102, 0, 20174, 0, -12101, 0, 20173, 0, -12100, 0, 20164, 0, -12099, 0, 20166, 0, -12098, 0, 20162, 0, -12097, 0, 20183, 0, -12096, 0, 20190, 0, -12095, 0, 20205, 0, -12094, 0, 20191, 0, -12093, 0, 20215, 0, -12092, 0, 20233, 0, -12091, 0, 20314, 0, -12090, 0, 20272, 0, -12089, 0, 20315, 0, -12088, 0, 20317, 0, -12087, 0, 20311, 0, -12086, 0, 20295, 0, -12085, 0, 20342, 0, -12084, 0, 20360, 0, -12083, 0, 20367, 0, -12082, 0, 20376, 0, -12081, 0, 20347, 0, -12080, 0, 20329, 0, -12079, 0, 20336, 0, -12078, 0, 20369, 0, -12077, 0, 20335, 0, -12076, 0, 20358, 0, -12075, 0, 20374, 0, -12074, 0, 20760, 0, -12073, 0, 20436, 0, -12072, 0, 20447, 0, -12071, 0, 20430, 0, -12070, 0, 20440, 0, -12069, 0, 20443, 0, -12068, 0, 20433, 0, -12067, 0, 20442, 0, -12066, 0, 20432, 0, -12065, 0, 20452, 0, -12064, 0, 20453, 0, -12063, 0, 20506, 0, -12062, 0, 20520, 0, -12061, 0, 20500, 0, -12060, 0, 20522, 0, -12059, 0, 20517, 0, -12058, 0, 20485, 0, -12057, 0, 20252, 0, -12056, 0, 20470, 0, -12055, 0, 20513, 0, -12054, 0, 20521, 0, -12053, 0, 20524, 0, -12052, 0, 20478, 0, -12051, 0, 20463, 0, -12050, 0, 20497, 0, -12049, 0, 20486, 0, -12048, 0, 20547, 0, -12047, 0, 20551, 0, -12046, 0, 26371, 0, -12045, 0, 20565, 0, -12044, 0, 20560, 0, -12043, 0, 20552, 0, -12042, 0, 20570, 0, -12041, 0, 20566, 0, -12040, 0, 20588, 0, -12039, 0, 20600, 0, -12038, 0, 20608, 0, -12037, 0, 20634, 0, -12036, 0, 20613, 0, -12035, 0, 20660, 0, -12034, 0, 20658, 0, -11871, 0, 20681, 0, -11870, 0, 20682, 0, -11869, 0, 20659, 0, -11868, 0, 20674, 0, -11867, 0, 20694, 0, -11866, 0, 20702, 0, -11865, 0, 20709, 0, -11864, 0, 20717, 0, -11863, 0, 20707, 0, -11862, 0, 20718, 0, -11861, 0, 20729, 0, -11860, 0, 20725, 0, -11859, 0, 20745, 0, -11858, 0, 20737, 0, -11857, 0, 20738, 0, -11856, 0, 20758, 0, -11855, 0, 20757, 0, -11854, 0, 20756, 0, -11853, 0, 20762, 0, -11852, 0, 20769, 0, -11851, 0, 20794, 0, -11850, 0, 20791, 0, -11849, 0, 20796, 0, -11848, 0, 20795, 0, -11847, 0, 20799, 0, -11846, 0, 20800, 0, -11845, 0, 20818, 0, -11844, 0, 20812, 0, -11843, 0, 20820, 0, -11842, 0, 20834, 0, -11841, 0, 31480, 0, -11840, 0, 20841, 0, -11839, 0, 20842, 0, -11838, 0, 20846, 0, -11837, 0, 20864, 0, -11836, 0, 20866, 0, -11835, 0, 22232, 0, -11834, 0, 20876, 0, -11833, 0, 20873, 0, -11832, 0, 20879, 0, -11831, 0, 20881, 0, -11830, 0, 20883, 0, -11829, 0, 20885, 0, -11828, 0, 20886, 0, -11827, 0, 20900, 0, -11826, 0, 20902, 0, -11825, 0, 20898, 0, -11824, 0, 20905, 0, -11823, 0, 20906, 0, -11822, 0, 20907, 0, -11821, 0, 20915, 0, -11820, 0, 20913, 0, -11819, 0, 20914, 0, -11818, 0, 20912, 0, -11817, 0, 20917, 0, -11816, 0, 20925, 0, -11815, 0, 20933, 0, -11814, 0, 20937, 0, -11813, 0, 20955, 0, -11812, 0, 20960, 0, -11811, 0, -31147, 0, -11810, 0, 20969, 0, -11809, 0, 20973, 0, -11808, 0, 20976, 0, -11807, 0, 20981, 0, -11806, 0, 20990, 0, -11805, 0, 20996, 0, -11804, 0, 21003, 0, -11803, 0, 21012, 0, -11802, 0, 21006, 0, -11801, 0, 21031, 0, -11800, 0, 21034, 0, -11799, 0, 21038, 0, -11798, 0, 21043, 0, -11797, 0, 21049, 0, -11796, 0, 21071, 0, -11795, 0, 21060, 0, -11794, 0, 21067, 0, -11793, 0, 21068, 0, -11792, 0, 21086, 0, -11791, 0, 21076, 0, -11790, 0, 21098, 0, -11789, 0, 21108, 0, -11788, 0, 21097, 0, -11787, 0, 21107, 0, -11786, 0, 21119, 0, -11785, 0, 21117, 0, -11784, 0, 21133, 0, -11783, 0, 21140, 0, -11782, 0, 21138, 0, -11781, 0, 21105, 0, -11780, 0, 21128, 0, -11779, 0, 21137, 0, -11778, 0, -28760, 0, -11615, 0, -28761, 0, -11614, 0, 21164, 0, -11613, 0, 21165, 0, -11612, 0, 21180, 0, -11611, 0, 21173, 0, -11610, 0, 21185, 0, -11609, 0, 21197, 0, -11608, 0, 21207, 0, -11607, 0, 21214, 0, -11606, 0, 21219, 0, -11605, 0, 21222, 0, -11604, 0, -26387, 0, -11603, 0, 21216, 0, -11602, 0, 21235, 0, -11601, 0, 21237, 0, -11600, 0, 21240, 0, -11599, 0, 21241, 0, -11598, 0, 21254, 0, -11597, 0, 21256, 0, -11596, 0, 30008, 0, -11595, 0, 21261, 0, -11594, 0, 21264, 0, -11593, 0, 21263, 0, -11592, 0, 21269, 0, -11591, 0, 21274, 0, -11590, 0, 21283, 0, -11589, 0, 21295, 0, -11588, 0, 21297, 0, -11587, 0, 21299, 0, -11586, 0, 21304, 0, -11585, 0, 21312, 0, -11584, 0, 21318, 0, -11583, 0, 21317, 0, -11582, 0, 19991, 0, -11581, 0, 21321, 0, -11580, 0, 21325, 0, -11579, 0, 20950, 0, -11578, 0, 21342, 0, -11577, 0, 21353, 0, -11576, 0, 21358, 0, -11575, 0, 22808, 0, -11574, 0, 21371, 0, -11573, 0, 21367, 0, -11572, 0, 21378, 0, -11571, 0, 21398, 0, -11570, 0, 21408, 0, -11569, 0, 21414, 0, -11568, 0, 21413, 0, -11567, 0, 21422, 0, -11566, 0, 21424, 0, -11565, 0, 21430, 0, -11564, 0, 21443, 0, -11563, 0, 31762, 0, -11562, 0, -26919, 0, -11561, 0, 21471, 0, -11560, 0, 26364, 0, -11559, 0, 29166, 0, -11558, 0, 21486, 0, -11557, 0, 21480, 0, -11556, 0, 21485, 0, -11555, 0, 21498, 0, -11554, 0, 21505, 0, -11553, 0, 21565, 0, -11552, 0, 21568, 0, -11551, 0, 21548, 0, -11550, 0, 21549, 0, -11549, 0, 21564, 0, -11548, 0, 21550, 0, -11547, 0, 21558, 0, -11546, 0, 21545, 0, -11545, 0, 21533, 0, -11544, 0, 21582, 0, -11543, 0, 21647, 0, -11542, 0, 21621, 0, -11541, 0, 21646, 0, -11540, 0, 21599, 0, -11539, 0, 21617, 0, -11538, 0, 21623, 0, -11537, 0, 21616, 0, -11536, 0, 21650, 0, -11535, 0, 21627, 0, -11534, 0, 21632, 0, -11533, 0, 21622, 0, -11532, 0, 21636, 0, -11531, 0, 21648, 0, -11530, 0, 21638, 0, -11529, 0, 21703, 0, -11528, 0, 21666, 0, -11527, 0, 21688, 0, -11526, 0, 21669, 0, -11525, 0, 21676, 0, -11524, 0, 21700, 0, -11523, 0, 21704, 0, -11522, 0, 21672, 0, -11359, 0, 21675, 0, -11358, 0, 21698, 0, -11357, 0, 21668, 0, -11356, 0, 21694, 0, -11355, 0, 21692, 0, -11354, 0, 21720, 0, -11353, 0, 21733, 0, -11352, 0, 21734, 0, -11351, 0, 21775, 0, -11350, 0, 21780, 0, -11349, 0, 21757, 0, -11348, 0, 21742, 0, -11347, 0, 21741, 0, -11346, 0, 21754, 0, -11345, 0, 21730, 0, -11344, 0, 21817, 0, -11343, 0, 21824, 0, -11342, 0, 21859, 0, -11341, 0, 21836, 0, -11340, 0, 21806, 0, -11339, 0, 21852, 0, -11338, 0, 21829, 0, -11337, 0, 21846, 0, -11336, 0, 21847, 0, -11335, 0, 21816, 0, -11334, 0, 21811, 0, -11333, 0, 21853, 0, -11332, 0, 21913, 0, -11331, 0, 21888, 0, -11330, 0, 21679, 0, -11329, 0, 21898, 0, -11328, 0, 21919, 0, -11327, 0, 21883, 0, -11326, 0, 21886, 0, -11325, 0, 21912, 0, -11324, 0, 21918, 0, -11323, 0, 21934, 0, -11322, 0, 21884, 0, -11321, 0, 21891, 0, -11320, 0, 21929, 0, -11319, 0, 21895, 0, -11318, 0, 21928, 0, -11317, 0, 21978, 0, -11316, 0, 21957, 0, -11315, 0, 21983, 0, -11314, 0, 21956, 0, -11313, 0, 21980, 0, -11312, 0, 21988, 0, -11311, 0, 21972, 0, -11310, 0, 22036, 0, -11309, 0, 22007, 0, -11308, 0, 22038, 0, -11307, 0, 22014, 0, -11306, 0, 22013, 0, -11305, 0, 22043, 0, -11304, 0, 22009, 0, -11303, 0, 22094, 0, -11302, 0, 22096, 0, -11301, 0, 29151, 0, -11300, 0, 22068, 0, -11299, 0, 22070, 0, -11298, 0, 22066, 0, -11297, 0, 22072, 0, -11296, 0, 22123, 0, -11295, 0, 22116, 0, -11294, 0, 22063, 0, -11293, 0, 22124, 0, -11292, 0, 22122, 0, -11291, 0, 22150, 0, -11290, 0, 22144, 0, -11289, 0, 22154, 0, -11288, 0, 22176, 0, -11287, 0, 22164, 0, -11286, 0, 22159, 0, -11285, 0, 22181, 0, -11284, 0, 22190, 0, -11283, 0, 22198, 0, -11282, 0, 22196, 0, -11281, 0, 22210, 0, -11280, 0, 22204, 0, -11279, 0, 22209, 0, -11278, 0, 22211, 0, -11277, 0, 22208, 0, -11276, 0, 22216, 0, -11275, 0, 22222, 0, -11274, 0, 22225, 0, -11273, 0, 22227, 0, -11272, 0, 22231, 0, -11271, 0, 22254, 0, -11270, 0, 22265, 0, -11269, 0, 22272, 0, -11268, 0, 22271, 0, -11267, 0, 22276, 0, -11266, 0, 22281, 0, -11103, 0, 22280, 0, -11102, 0, 22283, 0, -11101, 0, 22285, 0, -11100, 0, 22291, 0, -11099, 0, 22296, 0, -11098, 0, 22294, 0, -11097, 0, 21959, 0, -11096, 0, 22300, 0, -11095, 0, 22310, 0, -11094, 0, 22327, 0, -11093, 0, 22328, 0, -11092, 0, 22350, 0, -11091, 0, 22331, 0, -11090, 0, 22336, 0, -11089, 0, 22351, 0, -11088, 0, 22377, 0, -11087, 0, 22464, 0, -11086, 0, 22408, 0, -11085, 0, 22369, 0, -11084, 0, 22399, 0, -11083, 0, 22409, 0, -11082, 0, 22419, 0, -11081, 0, 22432, 0, -11080, 0, 22451, 0, -11079, 0, 22436, 0, -11078, 0, 22442, 0, -11077, 0, 22448, 0, -11076, 0, 22467, 0, -11075, 0, 22470, 0, -11074, 0, 22484, 0, -11073, 0, 22482, 0, -11072, 0, 22483, 0, -11071, 0, 22538, 0, -11070, 0, 22486, 0, -11069, 0, 22499, 0, -11068, 0, 22539, 0, -11067, 0, 22553, 0, -11066, 0, 22557, 0, -11065, 0, 22642, 0, -11064, 0, 22561, 0, -11063, 0, 22626, 0, -11062, 0, 22603, 0, -11061, 0, 22640, 0, -11060, 0, 27584, 0, -11059, 0, 22610, 0, -11058, 0, 22589, 0, -11057, 0, 22649, 0, -11056, 0, 22661, 0, -11055, 0, 22713, 0, -11054, 0, 22687, 0, -11053, 0, 22699, 0, -11052, 0, 22714, 0, -11051, 0, 22750, 0, -11050, 0, 22715, 0, -11049, 0, 22712, 0, -11048, 0, 22702, 0, -11047, 0, 22725, 0, -11046, 0, 22739, 0, -11045, 0, 22737, 0, -11044, 0, 22743, 0, -11043, 0, 22745, 0, -11042, 0, 22744, 0, -11041, 0, 22757, 0, -11040, 0, 22748, 0, -11039, 0, 22756, 0, -11038, 0, 22751, 0, -11037, 0, 22767, 0, -11036, 0, 22778, 0, -11035, 0, 22777, 0, -11034, 0, 22779, 0, -11033, 0, 22780, 0, -11032, 0, 22781, 0, -11031, 0, 22786, 0, -11030, 0, 22794, 0, -11029, 0, 22800, 0, -11028, 0, 22811, 0, -11027, 0, 26790, 0, -11026, 0, 22821, 0, -11025, 0, 22828, 0, -11024, 0, 22829, 0, -11023, 0, 22834, 0, -11022, 0, 22840, 0, -11021, 0, 22846, 0, -11020, 0, 31442, 0, -11019, 0, 22869, 0, -11018, 0, 22864, 0, -11017, 0, 22862, 0, -11016, 0, 22874, 0, -11015, 0, 22872, 0, -11014, 0, 22882, 0, -11013, 0, 22880, 0, -11012, 0, 22887, 0, -11011, 0, 22892, 0, -11010, 0, 22889, 0, -10847, 0, 22904, 0, -10846, 0, 22913, 0, -10845, 0, 22941, 0, -10844, 0, 20318, 0, -10843, 0, 20395, 0, -10842, 0, 22947, 0, -10841, 0, 22962, 0, -10840, 0, 22982, 0, -10839, 0, 23016, 0, -10838, 0, 23004, 0, -10837, 0, 22925, 0, -10836, 0, 23001, 0, -10835, 0, 23002, 0, -10834, 0, 23077, 0, -10833, 0, 23071, 0, -10832, 0, 23057, 0, -10831, 0, 23068, 0, -10830, 0, 23049, 0, -10829, 0, 23066, 0, -10828, 0, 23104, 0, -10827, 0, 23148, 0, -10826, 0, 23113, 0, -10825, 0, 23093, 0, -10824, 0, 23094, 0, -10823, 0, 23138, 0, -10822, 0, 23146, 0, -10821, 0, 23194, 0, -10820, 0, 23228, 0, -10819, 0, 23230, 0, -10818, 0, 23243, 0, -10817, 0, 23234, 0, -10816, 0, 23229, 0, -10815, 0, 23267, 0, -10814, 0, 23255, 0, -10813, 0, 23270, 0, -10812, 0, 23273, 0, -10811, 0, 23254, 0, -10810, 0, 23290, 0, -10809, 0, 23291, 0, -10808, 0, 23308, 0, -10807, 0, 23307, 0, -10806, 0, 23318, 0, -10805, 0, 23346, 0, -10804, 0, 23248, 0, -10803, 0, 23338, 0, -10802, 0, 23350, 0, -10801, 0, 23358, 0, -10800, 0, 23363, 0, -10799, 0, 23365, 0, -10798, 0, 23360, 0, -10797, 0, 23377, 0, -10796, 0, 23381, 0, -10795, 0, 23386, 0, -10794, 0, 23387, 0, -10793, 0, 23397, 0, -10792, 0, 23401, 0, -10791, 0, 23408, 0, -10790, 0, 23411, 0, -10789, 0, 23413, 0, -10788, 0, 23416, 0, -10787, 0, 25992, 0, -10786, 0, 23418, 0, -10785, 0, 23424, 0, -10784, 0, 23427, 0, -10783, 0, 23462, 0, -10782, 0, 23480, 0, -10781, 0, 23491, 0, -10780, 0, 23495, 0, -10779, 0, 23497, 0, -10778, 0, 23508, 0, -10777, 0, 23504, 0, -10776, 0, 23524, 0, -10775, 0, 23526, 0, -10774, 0, 23522, 0, -10773, 0, 23518, 0, -10772, 0, 23525, 0, -10771, 0, 23531, 0, -10770, 0, 23536, 0, -10769, 0, 23542, 0, -10768, 0, 23539, 0, -10767, 0, 23557, 0, -10766, 0, 23559, 0, -10765, 0, 23560, 0, -10764, 0, 23565, 0, -10763, 0, 23571, 0, -10762, 0, 23584, 0, -10761, 0, 23586, 0, -10760, 0, 23592, 0, -10759, 0, 23608, 0, -10758, 0, 23609, 0, -10757, 0, 23617, 0, -10756, 0, 23622, 0, -10755, 0, 23630, 0, -10754, 0, 23635, 0, -10591, 0, 23632, 0, -10590, 0, 23631, 0, -10589, 0, 23409, 0, -10588, 0, 23660, 0, -10587, 0, 23662, 0, -10586, 0, 20066, 0, -10585, 0, 23670, 0, -10584, 0, 23673, 0, -10583, 0, 23692, 0, -10582, 0, 23697, 0, -10581, 0, 23700, 0, -10580, 0, 22939, 0, -10579, 0, 23723, 0, -10578, 0, 23739, 0, -10577, 0, 23734, 0, -10576, 0, 23740, 0, -10575, 0, 23735, 0, -10574, 0, 23749, 0, -10573, 0, 23742, 0, -10572, 0, 23751, 0, -10571, 0, 23769, 0, -10570, 0, 23785, 0, -10569, 0, 23805, 0, -10568, 0, 23802, 0, -10567, 0, 23789, 0, -10566, 0, 23948, 0, -10565, 0, 23786, 0, -10564, 0, 23819, 0, -10563, 0, 23829, 0, -10562, 0, 23831, 0, -10561, 0, 23900, 0, -10560, 0, 23839, 0, -10559, 0, 23835, 0, -10558, 0, 23825, 0, -10557, 0, 23828, 0, -10556, 0, 23842, 0, -10555, 0, 23834, 0, -10554, 0, 23833, 0, -10553, 0, 23832, 0, -10552, 0, 23884, 0, -10551, 0, 23890, 0, -10550, 0, 23886, 0, -10549, 0, 23883, 0, -10548, 0, 23916, 0, -10547, 0, 23923, 0, -10546, 0, 23926, 0, -10545, 0, 23943, 0, -10544, 0, 23940, 0, -10543, 0, 23938, 0, -10542, 0, 23970, 0, -10541, 0, 23965, 0, -10540, 0, 23980, 0, -10539, 0, 23982, 0, -10538, 0, 23997, 0, -10537, 0, 23952, 0, -10536, 0, 23991, 0, -10535, 0, 23996, 0, -10534, 0, 24009, 0, -10533, 0, 24013, 0, -10532, 0, 24019, 0, -10531, 0, 24018, 0, -10530, 0, 24022, 0, -10529, 0, 24027, 0, -10528, 0, 24043, 0, -10527, 0, 24050, 0, -10526, 0, 24053, 0, -10525, 0, 24075, 0, -10524, 0, 24090, 0, -10523, 0, 24089, 0, -10522, 0, 24081, 0, -10521, 0, 24091, 0, -10520, 0, 24118, 0, -10519, 0, 24119, 0, -10518, 0, 24132, 0, -10517, 0, 24131, 0, -10516, 0, 24128, 0, -10515, 0, 24142, 0, -10514, 0, 24151, 0, -10513, 0, 24148, 0, -10512, 0, 24159, 0, -10511, 0, 24162, 0, -10510, 0, 24164, 0, -10509, 0, 24135, 0, -10508, 0, 24181, 0, -10507, 0, 24182, 0, -10506, 0, 24186, 0, -10505, 0, -24900, 0, -10504, 0, 24191, 0, -10503, 0, 24224, 0, -10502, 0, 24257, 0, -10501, 0, 24258, 0, -10500, 0, 24264, 0, -10499, 0, 24272, 0, -10498, 0, 24271, 0, -10335, 0, 24278, 0, -10334, 0, 24291, 0, -10333, 0, 24285, 0, -10332, 0, 24282, 0, -10331, 0, 24283, 0, -10330, 0, 24290, 0, -10329, 0, 24289, 0, -10328, 0, 24296, 0, -10327, 0, 24297, 0, -10326, 0, 24300, 0, -10325, 0, 24305, 0, -10324, 0, 24307, 0, -10323, 0, 24304, 0, -10322, 0, 24308, 0, -10321, 0, 24312, 0, -10320, 0, 24318, 0, -10319, 0, 24323, 0, -10318, 0, 24329, 0, -10317, 0, 24413, 0, -10316, 0, 24412, 0, -10315, 0, 24331, 0, -10314, 0, 24337, 0, -10313, 0, 24342, 0, -10312, 0, 24361, 0, -10311, 0, 24365, 0, -10310, 0, 24376, 0, -10309, 0, 24385, 0, -10308, 0, 24392, 0, -10307, 0, 24396, 0, -10306, 0, 24398, 0, -10305, 0, 24367, 0, -10304, 0, 24401, 0, -10303, 0, 24406, 0, -10302, 0, 24407, 0, -10301, 0, 24409, 0, -10300, 0, 24417, 0, -10299, 0, 24429, 0, -10298, 0, 24435, 0, -10297, 0, 24439, 0, -10296, 0, 24451, 0, -10295, 0, 24450, 0, -10294, 0, 24447, 0, -10293, 0, 24458, 0, -10292, 0, 24456, 0, -10291, 0, 24465, 0, -10290, 0, 24455, 0, -10289, 0, 24478, 0, -10288, 0, 24473, 0, -10287, 0, 24472, 0, -10286, 0, 24480, 0, -10285, 0, 24488, 0, -10284, 0, 24493, 0, -10283, 0, 24508, 0, -10282, 0, 24534, 0, -10281, 0, 24571, 0, -10280, 0, 24548, 0, -10279, 0, 24568, 0, -10278, 0, 24561, 0, -10277, 0, 24541, 0, -10276, 0, 24755, 0, -10275, 0, 24575, 0, -10274, 0, 24609, 0, -10273, 0, 24672, 0, -10272, 0, 24601, 0, -10271, 0, 24592, 0, -10270, 0, 24617, 0, -10269, 0, 24590, 0, -10268, 0, 24625, 0, -10267, 0, 24603, 0, -10266, 0, 24597, 0, -10265, 0, 24619, 0, -10264, 0, 24614, 0, -10263, 0, 24591, 0, -10262, 0, 24634, 0, -10261, 0, 24666, 0, -10260, 0, 24641, 0, -10259, 0, 24682, 0, -10258, 0, 24695, 0, -10257, 0, 24671, 0, -10256, 0, 24650, 0, -10255, 0, 24646, 0, -10254, 0, 24653, 0, -10253, 0, 24675, 0, -10252, 0, 24643, 0, -10251, 0, 24676, 0, -10250, 0, 24642, 0, -10249, 0, 24684, 0, -10248, 0, 24683, 0, -10247, 0, 24665, 0, -10246, 0, 24705, 0, -10245, 0, 24717, 0, -10244, 0, 24807, 0, -10243, 0, 24707, 0, -10242, 0, 24730, 0, -10079, 0, 24708, 0, -10078, 0, 24731, 0, -10077, 0, 24726, 0, -10076, 0, 24727, 0, -10075, 0, 24722, 0, -10074, 0, 24743, 0, -10073, 0, 24715, 0, -10072, 0, 24801, 0, -10071, 0, 24760, 0, -10070, 0, 24800, 0, -10069, 0, 24787, 0, -10068, 0, 24756, 0, -10067, 0, 24560, 0, -10066, 0, 24765, 0, -10065, 0, 24774, 0, -10064, 0, 24757, 0, -10063, 0, 24792, 0, -10062, 0, 24909, 0, -10061, 0, 24853, 0, -10060, 0, 24838, 0, -10059, 0, 24822, 0, -10058, 0, 24823, 0, -10057, 0, 24832, 0, -10056, 0, 24820, 0, -10055, 0, 24826, 0, -10054, 0, 24835, 0, -10053, 0, 24865, 0, -10052, 0, 24827, 0, -10051, 0, 24817, 0, -10050, 0, 24845, 0, -10049, 0, 24846, 0, -10048, 0, 24903, 0, -10047, 0, 24894, 0, -10046, 0, 24872, 0, -10045, 0, 24871, 0, -10044, 0, 24906, 0, -10043, 0, 24895, 0, -10042, 0, 24892, 0, -10041, 0, 24876, 0, -10040, 0, 24884, 0, -10039, 0, 24893, 0, -10038, 0, 24898, 0, -10037, 0, 24900, 0, -10036, 0, 24947, 0, -10035, 0, 24951, 0, -10034, 0, 24920, 0, -10033, 0, 24921, 0, -10032, 0, 24922, 0, -10031, 0, 24939, 0, -10030, 0, 24948, 0, -10029, 0, 24943, 0, -10028, 0, 24933, 0, -10027, 0, 24945, 0, -10026, 0, 24927, 0, -10025, 0, 24925, 0, -10024, 0, 24915, 0, -10023, 0, 24949, 0, -10022, 0, 24985, 0, -10021, 0, 24982, 0, -10020, 0, 24967, 0, -10019, 0, 25004, 0, -10018, 0, 24980, 0, -10017, 0, 24986, 0, -10016, 0, 24970, 0, -10015, 0, 24977, 0, -10014, 0, 25003, 0, -10013, 0, 25006, 0, -10012, 0, 25036, 0, -10011, 0, 25034, 0, -10010, 0, 25033, 0, -10009, 0, 25079, 0, -10008, 0, 25032, 0, -10007, 0, 25027, 0, -10006, 0, 25030, 0, -10005, 0, 25018, 0, -10004, 0, 25035, 0, -10003, 0, 32633, 0, -10002, 0, 25037, 0, -10001, 0, 25062, 0, -10000, 0, 25059, 0, -9999, 0, 25078, 0, -9998, 0, 25082, 0, -9997, 0, 25076, 0, -9996, 0, 25087, 0, -9995, 0, 25085, 0, -9994, 0, 25084, 0, -9993, 0, 25086, 0, -9992, 0, 25088, 0, -9991, 0, 25096, 0, -9990, 0, 25097, 0, -9989, 0, 25101, 0, -9988, 0, 25100, 0, -9987, 0, 25108, 0, -9986, 0, 25115, 0, -9823, 0, 25118, 0, -9822, 0, 25121, 0, -9821, 0, 25130, 0, -9820, 0, 25134, 0, -9819, 0, 25136, 0, -9818, 0, 25138, 0, -9817, 0, 25139, 0, -9816, 0, 25153, 0, -9815, 0, 25166, 0, -9814, 0, 25182, 0, -9813, 0, 25187, 0, -9812, 0, 25179, 0, -9811, 0, 25184, 0, -9810, 0, 25192, 0, -9809, 0, 25212, 0, -9808, 0, 25218, 0, -9807, 0, 25225, 0, -9806, 0, 25214, 0, -9805, 0, 25234, 0, -9804, 0, 25235, 0, -9803, 0, 25238, 0, -9802, 0, 25300, 0, -9801, 0, 25219, 0, -9800, 0, 25236, 0, -9799, 0, 25303, 0, -9798, 0, 25297, 0, -9797, 0, 25275, 0, -9796, 0, 25295, 0, -9795, 0, 25343, 0, -9794, 0, 25286, 0, -9793, 0, 25812, 0, -9792, 0, 25288, 0, -9791, 0, 25308, 0, -9790, 0, 25292, 0, -9789, 0, 25290, 0, -9788, 0, 25282, 0, -9787, 0, 25287, 0, -9786, 0, 25243, 0, -9785, 0, 25289, 0, -9784, 0, 25356, 0, -9783, 0, 25326, 0, -9782, 0, 25329, 0, -9781, 0, 25383, 0, -9780, 0, 25346, 0, -9779, 0, 25352, 0, -9778, 0, 25327, 0, -9777, 0, 25333, 0, -9776, 0, 25424, 0, -9775, 0, 25406, 0, -9774, 0, 25421, 0, -9773, 0, 25628, 0, -9772, 0, 25423, 0, -9771, 0, 25494, 0, -9770, 0, 25486, 0, -9769, 0, 25472, 0, -9768, 0, 25515, 0, -9767, 0, 25462, 0, -9766, 0, 25507, 0, -9765, 0, 25487, 0, -9764, 0, 25481, 0, -9763, 0, 25503, 0, -9762, 0, 25525, 0, -9761, 0, 25451, 0, -9760, 0, 25449, 0, -9759, 0, 25534, 0, -9758, 0, 25577, 0, -9757, 0, 25536, 0, -9756, 0, 25542, 0, -9755, 0, 25571, 0, -9754, 0, 25545, 0, -9753, 0, 25554, 0, -9752, 0, 25590, 0, -9751, 0, 25540, 0, -9750, 0, 25622, 0, -9749, 0, 25652, 0, -9748, 0, 25606, 0, -9747, 0, 25619, 0, -9746, 0, 25638, 0, -9745, 0, 25654, 0, -9744, 0, 25885, 0, -9743, 0, 25623, 0, -9742, 0, 25640, 0, -9741, 0, 25615, 0, -9740, 0, 25703, 0, -9739, 0, 25711, 0, -9738, 0, 25718, 0, -9737, 0, 25678, 0, -9736, 0, 25898, 0, -9735, 0, 25749, 0, -9734, 0, 25747, 0, -9733, 0, 25765, 0, -9732, 0, 25769, 0, -9731, 0, 25736, 0, -9730, 0, 25788, 0, -9567, 0, 25818, 0, -9566, 0, 25810, 0, -9565, 0, 25797, 0, -9564, 0, 25799, 0, -9563, 0, 25787, 0, -9562, 0, 25816, 0, -9561, 0, 25794, 0, -9560, 0, 25841, 0, -9559, 0, 25831, 0, -9558, 0, -32247, 0, -9557, 0, 25824, 0, -9556, 0, 25825, 0, -9555, 0, 25260, 0, -9554, 0, 25827, 0, -9553, 0, 25839, 0, -9552, 0, 25900, 0, -9551, 0, 25846, 0, -9550, 0, 25844, 0, -9549, 0, 25842, 0, -9548, 0, 25850, 0, -9547, 0, 25856, 0, -9546, 0, 25853, 0, -9545, 0, 25880, 0, -9544, 0, 25884, 0, -9543, 0, 25861, 0, -9542, 0, 25892, 0, -9541, 0, 25891, 0, -9540, 0, 25899, 0, -9539, 0, 25908, 0, -9538, 0, 25909, 0, -9537, 0, 25911, 0, -9536, 0, 25910, 0, -9535, 0, 25912, 0, -9534, 0, 30027, 0, -9533, 0, 25928, 0, -9532, 0, 25942, 0, -9531, 0, 25941, 0, -9530, 0, 25933, 0, -9529, 0, 25944, 0, -9528, 0, 25950, 0, -9527, 0, 25949, 0, -9526, 0, 25970, 0, -9525, 0, 25976, 0, -9524, 0, 25986, 0, -9523, 0, 25987, 0, -9522, 0, -29814, 0, -9521, 0, 26011, 0, -9520, 0, 26015, 0, -9519, 0, 26027, 0, -9518, 0, 26039, 0, -9517, 0, 26051, 0, -9516, 0, 26054, 0, -9515, 0, 26049, 0, -9514, 0, 26052, 0, -9513, 0, 26060, 0, -9512, 0, 26066, 0, -9511, 0, 26075, 0, -9510, 0, 26073, 0, -9509, 0, 26080, 0, -9508, 0, 26081, 0, -9507, 0, 26097, 0, -9506, 0, 26482, 0, -9505, 0, 26122, 0, -9504, 0, 26115, 0, -9503, 0, 26107, 0, -9502, 0, 26483, 0, -9501, 0, 26165, 0, -9500, 0, 26166, 0, -9499, 0, 26164, 0, -9498, 0, 26140, 0, -9497, 0, 26191, 0, -9496, 0, 26180, 0, -9495, 0, 26185, 0, -9494, 0, 26177, 0, -9493, 0, 26206, 0, -9492, 0, 26205, 0, -9491, 0, 26212, 0, -9490, 0, 26215, 0, -9489, 0, 26216, 0, -9488, 0, 26207, 0, -9487, 0, 26210, 0, -9486, 0, 26224, 0, -9485, 0, 26243, 0, -9484, 0, 26248, 0, -9483, 0, 26254, 0, -9482, 0, 26249, 0, -9481, 0, 26244, 0, -9480, 0, 26264, 0, -9479, 0, 26269, 0, -9478, 0, 26305, 0, -9477, 0, 26297, 0, -9476, 0, 26313, 0, -9475, 0, 26302, 0, -9474, 0, 26300, 0, -9311, 0, 26308, 0, -9310, 0, 26296, 0, -9309, 0, 26326, 0, -9308, 0, 26330, 0, -9307, 0, 26336, 0, -9306, 0, 26175, 0, -9305, 0, 26342, 0, -9304, 0, 26345, 0, -9303, 0, 26352, 0, -9302, 0, 26357, 0, -9301, 0, 26359, 0, -9300, 0, 26383, 0, -9299, 0, 26390, 0, -9298, 0, 26398, 0, -9297, 0, 26406, 0, -9296, 0, 26407, 0, -9295, 0, -26824, 0, -9294, 0, 26414, 0, -9293, 0, 26431, 0, -9292, 0, 26422, 0, -9291, 0, 26433, 0, -9290, 0, 26424, 0, -9289, 0, 26423, 0, -9288, 0, 26438, 0, -9287, 0, 26462, 0, -9286, 0, 26464, 0, -9285, 0, 26457, 0, -9284, 0, 26467, 0, -9283, 0, 26468, 0, -9282, 0, 26505, 0, -9281, 0, 26480, 0, -9280, 0, 26537, 0, -9279, 0, 26492, 0, -9278, 0, 26474, 0, -9277, 0, 26508, 0, -9276, 0, 26507, 0, -9275, 0, 26534, 0, -9274, 0, 26529, 0, -9273, 0, 26501, 0, -9272, 0, 26551, 0, -9271, 0, 26607, 0, -9270, 0, 26548, 0, -9269, 0, 26604, 0, -9268, 0, 26547, 0, -9267, 0, 26601, 0, -9266, 0, 26552, 0, -9265, 0, 26596, 0, -9264, 0, 26590, 0, -9263, 0, 26589, 0, -9262, 0, 26594, 0, -9261, 0, 26606, 0, -9260, 0, 26553, 0, -9259, 0, 26574, 0, -9258, 0, 26566, 0, -9257, 0, 26599, 0, -9256, 0, 27292, 0, -9255, 0, 26654, 0, -9254, 0, 26694, 0, -9253, 0, 26665, 0, -9252, 0, 26688, 0, -9251, 0, 26701, 0, -9250, 0, 26674, 0, -9249, 0, 26702, 0, -9248, 0, 26803, 0, -9247, 0, 26667, 0, -9246, 0, 26713, 0, -9245, 0, 26723, 0, -9244, 0, 26743, 0, -9243, 0, 26751, 0, -9242, 0, 26783, 0, -9241, 0, 26767, 0, -9240, 0, 26797, 0, -9239, 0, 26772, 0, -9238, 0, 26781, 0, -9237, 0, 26779, 0, -9236, 0, 26755, 0, -9235, 0, 27310, 0, -9234, 0, 26809, 0, -9233, 0, 26740, 0, -9232, 0, 26805, 0, -9231, 0, 26784, 0, -9230, 0, 26810, 0, -9229, 0, 26895, 0, -9228, 0, 26765, 0, -9227, 0, 26750, 0, -9226, 0, 26881, 0, -9225, 0, 26826, 0, -9224, 0, 26888, 0, -9223, 0, 26840, 0, -9222, 0, 26914, 0, -9221, 0, 26918, 0, -9220, 0, 26849, 0, -9219, 0, 26892, 0, -9218, 0, 26829, 0, -9055, 0, 26836, 0, -9054, 0, 26855, 0, -9053, 0, 26837, 0, -9052, 0, 26934, 0, -9051, 0, 26898, 0, -9050, 0, 26884, 0, -9049, 0, 26839, 0, -9048, 0, 26851, 0, -9047, 0, 26917, 0, -9046, 0, 26873, 0, -9045, 0, 26848, 0, -9044, 0, 26863, 0, -9043, 0, 26920, 0, -9042, 0, 26922, 0, -9041, 0, 26906, 0, -9040, 0, 26915, 0, -9039, 0, 26913, 0, -9038, 0, 26822, 0, -9037, 0, 27001, 0, -9036, 0, 26999, 0, -9035, 0, 26972, 0, -9034, 0, 27000, 0, -9033, 0, 26987, 0, -9032, 0, 26964, 0, -9031, 0, 27006, 0, -9030, 0, 26990, 0, -9029, 0, 26937, 0, -9028, 0, 26996, 0, -9027, 0, 26941, 0, -9026, 0, 26969, 0, -9025, 0, 26928, 0, -9024, 0, 26977, 0, -9023, 0, 26974, 0, -9022, 0, 26973, 0, -9021, 0, 27009, 0, -9020, 0, 26986, 0, -9019, 0, 27058, 0, -9018, 0, 27054, 0, -9017, 0, 27088, 0, -9016, 0, 27071, 0, -9015, 0, 27073, 0, -9014, 0, 27091, 0, -9013, 0, 27070, 0, -9012, 0, 27086, 0, -9011, 0, 23528, 0, -9010, 0, 27082, 0, -9009, 0, 27101, 0, -9008, 0, 27067, 0, -9007, 0, 27075, 0, -9006, 0, 27047, 0, -9005, 0, 27182, 0, -9004, 0, 27025, 0, -9003, 0, 27040, 0, -9002, 0, 27036, 0, -9001, 0, 27029, 0, -9000, 0, 27060, 0, -8999, 0, 27102, 0, -8998, 0, 27112, 0, -8997, 0, 27138, 0, -8996, 0, 27163, 0, -8995, 0, 27135, 0, -8994, 0, 27402, 0, -8993, 0, 27129, 0, -8992, 0, 27122, 0, -8991, 0, 27111, 0, -8990, 0, 27141, 0, -8989, 0, 27057, 0, -8988, 0, 27166, 0, -8987, 0, 27117, 0, -8986, 0, 27156, 0, -8985, 0, 27115, 0, -8984, 0, 27146, 0, -8983, 0, 27154, 0, -8982, 0, 27329, 0, -8981, 0, 27171, 0, -8980, 0, 27155, 0, -8979, 0, 27204, 0, -8978, 0, 27148, 0, -8977, 0, 27250, 0, -8976, 0, 27190, 0, -8975, 0, 27256, 0, -8974, 0, 27207, 0, -8973, 0, 27234, 0, -8972, 0, 27225, 0, -8971, 0, 27238, 0, -8970, 0, 27208, 0, -8969, 0, 27192, 0, -8968, 0, 27170, 0, -8967, 0, 27280, 0, -8966, 0, 27277, 0, -8965, 0, 27296, 0, -8964, 0, 27268, 0, -8963, 0, 27298, 0, -8962, 0, 27299, 0, -8799, 0, 27287, 0, -8798, 0, -31209, 0, -8797, 0, 27323, 0, -8796, 0, 27331, 0, -8795, 0, 27330, 0, -8794, 0, 27320, 0, -8793, 0, 27315, 0, -8792, 0, 27308, 0, -8791, 0, 27358, 0, -8790, 0, 27345, 0, -8789, 0, 27359, 0, -8788, 0, 27306, 0, -8787, 0, 27354, 0, -8786, 0, 27370, 0, -8785, 0, 27387, 0, -8784, 0, 27397, 0, -8783, 0, -31210, 0, -8782, 0, 27386, 0, -8781, 0, 27410, 0, -8780, 0, 27414, 0, -8779, 0, -25807, 0, -8778, 0, 27423, 0, -8777, 0, 27448, 0, -8776, 0, 27447, 0, -8775, 0, 30428, 0, -8774, 0, 27449, 0, -8773, 0, -26386, 0, -8772, 0, 27463, 0, -8771, 0, 27459, 0, -8770, 0, 27465, 0, -8769, 0, 27472, 0, -8768, 0, 27481, 0, -8767, 0, 27476, 0, -8766, 0, 27483, 0, -8765, 0, 27487, 0, -8764, 0, 27489, 0, -8763, 0, 27512, 0, -8762, 0, 27513, 0, -8761, 0, 27519, 0, -8760, 0, 27520, 0, -8759, 0, 27524, 0, -8758, 0, 27523, 0, -8757, 0, 27533, 0, -8756, 0, 27544, 0, -8755, 0, 27541, 0, -8754, 0, 27550, 0, -8753, 0, 27556, 0, -8752, 0, 27562, 0, -8751, 0, 27563, 0, -8750, 0, 27567, 0, -8749, 0, 27570, 0, -8748, 0, 27569, 0, -8747, 0, 27571, 0, -8746, 0, 27575, 0, -8745, 0, 27580, 0, -8744, 0, 27590, 0, -8743, 0, 27595, 0, -8742, 0, 27603, 0, -8741, 0, 27615, 0, -8740, 0, 27628, 0, -8739, 0, 27627, 0, -8738, 0, 27635, 0, -8737, 0, 27631, 0, -8736, 0, -24898, 0, -8735, 0, 27656, 0, -8734, 0, 27667, 0, -8733, 0, 27668, 0, -8732, 0, 27675, 0, -8731, 0, 27684, 0, -8730, 0, 27683, 0, -8729, 0, 27742, 0, -8728, 0, 27733, 0, -8727, 0, 27746, 0, -8726, 0, 27754, 0, -8725, 0, 27778, 0, -8724, 0, 27789, 0, -8723, 0, 27802, 0, -8722, 0, 27777, 0, -8721, 0, 27803, 0, -8720, 0, 27774, 0, -8719, 0, 27752, 0, -8718, 0, 27763, 0, -8717, 0, 27794, 0, -8716, 0, 27792, 0, -8715, 0, 27844, 0, -8714, 0, 27889, 0, -8713, 0, 27859, 0, -8712, 0, 27837, 0, -8711, 0, 27863, 0, -8710, 0, 27845, 0, -8709, 0, 27869, 0, -8708, 0, 27822, 0, -8707, 0, 27825, 0, -8706, 0, 27838, 0, -8543, 0, 27834, 0, -8542, 0, 27867, 0, -8541, 0, 27887, 0, -8540, 0, 27865, 0, -8539, 0, 27882, 0, -8538, 0, 27935, 0, -8537, 0, -30643, 0, -8536, 0, 27958, 0, -8535, 0, 27947, 0, -8534, 0, 27965, 0, -8533, 0, 27960, 0, -8532, 0, 27929, 0, -8531, 0, 27957, 0, -8530, 0, 27955, 0, -8529, 0, 27922, 0, -8528, 0, 27916, 0, -8527, 0, 28003, 0, -8526, 0, 28051, 0, -8525, 0, 28004, 0, -8524, 0, 27994, 0, -8523, 0, 28025, 0, -8522, 0, 27993, 0, -8521, 0, 28046, 0, -8520, 0, 28053, 0, -8519, 0, 28644, 0, -8518, 0, 28037, 0, -8517, 0, 28153, 0, -8516, 0, 28181, 0, -8515, 0, 28170, 0, -8514, 0, 28085, 0, -8513, 0, 28103, 0, -8512, 0, 28134, 0, -8511, 0, 28088, 0, -8510, 0, 28102, 0, -8509, 0, 28140, 0, -8508, 0, 28126, 0, -8507, 0, 28108, 0, -8506, 0, 28136, 0, -8505, 0, 28114, 0, -8504, 0, 28101, 0, -8503, 0, 28154, 0, -8502, 0, 28121, 0, -8501, 0, 28132, 0, -8500, 0, 28117, 0, -8499, 0, 28138, 0, -8498, 0, 28142, 0, -8497, 0, 28205, 0, -8496, 0, 28270, 0, -8495, 0, 28206, 0, -8494, 0, 28185, 0, -8493, 0, 28274, 0, -8492, 0, 28255, 0, -8491, 0, 28222, 0, -8490, 0, 28195, 0, -8489, 0, 28267, 0, -8488, 0, 28203, 0, -8487, 0, 28278, 0, -8486, 0, 28237, 0, -8485, 0, 28191, 0, -8484, 0, 28227, 0, -8483, 0, 28218, 0, -8482, 0, 28238, 0, -8481, 0, 28196, 0, -8480, 0, 28415, 0, -8479, 0, 28189, 0, -8478, 0, 28216, 0, -8477, 0, 28290, 0, -8476, 0, 28330, 0, -8475, 0, 28312, 0, -8474, 0, 28361, 0, -8473, 0, 28343, 0, -8472, 0, 28371, 0, -8471, 0, 28349, 0, -8470, 0, 28335, 0, -8469, 0, 28356, 0, -8468, 0, 28338, 0, -8467, 0, 28372, 0, -8466, 0, 28373, 0, -8465, 0, 28303, 0, -8464, 0, 28325, 0, -8463, 0, 28354, 0, -8462, 0, 28319, 0, -8461, 0, 28481, 0, -8460, 0, 28433, 0, -8459, 0, 28748, 0, -8458, 0, 28396, 0, -8457, 0, 28408, 0, -8456, 0, 28414, 0, -8455, 0, 28479, 0, -8454, 0, 28402, 0, -8453, 0, 28465, 0, -8452, 0, 28399, 0, -8451, 0, 28466, 0, -8450, 0, 28364, 0, -8287, 0, 28478, 0, -8286, 0, 28435, 0, -8285, 0, 28407, 0, -8284, 0, 28550, 0, -8283, 0, 28538, 0, -8282, 0, 28536, 0, -8281, 0, 28545, 0, -8280, 0, 28544, 0, -8279, 0, 28527, 0, -8278, 0, 28507, 0, -8277, 0, 28659, 0, -8276, 0, 28525, 0, -8275, 0, 28546, 0, -8274, 0, 28540, 0, -8273, 0, 28504, 0, -8272, 0, 28558, 0, -8271, 0, 28561, 0, -8270, 0, 28610, 0, -8269, 0, 28518, 0, -8268, 0, 28595, 0, -8267, 0, 28579, 0, -8266, 0, 28577, 0, -8265, 0, 28580, 0, -8264, 0, 28601, 0, -8263, 0, 28614, 0, -8262, 0, 28586, 0, -8261, 0, 28639, 0, -8260, 0, 28629, 0, -8259, 0, 28652, 0, -8258, 0, 28628, 0, -8257, 0, 28632, 0, -8256, 0, 28657, 0, -8255, 0, 28654, 0, -8254, 0, 28635, 0, -8253, 0, 28681, 0, -8252, 0, 28683, 0, -8251, 0, 28666, 0, -8250, 0, 28689, 0, -8249, 0, 28673, 0, -8248, 0, 28687, 0, -8247, 0, 28670, 0, -8246, 0, 28699, 0, -8245, 0, 28698, 0, -8244, 0, 28532, 0, -8243, 0, 28701, 0, -8242, 0, 28696, 0, -8241, 0, 28703, 0, -8240, 0, 28720, 0, -8239, 0, 28734, 0, -8238, 0, 28722, 0, -8237, 0, 28753, 0, -8236, 0, 28771, 0, -8235, 0, 28825, 0, -8234, 0, 28818, 0, -8233, 0, 28847, 0, -8232, 0, 28913, 0, -8231, 0, 28844, 0, -8230, 0, 28856, 0, -8229, 0, 28851, 0, -8228, 0, 28846, 0, -8227, 0, 28895, 0, -8226, 0, 28875, 0, -8225, 0, 28893, 0, -8224, 0, 28889, 0, -8223, 0, 28937, 0, -8222, 0, 28925, 0, -8221, 0, 28956, 0, -8220, 0, 28953, 0, -8219, 0, 29029, 0, -8218, 0, 29013, 0, -8217, 0, 29064, 0, -8216, 0, 29030, 0, -8215, 0, 29026, 0, -8214, 0, 29004, 0, -8213, 0, 29014, 0, -8212, 0, 29036, 0, -8211, 0, 29071, 0, -8210, 0, 29179, 0, -8209, 0, 29060, 0, -8208, 0, 29077, 0, -8207, 0, 29096, 0, -8206, 0, 29100, 0, -8205, 0, 29143, 0, -8204, 0, 29113, 0, -8203, 0, 29118, 0, -8202, 0, 29138, 0, -8201, 0, 29129, 0, -8200, 0, 29140, 0, -8199, 0, 29134, 0, -8198, 0, 29152, 0, -8197, 0, 29164, 0, -8196, 0, 29159, 0, -8195, 0, 29173, 0, -8194, 0, 29180, 0, -8031, 0, 29177, 0, -8030, 0, 29183, 0, -8029, 0, 29197, 0, -8028, 0, 29200, 0, -8027, 0, 29211, 0, -8026, 0, 29224, 0, -8025, 0, 29229, 0, -8024, 0, 29228, 0, -8023, 0, 29232, 0, -8022, 0, 29234, 0, -8021, 0, 29243, 0, -8020, 0, 29244, 0, -8019, 0, 29247, 0, -8018, 0, 29248, 0, -8017, 0, 29254, 0, -8016, 0, 29259, 0, -8015, 0, 29272, 0, -8014, 0, 29300, 0, -8013, 0, 29310, 0, -8012, 0, 29314, 0, -8011, 0, 29313, 0, -8010, 0, 29319, 0, -8009, 0, 29330, 0, -8008, 0, 29334, 0, -8007, 0, 29346, 0, -8006, 0, 29351, 0, -8005, 0, 29369, 0, -8004, 0, 29362, 0, -8003, 0, 29379, 0, -8002, 0, 29382, 0, -8001, 0, 29380, 0, -8000, 0, 29390, 0, -7999, 0, 29394, 0, -7998, 0, 29410, 0, -7997, 0, 29408, 0, -7996, 0, 29409, 0, -7995, 0, 29433, 0, -7994, 0, 29431, 0, -7993, 0, 20495, 0, -7992, 0, 29463, 0, -7991, 0, 29450, 0, -7990, 0, 29468, 0, -7989, 0, 29462, 0, -7988, 0, 29469, 0, -7987, 0, 29492, 0, -7986, 0, 29487, 0, -7985, 0, 29481, 0, -7984, 0, 29477, 0, -7983, 0, 29502, 0, -7982, 0, 29518, 0, -7981, 0, 29519, 0, -7980, 0, -24872, 0, -7979, 0, 29527, 0, -7978, 0, 29546, 0, -7977, 0, 29544, 0, -7976, 0, 29552, 0, -7975, 0, 29560, 0, -7974, 0, 29557, 0, -7973, 0, 29563, 0, -7972, 0, 29562, 0, -7971, 0, 29640, 0, -7970, 0, 29619, 0, -7969, 0, 29646, 0, -7968, 0, 29627, 0, -7967, 0, 29632, 0, -7966, 0, 29669, 0, -7965, 0, 29678, 0, -7964, 0, 29662, 0, -7963, 0, 29858, 0, -7962, 0, 29701, 0, -7961, 0, 29807, 0, -7960, 0, 29733, 0, -7959, 0, 29688, 0, -7958, 0, 29746, 0, -7957, 0, 29754, 0, -7956, 0, 29781, 0, -7955, 0, 29759, 0, -7954, 0, 29791, 0, -7953, 0, 29785, 0, -7952, 0, 29761, 0, -7951, 0, 29788, 0, -7950, 0, 29801, 0, -7949, 0, 29808, 0, -7948, 0, 29795, 0, -7947, 0, 29802, 0, -7946, 0, 29814, 0, -7945, 0, 29822, 0, -7944, 0, 29835, 0, -7943, 0, 29854, 0, -7942, 0, 29863, 0, -7941, 0, 29898, 0, -7940, 0, 29903, 0, -7939, 0, 29908, 0, -7938, 0, 29681, 0, -7775, 0, 29920, 0, -7774, 0, 29923, 0, -7773, 0, 29927, 0, -7772, 0, 29929, 0, -7771, 0, 29934, 0, -7770, 0, 29938, 0, -7769, 0, 29936, 0, -7768, 0, 29937, 0, -7767, 0, 29944, 0, -7766, 0, 29943, 0, -7765, 0, 29956, 0, -7764, 0, 29955, 0, -7763, 0, 29957, 0, -7762, 0, 29964, 0, -7761, 0, 29966, 0, -7760, 0, 29965, 0, -7759, 0, 29973, 0, -7758, 0, 29971, 0, -7757, 0, 29982, 0, -7756, 0, 29990, 0, -7755, 0, 29996, 0, -7754, 0, 30012, 0, -7753, 0, 30020, 0, -7752, 0, 30029, 0, -7751, 0, 30026, 0, -7750, 0, 30025, 0, -7749, 0, 30043, 0, -7748, 0, 30022, 0, -7747, 0, 30042, 0, -7746, 0, 30057, 0, -7745, 0, 30052, 0, -7744, 0, 30055, 0, -7743, 0, 30059, 0, -7742, 0, 30061, 0, -7741, 0, 30072, 0, -7740, 0, 30070, 0, -7739, 0, 30086, 0, -7738, 0, 30087, 0, -7737, 0, 30068, 0, -7736, 0, 30090, 0, -7735, 0, 30089, 0, -7734, 0, 30082, 0, -7733, 0, 30100, 0, -7732, 0, 30106, 0, -7731, 0, 30109, 0, -7730, 0, 30117, 0, -7729, 0, 30115, 0, -7728, 0, 30146, 0, -7727, 0, 30131, 0, -7726, 0, 30147, 0, -7725, 0, 30133, 0, -7724, 0, 30141, 0, -7723, 0, 30136, 0, -7722, 0, 30140, 0, -7721, 0, 30129, 0, -7720, 0, 30157, 0, -7719, 0, 30154, 0, -7718, 0, 30162, 0, -7717, 0, 30169, 0, -7716, 0, 30179, 0, -7715, 0, 30174, 0, -7714, 0, 30206, 0, -7713, 0, 30207, 0, -7712, 0, 30204, 0, -7711, 0, 30209, 0, -7710, 0, 30192, 0, -7709, 0, 30202, 0, -7708, 0, 30194, 0, -7707, 0, 30195, 0, -7706, 0, 30219, 0, -7705, 0, 30221, 0, -7704, 0, 30217, 0, -7703, 0, 30239, 0, -7702, 0, 30247, 0, -7701, 0, 30240, 0, -7700, 0, 30241, 0, -7699, 0, 30242, 0, -7698, 0, 30244, 0, -7697, 0, 30260, 0, -7696, 0, 30256, 0, -7695, 0, 30267, 0, -7694, 0, 30279, 0, -7693, 0, 30280, 0, -7692, 0, 30278, 0, -7691, 0, 30300, 0, -7690, 0, 30296, 0, -7689, 0, 30305, 0, -7688, 0, 30306, 0, -7687, 0, 30312, 0, -7686, 0, 30313, 0, -7685, 0, 30314, 0, -7684, 0, 30311, 0, -7683, 0, 30316, 0, -7682, 0, 30320, 0, -7519, 0, 30322, 0, -7518, 0, 30326, 0, -7517, 0, 30328, 0, -7516, 0, 30332, 0, -7515, 0, 30336, 0, -7514, 0, 30339, 0, -7513, 0, 30344, 0, -7512, 0, 30347, 0, -7511, 0, 30350, 0, -7510, 0, 30358, 0, -7509, 0, 30355, 0, -7508, 0, 30361, 0, -7507, 0, 30362, 0, -7506, 0, 30384, 0, -7505, 0, 30388, 0, -7504, 0, 30392, 0, -7503, 0, 30393, 0, -7502, 0, 30394, 0, -7501, 0, 30402, 0, -7500, 0, 30413, 0, -7499, 0, 30422, 0, -7498, 0, 30418, 0, -7497, 0, 30430, 0, -7496, 0, 30433, 0, -7495, 0, 30437, 0, -7494, 0, 30439, 0, -7493, 0, 30442, 0, -7492, 0, -31185, 0, -7491, 0, 30459, 0, -7490, 0, 30472, 0, -7489, 0, 30471, 0, -7488, 0, 30468, 0, -7487, 0, 30505, 0, -7486, 0, 30500, 0, -7485, 0, 30494, 0, -7484, 0, 30501, 0, -7483, 0, 30502, 0, -7482, 0, 30491, 0, -7481, 0, 30519, 0, -7480, 0, 30520, 0, -7479, 0, 30535, 0, -7478, 0, 30554, 0, -7477, 0, 30568, 0, -7476, 0, 30571, 0, -7475, 0, 30555, 0, -7474, 0, 30565, 0, -7473, 0, 30591, 0, -7472, 0, 30590, 0, -7471, 0, 30585, 0, -7470, 0, 30606, 0, -7469, 0, 30603, 0, -7468, 0, 30609, 0, -7467, 0, 30624, 0, -7466, 0, 30622, 0, -7465, 0, 30640, 0, -7464, 0, 30646, 0, -7463, 0, 30649, 0, -7462, 0, 30655, 0, -7461, 0, 30652, 0, -7460, 0, 30653, 0, -7459, 0, 30651, 0, -7458, 0, 30663, 0, -7457, 0, 30669, 0, -7456, 0, 30679, 0, -7455, 0, 30682, 0, -7454, 0, 30684, 0, -7453, 0, 30691, 0, -7452, 0, 30702, 0, -7451, 0, 30716, 0, -7450, 0, 30732, 0, -7449, 0, 30738, 0, -7448, 0, 31014, 0, -7447, 0, 30752, 0, -7446, 0, 31018, 0, -7445, 0, 30789, 0, -7444, 0, 30862, 0, -7443, 0, 30836, 0, -7442, 0, 30854, 0, -7441, 0, 30844, 0, -7440, 0, 30874, 0, -7439, 0, 30860, 0, -7438, 0, 30883, 0, -7437, 0, 30901, 0, -7436, 0, 30890, 0, -7435, 0, 30895, 0, -7434, 0, 30929, 0, -7433, 0, 30918, 0, -7432, 0, 30923, 0, -7431, 0, 30932, 0, -7430, 0, 30910, 0, -7429, 0, 30908, 0, -7428, 0, 30917, 0, -7427, 0, 30922, 0, -7426, 0, 30956, 0, -7263, 0, 30951, 0, -7262, 0, 30938, 0, -7261, 0, 30973, 0, -7260, 0, 30964, 0, -7259, 0, 30983, 0, -7258, 0, 30994, 0, -7257, 0, 30993, 0, -7256, 0, 31001, 0, -7255, 0, 31020, 0, -7254, 0, 31019, 0, -7253, 0, 31040, 0, -7252, 0, 31072, 0, -7251, 0, 31063, 0, -7250, 0, 31071, 0, -7249, 0, 31066, 0, -7248, 0, 31061, 0, -7247, 0, 31059, 0, -7246, 0, 31098, 0, -7245, 0, 31103, 0, -7244, 0, 31114, 0, -7243, 0, 31133, 0, -7242, 0, 31143, 0, -7241, 0, -24757, 0, -7240, 0, 31146, 0, -7239, 0, 31150, 0, -7238, 0, 31155, 0, -7237, 0, 31161, 0, -7236, 0, 31162, 0, -7235, 0, 31177, 0, -7234, 0, 31189, 0, -7233, 0, 31207, 0, -7232, 0, 31212, 0, -7231, 0, 31201, 0, -7230, 0, 31203, 0, -7229, 0, 31240, 0, -7228, 0, 31245, 0, -7227, 0, 31256, 0, -7226, 0, 31257, 0, -7225, 0, 31264, 0, -7224, 0, 31263, 0, -7223, 0, 31104, 0, -7222, 0, 31281, 0, -7221, 0, 31291, 0, -7220, 0, 31294, 0, -7219, 0, 31287, 0, -7218, 0, 31299, 0, -7217, 0, 31319, 0, -7216, 0, 31305, 0, -7215, 0, 31329, 0, -7214, 0, 31330, 0, -7213, 0, 31337, 0, -7212, 0, -24675, 0, -7211, 0, 31344, 0, -7210, 0, 31353, 0, -7209, 0, 31357, 0, -7208, 0, 31368, 0, -7207, 0, 31383, 0, -7206, 0, 31381, 0, -7205, 0, 31384, 0, -7204, 0, 31382, 0, -7203, 0, 31401, 0, -7202, 0, 31432, 0, -7201, 0, 31408, 0, -7200, 0, 31414, 0, -7199, 0, 31429, 0, -7198, 0, 31428, 0, -7197, 0, 31423, 0, -7196, 0, -28541, 0, -7195, 0, 31431, 0, -7194, 0, 31434, 0, -7193, 0, 31437, 0, -7192, 0, 31439, 0, -7191, 0, 31445, 0, -7190, 0, 31443, 0, -7189, 0, 31449, 0, -7188, 0, 31450, 0, -7187, 0, 31453, 0, -7186, 0, 31457, 0, -7185, 0, 31458, 0, -7184, 0, 31462, 0, -7183, 0, 31469, 0, -7182, 0, 31472, 0, -7181, 0, 31490, 0, -7180, 0, 31503, 0, -7179, 0, 31498, 0, -7178, 0, 31494, 0, -7177, 0, 31539, 0, -7176, 0, 31512, 0, -7175, 0, 31513, 0, -7174, 0, 31518, 0, -7173, 0, 31541, 0, -7172, 0, 31528, 0, -7171, 0, 31542, 0, -7170, 0, 31568, 0, -7007, 0, 31610, 0, -7006, 0, 31492, 0, -7005, 0, 31565, 0, -7004, 0, 31499, 0, -7003, 0, 31564, 0, -7002, 0, 31557, 0, -7001, 0, 31605, 0, -7000, 0, 31589, 0, -6999, 0, 31604, 0, -6998, 0, 31591, 0, -6997, 0, 31600, 0, -6996, 0, 31601, 0, -6995, 0, 31596, 0, -6994, 0, 31598, 0, -6993, 0, 31645, 0, -6992, 0, 31640, 0, -6991, 0, 31647, 0, -6990, 0, 31629, 0, -6989, 0, 31644, 0, -6988, 0, 31642, 0, -6987, 0, 31627, 0, -6986, 0, 31634, 0, -6985, 0, 31631, 0, -6984, 0, 31581, 0, -6983, 0, 31641, 0, -6982, 0, 31691, 0, -6981, 0, 31681, 0, -6980, 0, 31692, 0, -6979, 0, 31695, 0, -6978, 0, 31668, 0, -6977, 0, 31686, 0, -6976, 0, 31709, 0, -6975, 0, 31721, 0, -6974, 0, 31761, 0, -6973, 0, 31764, 0, -6972, 0, 31718, 0, -6971, 0, 31717, 0, -6970, 0, 31840, 0, -6969, 0, 31744, 0, -6968, 0, 31751, 0, -6967, 0, 31763, 0, -6966, 0, 31731, 0, -6965, 0, 31735, 0, -6964, 0, 31767, 0, -6963, 0, 31757, 0, -6962, 0, 31734, 0, -6961, 0, 31779, 0, -6960, 0, 31783, 0, -6959, 0, 31786, 0, -6958, 0, 31775, 0, -6957, 0, 31799, 0, -6956, 0, 31787, 0, -6955, 0, 31805, 0, -6954, 0, 31820, 0, -6953, 0, 31811, 0, -6952, 0, 31828, 0, -6951, 0, 31823, 0, -6950, 0, 31808, 0, -6949, 0, 31824, 0, -6948, 0, 31832, 0, -6947, 0, 31839, 0, -6946, 0, 31844, 0, -6945, 0, 31830, 0, -6944, 0, 31845, 0, -6943, 0, 31852, 0, -6942, 0, 31861, 0, -6941, 0, 31875, 0, -6940, 0, 31888, 0, -6939, 0, 31908, 0, -6938, 0, 31917, 0, -6937, 0, 31906, 0, -6936, 0, 31915, 0, -6935, 0, 31905, 0, -6934, 0, 31912, 0, -6933, 0, 31923, 0, -6932, 0, 31922, 0, -6931, 0, 31921, 0, -6930, 0, 31918, 0, -6929, 0, 31929, 0, -6928, 0, 31933, 0, -6927, 0, 31936, 0, -6926, 0, 31941, 0, -6925, 0, 31938, 0, -6924, 0, 31960, 0, -6923, 0, 31954, 0, -6922, 0, 31964, 0, -6921, 0, 31970, 0, -6920, 0, -25797, 0, -6919, 0, 31983, 0, -6918, 0, 31986, 0, -6917, 0, 31988, 0, -6916, 0, 31990, 0, -6915, 0, 31994, 0, -6914, 0, 32006, 0, -6751, 0, 32002, 0, -6750, 0, 32028, 0, -6749, 0, 32021, 0, -6748, 0, 32010, 0, -6747, 0, 32069, 0, -6746, 0, 32075, 0, -6745, 0, 32046, 0, -6744, 0, 32050, 0, -6743, 0, 32063, 0, -6742, 0, 32053, 0, -6741, 0, 32070, 0, -6740, 0, 32115, 0, -6739, 0, 32086, 0, -6738, 0, 32078, 0, -6737, 0, 32114, 0, -6736, 0, 32104, 0, -6735, 0, 32110, 0, -6734, 0, 32079, 0, -6733, 0, 32099, 0, -6732, 0, 32147, 0, -6731, 0, 32137, 0, -6730, 0, 32091, 0, -6729, 0, 32143, 0, -6728, 0, 32125, 0, -6727, 0, 32155, 0, -6726, 0, 32186, 0, -6725, 0, 32174, 0, -6724, 0, 32163, 0, -6723, 0, 32181, 0, -6722, 0, 32199, 0, -6721, 0, 32189, 0, -6720, 0, 32171, 0, -6719, 0, 32317, 0, -6718, 0, 32162, 0, -6717, 0, 32175, 0, -6716, 0, 32220, 0, -6715, 0, 32184, 0, -6714, 0, 32159, 0, -6713, 0, 32176, 0, -6712, 0, 32216, 0, -6711, 0, 32221, 0, -6710, 0, 32228, 0, -6709, 0, 32222, 0, -6708, 0, 32251, 0, -6707, 0, 32242, 0, -6706, 0, 32225, 0, -6705, 0, 32261, 0, -6704, 0, 32266, 0, -6703, 0, 32291, 0, -6702, 0, 32289, 0, -6701, 0, 32274, 0, -6700, 0, 32305, 0, -6699, 0, 32287, 0, -6698, 0, 32265, 0, -6697, 0, 32267, 0, -6696, 0, 32290, 0, -6695, 0, 32326, 0, -6694, 0, 32358, 0, -6693, 0, 32315, 0, -6692, 0, 32309, 0, -6691, 0, 32313, 0, -6690, 0, 32323, 0, -6689, 0, 32311, 0, -6688, 0, 32306, 0, -6687, 0, 32314, 0, -6686, 0, 32359, 0, -6685, 0, 32349, 0, -6684, 0, 32342, 0, -6683, 0, 32350, 0, -6682, 0, 32345, 0, -6681, 0, 32346, 0, -6680, 0, 32377, 0, -6679, 0, 32362, 0, -6678, 0, 32361, 0, -6677, 0, 32380, 0, -6676, 0, 32379, 0, -6675, 0, 32387, 0, -6674, 0, 32213, 0, -6673, 0, 32381, 0, -6672, 0, -28754, 0, -6671, 0, 32383, 0, -6670, 0, 32392, 0, -6669, 0, 32393, 0, -6668, 0, 32396, 0, -6667, 0, 32402, 0, -6666, 0, 32400, 0, -6665, 0, 32403, 0, -6664, 0, 32404, 0, -6663, 0, 32406, 0, -6662, 0, 32398, 0, -6661, 0, 32411, 0, -6660, 0, 32412, 0, -6659, 0, 32568, 0, -6658, 0, 32570, 0, -6495, 0, 32581, 0, -6494, 0, 32588, 0, -6493, 0, 32589, 0, -6492, 0, 32590, 0, -6491, 0, 32592, 0, -6490, 0, 32593, 0, -6489, 0, 32597, 0, -6488, 0, 32596, 0, -6487, 0, 32600, 0, -6486, 0, 32607, 0, -6485, 0, 32608, 0, -6484, 0, 32616, 0, -6483, 0, 32617, 0, -6482, 0, 32615, 0, -6481, 0, 32632, 0, -6480, 0, 32642, 0, -6479, 0, 32646, 0, -6478, 0, 32643, 0, -6477, 0, 32648, 0, -6476, 0, 32647, 0, -6475, 0, 32652, 0, -6474, 0, 32660, 0, -6473, 0, 32670, 0, -6472, 0, 32669, 0, -6471, 0, 32666, 0, -6470, 0, 32675, 0, -6469, 0, 32687, 0, -6468, 0, 32690, 0, -6467, 0, 32697, 0, -6466, 0, 32686, 0, -6465, 0, 32694, 0, -6464, 0, 32696, 0, -6463, 0, -29839, 0, -6462, 0, 32709, 0, -6461, 0, 32710, 0, -6460, 0, 32714, 0, -6459, 0, 32725, 0, -6458, 0, 32724, 0, -6457, 0, 32737, 0, -6456, 0, 32742, 0, -6455, 0, 32745, 0, -6454, 0, 32755, 0, -6453, 0, 32761, 0, -6452, 0, -26404, 0, -6451, 0, -32762, 0, -6450, 0, -32764, 0, -6449, 0, -32757, 0, -6448, 0, -32750, 0, -6447, 0, -32744, 0, -6446, 0, -32743, 0, -6445, 0, -32740, 0, -6444, 0, -32735, 0, -6443, 0, -32728, 0, -6442, 0, -32705, 0, -6441, 0, -32709, 0, -6440, 0, -32694, 0, -6439, 0, -32698, 0, -6438, 0, -32686, 0, -6437, 0, -32680, 0, -6436, 0, -32678, 0, -6435, 0, -32673, 0, -6434, 0, -32670, 0, -6433, 0, -32664, 0, -6432, 0, -32653, 0, -6431, 0, -32654, 0, -6430, 0, -32656, 0, -6429, 0, -32650, 0, -6428, 0, -32647, 0, -6427, 0, -32643, 0, -6426, 0, -32641, 0, -6425, 0, -32636, 0, -6424, 0, -32634, 0, -6423, 0, -32635, 0, -6422, 0, -32613, 0, -6421, 0, -32621, 0, -6420, 0, -32614, 0, -6419, 0, -32595, 0, -6418, 0, 20880, 0, -6417, 0, -32596, 0, -6416, 0, -32549, 0, -6415, 0, -32539, 0, -6414, 0, -32551, 0, -6413, 0, -32547, 0, -6412, 0, -32572, 0, -6411, 0, -32550, 0, -6410, 0, -32554, 0, -6409, 0, -32503, 0, -6408, 0, -32529, 0, -6407, 0, -32527, 0, -6406, 0, -32485, 0, -6405, 0, -32471, 0, -6404, 0, -32477, 0, -6403, 0, -32465, 0, -6402, 0, -32437, 0, -6239, 0, -26997, 0, -6238, 0, -32442, 0, -6237, 0, -32450, 0, -6236, 0, -32429, 0, -6235, 0, -32431, 0, -6234, 0, -32516, 0, -6233, 0, -32399, 0, -6232, 0, -32402, 0, -6231, 0, -32411, 0, -6230, 0, -32410, 0, -6229, 0, -32396, 0, -6228, 0, -32381, 0, -6227, 0, -32376, 0, -6226, 0, -32374, 0, -6225, 0, -32384, 0, -6224, 0, -32382, 0, -6223, 0, -32352, 0, -6222, 0, -32363, 0, -6221, 0, -32348, 0, -6220, 0, -32349, 0, -6219, 0, -32417, 0, -6218, 0, -32365, 0, -6217, 0, -32343, 0, -6216, 0, -32336, 0, -6215, 0, -32331, 0, -6214, 0, -32322, 0, -6213, 0, -32328, 0, -6212, 0, -32323, 0, -6211, 0, -32320, 0, -6210, 0, -32318, 0, -6209, 0, -32326, 0, -6208, 0, -32311, 0, -6207, 0, -32307, 0, -6206, 0, -32303, 0, -6205, 0, -32295, 0, -6204, 0, -32296, 0, -6203, 0, -32312, 0, -6202, 0, -32294, 0, -6201, 0, -32289, 0, -6200, 0, -32288, 0, -6199, 0, -32281, 0, -6198, 0, -32262, 0, -6197, 0, -32261, 0, -6196, 0, -32258, 0, -6195, 0, -32255, 0, -6194, 0, -32254, 0, -6193, 0, -32251, 0, -6192, 0, -32249, 0, -6191, 0, -32246, 0, -6190, 0, -32243, 0, -6189, 0, -32240, 0, -6188, 0, -32234, 0, -6187, 0, -32215, 0, -6186, 0, -32213, 0, -6185, 0, -32200, 0, -6184, 0, -32205, 0, -6183, 0, -32192, 0, -6182, 0, -32167, 0, -6181, 0, -32168, 0, -6180, 0, -32163, 0, -6179, 0, -32166, 0, -6178, 0, -32161, 0, -6177, 0, -32156, 0, -6176, 0, -32158, 0, -6175, 0, -32152, 0, -6174, 0, -32150, 0, -6173, 0, -32149, 0, -6172, 0, -32210, 0, -6171, 0, -32143, 0, -6170, 0, -32137, 0, -6169, 0, -32136, 0, -6168, 0, -32130, 0, -6167, 0, -32115, 0, -6166, 0, -32110, 0, -6165, 0, -32085, 0, -6164, 0, -32097, 0, -6163, 0, -32069, 0, -6162, 0, -32084, 0, -6161, 0, -32031, 0, -6160, 0, -32029, 0, -6159, 0, -32033, 0, -6158, 0, -32046, 0, -6157, 0, -32012, 0, -6156, 0, -32013, 0, -6155, 0, -32006, 0, -6154, 0, -31853, 0, -6153, 0, -31997, 0, -6152, 0, -32005, 0, -6151, 0, -32007, 0, -6150, 0, -32034, 0, -6149, 0, -31994, 0, -6148, 0, -32036, 0, -6147, 0, -31991, 0, -6146, 0, -32039, 0, -5983, 0, -31947, 0, -5982, 0, -31948, 0, -5981, 0, -31978, 0, -5980, 0, -31950, 0, -5979, 0, -31951, 0, -5978, 0, -31936, 0, -5977, 0, -31943, 0, -5976, 0, -31920, 0, -5975, 0, -31931, 0, -5974, 0, -31953, 0, -5973, 0, -31957, 0, -5972, 0, -31977, 0, -5971, 0, -31976, 0, -5970, 0, -31867, 0, -5969, 0, -31846, 0, -5968, 0, -31830, 0, -5967, 0, -31841, 0, -5966, 0, -31838, 0, -5965, 0, -31850, 0, -5964, 0, -31965, 0, -5963, 0, -31858, 0, -5962, 0, -31865, 0, -5961, 0, -31862, 0, -5960, 0, -31876, 0, -5959, 0, -31819, 0, -5958, 0, -31885, 0, -5957, 0, -31883, 0, -5956, 0, -31840, 0, -5955, 0, -31863, 0, -5954, 0, -31832, 0, -5953, 0, -31756, 0, -5952, 0, -31725, 0, -5951, 0, -31765, 0, -5950, 0, -31794, 0, -5949, 0, -31747, 0, -5948, 0, -31741, 0, -5947, 0, -31784, 0, -5946, 0, -31733, 0, -5945, 0, -31807, 0, -5944, 0, -31753, 0, -5943, 0, -31737, 0, -5942, 0, -31776, 0, -5941, 0, -31758, 0, -5940, 0, -31731, 0, -5939, 0, -31710, 0, -5938, 0, -31712, 0, -5937, 0, -31811, 0, -5936, 0, -31688, 0, -5935, 0, -31482, 0, -5934, 0, -31749, 0, -5933, 0, -31635, 0, -5932, 0, -31702, 0, -5931, 0, -31684, 0, -5930, 0, -31398, 0, -5929, 0, -31612, 0, -5928, 0, -31625, 0, -5927, 0, -31637, 0, -5926, 0, -31571, 0, -5925, 0, -31634, 0, -5924, 0, -31614, 0, -5923, 0, -31639, 0, -5922, 0, -31674, 0, -5921, 0, -31700, 0, -5920, 0, -31633, 0, -5919, 0, -31623, 0, -5918, 0, -31691, 0, -5917, 0, -31542, 0, -5916, 0, -31646, 0, -5915, 0, -31559, 0, -5914, 0, -31553, 0, -5913, 0, -31585, 0, -5912, 0, -31527, 0, -5911, 0, -31539, 0, -5910, 0, -31557, 0, -5909, 0, -31526, 0, -5908, 0, -31536, 0, -5907, 0, -31551, 0, -5906, 0, -31546, 0, -5905, 0, -31530, 0, -5904, 0, -31583, 0, -5903, 0, -31455, 0, -5902, 0, -31489, 0, -5901, 0, -31500, 0, -5900, 0, -31465, 0, -5899, 0, -31464, 0, -5898, 0, -31444, 0, -5897, 0, -31457, 0, -5896, 0, -31467, 0, -5895, 0, -31468, 0, -5894, 0, -31492, 0, -5893, 0, -31424, 0, -5892, 0, -31389, 0, -5891, 0, -31400, 0, -5890, 0, -31416, 0, -5727, 0, -31423, 0, -5726, 0, -31230, 0, -5725, 0, -31413, 0, -5724, 0, -31403, 0, -5723, 0, -31360, 0, -5722, 0, -31324, 0, -5721, 0, -31352, 0, -5720, 0, -31343, 0, -5719, 0, -31350, 0, -5718, 0, -31320, 0, -5717, 0, -31379, 0, -5716, 0, -31340, 0, -5715, 0, -31333, 0, -5714, 0, -31254, 0, -5713, 0, -31353, 0, -5712, 0, -31332, 0, -5711, 0, -31369, 0, -5710, 0, -31362, 0, -5709, 0, -31344, 0, -5708, 0, -31287, 0, -5707, 0, -31302, 0, -5706, 0, -31281, 0, -5705, 0, -31303, 0, -5704, 0, -31280, 0, -5703, 0, -31275, 0, -5702, 0, -31267, 0, -5701, 0, -31259, 0, -5700, 0, -31268, 0, -5699, 0, -31239, 0, -5698, 0, -31222, 0, -5697, 0, -31213, 0, -5696, 0, -31221, 0, -5695, 0, -31234, 0, -5694, 0, -31238, 0, -5693, 0, -31226, 0, -5692, 0, -31198, 0, -5691, 0, -31206, 0, -5690, 0, -31184, 0, -5689, 0, -31169, 0, -5688, 0, -31155, 0, -5687, 0, 20053, 0, -5686, 0, -31148, 0, -5685, 0, -31137, 0, -5684, 0, -31129, 0, -5683, 0, -31119, 0, -5682, 0, -31085, 0, -5681, 0, -31069, 0, -5680, 0, -31063, 0, -5679, 0, -31062, 0, -5678, 0, -31093, 0, -5677, 0, -31092, 0, -5676, 0, -31050, 0, -5675, 0, -31057, 0, -5674, 0, -31036, 0, -5673, 0, -31034, 0, -5672, 0, -31056, 0, -5671, 0, -31031, 0, -5670, 0, -30685, 0, -5669, 0, -31061, 0, -5668, 0, -31020, 0, -5667, 0, -31010, 0, -5666, 0, -30999, 0, -5665, 0, -30996, 0, -5664, 0, -31009, 0, -5663, 0, -31013, 0, -5662, 0, -30993, 0, -5661, 0, -30958, 0, -5660, 0, -30970, 0, -5659, 0, -30968, 0, -5658, 0, -30976, 0, -5657, 0, -30973, 0, -5656, 0, -30981, 0, -5655, 0, -30959, 0, -5654, 0, -30967, 0, -5653, 0, -30963, 0, -5652, 0, -30983, 0, -5651, 0, -30966, 0, -5650, 0, -30924, 0, -5649, 0, -30913, 0, -5648, 0, -30921, 0, -5647, 0, -30917, 0, -5646, 0, -30939, 0, -5645, 0, -30935, 0, -5644, 0, -30950, 0, -5643, 0, -30880, 0, -5642, 0, -30881, 0, -5641, 0, -30856, 0, -5640, 0, -30900, 0, -5639, 0, -30898, 0, -5638, 0, -30860, 0, -5637, 0, -30889, 0, -5636, 0, -30872, 0, -5635, 0, -30866, 0, -5634, 0, -30887, 0, -5471, 0, -30893, 0, -5470, 0, -30877, 0, -5469, 0, -30870, 0, -5468, 0, -30715, 0, -5467, 0, -30814, 0, -5466, 0, -30817, 0, -5465, 0, -30846, 0, -5464, 0, -30801, 0, -5463, 0, -30773, 0, -5462, 0, -30787, 0, -5461, 0, -30784, 0, -5460, 0, -30768, 0, -5459, 0, -26922, 0, -5458, 0, -30805, 0, -5457, 0, -30780, 0, -5456, 0, -30797, 0, -5455, 0, -30777, 0, -5454, 0, -30778, 0, -5453, 0, -30789, 0, -5452, 0, -30737, 0, -5451, 0, -30734, 0, -5450, 0, -30752, 0, -5449, 0, -30705, 0, -5448, 0, -30707, 0, -5447, 0, -30722, 0, -5446, 0, -30730, 0, -5445, 0, -30729, 0, -5444, 0, -30706, 0, -5443, 0, -30766, 0, -5442, 0, -30703, 0, -5441, 0, -30698, 0, -5440, 0, -30699, 0, -5439, 0, -30686, 0, -5438, 0, -30687, 0, -5437, 0, -30671, 0, -5436, 0, -30666, 0, -5435, 0, -30663, 0, -5434, 0, -30681, 0, -5433, 0, -30661, 0, -5432, 0, -30652, 0, -5431, 0, -30654, 0, -5430, 0, -30638, 0, -5429, 0, -30631, 0, -5428, 0, -30626, 0, -5427, 0, -30622, 0, -5426, 0, -30613, 0, -5425, 0, -30591, 0, -5424, 0, -30594, 0, -5423, 0, -30562, 0, -5422, 0, -30603, 0, -5421, 0, -30595, 0, -5420, 0, -30539, 0, -5419, 0, -30606, 0, -5418, 0, -30590, 0, -5417, 0, -30569, 0, -5416, 0, -30574, 0, -5415, 0, -30546, 0, -5414, 0, -30567, 0, -5413, 0, -30558, 0, -5412, 0, -30579, 0, -5411, 0, -30556, 0, -5410, 0, -30544, 0, -5409, 0, -30529, 0, -5408, 0, -30543, 0, -5407, 0, -30525, 0, -5406, 0, -30524, 0, -5405, 0, -30508, 0, -5404, 0, -30504, 0, -5403, 0, -30503, 0, -5402, 0, -30499, 0, -5401, 0, -30471, 0, -5400, 0, -30462, 0, -5399, 0, -30468, 0, -5398, 0, -30476, 0, -5397, 0, -30488, 0, -5396, 0, -30478, 0, -5395, 0, -30460, 0, -5394, 0, -30452, 0, -5393, 0, -30454, 0, -5392, 0, -30445, 0, -5391, 0, -30397, 0, -5390, 0, -30434, 0, -5389, 0, -30427, 0, -5388, 0, -30422, 0, -5387, 0, -30421, 0, -5386, 0, -30399, 0, -5385, 0, -30396, 0, -5384, 0, -30405, 0, -5383, 0, -30410, 0, -5382, 0, -30408, 0, -5381, 0, -30388, 0, -5380, 0, -30435, 0, -5379, 0, -30368, 0, -5378, 0, -30370, 0, -5215, 0, -30362, 0, -5214, 0, -30364, 0, -5213, 0, -30355, 0, -5212, 0, -30358, 0, -5211, 0, -30353, 0, -5210, 0, -30348, 0, -5209, 0, -30345, 0, -5208, 0, -30338, 0, -5207, 0, -30333, 0, -5206, 0, -30328, 0, -5205, 0, -30326, 0, -5204, 0, -30317, 0, -5203, 0, -30312, 0, -5202, 0, -30303, 0, -5201, 0, -30295, 0, -5200, 0, -30298, 0, -5199, 0, -30292, 0, -5198, 0, -30289, 0, -5197, 0, -30286, 0, -5196, 0, -30278, 0, -5195, 0, -30275, 0, -5194, 0, -30273, 0, -5193, 0, -30272, 0, -5192, 0, -30246, 0, -5191, 0, -30244, 0, -5190, 0, -30243, 0, -5189, 0, -30233, 0, -5188, 0, -30220, 0, -5187, 0, -30216, 0, -5186, 0, -30205, 0, -5185, 0, -30186, 0, -5184, 0, -30192, 0, -5183, 0, -30196, 0, -5182, 0, -30181, 0, -5181, 0, -30179, 0, -5180, 0, -30171, 0, -5179, 0, -30154, 0, -5178, 0, -30143, 0, -5177, 0, -30117, 0, -5176, 0, -30126, 0, -5175, 0, -30138, 0, -5174, 0, -30136, 0, -5173, 0, -30084, 0, -5172, 0, -30099, 0, -5171, 0, -30100, 0, -5170, 0, -30110, 0, -5169, 0, -30075, 0, -5168, 0, -30078, 0, -5167, 0, -30076, 0, -5166, 0, -30040, 0, -5165, 0, -30047, 0, -5164, 0, -30063, 0, -5163, 0, -30043, 0, -5162, 0, -30042, 0, -5161, 0, -30054, 0, -5160, 0, -30045, 0, -5159, 0, -30012, 0, -5158, 0, -30003, 0, -5157, 0, -30014, 0, -5156, 0, -29990, 0, -5155, 0, -29973, 0, -5154, 0, -29965, 0, -5153, 0, -29977, 0, -5152, 0, -29980, 0, -5151, 0, -29967, 0, -5150, 0, -29932, 0, -5149, 0, -29984, 0, -5148, 0, -29982, 0, -5147, 0, -29961, 0, -5146, 0, -29986, 0, -5145, 0, -29989, 0, -5144, 0, -29940, 0, -5143, 0, -29945, 0, -5142, 0, -29926, 0, -5141, 0, -29983, 0, -5140, 0, -29930, 0, -5139, 0, -29936, 0, -5138, 0, -29929, 0, -5137, 0, -29920, 0, -5136, 0, -29901, 0, -5135, 0, -26709, 0, -5134, 0, -29914, 0, -5133, 0, -29909, 0, -5132, 0, -29890, 0, -5131, 0, -29912, 0, -5130, 0, -29887, 0, -5129, 0, -29876, 0, -5128, 0, -29873, 0, -5127, 0, -29874, 0, -5126, 0, -29879, 0, -5125, 0, -29866, 0, -5124, 0, -29861, 0, -5123, 0, -29862, 0, -5122, 0, -29845, 0, -4959, 0, -29857, 0, -4958, 0, -29844, 0, -4957, 0, -29841, 0, -4956, 0, -29836, 0, -4955, 0, -29827, 0, -4954, 0, -29824, 0, -4953, 0, -29812, 0, -4952, 0, -29810, 0, -4951, 0, -29806, 0, -4950, 0, -29805, 0, -4949, 0, -29802, 0, -4948, 0, -29799, 0, -4947, 0, -29798, 0, -4946, 0, -29638, 0, -4945, 0, -29631, 0, -4944, 0, -29633, 0, -4943, 0, -29624, 0, -4942, 0, -29620, 0, -4941, 0, -29618, 0, -4940, 0, -29616, 0, -4939, 0, -29611, 0, -4938, 0, -29598, 0, -4937, 0, -29588, 0, -4936, 0, -29576, 0, -4935, 0, -29574, 0, -4934, 0, -29566, 0, -4933, 0, -29559, 0, -4932, 0, -29563, 0, -4931, 0, -29558, 0, -4930, 0, -29555, 0, -4929, 0, -29554, 0, -4928, 0, -29548, 0, -4927, 0, -29572, 0, -4926, 0, -29544, 0, -4925, 0, 25117, 0, -4924, 0, -29523, 0, -4923, 0, -29526, 0, -4922, 0, -29507, 0, -4921, 0, -29518, 0, -4920, 0, -29517, 0, -4919, 0, -29522, 0, -4918, 0, -29514, 0, -4917, 0, -29496, 0, -4916, 0, -29503, 0, -4915, 0, -29468, 0, -4914, 0, -29469, 0, -4913, 0, -29478, 0, -4912, 0, -29443, 0, -4911, 0, -29446, 0, -4910, 0, -29445, 0, -4909, 0, -29436, 0, -4908, 0, -29435, 0, -4907, 0, -29430, 0, -4906, 0, -29433, 0, -4905, 0, -29425, 0, -4904, 0, -29427, 0, -4903, 0, -29424, 0, -4902, 0, -24754, 0, -4901, 0, -29421, 0, -4900, 0, -29491, 0, -4899, 0, -29420, 0, -4898, 0, -29418, 0, -4897, 0, -29337, 0, -4896, 0, -29331, 0, -4895, 0, -29327, 0, -4894, 0, -29325, 0, -4893, 0, -29311, 0, -4892, 0, -29287, 0, -4891, 0, -29246, 0, -4890, 0, -29250, 0, -4889, 0, -29254, 0, -4888, 0, -29233, 0, -4887, 0, -29222, 0, -4886, 0, -29226, 0, -4885, 0, -29236, 0, -4884, 0, -29221, 0, -4883, 0, -29237, 0, -4882, 0, -29206, 0, -4881, 0, -29205, 0, -4880, 0, -29217, 0, -4879, 0, -29213, 0, -4878, 0, -29188, 0, -4877, 0, -29176, 0, -4876, 0, -29175, 0, -4875, 0, -29185, 0, -4874, 0, -29155, 0, -4873, 0, -29154, 0, -4872, 0, -29168, 0, -4871, 0, -29153, 0, -4870, 0, -29118, 0, -4869, 0, -29131, 0, -4868, 0, -29136, 0, -4867, 0, -29132, 0, -4866, 0, -29110, 0, -4703, 0, -29113, 0, -4702, 0, -29111, 0, -4701, 0, -29108, 0, -4700, 0, -29104, 0, -4699, 0, -29112, 0, -4698, 0, -29095, 0, -4697, 0, -29084, 0, -4696, 0, -29088, 0, -4695, 0, -29142, 0, -4694, 0, -29085, 0, -4693, 0, -29099, 0, -4692, 0, -29066, 0, -4691, 0, -29070, 0, -4690, 0, -29060, 0, -4689, 0, -29055, 0, -4688, 0, -29049, 0, -4687, 0, -29051, 0, -4686, 0, -29052, 0, -4685, 0, -29045, 0, -4684, 0, -29046, 0, -4683, 0, -29037, 0, -4682, 0, -29039, 0, -4681, 0, -29036, 0, -4680, 0, -29031, 0, -4679, 0, -29014, 0, -4678, 0, -29023, 0, -4677, 0, -29012, 0, -4676, 0, -29008, 0, -4675, 0, -28986, 0, -4674, 0, -29007, 0, -4673, 0, -28994, 0, -4672, 0, -28987, 0, -4671, 0, -28984, 0, -4670, 0, -28981, 0, -4669, 0, -28965, 0, -4668, 0, -28957, 0, -4667, 0, -28932, 0, -4666, 0, -28933, 0, -4665, 0, -28949, 0, -4664, 0, -28930, 0, -4663, 0, -28918, 0, -4662, 0, -28923, 0, -4661, 0, -28907, 0, -4660, 0, -28910, 0, -4659, 0, -28903, 0, -4658, 0, -28909, 0, -4657, 0, -28900, 0, -4656, 0, -28897, 0, -4655, 0, -28901, 0, -4654, 0, -28916, 0, -4653, 0, -28890, 0, -4652, 0, -28877, 0, -4651, 0, -28869, 0, -4650, 0, -28871, 0, -4649, 0, -28859, 0, -4648, 0, -28862, 0, -4647, 0, -28866, 0, -4646, 0, -28852, 0, -4645, 0, -28855, 0, -4644, 0, -28858, 0, -4643, 0, -28850, 0, -4642, 0, -28841, 0, -4641, 0, -28836, 0, -4640, 0, -28830, 0, -4639, 0, -28829, 0, -4638, 0, -28828, 0, -4637, 0, -28772, 0, -4636, 0, -28769, 0, -4635, 0, -28765, 0, -4634, 0, -28755, 0, -4633, 0, -28753, 0, -4632, 0, -28745, 0, -4631, 0, -28710, 0, -4630, 0, -28699, 0, -4629, 0, -28702, 0, -4628, 0, -28694, 0, -4627, 0, -28689, 0, -4626, 0, -28537, 0, -4625, 0, -28684, 0, -4624, 0, -28667, 0, -4623, 0, -28679, 0, -4622, 0, -28678, 0, -4621, 0, -28655, 0, -4620, 0, -28651, 0, -4619, 0, -28639, 0, -4618, 0, -28659, 0, -4617, 0, -28642, 0, -4616, 0, -28650, 0, -4615, 0, -28661, 0, -4614, 0, -28633, 0, -4613, 0, -28618, 0, -4612, 0, -28619, 0, -4611, 0, -28615, 0, -4610, 0, -28680, 0, -4447, 0, -28593, 0, -4446, 0, -28592, 0, -4445, 0, -28591, 0, -4444, 0, -28590, 0, -4443, 0, -28658, 0, -4442, 0, -28599, 0, -4441, 0, -28610, 0, -4440, 0, -28586, 0, -4439, 0, -28584, 0, -4438, 0, -28578, 0, -4437, 0, -28568, 0, -4436, 0, -28561, 0, -4435, 0, -28554, 0, -4434, 0, -26968, 0, -4433, 0, -28558, 0, -4432, 0, -28542, 0, -4431, 0, -28547, 0, -4430, 0, -28543, 0, -4429, 0, -28544, 0, -4428, 0, -28534, 0, -4427, 0, -28535, 0, -4426, 0, -28529, 0, -4425, 0, -28504, 0, -4424, 0, -28497, 0, -4423, 0, -28495, 0, -4422, 0, -28491, 0, -4421, 0, -28446, 0, -4420, 0, -28444, 0, -4419, 0, 25160, 0, -4418, 0, -28453, 0, -4417, 0, -28414, 0, -4416, 0, -28398, 0, -4415, 0, -28391, 0, -4414, 0, -28366, 0, -4413, 0, -28368, 0, -4412, 0, -28342, 0, -4411, 0, -28330, 0, -4410, 0, -28328, 0, -4409, 0, -28317, 0, -4408, 0, -28315, 0, -4407, 0, -28311, 0, -4406, 0, -28301, 0, -4405, 0, -28302, 0, -4404, 0, -28277, 0, -4403, 0, -28279, 0, -4402, 0, -28286, 0, -4401, 0, -28254, 0, -4400, 0, -28245, 0, -4399, 0, -28241, 0, -4398, 0, -28246, 0, -4397, 0, -28235, 0, -4396, 0, -28236, 0, -4395, 0, -28230, 0, -4394, 0, -28224, 0, -4393, 0, -28223, 0, -4392, 0, -28215, 0, -4391, 0, -28213, 0, -4390, 0, -28208, 0, -4389, 0, -28202, 0, -4388, 0, -28193, 0, -4387, 0, -28191, 0, -4386, 0, -28197, 0, -4385, 0, -28164, 0, -4384, 0, -28171, 0, -4383, 0, -28170, 0, -4382, 0, -28130, 0, -4381, 0, -28161, 0, -4380, 0, -28140, 0, -4379, 0, -28116, 0, -4378, 0, -28139, 0, -4377, 0, -28143, 0, -4376, 0, -28066, 0, -4375, 0, -28073, 0, -4374, 0, -28091, 0, -4373, 0, -28087, 0, -4372, 0, -28060, 0, -4371, 0, -28088, 0, -4370, 0, -28011, 0, -4369, 0, -28097, 0, -4368, 0, -28085, 0, -4367, 0, -28080, 0, -4366, 0, -28004, 0, -4365, 0, -28010, 0, -4364, 0, -28013, 0, -4363, 0, -28005, 0, -4362, 0, -28070, 0, -4361, 0, -27953, 0, -4360, 0, -27975, 0, -4359, 0, -27977, 0, -4358, 0, -27927, 0, -4357, 0, -27889, 0, -4356, 0, -27910, 0, -4355, 0, -27836, 0, -4354, 0, -27858, 0, -4191, 0, -27879, 0, -4190, 0, -27870, 0, -4189, 0, -27878, 0, -4188, 0, -27869, 0, -4187, 0, -27846, 0, -4186, 0, -27851, 0, -4185, 0, -27845, 0, -4184, 0, -27812, 0, -4183, 0, -27808, 0, -4182, 0, -27780, 0, -4181, 0, -27794, 0, -4180, 0, -27818, 0, -4179, 0, -27728, 0, -4178, 0, -27732, 0, -4177, 0, -27731, 0, -4176, 0, -27756, 0, -4175, 0, -27719, 0, -4174, 0, -27690, 0, -4173, 0, -27689, 0, -4172, 0, -27672, 0, -4171, 0, -27675, 0, -4170, 0, -27688, 0, -4169, 0, -27709, 0, -4168, 0, -27683, 0, -4167, 0, -27696, 0, -4166, 0, -27704, 0, -4165, 0, -27676, 0, -4164, 0, -27622, 0, -4163, 0, -27628, 0, -4162, 0, -27629, 0, -4161, 0, -27645, 0, -4160, 0, -27641, 0, -4159, 0, -27632, 0, -4158, 0, -27594, 0, -4157, 0, -27605, 0, -4156, 0, -27595, 0, -4155, 0, -27615, 0, -4154, 0, -27590, 0, -4153, 0, -27583, 0, -4152, 0, -27566, 0, -4151, 0, -27580, 0, -4150, 0, -27557, 0, -4149, 0, -27552, 0, -4148, 0, -27550, 0, -4147, 0, -27554, 0, -4146, 0, -27542, 0, -4145, 0, -28119, 0, -4144, 0, -27536, 0, -4143, 0, -27531, 0, -4142, 0, -27529, 0, -4141, 0, -27523, 0, -4140, 0, -27558, 0, -4139, 0, -27524, 0, -4138, 0, -27522, 0, -4137, 0, -27519, 0, -4136, 0, -27521, 0, -4135, 0, -27262, 0, -4134, 0, -27257, 0, -4133, 0, -27254, 0, -4132, 0, -27244, 0, -4131, 0, -27242, 0, -4130, 0, -27240, 0, -4129, 0, -27239, 0, -4128, 0, -27232, 0, -4127, 0, -27224, 0, -4126, 0, -27225, 0, -4125, 0, -27219, 0, -4124, 0, -27204, 0, -4123, 0, -27205, 0, -4122, 0, -27207, 0, -4121, 0, -27202, 0, -4120, 0, -27190, 0, -4119, 0, 28662, 0, -4118, 0, -27197, 0, -4117, 0, -27187, 0, -4116, 0, -27188, 0, -4115, 0, -27179, 0, -4114, 0, -27180, 0, -4113, 0, -27178, 0, -4112, 0, -27172, 0, -4111, 0, -27167, 0, -4110, 0, -27163, 0, -4109, 0, -27166, 0, -4108, 0, -27103, 0, -4107, 0, -27096, 0, -4106, 0, -27090, 0, -4105, 0, -27089, 0, -4104, 0, -27070, 0, -4103, 0, -27060, 0, -4102, 0, -27057, 0, -4101, 0, -27061, 0, -4100, 0, -27017, 0, -4099, 0, -27044, 0, -4098, 0, -27042, 0, -3935, 0, -27043, 0, -3934, 0, -27041, 0, -3933, 0, -27034, 0, -3932, 0, -27022, 0, -3931, 0, -27028, 0, -3930, 0, -26995, 0, -3929, 0, -26984, 0, -3928, 0, -26987, 0, -3927, 0, -26985, 0, -3926, 0, -26966, 0, -3925, 0, -26969, 0, -3924, 0, -26959, 0, -3923, 0, -26958, 0, -3922, 0, -26960, 0, -3921, 0, -26956, 0, -3920, 0, -26954, 0, -3919, 0, -26952, 0, -3918, 0, -26951, 0, -3917, 0, -26930, 0, -3916, 0, -26933, 0, -3915, 0, -26935, 0, -3914, 0, -26931, 0, -3913, 0, -30387, 0, -3912, 0, -26916, 0, -3911, 0, -26867, 0, -3910, 0, -26923, 0, -3909, 0, -26887, 0, -3908, 0, -26876, 0, -3907, 0, -26874, 0, -3906, 0, -26872, 0, -3905, 0, -26861, 0, -3904, 0, -26866, 0, -3903, 0, -26863, 0, -3902, 0, -26865, 0, -3901, 0, -26858, 0, -3900, 0, -26855, 0, -3899, 0, -26844, 0, -3898, 0, -26838, 0, -3897, 0, -26832, 0, -3896, 0, -26823, 0, -3895, 0, -26819, 0, -3894, 0, -26818, 0, -3893, 0, -26812, 0, -3892, 0, -26810, 0, -3891, 0, -26808, 0, -3890, 0, -26814, 0, -3889, 0, -26807, 0, -3888, 0, -26788, 0, -3887, 0, -26784, 0, -3886, 0, -26780, 0, -3885, 0, -26778, 0, -3884, 0, -26776, 0, -3883, 0, 21202, 0, -3882, 0, -26773, 0, -3881, 0, -26767, 0, -3880, 0, -26759, 0, -3879, 0, -26747, 0, -3878, 0, -26756, 0, -3877, 0, -26751, 0, -3876, 0, -26758, 0, -3875, 0, -26746, 0, -3874, 0, -26741, 0, -3873, 0, -26737, 0, -3872, 0, -26736, 0, -3871, 0, -26724, 0, -3870, 0, -26712, 0, -3869, 0, -26714, 0, -3868, 0, -26717, 0, -3867, 0, -26701, 0, -3866, 0, -26700, 0, -3865, 0, -26685, 0, -3864, 0, -26682, 0, -3863, 0, -26680, 0, -3862, 0, -26677, 0, -3861, 0, -26660, 0, -3860, 0, -26643, 0, -3859, 0, -24753, 0, -3858, 0, -26638, 0, -3857, 0, 31455, 0, -3856, 0, -26634, 0, -3855, 0, -26635, 0, -3854, 0, -26609, 0, -3853, 0, -26612, 0, -3852, 0, -26568, 0, -3851, 0, -26588, 0, -3850, 0, -26591, 0, -3849, 0, -26569, 0, -3848, 0, -26563, 0, -3847, 0, -26554, 0, -3846, 0, -26545, 0, -3845, 0, -26549, 0, -3844, 0, -26517, 0, -3843, 0, -26513, 0, -3842, 0, -26512, 0, -3679, 0, -26511, 0, -3678, 0, -26508, 0, -3677, 0, -26509, 0, -3676, 0, -26454, 0, -3675, 0, -26449, 0, -3674, 0, -26447, 0, -3673, 0, -26442, 0, -3672, 0, -26428, 0, -3671, 0, -26429, 0, -3670, 0, -26426, 0, -3669, 0, -26391, 0, -3668, 0, -26389, 0, -3667, 0, -26365, 0, -3666, 0, -26359, 0, -3665, 0, -26350, 0, -3664, 0, -26348, 0, -3663, 0, -26344, 0, -3662, 0, -26335, 0, -3661, 0, -26339, 0, -3660, 0, -26338, 0, -3659, 0, -26332, 0, -3658, 0, -26336, 0, -3657, 0, -26324, 0, -3656, 0, -26322, 0, -3655, 0, -26307, 0, -3654, 0, -26306, 0, -3653, 0, -26302, 0, -3652, 0, -26295, 0, -3651, 0, -26299, 0, -3650, 0, -26288, 0, -3649, 0, -26293, 0, -3648, 0, -26287, 0, -3647, 0, -26286, 0, -3646, 0, -26292, 0, -3645, 0, -26283, 0, -3644, 0, -26217, 0, -3643, 0, -26216, 0, -3642, 0, -26203, 0, -3641, 0, -26195, 0, -3640, 0, -26194, 0, -3639, 0, -26180, 0, -3638, 0, -26145, 0, -3637, 0, -26149, 0, -3636, 0, -26147, 0, -3635, 0, -26152, 0, -3634, 0, -26159, 0, -3633, 0, -26131, 0, -3632, 0, -26130, 0, -3631, 0, -26127, 0, -3630, 0, -26126, 0, -3629, 0, -26117, 0, -3628, 0, -26120, 0, -3627, 0, -26111, 0, -3626, 0, -26097, 0, -3625, 0, -26107, 0, -3624, 0, -26142, 0, -3623, 0, -26087, 0, -3622, 0, -26069, 0, -3621, 0, -26057, 0, -3620, 0, -26043, 0, -3619, 0, -26046, 0, -3618, 0, -26048, 0, -3617, 0, -26045, 0, -3616, 0, -26050, 0, -3615, 0, -26027, 0, -3614, 0, -26035, 0, -3613, 0, -26021, 0, -3612, 0, -26025, 0, -3611, 0, -26017, 0, -3610, 0, -26014, 0, -3609, 0, -26011, 0, -3608, 0, -26012, 0, -3607, 0, -26007, 0, -3606, 0, -26005, 0, -3605, 0, -26006, 0, -3604, 0, -25939, 0, -3603, 0, -25936, 0, -3602, 0, -25924, 0, -3601, 0, -25920, 0, -3600, 0, -25905, 0, -3599, 0, -25903, 0, -3598, 0, -25901, 0, -3597, 0, -25900, 0, -3596, 0, -25890, 0, -3595, 0, -25889, 0, -3594, 0, -25886, 0, -3593, 0, -25885, 0, -3592, 0, -25882, 0, -3591, 0, -25873, 0, -3590, 0, -25877, 0, -3589, 0, -25874, 0, -3588, 0, -25868, 0, -3587, 0, -25871, 0, -3586, 0, -25865, 0, -3423, 0, -25861, 0, -3422, 0, -25850, 0, -3421, 0, -25832, 0, -3420, 0, -25830, 0, -3419, 0, -25825, 0, -3418, 0, -25822, 0, -3417, 0, -25821, 0, -3416, 0, -25819, 0, -3415, 0, -25817, 0, -3414, 0, -25816, 0, -3413, 0, -25815, 0, -3412, 0, -25814, 0, -3411, 0, -25810, 0, -3410, 0, -25809, 0, -3409, 0, -25806, 0, -3408, 0, -25788, 0, -3407, 0, -25789, 0, -3406, 0, -25777, 0, -3405, 0, -25779, 0, -3404, 0, -25778, 0, -3403, 0, -25775, 0, -3402, 0, -25768, 0, -3401, 0, -25740, 0, -3400, 0, -25709, 0, -3399, 0, -25725, 0, -3398, 0, -25711, 0, -3397, 0, -25706, 0, -3396, 0, -25705, 0, -3395, 0, -25697, 0, -3394, 0, -25696, 0, -3393, 0, -25688, 0, -3392, 0, -25676, 0, -3391, 0, -25664, 0, -3390, 0, -25654, 0, -3389, 0, -25671, 0, -3388, 0, -25658, 0, -3387, 0, -25649, 0, -3386, 0, -25647, 0, -3385, 0, -25646, 0, -3384, 0, -25629, 0, -3383, 0, -25630, 0, -3382, 0, -25628, 0, -3381, 0, -25644, 0, -3380, 0, -25631, 0, -3379, 0, -25542, 0, -3378, 0, -25614, 0, -3377, 0, -25615, 0, -3376, 0, -25616, 0, -3375, 0, -25579, 0, -3374, 0, -25580, 0, -3373, 0, -25591, 0, -3372, 0, -25581, 0, -3371, 0, -25588, 0, -3370, 0, -25594, 0, -3369, 0, -25592, 0, -3368, 0, -25582, 0, -3367, 0, -25590, 0, -3366, 0, -25596, 0, -3365, 0, -25554, 0, -3364, 0, -25573, 0, -3363, 0, -25563, 0, -3362, 0, -25564, 0, -3361, 0, -25567, 0, -3360, 0, -25552, 0, -3359, 0, -25529, 0, -3358, 0, -25550, 0, -3357, 0, -25530, 0, -3356, 0, -25538, 0, -3355, 0, -25510, 0, -3354, 0, -25504, 0, -3353, 0, -25497, 0, -3352, 0, -25482, 0, -3351, 0, -25480, 0, -3350, 0, -25369, 0, -3349, 0, -25364, 0, -3348, 0, -25360, 0, -3347, 0, -25335, 0, -3346, 0, -25336, 0, -3345, 0, -25365, 0, -3344, 0, -25341, 0, -3343, 0, -25338, 0, -3342, 0, -25302, 0, -3341, 0, -25306, 0, -3340, 0, -25169, 0, -3339, 0, -25309, 0, -3338, 0, -25313, 0, -3337, 0, -25276, 0, -3336, 0, -25323, 0, -3335, 0, -25326, 0, -3334, 0, -25279, 0, -3333, 0, -25281, 0, -3332, 0, -25282, 0, -3331, 0, -25274, 0, -3330, 0, -25272, 0, -3167, 0, -25251, 0, -3166, 0, -25250, 0, -3165, 0, -25244, 0, -3164, 0, -25263, 0, -3163, 0, -25264, 0, -3162, 0, -25255, 0, -3161, 0, -25230, 0, -3160, 0, -25207, 0, -3159, 0, -25209, 0, -3158, 0, -25173, 0, -3157, 0, -25233, 0, -3156, 0, -25222, 0, -3155, 0, -25190, 0, -3154, 0, -25180, 0, -3153, 0, -25175, 0, -3152, 0, -25166, 0, -3151, 0, -25148, 0, -3150, 0, -25151, 0, -3149, 0, -25157, 0, -3148, 0, -25160, 0, -3147, 0, -25158, 0, -3146, 0, -25146, 0, -3145, 0, -25137, 0, -3144, 0, -25150, 0, -3143, 0, -25127, 0, -3142, 0, -25133, 0, -3141, 0, -25096, 0, -3140, 0, -25114, 0, -3139, 0, -25107, 0, -3138, 0, -25105, 0, -3137, 0, -25091, 0, -3136, 0, -25062, 0, -3135, 0, -25061, 0, -3134, 0, -25058, 0, -3133, 0, -24971, 0, -3132, 0, -24967, 0, -3131, 0, -24963, 0, -3130, 0, -24959, 0, -3129, 0, -24952, 0, -3128, 0, -24949, 0, -3127, 0, -24948, 0, -3126, 0, -24942, 0, -3125, 0, -24939, 0, -3124, 0, -24943, 0, -3123, 0, -24931, 0, -3122, 0, -24923, 0, -3121, 0, -24919, 0, -3120, 0, -24904, 0, -3119, 0, -24918, 0, -3118, 0, -24915, 0, -3117, 0, -26783, 0, -3116, 0, -24884, 0, -3115, 0, -24882, 0, -3114, 0, -24881, 0, -3113, 0, -24880, 0, -3112, 0, -24876, 0, -3111, 0, -24868, 0, -3110, 0, -24866, 0, -3109, 0, -24867, 0, -3108, 0, -24864, 0, -3107, 0, -24859, 0, -3106, 0, -24856, 0, -3105, 0, -24849, 0, -3104, 0, -24844, 0, -3103, 0, -24842, 0, -3102, 0, -24841, 0, -3101, 0, -24839, 0, -3100, 0, -24837, 0, -3099, 0, -24836, 0, -3098, 0, -24835, 0, -3097, 0, -24825, 0, -3096, 0, -24824, 0, -3095, 0, 30391, 0, -3094, 0, -24811, 0, -3093, 0, -24799, 0, -3092, 0, -24788, 0, -3091, 0, -24770, 0, -3090, 0, -24758, 0, -3089, 0, -24750, 0, -3088, 0, -24748, 0, -3087, 0, -24733, 0, -3086, 0, -24737, 0, -3085, 0, -24736, 0, -3084, 0, -24735, 0, -3083, 0, -24730, 0, -3082, 0, -24729, 0, -3081, 0, -24724, 0, -3080, 0, -24726, 0, -3079, 0, -24713, 0, -3078, 0, -24718, 0, -3077, 0, -24714, 0, -3076, 0, -24683, 0, -3075, 0, -24676, 0, -3074, 0, -24672, 0, -2911, 0, 22575, 0, -2910, 0, 27079, 0, -2909, 0, -28583, 0, -2908, 0, 29796, 0, -2907, 0, 20956, 0, -2906, 0, 29081, 0, -29023, 0, -159, 0, -29022, 0, -158, 0, -29021, 0, -157, 0, -29020, 0, -156, 0, -29019, 0, -155, 0, -29018, 0, -154, 0, -29017, 0, -153, 0, -29016, 0, -152, 0, -29015, 0, -151, 0, -29014, 0, -150, 0, -29013, 0, -149, 0, -29012, 0, -148, 0, -29011, 0, -147, 0, -29010, 0, -146, 0, -29009, 0, -145, 0, -29008, 0, -144, 0, -29007, 0, -143, 0, -29006, 0, -142, 0, -29005, 0, -141, 0, -29004, 0, -140, 0, -29003, 0, -139, 0, -29002, 0, -138, 0, -29001, 0, -137, 0, -29000, 0, -136, 0, -28999, 0, -135, 0, -28998, 0, -134, 0, -28997, 0, -133, 0, -28996, 0, -132, 0, -28995, 0, -131, 0, -28994, 0, -130, 0, -28993, 0, -129, 0, -28992, 0, -128, 0, -28991, 0, -127, 0, -28990, 0, -126, 0, -28989, 0, -125, 0, -28988, 0, -124, 0, -28987, 0, -123, 0, -28986, 0, -122, 0, -28985, 0, -121, 0, -28984, 0, -120, 0, -28983, 0, -119, 0, -28982, 0, -118, 0, -28981, 0, -117, 0, -28980, 0, -116, 0, -28979, 0, -115, 0, -28978, 0, -114, 0, -28977, 0, -113, 0, -28976, 0, -112, 0, -28975, 0, -111, 0, -28974, 0, -110, 0, -28973, 0, -109, 0, -28972, 0, -108, 0, -28971, 0, -107, 0, -28970, 0, -106, 0, -28969, 0, -105, 0, -28968, 0, -104, 0, -28967, 0, -103, 0, -28966, 0, -102, 0, -28965, 0, -101, 0, -28964, 0, -100, 0, -28963, 0, -99, 0, -28962, 0, -98, 0, -28961, 0, -97, 0, -1, 0, -1, 0], ["i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0], ALLOC_STATIC);
STRING_TABLE.__str51090=allocate([65,100,111,98,101,0] /* Adobe\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str61091=allocate([74,97,112,97,110,49,0] /* Japan1\00 */, "i8", ALLOC_STATIC);
_JWW_LINE_HEAD_EUC=allocate([-24157, 0, -24158, 0, -23391, 0, -23135, 0, -23389, 0, -23133, 0, -23387, 0, -23131, 0, -23385, 0, -23129, 0, -23383, 0, -23127, 0, -23357, 0, -23101, 0, -23325, 0, -23069, 0, -23323, 0, -23067, 0, -23321, 0, -23065, 0, -23314, 0, -23058, 0, -24105, 0, -24117, 0, -24115, 0, -24111, 0, -24109, 0, -24107, 0, -24103, 0, -24101, 0, -24092, 0, -23836, 0, 0, 0], ["i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0], ALLOC_STATIC);
_EUC_AddCodeSpaceRange_code_space_range1=allocate([0, 0, 128, 0, 0, 0], ["i16",0,"i16",0,"i16",0], ALLOC_STATIC);
_EUC_AddCodeSpaceRange_code_space_range2=allocate([-29024, 0, -28961, 0, 0, 0], ["i16",0,"i16",0,"i16",0], ALLOC_STATIC);
_EUC_AddCodeSpaceRange_code_space_range3=allocate([-24159, 0, -258, 0, 0, 0], ["i16",0,"i16",0,"i16",0], ALLOC_STATIC);
_CMAP_ARRAY_90msp_RKSJ_H=allocate([32, 0, 126, 0, 1, 0, -32448, 0, -32386, 0, 633, 0, -32384, 0, -32340, 0, 696, 0, -32328, 0, -32321, 0, 741, 0, -32312, 0, -32306, 0, 749, 0, -32294, 0, -32280, 0, 756, 0, -32272, 0, -32265, 0, 771, 0, -32260, 0, -32260, 0, 779, 0, -32177, 0, -32168, 0, 780, 0, -32160, 0, -32135, 0, 790, 0, -32127, 0, -32102, 0, 816, 0, -32097, 0, -32015, 0, 842, 0, -31936, 0, -31874, 0, 925, 0, -31872, 0, -31850, 0, 988, 0, -31841, 0, -31818, 0, 1011, 0, -31809, 0, -31786, 0, 1035, 0, -31680, 0, -31648, 0, 1059, 0, -31632, 0, -31618, 0, 1092, 0, -31616, 0, -31599, 0, 1107, 0, -31585, 0, -31585, 0, 7479, 0, -31584, 0, -31584, 0, 7481, 0, -31583, 0, -31583, 0, 7491, 0, -31582, 0, -31582, 0, 7495, 0, -31581, 0, -31581, 0, 7503, 0, -31580, 0, -31580, 0, 7499, 0, -31579, 0, -31579, 0, 7507, 0, -31578, 0, -31578, 0, 7523, 0, -31577, 0, -31577, 0, 7515, 0, -31576, 0, -31576, 0, 7531, 0, -31575, 0, -31575, 0, 7539, 0, -31574, 0, -31574, 0, 7480, 0, -31573, 0, -31573, 0, 7482, 0, -31572, 0, -31572, 0, 7494, 0, -31571, 0, -31571, 0, 7498, 0, -31570, 0, -31570, 0, 7506, 0, -31569, 0, -31569, 0, 7502, 0, -31568, 0, -31568, 0, 7514, 0, -31567, 0, -31567, 0, 7530, 0, -31566, 0, -31566, 0, 7522, 0, -31565, 0, -31565, 0, 7538, 0, -31564, 0, -31564, 0, 7554, 0, -31563, 0, -31563, 0, 7511, 0, -31562, 0, -31562, 0, 7526, 0, -31561, 0, -31561, 0, 7519, 0, -31560, 0, -31560, 0, 7534, 0, -31559, 0, -31559, 0, 7542, 0, -31558, 0, -31558, 0, 7508, 0, -31557, 0, -31557, 0, 7527, 0, -31556, 0, -31556, 0, 7516, 0, -31555, 0, -31555, 0, 7535, 0, -31554, 0, -31554, 0, 7545, 0, -30912, 0, -30883, 0, 7555, 0, -30881, 0, -30880, 0, 7585, 0, -30879, 0, -30879, 0, 8038, 0, -30878, 0, -30878, 0, 7588, 0, -30877, 0, -30877, 0, 8040, 0, -30876, 0, -30876, 0, 7590, 0, -30875, 0, -30875, 0, 8042, 0, -30874, 0, -30873, 0, 7592, 0, -30872, 0, -30872, 0, 8044, 0, -30871, 0, -30870, 0, 7595, 0, -30869, 0, -30869, 0, 8043, 0, -30868, 0, -30867, 0, 7598, 0, -30866, 0, -30866, 0, 8047, 0, -30865, 0, -30859, 0, 7601, 0, -30850, 0, -30850, 0, 8323, 0, -30848, 0, -30845, 0, 7608, 0, -30844, 0, -30844, 0, 8055, 0, -30843, 0, -30833, 0, 7613, 0, -30832, 0, -30832, 0, 762, 0, -30831, 0, -30831, 0, 761, 0, -30830, 0, -30830, 0, 769, 0, -30829, 0, -30823, 0, 7624, 0, -30822, 0, -30822, 0, 768, 0, -30821, 0, -30820, 0, 7631, 0, -30561, 0, -30468, 0, 1125, 0, -30400, 0, -30338, 0, 1219, 0, -30336, 0, -30212, 0, 1282, 0, -30144, 0, -30082, 0, 1407, 0, -30080, 0, -29956, 0, 1470, 0, -29888, 0, -29826, 0, 1595, 0, -29824, 0, -29700, 0, 1658, 0, -29632, 0, -29570, 0, 1783, 0, -29568, 0, -29444, 0, 1846, 0, -29376, 0, -29314, 0, 1971, 0, -29312, 0, -29188, 0, 2034, 0, -29120, 0, -29058, 0, 2159, 0, -29056, 0, -28932, 0, 2222, 0, -28864, 0, -28802, 0, 2347, 0, -28800, 0, -28676, 0, 2410, 0, -28608, 0, -28546, 0, 2535, 0, -28544, 0, -28420, 0, 2598, 0, -28352, 0, -28290, 0, 2723, 0, -28288, 0, -28164, 0, 2786, 0, -28096, 0, -28034, 0, 2911, 0, -28032, 0, -27908, 0, 2974, 0, -27840, 0, -27778, 0, 3099, 0, -27776, 0, -27652, 0, 3162, 0, -27584, 0, -27522, 0, 3287, 0, -27520, 0, -27396, 0, 3350, 0, -27328, 0, -27266, 0, 3475, 0, -27264, 0, -27140, 0, 3538, 0, -27072, 0, -27010, 0, 3663, 0, -27008, 0, -26884, 0, 3726, 0, -26816, 0, -26754, 0, 3851, 0, -26752, 0, -26628, 0, 3914, 0, -26560, 0, -26510, 0, 4039, 0, -26465, 0, -26372, 0, 4090, 0, -26304, 0, -26242, 0, 4184, 0, -26240, 0, -26116, 0, 4247, 0, -26048, 0, -25986, 0, 4372, 0, -25984, 0, -25860, 0, 4435, 0, -25792, 0, -25730, 0, 4560, 0, -25728, 0, -25604, 0, 4623, 0, -25536, 0, -25474, 0, 4748, 0, -25472, 0, -25348, 0, 4811, 0, -25280, 0, -25218, 0, 4936, 0, -25216, 0, -25092, 0, 4999, 0, -25024, 0, -24962, 0, 5124, 0, -24960, 0, -24836, 0, 5187, 0, -24768, 0, -24706, 0, 5312, 0, -24704, 0, -24580, 0, 5375, 0, 160, 0, 223, 0, 326, 0, -8128, 0, -8066, 0, 5500, 0, -8064, 0, -7940, 0, 5563, 0, -7872, 0, -7810, 0, 5688, 0, -7808, 0, -7684, 0, 5751, 0, -7616, 0, -7554, 0, 5876, 0, -7552, 0, -7428, 0, 5939, 0, -7360, 0, -7298, 0, 6064, 0, -7296, 0, -7172, 0, 6127, 0, -7104, 0, -7042, 0, 6252, 0, -7040, 0, -6916, 0, 6315, 0, -6848, 0, -6786, 0, 6440, 0, -6784, 0, -6660, 0, 6503, 0, -6592, 0, -6530, 0, 6628, 0, -6528, 0, -6404, 0, 6691, 0, -6336, 0, -6274, 0, 6816, 0, -6272, 0, -6148, 0, 6879, 0, -6080, 0, -6018, 0, 7004, 0, -6016, 0, -5892, 0, 7067, 0, -5824, 0, -5762, 0, 7192, 0, -5760, 0, -5636, 0, 7255, 0, -5568, 0, -5506, 0, 7380, 0, -5504, 0, -5470, 0, 7443, 0, -5469, 0, -5468, 0, 8284, 0, -4800, 0, -4738, 0, 8359, 0, -4736, 0, -4685, 0, 8422, 0, -4684, 0, -4684, 0, 1993, 0, -4683, 0, -4612, 0, 8474, 0, -4544, 0, -4482, 0, 8546, 0, -4480, 0, -4372, 0, 8609, 0, -4369, 0, -4360, 0, 8092, 0, -4359, 0, -4359, 0, 751, 0, -4358, 0, -4356, 0, 8005, 0, -1472, 0, -1463, 0, 8092, 0, -1462, 0, -1453, 0, 7575, 0, -1452, 0, -1452, 0, 751, 0, -1451, 0, -1449, 0, 8005, 0, -1448, 0, -1448, 0, 7618, 0, -1447, 0, -1447, 0, 7610, 0, -1446, 0, -1446, 0, 8055, 0, -1445, 0, -1445, 0, 768, 0, -1444, 0, -1410, 0, 8359, 0, -1408, 0, -1329, 0, 8394, 0, -1328, 0, -1328, 0, 1993, 0, -1327, 0, -1284, 0, 8474, 0, -1216, 0, -1154, 0, 8518, 0, -1152, 0, -1028, 0, 8581, 0, -960, 0, -949, 0, 8706, 0, -1, 0, -1, 0, 0, 0], ["i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0], ALLOC_STATIC);
_MSP_RKSJ_NOTDEF_RANGE=allocate([0, 0, 31, 0, 1, 0], ["i16",0,"i16",0,"i16",0], ALLOC_STATIC);
_CP932_UNICODE_ARRAY=allocate([0, 0, 0, 0, 1, 0, 1, 0, 2, 0, 2, 0, 3, 0, 3, 0, 4, 0, 4, 0, 5, 0, 5, 0, 6, 0, 6, 0, 7, 0, 7, 0, 8, 0, 8, 0, 9, 0, 9, 0, 10, 0, 10, 0, 11, 0, 11, 0, 12, 0, 12, 0, 13, 0, 13, 0, 14, 0, 14, 0, 15, 0, 15, 0, 16, 0, 16, 0, 17, 0, 17, 0, 18, 0, 18, 0, 19, 0, 19, 0, 20, 0, 20, 0, 21, 0, 21, 0, 22, 0, 22, 0, 23, 0, 23, 0, 24, 0, 24, 0, 25, 0, 25, 0, 26, 0, 26, 0, 27, 0, 27, 0, 28, 0, 28, 0, 29, 0, 29, 0, 30, 0, 30, 0, 31, 0, 31, 0, 32, 0, 32, 0, 33, 0, 33, 0, 34, 0, 34, 0, 35, 0, 35, 0, 36, 0, 36, 0, 37, 0, 37, 0, 38, 0, 38, 0, 39, 0, 39, 0, 40, 0, 40, 0, 41, 0, 41, 0, 42, 0, 42, 0, 43, 0, 43, 0, 44, 0, 44, 0, 45, 0, 45, 0, 46, 0, 46, 0, 47, 0, 47, 0, 48, 0, 48, 0, 49, 0, 49, 0, 50, 0, 50, 0, 51, 0, 51, 0, 52, 0, 52, 0, 53, 0, 53, 0, 54, 0, 54, 0, 55, 0, 55, 0, 56, 0, 56, 0, 57, 0, 57, 0, 58, 0, 58, 0, 59, 0, 59, 0, 60, 0, 60, 0, 61, 0, 61, 0, 62, 0, 62, 0, 63, 0, 63, 0, 64, 0, 64, 0, 65, 0, 65, 0, 66, 0, 66, 0, 67, 0, 67, 0, 68, 0, 68, 0, 69, 0, 69, 0, 70, 0, 70, 0, 71, 0, 71, 0, 72, 0, 72, 0, 73, 0, 73, 0, 74, 0, 74, 0, 75, 0, 75, 0, 76, 0, 76, 0, 77, 0, 77, 0, 78, 0, 78, 0, 79, 0, 79, 0, 80, 0, 80, 0, 81, 0, 81, 0, 82, 0, 82, 0, 83, 0, 83, 0, 84, 0, 84, 0, 85, 0, 85, 0, 86, 0, 86, 0, 87, 0, 87, 0, 88, 0, 88, 0, 89, 0, 89, 0, 90, 0, 90, 0, 91, 0, 91, 0, 92, 0, 92, 0, 93, 0, 93, 0, 94, 0, 94, 0, 95, 0, 95, 0, 96, 0, 96, 0, 97, 0, 97, 0, 98, 0, 98, 0, 99, 0, 99, 0, 100, 0, 100, 0, 101, 0, 101, 0, 102, 0, 102, 0, 103, 0, 103, 0, 104, 0, 104, 0, 105, 0, 105, 0, 106, 0, 106, 0, 107, 0, 107, 0, 108, 0, 108, 0, 109, 0, 109, 0, 110, 0, 110, 0, 111, 0, 111, 0, 112, 0, 112, 0, 113, 0, 113, 0, 114, 0, 114, 0, 115, 0, 115, 0, 116, 0, 116, 0, 117, 0, 117, 0, 118, 0, 118, 0, 119, 0, 119, 0, 120, 0, 120, 0, 121, 0, 121, 0, 122, 0, 122, 0, 123, 0, 123, 0, 124, 0, 124, 0, 125, 0, 125, 0, 126, 0, 126, 0, 127, 0, 127, 0, 161, 0, -159, 0, 162, 0, -158, 0, 163, 0, -157, 0, 164, 0, -156, 0, 165, 0, -155, 0, 166, 0, -154, 0, 167, 0, -153, 0, 168, 0, -152, 0, 169, 0, -151, 0, 170, 0, -150, 0, 171, 0, -149, 0, 172, 0, -148, 0, 173, 0, -147, 0, 174, 0, -146, 0, 175, 0, -145, 0, 176, 0, -144, 0, 177, 0, -143, 0, 178, 0, -142, 0, 179, 0, -141, 0, 180, 0, -140, 0, 181, 0, -139, 0, 182, 0, -138, 0, 183, 0, -137, 0, 184, 0, -136, 0, 185, 0, -135, 0, 186, 0, -134, 0, 187, 0, -133, 0, 188, 0, -132, 0, 189, 0, -131, 0, 190, 0, -130, 0, 191, 0, -129, 0, 192, 0, -128, 0, 193, 0, -127, 0, 194, 0, -126, 0, 195, 0, -125, 0, 196, 0, -124, 0, 197, 0, -123, 0, 198, 0, -122, 0, 199, 0, -121, 0, 200, 0, -120, 0, 201, 0, -119, 0, 202, 0, -118, 0, 203, 0, -117, 0, 204, 0, -116, 0, 205, 0, -115, 0, 206, 0, -114, 0, 207, 0, -113, 0, 208, 0, -112, 0, 209, 0, -111, 0, 210, 0, -110, 0, 211, 0, -109, 0, 212, 0, -108, 0, 213, 0, -107, 0, 214, 0, -106, 0, 215, 0, -105, 0, 216, 0, -104, 0, 217, 0, -103, 0, 218, 0, -102, 0, 219, 0, -101, 0, 220, 0, -100, 0, 221, 0, -99, 0, 222, 0, -98, 0, 223, 0, -97, 0, -32448, 0, 12288, 0, -32447, 0, 12289, 0, -32446, 0, 12290, 0, -32445, 0, -244, 0, -32444, 0, -242, 0, -32443, 0, 12539, 0, -32442, 0, -230, 0, -32441, 0, -229, 0, -32440, 0, -225, 0, -32439, 0, -255, 0, -32438, 0, 12443, 0, -32437, 0, 12444, 0, -32436, 0, 180, 0, -32435, 0, -192, 0, -32434, 0, 168, 0, -32433, 0, -194, 0, -32432, 0, -29, 0, -32431, 0, -193, 0, -32430, 0, 12541, 0, -32429, 0, 12542, 0, -32428, 0, 12445, 0, -32427, 0, 12446, 0, -32426, 0, 12291, 0, -32425, 0, 20189, 0, -32424, 0, 12293, 0, -32423, 0, 12294, 0, -32422, 0, 12295, 0, -32421, 0, 12540, 0, -32420, 0, 8213, 0, -32419, 0, 8208, 0, -32418, 0, -241, 0, -32417, 0, -196, 0, -32416, 0, -162, 0, -32415, 0, 8741, 0, -32414, 0, -164, 0, -32413, 0, 8230, 0, -32412, 0, 8229, 0, -32411, 0, 8216, 0, -32410, 0, 8217, 0, -32409, 0, 8220, 0, -32408, 0, 8221, 0, -32407, 0, -248, 0, -32406, 0, -247, 0, -32405, 0, 12308, 0, -32404, 0, 12309, 0, -32403, 0, -197, 0, -32402, 0, -195, 0, -32401, 0, -165, 0, -32400, 0, -163, 0, -32399, 0, 12296, 0, -32398, 0, 12297, 0, -32397, 0, 12298, 0, -32396, 0, 12299, 0, -32395, 0, 12300, 0, -32394, 0, 12301, 0, -32393, 0, 12302, 0, -32392, 0, 12303, 0, -32391, 0, 12304, 0, -32390, 0, 12305, 0, -32389, 0, -245, 0, -32388, 0, -243, 0, -32387, 0, 177, 0, -32386, 0, 215, 0, -32384, 0, 247, 0, -32383, 0, -227, 0, -32382, 0, 8800, 0, -32381, 0, -228, 0, -32380, 0, -226, 0, -32379, 0, 8806, 0, -32378, 0, 8807, 0, -32377, 0, 8734, 0, -32376, 0, 8756, 0, -32375, 0, 9794, 0, -32374, 0, 9792, 0, -32373, 0, 176, 0, -32372, 0, 8242, 0, -32371, 0, 8243, 0, -32370, 0, 8451, 0, -32369, 0, -27, 0, -32368, 0, -252, 0, -32367, 0, -32, 0, -32366, 0, -31, 0, -32365, 0, -251, 0, -32364, 0, -253, 0, -32363, 0, -250, 0, -32362, 0, -246, 0, -32361, 0, -224, 0, -32360, 0, 167, 0, -32359, 0, 9734, 0, -32358, 0, 9733, 0, -32357, 0, 9675, 0, -32356, 0, 9679, 0, -32355, 0, 9678, 0, -32354, 0, 9671, 0, -32353, 0, 9670, 0, -32352, 0, 9633, 0, -32351, 0, 9632, 0, -32350, 0, 9651, 0, -32349, 0, 9650, 0, -32348, 0, 9661, 0, -32347, 0, 9660, 0, -32346, 0, 8251, 0, -32345, 0, 12306, 0, -32344, 0, 8594, 0, -32343, 0, 8592, 0, -32342, 0, 8593, 0, -32341, 0, 8595, 0, -32340, 0, 12307, 0, -32328, 0, 8712, 0, -32327, 0, 8715, 0, -32326, 0, 8838, 0, -32325, 0, 8839, 0, -32324, 0, 8834, 0, -32323, 0, 8835, 0, -32322, 0, 8746, 0, -32321, 0, 8745, 0, -32312, 0, 8743, 0, -32311, 0, 8744, 0, -32310, 0, -30, 0, -32309, 0, 8658, 0, -32308, 0, 8660, 0, -32307, 0, 8704, 0, -32306, 0, 8707, 0, -32294, 0, 8736, 0, -32293, 0, 8869, 0, -32292, 0, 8978, 0, -32291, 0, 8706, 0, -32290, 0, 8711, 0, -32289, 0, 8801, 0, -32288, 0, 8786, 0, -32287, 0, 8810, 0, -32286, 0, 8811, 0, -32285, 0, 8730, 0, -32284, 0, 8765, 0, -32283, 0, 8733, 0, -32282, 0, 8757, 0, -32281, 0, 8747, 0, -32280, 0, 8748, 0, -32272, 0, 8491, 0, -32271, 0, 8240, 0, -32270, 0, 9839, 0, -32269, 0, 9837, 0, -32268, 0, 9834, 0, -32267, 0, 8224, 0, -32266, 0, 8225, 0, -32265, 0, 182, 0, -32260, 0, 9711, 0, -32177, 0, -240, 0, -32176, 0, -239, 0, -32175, 0, -238, 0, -32174, 0, -237, 0, -32173, 0, -236, 0, -32172, 0, -235, 0, -32171, 0, -234, 0, -32170, 0, -233, 0, -32169, 0, -232, 0, -32168, 0, -231, 0, -32160, 0, -223, 0, -32159, 0, -222, 0, -32158, 0, -221, 0, -32157, 0, -220, 0, -32156, 0, -219, 0, -32155, 0, -218, 0, -32154, 0, -217, 0, -32153, 0, -216, 0, -32152, 0, -215, 0, -32151, 0, -214, 0, -32150, 0, -213, 0, -32149, 0, -212, 0, -32148, 0, -211, 0, -32147, 0, -210, 0, -32146, 0, -209, 0, -32145, 0, -208, 0, -32144, 0, -207, 0, -32143, 0, -206, 0, -32142, 0, -205, 0, -32141, 0, -204, 0, -32140, 0, -203, 0, -32139, 0, -202, 0, -32138, 0, -201, 0, -32137, 0, -200, 0, -32136, 0, -199, 0, -32135, 0, -198, 0, -32127, 0, -191, 0, -32126, 0, -190, 0, -32125, 0, -189, 0, -32124, 0, -188, 0, -32123, 0, -187, 0, -32122, 0, -186, 0, -32121, 0, -185, 0, -32120, 0, -184, 0, -32119, 0, -183, 0, -32118, 0, -182, 0, -32117, 0, -181, 0, -32116, 0, -180, 0, -32115, 0, -179, 0, -32114, 0, -178, 0, -32113, 0, -177, 0, -32112, 0, -176, 0, -32111, 0, -175, 0, -32110, 0, -174, 0, -32109, 0, -173, 0, -32108, 0, -172, 0, -32107, 0, -171, 0, -32106, 0, -170, 0, -32105, 0, -169, 0, -32104, 0, -168, 0, -32103, 0, -167, 0, -32102, 0, -166, 0, -32097, 0, 12353, 0, -32096, 0, 12354, 0, -32095, 0, 12355, 0, -32094, 0, 12356, 0, -32093, 0, 12357, 0, -32092, 0, 12358, 0, -32091, 0, 12359, 0, -32090, 0, 12360, 0, -32089, 0, 12361, 0, -32088, 0, 12362, 0, -32087, 0, 12363, 0, -32086, 0, 12364, 0, -32085, 0, 12365, 0, -32084, 0, 12366, 0, -32083, 0, 12367, 0, -32082, 0, 12368, 0, -32081, 0, 12369, 0, -32080, 0, 12370, 0, -32079, 0, 12371, 0, -32078, 0, 12372, 0, -32077, 0, 12373, 0, -32076, 0, 12374, 0, -32075, 0, 12375, 0, -32074, 0, 12376, 0, -32073, 0, 12377, 0, -32072, 0, 12378, 0, -32071, 0, 12379, 0, -32070, 0, 12380, 0, -32069, 0, 12381, 0, -32068, 0, 12382, 0, -32067, 0, 12383, 0, -32066, 0, 12384, 0, -32065, 0, 12385, 0, -32064, 0, 12386, 0, -32063, 0, 12387, 0, -32062, 0, 12388, 0, -32061, 0, 12389, 0, -32060, 0, 12390, 0, -32059, 0, 12391, 0, -32058, 0, 12392, 0, -32057, 0, 12393, 0, -32056, 0, 12394, 0, -32055, 0, 12395, 0, -32054, 0, 12396, 0, -32053, 0, 12397, 0, -32052, 0, 12398, 0, -32051, 0, 12399, 0, -32050, 0, 12400, 0, -32049, 0, 12401, 0, -32048, 0, 12402, 0, -32047, 0, 12403, 0, -32046, 0, 12404, 0, -32045, 0, 12405, 0, -32044, 0, 12406, 0, -32043, 0, 12407, 0, -32042, 0, 12408, 0, -32041, 0, 12409, 0, -32040, 0, 12410, 0, -32039, 0, 12411, 0, -32038, 0, 12412, 0, -32037, 0, 12413, 0, -32036, 0, 12414, 0, -32035, 0, 12415, 0, -32034, 0, 12416, 0, -32033, 0, 12417, 0, -32032, 0, 12418, 0, -32031, 0, 12419, 0, -32030, 0, 12420, 0, -32029, 0, 12421, 0, -32028, 0, 12422, 0, -32027, 0, 12423, 0, -32026, 0, 12424, 0, -32025, 0, 12425, 0, -32024, 0, 12426, 0, -32023, 0, 12427, 0, -32022, 0, 12428, 0, -32021, 0, 12429, 0, -32020, 0, 12430, 0, -32019, 0, 12431, 0, -32018, 0, 12432, 0, -32017, 0, 12433, 0, -32016, 0, 12434, 0, -32015, 0, 12435, 0, -31936, 0, 12449, 0, -31935, 0, 12450, 0, -31934, 0, 12451, 0, -31933, 0, 12452, 0, -31932, 0, 12453, 0, -31931, 0, 12454, 0, -31930, 0, 12455, 0, -31929, 0, 12456, 0, -31928, 0, 12457, 0, -31927, 0, 12458, 0, -31926, 0, 12459, 0, -31925, 0, 12460, 0, -31924, 0, 12461, 0, -31923, 0, 12462, 0, -31922, 0, 12463, 0, -31921, 0, 12464, 0, -31920, 0, 12465, 0, -31919, 0, 12466, 0, -31918, 0, 12467, 0, -31917, 0, 12468, 0, -31916, 0, 12469, 0, -31915, 0, 12470, 0, -31914, 0, 12471, 0, -31913, 0, 12472, 0, -31912, 0, 12473, 0, -31911, 0, 12474, 0, -31910, 0, 12475, 0, -31909, 0, 12476, 0, -31908, 0, 12477, 0, -31907, 0, 12478, 0, -31906, 0, 12479, 0, -31905, 0, 12480, 0, -31904, 0, 12481, 0, -31903, 0, 12482, 0, -31902, 0, 12483, 0, -31901, 0, 12484, 0, -31900, 0, 12485, 0, -31899, 0, 12486, 0, -31898, 0, 12487, 0, -31897, 0, 12488, 0, -31896, 0, 12489, 0, -31895, 0, 12490, 0, -31894, 0, 12491, 0, -31893, 0, 12492, 0, -31892, 0, 12493, 0, -31891, 0, 12494, 0, -31890, 0, 12495, 0, -31889, 0, 12496, 0, -31888, 0, 12497, 0, -31887, 0, 12498, 0, -31886, 0, 12499, 0, -31885, 0, 12500, 0, -31884, 0, 12501, 0, -31883, 0, 12502, 0, -31882, 0, 12503, 0, -31881, 0, 12504, 0, -31880, 0, 12505, 0, -31879, 0, 12506, 0, -31878, 0, 12507, 0, -31877, 0, 12508, 0, -31876, 0, 12509, 0, -31875, 0, 12510, 0, -31874, 0, 12511, 0, -31872, 0, 12512, 0, -31871, 0, 12513, 0, -31870, 0, 12514, 0, -31869, 0, 12515, 0, -31868, 0, 12516, 0, -31867, 0, 12517, 0, -31866, 0, 12518, 0, -31865, 0, 12519, 0, -31864, 0, 12520, 0, -31863, 0, 12521, 0, -31862, 0, 12522, 0, -31861, 0, 12523, 0, -31860, 0, 12524, 0, -31859, 0, 12525, 0, -31858, 0, 12526, 0, -31857, 0, 12527, 0, -31856, 0, 12528, 0, -31855, 0, 12529, 0, -31854, 0, 12530, 0, -31853, 0, 12531, 0, -31852, 0, 12532, 0, -31851, 0, 12533, 0, -31850, 0, 12534, 0, -31841, 0, 913, 0, -31840, 0, 914, 0, -31839, 0, 915, 0, -31838, 0, 916, 0, -31837, 0, 917, 0, -31836, 0, 918, 0, -31835, 0, 919, 0, -31834, 0, 920, 0, -31833, 0, 921, 0, -31832, 0, 922, 0, -31831, 0, 923, 0, -31830, 0, 924, 0, -31829, 0, 925, 0, -31828, 0, 926, 0, -31827, 0, 927, 0, -31826, 0, 928, 0, -31825, 0, 929, 0, -31824, 0, 931, 0, -31823, 0, 932, 0, -31822, 0, 933, 0, -31821, 0, 934, 0, -31820, 0, 935, 0, -31819, 0, 936, 0, -31818, 0, 937, 0, -31809, 0, 945, 0, -31808, 0, 946, 0, -31807, 0, 947, 0, -31806, 0, 948, 0, -31805, 0, 949, 0, -31804, 0, 950, 0, -31803, 0, 951, 0, -31802, 0, 952, 0, -31801, 0, 953, 0, -31800, 0, 954, 0, -31799, 0, 955, 0, -31798, 0, 956, 0, -31797, 0, 957, 0, -31796, 0, 958, 0, -31795, 0, 959, 0, -31794, 0, 960, 0, -31793, 0, 961, 0, -31792, 0, 963, 0, -31791, 0, 964, 0, -31790, 0, 965, 0, -31789, 0, 966, 0, -31788, 0, 967, 0, -31787, 0, 968, 0, -31786, 0, 969, 0, -31680, 0, 1040, 0, -31679, 0, 1041, 0, -31678, 0, 1042, 0, -31677, 0, 1043, 0, -31676, 0, 1044, 0, -31675, 0, 1045, 0, -31674, 0, 1025, 0, -31673, 0, 1046, 0, -31672, 0, 1047, 0, -31671, 0, 1048, 0, -31670, 0, 1049, 0, -31669, 0, 1050, 0, -31668, 0, 1051, 0, -31667, 0, 1052, 0, -31666, 0, 1053, 0, -31665, 0, 1054, 0, -31664, 0, 1055, 0, -31663, 0, 1056, 0, -31662, 0, 1057, 0, -31661, 0, 1058, 0, -31660, 0, 1059, 0, -31659, 0, 1060, 0, -31658, 0, 1061, 0, -31657, 0, 1062, 0, -31656, 0, 1063, 0, -31655, 0, 1064, 0, -31654, 0, 1065, 0, -31653, 0, 1066, 0, -31652, 0, 1067, 0, -31651, 0, 1068, 0, -31650, 0, 1069, 0, -31649, 0, 1070, 0, -31648, 0, 1071, 0, -31632, 0, 1072, 0, -31631, 0, 1073, 0, -31630, 0, 1074, 0, -31629, 0, 1075, 0, -31628, 0, 1076, 0, -31627, 0, 1077, 0, -31626, 0, 1105, 0, -31625, 0, 1078, 0, -31624, 0, 1079, 0, -31623, 0, 1080, 0, -31622, 0, 1081, 0, -31621, 0, 1082, 0, -31620, 0, 1083, 0, -31619, 0, 1084, 0, -31618, 0, 1085, 0, -31616, 0, 1086, 0, -31615, 0, 1087, 0, -31614, 0, 1088, 0, -31613, 0, 1089, 0, -31612, 0, 1090, 0, -31611, 0, 1091, 0, -31610, 0, 1092, 0, -31609, 0, 1093, 0, -31608, 0, 1094, 0, -31607, 0, 1095, 0, -31606, 0, 1096, 0, -31605, 0, 1097, 0, -31604, 0, 1098, 0, -31603, 0, 1099, 0, -31602, 0, 1100, 0, -31601, 0, 1101, 0, -31600, 0, 1102, 0, -31599, 0, 1103, 0, -31585, 0, 9472, 0, -31584, 0, 9474, 0, -31583, 0, 9484, 0, -31582, 0, 9488, 0, -31581, 0, 9496, 0, -31580, 0, 9492, 0, -31579, 0, 9500, 0, -31578, 0, 9516, 0, -31577, 0, 9508, 0, -31576, 0, 9524, 0, -31575, 0, 9532, 0, -31574, 0, 9473, 0, -31573, 0, 9475, 0, -31572, 0, 9487, 0, -31571, 0, 9491, 0, -31570, 0, 9499, 0, -31569, 0, 9495, 0, -31568, 0, 9507, 0, -31567, 0, 9523, 0, -31566, 0, 9515, 0, -31565, 0, 9531, 0, -31564, 0, 9547, 0, -31563, 0, 9504, 0, -31562, 0, 9519, 0, -31561, 0, 9512, 0, -31560, 0, 9527, 0, -31559, 0, 9535, 0, -31558, 0, 9501, 0, -31557, 0, 9520, 0, -31556, 0, 9509, 0, -31555, 0, 9528, 0, -31554, 0, 9538, 0, -30912, 0, 9312, 0, -30911, 0, 9313, 0, -30910, 0, 9314, 0, -30909, 0, 9315, 0, -30908, 0, 9316, 0, -30907, 0, 9317, 0, -30906, 0, 9318, 0, -30905, 0, 9319, 0, -30904, 0, 9320, 0, -30903, 0, 9321, 0, -30902, 0, 9322, 0, -30901, 0, 9323, 0, -30900, 0, 9324, 0, -30899, 0, 9325, 0, -30898, 0, 9326, 0, -30897, 0, 9327, 0, -30896, 0, 9328, 0, -30895, 0, 9329, 0, -30894, 0, 9330, 0, -30893, 0, 9331, 0, -30892, 0, 8544, 0, -30891, 0, 8545, 0, -30890, 0, 8546, 0, -30889, 0, 8547, 0, -30888, 0, 8548, 0, -30887, 0, 8549, 0, -30886, 0, 8550, 0, -30885, 0, 8551, 0, -30884, 0, 8552, 0, -30883, 0, 8553, 0, -30881, 0, 13129, 0, -30880, 0, 13076, 0, -30879, 0, 13090, 0, -30878, 0, 13133, 0, -30877, 0, 13080, 0, -30876, 0, 13095, 0, -30875, 0, 13059, 0, -30874, 0, 13110, 0, -30873, 0, 13137, 0, -30872, 0, 13143, 0, -30871, 0, 13069, 0, -30870, 0, 13094, 0, -30869, 0, 13091, 0, -30868, 0, 13099, 0, -30867, 0, 13130, 0, -30866, 0, 13115, 0, -30865, 0, 13212, 0, -30864, 0, 13213, 0, -30863, 0, 13214, 0, -30862, 0, 13198, 0, -30861, 0, 13199, 0, -30860, 0, 13252, 0, -30859, 0, 13217, 0, -30850, 0, 13179, 0, -30848, 0, 12317, 0, -30847, 0, 12319, 0, -30846, 0, 8470, 0, -30845, 0, 13261, 0, -30844, 0, 8481, 0, -30843, 0, 12964, 0, -30842, 0, 12965, 0, -30841, 0, 12966, 0, -30840, 0, 12967, 0, -30839, 0, 12968, 0, -30838, 0, 12849, 0, -30837, 0, 12850, 0, -30836, 0, 12857, 0, -30835, 0, 13182, 0, -30834, 0, 13181, 0, -30833, 0, 13180, 0, -30832, 0, 8786, 0, -30831, 0, 8801, 0, -30830, 0, 8747, 0, -30829, 0, 8750, 0, -30828, 0, 8721, 0, -30827, 0, 8730, 0, -30826, 0, 8869, 0, -30825, 0, 8736, 0, -30824, 0, 8735, 0, -30823, 0, 8895, 0, -30822, 0, 8757, 0, -30821, 0, 8745, 0, -30820, 0, 8746, 0, -30561, 0, 20124, 0, -30560, 0, 21782, 0, -30559, 0, 23043, 0, -30558, 0, -27073, 0, -30557, 0, 21696, 0, -30556, 0, 24859, 0, -30555, 0, 25384, 0, -30554, 0, 23030, 0, -30553, 0, -28638, 0, -30552, 0, -31627, 0, -30551, 0, -31972, 0, -30550, 0, 31312, 0, -30549, 0, 24746, 0, -30548, 0, 25569, 0, -30547, 0, 28197, 0, -30546, 0, 26093, 0, -30545, 0, -31642, 0, -30544, 0, -32090, 0, -30543, 0, -25611, 0, -30542, 0, 26771, 0, -30541, 0, 22311, 0, -30540, 0, 26017, 0, -30539, 0, 25201, 0, -30538, 0, 23451, 0, -30537, 0, 22992, 0, -30536, 0, -31109, 0, -30535, 0, -26380, 0, -30534, 0, 32098, 0, -30533, 0, 32190, 0, -30532, 0, -25714, 0, -30531, 0, 25110, 0, -30530, 0, 31903, 0, -30529, 0, -30537, 0, -30528, 0, 23433, 0, -30527, 0, 24245, 0, -30526, 0, 25353, 0, -30525, 0, 26263, 0, -30524, 0, 26696, 0, -30523, 0, -27193, 0, -30522, 0, -26739, 0, -30521, 0, 26447, 0, -30520, 0, 20197, 0, -30519, 0, 20234, 0, -30518, 0, 20301, 0, -30517, 0, 20381, 0, -30516, 0, 20553, 0, -30515, 0, 22258, 0, -30514, 0, 22839, 0, -30513, 0, 22996, 0, -30512, 0, 23041, 0, -30511, 0, 23561, 0, -30510, 0, 24799, 0, -30509, 0, 24847, 0, -30508, 0, 24944, 0, -30507, 0, 26131, 0, -30506, 0, 26885, 0, -30505, 0, 28858, 0, -30504, 0, 30031, 0, -30503, 0, 30064, 0, -30502, 0, 31227, 0, -30501, 0, 32173, 0, -30500, 0, 32239, 0, -30499, 0, -32573, 0, -30498, 0, -31730, 0, -30497, 0, -30621, 0, -30496, 0, -29950, 0, -30495, 0, -28587, 0, -30494, 0, -28550, 0, -30493, 0, 21307, 0, -30492, 0, 20117, 0, -30491, 0, 20133, 0, -30490, 0, 22495, 0, -30489, 0, -32590, 0, -30488, 0, -28479, 0, -30487, 0, 30959, 0, -30486, 0, 19968, 0, -30485, 0, 22769, 0, -30484, 0, 28322, 0, -30483, 0, -28616, 0, -30482, 0, 31282, 0, -30481, 0, -31960, 0, -30480, 0, -32117, 0, -30479, 0, -25553, 0, -30478, 0, 20801, 0, -30477, 0, 21360, 0, -30476, 0, 21693, 0, -30475, 0, 21729, 0, -30474, 0, 22240, 0, -30473, 0, 23035, 0, -30472, 0, 24341, 0, -30471, 0, -26382, 0, -30470, 0, 28139, 0, -30469, 0, -32540, 0, -30468, 0, -31443, 0, -30400, 0, -27038, 0, -30399, 0, -27024, 0, -30398, 0, -26976, 0, -30397, 0, -26629, 0, -30396, 0, 21515, 0, -30395, 0, 21491, 0, -30394, 0, 23431, 0, -30393, 0, 28879, 0, -30392, 0, 32701, 0, -30391, 0, -28734, 0, -30390, 0, -26904, 0, -30389, 0, 21359, 0, -30388, 0, -25252, 0, -30387, 0, 31418, 0, -30386, 0, 19985, 0, -30385, 0, 30867, 0, -30384, 0, -32260, 0, -30383, 0, 28198, 0, -30382, 0, 22040, 0, -30381, 0, 21764, 0, -30380, 0, 27421, 0, -30379, 0, -31462, 0, -30378, 0, -25541, 0, -30377, 0, 23013, 0, -30376, 0, 21417, 0, -30375, 0, 28006, 0, -30374, 0, 29916, 0, -30373, 0, -27249, 0, -30372, 0, 22082, 0, -30371, 0, 20113, 0, -30370, 0, -28597, 0, -30369, 0, -26894, 0, -30368, 0, -31921, 0, -30367, 0, -26356, 0, -30366, 0, 21473, 0, -30365, 0, 21942, 0, -30364, 0, 23344, 0, -30363, 0, 24433, 0, -30362, 0, 26144, 0, -30361, 0, 26355, 0, -30360, 0, 26628, 0, -30359, 0, 27704, 0, -30358, 0, 27891, 0, -30357, 0, 27945, 0, -30356, 0, 29787, 0, -30355, 0, 30408, 0, -30354, 0, 31310, 0, -30353, 0, -26572, 0, -30352, 0, -32015, 0, -30351, 0, -30629, 0, -30350, 0, -30112, 0, -30349, 0, -27923, 0, -30348, 0, 28082, 0, -30347, 0, 30123, 0, -30346, 0, 30410, 0, -30345, 0, -26171, 0, -30344, 0, 24742, 0, -30343, 0, -29951, 0, -30342, 0, -29302, 0, -30341, 0, -27214, 0, -30340, 0, 27022, 0, -30339, 0, 21421, 0, -30338, 0, 20870, 0, -30336, 0, 22290, 0, -30335, 0, 22576, 0, -30334, 0, 22852, 0, -30333, 0, 23476, 0, -30332, 0, 24310, 0, -30331, 0, 24616, 0, -30330, 0, 25513, 0, -30329, 0, 25588, 0, -30328, 0, 27839, 0, -30327, 0, 28436, 0, -30326, 0, 28814, 0, -30325, 0, 28948, 0, -30324, 0, 29017, 0, -30323, 0, 29141, 0, -30322, 0, 29503, 0, -30321, 0, 32257, 0, -30320, 0, -32138, 0, -30319, 0, -32047, 0, -30318, 0, -31337, 0, -30317, 0, -28576, 0, -30316, 0, -28069, 0, -30315, 0, -25317, 0, -30314, 0, 22633, 0, -30313, 0, 26044, 0, -30312, 0, 27738, 0, -30311, 0, 29989, 0, -30310, 0, 20985, 0, -30309, 0, 22830, 0, -30308, 0, 22885, 0, -30307, 0, 24448, 0, -30306, 0, 24540, 0, -30305, 0, 25276, 0, -30304, 0, 26106, 0, -30303, 0, 27178, 0, -30302, 0, 27431, 0, -30301, 0, 27572, 0, -30300, 0, 29579, 0, -30299, 0, 32705, 0, -30298, 0, -30378, 0, -30297, 0, -25300, 0, -30296, 0, -25330, 0, -30295, 0, -24892, 0, -30294, 0, 23713, 0, -30293, 0, 27798, 0, -30292, 0, -31877, 0, -30291, 0, 20740, 0, -30290, 0, 23627, 0, -30289, 0, 25014, 0, -30288, 0, -32314, 0, -30287, 0, 26742, 0, -30286, 0, 29281, 0, -30285, 0, 20057, 0, -30284, 0, 20474, 0, -30283, 0, 21368, 0, -30282, 0, 24681, 0, -30281, 0, 28201, 0, -30280, 0, 31311, 0, -30279, 0, -26637, 0, -30278, 0, 19979, 0, -30277, 0, 21270, 0, -30276, 0, 20206, 0, -30275, 0, 20309, 0, -30274, 0, 20285, 0, -30273, 0, 20385, 0, -30272, 0, 20339, 0, -30271, 0, 21152, 0, -30270, 0, 21487, 0, -30269, 0, 22025, 0, -30268, 0, 22799, 0, -30267, 0, 23233, 0, -30266, 0, 23478, 0, -30265, 0, 23521, 0, -30264, 0, 31185, 0, -30263, 0, 26247, 0, -30262, 0, 26524, 0, -30261, 0, 26550, 0, -30260, 0, 27468, 0, -30259, 0, 27827, 0, -30258, 0, 28779, 0, -30257, 0, 29634, 0, -30256, 0, 31117, 0, -30255, 0, 31166, 0, -30254, 0, 31292, 0, -30253, 0, 31623, 0, -30252, 0, -32079, 0, -30251, 0, -32037, 0, -30250, 0, -31996, 0, -30249, 0, -31881, 0, -30248, 0, -31761, 0, -30247, 0, -31789, 0, -30246, 0, -30874, 0, -30245, 0, -30030, 0, -30244, 0, 22057, 0, -30243, 0, -29528, 0, -30242, 0, -28698, 0, -30241, 0, -28594, 0, -30240, 0, -26850, 0, -30239, 0, -31094, 0, -30238, 0, 20420, 0, -30237, 0, 23784, 0, -30236, 0, 25105, 0, -30235, 0, 29273, 0, -30234, 0, 30011, 0, -30233, 0, -32283, 0, -30232, 0, -32067, 0, -30231, 0, -30978, 0, -30230, 0, -29504, 0, -30229, 0, -26939, 0, -30228, 0, -26349, 0, -30227, 0, -26155, 0, -30226, 0, 20171, 0, -30225, 0, 20250, 0, -30224, 0, -30237, 0, -30223, 0, 22238, 0, -30222, 0, 22602, 0, -30221, 0, 22730, 0, -30220, 0, 24315, 0, -30219, 0, 24555, 0, -30218, 0, 24618, 0, -30217, 0, 24724, 0, -30216, 0, 24674, 0, -30215, 0, 25040, 0, -30214, 0, 25106, 0, -30213, 0, 25296, 0, -30212, 0, 25913, 0, -30144, 0, -25791, 0, -30143, 0, 26214, 0, -30142, 0, 26800, 0, -30141, 0, 28023, 0, -30140, 0, 28784, 0, -30139, 0, 30028, 0, -30138, 0, 30342, 0, -30137, 0, 32117, 0, -30136, 0, -32091, 0, -30135, 0, -30727, 0, -30134, 0, -27253, 0, -30133, 0, -26994, 0, -30132, 0, -29539, 0, -30131, 0, 20977, 0, -30130, 0, 21182, 0, -30129, 0, 22806, 0, -30128, 0, 21683, 0, -30127, 0, 23475, 0, -30126, 0, 23830, 0, -30125, 0, 24936, 0, -30124, 0, 27010, 0, -30123, 0, 28079, 0, -30122, 0, 30861, 0, -30121, 0, -31541, 0, -30120, 0, -30633, 0, -30119, 0, -30094, 0, -30118, 0, -27737, 0, -30117, 0, -25928, 0, -30116, 0, 28012, 0, -30115, 0, -26200, 0, -30114, 0, -31015, 0, -30113, 0, 22435, 0, -30112, 0, 26623, 0, -30111, 0, -31026, 0, -30110, 0, -28146, 0, -30109, 0, 21123, 0, -30108, 0, 22151, 0, -30107, 0, 21508, 0, -30106, 0, 24275, 0, -30105, 0, 25313, 0, -30104, 0, 25785, 0, -30103, 0, 26684, 0, -30102, 0, 26680, 0, -30101, 0, 27579, 0, -30100, 0, 29554, 0, -30099, 0, 30906, 0, -30098, 0, 31339, 0, -30097, 0, -30310, 0, -30096, 0, -30254, 0, -30095, 0, -29333, 0, -30094, 0, -28925, 0, -30093, 0, -28435, 0, -30092, 0, -27229, 0, -30091, 0, -26988, 0, -30090, 0, -26775, 0, -30089, 0, 23398, 0, -30088, 0, 23731, 0, -30087, 0, 27005, 0, -30086, 0, -26547, 0, -30085, 0, -26546, 0, -30084, 0, 25499, 0, -30083, 0, 31520, 0, -30082, 0, 27179, 0, -30080, 0, 27263, 0, -30079, 0, 26806, 0, -30078, 0, -25587, 0, -30077, 0, 28511, 0, -30076, 0, 21106, 0, -30075, 0, 21917, 0, -30074, 0, 24688, 0, -30073, 0, 25324, 0, -30072, 0, 27963, 0, -30071, 0, 28167, 0, -30070, 0, 28369, 0, -30069, 0, -31653, 0, -30068, 0, -30448, 0, -30067, 0, -28860, 0, -30066, 0, 19988, 0, -30065, 0, -25543, 0, -30064, 0, 21494, 0, -30063, 0, 26907, 0, -30062, 0, 27194, 0, -30061, 0, -26748, 0, -30060, 0, 26666, 0, -30059, 0, 20828, 0, -30058, 0, 31427, 0, -30057, 0, -31566, 0, -30056, 0, -28196, 0, -30055, 0, -27764, 0, -30054, 0, 22107, 0, -30053, 0, -25304, 0, -30052, 0, 26658, 0, -30051, 0, -31995, 0, -30050, 0, -31695, 0, -30049, 0, 31909, 0, -30048, 0, 21000, 0, -30047, 0, -32059, 0, -30046, 0, 29926, 0, -30045, 0, 20094, 0, -30044, 0, 20355, 0, -30043, 0, 20896, 0, -30042, 0, 23506, 0, -30041, 0, 21002, 0, -30040, 0, 21208, 0, -30039, 0, 21223, 0, -30038, 0, 24059, 0, -30037, 0, 21914, 0, -30036, 0, 22570, 0, -30035, 0, 23014, 0, -30034, 0, 23436, 0, -30033, 0, 23448, 0, -30032, 0, 23515, 0, -30031, 0, 24178, 0, -30030, 0, 24185, 0, -30029, 0, 24739, 0, -30028, 0, 24863, 0, -30027, 0, 24931, 0, -30026, 0, 25022, 0, -30025, 0, 25563, 0, -30024, 0, 25954, 0, -30023, 0, 26577, 0, -30022, 0, 26707, 0, -30021, 0, 26874, 0, -30020, 0, 27454, 0, -30019, 0, 27475, 0, -30018, 0, 27735, 0, -30017, 0, 28450, 0, -30016, 0, 28567, 0, -30015, 0, 28485, 0, -30014, 0, 29872, 0, -30013, 0, 29976, 0, -30012, 0, 30435, 0, -30011, 0, 30475, 0, -30010, 0, 31487, 0, -30009, 0, 31649, 0, -30008, 0, 31777, 0, -30007, 0, 32233, 0, -30006, 0, 32566, 0, -30005, 0, 32752, 0, -30004, 0, -32611, 0, -30003, 0, -32154, 0, -30002, 0, -31842, 0, -30001, 0, -30285, 0, -30000, 0, -30004, 0, -29999, 0, -29525, 0, -29998, 0, -28540, 0, -29997, 0, -27567, 0, -29996, 0, -27245, 0, -29995, 0, -27247, 0, -29994, 0, -27230, 0, -29993, 0, -27035, 0, -29992, 0, -26669, 0, -29991, 0, -26328, 0, -29990, 0, -32232, 0, -29989, 0, 20024, 0, -29988, 0, 21547, 0, -29987, 0, 23736, 0, -29986, 0, 24012, 0, -29985, 0, 29609, 0, -29984, 0, 30284, 0, -29983, 0, 30524, 0, -29982, 0, 23721, 0, -29981, 0, 32747, 0, -29980, 0, -29429, 0, -29979, 0, -26943, 0, -29978, 0, -26607, 0, -29977, 0, -26540, 0, -29976, 0, -26536, 0, -29975, 0, 20225, 0, -29974, 0, 20238, 0, -29973, 0, 21361, 0, -29972, 0, 21916, 0, -29971, 0, 22120, 0, -29970, 0, 22522, 0, -29969, 0, 22855, 0, -29968, 0, 23305, 0, -29967, 0, 23492, 0, -29966, 0, 23696, 0, -29965, 0, 24076, 0, -29964, 0, 24190, 0, -29963, 0, 24524, 0, -29962, 0, 25582, 0, -29961, 0, 26426, 0, -29960, 0, 26071, 0, -29959, 0, 26082, 0, -29958, 0, 26399, 0, -29957, 0, 26827, 0, -29956, 0, 26820, 0, -29888, 0, 27231, 0, -29887, 0, 24112, 0, -29886, 0, 27589, 0, -29885, 0, 27671, 0, -29884, 0, 27773, 0, -29883, 0, 30079, 0, -29882, 0, 31048, 0, -29881, 0, 23395, 0, -29880, 0, 31232, 0, -29879, 0, 32000, 0, -29878, 0, 24509, 0, -29877, 0, -30321, 0, -29876, 0, -30184, 0, -29875, 0, -29516, 0, -29874, 0, -29321, 0, -29873, 0, -28980, 0, -29872, 0, -28899, 0, -29871, 0, -26398, 0, -29870, 0, -26098, 0, -29869, 0, -25796, 0, -29868, 0, 20096, 0, -29867, 0, 20605, 0, -29866, 0, 20736, 0, -29865, 0, 22931, 0, -29864, 0, 23452, 0, -29863, 0, 25135, 0, -29862, 0, 25216, 0, -29861, 0, 25836, 0, -29860, 0, 27450, 0, -29859, 0, 29344, 0, -29858, 0, 30097, 0, -29857, 0, 31047, 0, -29856, 0, 32681, 0, -29855, 0, -30725, 0, -29854, 0, -30020, 0, -29853, 0, -29840, 0, -29852, 0, 25516, 0, -29851, 0, -31798, 0, -29850, 0, -26720, 0, -29849, 0, 21513, 0, -29848, 0, 21507, 0, -29847, 0, 21931, 0, -29846, 0, 26708, 0, -29845, 0, 27224, 0, -29844, 0, -30096, 0, -29843, 0, 30759, 0, -29842, 0, 26485, 0, -29841, 0, -24883, 0, -29840, 0, 21364, 0, -29839, 0, 23458, 0, -29838, 0, -32486, 0, -29837, 0, -31152, 0, -29836, 0, -28666, 0, -29835, 0, 19992, 0, -29834, 0, 20037, 0, -29833, 0, 20167, 0, -29832, 0, 20241, 0, -29831, 0, 21450, 0, -29830, 0, 21560, 0, -29829, 0, 23470, 0, -29828, 0, 24339, 0, -29827, 0, 24613, 0, -29826, 0, 25937, 0, -29824, 0, 26429, 0, -29823, 0, 27714, 0, -29822, 0, 27762, 0, -29821, 0, 27875, 0, -29820, 0, 28792, 0, -29819, 0, 29699, 0, -29818, 0, 31350, 0, -29817, 0, 31406, 0, -29816, 0, 31496, 0, -29815, 0, 32026, 0, -29814, 0, 31998, 0, -29813, 0, 32102, 0, -29812, 0, 26087, 0, -29811, 0, 29275, 0, -29810, 0, 21435, 0, -29809, 0, 23621, 0, -29808, 0, 24040, 0, -29807, 0, 25298, 0, -29806, 0, 25312, 0, -29805, 0, 25369, 0, -29804, 0, 28192, 0, -29803, 0, -31142, 0, -29802, 0, -30159, 0, -29801, 0, -29219, 0, -29800, 0, -27912, 0, -29799, 0, 28417, 0, -29798, 0, 31142, 0, -29797, 0, -25766, 0, -29796, 0, 20136, 0, -29795, 0, 20139, 0, -29794, 0, 20140, 0, -29793, 0, 20379, 0, -29792, 0, 20384, 0, -29791, 0, 20689, 0, -29790, 0, 20807, 0, -29789, 0, 31478, 0, -29788, 0, 20849, 0, -29787, 0, 20982, 0, -29786, 0, 21332, 0, -29785, 0, 21281, 0, -29784, 0, 21375, 0, -29783, 0, 21483, 0, -29782, 0, 21932, 0, -29781, 0, 22659, 0, -29780, 0, 23777, 0, -29779, 0, 24375, 0, -29778, 0, 24394, 0, -29777, 0, 24623, 0, -29776, 0, 24656, 0, -29775, 0, 24685, 0, -29774, 0, 25375, 0, -29773, 0, 25945, 0, -29772, 0, 27211, 0, -29771, 0, 27841, 0, -29770, 0, 29378, 0, -29769, 0, 29421, 0, -29768, 0, 30703, 0, -29767, 0, -32520, 0, -29766, 0, -32507, 0, -29765, 0, -32248, 0, -29764, 0, -31410, 0, -29763, 0, -28425, 0, -29762, 0, -27679, 0, -29761, 0, -26625, 0, -29760, 0, -26281, 0, -29759, 0, -26022, 0, -29758, 0, 20208, 0, -29757, 0, 20957, 0, -29756, 0, 23597, 0, -29755, 0, 26241, 0, -29754, 0, 26989, 0, -29753, 0, 23616, 0, -29752, 0, 26354, 0, -29751, 0, 26997, 0, -29750, 0, 29577, 0, -29749, 0, 26704, 0, -29748, 0, 31873, 0, -29747, 0, 20677, 0, -29746, 0, 21220, 0, -29745, 0, 22343, 0, -29744, 0, 24062, 0, -29743, 0, -27866, 0, -29742, 0, 26020, 0, -29741, 0, 27427, 0, -29740, 0, 27453, 0, -29739, 0, 29748, 0, -29738, 0, 31105, 0, -29737, 0, 31165, 0, -29736, 0, 31563, 0, -29735, 0, 32202, 0, -29734, 0, -32071, 0, -29733, 0, -31796, 0, -29732, 0, -30593, 0, -29731, 0, -30369, 0, -29730, 0, -29895, 0, -29729, 0, -28719, 0, -29728, 0, -28207, 0, -29727, 0, 21535, 0, -29726, 0, -28032, 0, -29725, 0, 20061, 0, -29724, 0, 20534, 0, -29723, 0, 21477, 0, -29722, 0, 21306, 0, -29721, 0, 29399, 0, -29720, 0, 29590, 0, -29719, 0, 30697, 0, -29718, 0, -32026, 0, -29717, 0, -29009, 0, -29716, 0, -26170, 0, -29715, 0, -26168, 0, -29714, 0, -26158, 0, -29713, 0, 20855, 0, -29712, 0, 24858, 0, -29711, 0, -31138, 0, -29710, 0, 21936, 0, -29709, 0, 31354, 0, -29708, 0, 20598, 0, -29707, 0, 23507, 0, -29706, 0, -28601, 0, -29705, 0, -27003, 0, -29704, 0, 20018, 0, -29703, 0, 27355, 0, -29702, 0, -28185, 0, -29701, 0, 23633, 0, -29700, 0, 23624, 0, -29632, 0, 25496, 0, -29631, 0, 31391, 0, -29630, 0, 27795, 0, -29629, 0, -26764, 0, -29628, 0, -28831, 0, -29627, 0, 31402, 0, -29626, 0, 29066, 0, -29625, 0, -27000, 0, -29624, 0, 31874, 0, -29623, 0, 26647, 0, -29622, 0, 32368, 0, -29621, 0, 26705, 0, -29620, 0, -27796, 0, -29619, 0, 21234, 0, -29618, 0, 21531, 0, -29617, 0, -31317, 0, -29616, 0, -30189, 0, -29615, 0, 32676, 0, -29614, 0, -28979, 0, -29613, 0, -28447, 0, -29612, 0, 21350, 0, -29611, 0, -30584, 0, -29610, 0, 31041, 0, -29609, 0, 20418, 0, -29608, 0, 20670, 0, -29607, 0, 21009, 0, -29606, 0, 20804, 0, -29605, 0, 21843, 0, -29604, 0, 22317, 0, -29603, 0, 29674, 0, -29602, 0, 22411, 0, -29601, 0, 22865, 0, -29600, 0, 24418, 0, -29599, 0, 24452, 0, -29598, 0, 24693, 0, -29597, 0, 24950, 0, -29596, 0, 24935, 0, -29595, 0, 25001, 0, -29594, 0, 25522, 0, -29593, 0, 25658, 0, -29592, 0, 25964, 0, -29591, 0, 26223, 0, -29590, 0, 26690, 0, -29589, 0, 28179, 0, -29588, 0, 30054, 0, -29587, 0, 31293, 0, -29586, 0, 31995, 0, -29585, 0, 32076, 0, -29584, 0, 32153, 0, -29583, 0, 32331, 0, -29582, 0, 32619, 0, -29581, 0, -31986, 0, -29580, 0, -31926, 0, -29579, 0, -31027, 0, -29578, 0, -30200, 0, -29577, 0, -30109, 0, -29576, 0, -29850, 0, -29575, 0, -28931, 0, -29574, 0, -26598, 0, -29573, 0, -25201, 0, -29572, 0, -32072, 0, -29571, 0, -28722, 0, -29570, 0, -25624, 0, -29568, 0, 21127, 0, -29567, 0, 25119, 0, -29566, 0, 25731, 0, -29565, 0, 28608, 0, -29564, 0, -26983, 0, -29563, 0, 26689, 0, -29562, 0, 20625, 0, -29561, 0, 27424, 0, -29560, 0, 27770, 0, -29559, 0, 28500, 0, -29558, 0, 31348, 0, -29557, 0, 32080, 0, -29556, 0, -30656, 0, -29555, 0, -30173, 0, -29554, 0, 26376, 0, -29553, 0, 20214, 0, -29552, 0, 20537, 0, -29551, 0, 20518, 0, -29550, 0, 20581, 0, -29549, 0, 20860, 0, -29548, 0, 21048, 0, -29547, 0, 21091, 0, -29546, 0, 21927, 0, -29545, 0, 22287, 0, -29544, 0, 22533, 0, -29543, 0, 23244, 0, -29542, 0, 24314, 0, -29541, 0, 25010, 0, -29540, 0, 25080, 0, -29539, 0, 25331, 0, -29538, 0, 25458, 0, -29537, 0, 26908, 0, -29536, 0, 27177, 0, -29535, 0, 29309, 0, -29534, 0, 29356, 0, -29533, 0, 29486, 0, -29532, 0, 30740, 0, -29531, 0, 30831, 0, -29530, 0, 32121, 0, -29529, 0, 30476, 0, -29528, 0, -32599, 0, -29527, 0, -30325, 0, -29526, 0, -29927, 0, -29525, 0, -29470, 0, -29524, 0, -28974, 0, -29523, 0, -28573, 0, -29522, 0, -27787, 0, -29521, 0, -27014, 0, -29520, 0, -26539, 0, -29519, 0, -26093, 0, -29518, 0, -24968, 0, -29517, 0, 20803, 0, -29516, 0, 21407, 0, -29515, 0, 21427, 0, -29514, 0, 24187, 0, -29513, 0, 24358, 0, -29512, 0, 28187, 0, -29511, 0, 28304, 0, -29510, 0, 29572, 0, -29509, 0, 29694, 0, -29508, 0, 32067, 0, -29507, 0, -32201, 0, -29506, 0, -30208, 0, -29505, 0, -29958, 0, -29504, 0, -27056, 0, -29503, 0, 20046, 0, -29502, 0, 20491, 0, -29501, 0, 21476, 0, -29500, 0, 21628, 0, -29499, 0, 22266, 0, -29498, 0, 22993, 0, -29497, 0, 23396, 0, -29496, 0, 24049, 0, -29495, 0, 24235, 0, -29494, 0, 24359, 0, -29493, 0, 25144, 0, -29492, 0, 25925, 0, -29491, 0, 26543, 0, -29490, 0, 28246, 0, -29489, 0, 29392, 0, -29488, 0, 31946, 0, -29487, 0, -30540, 0, -29486, 0, -32607, 0, -29485, 0, -32543, 0, -29484, 0, -31760, 0, -29483, 0, -31154, 0, -29482, 0, -30073, 0, -29481, 0, -29208, 0, -29480, 0, -28105, 0, -29479, 0, -26937, 0, -29478, 0, -26521, 0, -29477, 0, -24813, 0, -29476, 0, 20116, 0, -29475, 0, 20114, 0, -29474, 0, 20237, 0, -29473, 0, 21320, 0, -29472, 0, 21577, 0, -29471, 0, 21566, 0, -29470, 0, 23087, 0, -29469, 0, 24460, 0, -29468, 0, 24481, 0, -29467, 0, 24735, 0, -29466, 0, 26791, 0, -29465, 0, 27278, 0, -29464, 0, 29786, 0, -29463, 0, 30849, 0, -29462, 0, -30050, 0, -29461, 0, -30044, 0, -29460, 0, -29833, 0, -29459, 0, -28272, 0, -29458, 0, 20062, 0, -29457, 0, -25655, 0, -29456, 0, 20132, 0, -29455, 0, 20348, 0, -29454, 0, 20399, 0, -29453, 0, 20505, 0, -29452, 0, 20502, 0, -29451, 0, 20809, 0, -29450, 0, 20844, 0, -29449, 0, 21151, 0, -29448, 0, 21177, 0, -29447, 0, 21246, 0, -29446, 0, 21402, 0, -29445, 0, 21475, 0, -29444, 0, 21521, 0, -29376, 0, 21518, 0, -29375, 0, 21897, 0, -29374, 0, 22353, 0, -29373, 0, 22434, 0, -29372, 0, 22909, 0, -29371, 0, 23380, 0, -29370, 0, 23389, 0, -29369, 0, 23439, 0, -29368, 0, 24037, 0, -29367, 0, 24039, 0, -29366, 0, 24055, 0, -29365, 0, 24184, 0, -29364, 0, 24195, 0, -29363, 0, 24218, 0, -29362, 0, 24247, 0, -29361, 0, 24344, 0, -29360, 0, 24658, 0, -29359, 0, 24908, 0, -29358, 0, 25239, 0, -29357, 0, 25304, 0, -29356, 0, 25511, 0, -29355, 0, 25915, 0, -29354, 0, 26114, 0, -29353, 0, 26179, 0, -29352, 0, 26356, 0, -29351, 0, 26477, 0, -29350, 0, 26657, 0, -29349, 0, 26775, 0, -29348, 0, 27083, 0, -29347, 0, 27743, 0, -29346, 0, 27946, 0, -29345, 0, 28009, 0, -29344, 0, 28207, 0, -29343, 0, 28317, 0, -29342, 0, 30002, 0, -29341, 0, 30343, 0, -29340, 0, 30828, 0, -29339, 0, 31295, 0, -29338, 0, 31968, 0, -29337, 0, 32005, 0, -29336, 0, 32024, 0, -29335, 0, 32094, 0, -29334, 0, 32177, 0, -29333, 0, -32747, 0, -29332, 0, -32765, 0, -29331, 0, -32593, 0, -29330, 0, -32591, 0, -29329, 0, -32428, 0, -29328, 0, -32369, 0, -29327, 0, -32214, 0, -29326, 0, -31918, 0, -29325, 0, -30644, 0, -29324, 0, -30623, 0, -29323, 0, -29925, 0, -29322, 0, -29534, 0, -29321, 0, -29444, 0, -29320, 0, -28470, 0, -29319, 0, -28299, 0, -29318, 0, -28047, 0, -29317, 0, 30783, 0, -29316, 0, -27908, 0, -29315, 0, -27228, 0, -29314, 0, -27059, 0, -29312, 0, -26619, 0, -29311, 0, -26215, 0, -29310, 0, -25896, 0, -29309, 0, -25285, 0, -29308, 0, 21083, 0, -29307, 0, 21163, 0, -29306, 0, 21495, 0, -29305, 0, 21512, 0, -29304, 0, 22741, 0, -29303, 0, 25335, 0, -29302, 0, 28640, 0, -29301, 0, -29590, 0, -29300, 0, -28833, 0, -29299, 0, -24903, 0, -29298, 0, 20811, 0, -29297, 0, 21051, 0, -29296, 0, 21578, 0, -29295, 0, 22269, 0, -29294, 0, 31296, 0, -29293, 0, -28297, 0, -29292, 0, -25248, 0, -29291, 0, -24878, 0, -29290, 0, 29508, 0, -29289, 0, 28425, 0, -29288, 0, -32400, 0, -29287, 0, 29969, 0, -29286, 0, 24573, 0, -29285, 0, 24794, 0, -29284, 0, -25944, 0, -29283, 0, 29403, 0, -29282, 0, -28740, 0, -29281, 0, 27492, 0, -29280, 0, -26621, 0, -29279, 0, 20170, 0, -29278, 0, 22256, 0, -29277, 0, 22372, 0, -29276, 0, 22718, 0, -29275, 0, 23130, 0, -29274, 0, 24680, 0, -29273, 0, 25031, 0, -29272, 0, 26127, 0, -29271, 0, 26118, 0, -29270, 0, 26681, 0, -29269, 0, 26801, 0, -29268, 0, 28151, 0, -29267, 0, 30165, 0, -29266, 0, 32058, 0, -29265, 0, -32146, 0, -29264, 0, -25790, 0, -29263, 0, 20123, 0, -29262, 0, 20304, 0, -29261, 0, 21449, 0, -29260, 0, 21766, 0, -29259, 0, 23919, 0, -29258, 0, 24038, 0, -29257, 0, 24046, 0, -29256, 0, 26619, 0, -29255, 0, 27801, 0, -29254, 0, 29811, 0, -29253, 0, 30722, 0, -29252, 0, -30128, 0, -29251, 0, -27754, 0, -29250, 0, -30497, 0, -29249, 0, 22352, 0, -29248, 0, 24231, 0, -29247, 0, 25387, 0, -29246, 0, 20661, 0, -29245, 0, 20652, 0, -29244, 0, 20877, 0, -29243, 0, 26368, 0, -29242, 0, 21705, 0, -29241, 0, 22622, 0, -29240, 0, 22971, 0, -29239, 0, 23472, 0, -29238, 0, 24425, 0, -29237, 0, 25165, 0, -29236, 0, 25505, 0, -29235, 0, 26685, 0, -29234, 0, 27507, 0, -29233, 0, 28168, 0, -29232, 0, 28797, 0, -29231, 0, -28217, 0, -29230, 0, 29312, 0, -29229, 0, 30741, 0, -29228, 0, 30758, 0, -29227, 0, 31085, 0, -29226, 0, 25998, 0, -29225, 0, 32048, 0, -29224, 0, -31780, 0, -29223, 0, -30527, 0, -29222, 0, -28919, 0, -29221, 0, -26981, 0, -29220, 0, 21092, 0, -29219, 0, 22312, 0, -29218, 0, 26448, 0, -29217, 0, 32618, 0, -29216, 0, -29535, 0, -29215, 0, 20916, 0, -29214, 0, 22338, 0, -29213, 0, -27094, 0, -29212, 0, 22586, 0, -29211, 0, 27018, 0, -29210, 0, -32588, 0, -29209, 0, 21682, 0, -29208, 0, 23822, 0, -29207, 0, 22524, 0, -29206, 0, 30869, 0, -29205, 0, -25094, 0, -29204, 0, 20316, 0, -29203, 0, 21066, 0, -29202, 0, 21643, 0, -29201, 0, 25662, 0, -29200, 0, 26152, 0, -29199, 0, 26388, 0, -29198, 0, 26613, 0, -29197, 0, 31364, 0, -29196, 0, 31574, 0, -29195, 0, 32034, 0, -29194, 0, -27857, 0, -29193, 0, 26716, 0, -29192, 0, -25683, 0, -29191, 0, 31545, 0, -29190, 0, 21273, 0, -29189, 0, 20874, 0, -29188, 0, 21047, 0, -29120, 0, 23519, 0, -29119, 0, 25334, 0, -29118, 0, 25774, 0, -29117, 0, 25830, 0, -29116, 0, 26413, 0, -29115, 0, 27578, 0, -29114, 0, -31319, 0, -29113, 0, -26927, 0, -29112, 0, 30352, 0, -29111, 0, -25642, 0, -29110, 0, 25420, 0, -29109, 0, -27898, 0, -29108, 0, -25685, 0, -29107, 0, 30399, 0, -29106, 0, 26194, 0, -29105, 0, 19977, 0, -29104, 0, 20632, 0, -29103, 0, 21442, 0, -29102, 0, 23665, 0, -29101, 0, 24808, 0, -29100, 0, 25746, 0, -29099, 0, 25955, 0, -29098, 0, 26719, 0, -29097, 0, 29158, 0, -29096, 0, 29642, 0, -29095, 0, 29987, 0, -29094, 0, 31639, 0, -29093, 0, 32386, 0, -29092, 0, -31083, 0, -29091, 0, -29821, 0, -29090, 0, -29477, 0, -29089, 0, -28296, 0, -29088, 0, -26352, 0, -29087, 0, 26028, 0, -29086, 0, 26283, 0, -29085, 0, 27531, 0, -29084, 0, 20181, 0, -29083, 0, 20180, 0, -29082, 0, 20282, 0, -29081, 0, 20351, 0, -29080, 0, 21050, 0, -29079, 0, 21496, 0, -29078, 0, 21490, 0, -29077, 0, 21987, 0, -29076, 0, 22235, 0, -29075, 0, 22763, 0, -29074, 0, 22987, 0, -29073, 0, 22985, 0, -29072, 0, 23039, 0, -29071, 0, 23376, 0, -29070, 0, 23629, 0, -29069, 0, 24066, 0, -29068, 0, 24107, 0, -29067, 0, 24535, 0, -29066, 0, 24605, 0, -29065, 0, 25351, 0, -29064, 0, 25903, 0, -29063, 0, 23388, 0, -29062, 0, 26031, 0, -29061, 0, 26045, 0, -29060, 0, 26088, 0, -29059, 0, 26525, 0, -29058, 0, 27490, 0, -29056, 0, 27515, 0, -29055, 0, 27663, 0, -29054, 0, 29509, 0, -29053, 0, 31049, 0, -29052, 0, 31169, 0, -29051, 0, 31992, 0, -29050, 0, 32025, 0, -29049, 0, 32043, 0, -29048, 0, -32606, 0, -29047, 0, -32510, 0, -29046, 0, -32269, 0, -29045, 0, -30314, 0, -29044, 0, -30114, 0, -29043, 0, -30103, 0, -29042, 0, -30106, 0, -29041, 0, -30068, 0, -29040, 0, -29970, 0, -29039, 0, -29497, 0, -29038, 0, -29476, 0, -29037, 0, -26932, 0, -29036, 0, -26372, 0, -29035, 0, 27503, 0, -29034, 0, 20107, 0, -29033, 0, 20284, 0, -29032, 0, 20365, 0, -29031, 0, 20816, 0, -29030, 0, 23383, 0, -29029, 0, 23546, 0, -29028, 0, 24904, 0, -29027, 0, 25345, 0, -29026, 0, 26178, 0, -29025, 0, 27425, 0, -29024, 0, 28363, 0, -29023, 0, 27835, 0, -29022, 0, 29246, 0, -29021, 0, 29885, 0, -29020, 0, 30164, 0, -29019, 0, 30913, 0, -29018, 0, 31034, 0, -29017, 0, -32756, 0, -29016, 0, -32717, 0, -29015, 0, -32278, 0, -29014, 0, -31596, 0, -29013, 0, -28770, 0, -29012, 0, 27728, 0, -29011, 0, -24961, 0, -29010, 0, 24335, 0, -29009, 0, -29864, 0, -29008, 0, -25301, 0, -29007, 0, 31482, 0, -29006, 0, -28936, 0, -29005, 0, 23437, 0, -29004, 0, -26901, 0, -29003, 0, 19971, 0, -29002, 0, 21489, 0, -29001, 0, 22519, 0, -29000, 0, 22833, 0, -28999, 0, 23241, 0, -28998, 0, 23460, 0, -28997, 0, 24713, 0, -28996, 0, 28287, 0, -28995, 0, 28422, 0, -28994, 0, 30142, 0, -28993, 0, -29462, 0, -28992, 0, 23455, 0, -28991, 0, -31488, 0, -28990, 0, 31712, 0, -28989, 0, 20594, 0, -28988, 0, 26612, 0, -28987, 0, -32099, 0, -28986, 0, 23649, 0, -28985, 0, -31414, 0, -28984, 0, 32286, 0, -28983, 0, -32242, 0, -28982, 0, 20889, 0, -28981, 0, 23556, 0, -28980, 0, 25448, 0, -28979, 0, -29338, 0, -28978, 0, 26012, 0, -28977, 0, 29038, 0, -28976, 0, 31038, 0, -28975, 0, 32023, 0, -28974, 0, -32763, 0, -28973, 0, -29923, 0, -28972, 0, -28982, 0, -28971, 0, -28562, 0, -28970, 0, -31033, 0, -28969, 0, -28502, 0, -28968, 0, 20511, 0, -28967, 0, 21242, 0, -28966, 0, 23610, 0, -28965, 0, 26451, 0, -28964, 0, 28796, 0, -28963, 0, 29237, 0, -28962, 0, -28340, 0, -28961, 0, -28216, 0, -28960, 0, -27861, 0, -28959, 0, -32027, 0, -28958, 0, 23490, 0, -28957, 0, 24369, 0, -28956, 0, 24825, 0, -28955, 0, 20027, 0, -28954, 0, 21462, 0, -28953, 0, 23432, 0, -28952, 0, 25163, 0, -28951, 0, 26417, 0, -28950, 0, 27530, 0, -28949, 0, 29417, 0, -28948, 0, 29664, 0, -28947, 0, 31278, 0, -28946, 0, -32405, 0, -28945, 0, -29277, 0, -28944, 0, -28334, 0, -28943, 0, -26218, 0, -28942, 0, 20754, 0, -28941, 0, 21463, 0, -28940, 0, 21610, 0, -28939, 0, 23551, 0, -28938, 0, 25480, 0, -28937, 0, 27193, 0, -28936, 0, 32172, 0, -28935, 0, -26880, 0, -28934, 0, 22234, 0, -28933, 0, 21454, 0, -28932, 0, 21608, 0, -28864, 0, 23447, 0, -28863, 0, 23601, 0, -28862, 0, 24030, 0, -28861, 0, 20462, 0, -28860, 0, 24833, 0, -28859, 0, 25342, 0, -28858, 0, 27954, 0, -28857, 0, 31168, 0, -28856, 0, 31179, 0, -28855, 0, 32066, 0, -28854, 0, 32333, 0, -28853, 0, 32722, 0, -28852, 0, -32275, 0, -28851, 0, -32225, 0, -28850, 0, -31600, 0, -28849, 0, -30650, 0, -28848, 0, -30350, 0, -28847, 0, -29808, 0, -28846, 0, -29068, 0, -28845, 0, -28881, 0, -28844, 0, -28623, 0, -28843, 0, -28341, 0, -28842, 0, -28308, 0, -28841, 0, -26938, 0, -28840, 0, -28260, 0, -28839, 0, 20160, 0, -28838, 0, 20303, 0, -28837, 0, 20805, 0, -28836, 0, 21313, 0, -28835, 0, 24467, 0, -28834, 0, 25102, 0, -28833, 0, 26580, 0, -28832, 0, 27713, 0, -28831, 0, 28171, 0, -28830, 0, 29539, 0, -28829, 0, 32294, 0, -28828, 0, -28211, 0, -28827, 0, -28029, 0, -28826, 0, 21460, 0, -28825, 0, 22809, 0, -28824, 0, 23487, 0, -28823, 0, 28113, 0, -28822, 0, 31069, 0, -28821, 0, 32302, 0, -28820, 0, 31899, 0, -28819, 0, 22654, 0, -28818, 0, 29087, 0, -28817, 0, 20986, 0, -28816, 0, -30637, 0, -28815, 0, -28688, 0, -28814, 0, 20426, 0, -28813, 0, 23803, 0, -28812, 0, 26149, 0, -28811, 0, 30636, 0, -28810, 0, 31459, 0, -28809, 0, -32228, 0, -28808, 0, -26113, 0, -28807, 0, 20934, 0, -28806, 0, 24490, 0, -28805, 0, 26092, 0, -28804, 0, 26991, 0, -28803, 0, 27529, 0, -28802, 0, 28147, 0, -28800, 0, 28310, 0, -28799, 0, 28516, 0, -28798, 0, 30462, 0, -28797, 0, 32020, 0, -28796, 0, 24033, 0, -28795, 0, -28555, 0, -28794, 0, -28281, 0, -28793, 0, -26618, 0, -28792, 0, 20966, 0, -28791, 0, 21021, 0, -28790, 0, 25152, 0, -28789, 0, 26257, 0, -28788, 0, 26329, 0, -28787, 0, 28186, 0, -28786, 0, 24246, 0, -28785, 0, 32210, 0, -28784, 0, 32626, 0, -28783, 0, 26360, 0, -28782, 0, -31313, 0, -28781, 0, -31241, 0, -28780, 0, -29960, 0, -28779, 0, 21161, 0, -28778, 0, 21465, 0, -28777, 0, 22899, 0, -28776, 0, 24207, 0, -28775, 0, 24464, 0, -28774, 0, 24661, 0, -28773, 0, -27932, 0, -28772, 0, -27036, 0, -28771, 0, 20663, 0, -28770, 0, 20767, 0, -28769, 0, 21213, 0, -28768, 0, 21280, 0, -28767, 0, 21319, 0, -28766, 0, 21484, 0, -28765, 0, 21736, 0, -28764, 0, 21830, 0, -28763, 0, 21809, 0, -28762, 0, 22039, 0, -28761, 0, 22888, 0, -28760, 0, 22974, 0, -28759, 0, 23100, 0, -28758, 0, 23477, 0, -28757, 0, 23558, 0, -28756, 0, 23567, 0, -28755, 0, 23569, 0, -28754, 0, 23578, 0, -28753, 0, 24196, 0, -28752, 0, 24202, 0, -28751, 0, 24288, 0, -28750, 0, 24432, 0, -28749, 0, 25215, 0, -28748, 0, 25220, 0, -28747, 0, 25307, 0, -28746, 0, 25484, 0, -28745, 0, 25463, 0, -28744, 0, 26119, 0, -28743, 0, 26124, 0, -28742, 0, 26157, 0, -28741, 0, 26230, 0, -28740, 0, 26494, 0, -28739, 0, 26786, 0, -28738, 0, 27167, 0, -28737, 0, 27189, 0, -28736, 0, 27836, 0, -28735, 0, 28040, 0, -28734, 0, 28169, 0, -28733, 0, 28248, 0, -28732, 0, 28988, 0, -28731, 0, 28966, 0, -28730, 0, 29031, 0, -28729, 0, 30151, 0, -28728, 0, 30465, 0, -28727, 0, 30813, 0, -28726, 0, 30977, 0, -28725, 0, 31077, 0, -28724, 0, 31216, 0, -28723, 0, 31456, 0, -28722, 0, 31505, 0, -28721, 0, 31911, 0, -28720, 0, 32057, 0, -28719, 0, -32618, 0, -28718, 0, -31786, 0, -28717, 0, -31605, 0, -28716, 0, -31415, 0, -28715, 0, -30627, 0, -28714, 0, -30477, 0, -28713, 0, -30177, 0, -28712, 0, -30148, 0, -28711, 0, -30124, 0, -28710, 0, -30093, 0, -28709, 0, -29599, 0, -28708, 0, -29474, 0, -28707, 0, -28252, 0, -28706, 0, -28058, 0, -28705, 0, -27778, 0, -28704, 0, -27624, 0, -28703, 0, -26980, 0, -28702, 0, -26728, 0, -28701, 0, 19978, 0, -28700, 0, 19976, 0, -28699, 0, 19998, 0, -28698, 0, 20055, 0, -28697, 0, 20887, 0, -28696, 0, 21104, 0, -28695, 0, 22478, 0, -28694, 0, 22580, 0, -28693, 0, 22732, 0, -28692, 0, 23330, 0, -28691, 0, 24120, 0, -28690, 0, 24773, 0, -28689, 0, 25854, 0, -28688, 0, 26465, 0, -28687, 0, 26454, 0, -28686, 0, 27972, 0, -28685, 0, 29366, 0, -28684, 0, 30067, 0, -28683, 0, 31331, 0, -28682, 0, -31560, 0, -28681, 0, -29838, 0, -28680, 0, -28232, 0, -28679, 0, -27872, 0, -28678, 0, 22065, 0, -28677, 0, 22516, 0, -28676, 0, -26370, 0, -28608, 0, 25325, 0, -28607, 0, 26893, 0, -28606, 0, 27542, 0, -28605, 0, 29165, 0, -28604, 0, 32340, 0, -28603, 0, -32649, 0, -28602, 0, -32142, 0, -28601, 0, -30234, 0, -28600, 0, -26401, 0, -28599, 0, -30891, 0, -28598, 0, -28751, 0, -28597, 0, 23611, 0, -28596, 0, 20280, 0, -28595, 0, 20449, 0, -28594, 0, 20405, 0, -28593, 0, 21767, 0, -28592, 0, 23072, 0, -28591, 0, 23517, 0, -28590, 0, 23529, 0, -28589, 0, 24515, 0, -28588, 0, 24910, 0, -28587, 0, 25391, 0, -28586, 0, 26032, 0, -28585, 0, 26187, 0, -28584, 0, 26862, 0, -28583, 0, 27035, 0, -28582, 0, 28024, 0, -28581, 0, 28145, 0, -28580, 0, 30003, 0, -28579, 0, 30137, 0, -28578, 0, 30495, 0, -28577, 0, 31070, 0, -28576, 0, 31206, 0, -28575, 0, 32051, 0, -28574, 0, -32285, 0, -28573, 0, -32081, 0, -28572, 0, -31318, 0, -28571, 0, -30294, 0, -28570, 0, -30150, 0, -28569, 0, -29013, 0, -28568, 0, -28773, 0, -28567, 0, -28622, 0, -28566, 0, -28195, 0, -28565, 0, -26873, 0, -28564, 0, 20154, 0, -28563, 0, 20161, 0, -28562, 0, 20995, 0, -28561, 0, 22645, 0, -28560, 0, 22764, 0, -28559, 0, 23563, 0, -28558, 0, 29978, 0, -28557, 0, 23613, 0, -28556, 0, -32434, 0, -28555, 0, -30198, 0, -28554, 0, -28731, 0, -28553, 0, -27037, 0, -28552, 0, -26771, 0, -28551, 0, 31525, 0, -28550, 0, -30001, 0, -28549, 0, -26616, 0, -28548, 0, -28318, 0, -28547, 0, 22259, 0, -28546, 0, 21416, 0, -28544, 0, -28649, 0, -28543, 0, 21561, 0, -28542, 0, 22402, 0, -28541, 0, 24101, 0, -28540, 0, 25512, 0, -28539, 0, 27700, 0, -28538, 0, 28810, 0, -28537, 0, 30561, 0, -28536, 0, 31883, 0, -28535, 0, 32736, 0, -28534, 0, -30608, 0, -28533, 0, -28606, 0, -28532, 0, -28332, 0, -28531, 0, -27888, 0, -28530, 0, -27880, 0, -28529, 0, -26993, 0, -28528, 0, 29790, 0, -28527, 0, -25916, 0, -28526, 0, 23815, 0, -28525, 0, 23913, 0, -28524, 0, 25968, 0, -28523, 0, 26530, 0, -28522, 0, -29272, 0, -28521, 0, -26917, 0, -28520, 0, 25454, 0, -28519, 0, 26441, 0, -28518, 0, 26905, 0, -28517, 0, -31803, 0, -28516, 0, -26601, 0, -28515, 0, -26944, 0, -28514, 0, -30466, 0, -28513, 0, 28548, 0, -28512, 0, 25722, 0, -28511, 0, 23544, 0, -28510, 0, 19990, 0, -28509, 0, 28716, 0, -28508, 0, 30045, 0, -28507, 0, 26159, 0, -28506, 0, 20932, 0, -28505, 0, 21046, 0, -28504, 0, 21218, 0, -28503, 0, 22995, 0, -28502, 0, 24449, 0, -28501, 0, 24615, 0, -28500, 0, 25104, 0, -28499, 0, 25919, 0, -28498, 0, 25972, 0, -28497, 0, 26143, 0, -28496, 0, 26228, 0, -28495, 0, 26866, 0, -28494, 0, 26646, 0, -28493, 0, 27491, 0, -28492, 0, 28165, 0, -28491, 0, 29298, 0, -28490, 0, 29983, 0, -28489, 0, 30427, 0, -28488, 0, 31934, 0, -28487, 0, -32682, 0, -28486, 0, 22768, 0, -28485, 0, -30467, 0, -28484, 0, -30337, 0, -28483, 0, -30048, 0, -28482, 0, -30061, 0, -28481, 0, -30005, 0, -28480, 0, -28643, 0, -28479, 0, -28270, 0, -28478, 0, -26798, 0, -28477, 0, -26791, 0, -28476, 0, 25993, 0, -28475, 0, 31246, 0, -28474, 0, -32506, 0, -28473, 0, -26949, 0, -28472, 0, 24109, 0, -28471, 0, 24796, 0, -28470, 0, 25114, 0, -28469, 0, 26021, 0, -28468, 0, 26132, 0, -28467, 0, 26512, 0, -28466, 0, 30707, 0, -28465, 0, 31309, 0, -28464, 0, 31821, 0, -28463, 0, 32318, 0, -28462, 0, -32502, 0, -28461, 0, -29524, 0, -28460, 0, -29340, 0, -28459, 0, -29215, 0, -28458, 0, -29089, 0, -28457, 0, 30889, 0, -28456, 0, 20999, 0, -28455, 0, 25305, 0, -28454, 0, 25509, 0, -28453, 0, 25666, 0, -28452, 0, 25240, 0, -28451, 0, -30163, 0, -28450, 0, 31363, 0, -28449, 0, 31680, 0, -28448, 0, -30036, 0, -28447, 0, -26902, 0, -28446, 0, 32118, 0, -28445, 0, -32244, 0, -28444, 0, -30903, 0, -28443, 0, 20185, 0, -28442, 0, 20808, 0, -28441, 0, 21315, 0, -28440, 0, 21344, 0, -28439, 0, 23459, 0, -28438, 0, 23554, 0, -28437, 0, 23574, 0, -28436, 0, 24029, 0, -28435, 0, 25126, 0, -28434, 0, 25159, 0, -28433, 0, 25776, 0, -28432, 0, 26643, 0, -28431, 0, 26676, 0, -28430, 0, 27849, 0, -28429, 0, 27973, 0, -28428, 0, 27927, 0, -28427, 0, 26579, 0, -28426, 0, 28508, 0, -28425, 0, 29006, 0, -28424, 0, 29053, 0, -28423, 0, 26059, 0, -28422, 0, 31359, 0, -28421, 0, 31661, 0, -28420, 0, 32218, 0, -28352, 0, 32330, 0, -28351, 0, 32680, 0, -28350, 0, -32390, 0, -28349, 0, -32229, 0, -28348, 0, -32199, 0, -28347, 0, -31322, 0, -28346, 0, -30098, 0, -28345, 0, -29490, 0, -28344, 0, -29195, 0, -28343, 0, -28552, 0, -28342, 0, -28553, 0, -28341, 0, -27987, 0, -28340, 0, -28015, 0, -28339, 0, -27261, 0, -28338, 0, -25682, 0, -28337, 0, 21069, 0, -28336, 0, 21892, 0, -28335, 0, 28472, 0, -28334, 0, 28982, 0, -28333, 0, 20840, 0, -28332, 0, 31109, 0, -28331, 0, 32341, 0, -28330, 0, -32333, 0, -28329, 0, 31950, 0, -28328, 0, 22092, 0, -28327, 0, 22609, 0, -28326, 0, 23720, 0, -28325, 0, 25514, 0, -28324, 0, 26366, 0, -28323, 0, 26365, 0, -28322, 0, 26970, 0, -28321, 0, 29401, 0, -28320, 0, 30095, 0, -28319, 0, 30094, 0, -28318, 0, 30990, 0, -28317, 0, 31062, 0, -28316, 0, 31199, 0, -28315, 0, 31895, 0, -28314, 0, 32032, 0, -28313, 0, 32068, 0, -28312, 0, -31225, 0, -28311, 0, -30156, 0, -28310, 0, -27077, 0, -28309, 0, -28575, 0, -28308, 0, -24800, 0, -28307, 0, 20711, 0, -28306, 0, 21109, 0, -28305, 0, 21452, 0, -28304, 0, 21474, 0, -28303, 0, 20489, 0, -28302, 0, 21930, 0, -28301, 0, 22766, 0, -28300, 0, 22863, 0, -28299, 0, 29245, 0, -28298, 0, 23435, 0, -28297, 0, 23652, 0, -28296, 0, 21277, 0, -28295, 0, 24803, 0, -28294, 0, 24819, 0, -28293, 0, 25436, 0, -28292, 0, 25475, 0, -28291, 0, 25407, 0, -28290, 0, 25531, 0, -28288, 0, 25805, 0, -28287, 0, 26089, 0, -28286, 0, 26361, 0, -28285, 0, 24035, 0, -28284, 0, 27085, 0, -28283, 0, 27133, 0, -28282, 0, 28437, 0, -28281, 0, 29157, 0, -28280, 0, 20105, 0, -28279, 0, 30185, 0, -28278, 0, 30456, 0, -28277, 0, 31379, 0, -28276, 0, 31967, 0, -28275, 0, 32207, 0, -28274, 0, 32156, 0, -28273, 0, -32671, 0, -28272, 0, -31927, 0, -28271, 0, -31912, 0, -28270, 0, -31636, 0, -28269, 0, -31556, 0, -28268, 0, -31237, 0, -28267, 0, -30523, 0, -28266, 0, -29328, 0, -28265, 0, -28671, 0, -28264, 0, -28563, 0, -28263, 0, -27753, 0, -28262, 0, -26852, 0, -28261, 0, -26094, 0, -28260, 0, 20687, 0, -28259, 0, 22679, 0, -28258, 0, 24974, 0, -28257, 0, -32301, 0, -28256, 0, -31435, 0, -28255, 0, -29432, 0, -28254, 0, -28640, 0, -28253, 0, 20419, 0, -28252, 0, 20596, 0, -28251, 0, 21063, 0, -28250, 0, 21363, 0, -28249, 0, 24687, 0, -28248, 0, 25417, 0, -28247, 0, 26463, 0, -28246, 0, 28204, 0, -28245, 0, -29261, 0, -28244, 0, -28641, 0, -28243, 0, 20439, 0, -28242, 0, 23646, 0, -28241, 0, -29494, 0, -28240, 0, 26063, 0, -28239, 0, 32154, 0, -28238, 0, 21330, 0, -28237, 0, -30570, 0, -28236, 0, 20854, 0, -28235, 0, 25539, 0, -28234, 0, 23384, 0, -28233, 0, 23403, 0, -28232, 0, 23562, 0, -28231, 0, 25613, 0, -28230, 0, 26449, 0, -28229, 0, -28580, 0, -28228, 0, 20182, 0, -28227, 0, 22810, 0, -28226, 0, 22826, 0, -28225, 0, 27760, 0, -28224, 0, -30127, 0, -28223, 0, 21822, 0, -28222, 0, 22549, 0, -28221, 0, 22949, 0, -28220, 0, 24816, 0, -28219, 0, 25171, 0, -28218, 0, 26561, 0, -28217, 0, -32203, 0, -28216, 0, 26965, 0, -28215, 0, -27072, 0, -28214, 0, -26172, 0, -28213, 0, -26072, 0, -28212, 0, 20307, 0, -28211, 0, 22534, 0, -28210, 0, 23550, 0, -28209, 0, -32752, 0, -28208, 0, 23729, 0, -28207, 0, 24111, 0, -28206, 0, 24453, 0, -28205, 0, 24608, 0, -28204, 0, 24907, 0, -28203, 0, 25140, 0, -28202, 0, 26367, 0, -28201, 0, 27888, 0, -28200, 0, 28382, 0, -28199, 0, -32562, 0, -28198, 0, -32385, 0, -28197, 0, -32044, 0, -28196, 0, -30581, 0, -28195, 0, -29512, 0, -28194, 0, -28672, 0, -28193, 0, -28626, 0, -28192, 0, -26998, 0, -28191, 0, -24869, 0, -28190, 0, -25637, 0, -28189, 0, 20195, 0, -28188, 0, 21488, 0, -28187, 0, 22823, 0, -28186, 0, 31532, 0, -28185, 0, -28275, 0, -28184, 0, -26548, 0, -28183, 0, -25095, 0, -28182, 0, 28381, 0, -28181, 0, 28711, 0, -28180, 0, 21331, 0, -28179, 0, 21828, 0, -28178, 0, 23429, 0, -28177, 0, 25176, 0, -28176, 0, 25246, 0, -28175, 0, 25299, 0, -28174, 0, 27810, 0, -28173, 0, 28655, 0, -28172, 0, 29730, 0, -28171, 0, -30185, 0, -28170, 0, -27592, 0, -28169, 0, 28609, 0, -28168, 0, -29954, 0, -28167, 0, -31944, 0, -28166, 0, 20967, 0, -28165, 0, -30984, 0, -28164, 0, 21482, 0, -28096, 0, 21481, 0, -28095, 0, 20294, 0, -28094, 0, -28588, 0, -28093, 0, -28752, 0, -28092, 0, 22890, 0, -28091, 0, -32463, 0, -28090, 0, 24061, 0, -28089, 0, 31466, 0, -28088, 0, -28737, 0, -28087, 0, 26842, 0, -28086, 0, -29641, 0, -28085, 0, 29432, 0, -28084, 0, -25528, 0, -28083, 0, 27197, 0, -28082, 0, -30032, 0, -28081, 0, 20025, 0, -28080, 0, 21336, 0, -28079, 0, 22022, 0, -28078, 0, 22374, 0, -28077, 0, 25285, 0, -28076, 0, 25506, 0, -28075, 0, 26086, 0, -28074, 0, 27470, 0, -28073, 0, 28129, 0, -28072, 0, 28251, 0, -28071, 0, 28845, 0, -28070, 0, 30701, 0, -28069, 0, 31471, 0, -28068, 0, 31658, 0, -28067, 0, 32187, 0, -28066, 0, -32707, 0, -28065, 0, -32570, 0, -28064, 0, -31029, 0, -28063, 0, -30059, 0, -28062, 0, -27813, 0, -28061, 0, 22243, 0, -28060, 0, 22727, 0, -28059, 0, 24382, 0, -28058, 0, 26029, 0, -28057, 0, 26262, 0, -28056, 0, 27264, 0, -28055, 0, 27573, 0, -28054, 0, 30007, 0, -28053, 0, -30009, 0, -28052, 0, 20516, 0, -28051, 0, 30693, 0, -28050, 0, 22320, 0, -28049, 0, 24347, 0, -28048, 0, 24677, 0, -28047, 0, 26234, 0, -28046, 0, 27744, 0, -28045, 0, 30196, 0, -28044, 0, 31258, 0, -28043, 0, 32622, 0, -28042, 0, -32268, 0, -28041, 0, -30952, 0, -28040, 0, -28603, 0, -28039, 0, -26189, 0, -28038, 0, 31689, 0, -28037, 0, 30044, 0, -28036, 0, 31481, 0, -28035, 0, 31569, 0, -28034, 0, -31548, 0, -28032, 0, -28656, 0, -28031, 0, 31209, 0, -28030, 0, 31378, 0, -28029, 0, -31946, 0, -28028, 0, 23265, 0, -28027, 0, 30528, 0, -28026, 0, 20013, 0, -28025, 0, 20210, 0, -28024, 0, 23449, 0, -28023, 0, 24544, 0, -28022, 0, 25277, 0, -28021, 0, 26172, 0, -28020, 0, 26609, 0, -28019, 0, 27880, 0, -28018, 0, -31125, 0, -28017, 0, -30601, 0, -28016, 0, -30149, 0, -28015, 0, -28338, 0, -28014, 0, -27917, 0, -28013, 0, -26160, 0, -28012, 0, 27159, 0, -28011, 0, 28710, 0, -28010, 0, 29482, 0, -28009, 0, -32025, 0, -28008, 0, -31657, 0, -28007, 0, -29521, 0, -28006, 0, 19969, 0, -28005, 0, 20806, 0, -28004, 0, 20939, 0, -28003, 0, 21899, 0, -28002, 0, 23541, 0, -28001, 0, 24086, 0, -28000, 0, 24115, 0, -27999, 0, 24193, 0, -27998, 0, 24340, 0, -27997, 0, 24373, 0, -27996, 0, 24427, 0, -27995, 0, 24500, 0, -27994, 0, 25074, 0, -27993, 0, 25361, 0, -27992, 0, 26274, 0, -27991, 0, 26397, 0, -27990, 0, 28526, 0, -27989, 0, 29266, 0, -27988, 0, 30010, 0, -27987, 0, 30522, 0, -27986, 0, -32652, 0, -27985, 0, -32455, 0, -27984, 0, -32392, 0, -27983, 0, -30858, 0, -27982, 0, -30017, 0, -27981, 0, -29988, 0, -27980, 0, -29307, 0, -27979, 0, -29197, 0, -27978, 0, -28006, 0, -27977, 0, -27273, 0, -27976, 0, -26622, 0, -27975, 0, -25371, 0, -27974, 0, 21189, 0, -27973, 0, 25431, 0, -27972, 0, 30452, 0, -27971, 0, 26389, 0, -27970, 0, 27784, 0, -27969, 0, 29645, 0, -27968, 0, -29501, 0, -27967, 0, -27730, 0, -27966, 0, -27021, 0, -27965, 0, 27941, 0, -27964, 0, 22684, 0, -27963, 0, 26894, 0, -27962, 0, 27084, 0, -27961, 0, -28675, 0, -27960, 0, -27750, 0, -27959, 0, 30171, 0, -27958, 0, -28646, 0, -27957, 0, 22618, 0, -27956, 0, 26626, 0, -27955, 0, 25524, 0, -27954, 0, 27131, 0, -27953, 0, 20291, 0, -27952, 0, 28460, 0, -27951, 0, 26584, 0, -27950, 0, -28741, 0, -27949, 0, -31450, 0, -27948, 0, 32180, 0, -27947, 0, -27820, 0, -27946, 0, 26943, 0, -27945, 0, 28528, 0, -27944, 0, 22378, 0, -27943, 0, 22775, 0, -27942, 0, 23340, 0, -27941, 0, 32044, 0, -27940, 0, 29226, 0, -27939, 0, 21514, 0, -27938, 0, -28189, 0, -27937, 0, -25164, 0, -27936, 0, 20141, 0, -27935, 0, 20302, 0, -27934, 0, 20572, 0, -27933, 0, 20597, 0, -27932, 0, 21059, 0, -27931, 0, -29538, 0, -27930, 0, 21576, 0, -27929, 0, 22564, 0, -27928, 0, 23450, 0, -27927, 0, 24093, 0, -27926, 0, 24213, 0, -27925, 0, 24237, 0, -27924, 0, 24311, 0, -27923, 0, 24351, 0, -27922, 0, 24716, 0, -27921, 0, 25269, 0, -27920, 0, 25402, 0, -27919, 0, 25552, 0, -27918, 0, 26799, 0, -27917, 0, 27712, 0, -27916, 0, 30855, 0, -27915, 0, 31118, 0, -27914, 0, 31243, 0, -27913, 0, 32224, 0, -27912, 0, -32185, 0, -27911, 0, -30206, 0, -27910, 0, -29978, 0, -27909, 0, -29116, 0, -27908, 0, -28653, 0, -27840, 0, -28488, 0, -27839, 0, -28371, 0, -27838, 0, -28200, 0, -27837, 0, -24818, 0, -27836, 0, 27877, 0, -27835, 0, 25688, 0, -27834, 0, 25826, 0, -27833, 0, 25973, 0, -27832, 0, 28404, 0, -27831, 0, 30340, 0, -27830, 0, 31515, 0, -27829, 0, -28567, 0, -27828, 0, -27695, 0, -27827, 0, 28346, 0, -27826, 0, 21746, 0, -27825, 0, 24505, 0, -27824, 0, 25764, 0, -27823, 0, -28851, 0, -27822, 0, -28691, 0, -27821, 0, -28092, 0, -27820, 0, 20856, 0, -27819, 0, 22635, 0, -27818, 0, 22825, 0, -27817, 0, 23637, 0, -27816, 0, 24215, 0, -27815, 0, 28155, 0, -27814, 0, 32399, 0, -27813, 0, 29980, 0, -27812, 0, -29508, 0, -27811, 0, -28958, 0, -27810, 0, -26533, 0, -27809, 0, 28857, 0, -27808, 0, 20253, 0, -27807, 0, 27583, 0, -27806, 0, 28593, 0, -27805, 0, 30000, 0, -27804, 0, -26885, 0, -27803, 0, 20814, 0, -27802, 0, 21520, 0, -27801, 0, 22581, 0, -27800, 0, 22615, 0, -27799, 0, 22956, 0, -27798, 0, 23648, 0, -27797, 0, 24466, 0, -27796, 0, 26007, 0, -27795, 0, 26460, 0, -27794, 0, 28193, 0, -27793, 0, 30331, 0, -27792, 0, -31777, 0, -27791, 0, -29459, 0, -27790, 0, -28652, 0, -27789, 0, -28419, 0, -27788, 0, -27827, 0, -27787, 0, 30757, 0, -27786, 0, 30778, 0, -27785, 0, 21162, 0, -27784, 0, 24230, 0, -27783, 0, 22303, 0, -27782, 0, 22900, 0, -27781, 0, 24594, 0, -27780, 0, 20498, 0, -27779, 0, 20826, 0, -27778, 0, 20908, 0, -27776, 0, 20941, 0, -27775, 0, 20992, 0, -27774, 0, 21776, 0, -27773, 0, 22612, 0, -27772, 0, 22616, 0, -27771, 0, 22871, 0, -27770, 0, 23445, 0, -27769, 0, 23798, 0, -27768, 0, 23947, 0, -27767, 0, 24764, 0, -27766, 0, 25237, 0, -27765, 0, 25645, 0, -27764, 0, 26481, 0, -27763, 0, 26691, 0, -27762, 0, 26812, 0, -27761, 0, 26847, 0, -27760, 0, 30423, 0, -27759, 0, 28120, 0, -27758, 0, 28271, 0, -27757, 0, 28059, 0, -27756, 0, 28783, 0, -27755, 0, 29128, 0, -27754, 0, 24403, 0, -27753, 0, 30168, 0, -27752, 0, 31095, 0, -27751, 0, 31561, 0, -27750, 0, 31572, 0, -27749, 0, 31570, 0, -27748, 0, 31958, 0, -27747, 0, 32113, 0, -27746, 0, 21040, 0, -27745, 0, -31645, 0, -27744, 0, -31383, 0, -27743, 0, -31260, 0, -27742, 0, -30194, 0, -27741, 0, -29948, 0, -27740, 0, -29626, 0, -27739, 0, -29169, 0, -27738, 0, -28669, 0, -27737, 0, -28657, 0, -27736, 0, -27623, 0, -27735, 0, -27018, 0, -27734, 0, -26579, 0, -27733, 0, -26064, 0, -27732, 0, -27176, 0, -27731, 0, 20685, 0, -27730, 0, 21205, 0, -27729, 0, 21516, 0, -27728, 0, 22530, 0, -27727, 0, 23566, 0, -27726, 0, 24999, 0, -27725, 0, 25758, 0, -27724, 0, 27934, 0, -27723, 0, 30643, 0, -27722, 0, 31461, 0, -27721, 0, -32524, 0, -27720, 0, -31740, 0, -27719, 0, -28589, 0, -27718, 0, -28027, 0, -27717, 0, 23776, 0, -27716, 0, -25337, 0, -27715, 0, 21311, 0, -27714, 0, 24471, 0, -27713, 0, 24499, 0, -27712, 0, 28060, 0, -27711, 0, 29305, 0, -27710, 0, 30563, 0, -27709, 0, 31167, 0, -27708, 0, 31716, 0, -27707, 0, 27602, 0, -27706, 0, 29420, 0, -27705, 0, -30035, 0, -27704, 0, 26627, 0, -27703, 0, 27233, 0, -27702, 0, 20984, 0, -27701, 0, 31361, 0, -27700, 0, 26932, 0, -27699, 0, 23626, 0, -27698, 0, -25354, 0, -27697, 0, -32021, 0, -27696, 0, 23493, 0, -27695, 0, -28343, 0, -27694, 0, 28702, 0, -27693, 0, 22136, 0, -27692, 0, 23663, 0, -27691, 0, 24775, 0, -27690, 0, 25958, 0, -27689, 0, 27788, 0, -27688, 0, -29606, 0, -27687, 0, -28607, 0, -27686, 0, -26605, 0, -27685, 0, 21585, 0, -27684, 0, 26311, 0, -27683, 0, -28147, 0, -27682, 0, 22856, 0, -27681, 0, -28509, 0, -27680, 0, 20869, 0, -27679, 0, 20045, 0, -27678, 0, 20970, 0, -27677, 0, -31335, 0, -27676, 0, -29938, 0, -27675, 0, 28760, 0, -27674, 0, 25466, 0, -27673, 0, -27829, 0, -27672, 0, 26978, 0, -27671, 0, -26188, 0, -27670, 0, 32260, 0, -27669, 0, 30071, 0, -27668, 0, 21335, 0, -27667, 0, 26976, 0, -27666, 0, -28961, 0, -27665, 0, -26909, 0, -27664, 0, 27741, 0, -27663, 0, 20108, 0, -27662, 0, 23612, 0, -27661, 0, 24336, 0, -27660, 0, -28695, 0, -27659, 0, 21250, 0, -27658, 0, -29487, 0, -27657, 0, -32631, 0, -27656, 0, -31111, 0, -27655, 0, 24319, 0, -27654, 0, 26085, 0, -27653, 0, 20083, 0, -27652, 0, 20837, 0, -27584, 0, 22914, 0, -27583, 0, 23615, 0, -27582, 0, -26642, 0, -27581, 0, 20219, 0, -27580, 0, 22922, 0, -27579, 0, 24525, 0, -27578, 0, -30067, 0, -27577, 0, 28641, 0, -27576, 0, 31152, 0, -27575, 0, 31074, 0, -27574, 0, 23527, 0, -27573, 0, -31631, 0, -27572, 0, 29483, 0, -27571, 0, 29105, 0, -27570, 0, 24180, 0, -27569, 0, 24565, 0, -27568, 0, 25467, 0, -27567, 0, 25754, 0, -27566, 0, 29123, 0, -27565, 0, 31896, 0, -27564, 0, 20035, 0, -27563, 0, 24316, 0, -27562, 0, 20043, 0, -27561, 0, 22492, 0, -27560, 0, 22178, 0, -27559, 0, 24745, 0, -27558, 0, 28611, 0, -27557, 0, 32013, 0, -27556, 0, -32515, 0, -27555, 0, -32461, 0, -27554, 0, -32321, 0, -27553, 0, -28750, 0, -27552, 0, -30313, 0, -27551, 0, -31068, 0, -27550, 0, 24052, 0, -27549, 0, 25226, 0, -27548, 0, 25773, 0, -27547, 0, -30329, 0, -27546, 0, 26487, 0, -27545, 0, 27874, 0, -27544, 0, 27966, 0, -27543, 0, 29750, 0, -27542, 0, 30772, 0, -27541, 0, 23110, 0, -27540, 0, 32629, 0, -27539, 0, -32083, 0, -27538, 0, -26196, 0, -27537, 0, 20467, 0, -27536, 0, 24259, 0, -27535, 0, 25309, 0, -27534, 0, 25490, 0, -27533, 0, 25943, 0, -27532, 0, 26479, 0, -27531, 0, 30403, 0, -27530, 0, 29260, 0, -27529, 0, -32564, 0, -27528, 0, -32582, 0, -27527, 0, -28887, 0, -27526, 0, -28339, 0, -27525, 0, 20493, 0, -27524, 0, 22521, 0, -27523, 0, 23186, 0, -27522, 0, 26757, 0, -27520, 0, 26995, 0, -27519, 0, 29028, 0, -27518, 0, 29437, 0, -27517, 0, -29513, 0, -27516, 0, 22770, 0, -27515, 0, -29472, 0, -27514, 0, -27030, 0, -27513, 0, -28647, 0, -27512, 0, -30849, 0, -27511, 0, 31204, 0, -27510, 0, 30695, 0, -27509, 0, -31703, 0, -27508, 0, 20271, 0, -27507, 0, 21093, 0, -27506, 0, 21338, 0, -27505, 0, 25293, 0, -27504, 0, 26575, 0, -27503, 0, 27850, 0, -27502, 0, 30333, 0, -27501, 0, 31636, 0, -27500, 0, 31893, 0, -27499, 0, -32202, 0, -27498, 0, -31356, 0, -27497, 0, -28693, 0, -27496, 0, 26333, 0, -27495, 0, 28448, 0, -27494, 0, 29190, 0, -27493, 0, 32283, 0, -27492, 0, -31829, 0, -27491, 0, -26175, 0, -27490, 0, -24922, 0, -27489, 0, 20989, 0, -27488, 0, 31665, 0, -27487, 0, 30834, 0, -27486, 0, 31672, 0, -27485, 0, -32633, 0, -27484, 0, 31560, 0, -27483, 0, 27368, 0, -27482, 0, 24161, 0, -27481, 0, -32628, 0, -27480, 0, 30033, 0, -27479, 0, 30048, 0, -27478, 0, 20843, 0, -27477, 0, -28062, 0, -27476, 0, 28300, 0, -27475, 0, 30330, 0, -27474, 0, -28265, 0, -27473, 0, -25878, 0, -27472, 0, 20240, 0, -27471, 0, 32624, 0, -27470, 0, 25244, 0, -27469, 0, 31567, 0, -27468, 0, -27227, 0, -27467, 0, -25367, 0, -27466, 0, 22138, 0, -27465, 0, 22617, 0, -27464, 0, -31004, 0, -27463, 0, -26948, 0, -27462, 0, 20276, 0, -27461, 0, 21028, 0, -27460, 0, 21322, 0, -27459, 0, 21453, 0, -27458, 0, 21467, 0, -27457, 0, 24070, 0, -27456, 0, 25644, 0, -27455, 0, 26001, 0, -27454, 0, 26495, 0, -27453, 0, 27710, 0, -27452, 0, 27726, 0, -27451, 0, 29256, 0, -27450, 0, 29359, 0, -27449, 0, 29677, 0, -27448, 0, 30036, 0, -27447, 0, 32321, 0, -27446, 0, -32212, 0, -27445, 0, -31255, 0, -27444, 0, -29527, 0, -27443, 0, 31684, 0, -27442, 0, -28218, 0, -27441, 0, 29033, 0, -27440, 0, -26606, 0, -27439, 0, -26385, 0, -27438, 0, 25405, 0, -27437, 0, 26217, 0, -27436, 0, 30058, 0, -27435, 0, 30436, 0, -27434, 0, 30928, 0, -27433, 0, -31421, 0, -27432, 0, -30994, 0, -27431, 0, 21290, 0, -27430, 0, 21329, 0, -27429, 0, 21542, 0, -27428, 0, 22915, 0, -27427, 0, 24199, 0, -27426, 0, 24444, 0, -27425, 0, 24754, 0, -27424, 0, 25161, 0, -27423, 0, 25209, 0, -27422, 0, 25259, 0, -27421, 0, 26000, 0, -27420, 0, 27604, 0, -27419, 0, 27852, 0, -27418, 0, 30130, 0, -27417, 0, 30382, 0, -27416, 0, 30865, 0, -27415, 0, 31192, 0, -27414, 0, 32203, 0, -27413, 0, 32631, 0, -27412, 0, -32603, 0, -27411, 0, -30549, 0, -27410, 0, -30023, 0, -27409, 0, -29509, 0, -27408, 0, -28545, 0, -27407, 0, -26786, 0, -27406, 0, -26405, 0, -27405, 0, 27147, 0, -27404, 0, 31800, 0, -27403, 0, 20633, 0, -27402, 0, 23614, 0, -27401, 0, 24494, 0, -27400, 0, 26503, 0, -27399, 0, 27608, 0, -27398, 0, 29749, 0, -27397, 0, 30473, 0, -27396, 0, 32654, 0, -27328, 0, -24773, 0, -27327, 0, 26570, 0, -27326, 0, 31255, 0, -27325, 0, 21305, 0, -27324, 0, 30091, 0, -27323, 0, -25875, 0, -27322, 0, 24422, 0, -27321, 0, -32355, 0, -27320, 0, -31759, 0, -27319, 0, -32616, 0, -27318, 0, 24380, 0, -27317, 0, 24517, 0, -27316, 0, 30050, 0, -27315, 0, 31558, 0, -27314, 0, -28612, 0, -27313, 0, 26727, 0, -27312, 0, 23019, 0, -27311, 0, 23195, 0, -27310, 0, 32016, 0, -27309, 0, 30334, 0, -27308, 0, -29908, 0, -27307, 0, 20469, 0, -27306, 0, 24426, 0, -27305, 0, 27161, 0, -27304, 0, 27703, 0, -27303, 0, 28418, 0, -27302, 0, 29922, 0, -27301, 0, 31080, 0, -27300, 0, -30616, 0, -27299, 0, -30123, 0, -27298, 0, -29575, 0, -27297, 0, 24287, 0, -27296, 0, 25551, 0, -27295, 0, 30149, 0, -27294, 0, 31186, 0, -27293, 0, -32041, 0, -27292, 0, -27864, 0, -27291, 0, -27918, 0, -27290, 0, -31588, 0, -27289, 0, -30995, 0, -27288, 0, -25555, 0, -27287, 0, 21697, 0, -27286, 0, 24428, 0, -27285, 0, 25996, 0, -27284, 0, 27996, 0, -27283, 0, 28693, 0, -27282, 0, -29529, 0, -27281, 0, -29485, 0, -27280, 0, -26565, 0, -27279, 0, 25935, 0, -27278, 0, 29942, 0, -27277, 0, 19981, 0, -27276, 0, 20184, 0, -27275, 0, 22496, 0, -27274, 0, 22827, 0, -27273, 0, 23142, 0, -27272, 0, 23500, 0, -27271, 0, 20904, 0, -27270, 0, 24067, 0, -27269, 0, 24220, 0, -27268, 0, 24598, 0, -27267, 0, 25206, 0, -27266, 0, 25975, 0, -27264, 0, 26023, 0, -27263, 0, 26222, 0, -27262, 0, 28014, 0, -27261, 0, 29238, 0, -27260, 0, 31526, 0, -27259, 0, -32432, 0, -27258, 0, -32358, 0, -27257, 0, -32103, 0, -27256, 0, -29860, 0, -27255, 0, -29536, 0, -27254, 0, -29466, 0, -27253, 0, -29324, 0, -27252, 0, -27108, 0, -27251, 0, -27068, 0, -27250, 0, 20398, 0, -27249, 0, 25771, 0, -27248, 0, 27494, 0, -27247, 0, -32226, 0, -27246, 0, -31647, 0, -27245, 0, -31382, 0, -27244, 0, -28440, 0, -27243, 0, 23553, 0, -27242, 0, 26963, 0, -27241, 0, -26456, 0, -27240, 0, -31622, 0, -27239, 0, -31401, 0, -27238, 0, 20239, 0, -27237, 0, 21103, 0, -27236, 0, 24489, 0, -27235, 0, 24133, 0, -27234, 0, 26381, 0, -27233, 0, 31119, 0, -27232, 0, -32391, 0, -27231, 0, -30457, 0, -27230, 0, -30330, 0, -27229, 0, 28149, 0, -27228, 0, 24343, 0, -27227, 0, 25173, 0, -27226, 0, 27832, 0, -27225, 0, 20175, 0, -27224, 0, 29289, 0, -27223, 0, -25710, 0, -27222, 0, 20998, 0, -27221, 0, 21563, 0, -27220, 0, 22132, 0, -27219, 0, 22707, 0, -27218, 0, 24996, 0, -27217, 0, 25198, 0, -27216, 0, 28954, 0, -27215, 0, 22894, 0, -27214, 0, 31881, 0, -27213, 0, 31966, 0, -27212, 0, 32027, 0, -27211, 0, -26896, 0, -27210, 0, 25991, 0, -27209, 0, -32674, 0, -27208, 0, 19993, 0, -27207, 0, 20341, 0, -27206, 0, 20853, 0, -27205, 0, 22592, 0, -27204, 0, 24163, 0, -27203, 0, 24179, 0, -27202, 0, 24330, 0, -27201, 0, 26564, 0, -27200, 0, 20006, 0, -27199, 0, -31427, 0, -27198, 0, -27255, 0, -27197, 0, -27045, 0, -27196, 0, 31859, 0, -27195, 0, -26623, 0, -27194, 0, 20731, 0, -27193, 0, 22721, 0, -27192, 0, 30294, 0, -27191, 0, 30887, 0, -27190, 0, 21029, 0, -27189, 0, 30629, 0, -27188, 0, -31471, 0, -27187, 0, 31622, 0, -27186, 0, 20559, 0, -27185, 0, 22793, 0, -27184, 0, 29255, 0, -27183, 0, 31687, 0, -27182, 0, 32232, 0, -27181, 0, -28742, 0, -27180, 0, -28716, 0, -27179, 0, -28595, 0, -27178, 0, 20415, 0, -27177, 0, 21193, 0, -27176, 0, 23081, 0, -27175, 0, 24321, 0, -27174, 0, -26707, 0, -27173, 0, 20445, 0, -27172, 0, -32233, 0, -27171, 0, -27926, 0, -27170, 0, 22275, 0, -27169, 0, 25429, 0, -27168, 0, 27497, 0, -27167, 0, 29995, 0, -27166, 0, -30500, 0, -27165, 0, -28908, 0, -27164, 0, 31298, 0, -27163, 0, 21215, 0, -27162, 0, 22675, 0, -27161, 0, 24917, 0, -27160, 0, 25098, 0, -27159, 0, 26286, 0, -27158, 0, 27597, 0, -27157, 0, 31807, 0, -27156, 0, -31767, 0, -27155, 0, 20515, 0, -27154, 0, 20472, 0, -27153, 0, 21253, 0, -27152, 0, 21574, 0, -27151, 0, 22577, 0, -27150, 0, 22857, 0, -27149, 0, 23453, 0, -27148, 0, 23792, 0, -27147, 0, 23791, 0, -27146, 0, 23849, 0, -27145, 0, 24214, 0, -27144, 0, 25265, 0, -27143, 0, 25447, 0, -27142, 0, 25918, 0, -27141, 0, 26041, 0, -27140, 0, 26379, 0, -27072, 0, 27861, 0, -27071, 0, 27873, 0, -27070, 0, 28921, 0, -27069, 0, 30770, 0, -27068, 0, 32299, 0, -27067, 0, -32546, 0, -27066, 0, -32077, 0, -27065, 0, -31732, 0, -27064, 0, -31508, 0, -27063, 0, -30974, 0, -27062, 0, -30446, 0, -27061, 0, -30166, 0, -27060, 0, -29622, 0, -27059, 0, -28506, 0, -27058, 0, -27950, 0, -27057, 0, -26371, 0, -27056, 0, -25357, 0, -27055, 0, -25236, 0, -27054, 0, 20047, 0, -27053, 0, 20129, 0, -27052, 0, 20621, 0, -27051, 0, 21078, 0, -27050, 0, 22346, 0, -27049, 0, 22952, 0, -27048, 0, 24125, 0, -27047, 0, 24536, 0, -27046, 0, 24537, 0, -27045, 0, 25151, 0, -27044, 0, 26292, 0, -27043, 0, 26395, 0, -27042, 0, 26576, 0, -27041, 0, 26834, 0, -27040, 0, 20882, 0, -27039, 0, 32033, 0, -27038, 0, -32598, 0, -27037, 0, -32344, 0, -27036, 0, -29952, 0, -27035, 0, -29556, 0, -27034, 0, -29505, 0, -27033, 0, -28034, 0, -27032, 0, -27086, 0, -27031, 0, 21536, 0, -27030, 0, -26580, 0, -27029, 0, 21271, 0, -27028, 0, 20693, 0, -27027, 0, 21340, 0, -27026, 0, 22696, 0, -27025, 0, 25778, 0, -27024, 0, 26420, 0, -27023, 0, 29287, 0, -27022, 0, 30566, 0, -27021, 0, 31302, 0, -27020, 0, -28186, 0, -27019, 0, 21187, 0, -27018, 0, 27809, 0, -27017, 0, 27526, 0, -27016, 0, 22528, 0, -27015, 0, 24140, 0, -27014, 0, 22868, 0, -27013, 0, 26412, 0, -27012, 0, 32763, 0, -27011, 0, 20961, 0, -27010, 0, 30406, 0, -27008, 0, 25705, 0, -27007, 0, 30952, 0, -27006, 0, -25772, 0, -27005, 0, -24901, 0, -27004, 0, 22475, 0, -27003, 0, 22969, 0, -27002, 0, 26151, 0, -27001, 0, 26522, 0, -27000, 0, 27598, 0, -26999, 0, 21737, 0, -26998, 0, 27097, 0, -26997, 0, 24149, 0, -26996, 0, -32356, 0, -26995, 0, 26517, 0, -26994, 0, -25686, 0, -26993, 0, 26622, 0, -26992, 0, -25518, 0, -26991, 0, 26717, 0, -26990, 0, 20134, 0, -26989, 0, 20451, 0, -26988, 0, 21448, 0, -26987, 0, 25273, 0, -26986, 0, 26411, 0, -26985, 0, 27819, 0, -26984, 0, -28732, 0, -26983, 0, 20397, 0, -26982, 0, 32365, 0, -26981, 0, -24897, 0, -26980, 0, 19975, 0, -26979, 0, 24930, 0, -26978, 0, 28288, 0, -26977, 0, 28459, 0, -26976, 0, -31469, 0, -26975, 0, 21619, 0, -26974, 0, 26410, 0, -26973, 0, -25787, 0, -26972, 0, 24051, 0, -26971, 0, 31637, 0, -26970, 0, 23724, 0, -26969, 0, 23494, 0, -26968, 0, -30948, 0, -26967, 0, 28234, 0, -26966, 0, -31535, 0, -26965, 0, 31252, 0, -26964, 0, -32504, 0, -26963, 0, 22937, 0, -26962, 0, 31885, 0, -26961, 0, 27665, 0, -26960, 0, 30496, 0, -26959, 0, 21209, 0, -26958, 0, 22818, 0, -26957, 0, 28961, 0, -26956, 0, 29279, 0, -26955, 0, 30683, 0, -26954, 0, -26841, 0, -26953, 0, -25247, 0, -26952, 0, 26891, 0, -26951, 0, 23167, 0, -26950, 0, 23064, 0, -26949, 0, 20901, 0, -26948, 0, 21517, 0, -26947, 0, 21629, 0, -26946, 0, 26126, 0, -26945, 0, 30431, 0, -26944, 0, -28681, 0, -26943, 0, -28008, 0, -26942, 0, -25356, 0, -26941, 0, 23018, 0, -26940, 0, 29277, 0, -26939, 0, 28357, 0, -26938, 0, 20813, 0, -26937, 0, 26825, 0, -26936, 0, 32191, 0, -26935, 0, 32236, 0, -26934, 0, -26782, 0, -26933, 0, -24902, 0, -26932, 0, 25720, 0, -26931, 0, 27169, 0, -26930, 0, -31998, 0, -26929, 0, 22916, 0, -26928, 0, 23391, 0, -26927, 0, 27611, 0, -26926, 0, 29467, 0, -26925, 0, 30450, 0, -26924, 0, 32178, 0, -26923, 0, -32745, 0, -26922, 0, -31591, 0, -26921, 0, 20786, 0, -26920, 0, 26408, 0, -26919, 0, -24871, 0, -26918, 0, 30446, 0, -26917, 0, 26466, 0, -26916, 0, 21247, 0, -26915, 0, -26363, 0, -26914, 0, 23588, 0, -26913, 0, 25147, 0, -26912, 0, 31870, 0, -26911, 0, -29520, 0, -26910, 0, 21839, 0, -26909, 0, 24758, 0, -26908, 0, 32011, 0, -26907, 0, -27264, 0, -26906, 0, 21249, 0, -26905, 0, 20063, 0, -26904, 0, 20918, 0, -26903, 0, 22812, 0, -26902, 0, 29242, 0, -26901, 0, -32714, 0, -26900, 0, -28210, 0, -26899, 0, 24357, 0, -26898, 0, 30690, 0, -26897, 0, 21380, 0, -26896, 0, 24441, 0, -26895, 0, 32004, 0, -26894, 0, -31316, 0, -26893, 0, -30157, 0, -26892, 0, -29043, 0, -26891, 0, -26794, 0, -26890, 0, 26611, 0, -26889, 0, -31314, 0, -26888, 0, -27565, 0, -26887, 0, 24841, 0, -26886, 0, 24840, 0, -26885, 0, 27833, 0, -26884, 0, 30290, 0, -26816, 0, -29971, 0, -26815, 0, -28872, 0, -26814, 0, 21807, 0, -26813, 0, 20305, 0, -26812, 0, 20778, 0, -26811, 0, 21191, 0, -26810, 0, 21451, 0, -26809, 0, 23461, 0, -26808, 0, 24189, 0, -26807, 0, 24736, 0, -26806, 0, 24962, 0, -26805, 0, 25558, 0, -26804, 0, 26377, 0, -26803, 0, 26586, 0, -26802, 0, 28263, 0, -26801, 0, 28044, 0, -26800, 0, 29494, 0, -26799, 0, 29495, 0, -26798, 0, 30001, 0, -26797, 0, 31056, 0, -26796, 0, -30507, 0, -26795, 0, -30056, 0, -26794, 0, -28598, 0, -26793, 0, -28527, 0, -26792, 0, -28427, 0, -26791, 0, -26940, 0, -26790, 0, -30835, 0, -26789, 0, 22805, 0, -26788, 0, 20104, 0, -26787, 0, 20313, 0, -26786, 0, 19982, 0, -26785, 0, -30071, 0, -26784, 0, -28865, 0, -26783, 0, -26608, 0, -26782, 0, 20653, 0, -26781, 0, 24188, 0, -26780, 0, 22934, 0, -26779, 0, 23481, 0, -26778, 0, 24248, 0, -26777, 0, 25562, 0, -26776, 0, 25594, 0, -26775, 0, 25793, 0, -26774, 0, 26332, 0, -26773, 0, 26954, 0, -26772, 0, 27096, 0, -26771, 0, 27915, 0, -26770, 0, 28342, 0, -26769, 0, 29076, 0, -26768, 0, 29992, 0, -26767, 0, 31407, 0, -26766, 0, 32650, 0, -26765, 0, -32768, 0, -26764, 0, -31671, 0, -26763, 0, -31543, 0, -26762, 0, -30335, 0, -26761, 0, -29919, 0, -26760, 0, -29174, 0, -26759, 0, -28571, 0, -26758, 0, -27011, 0, -26757, 0, -26358, 0, -26756, 0, 24958, 0, -26755, 0, 25233, 0, -26754, 0, 27442, 0, -26752, 0, 27779, 0, -26751, 0, 28020, 0, -26750, 0, 32716, 0, -26749, 0, 32764, 0, -26748, 0, 28096, 0, -26747, 0, 32645, 0, -26746, 0, -30790, 0, -26745, 0, -30472, 0, -26744, 0, 26469, 0, -26743, 0, -31823, 0, -26742, 0, -26564, 0, -26741, 0, -26889, 0, -26740, 0, 27931, 0, -26739, 0, 32097, 0, -26738, 0, -31683, 0, -26737, 0, -28310, 0, -26736, 0, 20081, 0, -26735, 0, 21365, 0, -26734, 0, 23888, 0, -26733, 0, 27396, 0, -26732, 0, 28651, 0, -26731, 0, -31283, 0, -26730, 0, -31187, 0, -26729, 0, -30297, 0, -26728, 0, 21033, 0, -26727, 0, 21519, 0, -26726, 0, 23653, 0, -26725, 0, 26446, 0, -26724, 0, 26792, 0, -26723, 0, 29702, 0, -26722, 0, 29827, 0, -26721, 0, 30178, 0, -26720, 0, -30513, 0, -26719, 0, -30495, 0, -26718, 0, -28212, 0, -26717, 0, -26910, 0, -26716, 0, -27016, 0, -26715, 0, 24459, 0, -26714, 0, 29575, 0, -26713, 0, 31435, 0, -26712, 0, -31666, 0, -26711, 0, 25504, 0, -26710, 0, 30053, 0, -26709, 0, 21129, 0, -26708, 0, 27969, 0, -26707, 0, 28316, 0, -26706, 0, 29705, 0, -26705, 0, 30041, 0, -26704, 0, 30827, 0, -26703, 0, 31890, 0, -26702, 0, -27002, 0, -26701, 0, 31452, 0, -26700, 0, -24691, 0, -26699, 0, 20406, 0, -26698, 0, 24942, 0, -26697, 0, 26053, 0, -26696, 0, -31140, 0, -26695, 0, 20102, 0, -26694, 0, 20142, 0, -26693, 0, 20698, 0, -26692, 0, 20001, 0, -26691, 0, 20940, 0, -26690, 0, 23534, 0, -26689, 0, 26009, 0, -26688, 0, 26753, 0, -26687, 0, 28092, 0, -26686, 0, 29471, 0, -26685, 0, 30274, 0, -26684, 0, 30637, 0, -26683, 0, 31260, 0, -26682, 0, 31975, 0, -26681, 0, -32145, 0, -26680, 0, -29998, 0, -26679, 0, -28548, 0, -26678, 0, -28209, 0, -26677, 0, -27019, 0, -26676, 0, -26600, 0, -26675, 0, 21147, 0, -26674, 0, 32209, 0, -26673, 0, 20523, 0, -26672, 0, 21400, 0, -26671, 0, 26519, 0, -26670, 0, 28107, 0, -26669, 0, 29136, 0, -26668, 0, 29747, 0, -26667, 0, -32280, 0, -26666, 0, -28886, 0, -26665, 0, -26973, 0, -26664, 0, -25513, 0, -26663, 0, -24929, 0, -26662, 0, 29792, 0, -26661, 0, 22593, 0, -26660, 0, 28057, 0, -26659, 0, 32047, 0, -26658, 0, -26530, 0, -26657, 0, 20196, 0, -26656, 0, 20278, 0, -26655, 0, 20363, 0, -26654, 0, 20919, 0, -26653, 0, 21169, 0, -26652, 0, 23994, 0, -26651, 0, 24604, 0, -26650, 0, 29618, 0, -26649, 0, 31036, 0, -26648, 0, -32045, 0, -26647, 0, -28108, 0, -26646, 0, -26953, 0, -26645, 0, -26890, 0, -26644, 0, -26870, 0, -26643, 0, -24937, 0, -26642, 0, -24734, 0, -26641, 0, 26278, 0, -26640, 0, 27508, 0, -26639, 0, 21015, 0, -26638, 0, 21155, 0, -26637, 0, 28872, 0, -26636, 0, -30526, 0, -26635, 0, 24265, 0, -26634, 0, 24651, 0, -26633, 0, 24976, 0, -26632, 0, 28451, 0, -26631, 0, 29001, 0, -26630, 0, 31806, 0, -26629, 0, 32244, 0, -26628, 0, -32657, 0, -26560, 0, -31506, 0, -26559, 0, -28637, 0, -26558, 0, -27860, 0, -26557, 0, 21570, 0, -26556, 0, -25745, 0, -26555, 0, 27347, 0, -26554, 0, 28809, 0, -26553, 0, -29502, 0, -26552, 0, -29201, 0, -26551, 0, -26830, 0, -26550, 0, 21172, 0, -26549, 0, 23105, 0, -26548, 0, 24266, 0, -26547, 0, 24324, 0, -26546, 0, 26391, 0, -26545, 0, 27004, 0, -26544, 0, 27028, 0, -26543, 0, 28010, 0, -26542, 0, 28431, 0, -26541, 0, 29282, 0, -26540, 0, 29436, 0, -26539, 0, 31725, 0, -26538, 0, -32767, 0, -26537, 0, -32642, 0, -26536, 0, -30901, 0, -26535, 0, -28466, 0, -26534, 0, 20845, 0, -26533, 0, -24941, 0, -26532, 0, 31108, 0, -26531, 0, -32629, 0, -26530, 0, -27854, 0, -26529, 0, -29994, 0, -26528, 0, 20525, 0, -26527, 0, 21644, 0, -26526, 0, -30095, 0, -26525, 0, 27498, 0, -26524, 0, -29500, 0, -26523, 0, -32505, 0, -26522, 0, 24785, 0, -26521, 0, 26528, 0, -26520, 0, -25102, 0, -26519, 0, 20121, 0, -26518, 0, 20120, 0, -26517, 0, -25584, 0, -26516, 0, -30101, 0, -26515, 0, -31295, 0, -26514, 0, -31384, 0, -26513, 0, 26880, 0, -26512, 0, 28286, 0, -26511, 0, 30871, 0, -26510, 0, -32427, 0, -26465, 0, 24332, 0, -26464, 0, 19984, 0, -26463, 0, 19989, 0, -26462, 0, 20010, 0, -26461, 0, 20017, 0, -26460, 0, 20022, 0, -26459, 0, 20028, 0, -26458, 0, 20031, 0, -26457, 0, 20034, 0, -26456, 0, 20054, 0, -26455, 0, 20056, 0, -26454, 0, 20098, 0, -26453, 0, 20101, 0, -26452, 0, -29589, 0, -26451, 0, 20106, 0, -26450, 0, -32238, 0, -26449, 0, 24333, 0, -26448, 0, 20110, 0, -26447, 0, 20126, 0, -26446, 0, 20127, 0, -26445, 0, 20128, 0, -26444, 0, 20130, 0, -26443, 0, 20144, 0, -26442, 0, 20147, 0, -26441, 0, 20150, 0, -26440, 0, 20174, 0, -26439, 0, 20173, 0, -26438, 0, 20164, 0, -26437, 0, 20166, 0, -26436, 0, 20162, 0, -26435, 0, 20183, 0, -26434, 0, 20190, 0, -26433, 0, 20205, 0, -26432, 0, 20191, 0, -26431, 0, 20215, 0, -26430, 0, 20233, 0, -26429, 0, 20314, 0, -26428, 0, 20272, 0, -26427, 0, 20315, 0, -26426, 0, 20317, 0, -26425, 0, 20311, 0, -26424, 0, 20295, 0, -26423, 0, 20342, 0, -26422, 0, 20360, 0, -26421, 0, 20367, 0, -26420, 0, 20376, 0, -26419, 0, 20347, 0, -26418, 0, 20329, 0, -26417, 0, 20336, 0, -26416, 0, 20369, 0, -26415, 0, 20335, 0, -26414, 0, 20358, 0, -26413, 0, 20374, 0, -26412, 0, 20760, 0, -26411, 0, 20436, 0, -26410, 0, 20447, 0, -26409, 0, 20430, 0, -26408, 0, 20440, 0, -26407, 0, 20443, 0, -26406, 0, 20433, 0, -26405, 0, 20442, 0, -26404, 0, 20432, 0, -26403, 0, 20452, 0, -26402, 0, 20453, 0, -26401, 0, 20506, 0, -26400, 0, 20520, 0, -26399, 0, 20500, 0, -26398, 0, 20522, 0, -26397, 0, 20517, 0, -26396, 0, 20485, 0, -26395, 0, 20252, 0, -26394, 0, 20470, 0, -26393, 0, 20513, 0, -26392, 0, 20521, 0, -26391, 0, 20524, 0, -26390, 0, 20478, 0, -26389, 0, 20463, 0, -26388, 0, 20497, 0, -26387, 0, 20486, 0, -26386, 0, 20547, 0, -26385, 0, 20551, 0, -26384, 0, 26371, 0, -26383, 0, 20565, 0, -26382, 0, 20560, 0, -26381, 0, 20552, 0, -26380, 0, 20570, 0, -26379, 0, 20566, 0, -26378, 0, 20588, 0, -26377, 0, 20600, 0, -26376, 0, 20608, 0, -26375, 0, 20634, 0, -26374, 0, 20613, 0, -26373, 0, 20660, 0, -26372, 0, 20658, 0, -26304, 0, 20681, 0, -26303, 0, 20682, 0, -26302, 0, 20659, 0, -26301, 0, 20674, 0, -26300, 0, 20694, 0, -26299, 0, 20702, 0, -26298, 0, 20709, 0, -26297, 0, 20717, 0, -26296, 0, 20707, 0, -26295, 0, 20718, 0, -26294, 0, 20729, 0, -26293, 0, 20725, 0, -26292, 0, 20745, 0, -26291, 0, 20737, 0, -26290, 0, 20738, 0, -26289, 0, 20758, 0, -26288, 0, 20757, 0, -26287, 0, 20756, 0, -26286, 0, 20762, 0, -26285, 0, 20769, 0, -26284, 0, 20794, 0, -26283, 0, 20791, 0, -26282, 0, 20796, 0, -26281, 0, 20795, 0, -26280, 0, 20799, 0, -26279, 0, 20800, 0, -26278, 0, 20818, 0, -26277, 0, 20812, 0, -26276, 0, 20820, 0, -26275, 0, 20834, 0, -26274, 0, 31480, 0, -26273, 0, 20841, 0, -26272, 0, 20842, 0, -26271, 0, 20846, 0, -26270, 0, 20864, 0, -26269, 0, 20866, 0, -26268, 0, 22232, 0, -26267, 0, 20876, 0, -26266, 0, 20873, 0, -26265, 0, 20879, 0, -26264, 0, 20881, 0, -26263, 0, 20883, 0, -26262, 0, 20885, 0, -26261, 0, 20886, 0, -26260, 0, 20900, 0, -26259, 0, 20902, 0, -26258, 0, 20898, 0, -26257, 0, 20905, 0, -26256, 0, 20906, 0, -26255, 0, 20907, 0, -26254, 0, 20915, 0, -26253, 0, 20913, 0, -26252, 0, 20914, 0, -26251, 0, 20912, 0, -26250, 0, 20917, 0, -26249, 0, 20925, 0, -26248, 0, 20933, 0, -26247, 0, 20937, 0, -26246, 0, 20955, 0, -26245, 0, 20960, 0, -26244, 0, -31147, 0, -26243, 0, 20969, 0, -26242, 0, 20973, 0, -26240, 0, 20976, 0, -26239, 0, 20981, 0, -26238, 0, 20990, 0, -26237, 0, 20996, 0, -26236, 0, 21003, 0, -26235, 0, 21012, 0, -26234, 0, 21006, 0, -26233, 0, 21031, 0, -26232, 0, 21034, 0, -26231, 0, 21038, 0, -26230, 0, 21043, 0, -26229, 0, 21049, 0, -26228, 0, 21071, 0, -26227, 0, 21060, 0, -26226, 0, 21067, 0, -26225, 0, 21068, 0, -26224, 0, 21086, 0, -26223, 0, 21076, 0, -26222, 0, 21098, 0, -26221, 0, 21108, 0, -26220, 0, 21097, 0, -26219, 0, 21107, 0, -26218, 0, 21119, 0, -26217, 0, 21117, 0, -26216, 0, 21133, 0, -26215, 0, 21140, 0, -26214, 0, 21138, 0, -26213, 0, 21105, 0, -26212, 0, 21128, 0, -26211, 0, 21137, 0, -26210, 0, -28760, 0, -26209, 0, -28761, 0, -26208, 0, 21164, 0, -26207, 0, 21165, 0, -26206, 0, 21180, 0, -26205, 0, 21173, 0, -26204, 0, 21185, 0, -26203, 0, 21197, 0, -26202, 0, 21207, 0, -26201, 0, 21214, 0, -26200, 0, 21219, 0, -26199, 0, 21222, 0, -26198, 0, -26387, 0, -26197, 0, 21216, 0, -26196, 0, 21235, 0, -26195, 0, 21237, 0, -26194, 0, 21240, 0, -26193, 0, 21241, 0, -26192, 0, 21254, 0, -26191, 0, 21256, 0, -26190, 0, 30008, 0, -26189, 0, 21261, 0, -26188, 0, 21264, 0, -26187, 0, 21263, 0, -26186, 0, 21269, 0, -26185, 0, 21274, 0, -26184, 0, 21283, 0, -26183, 0, 21295, 0, -26182, 0, 21297, 0, -26181, 0, 21299, 0, -26180, 0, 21304, 0, -26179, 0, 21312, 0, -26178, 0, 21318, 0, -26177, 0, 21317, 0, -26176, 0, 19991, 0, -26175, 0, 21321, 0, -26174, 0, 21325, 0, -26173, 0, 20950, 0, -26172, 0, 21342, 0, -26171, 0, 21353, 0, -26170, 0, 21358, 0, -26169, 0, 22808, 0, -26168, 0, 21371, 0, -26167, 0, 21367, 0, -26166, 0, 21378, 0, -26165, 0, 21398, 0, -26164, 0, 21408, 0, -26163, 0, 21414, 0, -26162, 0, 21413, 0, -26161, 0, 21422, 0, -26160, 0, 21424, 0, -26159, 0, 21430, 0, -26158, 0, 21443, 0, -26157, 0, 31762, 0, -26156, 0, -26919, 0, -26155, 0, 21471, 0, -26154, 0, 26364, 0, -26153, 0, 29166, 0, -26152, 0, 21486, 0, -26151, 0, 21480, 0, -26150, 0, 21485, 0, -26149, 0, 21498, 0, -26148, 0, 21505, 0, -26147, 0, 21565, 0, -26146, 0, 21568, 0, -26145, 0, 21548, 0, -26144, 0, 21549, 0, -26143, 0, 21564, 0, -26142, 0, 21550, 0, -26141, 0, 21558, 0, -26140, 0, 21545, 0, -26139, 0, 21533, 0, -26138, 0, 21582, 0, -26137, 0, 21647, 0, -26136, 0, 21621, 0, -26135, 0, 21646, 0, -26134, 0, 21599, 0, -26133, 0, 21617, 0, -26132, 0, 21623, 0, -26131, 0, 21616, 0, -26130, 0, 21650, 0, -26129, 0, 21627, 0, -26128, 0, 21632, 0, -26127, 0, 21622, 0, -26126, 0, 21636, 0, -26125, 0, 21648, 0, -26124, 0, 21638, 0, -26123, 0, 21703, 0, -26122, 0, 21666, 0, -26121, 0, 21688, 0, -26120, 0, 21669, 0, -26119, 0, 21676, 0, -26118, 0, 21700, 0, -26117, 0, 21704, 0, -26116, 0, 21672, 0, -26048, 0, 21675, 0, -26047, 0, 21698, 0, -26046, 0, 21668, 0, -26045, 0, 21694, 0, -26044, 0, 21692, 0, -26043, 0, 21720, 0, -26042, 0, 21733, 0, -26041, 0, 21734, 0, -26040, 0, 21775, 0, -26039, 0, 21780, 0, -26038, 0, 21757, 0, -26037, 0, 21742, 0, -26036, 0, 21741, 0, -26035, 0, 21754, 0, -26034, 0, 21730, 0, -26033, 0, 21817, 0, -26032, 0, 21824, 0, -26031, 0, 21859, 0, -26030, 0, 21836, 0, -26029, 0, 21806, 0, -26028, 0, 21852, 0, -26027, 0, 21829, 0, -26026, 0, 21846, 0, -26025, 0, 21847, 0, -26024, 0, 21816, 0, -26023, 0, 21811, 0, -26022, 0, 21853, 0, -26021, 0, 21913, 0, -26020, 0, 21888, 0, -26019, 0, 21679, 0, -26018, 0, 21898, 0, -26017, 0, 21919, 0, -26016, 0, 21883, 0, -26015, 0, 21886, 0, -26014, 0, 21912, 0, -26013, 0, 21918, 0, -26012, 0, 21934, 0, -26011, 0, 21884, 0, -26010, 0, 21891, 0, -26009, 0, 21929, 0, -26008, 0, 21895, 0, -26007, 0, 21928, 0, -26006, 0, 21978, 0, -26005, 0, 21957, 0, -26004, 0, 21983, 0, -26003, 0, 21956, 0, -26002, 0, 21980, 0, -26001, 0, 21988, 0, -26000, 0, 21972, 0, -25999, 0, 22036, 0, -25998, 0, 22007, 0, -25997, 0, 22038, 0, -25996, 0, 22014, 0, -25995, 0, 22013, 0, -25994, 0, 22043, 0, -25993, 0, 22009, 0, -25992, 0, 22094, 0, -25991, 0, 22096, 0, -25990, 0, 29151, 0, -25989, 0, 22068, 0, -25988, 0, 22070, 0, -25987, 0, 22066, 0, -25986, 0, 22072, 0, -25984, 0, 22123, 0, -25983, 0, 22116, 0, -25982, 0, 22063, 0, -25981, 0, 22124, 0, -25980, 0, 22122, 0, -25979, 0, 22150, 0, -25978, 0, 22144, 0, -25977, 0, 22154, 0, -25976, 0, 22176, 0, -25975, 0, 22164, 0, -25974, 0, 22159, 0, -25973, 0, 22181, 0, -25972, 0, 22190, 0, -25971, 0, 22198, 0, -25970, 0, 22196, 0, -25969, 0, 22210, 0, -25968, 0, 22204, 0, -25967, 0, 22209, 0, -25966, 0, 22211, 0, -25965, 0, 22208, 0, -25964, 0, 22216, 0, -25963, 0, 22222, 0, -25962, 0, 22225, 0, -25961, 0, 22227, 0, -25960, 0, 22231, 0, -25959, 0, 22254, 0, -25958, 0, 22265, 0, -25957, 0, 22272, 0, -25956, 0, 22271, 0, -25955, 0, 22276, 0, -25954, 0, 22281, 0, -25953, 0, 22280, 0, -25952, 0, 22283, 0, -25951, 0, 22285, 0, -25950, 0, 22291, 0, -25949, 0, 22296, 0, -25948, 0, 22294, 0, -25947, 0, 21959, 0, -25946, 0, 22300, 0, -25945, 0, 22310, 0, -25944, 0, 22327, 0, -25943, 0, 22328, 0, -25942, 0, 22350, 0, -25941, 0, 22331, 0, -25940, 0, 22336, 0, -25939, 0, 22351, 0, -25938, 0, 22377, 0, -25937, 0, 22464, 0, -25936, 0, 22408, 0, -25935, 0, 22369, 0, -25934, 0, 22399, 0, -25933, 0, 22409, 0, -25932, 0, 22419, 0, -25931, 0, 22432, 0, -25930, 0, 22451, 0, -25929, 0, 22436, 0, -25928, 0, 22442, 0, -25927, 0, 22448, 0, -25926, 0, 22467, 0, -25925, 0, 22470, 0, -25924, 0, 22484, 0, -25923, 0, 22482, 0, -25922, 0, 22483, 0, -25921, 0, 22538, 0, -25920, 0, 22486, 0, -25919, 0, 22499, 0, -25918, 0, 22539, 0, -25917, 0, 22553, 0, -25916, 0, 22557, 0, -25915, 0, 22642, 0, -25914, 0, 22561, 0, -25913, 0, 22626, 0, -25912, 0, 22603, 0, -25911, 0, 22640, 0, -25910, 0, 27584, 0, -25909, 0, 22610, 0, -25908, 0, 22589, 0, -25907, 0, 22649, 0, -25906, 0, 22661, 0, -25905, 0, 22713, 0, -25904, 0, 22687, 0, -25903, 0, 22699, 0, -25902, 0, 22714, 0, -25901, 0, 22750, 0, -25900, 0, 22715, 0, -25899, 0, 22712, 0, -25898, 0, 22702, 0, -25897, 0, 22725, 0, -25896, 0, 22739, 0, -25895, 0, 22737, 0, -25894, 0, 22743, 0, -25893, 0, 22745, 0, -25892, 0, 22744, 0, -25891, 0, 22757, 0, -25890, 0, 22748, 0, -25889, 0, 22756, 0, -25888, 0, 22751, 0, -25887, 0, 22767, 0, -25886, 0, 22778, 0, -25885, 0, 22777, 0, -25884, 0, 22779, 0, -25883, 0, 22780, 0, -25882, 0, 22781, 0, -25881, 0, 22786, 0, -25880, 0, 22794, 0, -25879, 0, 22800, 0, -25878, 0, 22811, 0, -25877, 0, 26790, 0, -25876, 0, 22821, 0, -25875, 0, 22828, 0, -25874, 0, 22829, 0, -25873, 0, 22834, 0, -25872, 0, 22840, 0, -25871, 0, 22846, 0, -25870, 0, 31442, 0, -25869, 0, 22869, 0, -25868, 0, 22864, 0, -25867, 0, 22862, 0, -25866, 0, 22874, 0, -25865, 0, 22872, 0, -25864, 0, 22882, 0, -25863, 0, 22880, 0, -25862, 0, 22887, 0, -25861, 0, 22892, 0, -25860, 0, 22889, 0, -25792, 0, 22904, 0, -25791, 0, 22913, 0, -25790, 0, 22941, 0, -25789, 0, 20318, 0, -25788, 0, 20395, 0, -25787, 0, 22947, 0, -25786, 0, 22962, 0, -25785, 0, 22982, 0, -25784, 0, 23016, 0, -25783, 0, 23004, 0, -25782, 0, 22925, 0, -25781, 0, 23001, 0, -25780, 0, 23002, 0, -25779, 0, 23077, 0, -25778, 0, 23071, 0, -25777, 0, 23057, 0, -25776, 0, 23068, 0, -25775, 0, 23049, 0, -25774, 0, 23066, 0, -25773, 0, 23104, 0, -25772, 0, 23148, 0, -25771, 0, 23113, 0, -25770, 0, 23093, 0, -25769, 0, 23094, 0, -25768, 0, 23138, 0, -25767, 0, 23146, 0, -25766, 0, 23194, 0, -25765, 0, 23228, 0, -25764, 0, 23230, 0, -25763, 0, 23243, 0, -25762, 0, 23234, 0, -25761, 0, 23229, 0, -25760, 0, 23267, 0, -25759, 0, 23255, 0, -25758, 0, 23270, 0, -25757, 0, 23273, 0, -25756, 0, 23254, 0, -25755, 0, 23290, 0, -25754, 0, 23291, 0, -25753, 0, 23308, 0, -25752, 0, 23307, 0, -25751, 0, 23318, 0, -25750, 0, 23346, 0, -25749, 0, 23248, 0, -25748, 0, 23338, 0, -25747, 0, 23350, 0, -25746, 0, 23358, 0, -25745, 0, 23363, 0, -25744, 0, 23365, 0, -25743, 0, 23360, 0, -25742, 0, 23377, 0, -25741, 0, 23381, 0, -25740, 0, 23386, 0, -25739, 0, 23387, 0, -25738, 0, 23397, 0, -25737, 0, 23401, 0, -25736, 0, 23408, 0, -25735, 0, 23411, 0, -25734, 0, 23413, 0, -25733, 0, 23416, 0, -25732, 0, 25992, 0, -25731, 0, 23418, 0, -25730, 0, 23424, 0, -25728, 0, 23427, 0, -25727, 0, 23462, 0, -25726, 0, 23480, 0, -25725, 0, 23491, 0, -25724, 0, 23495, 0, -25723, 0, 23497, 0, -25722, 0, 23508, 0, -25721, 0, 23504, 0, -25720, 0, 23524, 0, -25719, 0, 23526, 0, -25718, 0, 23522, 0, -25717, 0, 23518, 0, -25716, 0, 23525, 0, -25715, 0, 23531, 0, -25714, 0, 23536, 0, -25713, 0, 23542, 0, -25712, 0, 23539, 0, -25711, 0, 23557, 0, -25710, 0, 23559, 0, -25709, 0, 23560, 0, -25708, 0, 23565, 0, -25707, 0, 23571, 0, -25706, 0, 23584, 0, -25705, 0, 23586, 0, -25704, 0, 23592, 0, -25703, 0, 23608, 0, -25702, 0, 23609, 0, -25701, 0, 23617, 0, -25700, 0, 23622, 0, -25699, 0, 23630, 0, -25698, 0, 23635, 0, -25697, 0, 23632, 0, -25696, 0, 23631, 0, -25695, 0, 23409, 0, -25694, 0, 23660, 0, -25693, 0, 23662, 0, -25692, 0, 20066, 0, -25691, 0, 23670, 0, -25690, 0, 23673, 0, -25689, 0, 23692, 0, -25688, 0, 23697, 0, -25687, 0, 23700, 0, -25686, 0, 22939, 0, -25685, 0, 23723, 0, -25684, 0, 23739, 0, -25683, 0, 23734, 0, -25682, 0, 23740, 0, -25681, 0, 23735, 0, -25680, 0, 23749, 0, -25679, 0, 23742, 0, -25678, 0, 23751, 0, -25677, 0, 23769, 0, -25676, 0, 23785, 0, -25675, 0, 23805, 0, -25674, 0, 23802, 0, -25673, 0, 23789, 0, -25672, 0, 23948, 0, -25671, 0, 23786, 0, -25670, 0, 23819, 0, -25669, 0, 23829, 0, -25668, 0, 23831, 0, -25667, 0, 23900, 0, -25666, 0, 23839, 0, -25665, 0, 23835, 0, -25664, 0, 23825, 0, -25663, 0, 23828, 0, -25662, 0, 23842, 0, -25661, 0, 23834, 0, -25660, 0, 23833, 0, -25659, 0, 23832, 0, -25658, 0, 23884, 0, -25657, 0, 23890, 0, -25656, 0, 23886, 0, -25655, 0, 23883, 0, -25654, 0, 23916, 0, -25653, 0, 23923, 0, -25652, 0, 23926, 0, -25651, 0, 23943, 0, -25650, 0, 23940, 0, -25649, 0, 23938, 0, -25648, 0, 23970, 0, -25647, 0, 23965, 0, -25646, 0, 23980, 0, -25645, 0, 23982, 0, -25644, 0, 23997, 0, -25643, 0, 23952, 0, -25642, 0, 23991, 0, -25641, 0, 23996, 0, -25640, 0, 24009, 0, -25639, 0, 24013, 0, -25638, 0, 24019, 0, -25637, 0, 24018, 0, -25636, 0, 24022, 0, -25635, 0, 24027, 0, -25634, 0, 24043, 0, -25633, 0, 24050, 0, -25632, 0, 24053, 0, -25631, 0, 24075, 0, -25630, 0, 24090, 0, -25629, 0, 24089, 0, -25628, 0, 24081, 0, -25627, 0, 24091, 0, -25626, 0, 24118, 0, -25625, 0, 24119, 0, -25624, 0, 24132, 0, -25623, 0, 24131, 0, -25622, 0, 24128, 0, -25621, 0, 24142, 0, -25620, 0, 24151, 0, -25619, 0, 24148, 0, -25618, 0, 24159, 0, -25617, 0, 24162, 0, -25616, 0, 24164, 0, -25615, 0, 24135, 0, -25614, 0, 24181, 0, -25613, 0, 24182, 0, -25612, 0, 24186, 0, -25611, 0, -24900, 0, -25610, 0, 24191, 0, -25609, 0, 24224, 0, -25608, 0, 24257, 0, -25607, 0, 24258, 0, -25606, 0, 24264, 0, -25605, 0, 24272, 0, -25604, 0, 24271, 0, -25536, 0, 24278, 0, -25535, 0, 24291, 0, -25534, 0, 24285, 0, -25533, 0, 24282, 0, -25532, 0, 24283, 0, -25531, 0, 24290, 0, -25530, 0, 24289, 0, -25529, 0, 24296, 0, -25528, 0, 24297, 0, -25527, 0, 24300, 0, -25526, 0, 24305, 0, -25525, 0, 24307, 0, -25524, 0, 24304, 0, -25523, 0, 24308, 0, -25522, 0, 24312, 0, -25521, 0, 24318, 0, -25520, 0, 24323, 0, -25519, 0, 24329, 0, -25518, 0, 24413, 0, -25517, 0, 24412, 0, -25516, 0, 24331, 0, -25515, 0, 24337, 0, -25514, 0, 24342, 0, -25513, 0, 24361, 0, -25512, 0, 24365, 0, -25511, 0, 24376, 0, -25510, 0, 24385, 0, -25509, 0, 24392, 0, -25508, 0, 24396, 0, -25507, 0, 24398, 0, -25506, 0, 24367, 0, -25505, 0, 24401, 0, -25504, 0, 24406, 0, -25503, 0, 24407, 0, -25502, 0, 24409, 0, -25501, 0, 24417, 0, -25500, 0, 24429, 0, -25499, 0, 24435, 0, -25498, 0, 24439, 0, -25497, 0, 24451, 0, -25496, 0, 24450, 0, -25495, 0, 24447, 0, -25494, 0, 24458, 0, -25493, 0, 24456, 0, -25492, 0, 24465, 0, -25491, 0, 24455, 0, -25490, 0, 24478, 0, -25489, 0, 24473, 0, -25488, 0, 24472, 0, -25487, 0, 24480, 0, -25486, 0, 24488, 0, -25485, 0, 24493, 0, -25484, 0, 24508, 0, -25483, 0, 24534, 0, -25482, 0, 24571, 0, -25481, 0, 24548, 0, -25480, 0, 24568, 0, -25479, 0, 24561, 0, -25478, 0, 24541, 0, -25477, 0, 24755, 0, -25476, 0, 24575, 0, -25475, 0, 24609, 0, -25474, 0, 24672, 0, -25472, 0, 24601, 0, -25471, 0, 24592, 0, -25470, 0, 24617, 0, -25469, 0, 24590, 0, -25468, 0, 24625, 0, -25467, 0, 24603, 0, -25466, 0, 24597, 0, -25465, 0, 24619, 0, -25464, 0, 24614, 0, -25463, 0, 24591, 0, -25462, 0, 24634, 0, -25461, 0, 24666, 0, -25460, 0, 24641, 0, -25459, 0, 24682, 0, -25458, 0, 24695, 0, -25457, 0, 24671, 0, -25456, 0, 24650, 0, -25455, 0, 24646, 0, -25454, 0, 24653, 0, -25453, 0, 24675, 0, -25452, 0, 24643, 0, -25451, 0, 24676, 0, -25450, 0, 24642, 0, -25449, 0, 24684, 0, -25448, 0, 24683, 0, -25447, 0, 24665, 0, -25446, 0, 24705, 0, -25445, 0, 24717, 0, -25444, 0, 24807, 0, -25443, 0, 24707, 0, -25442, 0, 24730, 0, -25441, 0, 24708, 0, -25440, 0, 24731, 0, -25439, 0, 24726, 0, -25438, 0, 24727, 0, -25437, 0, 24722, 0, -25436, 0, 24743, 0, -25435, 0, 24715, 0, -25434, 0, 24801, 0, -25433, 0, 24760, 0, -25432, 0, 24800, 0, -25431, 0, 24787, 0, -25430, 0, 24756, 0, -25429, 0, 24560, 0, -25428, 0, 24765, 0, -25427, 0, 24774, 0, -25426, 0, 24757, 0, -25425, 0, 24792, 0, -25424, 0, 24909, 0, -25423, 0, 24853, 0, -25422, 0, 24838, 0, -25421, 0, 24822, 0, -25420, 0, 24823, 0, -25419, 0, 24832, 0, -25418, 0, 24820, 0, -25417, 0, 24826, 0, -25416, 0, 24835, 0, -25415, 0, 24865, 0, -25414, 0, 24827, 0, -25413, 0, 24817, 0, -25412, 0, 24845, 0, -25411, 0, 24846, 0, -25410, 0, 24903, 0, -25409, 0, 24894, 0, -25408, 0, 24872, 0, -25407, 0, 24871, 0, -25406, 0, 24906, 0, -25405, 0, 24895, 0, -25404, 0, 24892, 0, -25403, 0, 24876, 0, -25402, 0, 24884, 0, -25401, 0, 24893, 0, -25400, 0, 24898, 0, -25399, 0, 24900, 0, -25398, 0, 24947, 0, -25397, 0, 24951, 0, -25396, 0, 24920, 0, -25395, 0, 24921, 0, -25394, 0, 24922, 0, -25393, 0, 24939, 0, -25392, 0, 24948, 0, -25391, 0, 24943, 0, -25390, 0, 24933, 0, -25389, 0, 24945, 0, -25388, 0, 24927, 0, -25387, 0, 24925, 0, -25386, 0, 24915, 0, -25385, 0, 24949, 0, -25384, 0, 24985, 0, -25383, 0, 24982, 0, -25382, 0, 24967, 0, -25381, 0, 25004, 0, -25380, 0, 24980, 0, -25379, 0, 24986, 0, -25378, 0, 24970, 0, -25377, 0, 24977, 0, -25376, 0, 25003, 0, -25375, 0, 25006, 0, -25374, 0, 25036, 0, -25373, 0, 25034, 0, -25372, 0, 25033, 0, -25371, 0, 25079, 0, -25370, 0, 25032, 0, -25369, 0, 25027, 0, -25368, 0, 25030, 0, -25367, 0, 25018, 0, -25366, 0, 25035, 0, -25365, 0, 32633, 0, -25364, 0, 25037, 0, -25363, 0, 25062, 0, -25362, 0, 25059, 0, -25361, 0, 25078, 0, -25360, 0, 25082, 0, -25359, 0, 25076, 0, -25358, 0, 25087, 0, -25357, 0, 25085, 0, -25356, 0, 25084, 0, -25355, 0, 25086, 0, -25354, 0, 25088, 0, -25353, 0, 25096, 0, -25352, 0, 25097, 0, -25351, 0, 25101, 0, -25350, 0, 25100, 0, -25349, 0, 25108, 0, -25348, 0, 25115, 0, -25280, 0, 25118, 0, -25279, 0, 25121, 0, -25278, 0, 25130, 0, -25277, 0, 25134, 0, -25276, 0, 25136, 0, -25275, 0, 25138, 0, -25274, 0, 25139, 0, -25273, 0, 25153, 0, -25272, 0, 25166, 0, -25271, 0, 25182, 0, -25270, 0, 25187, 0, -25269, 0, 25179, 0, -25268, 0, 25184, 0, -25267, 0, 25192, 0, -25266, 0, 25212, 0, -25265, 0, 25218, 0, -25264, 0, 25225, 0, -25263, 0, 25214, 0, -25262, 0, 25234, 0, -25261, 0, 25235, 0, -25260, 0, 25238, 0, -25259, 0, 25300, 0, -25258, 0, 25219, 0, -25257, 0, 25236, 0, -25256, 0, 25303, 0, -25255, 0, 25297, 0, -25254, 0, 25275, 0, -25253, 0, 25295, 0, -25252, 0, 25343, 0, -25251, 0, 25286, 0, -25250, 0, 25812, 0, -25249, 0, 25288, 0, -25248, 0, 25308, 0, -25247, 0, 25292, 0, -25246, 0, 25290, 0, -25245, 0, 25282, 0, -25244, 0, 25287, 0, -25243, 0, 25243, 0, -25242, 0, 25289, 0, -25241, 0, 25356, 0, -25240, 0, 25326, 0, -25239, 0, 25329, 0, -25238, 0, 25383, 0, -25237, 0, 25346, 0, -25236, 0, 25352, 0, -25235, 0, 25327, 0, -25234, 0, 25333, 0, -25233, 0, 25424, 0, -25232, 0, 25406, 0, -25231, 0, 25421, 0, -25230, 0, 25628, 0, -25229, 0, 25423, 0, -25228, 0, 25494, 0, -25227, 0, 25486, 0, -25226, 0, 25472, 0, -25225, 0, 25515, 0, -25224, 0, 25462, 0, -25223, 0, 25507, 0, -25222, 0, 25487, 0, -25221, 0, 25481, 0, -25220, 0, 25503, 0, -25219, 0, 25525, 0, -25218, 0, 25451, 0, -25216, 0, 25449, 0, -25215, 0, 25534, 0, -25214, 0, 25577, 0, -25213, 0, 25536, 0, -25212, 0, 25542, 0, -25211, 0, 25571, 0, -25210, 0, 25545, 0, -25209, 0, 25554, 0, -25208, 0, 25590, 0, -25207, 0, 25540, 0, -25206, 0, 25622, 0, -25205, 0, 25652, 0, -25204, 0, 25606, 0, -25203, 0, 25619, 0, -25202, 0, 25638, 0, -25201, 0, 25654, 0, -25200, 0, 25885, 0, -25199, 0, 25623, 0, -25198, 0, 25640, 0, -25197, 0, 25615, 0, -25196, 0, 25703, 0, -25195, 0, 25711, 0, -25194, 0, 25718, 0, -25193, 0, 25678, 0, -25192, 0, 25898, 0, -25191, 0, 25749, 0, -25190, 0, 25747, 0, -25189, 0, 25765, 0, -25188, 0, 25769, 0, -25187, 0, 25736, 0, -25186, 0, 25788, 0, -25185, 0, 25818, 0, -25184, 0, 25810, 0, -25183, 0, 25797, 0, -25182, 0, 25799, 0, -25181, 0, 25787, 0, -25180, 0, 25816, 0, -25179, 0, 25794, 0, -25178, 0, 25841, 0, -25177, 0, 25831, 0, -25176, 0, -32247, 0, -25175, 0, 25824, 0, -25174, 0, 25825, 0, -25173, 0, 25260, 0, -25172, 0, 25827, 0, -25171, 0, 25839, 0, -25170, 0, 25900, 0, -25169, 0, 25846, 0, -25168, 0, 25844, 0, -25167, 0, 25842, 0, -25166, 0, 25850, 0, -25165, 0, 25856, 0, -25164, 0, 25853, 0, -25163, 0, 25880, 0, -25162, 0, 25884, 0, -25161, 0, 25861, 0, -25160, 0, 25892, 0, -25159, 0, 25891, 0, -25158, 0, 25899, 0, -25157, 0, 25908, 0, -25156, 0, 25909, 0, -25155, 0, 25911, 0, -25154, 0, 25910, 0, -25153, 0, 25912, 0, -25152, 0, 30027, 0, -25151, 0, 25928, 0, -25150, 0, 25942, 0, -25149, 0, 25941, 0, -25148, 0, 25933, 0, -25147, 0, 25944, 0, -25146, 0, 25950, 0, -25145, 0, 25949, 0, -25144, 0, 25970, 0, -25143, 0, 25976, 0, -25142, 0, 25986, 0, -25141, 0, 25987, 0, -25140, 0, -29814, 0, -25139, 0, 26011, 0, -25138, 0, 26015, 0, -25137, 0, 26027, 0, -25136, 0, 26039, 0, -25135, 0, 26051, 0, -25134, 0, 26054, 0, -25133, 0, 26049, 0, -25132, 0, 26052, 0, -25131, 0, 26060, 0, -25130, 0, 26066, 0, -25129, 0, 26075, 0, -25128, 0, 26073, 0, -25127, 0, 26080, 0, -25126, 0, 26081, 0, -25125, 0, 26097, 0, -25124, 0, 26482, 0, -25123, 0, 26122, 0, -25122, 0, 26115, 0, -25121, 0, 26107, 0, -25120, 0, 26483, 0, -25119, 0, 26165, 0, -25118, 0, 26166, 0, -25117, 0, 26164, 0, -25116, 0, 26140, 0, -25115, 0, 26191, 0, -25114, 0, 26180, 0, -25113, 0, 26185, 0, -25112, 0, 26177, 0, -25111, 0, 26206, 0, -25110, 0, 26205, 0, -25109, 0, 26212, 0, -25108, 0, 26215, 0, -25107, 0, 26216, 0, -25106, 0, 26207, 0, -25105, 0, 26210, 0, -25104, 0, 26224, 0, -25103, 0, 26243, 0, -25102, 0, 26248, 0, -25101, 0, 26254, 0, -25100, 0, 26249, 0, -25099, 0, 26244, 0, -25098, 0, 26264, 0, -25097, 0, 26269, 0, -25096, 0, 26305, 0, -25095, 0, 26297, 0, -25094, 0, 26313, 0, -25093, 0, 26302, 0, -25092, 0, 26300, 0, -25024, 0, 26308, 0, -25023, 0, 26296, 0, -25022, 0, 26326, 0, -25021, 0, 26330, 0, -25020, 0, 26336, 0, -25019, 0, 26175, 0, -25018, 0, 26342, 0, -25017, 0, 26345, 0, -25016, 0, 26352, 0, -25015, 0, 26357, 0, -25014, 0, 26359, 0, -25013, 0, 26383, 0, -25012, 0, 26390, 0, -25011, 0, 26398, 0, -25010, 0, 26406, 0, -25009, 0, 26407, 0, -25008, 0, -26824, 0, -25007, 0, 26414, 0, -25006, 0, 26431, 0, -25005, 0, 26422, 0, -25004, 0, 26433, 0, -25003, 0, 26424, 0, -25002, 0, 26423, 0, -25001, 0, 26438, 0, -25000, 0, 26462, 0, -24999, 0, 26464, 0, -24998, 0, 26457, 0, -24997, 0, 26467, 0, -24996, 0, 26468, 0, -24995, 0, 26505, 0, -24994, 0, 26480, 0, -24993, 0, 26537, 0, -24992, 0, 26492, 0, -24991, 0, 26474, 0, -24990, 0, 26508, 0, -24989, 0, 26507, 0, -24988, 0, 26534, 0, -24987, 0, 26529, 0, -24986, 0, 26501, 0, -24985, 0, 26551, 0, -24984, 0, 26607, 0, -24983, 0, 26548, 0, -24982, 0, 26604, 0, -24981, 0, 26547, 0, -24980, 0, 26601, 0, -24979, 0, 26552, 0, -24978, 0, 26596, 0, -24977, 0, 26590, 0, -24976, 0, 26589, 0, -24975, 0, 26594, 0, -24974, 0, 26606, 0, -24973, 0, 26553, 0, -24972, 0, 26574, 0, -24971, 0, 26566, 0, -24970, 0, 26599, 0, -24969, 0, 27292, 0, -24968, 0, 26654, 0, -24967, 0, 26694, 0, -24966, 0, 26665, 0, -24965, 0, 26688, 0, -24964, 0, 26701, 0, -24963, 0, 26674, 0, -24962, 0, 26702, 0, -24960, 0, 26803, 0, -24959, 0, 26667, 0, -24958, 0, 26713, 0, -24957, 0, 26723, 0, -24956, 0, 26743, 0, -24955, 0, 26751, 0, -24954, 0, 26783, 0, -24953, 0, 26767, 0, -24952, 0, 26797, 0, -24951, 0, 26772, 0, -24950, 0, 26781, 0, -24949, 0, 26779, 0, -24948, 0, 26755, 0, -24947, 0, 27310, 0, -24946, 0, 26809, 0, -24945, 0, 26740, 0, -24944, 0, 26805, 0, -24943, 0, 26784, 0, -24942, 0, 26810, 0, -24941, 0, 26895, 0, -24940, 0, 26765, 0, -24939, 0, 26750, 0, -24938, 0, 26881, 0, -24937, 0, 26826, 0, -24936, 0, 26888, 0, -24935, 0, 26840, 0, -24934, 0, 26914, 0, -24933, 0, 26918, 0, -24932, 0, 26849, 0, -24931, 0, 26892, 0, -24930, 0, 26829, 0, -24929, 0, 26836, 0, -24928, 0, 26855, 0, -24927, 0, 26837, 0, -24926, 0, 26934, 0, -24925, 0, 26898, 0, -24924, 0, 26884, 0, -24923, 0, 26839, 0, -24922, 0, 26851, 0, -24921, 0, 26917, 0, -24920, 0, 26873, 0, -24919, 0, 26848, 0, -24918, 0, 26863, 0, -24917, 0, 26920, 0, -24916, 0, 26922, 0, -24915, 0, 26906, 0, -24914, 0, 26915, 0, -24913, 0, 26913, 0, -24912, 0, 26822, 0, -24911, 0, 27001, 0, -24910, 0, 26999, 0, -24909, 0, 26972, 0, -24908, 0, 27000, 0, -24907, 0, 26987, 0, -24906, 0, 26964, 0, -24905, 0, 27006, 0, -24904, 0, 26990, 0, -24903, 0, 26937, 0, -24902, 0, 26996, 0, -24901, 0, 26941, 0, -24900, 0, 26969, 0, -24899, 0, 26928, 0, -24898, 0, 26977, 0, -24897, 0, 26974, 0, -24896, 0, 26973, 0, -24895, 0, 27009, 0, -24894, 0, 26986, 0, -24893, 0, 27058, 0, -24892, 0, 27054, 0, -24891, 0, 27088, 0, -24890, 0, 27071, 0, -24889, 0, 27073, 0, -24888, 0, 27091, 0, -24887, 0, 27070, 0, -24886, 0, 27086, 0, -24885, 0, 23528, 0, -24884, 0, 27082, 0, -24883, 0, 27101, 0, -24882, 0, 27067, 0, -24881, 0, 27075, 0, -24880, 0, 27047, 0, -24879, 0, 27182, 0, -24878, 0, 27025, 0, -24877, 0, 27040, 0, -24876, 0, 27036, 0, -24875, 0, 27029, 0, -24874, 0, 27060, 0, -24873, 0, 27102, 0, -24872, 0, 27112, 0, -24871, 0, 27138, 0, -24870, 0, 27163, 0, -24869, 0, 27135, 0, -24868, 0, 27402, 0, -24867, 0, 27129, 0, -24866, 0, 27122, 0, -24865, 0, 27111, 0, -24864, 0, 27141, 0, -24863, 0, 27057, 0, -24862, 0, 27166, 0, -24861, 0, 27117, 0, -24860, 0, 27156, 0, -24859, 0, 27115, 0, -24858, 0, 27146, 0, -24857, 0, 27154, 0, -24856, 0, 27329, 0, -24855, 0, 27171, 0, -24854, 0, 27155, 0, -24853, 0, 27204, 0, -24852, 0, 27148, 0, -24851, 0, 27250, 0, -24850, 0, 27190, 0, -24849, 0, 27256, 0, -24848, 0, 27207, 0, -24847, 0, 27234, 0, -24846, 0, 27225, 0, -24845, 0, 27238, 0, -24844, 0, 27208, 0, -24843, 0, 27192, 0, -24842, 0, 27170, 0, -24841, 0, 27280, 0, -24840, 0, 27277, 0, -24839, 0, 27296, 0, -24838, 0, 27268, 0, -24837, 0, 27298, 0, -24836, 0, 27299, 0, -24768, 0, 27287, 0, -24767, 0, -31209, 0, -24766, 0, 27323, 0, -24765, 0, 27331, 0, -24764, 0, 27330, 0, -24763, 0, 27320, 0, -24762, 0, 27315, 0, -24761, 0, 27308, 0, -24760, 0, 27358, 0, -24759, 0, 27345, 0, -24758, 0, 27359, 0, -24757, 0, 27306, 0, -24756, 0, 27354, 0, -24755, 0, 27370, 0, -24754, 0, 27387, 0, -24753, 0, 27397, 0, -24752, 0, -31210, 0, -24751, 0, 27386, 0, -24750, 0, 27410, 0, -24749, 0, 27414, 0, -24748, 0, -25807, 0, -24747, 0, 27423, 0, -24746, 0, 27448, 0, -24745, 0, 27447, 0, -24744, 0, 30428, 0, -24743, 0, 27449, 0, -24742, 0, -26386, 0, -24741, 0, 27463, 0, -24740, 0, 27459, 0, -24739, 0, 27465, 0, -24738, 0, 27472, 0, -24737, 0, 27481, 0, -24736, 0, 27476, 0, -24735, 0, 27483, 0, -24734, 0, 27487, 0, -24733, 0, 27489, 0, -24732, 0, 27512, 0, -24731, 0, 27513, 0, -24730, 0, 27519, 0, -24729, 0, 27520, 0, -24728, 0, 27524, 0, -24727, 0, 27523, 0, -24726, 0, 27533, 0, -24725, 0, 27544, 0, -24724, 0, 27541, 0, -24723, 0, 27550, 0, -24722, 0, 27556, 0, -24721, 0, 27562, 0, -24720, 0, 27563, 0, -24719, 0, 27567, 0, -24718, 0, 27570, 0, -24717, 0, 27569, 0, -24716, 0, 27571, 0, -24715, 0, 27575, 0, -24714, 0, 27580, 0, -24713, 0, 27590, 0, -24712, 0, 27595, 0, -24711, 0, 27603, 0, -24710, 0, 27615, 0, -24709, 0, 27628, 0, -24708, 0, 27627, 0, -24707, 0, 27635, 0, -24706, 0, 27631, 0, -24704, 0, -24898, 0, -24703, 0, 27656, 0, -24702, 0, 27667, 0, -24701, 0, 27668, 0, -24700, 0, 27675, 0, -24699, 0, 27684, 0, -24698, 0, 27683, 0, -24697, 0, 27742, 0, -24696, 0, 27733, 0, -24695, 0, 27746, 0, -24694, 0, 27754, 0, -24693, 0, 27778, 0, -24692, 0, 27789, 0, -24691, 0, 27802, 0, -24690, 0, 27777, 0, -24689, 0, 27803, 0, -24688, 0, 27774, 0, -24687, 0, 27752, 0, -24686, 0, 27763, 0, -24685, 0, 27794, 0, -24684, 0, 27792, 0, -24683, 0, 27844, 0, -24682, 0, 27889, 0, -24681, 0, 27859, 0, -24680, 0, 27837, 0, -24679, 0, 27863, 0, -24678, 0, 27845, 0, -24677, 0, 27869, 0, -24676, 0, 27822, 0, -24675, 0, 27825, 0, -24674, 0, 27838, 0, -24673, 0, 27834, 0, -24672, 0, 27867, 0, -24671, 0, 27887, 0, -24670, 0, 27865, 0, -24669, 0, 27882, 0, -24668, 0, 27935, 0, -24667, 0, -30643, 0, -24666, 0, 27958, 0, -24665, 0, 27947, 0, -24664, 0, 27965, 0, -24663, 0, 27960, 0, -24662, 0, 27929, 0, -24661, 0, 27957, 0, -24660, 0, 27955, 0, -24659, 0, 27922, 0, -24658, 0, 27916, 0, -24657, 0, 28003, 0, -24656, 0, 28051, 0, -24655, 0, 28004, 0, -24654, 0, 27994, 0, -24653, 0, 28025, 0, -24652, 0, 27993, 0, -24651, 0, 28046, 0, -24650, 0, 28053, 0, -24649, 0, 28644, 0, -24648, 0, 28037, 0, -24647, 0, 28153, 0, -24646, 0, 28181, 0, -24645, 0, 28170, 0, -24644, 0, 28085, 0, -24643, 0, 28103, 0, -24642, 0, 28134, 0, -24641, 0, 28088, 0, -24640, 0, 28102, 0, -24639, 0, 28140, 0, -24638, 0, 28126, 0, -24637, 0, 28108, 0, -24636, 0, 28136, 0, -24635, 0, 28114, 0, -24634, 0, 28101, 0, -24633, 0, 28154, 0, -24632, 0, 28121, 0, -24631, 0, 28132, 0, -24630, 0, 28117, 0, -24629, 0, 28138, 0, -24628, 0, 28142, 0, -24627, 0, 28205, 0, -24626, 0, 28270, 0, -24625, 0, 28206, 0, -24624, 0, 28185, 0, -24623, 0, 28274, 0, -24622, 0, 28255, 0, -24621, 0, 28222, 0, -24620, 0, 28195, 0, -24619, 0, 28267, 0, -24618, 0, 28203, 0, -24617, 0, 28278, 0, -24616, 0, 28237, 0, -24615, 0, 28191, 0, -24614, 0, 28227, 0, -24613, 0, 28218, 0, -24612, 0, 28238, 0, -24611, 0, 28196, 0, -24610, 0, 28415, 0, -24609, 0, 28189, 0, -24608, 0, 28216, 0, -24607, 0, 28290, 0, -24606, 0, 28330, 0, -24605, 0, 28312, 0, -24604, 0, 28361, 0, -24603, 0, 28343, 0, -24602, 0, 28371, 0, -24601, 0, 28349, 0, -24600, 0, 28335, 0, -24599, 0, 28356, 0, -24598, 0, 28338, 0, -24597, 0, 28372, 0, -24596, 0, 28373, 0, -24595, 0, 28303, 0, -24594, 0, 28325, 0, -24593, 0, 28354, 0, -24592, 0, 28319, 0, -24591, 0, 28481, 0, -24590, 0, 28433, 0, -24589, 0, 28748, 0, -24588, 0, 28396, 0, -24587, 0, 28408, 0, -24586, 0, 28414, 0, -24585, 0, 28479, 0, -24584, 0, 28402, 0, -24583, 0, 28465, 0, -24582, 0, 28399, 0, -24581, 0, 28466, 0, -24580, 0, 28364, 0, -8128, 0, 28478, 0, -8127, 0, 28435, 0, -8126, 0, 28407, 0, -8125, 0, 28550, 0, -8124, 0, 28538, 0, -8123, 0, 28536, 0, -8122, 0, 28545, 0, -8121, 0, 28544, 0, -8120, 0, 28527, 0, -8119, 0, 28507, 0, -8118, 0, 28659, 0, -8117, 0, 28525, 0, -8116, 0, 28546, 0, -8115, 0, 28540, 0, -8114, 0, 28504, 0, -8113, 0, 28558, 0, -8112, 0, 28561, 0, -8111, 0, 28610, 0, -8110, 0, 28518, 0, -8109, 0, 28595, 0, -8108, 0, 28579, 0, -8107, 0, 28577, 0, -8106, 0, 28580, 0, -8105, 0, 28601, 0, -8104, 0, 28614, 0, -8103, 0, 28586, 0, -8102, 0, 28639, 0, -8101, 0, 28629, 0, -8100, 0, 28652, 0, -8099, 0, 28628, 0, -8098, 0, 28632, 0, -8097, 0, 28657, 0, -8096, 0, 28654, 0, -8095, 0, 28635, 0, -8094, 0, 28681, 0, -8093, 0, 28683, 0, -8092, 0, 28666, 0, -8091, 0, 28689, 0, -8090, 0, 28673, 0, -8089, 0, 28687, 0, -8088, 0, 28670, 0, -8087, 0, 28699, 0, -8086, 0, 28698, 0, -8085, 0, 28532, 0, -8084, 0, 28701, 0, -8083, 0, 28696, 0, -8082, 0, 28703, 0, -8081, 0, 28720, 0, -8080, 0, 28734, 0, -8079, 0, 28722, 0, -8078, 0, 28753, 0, -8077, 0, 28771, 0, -8076, 0, 28825, 0, -8075, 0, 28818, 0, -8074, 0, 28847, 0, -8073, 0, 28913, 0, -8072, 0, 28844, 0, -8071, 0, 28856, 0, -8070, 0, 28851, 0, -8069, 0, 28846, 0, -8068, 0, 28895, 0, -8067, 0, 28875, 0, -8066, 0, 28893, 0, -8064, 0, 28889, 0, -8063, 0, 28937, 0, -8062, 0, 28925, 0, -8061, 0, 28956, 0, -8060, 0, 28953, 0, -8059, 0, 29029, 0, -8058, 0, 29013, 0, -8057, 0, 29064, 0, -8056, 0, 29030, 0, -8055, 0, 29026, 0, -8054, 0, 29004, 0, -8053, 0, 29014, 0, -8052, 0, 29036, 0, -8051, 0, 29071, 0, -8050, 0, 29179, 0, -8049, 0, 29060, 0, -8048, 0, 29077, 0, -8047, 0, 29096, 0, -8046, 0, 29100, 0, -8045, 0, 29143, 0, -8044, 0, 29113, 0, -8043, 0, 29118, 0, -8042, 0, 29138, 0, -8041, 0, 29129, 0, -8040, 0, 29140, 0, -8039, 0, 29134, 0, -8038, 0, 29152, 0, -8037, 0, 29164, 0, -8036, 0, 29159, 0, -8035, 0, 29173, 0, -8034, 0, 29180, 0, -8033, 0, 29177, 0, -8032, 0, 29183, 0, -8031, 0, 29197, 0, -8030, 0, 29200, 0, -8029, 0, 29211, 0, -8028, 0, 29224, 0, -8027, 0, 29229, 0, -8026, 0, 29228, 0, -8025, 0, 29232, 0, -8024, 0, 29234, 0, -8023, 0, 29243, 0, -8022, 0, 29244, 0, -8021, 0, 29247, 0, -8020, 0, 29248, 0, -8019, 0, 29254, 0, -8018, 0, 29259, 0, -8017, 0, 29272, 0, -8016, 0, 29300, 0, -8015, 0, 29310, 0, -8014, 0, 29314, 0, -8013, 0, 29313, 0, -8012, 0, 29319, 0, -8011, 0, 29330, 0, -8010, 0, 29334, 0, -8009, 0, 29346, 0, -8008, 0, 29351, 0, -8007, 0, 29369, 0, -8006, 0, 29362, 0, -8005, 0, 29379, 0, -8004, 0, 29382, 0, -8003, 0, 29380, 0, -8002, 0, 29390, 0, -8001, 0, 29394, 0, -8000, 0, 29410, 0, -7999, 0, 29408, 0, -7998, 0, 29409, 0, -7997, 0, 29433, 0, -7996, 0, 29431, 0, -7995, 0, 20495, 0, -7994, 0, 29463, 0, -7993, 0, 29450, 0, -7992, 0, 29468, 0, -7991, 0, 29462, 0, -7990, 0, 29469, 0, -7989, 0, 29492, 0, -7988, 0, 29487, 0, -7987, 0, 29481, 0, -7986, 0, 29477, 0, -7985, 0, 29502, 0, -7984, 0, 29518, 0, -7983, 0, 29519, 0, -7982, 0, -24872, 0, -7981, 0, 29527, 0, -7980, 0, 29546, 0, -7979, 0, 29544, 0, -7978, 0, 29552, 0, -7977, 0, 29560, 0, -7976, 0, 29557, 0, -7975, 0, 29563, 0, -7974, 0, 29562, 0, -7973, 0, 29640, 0, -7972, 0, 29619, 0, -7971, 0, 29646, 0, -7970, 0, 29627, 0, -7969, 0, 29632, 0, -7968, 0, 29669, 0, -7967, 0, 29678, 0, -7966, 0, 29662, 0, -7965, 0, 29858, 0, -7964, 0, 29701, 0, -7963, 0, 29807, 0, -7962, 0, 29733, 0, -7961, 0, 29688, 0, -7960, 0, 29746, 0, -7959, 0, 29754, 0, -7958, 0, 29781, 0, -7957, 0, 29759, 0, -7956, 0, 29791, 0, -7955, 0, 29785, 0, -7954, 0, 29761, 0, -7953, 0, 29788, 0, -7952, 0, 29801, 0, -7951, 0, 29808, 0, -7950, 0, 29795, 0, -7949, 0, 29802, 0, -7948, 0, 29814, 0, -7947, 0, 29822, 0, -7946, 0, 29835, 0, -7945, 0, 29854, 0, -7944, 0, 29863, 0, -7943, 0, 29898, 0, -7942, 0, 29903, 0, -7941, 0, 29908, 0, -7940, 0, 29681, 0, -7872, 0, 29920, 0, -7871, 0, 29923, 0, -7870, 0, 29927, 0, -7869, 0, 29929, 0, -7868, 0, 29934, 0, -7867, 0, 29938, 0, -7866, 0, 29936, 0, -7865, 0, 29937, 0, -7864, 0, 29944, 0, -7863, 0, 29943, 0, -7862, 0, 29956, 0, -7861, 0, 29955, 0, -7860, 0, 29957, 0, -7859, 0, 29964, 0, -7858, 0, 29966, 0, -7857, 0, 29965, 0, -7856, 0, 29973, 0, -7855, 0, 29971, 0, -7854, 0, 29982, 0, -7853, 0, 29990, 0, -7852, 0, 29996, 0, -7851, 0, 30012, 0, -7850, 0, 30020, 0, -7849, 0, 30029, 0, -7848, 0, 30026, 0, -7847, 0, 30025, 0, -7846, 0, 30043, 0, -7845, 0, 30022, 0, -7844, 0, 30042, 0, -7843, 0, 30057, 0, -7842, 0, 30052, 0, -7841, 0, 30055, 0, -7840, 0, 30059, 0, -7839, 0, 30061, 0, -7838, 0, 30072, 0, -7837, 0, 30070, 0, -7836, 0, 30086, 0, -7835, 0, 30087, 0, -7834, 0, 30068, 0, -7833, 0, 30090, 0, -7832, 0, 30089, 0, -7831, 0, 30082, 0, -7830, 0, 30100, 0, -7829, 0, 30106, 0, -7828, 0, 30109, 0, -7827, 0, 30117, 0, -7826, 0, 30115, 0, -7825, 0, 30146, 0, -7824, 0, 30131, 0, -7823, 0, 30147, 0, -7822, 0, 30133, 0, -7821, 0, 30141, 0, -7820, 0, 30136, 0, -7819, 0, 30140, 0, -7818, 0, 30129, 0, -7817, 0, 30157, 0, -7816, 0, 30154, 0, -7815, 0, 30162, 0, -7814, 0, 30169, 0, -7813, 0, 30179, 0, -7812, 0, 30174, 0, -7811, 0, 30206, 0, -7810, 0, 30207, 0, -7808, 0, 30204, 0, -7807, 0, 30209, 0, -7806, 0, 30192, 0, -7805, 0, 30202, 0, -7804, 0, 30194, 0, -7803, 0, 30195, 0, -7802, 0, 30219, 0, -7801, 0, 30221, 0, -7800, 0, 30217, 0, -7799, 0, 30239, 0, -7798, 0, 30247, 0, -7797, 0, 30240, 0, -7796, 0, 30241, 0, -7795, 0, 30242, 0, -7794, 0, 30244, 0, -7793, 0, 30260, 0, -7792, 0, 30256, 0, -7791, 0, 30267, 0, -7790, 0, 30279, 0, -7789, 0, 30280, 0, -7788, 0, 30278, 0, -7787, 0, 30300, 0, -7786, 0, 30296, 0, -7785, 0, 30305, 0, -7784, 0, 30306, 0, -7783, 0, 30312, 0, -7782, 0, 30313, 0, -7781, 0, 30314, 0, -7780, 0, 30311, 0, -7779, 0, 30316, 0, -7778, 0, 30320, 0, -7777, 0, 30322, 0, -7776, 0, 30326, 0, -7775, 0, 30328, 0, -7774, 0, 30332, 0, -7773, 0, 30336, 0, -7772, 0, 30339, 0, -7771, 0, 30344, 0, -7770, 0, 30347, 0, -7769, 0, 30350, 0, -7768, 0, 30358, 0, -7767, 0, 30355, 0, -7766, 0, 30361, 0, -7765, 0, 30362, 0, -7764, 0, 30384, 0, -7763, 0, 30388, 0, -7762, 0, 30392, 0, -7761, 0, 30393, 0, -7760, 0, 30394, 0, -7759, 0, 30402, 0, -7758, 0, 30413, 0, -7757, 0, 30422, 0, -7756, 0, 30418, 0, -7755, 0, 30430, 0, -7754, 0, 30433, 0, -7753, 0, 30437, 0, -7752, 0, 30439, 0, -7751, 0, 30442, 0, -7750, 0, -31185, 0, -7749, 0, 30459, 0, -7748, 0, 30472, 0, -7747, 0, 30471, 0, -7746, 0, 30468, 0, -7745, 0, 30505, 0, -7744, 0, 30500, 0, -7743, 0, 30494, 0, -7742, 0, 30501, 0, -7741, 0, 30502, 0, -7740, 0, 30491, 0, -7739, 0, 30519, 0, -7738, 0, 30520, 0, -7737, 0, 30535, 0, -7736, 0, 30554, 0, -7735, 0, 30568, 0, -7734, 0, 30571, 0, -7733, 0, 30555, 0, -7732, 0, 30565, 0, -7731, 0, 30591, 0, -7730, 0, 30590, 0, -7729, 0, 30585, 0, -7728, 0, 30606, 0, -7727, 0, 30603, 0, -7726, 0, 30609, 0, -7725, 0, 30624, 0, -7724, 0, 30622, 0, -7723, 0, 30640, 0, -7722, 0, 30646, 0, -7721, 0, 30649, 0, -7720, 0, 30655, 0, -7719, 0, 30652, 0, -7718, 0, 30653, 0, -7717, 0, 30651, 0, -7716, 0, 30663, 0, -7715, 0, 30669, 0, -7714, 0, 30679, 0, -7713, 0, 30682, 0, -7712, 0, 30684, 0, -7711, 0, 30691, 0, -7710, 0, 30702, 0, -7709, 0, 30716, 0, -7708, 0, 30732, 0, -7707, 0, 30738, 0, -7706, 0, 31014, 0, -7705, 0, 30752, 0, -7704, 0, 31018, 0, -7703, 0, 30789, 0, -7702, 0, 30862, 0, -7701, 0, 30836, 0, -7700, 0, 30854, 0, -7699, 0, 30844, 0, -7698, 0, 30874, 0, -7697, 0, 30860, 0, -7696, 0, 30883, 0, -7695, 0, 30901, 0, -7694, 0, 30890, 0, -7693, 0, 30895, 0, -7692, 0, 30929, 0, -7691, 0, 30918, 0, -7690, 0, 30923, 0, -7689, 0, 30932, 0, -7688, 0, 30910, 0, -7687, 0, 30908, 0, -7686, 0, 30917, 0, -7685, 0, 30922, 0, -7684, 0, 30956, 0, -7616, 0, 30951, 0, -7615, 0, 30938, 0, -7614, 0, 30973, 0, -7613, 0, 30964, 0, -7612, 0, 30983, 0, -7611, 0, 30994, 0, -7610, 0, 30993, 0, -7609, 0, 31001, 0, -7608, 0, 31020, 0, -7607, 0, 31019, 0, -7606, 0, 31040, 0, -7605, 0, 31072, 0, -7604, 0, 31063, 0, -7603, 0, 31071, 0, -7602, 0, 31066, 0, -7601, 0, 31061, 0, -7600, 0, 31059, 0, -7599, 0, 31098, 0, -7598, 0, 31103, 0, -7597, 0, 31114, 0, -7596, 0, 31133, 0, -7595, 0, 31143, 0, -7594, 0, -24757, 0, -7593, 0, 31146, 0, -7592, 0, 31150, 0, -7591, 0, 31155, 0, -7590, 0, 31161, 0, -7589, 0, 31162, 0, -7588, 0, 31177, 0, -7587, 0, 31189, 0, -7586, 0, 31207, 0, -7585, 0, 31212, 0, -7584, 0, 31201, 0, -7583, 0, 31203, 0, -7582, 0, 31240, 0, -7581, 0, 31245, 0, -7580, 0, 31256, 0, -7579, 0, 31257, 0, -7578, 0, 31264, 0, -7577, 0, 31263, 0, -7576, 0, 31104, 0, -7575, 0, 31281, 0, -7574, 0, 31291, 0, -7573, 0, 31294, 0, -7572, 0, 31287, 0, -7571, 0, 31299, 0, -7570, 0, 31319, 0, -7569, 0, 31305, 0, -7568, 0, 31329, 0, -7567, 0, 31330, 0, -7566, 0, 31337, 0, -7565, 0, -24675, 0, -7564, 0, 31344, 0, -7563, 0, 31353, 0, -7562, 0, 31357, 0, -7561, 0, 31368, 0, -7560, 0, 31383, 0, -7559, 0, 31381, 0, -7558, 0, 31384, 0, -7557, 0, 31382, 0, -7556, 0, 31401, 0, -7555, 0, 31432, 0, -7554, 0, 31408, 0, -7552, 0, 31414, 0, -7551, 0, 31429, 0, -7550, 0, 31428, 0, -7549, 0, 31423, 0, -7548, 0, -28541, 0, -7547, 0, 31431, 0, -7546, 0, 31434, 0, -7545, 0, 31437, 0, -7544, 0, 31439, 0, -7543, 0, 31445, 0, -7542, 0, 31443, 0, -7541, 0, 31449, 0, -7540, 0, 31450, 0, -7539, 0, 31453, 0, -7538, 0, 31457, 0, -7537, 0, 31458, 0, -7536, 0, 31462, 0, -7535, 0, 31469, 0, -7534, 0, 31472, 0, -7533, 0, 31490, 0, -7532, 0, 31503, 0, -7531, 0, 31498, 0, -7530, 0, 31494, 0, -7529, 0, 31539, 0, -7528, 0, 31512, 0, -7527, 0, 31513, 0, -7526, 0, 31518, 0, -7525, 0, 31541, 0, -7524, 0, 31528, 0, -7523, 0, 31542, 0, -7522, 0, 31568, 0, -7521, 0, 31610, 0, -7520, 0, 31492, 0, -7519, 0, 31565, 0, -7518, 0, 31499, 0, -7517, 0, 31564, 0, -7516, 0, 31557, 0, -7515, 0, 31605, 0, -7514, 0, 31589, 0, -7513, 0, 31604, 0, -7512, 0, 31591, 0, -7511, 0, 31600, 0, -7510, 0, 31601, 0, -7509, 0, 31596, 0, -7508, 0, 31598, 0, -7507, 0, 31645, 0, -7506, 0, 31640, 0, -7505, 0, 31647, 0, -7504, 0, 31629, 0, -7503, 0, 31644, 0, -7502, 0, 31642, 0, -7501, 0, 31627, 0, -7500, 0, 31634, 0, -7499, 0, 31631, 0, -7498, 0, 31581, 0, -7497, 0, 31641, 0, -7496, 0, 31691, 0, -7495, 0, 31681, 0, -7494, 0, 31692, 0, -7493, 0, 31695, 0, -7492, 0, 31668, 0, -7491, 0, 31686, 0, -7490, 0, 31709, 0, -7489, 0, 31721, 0, -7488, 0, 31761, 0, -7487, 0, 31764, 0, -7486, 0, 31718, 0, -7485, 0, 31717, 0, -7484, 0, 31840, 0, -7483, 0, 31744, 0, -7482, 0, 31751, 0, -7481, 0, 31763, 0, -7480, 0, 31731, 0, -7479, 0, 31735, 0, -7478, 0, 31767, 0, -7477, 0, 31757, 0, -7476, 0, 31734, 0, -7475, 0, 31779, 0, -7474, 0, 31783, 0, -7473, 0, 31786, 0, -7472, 0, 31775, 0, -7471, 0, 31799, 0, -7470, 0, 31787, 0, -7469, 0, 31805, 0, -7468, 0, 31820, 0, -7467, 0, 31811, 0, -7466, 0, 31828, 0, -7465, 0, 31823, 0, -7464, 0, 31808, 0, -7463, 0, 31824, 0, -7462, 0, 31832, 0, -7461, 0, 31839, 0, -7460, 0, 31844, 0, -7459, 0, 31830, 0, -7458, 0, 31845, 0, -7457, 0, 31852, 0, -7456, 0, 31861, 0, -7455, 0, 31875, 0, -7454, 0, 31888, 0, -7453, 0, 31908, 0, -7452, 0, 31917, 0, -7451, 0, 31906, 0, -7450, 0, 31915, 0, -7449, 0, 31905, 0, -7448, 0, 31912, 0, -7447, 0, 31923, 0, -7446, 0, 31922, 0, -7445, 0, 31921, 0, -7444, 0, 31918, 0, -7443, 0, 31929, 0, -7442, 0, 31933, 0, -7441, 0, 31936, 0, -7440, 0, 31941, 0, -7439, 0, 31938, 0, -7438, 0, 31960, 0, -7437, 0, 31954, 0, -7436, 0, 31964, 0, -7435, 0, 31970, 0, -7434, 0, -25797, 0, -7433, 0, 31983, 0, -7432, 0, 31986, 0, -7431, 0, 31988, 0, -7430, 0, 31990, 0, -7429, 0, 31994, 0, -7428, 0, 32006, 0, -7360, 0, 32002, 0, -7359, 0, 32028, 0, -7358, 0, 32021, 0, -7357, 0, 32010, 0, -7356, 0, 32069, 0, -7355, 0, 32075, 0, -7354, 0, 32046, 0, -7353, 0, 32050, 0, -7352, 0, 32063, 0, -7351, 0, 32053, 0, -7350, 0, 32070, 0, -7349, 0, 32115, 0, -7348, 0, 32086, 0, -7347, 0, 32078, 0, -7346, 0, 32114, 0, -7345, 0, 32104, 0, -7344, 0, 32110, 0, -7343, 0, 32079, 0, -7342, 0, 32099, 0, -7341, 0, 32147, 0, -7340, 0, 32137, 0, -7339, 0, 32091, 0, -7338, 0, 32143, 0, -7337, 0, 32125, 0, -7336, 0, 32155, 0, -7335, 0, 32186, 0, -7334, 0, 32174, 0, -7333, 0, 32163, 0, -7332, 0, 32181, 0, -7331, 0, 32199, 0, -7330, 0, 32189, 0, -7329, 0, 32171, 0, -7328, 0, 32317, 0, -7327, 0, 32162, 0, -7326, 0, 32175, 0, -7325, 0, 32220, 0, -7324, 0, 32184, 0, -7323, 0, 32159, 0, -7322, 0, 32176, 0, -7321, 0, 32216, 0, -7320, 0, 32221, 0, -7319, 0, 32228, 0, -7318, 0, 32222, 0, -7317, 0, 32251, 0, -7316, 0, 32242, 0, -7315, 0, 32225, 0, -7314, 0, 32261, 0, -7313, 0, 32266, 0, -7312, 0, 32291, 0, -7311, 0, 32289, 0, -7310, 0, 32274, 0, -7309, 0, 32305, 0, -7308, 0, 32287, 0, -7307, 0, 32265, 0, -7306, 0, 32267, 0, -7305, 0, 32290, 0, -7304, 0, 32326, 0, -7303, 0, 32358, 0, -7302, 0, 32315, 0, -7301, 0, 32309, 0, -7300, 0, 32313, 0, -7299, 0, 32323, 0, -7298, 0, 32311, 0, -7296, 0, 32306, 0, -7295, 0, 32314, 0, -7294, 0, 32359, 0, -7293, 0, 32349, 0, -7292, 0, 32342, 0, -7291, 0, 32350, 0, -7290, 0, 32345, 0, -7289, 0, 32346, 0, -7288, 0, 32377, 0, -7287, 0, 32362, 0, -7286, 0, 32361, 0, -7285, 0, 32380, 0, -7284, 0, 32379, 0, -7283, 0, 32387, 0, -7282, 0, 32213, 0, -7281, 0, 32381, 0, -7280, 0, -28754, 0, -7279, 0, 32383, 0, -7278, 0, 32392, 0, -7277, 0, 32393, 0, -7276, 0, 32396, 0, -7275, 0, 32402, 0, -7274, 0, 32400, 0, -7273, 0, 32403, 0, -7272, 0, 32404, 0, -7271, 0, 32406, 0, -7270, 0, 32398, 0, -7269, 0, 32411, 0, -7268, 0, 32412, 0, -7267, 0, 32568, 0, -7266, 0, 32570, 0, -7265, 0, 32581, 0, -7264, 0, 32588, 0, -7263, 0, 32589, 0, -7262, 0, 32590, 0, -7261, 0, 32592, 0, -7260, 0, 32593, 0, -7259, 0, 32597, 0, -7258, 0, 32596, 0, -7257, 0, 32600, 0, -7256, 0, 32607, 0, -7255, 0, 32608, 0, -7254, 0, 32616, 0, -7253, 0, 32617, 0, -7252, 0, 32615, 0, -7251, 0, 32632, 0, -7250, 0, 32642, 0, -7249, 0, 32646, 0, -7248, 0, 32643, 0, -7247, 0, 32648, 0, -7246, 0, 32647, 0, -7245, 0, 32652, 0, -7244, 0, 32660, 0, -7243, 0, 32670, 0, -7242, 0, 32669, 0, -7241, 0, 32666, 0, -7240, 0, 32675, 0, -7239, 0, 32687, 0, -7238, 0, 32690, 0, -7237, 0, 32697, 0, -7236, 0, 32686, 0, -7235, 0, 32694, 0, -7234, 0, 32696, 0, -7233, 0, -29839, 0, -7232, 0, 32709, 0, -7231, 0, 32710, 0, -7230, 0, 32714, 0, -7229, 0, 32725, 0, -7228, 0, 32724, 0, -7227, 0, 32737, 0, -7226, 0, 32742, 0, -7225, 0, 32745, 0, -7224, 0, 32755, 0, -7223, 0, 32761, 0, -7222, 0, -26404, 0, -7221, 0, -32762, 0, -7220, 0, -32764, 0, -7219, 0, -32757, 0, -7218, 0, -32750, 0, -7217, 0, -32744, 0, -7216, 0, -32743, 0, -7215, 0, -32740, 0, -7214, 0, -32735, 0, -7213, 0, -32728, 0, -7212, 0, -32705, 0, -7211, 0, -32709, 0, -7210, 0, -32694, 0, -7209, 0, -32698, 0, -7208, 0, -32686, 0, -7207, 0, -32680, 0, -7206, 0, -32678, 0, -7205, 0, -32673, 0, -7204, 0, -32670, 0, -7203, 0, -32664, 0, -7202, 0, -32653, 0, -7201, 0, -32654, 0, -7200, 0, -32656, 0, -7199, 0, -32650, 0, -7198, 0, -32647, 0, -7197, 0, -32643, 0, -7196, 0, -32641, 0, -7195, 0, -32636, 0, -7194, 0, -32634, 0, -7193, 0, -32635, 0, -7192, 0, -32613, 0, -7191, 0, -32621, 0, -7190, 0, -32614, 0, -7189, 0, -32595, 0, -7188, 0, 20880, 0, -7187, 0, -32596, 0, -7186, 0, -32549, 0, -7185, 0, -32539, 0, -7184, 0, -32551, 0, -7183, 0, -32547, 0, -7182, 0, -32572, 0, -7181, 0, -32550, 0, -7180, 0, -32554, 0, -7179, 0, -32503, 0, -7178, 0, -32529, 0, -7177, 0, -32527, 0, -7176, 0, -32485, 0, -7175, 0, -32471, 0, -7174, 0, -32477, 0, -7173, 0, -32465, 0, -7172, 0, -32437, 0, -7104, 0, -26997, 0, -7103, 0, -32442, 0, -7102, 0, -32450, 0, -7101, 0, -32429, 0, -7100, 0, -32431, 0, -7099, 0, -32516, 0, -7098, 0, -32399, 0, -7097, 0, -32402, 0, -7096, 0, -32411, 0, -7095, 0, -32410, 0, -7094, 0, -32396, 0, -7093, 0, -32381, 0, -7092, 0, -32376, 0, -7091, 0, -32374, 0, -7090, 0, -32384, 0, -7089, 0, -32382, 0, -7088, 0, -32352, 0, -7087, 0, -32363, 0, -7086, 0, -32348, 0, -7085, 0, -32349, 0, -7084, 0, -32417, 0, -7083, 0, -32365, 0, -7082, 0, -32343, 0, -7081, 0, -32336, 0, -7080, 0, -32331, 0, -7079, 0, -32322, 0, -7078, 0, -32328, 0, -7077, 0, -32323, 0, -7076, 0, -32320, 0, -7075, 0, -32318, 0, -7074, 0, -32326, 0, -7073, 0, -32311, 0, -7072, 0, -32307, 0, -7071, 0, -32303, 0, -7070, 0, -32295, 0, -7069, 0, -32296, 0, -7068, 0, -32312, 0, -7067, 0, -32294, 0, -7066, 0, -32289, 0, -7065, 0, -32288, 0, -7064, 0, -32281, 0, -7063, 0, -32262, 0, -7062, 0, -32261, 0, -7061, 0, -32258, 0, -7060, 0, -32255, 0, -7059, 0, -32254, 0, -7058, 0, -32251, 0, -7057, 0, -32249, 0, -7056, 0, -32246, 0, -7055, 0, -32243, 0, -7054, 0, -32240, 0, -7053, 0, -32234, 0, -7052, 0, -32215, 0, -7051, 0, -32213, 0, -7050, 0, -32200, 0, -7049, 0, -32205, 0, -7048, 0, -32192, 0, -7047, 0, -32167, 0, -7046, 0, -32168, 0, -7045, 0, -32163, 0, -7044, 0, -32166, 0, -7043, 0, -32161, 0, -7042, 0, -32156, 0, -7040, 0, -32158, 0, -7039, 0, -32152, 0, -7038, 0, -32150, 0, -7037, 0, -32149, 0, -7036, 0, -32210, 0, -7035, 0, -32143, 0, -7034, 0, -32137, 0, -7033, 0, -32136, 0, -7032, 0, -32130, 0, -7031, 0, -32115, 0, -7030, 0, -32110, 0, -7029, 0, -32085, 0, -7028, 0, -32097, 0, -7027, 0, -32069, 0, -7026, 0, -32084, 0, -7025, 0, -32031, 0, -7024, 0, -32029, 0, -7023, 0, -32033, 0, -7022, 0, -32046, 0, -7021, 0, -32012, 0, -7020, 0, -32013, 0, -7019, 0, -32006, 0, -7018, 0, -31853, 0, -7017, 0, -31997, 0, -7016, 0, -32005, 0, -7015, 0, -32007, 0, -7014, 0, -32034, 0, -7013, 0, -31994, 0, -7012, 0, -32036, 0, -7011, 0, -31991, 0, -7010, 0, -32039, 0, -7009, 0, -31947, 0, -7008, 0, -31948, 0, -7007, 0, -31978, 0, -7006, 0, -31950, 0, -7005, 0, -31951, 0, -7004, 0, -31936, 0, -7003, 0, -31943, 0, -7002, 0, -31920, 0, -7001, 0, -31931, 0, -7000, 0, -31953, 0, -6999, 0, -31957, 0, -6998, 0, -31977, 0, -6997, 0, -31976, 0, -6996, 0, -31867, 0, -6995, 0, -31846, 0, -6994, 0, -31830, 0, -6993, 0, -31841, 0, -6992, 0, -31838, 0, -6991, 0, -31850, 0, -6990, 0, -31965, 0, -6989, 0, -31858, 0, -6988, 0, -31865, 0, -6987, 0, -31862, 0, -6986, 0, -31876, 0, -6985, 0, -31819, 0, -6984, 0, -31885, 0, -6983, 0, -31883, 0, -6982, 0, -31840, 0, -6981, 0, -31863, 0, -6980, 0, -31832, 0, -6979, 0, -31756, 0, -6978, 0, -31725, 0, -6977, 0, -31765, 0, -6976, 0, -31794, 0, -6975, 0, -31747, 0, -6974, 0, -31741, 0, -6973, 0, -31784, 0, -6972, 0, -31733, 0, -6971, 0, -31807, 0, -6970, 0, -31753, 0, -6969, 0, -31737, 0, -6968, 0, -31776, 0, -6967, 0, -31758, 0, -6966, 0, -31731, 0, -6965, 0, -31710, 0, -6964, 0, -31712, 0, -6963, 0, -31811, 0, -6962, 0, -31688, 0, -6961, 0, -31482, 0, -6960, 0, -31749, 0, -6959, 0, -31635, 0, -6958, 0, -31702, 0, -6957, 0, -31684, 0, -6956, 0, -31398, 0, -6955, 0, -31612, 0, -6954, 0, -31625, 0, -6953, 0, -31637, 0, -6952, 0, -31571, 0, -6951, 0, -31634, 0, -6950, 0, -31614, 0, -6949, 0, -31639, 0, -6948, 0, -31674, 0, -6947, 0, -31700, 0, -6946, 0, -31633, 0, -6945, 0, -31623, 0, -6944, 0, -31691, 0, -6943, 0, -31542, 0, -6942, 0, -31646, 0, -6941, 0, -31559, 0, -6940, 0, -31553, 0, -6939, 0, -31585, 0, -6938, 0, -31527, 0, -6937, 0, -31539, 0, -6936, 0, -31557, 0, -6935, 0, -31526, 0, -6934, 0, -31536, 0, -6933, 0, -31551, 0, -6932, 0, -31546, 0, -6931, 0, -31530, 0, -6930, 0, -31583, 0, -6929, 0, -31455, 0, -6928, 0, -31489, 0, -6927, 0, -31500, 0, -6926, 0, -31465, 0, -6925, 0, -31464, 0, -6924, 0, -31444, 0, -6923, 0, -31457, 0, -6922, 0, -31467, 0, -6921, 0, -31468, 0, -6920, 0, -31492, 0, -6919, 0, -31424, 0, -6918, 0, -31389, 0, -6917, 0, -31400, 0, -6916, 0, -31416, 0, -6848, 0, -31423, 0, -6847, 0, -31230, 0, -6846, 0, -31413, 0, -6845, 0, -31403, 0, -6844, 0, -31360, 0, -6843, 0, -31324, 0, -6842, 0, -31352, 0, -6841, 0, -31343, 0, -6840, 0, -31350, 0, -6839, 0, -31320, 0, -6838, 0, -31379, 0, -6837, 0, -31340, 0, -6836, 0, -31333, 0, -6835, 0, -31254, 0, -6834, 0, -31353, 0, -6833, 0, -31332, 0, -6832, 0, -31369, 0, -6831, 0, -31362, 0, -6830, 0, -31344, 0, -6829, 0, -31287, 0, -6828, 0, -31302, 0, -6827, 0, -31281, 0, -6826, 0, -31303, 0, -6825, 0, -31280, 0, -6824, 0, -31275, 0, -6823, 0, -31267, 0, -6822, 0, -31259, 0, -6821, 0, -31268, 0, -6820, 0, -31239, 0, -6819, 0, -31222, 0, -6818, 0, -31213, 0, -6817, 0, -31221, 0, -6816, 0, -31234, 0, -6815, 0, -31238, 0, -6814, 0, -31226, 0, -6813, 0, -31198, 0, -6812, 0, -31206, 0, -6811, 0, -31184, 0, -6810, 0, -31169, 0, -6809, 0, -31155, 0, -6808, 0, 20053, 0, -6807, 0, -31148, 0, -6806, 0, -31137, 0, -6805, 0, -31129, 0, -6804, 0, -31119, 0, -6803, 0, -31085, 0, -6802, 0, -31069, 0, -6801, 0, -31063, 0, -6800, 0, -31062, 0, -6799, 0, -31093, 0, -6798, 0, -31092, 0, -6797, 0, -31050, 0, -6796, 0, -31057, 0, -6795, 0, -31036, 0, -6794, 0, -31034, 0, -6793, 0, -31056, 0, -6792, 0, -31031, 0, -6791, 0, -30685, 0, -6790, 0, -31061, 0, -6789, 0, -31020, 0, -6788, 0, -31010, 0, -6787, 0, -30999, 0, -6786, 0, -30996, 0, -6784, 0, -31009, 0, -6783, 0, -31013, 0, -6782, 0, -30993, 0, -6781, 0, -30958, 0, -6780, 0, -30970, 0, -6779, 0, -30968, 0, -6778, 0, -30976, 0, -6777, 0, -30973, 0, -6776, 0, -30981, 0, -6775, 0, -30959, 0, -6774, 0, -30967, 0, -6773, 0, -30963, 0, -6772, 0, -30983, 0, -6771, 0, -30966, 0, -6770, 0, -30924, 0, -6769, 0, -30913, 0, -6768, 0, -30921, 0, -6767, 0, -30917, 0, -6766, 0, -30939, 0, -6765, 0, -30935, 0, -6764, 0, -30950, 0, -6763, 0, -30880, 0, -6762, 0, -30881, 0, -6761, 0, -30856, 0, -6760, 0, -30900, 0, -6759, 0, -30898, 0, -6758, 0, -30860, 0, -6757, 0, -30889, 0, -6756, 0, -30872, 0, -6755, 0, -30866, 0, -6754, 0, -30887, 0, -6753, 0, -30893, 0, -6752, 0, -30877, 0, -6751, 0, -30870, 0, -6750, 0, -30715, 0, -6749, 0, -30814, 0, -6748, 0, -30817, 0, -6747, 0, -30846, 0, -6746, 0, -30801, 0, -6745, 0, -30773, 0, -6744, 0, -30787, 0, -6743, 0, -30784, 0, -6742, 0, -30768, 0, -6741, 0, -26922, 0, -6740, 0, -30805, 0, -6739, 0, -30780, 0, -6738, 0, -30797, 0, -6737, 0, -30777, 0, -6736, 0, -30778, 0, -6735, 0, -30789, 0, -6734, 0, -30737, 0, -6733, 0, -30734, 0, -6732, 0, -30752, 0, -6731, 0, -30705, 0, -6730, 0, -30707, 0, -6729, 0, -30722, 0, -6728, 0, -30730, 0, -6727, 0, -30729, 0, -6726, 0, -30706, 0, -6725, 0, -30766, 0, -6724, 0, -30703, 0, -6723, 0, -30698, 0, -6722, 0, -30699, 0, -6721, 0, -30686, 0, -6720, 0, -30687, 0, -6719, 0, -30671, 0, -6718, 0, -30666, 0, -6717, 0, -30663, 0, -6716, 0, -30681, 0, -6715, 0, -30661, 0, -6714, 0, -30652, 0, -6713, 0, -30654, 0, -6712, 0, -30638, 0, -6711, 0, -30631, 0, -6710, 0, -30626, 0, -6709, 0, -30622, 0, -6708, 0, -30613, 0, -6707, 0, -30591, 0, -6706, 0, -30594, 0, -6705, 0, -30562, 0, -6704, 0, -30603, 0, -6703, 0, -30595, 0, -6702, 0, -30539, 0, -6701, 0, -30606, 0, -6700, 0, -30590, 0, -6699, 0, -30569, 0, -6698, 0, -30574, 0, -6697, 0, -30546, 0, -6696, 0, -30567, 0, -6695, 0, -30558, 0, -6694, 0, -30579, 0, -6693, 0, -30556, 0, -6692, 0, -30544, 0, -6691, 0, -30529, 0, -6690, 0, -30543, 0, -6689, 0, -30525, 0, -6688, 0, -30524, 0, -6687, 0, -30508, 0, -6686, 0, -30504, 0, -6685, 0, -30503, 0, -6684, 0, -30499, 0, -6683, 0, -30471, 0, -6682, 0, -30462, 0, -6681, 0, -30468, 0, -6680, 0, -30476, 0, -6679, 0, -30488, 0, -6678, 0, -30478, 0, -6677, 0, -30460, 0, -6676, 0, -30452, 0, -6675, 0, -30454, 0, -6674, 0, -30445, 0, -6673, 0, -30397, 0, -6672, 0, -30434, 0, -6671, 0, -30427, 0, -6670, 0, -30422, 0, -6669, 0, -30421, 0, -6668, 0, -30399, 0, -6667, 0, -30396, 0, -6666, 0, -30405, 0, -6665, 0, -30410, 0, -6664, 0, -30408, 0, -6663, 0, -30388, 0, -6662, 0, -30435, 0, -6661, 0, -30368, 0, -6660, 0, -30370, 0, -6592, 0, -30362, 0, -6591, 0, -30364, 0, -6590, 0, -30355, 0, -6589, 0, -30358, 0, -6588, 0, -30353, 0, -6587, 0, -30348, 0, -6586, 0, -30345, 0, -6585, 0, -30338, 0, -6584, 0, -30333, 0, -6583, 0, -30328, 0, -6582, 0, -30326, 0, -6581, 0, -30317, 0, -6580, 0, -30312, 0, -6579, 0, -30303, 0, -6578, 0, -30295, 0, -6577, 0, -30298, 0, -6576, 0, -30292, 0, -6575, 0, -30289, 0, -6574, 0, -30286, 0, -6573, 0, -30278, 0, -6572, 0, -30275, 0, -6571, 0, -30273, 0, -6570, 0, -30272, 0, -6569, 0, -30246, 0, -6568, 0, -30244, 0, -6567, 0, -30243, 0, -6566, 0, -30233, 0, -6565, 0, -30220, 0, -6564, 0, -30216, 0, -6563, 0, -30205, 0, -6562, 0, -30186, 0, -6561, 0, -30192, 0, -6560, 0, -30196, 0, -6559, 0, -30181, 0, -6558, 0, -30179, 0, -6557, 0, -30171, 0, -6556, 0, -30154, 0, -6555, 0, -30143, 0, -6554, 0, -30117, 0, -6553, 0, -30126, 0, -6552, 0, -30138, 0, -6551, 0, -30136, 0, -6550, 0, -30084, 0, -6549, 0, -30099, 0, -6548, 0, -30100, 0, -6547, 0, -30110, 0, -6546, 0, -30075, 0, -6545, 0, -30078, 0, -6544, 0, -30076, 0, -6543, 0, -30040, 0, -6542, 0, -30047, 0, -6541, 0, -30063, 0, -6540, 0, -30043, 0, -6539, 0, -30042, 0, -6538, 0, -30054, 0, -6537, 0, -30045, 0, -6536, 0, -30012, 0, -6535, 0, -30003, 0, -6534, 0, -30014, 0, -6533, 0, -29990, 0, -6532, 0, -29973, 0, -6531, 0, -29965, 0, -6530, 0, -29977, 0, -6528, 0, -29980, 0, -6527, 0, -29967, 0, -6526, 0, -29932, 0, -6525, 0, -29984, 0, -6524, 0, -29982, 0, -6523, 0, -29961, 0, -6522, 0, -29986, 0, -6521, 0, -29989, 0, -6520, 0, -29940, 0, -6519, 0, -29945, 0, -6518, 0, -29926, 0, -6517, 0, -29983, 0, -6516, 0, -29930, 0, -6515, 0, -29936, 0, -6514, 0, -29929, 0, -6513, 0, -29920, 0, -6512, 0, -29901, 0, -6511, 0, -26709, 0, -6510, 0, -29914, 0, -6509, 0, -29909, 0, -6508, 0, -29890, 0, -6507, 0, -29912, 0, -6506, 0, -29887, 0, -6505, 0, -29876, 0, -6504, 0, -29873, 0, -6503, 0, -29874, 0, -6502, 0, -29879, 0, -6501, 0, -29866, 0, -6500, 0, -29861, 0, -6499, 0, -29862, 0, -6498, 0, -29845, 0, -6497, 0, -29857, 0, -6496, 0, -29844, 0, -6495, 0, -29841, 0, -6494, 0, -29836, 0, -6493, 0, -29827, 0, -6492, 0, -29824, 0, -6491, 0, -29812, 0, -6490, 0, -29810, 0, -6489, 0, -29806, 0, -6488, 0, -29805, 0, -6487, 0, -29802, 0, -6486, 0, -29799, 0, -6485, 0, -29798, 0, -6484, 0, -29638, 0, -6483, 0, -29631, 0, -6482, 0, -29633, 0, -6481, 0, -29624, 0, -6480, 0, -29620, 0, -6479, 0, -29618, 0, -6478, 0, -29616, 0, -6477, 0, -29611, 0, -6476, 0, -29598, 0, -6475, 0, -29588, 0, -6474, 0, -29576, 0, -6473, 0, -29574, 0, -6472, 0, -29566, 0, -6471, 0, -29559, 0, -6470, 0, -29563, 0, -6469, 0, -29558, 0, -6468, 0, -29555, 0, -6467, 0, -29554, 0, -6466, 0, -29548, 0, -6465, 0, -29572, 0, -6464, 0, -29544, 0, -6463, 0, 25117, 0, -6462, 0, -29523, 0, -6461, 0, -29526, 0, -6460, 0, -29507, 0, -6459, 0, -29518, 0, -6458, 0, -29517, 0, -6457, 0, -29522, 0, -6456, 0, -29514, 0, -6455, 0, -29496, 0, -6454, 0, -29503, 0, -6453, 0, -29468, 0, -6452, 0, -29469, 0, -6451, 0, -29478, 0, -6450, 0, -29443, 0, -6449, 0, -29446, 0, -6448, 0, -29445, 0, -6447, 0, -29436, 0, -6446, 0, -29435, 0, -6445, 0, -29430, 0, -6444, 0, -29433, 0, -6443, 0, -29425, 0, -6442, 0, -29427, 0, -6441, 0, -29424, 0, -6440, 0, -24754, 0, -6439, 0, -29421, 0, -6438, 0, -29491, 0, -6437, 0, -29420, 0, -6436, 0, -29418, 0, -6435, 0, -29337, 0, -6434, 0, -29331, 0, -6433, 0, -29327, 0, -6432, 0, -29325, 0, -6431, 0, -29311, 0, -6430, 0, -29287, 0, -6429, 0, -29246, 0, -6428, 0, -29250, 0, -6427, 0, -29254, 0, -6426, 0, -29233, 0, -6425, 0, -29222, 0, -6424, 0, -29226, 0, -6423, 0, -29236, 0, -6422, 0, -29221, 0, -6421, 0, -29237, 0, -6420, 0, -29206, 0, -6419, 0, -29205, 0, -6418, 0, -29217, 0, -6417, 0, -29213, 0, -6416, 0, -29188, 0, -6415, 0, -29176, 0, -6414, 0, -29175, 0, -6413, 0, -29185, 0, -6412, 0, -29155, 0, -6411, 0, -29154, 0, -6410, 0, -29168, 0, -6409, 0, -29153, 0, -6408, 0, -29118, 0, -6407, 0, -29131, 0, -6406, 0, -29136, 0, -6405, 0, -29132, 0, -6404, 0, -29110, 0, -6336, 0, -29113, 0, -6335, 0, -29111, 0, -6334, 0, -29108, 0, -6333, 0, -29104, 0, -6332, 0, -29112, 0, -6331, 0, -29095, 0, -6330, 0, -29084, 0, -6329, 0, -29088, 0, -6328, 0, -29142, 0, -6327, 0, -29085, 0, -6326, 0, -29099, 0, -6325, 0, -29066, 0, -6324, 0, -29070, 0, -6323, 0, -29060, 0, -6322, 0, -29055, 0, -6321, 0, -29049, 0, -6320, 0, -29051, 0, -6319, 0, -29052, 0, -6318, 0, -29045, 0, -6317, 0, -29046, 0, -6316, 0, -29037, 0, -6315, 0, -29039, 0, -6314, 0, -29036, 0, -6313, 0, -29031, 0, -6312, 0, -29014, 0, -6311, 0, -29023, 0, -6310, 0, -29012, 0, -6309, 0, -29008, 0, -6308, 0, -28986, 0, -6307, 0, -29007, 0, -6306, 0, -28994, 0, -6305, 0, -28987, 0, -6304, 0, -28984, 0, -6303, 0, -28981, 0, -6302, 0, -28965, 0, -6301, 0, -28957, 0, -6300, 0, -28932, 0, -6299, 0, -28933, 0, -6298, 0, -28949, 0, -6297, 0, -28930, 0, -6296, 0, -28918, 0, -6295, 0, -28923, 0, -6294, 0, -28907, 0, -6293, 0, -28910, 0, -6292, 0, -28903, 0, -6291, 0, -28909, 0, -6290, 0, -28900, 0, -6289, 0, -28897, 0, -6288, 0, -28901, 0, -6287, 0, -28916, 0, -6286, 0, -28890, 0, -6285, 0, -28877, 0, -6284, 0, -28869, 0, -6283, 0, -28871, 0, -6282, 0, -28859, 0, -6281, 0, -28862, 0, -6280, 0, -28866, 0, -6279, 0, -28852, 0, -6278, 0, -28855, 0, -6277, 0, -28858, 0, -6276, 0, -28850, 0, -6275, 0, -28841, 0, -6274, 0, -28836, 0, -6272, 0, -28830, 0, -6271, 0, -28829, 0, -6270, 0, -28828, 0, -6269, 0, -28772, 0, -6268, 0, -28769, 0, -6267, 0, -28765, 0, -6266, 0, -28755, 0, -6265, 0, -28753, 0, -6264, 0, -28745, 0, -6263, 0, -28710, 0, -6262, 0, -28699, 0, -6261, 0, -28702, 0, -6260, 0, -28694, 0, -6259, 0, -28689, 0, -6258, 0, -28537, 0, -6257, 0, -28684, 0, -6256, 0, -28667, 0, -6255, 0, -28679, 0, -6254, 0, -28678, 0, -6253, 0, -28655, 0, -6252, 0, -28651, 0, -6251, 0, -28639, 0, -6250, 0, -28659, 0, -6249, 0, -28642, 0, -6248, 0, -28650, 0, -6247, 0, -28661, 0, -6246, 0, -28633, 0, -6245, 0, -28618, 0, -6244, 0, -28619, 0, -6243, 0, -28615, 0, -6242, 0, -28680, 0, -6241, 0, -28593, 0, -6240, 0, -28592, 0, -6239, 0, -28591, 0, -6238, 0, -28590, 0, -6237, 0, -28658, 0, -6236, 0, -28599, 0, -6235, 0, -28610, 0, -6234, 0, -28586, 0, -6233, 0, -28584, 0, -6232, 0, -28578, 0, -6231, 0, -28568, 0, -6230, 0, -28561, 0, -6229, 0, -28554, 0, -6228, 0, -26968, 0, -6227, 0, -28558, 0, -6226, 0, -28542, 0, -6225, 0, -28547, 0, -6224, 0, -28543, 0, -6223, 0, -28544, 0, -6222, 0, -28534, 0, -6221, 0, -28535, 0, -6220, 0, -28529, 0, -6219, 0, -28504, 0, -6218, 0, -28497, 0, -6217, 0, -28495, 0, -6216, 0, -28491, 0, -6215, 0, -28446, 0, -6214, 0, -28444, 0, -6213, 0, 25160, 0, -6212, 0, -28453, 0, -6211, 0, -28414, 0, -6210, 0, -28398, 0, -6209, 0, -28391, 0, -6208, 0, -28366, 0, -6207, 0, -28368, 0, -6206, 0, -28342, 0, -6205, 0, -28330, 0, -6204, 0, -28328, 0, -6203, 0, -28317, 0, -6202, 0, -28315, 0, -6201, 0, -28311, 0, -6200, 0, -28301, 0, -6199, 0, -28302, 0, -6198, 0, -28277, 0, -6197, 0, -28279, 0, -6196, 0, -28286, 0, -6195, 0, -28254, 0, -6194, 0, -28245, 0, -6193, 0, -28241, 0, -6192, 0, -28246, 0, -6191, 0, -28235, 0, -6190, 0, -28236, 0, -6189, 0, -28230, 0, -6188, 0, -28224, 0, -6187, 0, -28223, 0, -6186, 0, -28215, 0, -6185, 0, -28213, 0, -6184, 0, -28208, 0, -6183, 0, -28202, 0, -6182, 0, -28193, 0, -6181, 0, -28191, 0, -6180, 0, -28197, 0, -6179, 0, -28164, 0, -6178, 0, -28171, 0, -6177, 0, -28170, 0, -6176, 0, -28130, 0, -6175, 0, -28161, 0, -6174, 0, -28140, 0, -6173, 0, -28116, 0, -6172, 0, -28139, 0, -6171, 0, -28143, 0, -6170, 0, -28066, 0, -6169, 0, -28073, 0, -6168, 0, -28091, 0, -6167, 0, -28087, 0, -6166, 0, -28060, 0, -6165, 0, -28088, 0, -6164, 0, -28011, 0, -6163, 0, -28097, 0, -6162, 0, -28085, 0, -6161, 0, -28080, 0, -6160, 0, -28004, 0, -6159, 0, -28010, 0, -6158, 0, -28013, 0, -6157, 0, -28005, 0, -6156, 0, -28070, 0, -6155, 0, -27953, 0, -6154, 0, -27975, 0, -6153, 0, -27977, 0, -6152, 0, -27927, 0, -6151, 0, -27889, 0, -6150, 0, -27910, 0, -6149, 0, -27836, 0, -6148, 0, -27858, 0, -6080, 0, -27879, 0, -6079, 0, -27870, 0, -6078, 0, -27878, 0, -6077, 0, -27869, 0, -6076, 0, -27846, 0, -6075, 0, -27851, 0, -6074, 0, -27845, 0, -6073, 0, -27812, 0, -6072, 0, -27808, 0, -6071, 0, -27780, 0, -6070, 0, -27794, 0, -6069, 0, -27818, 0, -6068, 0, -27728, 0, -6067, 0, -27732, 0, -6066, 0, -27731, 0, -6065, 0, -27756, 0, -6064, 0, -27719, 0, -6063, 0, -27690, 0, -6062, 0, -27689, 0, -6061, 0, -27672, 0, -6060, 0, -27675, 0, -6059, 0, -27688, 0, -6058, 0, -27709, 0, -6057, 0, -27683, 0, -6056, 0, -27696, 0, -6055, 0, -27704, 0, -6054, 0, -27676, 0, -6053, 0, -27622, 0, -6052, 0, -27628, 0, -6051, 0, -27629, 0, -6050, 0, -27645, 0, -6049, 0, -27641, 0, -6048, 0, -27632, 0, -6047, 0, -27594, 0, -6046, 0, -27605, 0, -6045, 0, -27595, 0, -6044, 0, -27615, 0, -6043, 0, -27590, 0, -6042, 0, -27583, 0, -6041, 0, -27566, 0, -6040, 0, -27580, 0, -6039, 0, -27557, 0, -6038, 0, -27552, 0, -6037, 0, -27550, 0, -6036, 0, -27554, 0, -6035, 0, -27542, 0, -6034, 0, -28119, 0, -6033, 0, -27536, 0, -6032, 0, -27531, 0, -6031, 0, -27529, 0, -6030, 0, -27523, 0, -6029, 0, -27558, 0, -6028, 0, -27524, 0, -6027, 0, -27522, 0, -6026, 0, -27519, 0, -6025, 0, -27521, 0, -6024, 0, -27262, 0, -6023, 0, -27257, 0, -6022, 0, -27254, 0, -6021, 0, -27244, 0, -6020, 0, -27242, 0, -6019, 0, -27240, 0, -6018, 0, -27239, 0, -6016, 0, -27232, 0, -6015, 0, -27224, 0, -6014, 0, -27225, 0, -6013, 0, -27219, 0, -6012, 0, -27204, 0, -6011, 0, -27205, 0, -6010, 0, -27207, 0, -6009, 0, -27202, 0, -6008, 0, -27190, 0, -6007, 0, 28662, 0, -6006, 0, -27197, 0, -6005, 0, -27187, 0, -6004, 0, -27188, 0, -6003, 0, -27179, 0, -6002, 0, -27180, 0, -6001, 0, -27178, 0, -6000, 0, -27172, 0, -5999, 0, -27167, 0, -5998, 0, -27163, 0, -5997, 0, -27166, 0, -5996, 0, -27103, 0, -5995, 0, -27096, 0, -5994, 0, -27090, 0, -5993, 0, -27089, 0, -5992, 0, -27070, 0, -5991, 0, -27060, 0, -5990, 0, -27057, 0, -5989, 0, -27061, 0, -5988, 0, -27017, 0, -5987, 0, -27044, 0, -5986, 0, -27042, 0, -5985, 0, -27043, 0, -5984, 0, -27041, 0, -5983, 0, -27034, 0, -5982, 0, -27022, 0, -5981, 0, -27028, 0, -5980, 0, -26995, 0, -5979, 0, -26984, 0, -5978, 0, -26987, 0, -5977, 0, -26985, 0, -5976, 0, -26966, 0, -5975, 0, -26969, 0, -5974, 0, -26959, 0, -5973, 0, -26958, 0, -5972, 0, -26960, 0, -5971, 0, -26956, 0, -5970, 0, -26954, 0, -5969, 0, -26952, 0, -5968, 0, -26951, 0, -5967, 0, -26930, 0, -5966, 0, -26933, 0, -5965, 0, -26935, 0, -5964, 0, -26931, 0, -5963, 0, -30387, 0, -5962, 0, -26916, 0, -5961, 0, -26867, 0, -5960, 0, -26923, 0, -5959, 0, -26887, 0, -5958, 0, -26876, 0, -5957, 0, -26874, 0, -5956, 0, -26872, 0, -5955, 0, -26861, 0, -5954, 0, -26866, 0, -5953, 0, -26863, 0, -5952, 0, -26865, 0, -5951, 0, -26858, 0, -5950, 0, -26855, 0, -5949, 0, -26844, 0, -5948, 0, -26838, 0, -5947, 0, -26832, 0, -5946, 0, -26823, 0, -5945, 0, -26819, 0, -5944, 0, -26818, 0, -5943, 0, -26812, 0, -5942, 0, -26810, 0, -5941, 0, -26808, 0, -5940, 0, -26814, 0, -5939, 0, -26807, 0, -5938, 0, -26788, 0, -5937, 0, -26784, 0, -5936, 0, -26780, 0, -5935, 0, -26778, 0, -5934, 0, -26776, 0, -5933, 0, 21202, 0, -5932, 0, -26773, 0, -5931, 0, -26767, 0, -5930, 0, -26759, 0, -5929, 0, -26747, 0, -5928, 0, -26756, 0, -5927, 0, -26751, 0, -5926, 0, -26758, 0, -5925, 0, -26746, 0, -5924, 0, -26741, 0, -5923, 0, -26737, 0, -5922, 0, -26736, 0, -5921, 0, -26724, 0, -5920, 0, -26712, 0, -5919, 0, -26714, 0, -5918, 0, -26717, 0, -5917, 0, -26701, 0, -5916, 0, -26700, 0, -5915, 0, -26685, 0, -5914, 0, -26682, 0, -5913, 0, -26680, 0, -5912, 0, -26677, 0, -5911, 0, -26660, 0, -5910, 0, -26643, 0, -5909, 0, -24753, 0, -5908, 0, -26638, 0, -5907, 0, 31455, 0, -5906, 0, -26634, 0, -5905, 0, -26635, 0, -5904, 0, -26609, 0, -5903, 0, -26612, 0, -5902, 0, -26568, 0, -5901, 0, -26588, 0, -5900, 0, -26591, 0, -5899, 0, -26569, 0, -5898, 0, -26563, 0, -5897, 0, -26554, 0, -5896, 0, -26545, 0, -5895, 0, -26549, 0, -5894, 0, -26517, 0, -5893, 0, -26513, 0, -5892, 0, -26512, 0, -5824, 0, -26511, 0, -5823, 0, -26508, 0, -5822, 0, -26509, 0, -5821, 0, -26454, 0, -5820, 0, -26449, 0, -5819, 0, -26447, 0, -5818, 0, -26442, 0, -5817, 0, -26428, 0, -5816, 0, -26429, 0, -5815, 0, -26426, 0, -5814, 0, -26391, 0, -5813, 0, -26389, 0, -5812, 0, -26365, 0, -5811, 0, -26359, 0, -5810, 0, -26350, 0, -5809, 0, -26348, 0, -5808, 0, -26344, 0, -5807, 0, -26335, 0, -5806, 0, -26339, 0, -5805, 0, -26338, 0, -5804, 0, -26332, 0, -5803, 0, -26336, 0, -5802, 0, -26324, 0, -5801, 0, -26322, 0, -5800, 0, -26307, 0, -5799, 0, -26306, 0, -5798, 0, -26302, 0, -5797, 0, -26295, 0, -5796, 0, -26299, 0, -5795, 0, -26288, 0, -5794, 0, -26293, 0, -5793, 0, -26287, 0, -5792, 0, -26286, 0, -5791, 0, -26292, 0, -5790, 0, -26283, 0, -5789, 0, -26217, 0, -5788, 0, -26216, 0, -5787, 0, -26203, 0, -5786, 0, -26195, 0, -5785, 0, -26194, 0, -5784, 0, -26180, 0, -5783, 0, -26145, 0, -5782, 0, -26149, 0, -5781, 0, -26147, 0, -5780, 0, -26152, 0, -5779, 0, -26159, 0, -5778, 0, -26131, 0, -5777, 0, -26130, 0, -5776, 0, -26127, 0, -5775, 0, -26126, 0, -5774, 0, -26117, 0, -5773, 0, -26120, 0, -5772, 0, -26111, 0, -5771, 0, -26097, 0, -5770, 0, -26107, 0, -5769, 0, -26142, 0, -5768, 0, -26087, 0, -5767, 0, -26069, 0, -5766, 0, -26057, 0, -5765, 0, -26043, 0, -5764, 0, -26046, 0, -5763, 0, -26048, 0, -5762, 0, -26045, 0, -5760, 0, -26050, 0, -5759, 0, -26027, 0, -5758, 0, -26035, 0, -5757, 0, -26021, 0, -5756, 0, -26025, 0, -5755, 0, -26017, 0, -5754, 0, -26014, 0, -5753, 0, -26011, 0, -5752, 0, -26012, 0, -5751, 0, -26007, 0, -5750, 0, -26005, 0, -5749, 0, -26006, 0, -5748, 0, -25939, 0, -5747, 0, -25936, 0, -5746, 0, -25924, 0, -5745, 0, -25920, 0, -5744, 0, -25905, 0, -5743, 0, -25903, 0, -5742, 0, -25901, 0, -5741, 0, -25900, 0, -5740, 0, -25890, 0, -5739, 0, -25889, 0, -5738, 0, -25886, 0, -5737, 0, -25885, 0, -5736, 0, -25882, 0, -5735, 0, -25873, 0, -5734, 0, -25877, 0, -5733, 0, -25874, 0, -5732, 0, -25868, 0, -5731, 0, -25871, 0, -5730, 0, -25865, 0, -5729, 0, -25861, 0, -5728, 0, -25850, 0, -5727, 0, -25832, 0, -5726, 0, -25830, 0, -5725, 0, -25825, 0, -5724, 0, -25822, 0, -5723, 0, -25821, 0, -5722, 0, -25819, 0, -5721, 0, -25817, 0, -5720, 0, -25816, 0, -5719, 0, -25815, 0, -5718, 0, -25814, 0, -5717, 0, -25810, 0, -5716, 0, -25809, 0, -5715, 0, -25806, 0, -5714, 0, -25788, 0, -5713, 0, -25789, 0, -5712, 0, -25777, 0, -5711, 0, -25779, 0, -5710, 0, -25778, 0, -5709, 0, -25775, 0, -5708, 0, -25768, 0, -5707, 0, -25740, 0, -5706, 0, -25709, 0, -5705, 0, -25725, 0, -5704, 0, -25711, 0, -5703, 0, -25706, 0, -5702, 0, -25705, 0, -5701, 0, -25697, 0, -5700, 0, -25696, 0, -5699, 0, -25688, 0, -5698, 0, -25676, 0, -5697, 0, -25664, 0, -5696, 0, -25654, 0, -5695, 0, -25671, 0, -5694, 0, -25658, 0, -5693, 0, -25649, 0, -5692, 0, -25647, 0, -5691, 0, -25646, 0, -5690, 0, -25629, 0, -5689, 0, -25630, 0, -5688, 0, -25628, 0, -5687, 0, -25644, 0, -5686, 0, -25631, 0, -5685, 0, -25542, 0, -5684, 0, -25614, 0, -5683, 0, -25615, 0, -5682, 0, -25616, 0, -5681, 0, -25579, 0, -5680, 0, -25580, 0, -5679, 0, -25591, 0, -5678, 0, -25581, 0, -5677, 0, -25588, 0, -5676, 0, -25594, 0, -5675, 0, -25592, 0, -5674, 0, -25582, 0, -5673, 0, -25590, 0, -5672, 0, -25596, 0, -5671, 0, -25554, 0, -5670, 0, -25573, 0, -5669, 0, -25563, 0, -5668, 0, -25564, 0, -5667, 0, -25567, 0, -5666, 0, -25552, 0, -5665, 0, -25529, 0, -5664, 0, -25550, 0, -5663, 0, -25530, 0, -5662, 0, -25538, 0, -5661, 0, -25510, 0, -5660, 0, -25504, 0, -5659, 0, -25497, 0, -5658, 0, -25482, 0, -5657, 0, -25480, 0, -5656, 0, -25369, 0, -5655, 0, -25364, 0, -5654, 0, -25360, 0, -5653, 0, -25335, 0, -5652, 0, -25336, 0, -5651, 0, -25365, 0, -5650, 0, -25341, 0, -5649, 0, -25338, 0, -5648, 0, -25302, 0, -5647, 0, -25306, 0, -5646, 0, -25169, 0, -5645, 0, -25309, 0, -5644, 0, -25313, 0, -5643, 0, -25276, 0, -5642, 0, -25323, 0, -5641, 0, -25326, 0, -5640, 0, -25279, 0, -5639, 0, -25281, 0, -5638, 0, -25282, 0, -5637, 0, -25274, 0, -5636, 0, -25272, 0, -5568, 0, -25251, 0, -5567, 0, -25250, 0, -5566, 0, -25244, 0, -5565, 0, -25263, 0, -5564, 0, -25264, 0, -5563, 0, -25255, 0, -5562, 0, -25230, 0, -5561, 0, -25207, 0, -5560, 0, -25209, 0, -5559, 0, -25173, 0, -5558, 0, -25233, 0, -5557, 0, -25222, 0, -5556, 0, -25190, 0, -5555, 0, -25180, 0, -5554, 0, -25175, 0, -5553, 0, -25166, 0, -5552, 0, -25148, 0, -5551, 0, -25151, 0, -5550, 0, -25157, 0, -5549, 0, -25160, 0, -5548, 0, -25158, 0, -5547, 0, -25146, 0, -5546, 0, -25137, 0, -5545, 0, -25150, 0, -5544, 0, -25127, 0, -5543, 0, -25133, 0, -5542, 0, -25096, 0, -5541, 0, -25114, 0, -5540, 0, -25107, 0, -5539, 0, -25105, 0, -5538, 0, -25091, 0, -5537, 0, -25062, 0, -5536, 0, -25061, 0, -5535, 0, -25058, 0, -5534, 0, -24971, 0, -5533, 0, -24967, 0, -5532, 0, -24963, 0, -5531, 0, -24959, 0, -5530, 0, -24952, 0, -5529, 0, -24949, 0, -5528, 0, -24948, 0, -5527, 0, -24942, 0, -5526, 0, -24939, 0, -5525, 0, -24943, 0, -5524, 0, -24931, 0, -5523, 0, -24923, 0, -5522, 0, -24919, 0, -5521, 0, -24904, 0, -5520, 0, -24918, 0, -5519, 0, -24915, 0, -5518, 0, -26783, 0, -5517, 0, -24884, 0, -5516, 0, -24882, 0, -5515, 0, -24881, 0, -5514, 0, -24880, 0, -5513, 0, -24876, 0, -5512, 0, -24868, 0, -5511, 0, -24866, 0, -5510, 0, -24867, 0, -5509, 0, -24864, 0, -5508, 0, -24859, 0, -5507, 0, -24856, 0, -5506, 0, -24849, 0, -5504, 0, -24844, 0, -5503, 0, -24842, 0, -5502, 0, -24841, 0, -5501, 0, -24839, 0, -5500, 0, -24837, 0, -5499, 0, -24836, 0, -5498, 0, -24835, 0, -5497, 0, -24825, 0, -5496, 0, -24824, 0, -5495, 0, 30391, 0, -5494, 0, -24811, 0, -5493, 0, -24799, 0, -5492, 0, -24788, 0, -5491, 0, -24770, 0, -5490, 0, -24758, 0, -5489, 0, -24750, 0, -5488, 0, -24748, 0, -5487, 0, -24733, 0, -5486, 0, -24737, 0, -5485, 0, -24736, 0, -5484, 0, -24735, 0, -5483, 0, -24730, 0, -5482, 0, -24729, 0, -5481, 0, -24724, 0, -5480, 0, -24726, 0, -5479, 0, -24713, 0, -5478, 0, -24718, 0, -5477, 0, -24714, 0, -5476, 0, -24683, 0, -5475, 0, -24676, 0, -5474, 0, -24672, 0, -5473, 0, 22575, 0, -5472, 0, 27079, 0, -5471, 0, -28583, 0, -5470, 0, 29796, 0, -5469, 0, 20956, 0, -5468, 0, 29081, 0, -4800, 0, 32394, 0, -4799, 0, -30436, 0, -4798, 0, -27832, 0, -4797, 0, -28024, 0, -4796, 0, -31524, 0, -4795, 0, 20425, 0, -4794, 0, 28859, 0, -4793, 0, 26161, 0, -4792, 0, 26824, 0, -4791, 0, -27911, 0, -4790, 0, 26363, 0, -4789, 0, 24389, 0, -4788, 0, 20008, 0, -4787, 0, 20193, 0, -4786, 0, 20220, 0, -4785, 0, 20224, 0, -4784, 0, 20227, 0, -4783, 0, 20281, 0, -4782, 0, 20310, 0, -4781, 0, 20370, 0, -4780, 0, 20362, 0, -4779, 0, 20378, 0, -4778, 0, 20372, 0, -4777, 0, 20429, 0, -4776, 0, 20544, 0, -4775, 0, 20514, 0, -4774, 0, 20479, 0, -4773, 0, 20510, 0, -4772, 0, 20550, 0, -4771, 0, 20592, 0, -4770, 0, 20546, 0, -4769, 0, 20628, 0, -4768, 0, 20724, 0, -4767, 0, 20696, 0, -4766, 0, 20810, 0, -4765, 0, 20836, 0, -4764, 0, 20893, 0, -4763, 0, 20926, 0, -4762, 0, 20972, 0, -4761, 0, 21013, 0, -4760, 0, 21148, 0, -4759, 0, 21158, 0, -4758, 0, 21184, 0, -4757, 0, 21211, 0, -4756, 0, 21248, 0, -4755, 0, 21255, 0, -4754, 0, 21284, 0, -4753, 0, 21362, 0, -4752, 0, 21395, 0, -4751, 0, 21426, 0, -4750, 0, 21469, 0, -4749, 0, -1522, 0, -4748, 0, 21660, 0, -4747, 0, 21642, 0, -4746, 0, 21673, 0, -4745, 0, 21759, 0, -4744, 0, 21894, 0, -4743, 0, 22361, 0, -4742, 0, 22373, 0, -4741, 0, 22444, 0, -4740, 0, 22472, 0, -4739, 0, 22471, 0, -4738, 0, -1521, 0, -4736, 0, -1520, 0, -4735, 0, 22686, 0, -4734, 0, 22706, 0, -4733, 0, 22795, 0, -4732, 0, 22867, 0, -4731, 0, 22875, 0, -4730, 0, 22877, 0, -4729, 0, 22883, 0, -4728, 0, 22948, 0, -4727, 0, 22970, 0, -4726, 0, 23382, 0, -4725, 0, 23488, 0, -4724, 0, 29999, 0, -4723, 0, 23512, 0, -4722, 0, 23532, 0, -4721, 0, 23582, 0, -4720, 0, 23718, 0, -4719, 0, 23738, 0, -4718, 0, 23797, 0, -4717, 0, 23847, 0, -4716, 0, 23891, 0, -4715, 0, -1519, 0, -4714, 0, 23874, 0, -4713, 0, 23917, 0, -4712, 0, 23992, 0, -4711, 0, 23993, 0, -4710, 0, 24016, 0, -4709, 0, 24353, 0, -4708, 0, 24372, 0, -4707, 0, 24423, 0, -4706, 0, 24503, 0, -4705, 0, 24542, 0, -4704, 0, 24669, 0, -4703, 0, 24709, 0, -4702, 0, 24714, 0, -4701, 0, 24798, 0, -4700, 0, 24789, 0, -4699, 0, 24864, 0, -4698, 0, 24818, 0, -4697, 0, 24849, 0, -4696, 0, 24887, 0, -4695, 0, 24880, 0, -4694, 0, 24984, 0, -4693, 0, 25107, 0, -4692, 0, 25254, 0, -4691, 0, 25589, 0, -4690, 0, 25696, 0, -4689, 0, 25757, 0, -4688, 0, 25806, 0, -4687, 0, 25934, 0, -4686, 0, 26112, 0, -4685, 0, 26133, 0, -4684, 0, 26171, 0, -4683, 0, 26121, 0, -4682, 0, 26158, 0, -4681, 0, 26142, 0, -4680, 0, 26148, 0, -4679, 0, 26213, 0, -4678, 0, 26199, 0, -4677, 0, 26201, 0, -4676, 0, -1518, 0, -4675, 0, 26227, 0, -4674, 0, 26265, 0, -4673, 0, 26272, 0, -4672, 0, 26290, 0, -4671, 0, 26303, 0, -4670, 0, 26362, 0, -4669, 0, 26382, 0, -4668, 0, -1751, 0, -4667, 0, 26470, 0, -4666, 0, 26555, 0, -4665, 0, 26706, 0, -4664, 0, 26560, 0, -4663, 0, 26625, 0, -4662, 0, 26692, 0, -4661, 0, 26831, 0, -4660, 0, -1517, 0, -4659, 0, 26984, 0, -4658, 0, -1516, 0, -4657, 0, 27032, 0, -4656, 0, 27106, 0, -4655, 0, 27184, 0, -4654, 0, 27243, 0, -4653, 0, 27206, 0, -4652, 0, 27251, 0, -4651, 0, 27262, 0, -4650, 0, 27362, 0, -4649, 0, 27364, 0, -4648, 0, 27606, 0, -4647, 0, 27711, 0, -4646, 0, 27740, 0, -4645, 0, 27782, 0, -4644, 0, 27759, 0, -4643, 0, 27866, 0, -4642, 0, 27908, 0, -4641, 0, 28039, 0, -4640, 0, 28015, 0, -4639, 0, 28054, 0, -4638, 0, 28076, 0, -4637, 0, 28111, 0, -4636, 0, 28152, 0, -4635, 0, 28146, 0, -4634, 0, 28156, 0, -4633, 0, 28217, 0, -4632, 0, 28252, 0, -4631, 0, 28199, 0, -4630, 0, 28220, 0, -4629, 0, 28351, 0, -4628, 0, 28552, 0, -4627, 0, 28597, 0, -4626, 0, 28661, 0, -4625, 0, 28677, 0, -4624, 0, 28679, 0, -4623, 0, 28712, 0, -4622, 0, 28805, 0, -4621, 0, 28843, 0, -4620, 0, 28943, 0, -4619, 0, 28932, 0, -4618, 0, 29020, 0, -4617, 0, 28998, 0, -4616, 0, 28999, 0, -4615, 0, -1515, 0, -4614, 0, 29121, 0, -4613, 0, 29182, 0, -4612, 0, 29361, 0, -4544, 0, 29374, 0, -4543, 0, 29476, 0, -4542, 0, -1514, 0, -4541, 0, 29559, 0, -4540, 0, 29629, 0, -4539, 0, 29641, 0, -4538, 0, 29654, 0, -4537, 0, 29667, 0, -4536, 0, 29650, 0, -4535, 0, 29703, 0, -4534, 0, 29685, 0, -4533, 0, 29734, 0, -4532, 0, 29738, 0, -4531, 0, 29737, 0, -4530, 0, 29742, 0, -4529, 0, 29794, 0, -4528, 0, 29833, 0, -4527, 0, 29855, 0, -4526, 0, 29953, 0, -4525, 0, 30063, 0, -4524, 0, 30338, 0, -4523, 0, 30364, 0, -4522, 0, 30366, 0, -4521, 0, 30363, 0, -4520, 0, 30374, 0, -4519, 0, -1513, 0, -4518, 0, 30534, 0, -4517, 0, 21167, 0, -4516, 0, 30753, 0, -4515, 0, 30798, 0, -4514, 0, 30820, 0, -4513, 0, 30842, 0, -4512, 0, 31024, 0, -4511, 0, -1512, 0, -4510, 0, -1511, 0, -4509, 0, -1510, 0, -4508, 0, 31124, 0, -4507, 0, -1509, 0, -4506, 0, 31131, 0, -4505, 0, 31441, 0, -4504, 0, 31463, 0, -4503, 0, -1508, 0, -4502, 0, 31467, 0, -4501, 0, 31646, 0, -4500, 0, -1507, 0, -4499, 0, 32072, 0, -4498, 0, 32092, 0, -4497, 0, 32183, 0, -4496, 0, 32160, 0, -4495, 0, 32214, 0, -4494, 0, 32338, 0, -4493, 0, 32583, 0, -4492, 0, 32673, 0, -4491, 0, -1506, 0, -4490, 0, -31999, 0, -4489, 0, -31902, 0, -4488, 0, -31873, 0, -4487, 0, -31801, 0, -4486, 0, -31754, 0, -4485, 0, -31672, 0, -4484, 0, -31564, 0, -4483, 0, -31405, 0, -4482, 0, -31399, 0, -4480, 0, -31381, 0, -4479, 0, -1505, 0, -4478, 0, -31312, 0, -4477, 0, -1504, 0, -4476, 0, -1503, 0, -4475, 0, -30713, 0, -4474, 0, -30475, 0, -4473, 0, -30190, 0, -4472, 0, -30153, 0, -4471, 0, -30087, 0, -4470, 0, -30041, 0, -4469, 0, -30018, 0, -4468, 0, -29985, 0, -4467, 0, -1502, 0, -4466, 0, -29962, 0, -4465, 0, -29869, 0, -4464, 0, -29825, 0, -4463, 0, -29456, 0, -4462, 0, -29452, 0, -4461, 0, -29422, 0, -4460, 0, -29322, 0, -4459, 0, -1501, 0, -4458, 0, -28977, 0, -4457, 0, -1500, 0, -4456, 0, -1499, 0, -4455, 0, -28569, 0, -4454, 0, -28450, 0, -4453, 0, -1498, 0, -4452, 0, -28395, 0, -4451, 0, -28377, 0, -4450, 0, -28198, 0, -4449, 0, -28201, 0, -4448, 0, -28194, 0, -4447, 0, -28179, 0, -4446, 0, -28178, 0, -4445, 0, -28188, 0, -4444, 0, -28187, 0, -4443, 0, -28154, 0, -4442, 0, -28144, 0, -4441, 0, -28150, 0, -4440, 0, -28102, 0, -4439, 0, -28096, 0, -4438, 0, -28100, 0, -4437, 0, -28082, 0, -4436, 0, -28071, 0, -4435, 0, -28079, 0, -4434, 0, -28103, 0, -4433, 0, -28057, 0, -4432, 0, -27993, 0, -4431, 0, -28041, 0, -4430, 0, -28040, 0, -4429, 0, -27929, 0, -4428, 0, -27945, 0, -4427, 0, -27943, 0, -4426, 0, -27952, 0, -4425, 0, -1497, 0, -4424, 0, -27947, 0, -4423, 0, -27936, 0, -4422, 0, -27949, 0, -4421, 0, -27867, 0, -4420, 0, -27871, 0, -4419, 0, -27909, 0, -4418, 0, -1496, 0, -4417, 0, -27874, 0, -4416, 0, -27905, 0, -4415, 0, -27875, 0, -4414, 0, -27902, 0, -4413, 0, -27792, 0, -4412, 0, -27817, 0, -4411, 0, -27740, 0, -4410, 0, -27706, 0, -4409, 0, -27682, 0, -4408, 0, -27656, 0, -4407, 0, -27599, 0, -4406, 0, -27579, 0, -4405, 0, -27576, 0, -4404, 0, -27246, 0, -4403, 0, -1572, 0, -4402, 0, -1495, 0, -4401, 0, -26979, 0, -4400, 0, -26961, 0, -4399, 0, -26829, 0, -4398, 0, -26821, 0, -4397, 0, -26813, 0, -4396, 0, -26803, 0, -4395, 0, -26801, 0, -4394, 0, -26799, 0, -4393, 0, -26795, 0, -4392, 0, -26537, 0, -4391, 0, -26523, 0, -4390, 0, -1494, 0, -4389, 0, -1493, 0, -4388, 0, -26329, 0, -4387, 0, -1492, 0, -4386, 0, -26210, 0, -4385, 0, -26034, 0, -4384, 0, -25895, 0, -4383, 0, -25892, 0, -4382, 0, -25739, 0, -4381, 0, -25742, 0, -4380, 0, -25713, 0, -4379, 0, -25679, 0, -4378, 0, -25669, 0, -4377, 0, -25600, 0, -4376, 0, -25232, 0, -4375, 0, -25237, 0, -4374, 0, -1491, 0, -4373, 0, -25063, 0, -4372, 0, -24879, 0, -4369, 0, 8560, 0, -4368, 0, 8561, 0, -4367, 0, 8562, 0, -4366, 0, 8563, 0, -4365, 0, 8564, 0, -4364, 0, 8565, 0, -4363, 0, 8566, 0, -4362, 0, 8567, 0, -4361, 0, 8568, 0, -4360, 0, 8569, 0, -4359, 0, -30, 0, -4358, 0, -28, 0, -4357, 0, -249, 0, -4356, 0, -254, 0, -1472, 0, 8560, 0, -1471, 0, 8561, 0, -1470, 0, 8562, 0, -1469, 0, 8563, 0, -1468, 0, 8564, 0, -1467, 0, 8565, 0, -1466, 0, 8566, 0, -1465, 0, 8567, 0, -1464, 0, 8568, 0, -1463, 0, 8569, 0, -1462, 0, 8544, 0, -1461, 0, 8545, 0, -1460, 0, 8546, 0, -1459, 0, 8547, 0, -1458, 0, 8548, 0, -1457, 0, 8549, 0, -1456, 0, 8550, 0, -1455, 0, 8551, 0, -1454, 0, 8552, 0, -1453, 0, 8553, 0, -1452, 0, -30, 0, -1451, 0, -28, 0, -1450, 0, -249, 0, -1449, 0, -254, 0, -1448, 0, 12849, 0, -1447, 0, 8470, 0, -1446, 0, 8481, 0, -1445, 0, 8757, 0, -1444, 0, 32394, 0, -1443, 0, -30436, 0, -1442, 0, -27832, 0, -1441, 0, -28024, 0, -1440, 0, -31524, 0, -1439, 0, 20425, 0, -1438, 0, 28859, 0, -1437, 0, 26161, 0, -1436, 0, 26824, 0, -1435, 0, -27911, 0, -1434, 0, 26363, 0, -1433, 0, 24389, 0, -1432, 0, 20008, 0, -1431, 0, 20193, 0, -1430, 0, 20220, 0, -1429, 0, 20224, 0, -1428, 0, 20227, 0, -1427, 0, 20281, 0, -1426, 0, 20310, 0, -1425, 0, 20370, 0, -1424, 0, 20362, 0, -1423, 0, 20378, 0, -1422, 0, 20372, 0, -1421, 0, 20429, 0, -1420, 0, 20544, 0, -1419, 0, 20514, 0, -1418, 0, 20479, 0, -1417, 0, 20510, 0, -1416, 0, 20550, 0, -1415, 0, 20592, 0, -1414, 0, 20546, 0, -1413, 0, 20628, 0, -1412, 0, 20724, 0, -1411, 0, 20696, 0, -1410, 0, 20810, 0, -1408, 0, 20836, 0, -1407, 0, 20893, 0, -1406, 0, 20926, 0, -1405, 0, 20972, 0, -1404, 0, 21013, 0, -1403, 0, 21148, 0, -1402, 0, 21158, 0, -1401, 0, 21184, 0, -1400, 0, 21211, 0, -1399, 0, 21248, 0, -1398, 0, 21255, 0, -1397, 0, 21284, 0, -1396, 0, 21362, 0, -1395, 0, 21395, 0, -1394, 0, 21426, 0, -1393, 0, 21469, 0, -1392, 0, -1522, 0, -1391, 0, 21660, 0, -1390, 0, 21642, 0, -1389, 0, 21673, 0, -1388, 0, 21759, 0, -1387, 0, 21894, 0, -1386, 0, 22361, 0, -1385, 0, 22373, 0, -1384, 0, 22444, 0, -1383, 0, 22472, 0, -1382, 0, 22471, 0, -1381, 0, -1521, 0, -1380, 0, -1520, 0, -1379, 0, 22686, 0, -1378, 0, 22706, 0, -1377, 0, 22795, 0, -1376, 0, 22867, 0, -1375, 0, 22875, 0, -1374, 0, 22877, 0, -1373, 0, 22883, 0, -1372, 0, 22948, 0, -1371, 0, 22970, 0, -1370, 0, 23382, 0, -1369, 0, 23488, 0, -1368, 0, 29999, 0, -1367, 0, 23512, 0, -1366, 0, 23532, 0, -1365, 0, 23582, 0, -1364, 0, 23718, 0, -1363, 0, 23738, 0, -1362, 0, 23797, 0, -1361, 0, 23847, 0, -1360, 0, 23891, 0, -1359, 0, -1519, 0, -1358, 0, 23874, 0, -1357, 0, 23917, 0, -1356, 0, 23992, 0, -1355, 0, 23993, 0, -1354, 0, 24016, 0, -1353, 0, 24353, 0, -1352, 0, 24372, 0, -1351, 0, 24423, 0, -1350, 0, 24503, 0, -1349, 0, 24542, 0, -1348, 0, 24669, 0, -1347, 0, 24709, 0, -1346, 0, 24714, 0, -1345, 0, 24798, 0, -1344, 0, 24789, 0, -1343, 0, 24864, 0, -1342, 0, 24818, 0, -1341, 0, 24849, 0, -1340, 0, 24887, 0, -1339, 0, 24880, 0, -1338, 0, 24984, 0, -1337, 0, 25107, 0, -1336, 0, 25254, 0, -1335, 0, 25589, 0, -1334, 0, 25696, 0, -1333, 0, 25757, 0, -1332, 0, 25806, 0, -1331, 0, 25934, 0, -1330, 0, 26112, 0, -1329, 0, 26133, 0, -1328, 0, 26171, 0, -1327, 0, 26121, 0, -1326, 0, 26158, 0, -1325, 0, 26142, 0, -1324, 0, 26148, 0, -1323, 0, 26213, 0, -1322, 0, 26199, 0, -1321, 0, 26201, 0, -1320, 0, -1518, 0, -1319, 0, 26227, 0, -1318, 0, 26265, 0, -1317, 0, 26272, 0, -1316, 0, 26290, 0, -1315, 0, 26303, 0, -1314, 0, 26362, 0, -1313, 0, 26382, 0, -1312, 0, -1751, 0, -1311, 0, 26470, 0, -1310, 0, 26555, 0, -1309, 0, 26706, 0, -1308, 0, 26560, 0, -1307, 0, 26625, 0, -1306, 0, 26692, 0, -1305, 0, 26831, 0, -1304, 0, -1517, 0, -1303, 0, 26984, 0, -1302, 0, -1516, 0, -1301, 0, 27032, 0, -1300, 0, 27106, 0, -1299, 0, 27184, 0, -1298, 0, 27243, 0, -1297, 0, 27206, 0, -1296, 0, 27251, 0, -1295, 0, 27262, 0, -1294, 0, 27362, 0, -1293, 0, 27364, 0, -1292, 0, 27606, 0, -1291, 0, 27711, 0, -1290, 0, 27740, 0, -1289, 0, 27782, 0, -1288, 0, 27759, 0, -1287, 0, 27866, 0, -1286, 0, 27908, 0, -1285, 0, 28039, 0, -1284, 0, 28015, 0, -1216, 0, 28054, 0, -1215, 0, 28076, 0, -1214, 0, 28111, 0, -1213, 0, 28152, 0, -1212, 0, 28146, 0, -1211, 0, 28156, 0, -1210, 0, 28217, 0, -1209, 0, 28252, 0, -1208, 0, 28199, 0, -1207, 0, 28220, 0, -1206, 0, 28351, 0, -1205, 0, 28552, 0, -1204, 0, 28597, 0, -1203, 0, 28661, 0, -1202, 0, 28677, 0, -1201, 0, 28679, 0, -1200, 0, 28712, 0, -1199, 0, 28805, 0, -1198, 0, 28843, 0, -1197, 0, 28943, 0, -1196, 0, 28932, 0, -1195, 0, 29020, 0, -1194, 0, 28998, 0, -1193, 0, 28999, 0, -1192, 0, -1515, 0, -1191, 0, 29121, 0, -1190, 0, 29182, 0, -1189, 0, 29361, 0, -1188, 0, 29374, 0, -1187, 0, 29476, 0, -1186, 0, -1514, 0, -1185, 0, 29559, 0, -1184, 0, 29629, 0, -1183, 0, 29641, 0, -1182, 0, 29654, 0, -1181, 0, 29667, 0, -1180, 0, 29650, 0, -1179, 0, 29703, 0, -1178, 0, 29685, 0, -1177, 0, 29734, 0, -1176, 0, 29738, 0, -1175, 0, 29737, 0, -1174, 0, 29742, 0, -1173, 0, 29794, 0, -1172, 0, 29833, 0, -1171, 0, 29855, 0, -1170, 0, 29953, 0, -1169, 0, 30063, 0, -1168, 0, 30338, 0, -1167, 0, 30364, 0, -1166, 0, 30366, 0, -1165, 0, 30363, 0, -1164, 0, 30374, 0, -1163, 0, -1513, 0, -1162, 0, 30534, 0, -1161, 0, 21167, 0, -1160, 0, 30753, 0, -1159, 0, 30798, 0, -1158, 0, 30820, 0, -1157, 0, 30842, 0, -1156, 0, 31024, 0, -1155, 0, -1512, 0, -1154, 0, -1511, 0, -1152, 0, -1510, 0, -1151, 0, 31124, 0, -1150, 0, -1509, 0, -1149, 0, 31131, 0, -1148, 0, 31441, 0, -1147, 0, 31463, 0, -1146, 0, -1508, 0, -1145, 0, 31467, 0, -1144, 0, 31646, 0, -1143, 0, -1507, 0, -1142, 0, 32072, 0, -1141, 0, 32092, 0, -1140, 0, 32183, 0, -1139, 0, 32160, 0, -1138, 0, 32214, 0, -1137, 0, 32338, 0, -1136, 0, 32583, 0, -1135, 0, 32673, 0, -1134, 0, -1506, 0, -1133, 0, -31999, 0, -1132, 0, -31902, 0, -1131, 0, -31873, 0, -1130, 0, -31801, 0, -1129, 0, -31754, 0, -1128, 0, -31672, 0, -1127, 0, -31564, 0, -1126, 0, -31405, 0, -1125, 0, -31399, 0, -1124, 0, -31381, 0, -1123, 0, -1505, 0, -1122, 0, -31312, 0, -1121, 0, -1504, 0, -1120, 0, -1503, 0, -1119, 0, -30713, 0, -1118, 0, -30475, 0, -1117, 0, -30190, 0, -1116, 0, -30153, 0, -1115, 0, -30087, 0, -1114, 0, -30041, 0, -1113, 0, -30018, 0, -1112, 0, -29985, 0, -1111, 0, -1502, 0, -1110, 0, -29962, 0, -1109, 0, -29869, 0, -1108, 0, -29825, 0, -1107, 0, -29456, 0, -1106, 0, -29452, 0, -1105, 0, -29422, 0, -1104, 0, -29322, 0, -1103, 0, -1501, 0, -1102, 0, -28977, 0, -1101, 0, -1500, 0, -1100, 0, -1499, 0, -1099, 0, -28569, 0, -1098, 0, -28450, 0, -1097, 0, -1498, 0, -1096, 0, -28395, 0, -1095, 0, -28377, 0, -1094, 0, -28198, 0, -1093, 0, -28201, 0, -1092, 0, -28194, 0, -1091, 0, -28179, 0, -1090, 0, -28178, 0, -1089, 0, -28188, 0, -1088, 0, -28187, 0, -1087, 0, -28154, 0, -1086, 0, -28144, 0, -1085, 0, -28150, 0, -1084, 0, -28102, 0, -1083, 0, -28096, 0, -1082, 0, -28100, 0, -1081, 0, -28082, 0, -1080, 0, -28071, 0, -1079, 0, -28079, 0, -1078, 0, -28103, 0, -1077, 0, -28057, 0, -1076, 0, -27993, 0, -1075, 0, -28041, 0, -1074, 0, -28040, 0, -1073, 0, -27929, 0, -1072, 0, -27945, 0, -1071, 0, -27943, 0, -1070, 0, -27952, 0, -1069, 0, -1497, 0, -1068, 0, -27947, 0, -1067, 0, -27936, 0, -1066, 0, -27949, 0, -1065, 0, -27867, 0, -1064, 0, -27871, 0, -1063, 0, -27909, 0, -1062, 0, -1496, 0, -1061, 0, -27874, 0, -1060, 0, -27905, 0, -1059, 0, -27875, 0, -1058, 0, -27902, 0, -1057, 0, -27792, 0, -1056, 0, -27817, 0, -1055, 0, -27740, 0, -1054, 0, -27706, 0, -1053, 0, -27682, 0, -1052, 0, -27656, 0, -1051, 0, -27599, 0, -1050, 0, -27579, 0, -1049, 0, -27576, 0, -1048, 0, -27246, 0, -1047, 0, -1572, 0, -1046, 0, -1495, 0, -1045, 0, -26979, 0, -1044, 0, -26961, 0, -1043, 0, -26829, 0, -1042, 0, -26821, 0, -1041, 0, -26813, 0, -1040, 0, -26803, 0, -1039, 0, -26801, 0, -1038, 0, -26799, 0, -1037, 0, -26795, 0, -1036, 0, -26537, 0, -1035, 0, -26523, 0, -1034, 0, -1494, 0, -1033, 0, -1493, 0, -1032, 0, -26329, 0, -1031, 0, -1492, 0, -1030, 0, -26210, 0, -1029, 0, -26034, 0, -1028, 0, -25895, 0, -960, 0, -25892, 0, -959, 0, -25739, 0, -958, 0, -25742, 0, -957, 0, -25713, 0, -956, 0, -25679, 0, -955, 0, -25669, 0, -954, 0, -25600, 0, -953, 0, -25232, 0, -952, 0, -25237, 0, -951, 0, -1491, 0, -950, 0, -25063, 0, -949, 0, -24879, 0, -1, 0, -1, 0], ["i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0], ALLOC_STATIC);
_JWW_LINE_HEAD_SJIS=allocate([-32446, 0, -32447, 0, -32097, 0, -31936, 0, -32095, 0, -31934, 0, -32093, 0, -31932, 0, -32091, 0, -31930, 0, -32089, 0, -31928, 0, -32063, 0, -31902, 0, -32031, 0, -31869, 0, -32029, 0, -31867, 0, -32027, 0, -31865, 0, -32020, 0, -31858, 0, -32394, 0, -32406, 0, -32404, 0, -32400, 0, -32398, 0, -32396, 0, -32392, 0, -32390, 0, -32380, 0, -32286, 0, 0, 0], ["i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0], ALLOC_STATIC);
_RKSJ_AddCodeSpaceRange_code_space_range1=allocate([0, 0, 128, 0, 0, 0], ["i16",0,"i16",0,"i16",0], ALLOC_STATIC);
_RKSJ_AddCodeSpaceRange_code_space_range2=allocate([-32448, 0, -24580, 0, 0, 0], ["i16",0,"i16",0,"i16",0], ALLOC_STATIC);
_RKSJ_AddCodeSpaceRange_code_space_range3=allocate([160, 0, 223, 0, 0, 0], ["i16",0,"i16",0,"i16",0], ALLOC_STATIC);
_RKSJ_AddCodeSpaceRange_code_space_range4=allocate([-8128, 0, -772, 0, 0, 0], ["i16",0,"i16",0,"i16",0], ALLOC_STATIC);
_CMAP_ARRAY_90ms_RKSJ_H=allocate([32, 0, 125, 0, 231, 0, 126, 0, 126, 0, 631, 0, -32448, 0, -32386, 0, 633, 0, -32384, 0, -32340, 0, 696, 0, -32328, 0, -32321, 0, 741, 0, -32312, 0, -32306, 0, 749, 0, -32294, 0, -32280, 0, 756, 0, -32272, 0, -32265, 0, 771, 0, -32260, 0, -32260, 0, 779, 0, -32177, 0, -32168, 0, 780, 0, -32160, 0, -32135, 0, 790, 0, -32127, 0, -32102, 0, 816, 0, -32097, 0, -32015, 0, 842, 0, -31936, 0, -31874, 0, 925, 0, -31872, 0, -31850, 0, 988, 0, -31841, 0, -31818, 0, 1011, 0, -31809, 0, -31786, 0, 1035, 0, -31680, 0, -31648, 0, 1059, 0, -31632, 0, -31618, 0, 1092, 0, -31616, 0, -31599, 0, 1107, 0, -31585, 0, -31585, 0, 7479, 0, -31584, 0, -31584, 0, 7481, 0, -31583, 0, -31583, 0, 7491, 0, -31582, 0, -31582, 0, 7495, 0, -31581, 0, -31581, 0, 7503, 0, -31580, 0, -31580, 0, 7499, 0, -31579, 0, -31579, 0, 7507, 0, -31578, 0, -31578, 0, 7523, 0, -31577, 0, -31577, 0, 7515, 0, -31576, 0, -31576, 0, 7531, 0, -31575, 0, -31575, 0, 7539, 0, -31574, 0, -31574, 0, 7480, 0, -31573, 0, -31573, 0, 7482, 0, -31572, 0, -31572, 0, 7494, 0, -31571, 0, -31571, 0, 7498, 0, -31570, 0, -31570, 0, 7506, 0, -31569, 0, -31569, 0, 7502, 0, -31568, 0, -31568, 0, 7514, 0, -31567, 0, -31567, 0, 7530, 0, -31566, 0, -31566, 0, 7522, 0, -31565, 0, -31565, 0, 7538, 0, -31564, 0, -31564, 0, 7554, 0, -31563, 0, -31563, 0, 7511, 0, -31562, 0, -31562, 0, 7526, 0, -31561, 0, -31561, 0, 7519, 0, -31560, 0, -31560, 0, 7534, 0, -31559, 0, -31559, 0, 7542, 0, -31558, 0, -31558, 0, 7508, 0, -31557, 0, -31557, 0, 7527, 0, -31556, 0, -31556, 0, 7516, 0, -31555, 0, -31555, 0, 7535, 0, -31554, 0, -31554, 0, 7545, 0, -30912, 0, -30883, 0, 7555, 0, -30881, 0, -30880, 0, 7585, 0, -30879, 0, -30879, 0, 8038, 0, -30878, 0, -30878, 0, 7588, 0, -30877, 0, -30877, 0, 8040, 0, -30876, 0, -30876, 0, 7590, 0, -30875, 0, -30875, 0, 8042, 0, -30874, 0, -30873, 0, 7592, 0, -30872, 0, -30872, 0, 8044, 0, -30871, 0, -30870, 0, 7595, 0, -30869, 0, -30869, 0, 8043, 0, -30868, 0, -30867, 0, 7598, 0, -30866, 0, -30866, 0, 8047, 0, -30865, 0, -30859, 0, 7601, 0, -30850, 0, -30850, 0, 8323, 0, -30848, 0, -30845, 0, 7608, 0, -30844, 0, -30844, 0, 8055, 0, -30843, 0, -30833, 0, 7613, 0, -30832, 0, -30832, 0, 762, 0, -30831, 0, -30831, 0, 761, 0, -30830, 0, -30830, 0, 769, 0, -30829, 0, -30823, 0, 7624, 0, -30822, 0, -30822, 0, 768, 0, -30821, 0, -30820, 0, 7631, 0, -30561, 0, -30468, 0, 1125, 0, -30400, 0, -30338, 0, 1219, 0, -30336, 0, -30212, 0, 1282, 0, -30144, 0, -30082, 0, 1407, 0, -30080, 0, -29956, 0, 1470, 0, -29888, 0, -29826, 0, 1595, 0, -29824, 0, -29700, 0, 1658, 0, -29632, 0, -29570, 0, 1783, 0, -29568, 0, -29444, 0, 1846, 0, -29376, 0, -29314, 0, 1971, 0, -29312, 0, -29188, 0, 2034, 0, -29120, 0, -29058, 0, 2159, 0, -29056, 0, -28932, 0, 2222, 0, -28864, 0, -28802, 0, 2347, 0, -28800, 0, -28676, 0, 2410, 0, -28608, 0, -28546, 0, 2535, 0, -28544, 0, -28420, 0, 2598, 0, -28352, 0, -28290, 0, 2723, 0, -28288, 0, -28164, 0, 2786, 0, -28096, 0, -28034, 0, 2911, 0, -28032, 0, -27908, 0, 2974, 0, -27840, 0, -27778, 0, 3099, 0, -27776, 0, -27652, 0, 3162, 0, -27584, 0, -27522, 0, 3287, 0, -27520, 0, -27396, 0, 3350, 0, -27328, 0, -27266, 0, 3475, 0, -27264, 0, -27140, 0, 3538, 0, -27072, 0, -27010, 0, 3663, 0, -27008, 0, -26884, 0, 3726, 0, -26816, 0, -26754, 0, 3851, 0, -26752, 0, -26628, 0, 3914, 0, -26560, 0, -26510, 0, 4039, 0, -26465, 0, -26372, 0, 4090, 0, -26304, 0, -26242, 0, 4184, 0, -26240, 0, -26116, 0, 4247, 0, -26048, 0, -25986, 0, 4372, 0, -25984, 0, -25860, 0, 4435, 0, -25792, 0, -25730, 0, 4560, 0, -25728, 0, -25604, 0, 4623, 0, -25536, 0, -25474, 0, 4748, 0, -25472, 0, -25348, 0, 4811, 0, -25280, 0, -25218, 0, 4936, 0, -25216, 0, -25092, 0, 4999, 0, -25024, 0, -24962, 0, 5124, 0, -24960, 0, -24836, 0, 5187, 0, -24768, 0, -24706, 0, 5312, 0, -24704, 0, -24580, 0, 5375, 0, 160, 0, 223, 0, 326, 0, -8128, 0, -8066, 0, 5500, 0, -8064, 0, -7940, 0, 5563, 0, -7872, 0, -7810, 0, 5688, 0, -7808, 0, -7684, 0, 5751, 0, -7616, 0, -7554, 0, 5876, 0, -7552, 0, -7428, 0, 5939, 0, -7360, 0, -7298, 0, 6064, 0, -7296, 0, -7172, 0, 6127, 0, -7104, 0, -7042, 0, 6252, 0, -7040, 0, -6916, 0, 6315, 0, -6848, 0, -6786, 0, 6440, 0, -6784, 0, -6660, 0, 6503, 0, -6592, 0, -6530, 0, 6628, 0, -6528, 0, -6404, 0, 6691, 0, -6336, 0, -6274, 0, 6816, 0, -6272, 0, -6148, 0, 6879, 0, -6080, 0, -6018, 0, 7004, 0, -6016, 0, -5892, 0, 7067, 0, -5824, 0, -5762, 0, 7192, 0, -5760, 0, -5636, 0, 7255, 0, -5568, 0, -5506, 0, 7380, 0, -5504, 0, -5470, 0, 7443, 0, -5469, 0, -5468, 0, 8284, 0, -4800, 0, -4738, 0, 8359, 0, -4736, 0, -4685, 0, 8422, 0, -4684, 0, -4684, 0, 1993, 0, -4683, 0, -4612, 0, 8474, 0, -4544, 0, -4482, 0, 8546, 0, -4480, 0, -4372, 0, 8609, 0, -4369, 0, -4360, 0, 8092, 0, -4359, 0, -4359, 0, 751, 0, -4358, 0, -4356, 0, 8005, 0, -1472, 0, -1463, 0, 8092, 0, -1462, 0, -1453, 0, 7575, 0, -1452, 0, -1452, 0, 751, 0, -1451, 0, -1449, 0, 8005, 0, -1448, 0, -1448, 0, 7618, 0, -1447, 0, -1447, 0, 7610, 0, -1446, 0, -1446, 0, 8055, 0, -1445, 0, -1445, 0, 768, 0, -1444, 0, -1410, 0, 8359, 0, -1408, 0, -1329, 0, 8394, 0, -1328, 0, -1328, 0, 1993, 0, -1327, 0, -1284, 0, 8474, 0, -1216, 0, -1154, 0, 8518, 0, -1152, 0, -1028, 0, 8581, 0, -960, 0, -949, 0, 8706, 0, -1, 0, -1, 0, 0, 0], ["i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0], ALLOC_STATIC);
_CMAP_ARRAY_90ms_RKSJ_V=allocate([-32447, 0, -32446, 0, 7887, 0, -32445, 0, -32445, 0, 8268, 0, -32444, 0, -32444, 0, 8274, 0, -32432, 0, -32431, 0, 7889, 0, -32421, 0, -32419, 0, 7891, 0, -32416, 0, -32412, 0, 7894, 0, -32407, 0, -32390, 0, 7899, 0, -32383, 0, -32383, 0, 7917, 0, -32344, 0, -32344, 0, 739, 0, -32343, 0, -32343, 0, 738, 0, -32342, 0, -32341, 0, 736, 0, -32340, 0, -32340, 0, 8270, 0, -32097, 0, -32097, 0, 7918, 0, -32095, 0, -32095, 0, 7919, 0, -32093, 0, -32093, 0, 7920, 0, -32091, 0, -32091, 0, 7921, 0, -32089, 0, -32089, 0, 7922, 0, -32063, 0, -32063, 0, 7923, 0, -32031, 0, -32031, 0, 7924, 0, -32029, 0, -32029, 0, 7925, 0, -32027, 0, -32027, 0, 7926, 0, -32020, 0, -32020, 0, 7927, 0, -31936, 0, -31936, 0, 7928, 0, -31934, 0, -31934, 0, 7929, 0, -31932, 0, -31932, 0, 7930, 0, -31930, 0, -31930, 0, 7931, 0, -31928, 0, -31928, 0, 7932, 0, -31902, 0, -31902, 0, 7933, 0, -31869, 0, -31869, 0, 7934, 0, -31867, 0, -31867, 0, 7935, 0, -31865, 0, -31865, 0, 7936, 0, -31858, 0, -31858, 0, 7937, 0, -31851, 0, -31850, 0, 7938, 0, -31585, 0, -31585, 0, 7481, 0, -31584, 0, -31584, 0, 7479, 0, -31583, 0, -31583, 0, 7495, 0, -31582, 0, -31582, 0, 7503, 0, -31581, 0, -31581, 0, 7499, 0, -31580, 0, -31580, 0, 7491, 0, -31579, 0, -31579, 0, 7523, 0, -31578, 0, -31578, 0, 7515, 0, -31577, 0, -31577, 0, 7531, 0, -31576, 0, -31576, 0, 7507, 0, -31575, 0, -31575, 0, 7539, 0, -31574, 0, -31574, 0, 7482, 0, -31573, 0, -31573, 0, 7480, 0, -31572, 0, -31572, 0, 7498, 0, -31571, 0, -31571, 0, 7506, 0, -31570, 0, -31570, 0, 7502, 0, -31569, 0, -31569, 0, 7494, 0, -31568, 0, -31568, 0, 7530, 0, -31567, 0, -31567, 0, 7522, 0, -31566, 0, -31566, 0, 7538, 0, -31565, 0, -31565, 0, 7514, 0, -31564, 0, -31564, 0, 7554, 0, -31563, 0, -31563, 0, 7526, 0, -31562, 0, -31562, 0, 7519, 0, -31561, 0, -31561, 0, 7534, 0, -31560, 0, -31560, 0, 7511, 0, -31559, 0, -31559, 0, 7545, 0, -31558, 0, -31558, 0, 7527, 0, -31557, 0, -31557, 0, 7516, 0, -31556, 0, -31556, 0, 7535, 0, -31555, 0, -31555, 0, 7508, 0, -31554, 0, -31554, 0, 7542, 0, -30881, 0, -30880, 0, 7940, 0, -30879, 0, -30879, 0, 8329, 0, -30878, 0, -30878, 0, 7943, 0, -30877, 0, -30877, 0, 8339, 0, -30876, 0, -30876, 0, 7945, 0, -30875, 0, -30875, 0, 8338, 0, -30874, 0, -30873, 0, 7947, 0, -30872, 0, -30872, 0, 8344, 0, -30871, 0, -30870, 0, 7950, 0, -30869, 0, -30869, 0, 8348, 0, -30868, 0, -30867, 0, 7953, 0, -30866, 0, -30866, 0, 8349, 0, -30848, 0, -30847, 0, 7956, 0, -1, 0, -1, 0, 0, 0], ["i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0], ALLOC_STATIC);
_MS_RKSJ_NOTDEF_RANGE=allocate([0, 0, 31, 0, 231, 0], ["i16",0,"i16",0,"i16",0], ALLOC_STATIC);
STRING_TABLE.__str1093=allocate([75,83,67,109,115,45,85,72,67,45,72,0] /* KSCms-UHC-H\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str11094=allocate([75,83,67,109,115,45,85,72,67,45,72,87,45,72,0] /* KSCms-UHC-HW-H\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str21095=allocate([75,83,67,109,115,45,85,72,67,45,72,87,45,86,0] /* KSCms-UHC-HW-V\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str31096=allocate([75,83,67,45,69,85,67,45,72,0] /* KSC-EUC-H\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str41097=allocate([75,83,67,45,69,85,67,45,86,0] /* KSC-EUC-V\00 */, "i8", ALLOC_STATIC);
_CMAP_ARRAY_KSC_EUC_H=allocate([32, 0, 126, 0, 8094, 0, -24159, 0, -24066, 0, 101, 0, -23903, 0, -23835, 0, 195, 0, -23647, 0, -23554, 0, 264, 0, -23391, 0, -23341, 0, 358, 0, -23339, 0, -23298, 0, 409, 0, -23135, 0, -23126, 0, 451, 0, -23120, 0, -23111, 0, 461, 0, -23103, 0, -23080, 0, 471, 0, -23071, 0, -23048, 0, 495, 0, -22879, 0, -22812, 0, 519, 0, -22623, 0, -22545, 0, 587, 0, -22367, 0, -22364, 0, 666, 0, -22362, 0, -22362, 0, 670, 0, -22360, 0, -22353, 0, 671, 0, -22351, 0, -22274, 0, 679, 0, -22111, 0, -22018, 0, 757, 0, -21855, 0, -21773, 0, 851, 0, -21599, 0, -21514, 0, 934, 0, -21343, 0, -21311, 0, 1020, 0, -21295, 0, -21263, 0, 1053, 0, -20319, 0, -20226, 0, 1086, 0, -20063, 0, -19970, 0, 1180, 0, -19807, 0, -19714, 0, 1274, 0, -19551, 0, -19458, 0, 1368, 0, -19295, 0, -19202, 0, 1462, 0, -19039, 0, -18946, 0, 1556, 0, -18783, 0, -18690, 0, 1650, 0, -18527, 0, -18434, 0, 1744, 0, -18271, 0, -18178, 0, 1838, 0, -18015, 0, -17922, 0, 1932, 0, -17759, 0, -17666, 0, 2026, 0, -17503, 0, -17410, 0, 2120, 0, -17247, 0, -17154, 0, 2214, 0, -16991, 0, -16898, 0, 2308, 0, -16735, 0, -16642, 0, 2402, 0, -16479, 0, -16386, 0, 2496, 0, -16223, 0, -16130, 0, 2590, 0, -15967, 0, -15874, 0, 2684, 0, -15711, 0, -15618, 0, 2778, 0, -15455, 0, -15362, 0, 2872, 0, -15199, 0, -15106, 0, 2966, 0, -14943, 0, -14850, 0, 3060, 0, -14687, 0, -14594, 0, 3154, 0, -14431, 0, -14338, 0, 3248, 0, -14175, 0, -14082, 0, 3342, 0, -13663, 0, -13570, 0, 3436, 0, -13407, 0, -13361, 0, 3530, 0, -13360, 0, -13360, 0, 4116, 0, -13359, 0, -13355, 0, 3577, 0, -13354, 0, -13354, 0, 3678, 0, -13353, 0, -13338, 0, 3582, 0, -13337, 0, -13337, 0, 7053, 0, -13336, 0, -13314, 0, 3598, 0, -13151, 0, -13058, 0, 3621, 0, -12895, 0, -12850, 0, 3715, 0, -12849, 0, -12849, 0, 3460, 0, -12848, 0, -12825, 0, 3761, 0, -12824, 0, -12824, 0, 7900, 0, -12823, 0, -12802, 0, 3785, 0, -12639, 0, -12628, 0, 3807, 0, -12627, 0, -12627, 0, 3802, 0, -12626, 0, -12546, 0, 3819, 0, -12383, 0, -12294, 0, 3900, 0, -12293, 0, -12293, 0, 3902, 0, -12292, 0, -12290, 0, 3990, 0, -12127, 0, -12127, 0, 3993, 0, -12126, 0, -12126, 0, 3946, 0, -12125, 0, -12105, 0, 3994, 0, -12104, 0, -12104, 0, 3946, 0, -12103, 0, -12081, 0, 4015, 0, -12080, 0, -12080, 0, 3708, 0, -12079, 0, -12068, 0, 4038, 0, -12067, 0, -12067, 0, 4131, 0, -12066, 0, -12034, 0, 4050, 0, -11871, 0, -11821, 0, 4083, 0, -11820, 0, -11820, 0, 4374, 0, -11819, 0, -11819, 0, 4156, 0, -11818, 0, -11817, 0, 4134, 0, -11816, 0, -11816, 0, 4375, 0, -11815, 0, -11814, 0, 4136, 0, -11813, 0, -11808, 0, 4376, 0, -11807, 0, -11807, 0, 4138, 0, -11806, 0, -11806, 0, 5800, 0, -11805, 0, -11803, 0, 4382, 0, -11802, 0, -11802, 0, 4386, 0, -11801, 0, -11801, 0, 4139, 0, -11800, 0, -11797, 0, 4387, 0, -11796, 0, -11796, 0, 4140, 0, -11795, 0, -11795, 0, 4391, 0, -11794, 0, -11794, 0, 4141, 0, -11793, 0, -11792, 0, 4394, 0, -11791, 0, -11791, 0, 4142, 0, -11790, 0, -11790, 0, 4396, 0, -11789, 0, -11787, 0, 4143, 0, -11786, 0, -11786, 0, 4399, 0, -11785, 0, -11783, 0, 4146, 0, -11782, 0, -11782, 0, 4403, 0, -11781, 0, -11781, 0, 4149, 0, -11780, 0, -11779, 0, 4406, 0, -11778, 0, -11778, 0, 4409, 0, -11615, 0, -11615, 0, 4150, 0, -11614, 0, -11613, 0, 4410, 0, -11612, 0, -11610, 0, 4151, 0, -11609, 0, -11606, 0, 4412, 0, -11605, 0, -11605, 0, 4419, 0, -11604, 0, -11604, 0, 4154, 0, -11603, 0, -11603, 0, 4420, 0, -11602, 0, -11599, 0, 4155, 0, -11598, 0, -11598, 0, 4424, 0, -11597, 0, -11587, 0, 4159, 0, -11586, 0, -11586, 0, 4511, 0, -11585, 0, -11583, 0, 4170, 0, -11582, 0, -11581, 0, 4513, 0, -11580, 0, -11580, 0, 4517, 0, -11579, 0, -11579, 0, 4173, 0, -11578, 0, -11574, 0, 4518, 0, -11573, 0, -11573, 0, 4524, 0, -11572, 0, -11572, 0, 4174, 0, -11571, 0, -11570, 0, 4525, 0, -11569, 0, -11564, 0, 4528, 0, -11563, 0, -11561, 0, 4535, 0, -11560, 0, -11560, 0, 4175, 0, -11559, 0, -11558, 0, 4541, 0, -11557, 0, -11555, 0, 4176, 0, -11554, 0, -11553, 0, 4545, 0, -11552, 0, -11552, 0, 4179, 0, -11551, 0, -11551, 0, 4547, 0, -11550, 0, -11550, 0, 4550, 0, -11549, 0, -11549, 0, 4180, 0, -11548, 0, -11548, 0, 4564, 0, -11547, 0, -11544, 0, 4566, 0, -11543, 0, -11542, 0, 4571, 0, -11541, 0, -11541, 0, 4576, 0, -11540, 0, -11537, 0, 4181, 0, -11536, 0, -11533, 0, 4604, 0, -11532, 0, -11531, 0, 4609, 0, -11530, 0, -11530, 0, 4185, 0, -11529, 0, -11528, 0, 4611, 0, -11527, 0, -11522, 0, 4186, 0, -11359, 0, -11266, 0, 4192, 0, -11103, 0, -11035, 0, 4286, 0, -11034, 0, -11034, 0, 4318, 0, -11033, 0, -11013, 0, 4355, 0, -11012, 0, -11012, 0, 4136, 0, -11011, 0, -11010, 0, 4376, 0, -10847, 0, -10844, 0, 4378, 0, -10843, 0, -10843, 0, 5800, 0, -10842, 0, -10838, 0, 4382, 0, -10837, 0, -10837, 0, 4139, 0, -10836, 0, -10835, 0, 4387, 0, -10834, 0, -10834, 0, 4192, 0, -10833, 0, -10754, 0, 4389, 0, -10591, 0, -10569, 0, 4469, 0, -10568, 0, -10568, 0, 4167, 0, -10567, 0, -10548, 0, 4492, 0, -10547, 0, -10547, 0, 4172, 0, -10546, 0, -10498, 0, 4512, 0, -10335, 0, -10294, 0, 4561, 0, -10293, 0, -10293, 0, 5552, 0, -10292, 0, -10269, 0, 4603, 0, -10268, 0, -10268, 0, 6424, 0, -10267, 0, -10242, 0, 4627, 0, -10079, 0, -9986, 0, 4653, 0, -9823, 0, -9730, 0, 4747, 0, -9567, 0, -9474, 0, 4841, 0, -9311, 0, -9276, 0, 4935, 0, -9275, 0, -9275, 0, 5151, 0, -9274, 0, -9245, 0, 4971, 0, -9244, 0, -9244, 0, 4922, 0, -9243, 0, -9218, 0, 5001, 0, -9055, 0, -9052, 0, 5027, 0, -9051, 0, -9051, 0, 7518, 0, -9050, 0, -8962, 0, 5031, 0, -8799, 0, -8796, 0, 5120, 0, -8795, 0, -8795, 0, 5079, 0, -8794, 0, -8748, 0, 5124, 0, -8747, 0, -8747, 0, 5109, 0, -8746, 0, -8717, 0, 5171, 0, -8716, 0, -8716, 0, 7607, 0, -8715, 0, -8706, 0, 5201, 0, -8543, 0, -8453, 0, 5211, 0, -8452, 0, -8452, 0, 5584, 0, -8451, 0, -8451, 0, 5302, 0, -8450, 0, -8450, 0, 5367, 0, -8287, 0, -8270, 0, 5303, 0, -8269, 0, -8269, 0, 7083, 0, -8268, 0, -8224, 0, 5321, 0, -8223, 0, -8223, 0, 5362, 0, -8222, 0, -8217, 0, 5366, 0, -8216, 0, -8216, 0, 5485, 0, -8215, 0, -8194, 0, 5372, 0, -8031, 0, -7952, 0, 5394, 0, -7951, 0, -7951, 0, 6001, 0, -7950, 0, -7938, 0, 5474, 0, -7775, 0, -7764, 0, 5487, 0, -7763, 0, -7763, 0, 5460, 0, -7762, 0, -7700, 0, 5499, 0, -7699, 0, -7699, 0, 5317, 0, -7698, 0, -7682, 0, 5562, 0, -7519, 0, -7426, 0, 5579, 0, -7263, 0, -7180, 0, 5673, 0, -7179, 0, -7179, 0, 7009, 0, -7178, 0, -7170, 0, 5757, 0, -7007, 0, -7007, 0, 7370, 0, -7006, 0, -7000, 0, 5766, 0, -6999, 0, -6999, 0, 5678, 0, -6998, 0, -6914, 0, 5773, 0, -6751, 0, -6739, 0, 5858, 0, -6738, 0, -6738, 0, 5874, 0, -6737, 0, -6736, 0, 5871, 0, -6735, 0, -6734, 0, 4425, 0, -6733, 0, -6728, 0, 5873, 0, -6727, 0, -6727, 0, 4427, 0, -6726, 0, -6726, 0, 5879, 0, -6725, 0, -6724, 0, 4429, 0, -6723, 0, -6717, 0, 5880, 0, -6716, 0, -6716, 0, 4431, 0, -6715, 0, -6707, 0, 5887, 0, -6706, 0, -6706, 0, 4435, 0, -6705, 0, -6705, 0, 5896, 0, -6704, 0, -6704, 0, 4436, 0, -6703, 0, -6703, 0, 5897, 0, -6702, 0, -6702, 0, 4437, 0, -6701, 0, -6699, 0, 5898, 0, -6698, 0, -6698, 0, 4439, 0, -6697, 0, -6663, 0, 5901, 0, -6662, 0, -6661, 0, 4442, 0, -6660, 0, -6660, 0, 4159, 0, -6659, 0, -6659, 0, 5936, 0, -6658, 0, -6658, 0, 4444, 0, -6495, 0, -6495, 0, 4447, 0, -6494, 0, -6493, 0, 5937, 0, -6492, 0, -6492, 0, 4449, 0, -6491, 0, -6490, 0, 5939, 0, -6489, 0, -6489, 0, 4450, 0, -6488, 0, -6484, 0, 5941, 0, -6483, 0, -6483, 0, 4453, 0, -6482, 0, -6482, 0, 5946, 0, -6481, 0, -6479, 0, 4455, 0, -6478, 0, -6478, 0, 5947, 0, -6477, 0, -6477, 0, 4458, 0, -6476, 0, -6474, 0, 5948, 0, -6473, 0, -6472, 0, 4459, 0, -6471, 0, -6469, 0, 5951, 0, -6468, 0, -6468, 0, 4463, 0, -6467, 0, -6461, 0, 5954, 0, -6460, 0, -6460, 0, 4160, 0, -6459, 0, -6459, 0, 5961, 0, -6458, 0, -6457, 0, 4465, 0, -6456, 0, -6455, 0, 5962, 0, -6454, 0, -6454, 0, 4161, 0, -6453, 0, -6447, 0, 5964, 0, -6446, 0, -6446, 0, 4468, 0, -6445, 0, -6443, 0, 5971, 0, -6442, 0, -6442, 0, 4469, 0, -6441, 0, -6440, 0, 5974, 0, -6439, 0, -6439, 0, 4470, 0, -6438, 0, -6437, 0, 5976, 0, -6436, 0, -6436, 0, 4162, 0, -6435, 0, -6434, 0, 5978, 0, -6433, 0, -6433, 0, 4471, 0, -6432, 0, -6432, 0, 5980, 0, -6431, 0, -6431, 0, 4472, 0, -6430, 0, -6429, 0, 5981, 0, -6428, 0, -6428, 0, 4474, 0, -6427, 0, -6427, 0, 4473, 0, -6426, 0, -6426, 0, 4475, 0, -6425, 0, -6425, 0, 5983, 0, -6424, 0, -6424, 0, 4476, 0, -6423, 0, -6423, 0, 5984, 0, -6422, 0, -6421, 0, 4478, 0, -6420, 0, -6420, 0, 6447, 0, -6419, 0, -6418, 0, 5985, 0, -6417, 0, -6417, 0, 4481, 0, -6416, 0, -6416, 0, 5987, 0, -6415, 0, -6415, 0, 4482, 0, -6414, 0, -6414, 0, 5460, 0, -6413, 0, -6412, 0, 5988, 0, -6411, 0, -6411, 0, 4483, 0, -6410, 0, -6410, 0, 4163, 0, -6409, 0, -6409, 0, 4166, 0, -6408, 0, -6408, 0, 5990, 0, -6407, 0, -6407, 0, 4485, 0, -6406, 0, -6402, 0, 5991, 0, -6239, 0, -6239, 0, 4487, 0, -6238, 0, -6235, 0, 5996, 0, -6234, 0, -6234, 0, 4488, 0, -6233, 0, -6232, 0, 6000, 0, -6231, 0, -6231, 0, 4489, 0, -6230, 0, -6230, 0, 4491, 0, -6229, 0, -6229, 0, 6002, 0, -6228, 0, -6228, 0, 4167, 0, -6227, 0, -6227, 0, 4493, 0, -6226, 0, -6225, 0, 6003, 0, -6224, 0, -6224, 0, 4494, 0, -6223, 0, -6210, 0, 6005, 0, -6209, 0, -6209, 0, 4495, 0, -6208, 0, -6208, 0, 6019, 0, -6207, 0, -6207, 0, 7783, 0, -6206, 0, -6203, 0, 6020, 0, -6202, 0, -6202, 0, 4497, 0, -6201, 0, -6201, 0, 4499, 0, -6200, 0, -6198, 0, 6024, 0, -6197, 0, -6197, 0, 4501, 0, -6196, 0, -6196, 0, 6027, 0, -6195, 0, -6195, 0, 4502, 0, -6194, 0, -6194, 0, 6028, 0, -6193, 0, -6192, 0, 4503, 0, -6191, 0, -6190, 0, 6029, 0, -6189, 0, -6189, 0, 4506, 0, -6188, 0, -6178, 0, 6031, 0, -6177, 0, -6177, 0, 4508, 0, -6176, 0, -6173, 0, 6042, 0, -6172, 0, -6172, 0, 4509, 0, -6171, 0, -6171, 0, 6046, 0, -6170, 0, -6170, 0, 4510, 0, -6169, 0, -6154, 0, 6047, 0, -6153, 0, -6153, 0, 5797, 0, -6152, 0, -6146, 0, 6063, 0, -5983, 0, -5914, 0, 6070, 0, -5913, 0, -5912, 0, 4551, 0, -5911, 0, -5905, 0, 6140, 0, -5904, 0, -5904, 0, 4553, 0, -5903, 0, -5903, 0, 4180, 0, -5902, 0, -5898, 0, 6147, 0, -5897, 0, -5897, 0, 4555, 0, -5896, 0, -5896, 0, 6152, 0, -5895, 0, -5895, 0, 5800, 0, -5894, 0, -5894, 0, 6153, 0, -5893, 0, -5893, 0, 4556, 0, -5892, 0, -5891, 0, 6154, 0, -5890, 0, -5890, 0, 4557, 0, -5727, 0, -5722, 0, 6156, 0, -5721, 0, -5721, 0, 4560, 0, -5720, 0, -5717, 0, 6162, 0, -5716, 0, -5716, 0, 4561, 0, -5715, 0, -5685, 0, 6166, 0, -5684, 0, -5684, 0, 4563, 0, -5683, 0, -5642, 0, 6197, 0, -5641, 0, -5641, 0, 7988, 0, -5640, 0, -5634, 0, 6239, 0, -5471, 0, -5440, 0, 6246, 0, -5439, 0, -5439, 0, 6123, 0, -5438, 0, -5404, 0, 6278, 0, -5403, 0, -5403, 0, 4577, 0, -5402, 0, -5389, 0, 6313, 0, -5388, 0, -5388, 0, 4183, 0, -5387, 0, -5386, 0, 6327, 0, -5385, 0, -5385, 0, 4579, 0, -5384, 0, -5381, 0, 6329, 0, -5380, 0, -5380, 0, 4581, 0, -5379, 0, -5379, 0, 6333, 0, -5378, 0, -5378, 0, 4582, 0, -5215, 0, -5213, 0, 6334, 0, -5212, 0, -5212, 0, 4584, 0, -5211, 0, -5210, 0, 6337, 0, -5209, 0, -5209, 0, 4586, 0, -5208, 0, -5208, 0, 6339, 0, -5207, 0, -5207, 0, 4588, 0, -5206, 0, -5206, 0, 4184, 0, -5205, 0, -5191, 0, 6340, 0, -5190, 0, -5189, 0, 4590, 0, -5188, 0, -5188, 0, 6355, 0, -5187, 0, -5187, 0, 4592, 0, -5186, 0, -5184, 0, 6356, 0, -5183, 0, -5183, 0, 4593, 0, -5182, 0, -5182, 0, 4595, 0, -5181, 0, -5179, 0, 6359, 0, -5178, 0, -5177, 0, 4596, 0, -5176, 0, -5173, 0, 6362, 0, -5172, 0, -5172, 0, 4599, 0, -5171, 0, -5170, 0, 6366, 0, -5169, 0, -5167, 0, 4600, 0, -5166, 0, -5166, 0, 5552, 0, -5165, 0, -5161, 0, 6368, 0, -5160, 0, -5160, 0, 4603, 0, -5159, 0, -5122, 0, 6373, 0, -4959, 0, -4955, 0, 6411, 0, -4954, 0, -4954, 0, 4614, 0, -4953, 0, -4953, 0, 4616, 0, -4952, 0, -4951, 0, 6416, 0, -4950, 0, -4950, 0, 4618, 0, -4949, 0, -4946, 0, 6418, 0, -4945, 0, -4945, 0, 5950, 0, -4944, 0, -4943, 0, 4620, 0, -4942, 0, -4942, 0, 4187, 0, -4941, 0, -4940, 0, 6422, 0, -4939, 0, -4939, 0, 4625, 0, -4938, 0, -4937, 0, 6424, 0, -4936, 0, -4936, 0, 4627, 0, -4935, 0, -4935, 0, 6426, 0, -4934, 0, -4934, 0, 4629, 0, -4933, 0, -4929, 0, 6427, 0, -4928, 0, -4927, 0, 4632, 0, -4926, 0, -4924, 0, 6432, 0, -4923, 0, -4923, 0, 4634, 0, -4922, 0, -4922, 0, 4636, 0, -4921, 0, -4920, 0, 6435, 0, -4919, 0, -4918, 0, 4188, 0, -4917, 0, -4908, 0, 6437, 0, -4907, 0, -4907, 0, 4638, 0, -4906, 0, -4900, 0, 6447, 0, -4899, 0, -4898, 0, 4640, 0, -4897, 0, -4896, 0, 6454, 0, -4895, 0, -4895, 0, 4642, 0, -4894, 0, -4893, 0, 6456, 0, -4892, 0, -4892, 0, 4644, 0, -4891, 0, -4890, 0, 6458, 0, -4889, 0, -4888, 0, 4645, 0, -4887, 0, -4874, 0, 6460, 0, -4873, 0, -4872, 0, 4647, 0, -4871, 0, -4871, 0, 6474, 0, -4870, 0, -4870, 0, 4650, 0, -4869, 0, -4866, 0, 6475, 0, -4703, 0, -4701, 0, 4653, 0, -4700, 0, -4627, 0, 6479, 0, -4626, 0, -4626, 0, 5351, 0, -4625, 0, -4610, 0, 6553, 0, -4447, 0, -4390, 0, 6569, 0, -4389, 0, -4389, 0, 6494, 0, -4388, 0, -4354, 0, 6627, 0, -4191, 0, -4098, 0, 6662, 0, -3935, 0, -3842, 0, 6756, 0, -3679, 0, -3586, 0, 6850, 0, -3423, 0, -3396, 0, 6944, 0, -3395, 0, -3395, 0, 5731, 0, -3394, 0, -3335, 0, 6972, 0, -3334, 0, -3334, 0, 5771, 0, -3333, 0, -3330, 0, 7032, 0, -3167, 0, -3152, 0, 7036, 0, -3151, 0, -3151, 0, 4191, 0, -3150, 0, -3074, 0, 7052, 0, -2911, 0, -2906, 0, 7129, 0, -2905, 0, -2905, 0, 6484, 0, -2904, 0, -2835, 0, 7135, 0, -2834, 0, -2834, 0, 6684, 0, -2833, 0, -2818, 0, 7205, 0, -2655, 0, -2562, 0, 7221, 0, -2399, 0, -2317, 0, 7315, 0, -2316, 0, -2316, 0, 4279, 0, -2315, 0, -2315, 0, 7398, 0, -2314, 0, -2314, 0, 7139, 0, -2313, 0, -2306, 0, 7399, 0, -2143, 0, -2121, 0, 7407, 0, -2120, 0, -2120, 0, 4247, 0, -2119, 0, -2105, 0, 7430, 0, -2104, 0, -2104, 0, 4266, 0, -2103, 0, -2094, 0, 7445, 0, -2093, 0, -2093, 0, 4340, 0, -2092, 0, -2050, 0, 7455, 0, -1887, 0, -1830, 0, 7498, 0, -1829, 0, -1829, 0, 7572, 0, -1828, 0, -1809, 0, 7556, 0, -1808, 0, -1808, 0, 5088, 0, -1807, 0, -1794, 0, 7576, 0, -1631, 0, -1538, 0, 7590, 0, -1375, 0, -1375, 0, 7709, 0, -1374, 0, -1374, 0, 3558, 0, -1373, 0, -1307, 0, 7684, 0, -1306, 0, -1306, 0, 3644, 0, -1305, 0, -1282, 0, 7751, 0, -1119, 0, -1026, 0, 7775, 0, -863, 0, -856, 0, 7869, 0, -855, 0, -855, 0, 3815, 0, -854, 0, -770, 0, 7877, 0, -607, 0, -514, 0, 7962, 0, -1, 0, -1, 0, 0, 0], ["i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0], ALLOC_STATIC);
_CMAP_ARRAY_KSC_EUC_V=allocate([-24158, 0, -24157, 0, 8056, 0, -24155, 0, -24155, 0, 8058, 0, -24154, 0, -24154, 0, 8320, 0, -24151, 0, -24149, 0, 8059, 0, -24147, 0, -24147, 0, 8062, 0, -24142, 0, -24131, 0, 8063, 0, -24085, 0, -24085, 0, 8075, 0, -23647, 0, -23647, 0, 8076, 0, -23640, 0, -23639, 0, 8077, 0, -23636, 0, -23636, 0, 8079, 0, -23634, 0, -23634, 0, 8080, 0, -23622, 0, -23617, 0, 8081, 0, -23589, 0, -23589, 0, 8087, 0, -23587, 0, -23587, 0, 8088, 0, -23585, 0, -23585, 0, 8089, 0, -23557, 0, -23554, 0, 8090, 0, -1, 0, -1, 0, 0, 0], ["i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0], ALLOC_STATIC);
_KSC_EUC_NOTDEF_RANGE=allocate([0, 0, 31, 0, 8094, 0], ["i16",0,"i16",0,"i16",0], ALLOC_STATIC);
_KSC_EUC_UNICODE_ARRAY=allocate([32, 0, 32, 0, 33, 0, 33, 0, 34, 0, 34, 0, 35, 0, 35, 0, 36, 0, 36, 0, 37, 0, 37, 0, 38, 0, 38, 0, 39, 0, 39, 0, 40, 0, 40, 0, 41, 0, 41, 0, 42, 0, 42, 0, 43, 0, 43, 0, 44, 0, 44, 0, 45, 0, 45, 0, 46, 0, 46, 0, 47, 0, 47, 0, 48, 0, 48, 0, 49, 0, 49, 0, 50, 0, 50, 0, 51, 0, 51, 0, 52, 0, 52, 0, 53, 0, 53, 0, 54, 0, 54, 0, 55, 0, 55, 0, 56, 0, 56, 0, 57, 0, 57, 0, 58, 0, 58, 0, 59, 0, 59, 0, 60, 0, 60, 0, 61, 0, 61, 0, 62, 0, 62, 0, 63, 0, 63, 0, 64, 0, 64, 0, 65, 0, 65, 0, 66, 0, 66, 0, 67, 0, 67, 0, 68, 0, 68, 0, 69, 0, 69, 0, 70, 0, 70, 0, 71, 0, 71, 0, 72, 0, 72, 0, 73, 0, 73, 0, 74, 0, 74, 0, 75, 0, 75, 0, 76, 0, 76, 0, 77, 0, 77, 0, 78, 0, 78, 0, 79, 0, 79, 0, 80, 0, 80, 0, 81, 0, 81, 0, 82, 0, 82, 0, 83, 0, 83, 0, 84, 0, 84, 0, 85, 0, 85, 0, 86, 0, 86, 0, 87, 0, 87, 0, 88, 0, 88, 0, 89, 0, 89, 0, 90, 0, 90, 0, 91, 0, 91, 0, 92, 0, 92, 0, 93, 0, 93, 0, 94, 0, 94, 0, 95, 0, 95, 0, 96, 0, 96, 0, 97, 0, 97, 0, 98, 0, 98, 0, 99, 0, 99, 0, 100, 0, 100, 0, 101, 0, 101, 0, 102, 0, 102, 0, 103, 0, 103, 0, 104, 0, 104, 0, 105, 0, 105, 0, 106, 0, 106, 0, 107, 0, 107, 0, 108, 0, 108, 0, 109, 0, 109, 0, 110, 0, 110, 0, 111, 0, 111, 0, 112, 0, 112, 0, 113, 0, 113, 0, 114, 0, 114, 0, 115, 0, 115, 0, 116, 0, 116, 0, 117, 0, 117, 0, 118, 0, 118, 0, 119, 0, 119, 0, 120, 0, 120, 0, 121, 0, 121, 0, 122, 0, 122, 0, 123, 0, 123, 0, 124, 0, 124, 0, 125, 0, 125, 0, 126, 0, 126, 0, -24159, 0, 12288, 0, -24158, 0, 12289, 0, -24157, 0, 12290, 0, -24156, 0, 183, 0, -24155, 0, 8229, 0, -24154, 0, 8230, 0, -24153, 0, 168, 0, -24152, 0, 12291, 0, -24151, 0, 173, 0, -24150, 0, 8213, 0, -24149, 0, 8741, 0, -24148, 0, -196, 0, -24147, 0, 8764, 0, -24146, 0, 8216, 0, -24145, 0, 8217, 0, -24144, 0, 8220, 0, -24143, 0, 8221, 0, -24142, 0, 12308, 0, -24141, 0, 12309, 0, -24140, 0, 12296, 0, -24139, 0, 12297, 0, -24138, 0, 12298, 0, -24137, 0, 12299, 0, -24136, 0, 12300, 0, -24135, 0, 12301, 0, -24134, 0, 12302, 0, -24133, 0, 12303, 0, -24132, 0, 12304, 0, -24131, 0, 12305, 0, -24130, 0, 177, 0, -24129, 0, 215, 0, -24128, 0, 247, 0, -24127, 0, 8800, 0, -24126, 0, 8804, 0, -24125, 0, 8805, 0, -24124, 0, 8734, 0, -24123, 0, 8756, 0, -24122, 0, 176, 0, -24121, 0, 8242, 0, -24120, 0, 8243, 0, -24119, 0, 8451, 0, -24118, 0, 8491, 0, -24117, 0, -32, 0, -24116, 0, -31, 0, -24115, 0, -27, 0, -24114, 0, 9794, 0, -24113, 0, 9792, 0, -24112, 0, 8736, 0, -24111, 0, 8869, 0, -24110, 0, 8978, 0, -24109, 0, 8706, 0, -24108, 0, 8711, 0, -24107, 0, 8801, 0, -24106, 0, 8786, 0, -24105, 0, 167, 0, -24104, 0, 8251, 0, -24103, 0, 9734, 0, -24102, 0, 9733, 0, -24101, 0, 9675, 0, -24100, 0, 9679, 0, -24099, 0, 9678, 0, -24098, 0, 9671, 0, -24097, 0, 9670, 0, -24096, 0, 9633, 0, -24095, 0, 9632, 0, -24094, 0, 9651, 0, -24093, 0, 9650, 0, -24092, 0, 9661, 0, -24091, 0, 9660, 0, -24090, 0, 8594, 0, -24089, 0, 8592, 0, -24088, 0, 8593, 0, -24087, 0, 8595, 0, -24086, 0, 8596, 0, -24085, 0, 12307, 0, -24084, 0, 8810, 0, -24083, 0, 8811, 0, -24082, 0, 8730, 0, -24081, 0, 8765, 0, -24080, 0, 8733, 0, -24079, 0, 8757, 0, -24078, 0, 8747, 0, -24077, 0, 8748, 0, -24076, 0, 8712, 0, -24075, 0, 8715, 0, -24074, 0, 8838, 0, -24073, 0, 8839, 0, -24072, 0, 8834, 0, -24071, 0, 8835, 0, -24070, 0, 8746, 0, -24069, 0, 8745, 0, -24068, 0, 8743, 0, -24067, 0, 8744, 0, -24066, 0, -30, 0, -23903, 0, 8658, 0, -23902, 0, 8660, 0, -23901, 0, 8704, 0, -23900, 0, 8707, 0, -23899, 0, 180, 0, -23898, 0, -162, 0, -23897, 0, 711, 0, -23896, 0, 728, 0, -23895, 0, 733, 0, -23894, 0, 730, 0, -23893, 0, 729, 0, -23892, 0, 184, 0, -23891, 0, 731, 0, -23890, 0, 161, 0, -23889, 0, 191, 0, -23888, 0, 720, 0, -23887, 0, 8750, 0, -23886, 0, 8721, 0, -23885, 0, 8719, 0, -23884, 0, 164, 0, -23883, 0, 8457, 0, -23882, 0, 8240, 0, -23881, 0, 9665, 0, -23880, 0, 9664, 0, -23879, 0, 9655, 0, -23878, 0, 9654, 0, -23877, 0, 9828, 0, -23876, 0, 9824, 0, -23875, 0, 9825, 0, -23874, 0, 9829, 0, -23873, 0, 9831, 0, -23872, 0, 9827, 0, -23871, 0, 8857, 0, -23870, 0, 9672, 0, -23869, 0, 9635, 0, -23868, 0, 9680, 0, -23867, 0, 9681, 0, -23866, 0, 9618, 0, -23865, 0, 9636, 0, -23864, 0, 9637, 0, -23863, 0, 9640, 0, -23862, 0, 9639, 0, -23861, 0, 9638, 0, -23860, 0, 9641, 0, -23859, 0, 9832, 0, -23858, 0, 9743, 0, -23857, 0, 9742, 0, -23856, 0, 9756, 0, -23855, 0, 9758, 0, -23854, 0, 182, 0, -23853, 0, 8224, 0, -23852, 0, 8225, 0, -23851, 0, 8597, 0, -23850, 0, 8599, 0, -23849, 0, 8601, 0, -23848, 0, 8598, 0, -23847, 0, 8600, 0, -23846, 0, 9837, 0, -23845, 0, 9833, 0, -23844, 0, 9834, 0, -23843, 0, 9836, 0, -23842, 0, 12927, 0, -23841, 0, 12828, 0, -23840, 0, 8470, 0, -23839, 0, 13255, 0, -23838, 0, 8482, 0, -23837, 0, 13250, 0, -23836, 0, 13272, 0, -23835, 0, 8481, 0, -23647, 0, -255, 0, -23646, 0, -254, 0, -23645, 0, -253, 0, -23644, 0, -252, 0, -23643, 0, -251, 0, -23642, 0, -250, 0, -23641, 0, -249, 0, -23640, 0, -248, 0, -23639, 0, -247, 0, -23638, 0, -246, 0, -23637, 0, -245, 0, -23636, 0, -244, 0, -23635, 0, -243, 0, -23634, 0, -242, 0, -23633, 0, -241, 0, -23632, 0, -240, 0, -23631, 0, -239, 0, -23630, 0, -238, 0, -23629, 0, -237, 0, -23628, 0, -236, 0, -23627, 0, -235, 0, -23626, 0, -234, 0, -23625, 0, -233, 0, -23624, 0, -232, 0, -23623, 0, -231, 0, -23622, 0, -230, 0, -23621, 0, -229, 0, -23620, 0, -228, 0, -23619, 0, -227, 0, -23618, 0, -226, 0, -23617, 0, -225, 0, -23616, 0, -224, 0, -23615, 0, -223, 0, -23614, 0, -222, 0, -23613, 0, -221, 0, -23612, 0, -220, 0, -23611, 0, -219, 0, -23610, 0, -218, 0, -23609, 0, -217, 0, -23608, 0, -216, 0, -23607, 0, -215, 0, -23606, 0, -214, 0, -23605, 0, -213, 0, -23604, 0, -212, 0, -23603, 0, -211, 0, -23602, 0, -210, 0, -23601, 0, -209, 0, -23600, 0, -208, 0, -23599, 0, -207, 0, -23598, 0, -206, 0, -23597, 0, -205, 0, -23596, 0, -204, 0, -23595, 0, -203, 0, -23594, 0, -202, 0, -23593, 0, -201, 0, -23592, 0, -200, 0, -23591, 0, -199, 0, -23590, 0, -198, 0, -23589, 0, -197, 0, -23588, 0, -26, 0, -23587, 0, -195, 0, -23586, 0, -194, 0, -23585, 0, -193, 0, -23584, 0, -192, 0, -23583, 0, -191, 0, -23582, 0, -190, 0, -23581, 0, -189, 0, -23580, 0, -188, 0, -23579, 0, -187, 0, -23578, 0, -186, 0, -23577, 0, -185, 0, -23576, 0, -184, 0, -23575, 0, -183, 0, -23574, 0, -182, 0, -23573, 0, -181, 0, -23572, 0, -180, 0, -23571, 0, -179, 0, -23570, 0, -178, 0, -23569, 0, -177, 0, -23568, 0, -176, 0, -23567, 0, -175, 0, -23566, 0, -174, 0, -23565, 0, -173, 0, -23564, 0, -172, 0, -23563, 0, -171, 0, -23562, 0, -170, 0, -23561, 0, -169, 0, -23560, 0, -168, 0, -23559, 0, -167, 0, -23558, 0, -166, 0, -23557, 0, -165, 0, -23556, 0, -164, 0, -23555, 0, -163, 0, -23554, 0, -29, 0, -23391, 0, 12593, 0, -23390, 0, 12594, 0, -23389, 0, 12595, 0, -23388, 0, 12596, 0, -23387, 0, 12597, 0, -23386, 0, 12598, 0, -23385, 0, 12599, 0, -23384, 0, 12600, 0, -23383, 0, 12601, 0, -23382, 0, 12602, 0, -23381, 0, 12603, 0, -23380, 0, 12604, 0, -23379, 0, 12605, 0, -23378, 0, 12606, 0, -23377, 0, 12607, 0, -23376, 0, 12608, 0, -23375, 0, 12609, 0, -23374, 0, 12610, 0, -23373, 0, 12611, 0, -23372, 0, 12612, 0, -23371, 0, 12613, 0, -23370, 0, 12614, 0, -23369, 0, 12615, 0, -23368, 0, 12616, 0, -23367, 0, 12617, 0, -23366, 0, 12618, 0, -23365, 0, 12619, 0, -23364, 0, 12620, 0, -23363, 0, 12621, 0, -23362, 0, 12622, 0, -23361, 0, 12623, 0, -23360, 0, 12624, 0, -23359, 0, 12625, 0, -23358, 0, 12626, 0, -23357, 0, 12627, 0, -23356, 0, 12628, 0, -23355, 0, 12629, 0, -23354, 0, 12630, 0, -23353, 0, 12631, 0, -23352, 0, 12632, 0, -23351, 0, 12633, 0, -23350, 0, 12634, 0, -23349, 0, 12635, 0, -23348, 0, 12636, 0, -23347, 0, 12637, 0, -23346, 0, 12638, 0, -23345, 0, 12639, 0, -23344, 0, 12640, 0, -23343, 0, 12641, 0, -23342, 0, 12642, 0, -23341, 0, 12643, 0, -23339, 0, 12645, 0, -23338, 0, 12646, 0, -23337, 0, 12647, 0, -23336, 0, 12648, 0, -23335, 0, 12649, 0, -23334, 0, 12650, 0, -23333, 0, 12651, 0, -23332, 0, 12652, 0, -23331, 0, 12653, 0, -23330, 0, 12654, 0, -23329, 0, 12655, 0, -23328, 0, 12656, 0, -23327, 0, 12657, 0, -23326, 0, 12658, 0, -23325, 0, 12659, 0, -23324, 0, 12660, 0, -23323, 0, 12661, 0, -23322, 0, 12662, 0, -23321, 0, 12663, 0, -23320, 0, 12664, 0, -23319, 0, 12665, 0, -23318, 0, 12666, 0, -23317, 0, 12667, 0, -23316, 0, 12668, 0, -23315, 0, 12669, 0, -23314, 0, 12670, 0, -23313, 0, 12671, 0, -23312, 0, 12672, 0, -23311, 0, 12673, 0, -23310, 0, 12674, 0, -23309, 0, 12675, 0, -23308, 0, 12676, 0, -23307, 0, 12677, 0, -23306, 0, 12678, 0, -23305, 0, 12679, 0, -23304, 0, 12680, 0, -23303, 0, 12681, 0, -23302, 0, 12682, 0, -23301, 0, 12683, 0, -23300, 0, 12684, 0, -23299, 0, 12685, 0, -23298, 0, 12686, 0, -23135, 0, 8560, 0, -23134, 0, 8561, 0, -23133, 0, 8562, 0, -23132, 0, 8563, 0, -23131, 0, 8564, 0, -23130, 0, 8565, 0, -23129, 0, 8566, 0, -23128, 0, 8567, 0, -23127, 0, 8568, 0, -23126, 0, 8569, 0, -23120, 0, 8544, 0, -23119, 0, 8545, 0, -23118, 0, 8546, 0, -23117, 0, 8547, 0, -23116, 0, 8548, 0, -23115, 0, 8549, 0, -23114, 0, 8550, 0, -23113, 0, 8551, 0, -23112, 0, 8552, 0, -23111, 0, 8553, 0, -23103, 0, 913, 0, -23102, 0, 914, 0, -23101, 0, 915, 0, -23100, 0, 916, 0, -23099, 0, 917, 0, -23098, 0, 918, 0, -23097, 0, 919, 0, -23096, 0, 920, 0, -23095, 0, 921, 0, -23094, 0, 922, 0, -23093, 0, 923, 0, -23092, 0, 924, 0, -23091, 0, 925, 0, -23090, 0, 926, 0, -23089, 0, 927, 0, -23088, 0, 928, 0, -23087, 0, 929, 0, -23086, 0, 931, 0, -23085, 0, 932, 0, -23084, 0, 933, 0, -23083, 0, 934, 0, -23082, 0, 935, 0, -23081, 0, 936, 0, -23080, 0, 937, 0, -23071, 0, 945, 0, -23070, 0, 946, 0, -23069, 0, 947, 0, -23068, 0, 948, 0, -23067, 0, 949, 0, -23066, 0, 950, 0, -23065, 0, 951, 0, -23064, 0, 952, 0, -23063, 0, 953, 0, -23062, 0, 954, 0, -23061, 0, 955, 0, -23060, 0, 956, 0, -23059, 0, 957, 0, -23058, 0, 958, 0, -23057, 0, 959, 0, -23056, 0, 960, 0, -23055, 0, 961, 0, -23054, 0, 963, 0, -23053, 0, 964, 0, -23052, 0, 965, 0, -23051, 0, 966, 0, -23050, 0, 967, 0, -23049, 0, 968, 0, -23048, 0, 969, 0, -22879, 0, 9472, 0, -22878, 0, 9474, 0, -22877, 0, 9484, 0, -22876, 0, 9488, 0, -22875, 0, 9496, 0, -22874, 0, 9492, 0, -22873, 0, 9500, 0, -22872, 0, 9516, 0, -22871, 0, 9508, 0, -22870, 0, 9524, 0, -22869, 0, 9532, 0, -22868, 0, 9473, 0, -22867, 0, 9475, 0, -22866, 0, 9487, 0, -22865, 0, 9491, 0, -22864, 0, 9499, 0, -22863, 0, 9495, 0, -22862, 0, 9507, 0, -22861, 0, 9523, 0, -22860, 0, 9515, 0, -22859, 0, 9531, 0, -22858, 0, 9547, 0, -22857, 0, 9504, 0, -22856, 0, 9519, 0, -22855, 0, 9512, 0, -22854, 0, 9527, 0, -22853, 0, 9535, 0, -22852, 0, 9501, 0, -22851, 0, 9520, 0, -22850, 0, 9509, 0, -22849, 0, 9528, 0, -22848, 0, 9538, 0, -22847, 0, 9490, 0, -22846, 0, 9489, 0, -22845, 0, 9498, 0, -22844, 0, 9497, 0, -22843, 0, 9494, 0, -22842, 0, 9493, 0, -22841, 0, 9486, 0, -22840, 0, 9485, 0, -22839, 0, 9502, 0, -22838, 0, 9503, 0, -22837, 0, 9505, 0, -22836, 0, 9506, 0, -22835, 0, 9510, 0, -22834, 0, 9511, 0, -22833, 0, 9513, 0, -22832, 0, 9514, 0, -22831, 0, 9517, 0, -22830, 0, 9518, 0, -22829, 0, 9521, 0, -22828, 0, 9522, 0, -22827, 0, 9525, 0, -22826, 0, 9526, 0, -22825, 0, 9529, 0, -22824, 0, 9530, 0, -22823, 0, 9533, 0, -22822, 0, 9534, 0, -22821, 0, 9536, 0, -22820, 0, 9537, 0, -22819, 0, 9539, 0, -22818, 0, 9540, 0, -22817, 0, 9541, 0, -22816, 0, 9542, 0, -22815, 0, 9543, 0, -22814, 0, 9544, 0, -22813, 0, 9545, 0, -22812, 0, 9546, 0, -22623, 0, 13205, 0, -22622, 0, 13206, 0, -22621, 0, 13207, 0, -22620, 0, 8467, 0, -22619, 0, 13208, 0, -22618, 0, 13252, 0, -22617, 0, 13219, 0, -22616, 0, 13220, 0, -22615, 0, 13221, 0, -22614, 0, 13222, 0, -22613, 0, 13209, 0, -22612, 0, 13210, 0, -22611, 0, 13211, 0, -22610, 0, 13212, 0, -22609, 0, 13213, 0, -22608, 0, 13214, 0, -22607, 0, 13215, 0, -22606, 0, 13216, 0, -22605, 0, 13217, 0, -22604, 0, 13218, 0, -22603, 0, 13258, 0, -22602, 0, 13197, 0, -22601, 0, 13198, 0, -22600, 0, 13199, 0, -22599, 0, 13263, 0, -22598, 0, 13192, 0, -22597, 0, 13193, 0, -22596, 0, 13256, 0, -22595, 0, 13223, 0, -22594, 0, 13224, 0, -22593, 0, 13232, 0, -22592, 0, 13233, 0, -22591, 0, 13234, 0, -22590, 0, 13235, 0, -22589, 0, 13236, 0, -22588, 0, 13237, 0, -22587, 0, 13238, 0, -22586, 0, 13239, 0, -22585, 0, 13240, 0, -22584, 0, 13241, 0, -22583, 0, 13184, 0, -22582, 0, 13185, 0, -22581, 0, 13186, 0, -22580, 0, 13187, 0, -22579, 0, 13188, 0, -22578, 0, 13242, 0, -22577, 0, 13243, 0, -22576, 0, 13244, 0, -22575, 0, 13245, 0, -22574, 0, 13246, 0, -22573, 0, 13247, 0, -22572, 0, 13200, 0, -22571, 0, 13201, 0, -22570, 0, 13202, 0, -22569, 0, 13203, 0, -22568, 0, 13204, 0, -22567, 0, 8486, 0, -22566, 0, 13248, 0, -22565, 0, 13249, 0, -22564, 0, 13194, 0, -22563, 0, 13195, 0, -22562, 0, 13196, 0, -22561, 0, 13270, 0, -22560, 0, 13253, 0, -22559, 0, 13229, 0, -22558, 0, 13230, 0, -22557, 0, 13231, 0, -22556, 0, 13275, 0, -22555, 0, 13225, 0, -22554, 0, 13226, 0, -22553, 0, 13227, 0, -22552, 0, 13228, 0, -22551, 0, 13277, 0, -22550, 0, 13264, 0, -22549, 0, 13267, 0, -22548, 0, 13251, 0, -22547, 0, 13257, 0, -22546, 0, 13276, 0, -22545, 0, 13254, 0, -22367, 0, 198, 0, -22366, 0, 208, 0, -22365, 0, 170, 0, -22364, 0, 294, 0, -22362, 0, 306, 0, -22360, 0, 319, 0, -22359, 0, 321, 0, -22358, 0, 216, 0, -22357, 0, 338, 0, -22356, 0, 186, 0, -22355, 0, 222, 0, -22354, 0, 358, 0, -22353, 0, 330, 0, -22351, 0, 12896, 0, -22350, 0, 12897, 0, -22349, 0, 12898, 0, -22348, 0, 12899, 0, -22347, 0, 12900, 0, -22346, 0, 12901, 0, -22345, 0, 12902, 0, -22344, 0, 12903, 0, -22343, 0, 12904, 0, -22342, 0, 12905, 0, -22341, 0, 12906, 0, -22340, 0, 12907, 0, -22339, 0, 12908, 0, -22338, 0, 12909, 0, -22337, 0, 12910, 0, -22336, 0, 12911, 0, -22335, 0, 12912, 0, -22334, 0, 12913, 0, -22333, 0, 12914, 0, -22332, 0, 12915, 0, -22331, 0, 12916, 0, -22330, 0, 12917, 0, -22329, 0, 12918, 0, -22328, 0, 12919, 0, -22327, 0, 12920, 0, -22326, 0, 12921, 0, -22325, 0, 12922, 0, -22324, 0, 12923, 0, -22323, 0, 9424, 0, -22322, 0, 9425, 0, -22321, 0, 9426, 0, -22320, 0, 9427, 0, -22319, 0, 9428, 0, -22318, 0, 9429, 0, -22317, 0, 9430, 0, -22316, 0, 9431, 0, -22315, 0, 9432, 0, -22314, 0, 9433, 0, -22313, 0, 9434, 0, -22312, 0, 9435, 0, -22311, 0, 9436, 0, -22310, 0, 9437, 0, -22309, 0, 9438, 0, -22308, 0, 9439, 0, -22307, 0, 9440, 0, -22306, 0, 9441, 0, -22305, 0, 9442, 0, -22304, 0, 9443, 0, -22303, 0, 9444, 0, -22302, 0, 9445, 0, -22301, 0, 9446, 0, -22300, 0, 9447, 0, -22299, 0, 9448, 0, -22298, 0, 9449, 0, -22297, 0, 9312, 0, -22296, 0, 9313, 0, -22295, 0, 9314, 0, -22294, 0, 9315, 0, -22293, 0, 9316, 0, -22292, 0, 9317, 0, -22291, 0, 9318, 0, -22290, 0, 9319, 0, -22289, 0, 9320, 0, -22288, 0, 9321, 0, -22287, 0, 9322, 0, -22286, 0, 9323, 0, -22285, 0, 9324, 0, -22284, 0, 9325, 0, -22283, 0, 9326, 0, -22282, 0, 189, 0, -22281, 0, 8531, 0, -22280, 0, 8532, 0, -22279, 0, 188, 0, -22278, 0, 190, 0, -22277, 0, 8539, 0, -22276, 0, 8540, 0, -22275, 0, 8541, 0, -22274, 0, 8542, 0, -22111, 0, 230, 0, -22110, 0, 273, 0, -22109, 0, 240, 0, -22108, 0, 295, 0, -22107, 0, 305, 0, -22106, 0, 307, 0, -22105, 0, 312, 0, -22104, 0, 320, 0, -22103, 0, 322, 0, -22102, 0, 248, 0, -22101, 0, 339, 0, -22100, 0, 223, 0, -22099, 0, 254, 0, -22098, 0, 359, 0, -22097, 0, 331, 0, -22096, 0, 329, 0, -22095, 0, 12800, 0, -22094, 0, 12801, 0, -22093, 0, 12802, 0, -22092, 0, 12803, 0, -22091, 0, 12804, 0, -22090, 0, 12805, 0, -22089, 0, 12806, 0, -22088, 0, 12807, 0, -22087, 0, 12808, 0, -22086, 0, 12809, 0, -22085, 0, 12810, 0, -22084, 0, 12811, 0, -22083, 0, 12812, 0, -22082, 0, 12813, 0, -22081, 0, 12814, 0, -22080, 0, 12815, 0, -22079, 0, 12816, 0, -22078, 0, 12817, 0, -22077, 0, 12818, 0, -22076, 0, 12819, 0, -22075, 0, 12820, 0, -22074, 0, 12821, 0, -22073, 0, 12822, 0, -22072, 0, 12823, 0, -22071, 0, 12824, 0, -22070, 0, 12825, 0, -22069, 0, 12826, 0, -22068, 0, 12827, 0, -22067, 0, 9372, 0, -22066, 0, 9373, 0, -22065, 0, 9374, 0, -22064, 0, 9375, 0, -22063, 0, 9376, 0, -22062, 0, 9377, 0, -22061, 0, 9378, 0, -22060, 0, 9379, 0, -22059, 0, 9380, 0, -22058, 0, 9381, 0, -22057, 0, 9382, 0, -22056, 0, 9383, 0, -22055, 0, 9384, 0, -22054, 0, 9385, 0, -22053, 0, 9386, 0, -22052, 0, 9387, 0, -22051, 0, 9388, 0, -22050, 0, 9389, 0, -22049, 0, 9390, 0, -22048, 0, 9391, 0, -22047, 0, 9392, 0, -22046, 0, 9393, 0, -22045, 0, 9394, 0, -22044, 0, 9395, 0, -22043, 0, 9396, 0, -22042, 0, 9397, 0, -22041, 0, 9332, 0, -22040, 0, 9333, 0, -22039, 0, 9334, 0, -22038, 0, 9335, 0, -22037, 0, 9336, 0, -22036, 0, 9337, 0, -22035, 0, 9338, 0, -22034, 0, 9339, 0, -22033, 0, 9340, 0, -22032, 0, 9341, 0, -22031, 0, 9342, 0, -22030, 0, 9343, 0, -22029, 0, 9344, 0, -22028, 0, 9345, 0, -22027, 0, 9346, 0, -22026, 0, 185, 0, -22025, 0, 178, 0, -22024, 0, 179, 0, -22023, 0, 8308, 0, -22022, 0, 8319, 0, -22021, 0, 8321, 0, -22020, 0, 8322, 0, -22019, 0, 8323, 0, -22018, 0, 8324, 0, -21855, 0, 12353, 0, -21854, 0, 12354, 0, -21853, 0, 12355, 0, -21852, 0, 12356, 0, -21851, 0, 12357, 0, -21850, 0, 12358, 0, -21849, 0, 12359, 0, -21848, 0, 12360, 0, -21847, 0, 12361, 0, -21846, 0, 12362, 0, -21845, 0, 12363, 0, -21844, 0, 12364, 0, -21843, 0, 12365, 0, -21842, 0, 12366, 0, -21841, 0, 12367, 0, -21840, 0, 12368, 0, -21839, 0, 12369, 0, -21838, 0, 12370, 0, -21837, 0, 12371, 0, -21836, 0, 12372, 0, -21835, 0, 12373, 0, -21834, 0, 12374, 0, -21833, 0, 12375, 0, -21832, 0, 12376, 0, -21831, 0, 12377, 0, -21830, 0, 12378, 0, -21829, 0, 12379, 0, -21828, 0, 12380, 0, -21827, 0, 12381, 0, -21826, 0, 12382, 0, -21825, 0, 12383, 0, -21824, 0, 12384, 0, -21823, 0, 12385, 0, -21822, 0, 12386, 0, -21821, 0, 12387, 0, -21820, 0, 12388, 0, -21819, 0, 12389, 0, -21818, 0, 12390, 0, -21817, 0, 12391, 0, -21816, 0, 12392, 0, -21815, 0, 12393, 0, -21814, 0, 12394, 0, -21813, 0, 12395, 0, -21812, 0, 12396, 0, -21811, 0, 12397, 0, -21810, 0, 12398, 0, -21809, 0, 12399, 0, -21808, 0, 12400, 0, -21807, 0, 12401, 0, -21806, 0, 12402, 0, -21805, 0, 12403, 0, -21804, 0, 12404, 0, -21803, 0, 12405, 0, -21802, 0, 12406, 0, -21801, 0, 12407, 0, -21800, 0, 12408, 0, -21799, 0, 12409, 0, -21798, 0, 12410, 0, -21797, 0, 12411, 0, -21796, 0, 12412, 0, -21795, 0, 12413, 0, -21794, 0, 12414, 0, -21793, 0, 12415, 0, -21792, 0, 12416, 0, -21791, 0, 12417, 0, -21790, 0, 12418, 0, -21789, 0, 12419, 0, -21788, 0, 12420, 0, -21787, 0, 12421, 0, -21786, 0, 12422, 0, -21785, 0, 12423, 0, -21784, 0, 12424, 0, -21783, 0, 12425, 0, -21782, 0, 12426, 0, -21781, 0, 12427, 0, -21780, 0, 12428, 0, -21779, 0, 12429, 0, -21778, 0, 12430, 0, -21777, 0, 12431, 0, -21776, 0, 12432, 0, -21775, 0, 12433, 0, -21774, 0, 12434, 0, -21773, 0, 12435, 0, -21599, 0, 12449, 0, -21598, 0, 12450, 0, -21597, 0, 12451, 0, -21596, 0, 12452, 0, -21595, 0, 12453, 0, -21594, 0, 12454, 0, -21593, 0, 12455, 0, -21592, 0, 12456, 0, -21591, 0, 12457, 0, -21590, 0, 12458, 0, -21589, 0, 12459, 0, -21588, 0, 12460, 0, -21587, 0, 12461, 0, -21586, 0, 12462, 0, -21585, 0, 12463, 0, -21584, 0, 12464, 0, -21583, 0, 12465, 0, -21582, 0, 12466, 0, -21581, 0, 12467, 0, -21580, 0, 12468, 0, -21579, 0, 12469, 0, -21578, 0, 12470, 0, -21577, 0, 12471, 0, -21576, 0, 12472, 0, -21575, 0, 12473, 0, -21574, 0, 12474, 0, -21573, 0, 12475, 0, -21572, 0, 12476, 0, -21571, 0, 12477, 0, -21570, 0, 12478, 0, -21569, 0, 12479, 0, -21568, 0, 12480, 0, -21567, 0, 12481, 0, -21566, 0, 12482, 0, -21565, 0, 12483, 0, -21564, 0, 12484, 0, -21563, 0, 12485, 0, -21562, 0, 12486, 0, -21561, 0, 12487, 0, -21560, 0, 12488, 0, -21559, 0, 12489, 0, -21558, 0, 12490, 0, -21557, 0, 12491, 0, -21556, 0, 12492, 0, -21555, 0, 12493, 0, -21554, 0, 12494, 0, -21553, 0, 12495, 0, -21552, 0, 12496, 0, -21551, 0, 12497, 0, -21550, 0, 12498, 0, -21549, 0, 12499, 0, -21548, 0, 12500, 0, -21547, 0, 12501, 0, -21546, 0, 12502, 0, -21545, 0, 12503, 0, -21544, 0, 12504, 0, -21543, 0, 12505, 0, -21542, 0, 12506, 0, -21541, 0, 12507, 0, -21540, 0, 12508, 0, -21539, 0, 12509, 0, -21538, 0, 12510, 0, -21537, 0, 12511, 0, -21536, 0, 12512, 0, -21535, 0, 12513, 0, -21534, 0, 12514, 0, -21533, 0, 12515, 0, -21532, 0, 12516, 0, -21531, 0, 12517, 0, -21530, 0, 12518, 0, -21529, 0, 12519, 0, -21528, 0, 12520, 0, -21527, 0, 12521, 0, -21526, 0, 12522, 0, -21525, 0, 12523, 0, -21524, 0, 12524, 0, -21523, 0, 12525, 0, -21522, 0, 12526, 0, -21521, 0, 12527, 0, -21520, 0, 12528, 0, -21519, 0, 12529, 0, -21518, 0, 12530, 0, -21517, 0, 12531, 0, -21516, 0, 12532, 0, -21515, 0, 12533, 0, -21514, 0, 12534, 0, -21343, 0, 1040, 0, -21342, 0, 1041, 0, -21341, 0, 1042, 0, -21340, 0, 1043, 0, -21339, 0, 1044, 0, -21338, 0, 1045, 0, -21337, 0, 1025, 0, -21336, 0, 1046, 0, -21335, 0, 1047, 0, -21334, 0, 1048, 0, -21333, 0, 1049, 0, -21332, 0, 1050, 0, -21331, 0, 1051, 0, -21330, 0, 1052, 0, -21329, 0, 1053, 0, -21328, 0, 1054, 0, -21327, 0, 1055, 0, -21326, 0, 1056, 0, -21325, 0, 1057, 0, -21324, 0, 1058, 0, -21323, 0, 1059, 0, -21322, 0, 1060, 0, -21321, 0, 1061, 0, -21320, 0, 1062, 0, -21319, 0, 1063, 0, -21318, 0, 1064, 0, -21317, 0, 1065, 0, -21316, 0, 1066, 0, -21315, 0, 1067, 0, -21314, 0, 1068, 0, -21313, 0, 1069, 0, -21312, 0, 1070, 0, -21311, 0, 1071, 0, -21295, 0, 1072, 0, -21294, 0, 1073, 0, -21293, 0, 1074, 0, -21292, 0, 1075, 0, -21291, 0, 1076, 0, -21290, 0, 1077, 0, -21289, 0, 1105, 0, -21288, 0, 1078, 0, -21287, 0, 1079, 0, -21286, 0, 1080, 0, -21285, 0, 1081, 0, -21284, 0, 1082, 0, -21283, 0, 1083, 0, -21282, 0, 1084, 0, -21281, 0, 1085, 0, -21280, 0, 1086, 0, -21279, 0, 1087, 0, -21278, 0, 1088, 0, -21277, 0, 1089, 0, -21276, 0, 1090, 0, -21275, 0, 1091, 0, -21274, 0, 1092, 0, -21273, 0, 1093, 0, -21272, 0, 1094, 0, -21271, 0, 1095, 0, -21270, 0, 1096, 0, -21269, 0, 1097, 0, -21268, 0, 1098, 0, -21267, 0, 1099, 0, -21266, 0, 1100, 0, -21265, 0, 1101, 0, -21264, 0, 1102, 0, -21263, 0, 1103, 0, -20319, 0, -21504, 0, -20318, 0, -21503, 0, -20317, 0, -21500, 0, -20316, 0, -21497, 0, -20315, 0, -21496, 0, -20314, 0, -21495, 0, -20313, 0, -21494, 0, -20312, 0, -21488, 0, -20311, 0, -21487, 0, -20310, 0, -21486, 0, -20309, 0, -21485, 0, -20308, 0, -21484, 0, -20307, 0, -21483, 0, -20306, 0, -21482, 0, -20305, 0, -21481, 0, -20304, 0, -21479, 0, -20303, 0, -21478, 0, -20302, 0, -21477, 0, -20301, 0, -21476, 0, -20300, 0, -21475, 0, -20299, 0, -21472, 0, -20298, 0, -21468, 0, -20297, 0, -21460, 0, -20296, 0, -21459, 0, -20295, 0, -21457, 0, -20294, 0, -21456, 0, -20293, 0, -21455, 0, -20292, 0, -21448, 0, -20291, 0, -21447, 0, -20290, 0, -21444, 0, -20289, 0, -21440, 0, -20288, 0, -21429, 0, -20287, 0, -21427, 0, -20286, 0, -21420, 0, -20285, 0, -21416, 0, -20284, 0, -21412, 0, -20283, 0, -21392, 0, -20282, 0, -21391, 0, -20281, 0, -21388, 0, -20280, 0, -21385, 0, -20279, 0, -21384, 0, -20278, 0, -21382, 0, -20277, 0, -21376, 0, -20276, 0, -21375, 0, -20275, 0, -21373, 0, -20274, 0, -21372, 0, -20273, 0, -21371, 0, -20272, 0, -21370, 0, -20271, 0, -21367, 0, -20270, 0, -21366, 0, -20269, 0, -21365, 0, -20268, 0, -21364, 0, -20267, 0, -21360, 0, -20266, 0, -21356, 0, -20265, 0, -21348, 0, -20264, 0, -21347, 0, -20263, 0, -21345, 0, -20262, 0, -21344, 0, -20261, 0, -21343, 0, -20260, 0, -21336, 0, -20259, 0, -21335, 0, -20258, 0, -21334, 0, -20257, 0, -21332, 0, -20256, 0, -21329, 0, -20255, 0, -21328, 0, -20254, 0, -21320, 0, -20253, 0, -21319, 0, -20252, 0, -21317, 0, -20251, 0, -21316, 0, -20250, 0, -21315, 0, -20249, 0, -21311, 0, -20248, 0, -21308, 0, -20247, 0, -21304, 0, -20246, 0, -21300, 0, -20245, 0, -21291, 0, -20244, 0, -21289, 0, -20243, 0, -21280, 0, -20242, 0, -21279, 0, -20241, 0, -21276, 0, -20240, 0, -21273, 0, -20239, 0, -21272, 0, -20238, 0, -21270, 0, -20237, 0, -21268, 0, -20236, 0, -21265, 0, -20235, 0, -21264, 0, -20234, 0, -21263, 0, -20233, 0, -21261, 0, -20232, 0, -21259, 0, -20231, 0, -21258, 0, -20230, 0, -21252, 0, -20229, 0, -21251, 0, -20228, 0, -21248, 0, -20227, 0, -21244, 0, -20226, 0, -21242, 0, -20063, 0, -21236, 0, -20062, 0, -21235, 0, -20061, 0, -21233, 0, -20060, 0, -21231, 0, -20059, 0, -21224, 0, -20058, 0, -21220, 0, -20057, 0, -21216, 0, -20056, 0, -21207, 0, -20055, 0, -21204, 0, -20054, 0, -21203, 0, -20053, 0, -21196, 0, -20052, 0, -21195, 0, -20051, 0, -21192, 0, -20050, 0, -21188, 0, -20049, 0, -21180, 0, -20048, 0, -21179, 0, -20047, 0, -21177, 0, -20046, 0, -21175, 0, -20045, 0, -21168, 0, -20044, 0, -21164, 0, -20043, 0, -21160, 0, -20042, 0, -21151, 0, -20041, 0, -21149, 0, -20040, 0, -21140, 0, -20039, 0, -21139, 0, -20038, 0, -21136, 0, -20037, 0, -21133, 0, -20036, 0, -21132, 0, -20035, 0, -21131, 0, -20034, 0, -21130, 0, -20033, 0, -21125, 0, -20032, 0, -21124, 0, -20031, 0, -21123, 0, -20030, 0, -21121, 0, -20029, 0, -21119, 0, -20028, 0, -21118, 0, -20027, 0, -21112, 0, -20026, 0, -21111, 0, -20025, 0, -21108, 0, -20024, 0, -21104, 0, -20023, 0, -21092, 0, -20022, 0, -21091, 0, -20021, 0, -21084, 0, -20020, 0, -21065, 0, -20019, 0, -21056, 0, -20018, 0, -21055, 0, -20017, 0, -21052, 0, -20016, 0, -21048, 0, -20015, 0, -21040, 0, -20014, 0, -21039, 0, -20013, 0, -21037, 0, -20012, 0, -21028, 0, -20011, 0, -21024, 0, -20010, 0, -21020, 0, -20009, 0, -21000, 0, -20008, 0, -20999, 0, -20007, 0, -20996, 0, -20006, 0, -20993, 0, -20005, 0, -20992, 0, -20004, 0, -20991, 0, -20003, 0, -20984, 0, -20002, 0, -20983, 0, -20001, 0, -20981, 0, -20000, 0, -20979, 0, -19999, 0, -20972, 0, -19998, 0, -20944, 0, -19997, 0, -20943, 0, -19996, 0, -20940, 0, -19995, 0, -20937, 0, -19994, 0, -20936, 0, -19993, 0, -20934, 0, -19992, 0, -20928, 0, -19991, 0, -20927, 0, -19990, 0, -20925, 0, -19989, 0, -20923, 0, -19988, 0, -20922, 0, -19987, 0, -20918, 0, -19986, 0, -20916, 0, -19985, 0, -20915, 0, -19984, 0, -20914, 0, -19983, 0, -20912, 0, -19982, 0, -20908, 0, -19981, 0, -20906, 0, -19980, 0, -20900, 0, -19979, 0, -20899, 0, -19978, 0, -20897, 0, -19977, 0, -20896, 0, -19976, 0, -20895, 0, -19975, 0, -20891, 0, -19974, 0, -20888, 0, -19973, 0, -20887, 0, -19972, 0, -20884, 0, -19971, 0, -20880, 0, -19970, 0, -20872, 0, -19807, 0, -20871, 0, -19806, 0, -20869, 0, -19805, 0, -20868, 0, -19804, 0, -20867, 0, -19803, 0, -20860, 0, -19802, 0, -20859, 0, -19801, 0, -20852, 0, -19800, 0, -20804, 0, -19799, 0, -20803, 0, -19798, 0, -20802, 0, -19797, 0, -20800, 0, -19796, 0, -20796, 0, -19795, 0, -20788, 0, -19794, 0, -20787, 0, -19793, 0, -20785, 0, -19792, 0, -20784, 0, -19791, 0, -20783, 0, -19790, 0, -20776, 0, -19789, 0, -20775, 0, -19788, 0, -20772, 0, -19787, 0, -20760, 0, -19786, 0, -20757, 0, -19785, 0, -20755, 0, -19784, 0, -20748, 0, -19783, 0, -20744, 0, -19782, 0, -20740, 0, -19781, 0, -20729, 0, -19780, 0, -20728, 0, -19779, 0, -20723, 0, -19778, 0, -20720, 0, -19777, 0, -20692, 0, -19776, 0, -20691, 0, -19775, 0, -20688, 0, -19774, 0, -20686, 0, -19773, 0, -20684, 0, -19772, 0, -20676, 0, -19771, 0, -20675, 0, -19770, 0, -20673, 0, -19769, 0, -20671, 0, -19768, 0, -20670, 0, -19767, 0, -20669, 0, -19766, 0, -20664, 0, -19765, 0, -20663, 0, -19764, 0, -20656, 0, -19763, 0, -20644, 0, -19762, 0, -20643, 0, -19761, 0, -20636, 0, -19760, 0, -20635, 0, -19759, 0, -20615, 0, -19758, 0, -20608, 0, -19757, 0, -20604, 0, -19756, 0, -20600, 0, -19755, 0, -20592, 0, -19754, 0, -20591, 0, -19753, 0, -20587, 0, -19752, 0, -20580, 0, -19751, 0, -20552, 0, -19750, 0, -20551, 0, -19749, 0, -20548, 0, -19748, 0, -20544, 0, -19747, 0, -20537, 0, -19746, 0, -20536, 0, -19745, 0, -20535, 0, -19744, 0, -20533, 0, -19743, 0, -20531, 0, -19742, 0, -20530, 0, -19741, 0, -20524, 0, -19740, 0, -20516, 0, -19739, 0, -20504, 0, -19738, 0, -20503, 0, -19737, 0, -20496, 0, -19736, 0, -20495, 0, -19735, 0, -20492, 0, -19734, 0, -20488, 0, -19733, 0, -20480, 0, -19732, 0, -20479, 0, -19731, 0, -20476, 0, -19730, 0, -20468, 0, -19729, 0, -20464, 0, -19728, 0, -20460, 0, -19727, 0, -20452, 0, -19726, 0, -20451, 0, -19725, 0, -20440, 0, -19724, 0, -20412, 0, -19723, 0, -20411, 0, -19722, 0, -20408, 0, -19721, 0, -20406, 0, -19720, 0, -20404, 0, -19719, 0, -20402, 0, -19718, 0, -20397, 0, -19717, 0, -20396, 0, -19716, 0, -20395, 0, -19715, 0, -20393, 0, -19714, 0, -20391, 0, -19551, 0, -20387, 0, -19550, 0, -20356, 0, -19549, 0, -20355, 0, -19548, 0, -20352, 0, -19547, 0, -20348, 0, -19546, 0, -20340, 0, -19545, 0, -20339, 0, -19544, 0, -20337, 0, -19543, 0, -20335, 0, -19542, 0, -20328, 0, -19541, 0, -20327, 0, -19540, 0, -20326, 0, -19539, 0, -20324, 0, -19538, 0, -20321, 0, -19537, 0, -20320, 0, -19536, 0, -20319, 0, -19535, 0, -20318, 0, -19534, 0, -20312, 0, -19533, 0, -20311, 0, -19532, 0, -20309, 0, -19531, 0, -20308, 0, -19530, 0, -20307, 0, -19529, 0, -20306, 0, -19528, 0, -20305, 0, -19527, 0, -20303, 0, -19526, 0, -20301, 0, -19525, 0, -20300, 0, -19524, 0, -20299, 0, -19523, 0, -20296, 0, -19522, 0, -20292, 0, -19521, 0, -20284, 0, -19520, 0, -20283, 0, -19519, 0, -20281, 0, -19518, 0, -20280, 0, -19517, 0, -20279, 0, -19516, 0, -20272, 0, -19515, 0, -20271, 0, -19514, 0, -20268, 0, -19513, 0, -20264, 0, -19512, 0, -20256, 0, -19511, 0, -20251, 0, -19510, 0, -20216, 0, -19509, 0, -20215, 0, -19508, 0, -20213, 0, -19507, 0, -20212, 0, -19506, 0, -20208, 0, -19505, 0, -20206, 0, -19504, 0, -20205, 0, -19503, 0, -20200, 0, -19502, 0, -20199, 0, -19501, 0, -20197, 0, -19500, 0, -20196, 0, -19499, 0, -20195, 0, -19498, 0, -20189, 0, -19497, 0, -20188, 0, -19496, 0, -20187, 0, -19495, 0, -20184, 0, -19494, 0, -20180, 0, -19493, 0, -20172, 0, -19492, 0, -20171, 0, -19491, 0, -20169, 0, -19490, 0, -20168, 0, -19489, 0, -20167, 0, -19488, 0, -20160, 0, -19487, 0, -20159, 0, -19486, 0, -20156, 0, -19485, 0, -20152, 0, -19484, 0, -20144, 0, -19483, 0, -20143, 0, -19482, 0, -20140, 0, -19481, 0, -20139, 0, -19480, 0, -20136, 0, -19479, 0, -20132, 0, -19478, 0, -20128, 0, -19477, 0, -20104, 0, -19476, 0, -20103, 0, -19475, 0, -20100, 0, -19474, 0, -20096, 0, -19473, 0, -20094, 0, -19472, 0, -20088, 0, -19471, 0, -20087, 0, -19470, 0, -20085, 0, -19469, 0, -20083, 0, -19468, 0, -20078, 0, -19467, 0, -20077, 0, -19466, 0, -20076, 0, -19465, 0, -20072, 0, -19464, 0, -20068, 0, -19463, 0, -20056, 0, -19462, 0, -20020, 0, -19461, 0, -20016, 0, -19460, 0, -20012, 0, -19459, 0, -20004, 0, -19458, 0, -20003, 0, -19295, 0, -20001, 0, -19294, 0, -19992, 0, -19293, 0, -19991, 0, -19292, 0, -19988, 0, -19291, 0, -19984, 0, -19290, 0, -19975, 0, -19289, 0, -19973, 0, -19288, 0, -19971, 0, -19287, 0, -19964, 0, -19286, 0, -19963, 0, -19285, 0, -19960, 0, -19284, 0, -19957, 0, -19283, 0, -19956, 0, -19282, 0, -19948, 0, -19281, 0, -19947, 0, -19280, 0, -19945, 0, -19279, 0, -19943, 0, -19278, 0, -19936, 0, -19277, 0, -19916, 0, -19276, 0, -19908, 0, -19275, 0, -19880, 0, -19274, 0, -19876, 0, -19273, 0, -19872, 0, -19272, 0, -19864, 0, -19271, 0, -19863, 0, -19270, 0, -19852, 0, -19269, 0, -19851, 0, -19268, 0, -19844, 0, -19267, 0, -19836, 0, -19266, 0, -19835, 0, -19265, 0, -19831, 0, -19264, 0, -19824, 0, -19263, 0, -19823, 0, -19262, 0, -19820, 0, -19261, 0, -19816, 0, -19260, 0, -19815, 0, -19259, 0, -19814, 0, -19258, 0, -19808, 0, -19257, 0, -19807, 0, -19256, 0, -19805, 0, -19255, 0, -19803, 0, -19254, 0, -19802, 0, -19253, 0, -19798, 0, -19252, 0, -19796, 0, -19251, 0, -19792, 0, -19250, 0, -19788, 0, -19249, 0, -19768, 0, -19248, 0, -19767, 0, -19247, 0, -19764, 0, -19246, 0, -19760, 0, -19245, 0, -19758, 0, -19244, 0, -19752, 0, -19243, 0, -19751, 0, -19242, 0, -19749, 0, -19241, 0, -19747, 0, -19240, 0, -19742, 0, -19239, 0, -19740, 0, -19238, 0, -19739, 0, -19237, 0, -19738, 0, -19236, 0, -19736, 0, -19235, 0, -19733, 0, -19234, 0, -19732, 0, -19233, 0, -19731, 0, -19232, 0, -19730, 0, -19231, 0, -19729, 0, -19230, 0, -19725, 0, -19229, 0, -19724, 0, -19228, 0, -19723, 0, -19227, 0, -19721, 0, -19226, 0, -19720, 0, -19225, 0, -19719, 0, -19224, 0, -19718, 0, -19223, 0, -19717, 0, -19222, 0, -19713, 0, -19221, 0, -19712, 0, -19220, 0, -19711, 0, -19219, 0, -19708, 0, -19218, 0, -19704, 0, -19217, 0, -19696, 0, -19216, 0, -19695, 0, -19215, 0, -19693, 0, -19214, 0, -19692, 0, -19213, 0, -19691, 0, -19212, 0, -19684, 0, -19211, 0, -19628, 0, -19210, 0, -19627, 0, -19209, 0, -19626, 0, -19208, 0, -19624, 0, -19207, 0, -19621, 0, -19206, 0, -19620, 0, -19205, 0, -19618, 0, -19204, 0, -19617, 0, -19203, 0, -19612, 0, -19202, 0, -19611, 0, -19039, 0, -19609, 0, -19038, 0, -19607, 0, -19037, 0, -19605, 0, -19036, 0, -19602, 0, -19035, 0, -19600, 0, -19034, 0, -19599, 0, -19033, 0, -19596, 0, -19032, 0, -19592, 0, -19031, 0, -19584, 0, -19030, 0, -19583, 0, -19029, 0, -19581, 0, -19028, 0, -19580, 0, -19027, 0, -19579, 0, -19026, 0, -19572, 0, -19025, 0, -19568, 0, -19024, 0, -19564, 0, -19023, 0, -19552, 0, -19022, 0, -19551, 0, -19021, 0, -19544, 0, -19020, 0, -19540, 0, -19019, 0, -19516, 0, -19018, 0, -19515, 0, -19017, 0, -19512, 0, -19016, 0, -19509, 0, -19015, 0, -19508, 0, -19014, 0, -19506, 0, -19013, 0, -19504, 0, -19012, 0, -19500, 0, -19011, 0, -19499, 0, -19010, 0, -19497, 0, -19009, 0, -19495, 0, -19008, 0, -19493, 0, -19007, 0, -19491, 0, -19006, 0, -19488, 0, -19005, 0, -19484, 0, -19004, 0, -19480, 0, -19003, 0, -19460, 0, -19002, 0, -19440, 0, -19001, 0, -19432, 0, -19000, 0, -19428, 0, -18999, 0, -19424, 0, -18998, 0, -19416, 0, -18997, 0, -19415, 0, -18996, 0, -19413, 0, -18995, 0, -19404, 0, -18994, 0, -19376, 0, -18993, 0, -19375, 0, -18992, 0, -19372, 0, -18991, 0, -19368, 0, -18990, 0, -19360, 0, -18989, 0, -19359, 0, -18988, 0, -19357, 0, -18987, 0, -19355, 0, -18986, 0, -19348, 0, -18985, 0, -19328, 0, -18984, 0, -19320, 0, -18983, 0, -19299, 0, -18982, 0, -19292, 0, -18981, 0, -19288, 0, -18980, 0, -19284, 0, -18979, 0, -19275, 0, -18978, 0, -19273, 0, -18977, 0, -19271, 0, -18976, 0, -19264, 0, -18975, 0, -19260, 0, -18974, 0, -19256, 0, -18973, 0, -19248, 0, -18972, 0, -19243, 0, -18971, 0, -19236, 0, -18970, 0, -19235, 0, -18969, 0, -19232, 0, -18968, 0, -19229, 0, -18967, 0, -19228, 0, -18966, 0, -19226, 0, -18965, 0, -19220, 0, -18964, 0, -19219, 0, -18963, 0, -19217, 0, -18962, 0, -19215, 0, -18961, 0, -19208, 0, -18960, 0, -19180, 0, -18959, 0, -19179, 0, -18958, 0, -19176, 0, -18957, 0, -19173, 0, -18956, 0, -19172, 0, -18955, 0, -19164, 0, -18954, 0, -19163, 0, -18953, 0, -19161, 0, -18952, 0, -19160, 0, -18951, 0, -19159, 0, -18950, 0, -19158, 0, -18949, 0, -19152, 0, -18948, 0, -19151, 0, -18947, 0, -19148, 0, -18946, 0, -19144, 0, -18783, 0, -19136, 0, -18782, 0, -19135, 0, -18781, 0, -19133, 0, -18780, 0, -19132, 0, -18779, 0, -19131, 0, -18778, 0, -19125, 0, -18777, 0, -19124, 0, -18776, 0, -19123, 0, -18775, 0, -19120, 0, -18774, 0, -19116, 0, -18773, 0, -19108, 0, -18772, 0, -19107, 0, -18771, 0, -19105, 0, -18770, 0, -19104, 0, -18769, 0, -19103, 0, -18768, 0, -19040, 0, -18767, 0, -19039, 0, -18766, 0, -19036, 0, -18765, 0, -19032, 0, -18764, 0, -19030, 0, -18763, 0, -19029, 0, -18762, 0, -19024, 0, -18761, 0, -19023, 0, -18760, 0, -19021, 0, -18759, 0, -19020, 0, -18758, 0, -19019, 0, -18757, 0, -19013, 0, -18756, 0, -19012, 0, -18755, 0, -19011, 0, -18754, 0, -19008, 0, -18753, 0, -19004, 0, -18752, 0, -18996, 0, -18751, 0, -18995, 0, -18750, 0, -18993, 0, -18749, 0, -18992, 0, -18748, 0, -18991, 0, -18747, 0, -18984, 0, -18746, 0, -18964, 0, -18745, 0, -18928, 0, -18744, 0, -18927, 0, -18743, 0, -18924, 0, -18742, 0, -18920, 0, -18741, 0, -18907, 0, -18740, 0, -18900, 0, -18739, 0, -18892, 0, -18738, 0, -18872, 0, -18737, 0, -18844, 0, -18736, 0, -18840, 0, -18735, 0, -18788, 0, -18734, 0, -18787, 0, -18733, 0, -18784, 0, -18732, 0, -18780, 0, -18731, 0, -18773, 0, -18730, 0, -18772, 0, -18729, 0, -18767, 0, -18728, 0, -18732, 0, -18727, 0, -18704, 0, -18726, 0, -18700, 0, -18725, 0, -18696, 0, -18724, 0, -18688, 0, -18723, 0, -18687, 0, -18722, 0, -18683, 0, -18721, 0, -18648, 0, -18720, 0, -18647, 0, -18719, 0, -18644, 0, -18718, 0, -18641, 0, -18717, 0, -18640, 0, -18716, 0, -18632, 0, -18715, 0, -18631, 0, -18714, 0, -18629, 0, -18713, 0, -18620, 0, -18712, 0, -18616, 0, -18711, 0, -18612, 0, -18710, 0, -18604, 0, -18709, 0, -18603, 0, -18708, 0, -18592, 0, -18707, 0, -18588, 0, -18706, 0, -18584, 0, -18705, 0, -18576, 0, -18704, 0, -18575, 0, -18703, 0, -18573, 0, -18702, 0, -18571, 0, -18701, 0, -18564, 0, -18700, 0, -18563, 0, -18699, 0, -18560, 0, -18698, 0, -18556, 0, -18697, 0, -18548, 0, -18696, 0, -18547, 0, -18695, 0, -18545, 0, -18694, 0, -18544, 0, -18693, 0, -18543, 0, -18692, 0, -18542, 0, -18691, 0, -18538, 0, -18690, 0, -18537, 0, -18527, 0, -18536, 0, -18526, 0, -18535, 0, -18525, 0, -18532, 0, -18524, 0, -18528, 0, -18523, 0, -18520, 0, -18522, 0, -18519, 0, -18521, 0, -18517, 0, -18520, 0, -18516, 0, -18519, 0, -18515, 0, -18518, 0, -18508, 0, -18517, 0, -18507, 0, -18516, 0, -18504, 0, -18515, 0, -18489, 0, -18514, 0, -18487, 0, -18513, 0, -18452, 0, -18512, 0, -18451, 0, -18511, 0, -18448, 0, -18510, 0, -18444, 0, -18509, 0, -18436, 0, -18508, 0, -18435, 0, -18507, 0, -18433, 0, -18506, 0, -18432, 0, -18505, 0, -18431, 0, -18504, 0, -18425, 0, -18503, 0, -18424, 0, -18502, 0, -18423, 0, -18501, 0, -18420, 0, -18500, 0, -18416, 0, -18499, 0, -18408, 0, -18498, 0, -18407, 0, -18497, 0, -18405, 0, -18496, 0, -18403, 0, -18495, 0, -18396, 0, -18494, 0, -18395, 0, -18493, 0, -18392, 0, -18492, 0, -18388, 0, -18491, 0, -18380, 0, -18490, 0, -18379, 0, -18489, 0, -18377, 0, -18488, 0, -18376, 0, -18487, 0, -18375, 0, -18486, 0, -18368, 0, -18485, 0, -18364, 0, -18484, 0, -18351, 0, -18483, 0, -18349, 0, -18482, 0, -18340, 0, -18481, 0, -18339, 0, -18480, 0, -18336, 0, -18479, 0, -18332, 0, -18478, 0, -18324, 0, -18477, 0, -18323, 0, -18476, 0, -18321, 0, -18475, 0, -18319, 0, -18474, 0, -18312, 0, -18473, 0, -18308, 0, -18472, 0, -18291, 0, -18471, 0, -18264, 0, -18470, 0, -18256, 0, -18469, 0, -18252, 0, -18468, 0, -18248, 0, -18467, 0, -18240, 0, -18466, 0, -18239, 0, -18465, 0, -18237, 0, -18464, 0, -18235, 0, -18463, 0, -18228, 0, -18462, 0, -18224, 0, -18461, 0, -18220, 0, -18460, 0, -18211, 0, -18459, 0, -18209, 0, -18458, 0, -18207, 0, -18457, 0, -18200, 0, -18456, 0, -18199, 0, -18455, 0, -18196, 0, -18454, 0, -18192, 0, -18453, 0, -18184, 0, -18452, 0, -18183, 0, -18451, 0, -18181, 0, -18450, 0, -18179, 0, -18449, 0, -18172, 0, -18448, 0, -18152, 0, -18447, 0, -18144, 0, -18446, 0, -18116, 0, -18445, 0, -18115, 0, -18444, 0, -18112, 0, -18443, 0, -18108, 0, -18442, 0, -18100, 0, -18441, 0, -18097, 0, -18440, 0, -18095, 0, -18439, 0, -18088, 0, -18438, 0, -18087, 0, -18437, 0, -18084, 0, -18436, 0, -18080, 0, -18435, 0, -18072, 0, -18434, 0, -18071, 0, -18271, 0, -18069, 0, -18270, 0, -18067, 0, -18269, 0, -18060, 0, -18268, 0, -18059, 0, -18267, 0, -18056, 0, -18266, 0, -18052, 0, -18265, 0, -18044, 0, -18264, 0, -18043, 0, -18263, 0, -18041, 0, -18262, 0, -18039, 0, -18261, 0, -18038, 0, -18260, 0, -18035, 0, -18259, 0, -18034, 0, -18258, 0, -18004, 0, -18257, 0, -18003, 0, -18256, 0, -18000, 0, -18255, 0, -17996, 0, -18254, 0, -17988, 0, -18253, 0, -17987, 0, -18252, 0, -17985, 0, -18251, 0, -17983, 0, -18250, 0, -17976, 0, -18249, 0, -17975, 0, -18248, 0, -17972, 0, -18247, 0, -17970, 0, -18246, 0, -17969, 0, -18245, 0, -17968, 0, -18244, 0, -17967, 0, -18243, 0, -17966, 0, -18242, 0, -17960, 0, -18241, 0, -17959, 0, -18240, 0, -17957, 0, -18239, 0, -17955, 0, -18238, 0, -17954, 0, -18237, 0, -17951, 0, -18236, 0, -17949, 0, -18235, 0, -17948, 0, -18234, 0, -17947, 0, -18233, 0, -17944, 0, -18232, 0, -17940, 0, -18231, 0, -17932, 0, -18230, 0, -17931, 0, -18229, 0, -17929, 0, -18228, 0, -17928, 0, -18227, 0, -17927, 0, -18226, 0, -17926, 0, -18225, 0, -17920, 0, -18224, 0, -17919, 0, -18223, 0, -17912, 0, -18222, 0, -17899, 0, -18221, 0, -17864, 0, -18220, 0, -17863, 0, -18219, 0, -17860, 0, -18218, 0, -17856, 0, -18217, 0, -17854, 0, -18216, 0, -17848, 0, -18215, 0, -17847, 0, -18214, 0, -17845, 0, -18213, 0, -17843, 0, -18212, 0, -17842, 0, -18211, 0, -17837, 0, -18210, 0, -17836, 0, -18209, 0, -17835, 0, -18208, 0, -17832, 0, -18207, 0, -17828, 0, -18206, 0, -17820, 0, -18205, 0, -17819, 0, -18204, 0, -17817, 0, -18203, 0, -17816, 0, -18202, 0, -17815, 0, -18201, 0, -17808, 0, -18200, 0, -17807, 0, -18199, 0, -17804, 0, -18198, 0, -17800, 0, -18197, 0, -17789, 0, -18196, 0, -17788, 0, -18195, 0, -17787, 0, -18194, 0, -17785, 0, -18193, 0, -17780, 0, -18192, 0, -17752, 0, -18191, 0, -17751, 0, -18190, 0, -17749, 0, -18189, 0, -17748, 0, -18188, 0, -17744, 0, -18187, 0, -17742, 0, -18186, 0, -17736, 0, -18185, 0, -17735, 0, -18184, 0, -17733, 0, -18183, 0, -17731, 0, -18182, 0, -17724, 0, -18181, 0, -17720, 0, -18180, 0, -17704, 0, -18179, 0, -17703, 0, -18178, 0, -17668, 0, -18015, 0, -17664, 0, -18014, 0, -17660, 0, -18013, 0, -17651, 0, -18012, 0, -17649, 0, -18011, 0, -17647, 0, -18010, 0, -17640, 0, -18009, 0, -17636, 0, -18008, 0, -17632, 0, -18007, 0, -17623, 0, -18006, 0, -17621, 0, -18005, 0, -17612, 0, -18004, 0, -17611, 0, -18003, 0, -17610, 0, -18002, 0, -17608, 0, -18001, 0, -17605, 0, -18000, 0, -17604, 0, -17999, 0, -17603, 0, -17998, 0, -17602, 0, -17997, 0, -17596, 0, -17996, 0, -17595, 0, -17995, 0, -17593, 0, -17994, 0, -17591, 0, -17993, 0, -17587, 0, -17992, 0, -17585, 0, -17991, 0, -17584, 0, -17990, 0, -17580, 0, -17989, 0, -17576, 0, -17988, 0, -17567, 0, -17987, 0, -17565, 0, -17986, 0, -17556, 0, -17985, 0, -17528, 0, -17984, 0, -17524, 0, -17983, 0, -17520, 0, -17982, 0, -17500, 0, -17981, 0, -17496, 0, -17980, 0, -17492, 0, -17979, 0, -17484, 0, -17978, 0, -17481, 0, -17977, 0, -17472, 0, -17976, 0, -17468, 0, -17975, 0, -17464, 0, -17974, 0, -17456, 0, -17973, 0, -17453, 0, -17972, 0, -17416, 0, -17971, 0, -17415, 0, -17970, 0, -17412, 0, -17969, 0, -17409, 0, -17968, 0, -17408, 0, -17967, 0, -17406, 0, -17966, 0, -17400, 0, -17965, 0, -17399, 0, -17964, 0, -17397, 0, -17963, 0, -17396, 0, -17962, 0, -17395, 0, -17961, 0, -17393, 0, -17960, 0, -17391, 0, -17959, 0, -17388, 0, -17958, 0, -17387, 0, -17957, 0, -17386, 0, -17956, 0, -17385, 0, -17955, 0, -17384, 0, -17954, 0, -17381, 0, -17953, 0, -17380, 0, -17952, 0, -17379, 0, -17951, 0, -17378, 0, -17950, 0, -17377, 0, -17949, 0, -17372, 0, -17948, 0, -17371, 0, -17947, 0, -17369, 0, -17946, 0, -17367, 0, -17945, 0, -17363, 0, -17944, 0, -17360, 0, -17943, 0, -17359, 0, -17942, 0, -17356, 0, -17941, 0, -17352, 0, -17940, 0, -17344, 0, -17939, 0, -17343, 0, -17938, 0, -17341, 0, -17937, 0, -17340, 0, -17936, 0, -17339, 0, -17935, 0, -17335, 0, -17934, 0, -17332, 0, -17933, 0, -17331, 0, -17932, 0, -17328, 0, -17931, 0, -17315, 0, -17930, 0, -17276, 0, -17929, 0, -17275, 0, -17928, 0, -17272, 0, -17927, 0, -17269, 0, -17926, 0, -17268, 0, -17925, 0, -17266, 0, -17924, 0, -17260, 0, -17923, 0, -17259, 0, -17922, 0, -17257, 0, -17759, 0, -17255, 0, -17758, 0, -17254, 0, -17757, 0, -17248, 0, -17756, 0, -17247, 0, -17755, 0, -17244, 0, -17754, 0, -17241, 0, -17753, 0, -17240, 0, -17752, 0, -17232, 0, -17751, 0, -17231, 0, -17750, 0, -17229, 0, -17749, 0, -17228, 0, -17748, 0, -17227, 0, -17747, 0, -17220, 0, -17746, 0, -17219, 0, -17745, 0, -17216, 0, -17744, 0, -17212, 0, -17743, 0, -17203, 0, -17742, 0, -17201, 0, -17741, 0, -17200, 0, -17740, 0, -17199, 0, -17739, 0, -17195, 0, -17738, 0, -17192, 0, -17737, 0, -17188, 0, -17736, 0, -17164, 0, -17735, 0, -17163, 0, -17734, 0, -17162, 0, -17733, 0, -17160, 0, -17732, 0, -17156, 0, -17731, 0, -17148, 0, -17730, 0, -17147, 0, -17729, 0, -17145, 0, -17728, 0, -17143, 0, -17727, 0, -17136, 0, -17726, 0, -17132, 0, -17725, 0, -17116, 0, -17724, 0, -17108, 0, -17723, 0, -17088, 0, -17722, 0, -17080, 0, -17721, 0, -17079, 0, -17720, 0, -17076, 0, -17719, 0, -17072, 0, -17718, 0, -17064, 0, -17717, 0, -17063, 0, -17716, 0, -17052, 0, -17715, 0, -17048, 0, -17714, 0, -17024, 0, -17713, 0, -17023, 0, -17712, 0, -17020, 0, -17711, 0, -17017, 0, -17710, 0, -17016, 0, -17709, 0, -17015, 0, -17708, 0, -17014, 0, -17707, 0, -17008, 0, -17706, 0, -17007, 0, -17705, 0, -17005, 0, -17704, 0, -17003, 0, -17703, 0, -16999, 0, -17702, 0, -16998, 0, -17701, 0, -16996, 0, -17700, 0, -16988, 0, -17699, 0, -16976, 0, -17698, 0, -16968, 0, -17697, 0, -16940, 0, -17696, 0, -16939, 0, -17695, 0, -16936, 0, -17694, 0, -16932, 0, -17693, 0, -16919, 0, -17692, 0, -16912, 0, -17691, 0, -16908, 0, -17690, 0, -16904, 0, -17689, 0, -16896, 0, -17688, 0, -16893, 0, -17687, 0, -16891, 0, -17686, 0, -16884, 0, -17685, 0, -16883, 0, -17684, 0, -16880, 0, -17683, 0, -16876, 0, -17682, 0, -16868, 0, -17681, 0, -16867, 0, -17680, 0, -16865, 0, -17679, 0, -16828, 0, -17678, 0, -16827, 0, -17677, 0, -16824, 0, -17676, 0, -16820, 0, -17675, 0, -16818, 0, -17674, 0, -16812, 0, -17673, 0, -16811, 0, -17672, 0, -16809, 0, -17671, 0, -16807, 0, -17670, 0, -16806, 0, -17669, 0, -16805, 0, -17668, 0, -16800, 0, -17667, 0, -16799, 0, -17666, 0, -16796, 0, -17503, 0, -16792, 0, -17502, 0, -16790, 0, -17501, 0, -16784, 0, -17500, 0, -16783, 0, -17499, 0, -16781, 0, -17498, 0, -16780, 0, -17497, 0, -16779, 0, -17496, 0, -16773, 0, -17495, 0, -16772, 0, -17494, 0, -16771, 0, -17493, 0, -16768, 0, -17492, 0, -16764, 0, -17491, 0, -16756, 0, -17490, 0, -16755, 0, -17489, 0, -16753, 0, -17488, 0, -16752, 0, -17487, 0, -16751, 0, -17486, 0, -16744, 0, -17485, 0, -16743, 0, -17484, 0, -16728, 0, -17483, 0, -16688, 0, -17482, 0, -16687, 0, -17481, 0, -16684, 0, -17480, 0, -16681, 0, -17479, 0, -16680, 0, -17478, 0, -16672, 0, -17477, 0, -16669, 0, -17476, 0, -16668, 0, -17475, 0, -16667, 0, -17474, 0, -16660, 0, -17473, 0, -16639, 0, -17472, 0, -16632, 0, -17471, 0, -16631, 0, -17470, 0, -16616, 0, -17469, 0, -16615, 0, -17468, 0, -16613, 0, -17467, 0, -16612, 0, -17466, 0, -16611, 0, -17465, 0, -16576, 0, -17464, 0, -16575, 0, -17463, 0, -16572, 0, -17462, 0, -16568, 0, -17461, 0, -16560, 0, -17460, 0, -16559, 0, -17459, 0, -16555, 0, -17458, 0, -16492, 0, -17457, 0, -16464, 0, -17456, 0, -16443, 0, -17455, 0, -16436, 0, -17454, 0, -16435, 0, -17453, 0, -16432, 0, -17452, 0, -16428, 0, -17451, 0, -16420, 0, -17450, 0, -16417, 0, -17449, 0, -16415, 0, -17448, 0, -16324, 0, -17447, 0, -16303, 0, -17446, 0, -16296, 0, -17445, 0, -16292, 0, -17444, 0, -16288, 0, -17443, 0, -16280, 0, -17442, 0, -16279, 0, -17441, 0, -16240, 0, -17440, 0, -16239, 0, -17439, 0, -16236, 0, -17438, 0, -16232, 0, -17437, 0, -16224, 0, -17436, 0, -16223, 0, -17435, 0, -16221, 0, -17434, 0, -16219, 0, -17433, 0, -16212, 0, -17432, 0, -16211, 0, -17431, 0, -16209, 0, -17430, 0, -16208, 0, -17429, 0, -16205, 0, -17428, 0, -16204, 0, -17427, 0, -16203, 0, -17426, 0, -16202, 0, -17425, 0, -16196, 0, -17424, 0, -16195, 0, -17423, 0, -16193, 0, -17422, 0, -16192, 0, -17421, 0, -16191, 0, -17420, 0, -16187, 0, -17419, 0, -16184, 0, -17418, 0, -16183, 0, -17417, 0, -16180, 0, -17416, 0, -16176, 0, -17415, 0, -16168, 0, -17414, 0, -16167, 0, -17413, 0, -16165, 0, -17412, 0, -16164, 0, -17411, 0, -16163, 0, -17410, 0, -16156, 0, -17247, 0, -16155, 0, -17246, 0, -16152, 0, -17245, 0, -16148, 0, -17244, 0, -16140, 0, -17243, 0, -16139, 0, -17242, 0, -16137, 0, -17241, 0, -16135, 0, -17240, 0, -16128, 0, -17239, 0, -16124, 0, -17238, 0, -16120, 0, -17237, 0, -16112, 0, -17236, 0, -16107, 0, -17235, 0, -16100, 0, -17234, 0, -16099, 0, -17233, 0, -16098, 0, -17232, 0, -16097, 0, -17231, 0, -16096, 0, -17230, 0, -16093, 0, -17229, 0, -16092, 0, -17228, 0, -16090, 0, -17227, 0, -16089, 0, -17226, 0, -16084, 0, -17225, 0, -16083, 0, -17224, 0, -16081, 0, -17223, 0, -16080, 0, -17222, 0, -16079, 0, -17221, 0, -16074, 0, -17220, 0, -16072, 0, -17219, 0, -16071, 0, -17218, 0, -16068, 0, -17217, 0, -16064, 0, -17216, 0, -16056, 0, -17215, 0, -16055, 0, -17214, 0, -16053, 0, -17213, 0, -16052, 0, -17212, 0, -16051, 0, -17211, 0, -16044, 0, -17210, 0, -16043, 0, -17209, 0, -16040, 0, -17208, 0, -16036, 0, -17207, 0, -16028, 0, -17206, 0, -16027, 0, -17205, 0, -16025, 0, -17204, 0, -16024, 0, -17203, 0, -16023, 0, -17202, 0, -16016, 0, -17201, 0, -16012, 0, -17200, 0, -16008, 0, -17199, 0, -15995, 0, -17198, 0, -15988, 0, -17197, 0, -15987, 0, -17196, 0, -15986, 0, -17195, 0, -15984, 0, -17194, 0, -15980, 0, -17193, 0, -15978, 0, -17192, 0, -15972, 0, -17191, 0, -15971, 0, -17190, 0, -15969, 0, -17189, 0, -15967, 0, -17188, 0, -15963, 0, -17187, 0, -15960, 0, -17186, 0, -15959, 0, -17185, 0, -15956, 0, -17184, 0, -15952, 0, -17183, 0, -15939, 0, -17182, 0, -15932, 0, -17181, 0, -15928, 0, -17180, 0, -15924, 0, -17179, 0, -15916, 0, -17178, 0, -15913, 0, -17177, 0, -15912, 0, -17176, 0, -15904, 0, -17175, 0, -15900, 0, -17174, 0, -15896, 0, -17173, 0, -15888, 0, -17172, 0, -15887, 0, -17171, 0, -15885, 0, -17170, 0, -15876, 0, -17169, 0, -15875, 0, -17168, 0, -15872, 0, -17167, 0, -15868, 0, -17166, 0, -15860, 0, -17165, 0, -15859, 0, -17164, 0, -15857, 0, -17163, 0, -15855, 0, -17162, 0, -15848, 0, -17161, 0, -15847, 0, -17160, 0, -15844, 0, -17159, 0, -15841, 0, -17158, 0, -15840, 0, -17157, 0, -15832, 0, -17156, 0, -15831, 0, -17155, 0, -15829, 0, -17154, 0, -15827, 0, -16991, 0, -15825, 0, -16990, 0, -15823, 0, -16989, 0, -15822, 0, -16988, 0, -15820, 0, -16987, 0, -15800, 0, -16986, 0, -15792, 0, -16985, 0, -15791, 0, -16984, 0, -15788, 0, -16983, 0, -15784, 0, -16982, 0, -15776, 0, -16981, 0, -15771, 0, -16980, 0, -15764, 0, -16979, 0, -15763, 0, -16978, 0, -15760, 0, -16977, 0, -15756, 0, -16976, 0, -15748, 0, -16975, 0, -15747, 0, -16974, 0, -15745, 0, -16973, 0, -15743, 0, -16972, 0, -15736, 0, -16971, 0, -15735, 0, -16970, 0, -15728, 0, -16969, 0, -15720, 0, -16968, 0, -15717, 0, -16967, 0, -15715, 0, -16966, 0, -15708, 0, -16965, 0, -15707, 0, -16964, 0, -15704, 0, -16963, 0, -15700, 0, -16962, 0, -15699, 0, -16961, 0, -15692, 0, -16960, 0, -15691, 0, -16959, 0, -15689, 0, -16958, 0, -15687, 0, -16957, 0, -15652, 0, -16956, 0, -15651, 0, -16955, 0, -15648, 0, -16954, 0, -15645, 0, -16953, 0, -15644, 0, -16952, 0, -15637, 0, -16951, 0, -15636, 0, -16950, 0, -15635, 0, -16949, 0, -15633, 0, -16948, 0, -15631, 0, -16947, 0, -15626, 0, -16946, 0, -15624, 0, -16945, 0, -15623, 0, -16944, 0, -15621, 0, -16943, 0, -15620, 0, -16942, 0, -15616, 0, -16941, 0, -15608, 0, -16940, 0, -15607, 0, -16939, 0, -15604, 0, -16938, 0, -15603, 0, -16937, 0, -15597, 0, -16936, 0, -15596, 0, -16935, 0, -15595, 0, -16934, 0, -15592, 0, -16933, 0, -15588, 0, -16932, 0, -15580, 0, -16931, 0, -15579, 0, -16930, 0, -15576, 0, -16929, 0, -15575, 0, -16928, 0, -15547, 0, -16927, 0, -15512, 0, -16926, 0, -15511, 0, -16925, 0, -15508, 0, -16924, 0, -15504, 0, -16923, 0, -15502, 0, -16922, 0, -15496, 0, -16921, 0, -15495, 0, -16920, 0, -15492, 0, -16919, 0, -15491, 0, -16918, 0, -15484, 0, -16917, 0, -15480, 0, -16916, 0, -15476, 0, -16915, 0, -15424, 0, -16914, 0, -15400, 0, -16913, 0, -15399, 0, -16912, 0, -15396, 0, -16911, 0, -15393, 0, -16910, 0, -15392, 0, -16909, 0, -15390, 0, -16908, 0, -15384, 0, -16907, 0, -15383, 0, -16906, 0, -15379, 0, -16905, 0, -15372, 0, -16904, 0, -15371, 0, -16903, 0, -15368, 0, -16902, 0, -15352, 0, -16901, 0, -15344, 0, -16900, 0, -15324, 0, -16899, 0, -15316, 0, -16898, 0, -15312, 0, -16735, 0, -15308, 0, -16734, 0, -15300, 0, -16733, 0, -15299, 0, -16732, 0, -15288, 0, -16731, 0, -15260, 0, -16730, 0, -15259, 0, -16729, 0, -15256, 0, -16728, 0, -15252, 0, -16727, 0, -15244, 0, -16726, 0, -15243, 0, -16725, 0, -15239, 0, -16724, 0, -15232, 0, -16723, 0, -15212, 0, -16722, 0, -15204, 0, -16721, 0, -15176, 0, -16720, 0, -15172, 0, -16719, 0, -15127, 0, -16718, 0, -15120, 0, -16717, 0, -15119, 0, -16716, 0, -15116, 0, -16715, 0, -15112, 0, -16714, 0, -15110, 0, -16713, 0, -15105, 0, -16712, 0, -15104, 0, -16711, 0, -15103, 0, -16710, 0, -15092, 0, -16709, 0, -15088, 0, -16708, 0, -15084, 0, -16707, 0, -15076, 0, -16706, 0, -15064, 0, -16705, 0, -15063, 0, -16704, 0, -15060, 0, -16703, 0, -15056, 0, -16702, 0, -15048, 0, -16701, 0, -15047, 0, -16700, 0, -15045, 0, -16699, 0, -15043, 0, -16698, 0, -15036, 0, -16697, 0, -15035, 0, -16696, 0, -15032, 0, -16695, 0, -15031, 0, -16694, 0, -15030, 0, -16693, 0, -15028, 0, -16692, 0, -15027, 0, -16691, 0, -15026, 0, -16690, 0, -15021, 0, -16689, 0, -15020, 0, -16688, 0, -15019, 0, -16687, 0, -15017, 0, -16686, 0, -15016, 0, -16685, 0, -15015, 0, -16684, 0, -15011, 0, -16683, 0, -15010, 0, -16682, 0, -15008, 0, -16681, 0, -15007, 0, -16680, 0, -15004, 0, -16679, 0, -15000, 0, -16678, 0, -14992, 0, -16677, 0, -14991, 0, -16676, 0, -14989, 0, -16675, 0, -14988, 0, -16674, 0, -14987, 0, -16673, 0, -14980, 0, -16672, 0, -14979, 0, -16671, 0, -14976, 0, -16670, 0, -14972, 0, -16669, 0, -14969, 0, -16668, 0, -14964, 0, -16667, 0, -14963, 0, -16666, 0, -14961, 0, -16665, 0, -14959, 0, -16664, 0, -14955, 0, -16663, 0, -14953, 0, -16662, 0, -14952, 0, -16661, 0, -14948, 0, -16660, 0, -14944, 0, -16659, 0, -14935, 0, -16658, 0, -14924, 0, -16657, 0, -14923, 0, -16656, 0, -14920, 0, -16655, 0, -14919, 0, -16654, 0, -14917, 0, -16653, 0, -14916, 0, -16652, 0, -14915, 0, -16651, 0, -14914, 0, -16650, 0, -14908, 0, -16649, 0, -14907, 0, -16648, 0, -14906, 0, -16647, 0, -14905, 0, -16646, 0, -14904, 0, -16645, 0, -14903, 0, -16644, 0, -14902, 0, -16643, 0, -14900, 0, -16642, 0, -14898, 0, -16479, 0, -14896, 0, -16478, 0, -14895, 0, -16477, 0, -14892, 0, -16476, 0, -14888, 0, -16475, 0, -14880, 0, -16474, 0, -14879, 0, -16473, 0, -14877, 0, -16472, 0, -14875, 0, -16471, 0, -14868, 0, -16470, 0, -14867, 0, -16469, 0, -14866, 0, -16468, 0, -14864, 0, -16467, 0, -14860, 0, -16466, 0, -14858, 0, -16465, 0, -14857, 0, -16464, 0, -14852, 0, -16463, 0, -14851, 0, -16462, 0, -14850, 0, -16461, 0, -14849, 0, -16460, 0, -14848, 0, -16459, 0, -14847, 0, -16458, 0, -14843, 0, -16457, 0, -14842, 0, -16456, 0, -14841, 0, -16455, 0, -14840, 0, -16454, 0, -14836, 0, -16453, 0, -14832, 0, -16452, 0, -14824, 0, -16451, 0, -14823, 0, -16450, 0, -14821, 0, -16449, 0, -14820, 0, -16448, 0, -14812, 0, -16447, 0, -14811, 0, -16446, 0, -14808, 0, -16445, 0, -14804, 0, -16444, 0, -14803, 0, -16443, 0, -14802, 0, -16442, 0, -14800, 0, -16441, 0, -14797, 0, -16440, 0, -14796, 0, -16439, 0, -14795, 0, -16438, 0, -14793, 0, -16437, 0, -14791, 0, -16436, 0, -14789, 0, -16435, 0, -14784, 0, -16434, 0, -14783, 0, -16433, 0, -14780, 0, -16432, 0, -14776, 0, -16431, 0, -14768, 0, -16430, 0, -14767, 0, -16429, 0, -14765, 0, -16428, 0, -14764, 0, -16427, 0, -14763, 0, -16426, 0, -14756, 0, -16425, 0, -14755, 0, -16424, 0, -14752, 0, -16423, 0, -14740, 0, -16422, 0, -14737, 0, -16421, 0, -14735, 0, -16420, 0, -14728, 0, -16419, 0, -14727, 0, -16418, 0, -14724, 0, -16417, 0, -14720, 0, -16416, 0, -14712, 0, -16415, 0, -14711, 0, -16414, 0, -14709, 0, -16413, 0, -14707, 0, -16412, 0, -14700, 0, -16411, 0, -14699, 0, -16410, 0, -14696, 0, -16409, 0, -14692, 0, -16408, 0, -14684, 0, -16407, 0, -14683, 0, -16406, 0, -14681, 0, -16405, 0, -14679, 0, -16404, 0, -14672, 0, -16403, 0, -14671, 0, -16402, 0, -14668, 0, -16401, 0, -14664, 0, -16400, 0, -14663, 0, -16399, 0, -14662, 0, -16398, 0, -14656, 0, -16397, 0, -14655, 0, -16396, 0, -14653, 0, -16395, 0, -14651, 0, -16394, 0, -14644, 0, -16393, 0, -14643, 0, -16392, 0, -14640, 0, -16391, 0, -14636, 0, -16390, 0, -14628, 0, -16389, 0, -14627, 0, -16388, 0, -14624, 0, -16387, 0, -14623, 0, -16386, 0, -14616, 0, -16223, 0, -14615, 0, -16222, 0, -14612, 0, -16221, 0, -14608, 0, -16220, 0, -14600, 0, -16219, 0, -14599, 0, -16218, 0, -14595, 0, -16217, 0, -14588, 0, -16216, 0, -14587, 0, -16215, 0, -14584, 0, -16214, 0, -14580, 0, -16213, 0, -14572, 0, -16212, 0, -14571, 0, -16211, 0, -14569, 0, -16210, 0, -14567, 0, -16209, 0, -14560, 0, -16208, 0, -14559, 0, -16207, 0, -14556, 0, -16206, 0, -14552, 0, -16205, 0, -14544, 0, -16204, 0, -14543, 0, -16203, 0, -14541, 0, -16202, 0, -14539, 0, -16201, 0, -14537, 0, -16200, 0, -14532, 0, -16199, 0, -14531, 0, -16198, 0, -14528, 0, -16197, 0, -14524, 0, -16196, 0, -14518, 0, -16195, 0, -14516, 0, -16194, 0, -14515, 0, -16193, 0, -14513, 0, -16192, 0, -14511, 0, -16191, 0, -14510, 0, -16190, 0, -14509, 0, -16189, 0, -14508, 0, -16188, 0, -14507, 0, -16187, 0, -14506, 0, -16186, 0, -14505, 0, -16185, 0, -14504, 0, -16184, 0, -14500, 0, -16183, 0, -14496, 0, -16182, 0, -14488, 0, -16181, 0, -14485, 0, -16180, 0, -14476, 0, -16179, 0, -14475, 0, -16178, 0, -14472, 0, -16177, 0, -14468, 0, -16176, 0, -14467, 0, -16175, 0, -14466, 0, -16174, 0, -14461, 0, -16173, 0, -14460, 0, -16172, 0, -14459, 0, -16171, 0, -14457, 0, -16170, 0, -14456, 0, -16169, 0, -14455, 0, -16168, 0, -14454, 0, -16167, 0, -14450, 0, -16166, 0, -14448, 0, -16165, 0, -14447, 0, -16164, 0, -14444, 0, -16163, 0, -14442, 0, -16162, 0, -14441, 0, -16161, 0, -14440, 0, -16160, 0, -14438, 0, -16159, 0, -14432, 0, -16158, 0, -14431, 0, -16157, 0, -14429, 0, -16156, 0, -14428, 0, -16155, 0, -14427, 0, -16154, 0, -14426, 0, -16153, 0, -14420, 0, -16152, 0, -14419, 0, -16151, 0, -14416, 0, -16150, 0, -14412, 0, -16149, 0, -14404, 0, -16148, 0, -14403, 0, -16147, 0, -14401, 0, -16146, 0, -14400, 0, -16145, 0, -14399, 0, -16144, 0, -14392, 0, -16143, 0, -14391, 0, -16142, 0, -14388, 0, -16141, 0, -14386, 0, -16140, 0, -14384, 0, -16139, 0, -14376, 0, -16138, 0, -14371, 0, -16137, 0, -14364, 0, -16136, 0, -14360, 0, -16135, 0, -14356, 0, -16134, 0, -14336, 0, -16133, 0, -14335, 0, -16132, 0, -14332, 0, -16131, 0, -14328, 0, -16130, 0, -14326, 0, -15967, 0, -14320, 0, -15966, 0, -14319, 0, -15965, 0, -14317, 0, -15964, 0, -14315, 0, -15963, 0, -14314, 0, -15962, 0, -14308, 0, -15961, 0, -14307, 0, -15960, 0, -14304, 0, -15959, 0, -14300, 0, -15958, 0, -14292, 0, -15957, 0, -14291, 0, -15956, 0, -14289, 0, -15955, 0, -14287, 0, -15954, 0, -14280, 0, -15953, 0, -14276, 0, -15952, 0, -14272, 0, -15951, 0, -14264, 0, -15950, 0, -14263, 0, -15949, 0, -14260, 0, -15948, 0, -14259, 0, -15947, 0, -14252, 0, -15946, 0, -14224, 0, -15945, 0, -14223, 0, -15944, 0, -14220, 0, -15943, 0, -14216, 0, -15942, 0, -14214, 0, -15941, 0, -14208, 0, -15940, 0, -14207, 0, -15939, 0, -14205, 0, -15938, 0, -14203, 0, -15937, 0, -14202, 0, -15936, 0, -14201, 0, -15935, 0, -14197, 0, -15934, 0, -14196, 0, -15933, 0, -14195, 0, -15932, 0, -14188, 0, -15931, 0, -14179, 0, -15930, 0, -14177, 0, -15929, 0, -14175, 0, -15928, 0, -14168, 0, -15927, 0, -14148, 0, -15926, 0, -14147, 0, -15925, 0, -14140, 0, -15924, 0, -14136, 0, -15923, 0, -14132, 0, -15922, 0, -14124, 0, -15921, 0, -14123, 0, -15920, 0, -14121, 0, -15919, 0, -14119, 0, -15918, 0, -14112, 0, -15917, 0, -14111, 0, -15916, 0, -14108, 0, -15915, 0, -14091, 0, -15914, 0, -14084, 0, -15913, 0, -14083, 0, -15912, 0, -14080, 0, -15911, 0, -14076, 0, -15910, 0, -14075, 0, -15909, 0, -14074, 0, -15908, 0, -14068, 0, -15907, 0, -14067, 0, -15906, 0, -14065, 0, -15905, 0, -14063, 0, -15904, 0, -14056, 0, -15903, 0, -14036, 0, -15902, 0, -14028, 0, -15901, 0, -14000, 0, -15900, 0, -13999, 0, -15899, 0, -13996, 0, -15898, 0, -13992, 0, -15897, 0, -13984, 0, -15896, 0, -13983, 0, -15895, 0, -13981, 0, -15894, 0, -13972, 0, -15893, 0, -13968, 0, -15892, 0, -13964, 0, -15891, 0, -13956, 0, -15890, 0, -13944, 0, -15889, 0, -13943, 0, -15888, 0, -13940, 0, -15887, 0, -13936, 0, -15886, 0, -13928, 0, -15885, 0, -13927, 0, -15884, 0, -13925, 0, -15883, 0, -13923, 0, -15882, 0, -13888, 0, -15881, 0, -13887, 0, -15880, 0, -13884, 0, -15879, 0, -13881, 0, -15878, 0, -13880, 0, -15877, 0, -13878, 0, -15876, 0, -13872, 0, -15875, 0, -13871, 0, -15874, 0, -13869, 0, -15711, 0, -13867, 0, -15710, 0, -13866, 0, -15709, 0, -13863, 0, -15708, 0, -13862, 0, -15707, 0, -13860, 0, -15706, 0, -13859, 0, -15705, 0, -13856, 0, -15704, 0, -13854, 0, -15703, 0, -13852, 0, -15702, 0, -13849, 0, -15701, 0, -13844, 0, -15700, 0, -13843, 0, -15699, 0, -13841, 0, -15698, 0, -13840, 0, -15697, 0, -13839, 0, -15696, 0, -13832, 0, -15695, 0, -13831, 0, -15694, 0, -13828, 0, -15693, 0, -13824, 0, -15692, 0, -13816, 0, -15691, 0, -13815, 0, -15690, 0, -13813, 0, -15689, 0, -13812, 0, -15688, 0, -13811, 0, -15687, 0, -13804, 0, -15686, 0, -13800, 0, -15685, 0, -13783, 0, -15684, 0, -13748, 0, -15683, 0, -13747, 0, -15682, 0, -13744, 0, -15681, 0, -13740, 0, -15680, 0, -13732, 0, -15679, 0, -13731, 0, -15678, 0, -13729, 0, -15677, 0, -13728, 0, -15676, 0, -13727, 0, -15675, 0, -13720, 0, -15674, 0, -13699, 0, -15673, 0, -13692, 0, -15672, 0, -13672, 0, -15671, 0, -13636, 0, -15670, 0, -13635, 0, -15669, 0, -13632, 0, -15668, 0, -13628, 0, -15667, 0, -13620, 0, -15666, 0, -13619, 0, -15665, 0, -13617, 0, -15664, 0, -13615, 0, -15663, 0, -13613, 0, -15662, 0, -13608, 0, -15661, 0, -13607, 0, -15660, 0, -13600, 0, -15659, 0, -13588, 0, -15658, 0, -13580, 0, -15657, 0, -13560, 0, -15656, 0, -13552, 0, -15655, 0, -13548, 0, -15654, 0, -13544, 0, -15653, 0, -13536, 0, -15652, 0, -13535, 0, -15651, 0, -13503, 0, -15650, 0, -13496, 0, -15649, 0, -13495, 0, -15648, 0, -13492, 0, -15647, 0, -13488, 0, -15646, 0, -13480, 0, -15645, 0, -13479, 0, -15644, 0, -13475, 0, -15643, 0, -13468, 0, -15642, 0, -13448, 0, -15641, 0, -13447, 0, -15640, 0, -13412, 0, -15639, 0, -13384, 0, -15638, 0, -13356, 0, -15637, 0, -13340, 0, -15636, 0, -13337, 0, -15635, 0, -13335, 0, -15634, 0, -13300, 0, -15633, 0, -13299, 0, -15632, 0, -13296, 0, -15631, 0, -13292, 0, -15630, 0, -13284, 0, -15629, 0, -13283, 0, -15628, 0, -13279, 0, -15627, 0, -13278, 0, -15626, 0, -13273, 0, -15625, 0, -13272, 0, -15624, 0, -13271, 0, -15623, 0, -13268, 0, -15622, 0, -13266, 0, -15621, 0, -13264, 0, -15620, 0, -13256, 0, -15619, 0, -13255, 0, -15618, 0, -13253, 0, -15455, 0, -13252, 0, -15454, 0, -13251, 0, -15453, 0, -13250, 0, -15452, 0, -13244, 0, -15451, 0, -13243, 0, -15450, 0, -13240, 0, -15449, 0, -13236, 0, -15448, 0, -13228, 0, -15447, 0, -13227, 0, -15446, 0, -13225, 0, -15445, 0, -13224, 0, -15444, 0, -13223, 0, -15443, 0, -13216, 0, -15442, 0, -13212, 0, -15441, 0, -13210, 0, -15440, 0, -13208, 0, -15439, 0, -13200, 0, -15438, 0, -13195, 0, -15437, 0, -13160, 0, -15436, 0, -13159, 0, -15435, 0, -13156, 0, -15434, 0, -13152, 0, -15433, 0, -13144, 0, -15432, 0, -13143, 0, -15431, 0, -13141, 0, -15430, 0, -13140, 0, -15429, 0, -13139, 0, -15428, 0, -13132, 0, -15427, 0, -13131, 0, -15426, 0, -13128, 0, -15425, 0, -13124, 0, -15424, 0, -13116, 0, -15423, 0, -13115, 0, -15422, 0, -13113, 0, -15421, 0, -13111, 0, -15420, 0, -13104, 0, -15419, 0, -13100, 0, -15418, 0, -13084, 0, -15417, 0, -13076, 0, -15416, 0, -13072, 0, -15415, 0, -13055, 0, -15414, 0, -13048, 0, -15413, 0, -13047, 0, -15412, 0, -13044, 0, -15411, 0, -13040, 0, -15410, 0, -13032, 0, -15409, 0, -13031, 0, -15408, 0, -13029, 0, -15407, 0, -13027, 0, -15406, 0, -13020, 0, -15405, 0, -13016, 0, -15404, 0, -13012, 0, -15403, 0, -12999, 0, -15402, 0, -12964, 0, -15401, 0, -12960, 0, -15400, 0, -12956, 0, -15399, 0, -12948, 0, -15398, 0, -12947, 0, -15397, 0, -12945, 0, -15396, 0, -12943, 0, -15395, 0, -12936, 0, -15394, 0, -12920, 0, -15393, 0, -12908, 0, -15392, 0, -12907, 0, -15391, 0, -12904, 0, -15390, 0, -12900, 0, -15389, 0, -12892, 0, -15388, 0, -12891, 0, -15387, 0, -12889, 0, -15386, 0, -12887, 0, -15385, 0, -12880, 0, -15384, 0, -12860, 0, -15383, 0, -12852, 0, -15382, 0, -12848, 0, -15381, 0, -12824, 0, -15380, 0, -12820, 0, -15379, 0, -12816, 0, -15378, 0, -12808, 0, -15377, 0, -12807, 0, -15376, 0, -12805, 0, -15375, 0, -12803, 0, -15374, 0, -12796, 0, -15373, 0, -12792, 0, -15372, 0, -12788, 0, -15371, 0, -12780, 0, -15370, 0, -12775, 0, -15369, 0, -12768, 0, -15368, 0, -12767, 0, -15367, 0, -12764, 0, -15366, 0, -12760, 0, -15365, 0, -12752, 0, -15364, 0, -12751, 0, -15363, 0, -12749, 0, -15362, 0, -12747, 0, -15199, 0, -12712, 0, -15198, 0, -12711, 0, -15197, 0, -12708, 0, -15196, 0, -12705, 0, -15195, 0, -12704, 0, -15194, 0, -12703, 0, -15193, 0, -12696, 0, -15192, 0, -12695, 0, -15191, 0, -12693, 0, -15190, 0, -12691, 0, -15189, 0, -12684, 0, -15188, 0, -12683, 0, -15187, 0, -12680, 0, -15186, 0, -12676, 0, -15185, 0, -12668, 0, -15184, 0, -12667, 0, -15183, 0, -12665, 0, -15182, 0, -12663, 0, -15181, 0, -12656, 0, -15180, 0, -12655, 0, -15179, 0, -12652, 0, -15178, 0, -12648, 0, -15177, 0, -12640, 0, -15176, 0, -12639, 0, -15175, 0, -12637, 0, -15174, 0, -12636, 0, -15173, 0, -12635, 0, -15172, 0, -12628, 0, -15171, 0, -12627, 0, -15170, 0, -12607, 0, -15169, 0, -12572, 0, -15168, 0, -12571, 0, -15167, 0, -12568, 0, -15166, 0, -12565, 0, -15165, 0, -12564, 0, -15164, 0, -12556, 0, -15163, 0, -12555, 0, -15162, 0, -12553, 0, -15161, 0, -12552, 0, -15160, 0, -12551, 0, -15159, 0, -12544, 0, -15158, 0, -12543, 0, -15157, 0, -12540, 0, -15156, 0, -12536, 0, -15155, 0, -12528, 0, -15154, 0, -12527, 0, -15153, 0, -12525, 0, -15152, 0, -12523, 0, -15151, 0, -12516, 0, -15150, 0, -12512, 0, -15149, 0, -12508, 0, -15148, 0, -12500, 0, -15147, 0, -12499, 0, -15146, 0, -12497, 0, -15145, 0, -12496, 0, -15144, 0, -12495, 0, -15143, 0, -12488, 0, -15142, 0, -12460, 0, -15141, 0, -12459, 0, -15140, 0, -12456, 0, -15139, 0, -12452, 0, -15138, 0, -12444, 0, -15137, 0, -12443, 0, -15136, 0, -12441, 0, -15135, 0, -12439, 0, -15134, 0, -12432, 0, -15133, 0, -12431, 0, -15132, 0, -12428, 0, -15131, 0, -12424, 0, -15130, 0, -12416, 0, -15129, 0, -12411, 0, -15128, 0, -12404, 0, -15127, 0, -12383, 0, -15126, 0, -12376, 0, -15125, 0, -12368, 0, -15124, 0, -12348, 0, -15123, 0, -12320, 0, -15122, 0, -12319, 0, -15121, 0, -12316, 0, -15120, 0, -12312, 0, -15119, 0, -12304, 0, -15118, 0, -12303, 0, -15117, 0, -12301, 0, -15116, 0, -12299, 0, -15115, 0, -12292, 0, -15114, 0, -12288, 0, -15113, 0, -12284, 0, -15112, 0, -12271, 0, -15111, 0, -12264, 0, -15110, 0, -12243, 0, -15109, 0, -12236, 0, -15108, 0, -12235, 0, -15107, 0, -12232, 0, -15106, 0, -12228, 0, -14943, 0, -12220, 0, -14942, 0, -12219, 0, -14941, 0, -12217, 0, -14940, 0, -12215, 0, -14939, 0, -12208, 0, -14938, 0, -12204, 0, -14937, 0, -12200, 0, -14936, 0, -12192, 0, -14935, 0, -12180, 0, -14934, 0, -12179, 0, -14933, 0, -12176, 0, -14932, 0, -12172, 0, -14931, 0, -12164, 0, -14930, 0, -12163, 0, -14929, 0, -12159, 0, -14928, 0, -12124, 0, -14927, 0, -12123, 0, -14926, 0, -12120, 0, -14925, 0, -12116, 0, -14924, 0, -12108, 0, -14923, 0, -12107, 0, -14922, 0, -12105, 0, -14921, 0, -12103, 0, -14920, 0, -12096, 0, -14919, 0, -12095, 0, -14918, 0, -12092, 0, -14917, 0, -12088, 0, -14916, 0, -12087, 0, -14915, 0, -12080, 0, -14914, 0, -12079, 0, -14913, 0, -12077, 0, -14912, 0, -12076, 0, -14911, 0, -12075, 0, -14910, 0, -12068, 0, -14909, 0, -12067, 0, -14908, 0, -12064, 0, -14907, 0, -12060, 0, -14906, 0, -12052, 0, -14905, 0, -12051, 0, -14904, 0, -12049, 0, -14903, 0, -12048, 0, -14902, 0, -12047, 0, -14901, 0, -12040, 0, -14900, 0, -12019, 0, -14899, 0, -11984, 0, -14898, 0, -11983, 0, -14897, 0, -11980, 0, -14896, 0, -11976, 0, -14895, 0, -11974, 0, -14894, 0, -11968, 0, -14893, 0, -11967, 0, -14892, 0, -11965, 0, -14891, 0, -11964, 0, -14890, 0, -11963, 0, -14889, 0, -11956, 0, -14888, 0, -11955, 0, -14887, 0, -11952, 0, -14886, 0, -11948, 0, -14885, 0, -11940, 0, -14884, 0, -11939, 0, -14883, 0, -11937, 0, -14882, 0, -11935, 0, -14881, 0, -11928, 0, -14880, 0, -11924, 0, -14879, 0, -11908, 0, -14878, 0, -11900, 0, -14877, 0, -11896, 0, -14876, 0, -11872, 0, -14875, 0, -11871, 0, -14874, 0, -11868, 0, -14873, 0, -11864, 0, -14872, 0, -11856, 0, -14871, 0, -11855, 0, -14870, 0, -11853, 0, -14869, 0, -11851, 0, -14868, 0, -11846, 0, -14867, 0, -11844, 0, -14866, 0, -11840, 0, -14865, 0, -11816, 0, -14864, 0, -11788, 0, -14863, 0, -11784, 0, -14862, 0, -11769, 0, -14861, 0, -11767, 0, -14860, 0, -11760, 0, -14859, 0, -11732, 0, -14858, 0, -11731, 0, -14857, 0, -11728, 0, -14856, 0, -11724, 0, -14855, 0, -11716, 0, -14854, 0, -11715, 0, -14853, 0, -11713, 0, -14852, 0, -11711, 0, -14851, 0, -11704, 0, -14850, 0, -11684, 0, -14687, 0, -11676, 0, -14686, 0, -11648, 0, -14685, 0, -11647, 0, -14684, 0, -11644, 0, -14683, 0, -11640, 0, -14682, 0, -11632, 0, -14681, 0, -11631, 0, -14680, 0, -11627, 0, -14679, 0, -11620, 0, -14678, 0, -11616, 0, -14677, 0, -11612, 0, -14676, 0, -11604, 0, -14675, 0, -11599, 0, -14674, 0, -11592, 0, -14673, 0, -11591, 0, -14672, 0, -11588, 0, -14671, 0, -11585, 0, -14670, 0, -11584, 0, -14669, 0, -11582, 0, -14668, 0, -11576, 0, -14667, 0, -11575, 0, -14666, 0, -11573, 0, -14665, 0, -11564, 0, -14664, 0, -11560, 0, -14663, 0, -11556, 0, -14662, 0, -11548, 0, -14661, 0, -11547, 0, -14660, 0, -11536, 0, -14659, 0, -11535, 0, -14658, 0, -11532, 0, -14657, 0, -11528, 0, -14656, 0, -11520, 0, -14655, 0, -11519, 0, -14654, 0, -11517, 0, -14653, 0, -11515, 0, -14652, 0, -11508, 0, -14651, 0, -11507, 0, -14650, 0, -11506, 0, -14649, 0, -11504, 0, -14648, 0, -11500, 0, -14647, 0, -11498, 0, -14646, 0, -11492, 0, -14645, 0, -11491, 0, -14644, 0, -11489, 0, -14643, 0, -11488, 0, -14642, 0, -11487, 0, -14641, 0, -11483, 0, -14640, 0, -11480, 0, -14639, 0, -11479, 0, -14638, 0, -11476, 0, -14637, 0, -11472, 0, -14636, 0, -11464, 0, -14635, 0, -11463, 0, -14634, 0, -11461, 0, -14633, 0, -11460, 0, -14632, 0, -11459, 0, -14631, 0, -11452, 0, -14630, 0, -11451, 0, -14629, 0, -11396, 0, -14628, 0, -11395, 0, -14627, 0, -11392, 0, -14626, 0, -11388, 0, -14625, 0, -11380, 0, -14624, 0, -11379, 0, -14623, 0, -11377, 0, -14622, 0, -11376, 0, -14621, 0, -11375, 0, -14620, 0, -11368, 0, -14619, 0, -11367, 0, -14618, 0, -11364, 0, -14617, 0, -11360, 0, -14616, 0, -11352, 0, -14615, 0, -11351, 0, -14614, 0, -11349, 0, -14613, 0, -11347, 0, -14612, 0, -11340, 0, -14611, 0, -11336, 0, -14610, 0, -11332, 0, -14609, 0, -11324, 0, -14608, 0, -11323, 0, -14607, 0, -11320, 0, -14606, 0, -11319, 0, -14605, 0, -11312, 0, -14604, 0, -11304, 0, -14603, 0, -11295, 0, -14602, 0, -11293, 0, -14601, 0, -11284, 0, -14600, 0, -11283, 0, -14599, 0, -11280, 0, -14598, 0, -11276, 0, -14597, 0, -11268, 0, -14596, 0, -11267, 0, -14595, 0, -11265, 0, -14594, 0, -11263, 0, -14431, 0, -11256, 0, -14430, 0, -11235, 0, -14429, 0, -11200, 0, -14428, 0, -11196, 0, -14427, 0, -11172, 0, -14426, 0, -11168, 0, -14425, 0, -11164, 0, -14424, 0, -11155, 0, -14423, 0, -11153, 0, -14422, 0, -11144, 0, -14421, 0, -11143, 0, -14420, 0, -11140, 0, -14419, 0, -11137, 0, -14418, 0, -11136, 0, -14417, 0, -11134, 0, -14416, 0, -11128, 0, -14415, 0, -11127, 0, -14414, 0, -11125, 0, -14413, 0, -11123, 0, -14412, 0, -11116, 0, -14411, 0, -11095, 0, -14410, 0, -11060, 0, -14409, 0, -11056, 0, -14408, 0, -11052, 0, -14407, 0, -11044, 0, -14406, 0, -11041, 0, -14405, 0, -11032, 0, -14404, 0, -11028, 0, -14403, 0, -11024, 0, -14402, 0, -11016, 0, -14401, 0, -11013, 0, -14400, 0, -11011, 0, -14399, 0, -11004, 0, -14398, 0, -11000, 0, -14397, 0, -10996, 0, -14396, 0, -10988, 0, -14395, 0, -10987, 0, -14394, 0, -10985, 0, -14393, 0, -10948, 0, -14392, 0, -10947, 0, -14391, 0, -10944, 0, -14390, 0, -10940, 0, -14389, 0, -10932, 0, -14388, 0, -10931, 0, -14387, 0, -10929, 0, -14386, 0, -10927, 0, -14385, 0, -10920, 0, -14384, 0, -10919, 0, -14383, 0, -10916, 0, -14382, 0, -10912, 0, -14381, 0, -10907, 0, -14380, 0, -10904, 0, -14379, 0, -10903, 0, -14378, 0, -10901, 0, -14377, 0, -10899, 0, -14376, 0, -10892, 0, -14375, 0, -10891, 0, -14374, 0, -10888, 0, -14373, 0, -10884, 0, -14372, 0, -10876, 0, -14371, 0, -10875, 0, -14370, 0, -10873, 0, -14369, 0, -10872, 0, -14368, 0, -10871, 0, -14367, 0, -10864, 0, -14366, 0, -10843, 0, -14365, 0, -10808, 0, -14364, 0, -10807, 0, -14363, 0, -10804, 0, -14362, 0, -10800, 0, -14361, 0, -10798, 0, -14360, 0, -10792, 0, -14359, 0, -10791, 0, -14358, 0, -10789, 0, -14357, 0, -10787, 0, -14356, 0, -10780, 0, -14355, 0, -10779, 0, -14354, 0, -10776, 0, -14353, 0, -10772, 0, -14352, 0, -10764, 0, -14351, 0, -10763, 0, -14350, 0, -10761, 0, -14349, 0, -10759, 0, -14348, 0, -10752, 0, -14347, 0, -10751, 0, -14346, 0, -10748, 0, -14345, 0, -10744, 0, -14344, 0, -10736, 0, -14343, 0, -10735, 0, -14342, 0, -10733, 0, -14341, 0, -10732, 0, -14340, 0, -10731, 0, -14339, 0, -10724, 0, -14338, 0, -10720, 0, -14175, 0, -10716, 0, -14174, 0, -10707, 0, -14173, 0, -10696, 0, -14172, 0, -10695, 0, -14171, 0, -10692, 0, -14170, 0, -10688, 0, -14169, 0, -10683, 0, -14168, 0, -10680, 0, -14167, 0, -10679, 0, -14166, 0, -10677, 0, -14165, 0, -10675, 0, -14164, 0, -10671, 0, -14163, 0, -10668, 0, -14162, 0, -10667, 0, -14161, 0, -10664, 0, -14160, 0, -10660, 0, -14159, 0, -10649, 0, -14158, 0, -10647, 0, -14157, 0, -10640, 0, -14156, 0, -10639, 0, -14155, 0, -10636, 0, -14154, 0, -10621, 0, -14153, 0, -10619, 0, -14152, 0, -10612, 0, -14151, 0, -10611, 0, -14150, 0, -10608, 0, -14149, 0, -10604, 0, -14148, 0, -10595, 0, -14147, 0, -10593, 0, -14146, 0, -10591, 0, -14145, 0, -10584, 0, -14144, 0, -10580, 0, -14143, 0, -10576, 0, -14142, 0, -10567, 0, -14141, 0, -10565, 0, -14140, 0, -10556, 0, -14139, 0, -10555, 0, -14138, 0, -10552, 0, -14137, 0, -10548, 0, -14136, 0, -10543, 0, -14135, 0, -10540, 0, -14134, 0, -10537, 0, -14133, 0, -10535, 0, -14132, 0, -10528, 0, -14131, 0, -10524, 0, -14130, 0, -10520, 0, -14129, 0, -10512, 0, -14128, 0, -10507, 0, -14127, 0, -10500, 0, -14126, 0, -10499, 0, -14125, 0, -10496, 0, -14124, 0, -10492, 0, -14123, 0, -10479, 0, -14122, 0, -10472, 0, -14121, 0, -10471, 0, -14120, 0, -10468, 0, -14119, 0, -10464, 0, -14118, 0, -10456, 0, -14117, 0, -10455, 0, -14116, 0, -10453, 0, -14115, 0, -10451, 0, -14114, 0, -10444, 0, -14113, 0, -10443, 0, -14112, 0, -10440, 0, -14111, 0, -10436, 0, -14110, 0, -10428, 0, -14109, 0, -10425, 0, -14108, 0, -10423, 0, -14107, 0, -10416, 0, -14106, 0, -10415, 0, -14105, 0, -10412, 0, -14104, 0, -10410, 0, -14103, 0, -10409, 0, -14102, 0, -10408, 0, -14101, 0, -10407, 0, -14100, 0, -10400, 0, -14099, 0, -10399, 0, -14098, 0, -10397, 0, -14097, 0, -10395, 0, -14096, 0, -10391, 0, -14095, 0, -10388, 0, -14094, 0, -10384, 0, -14093, 0, -10380, 0, -14092, 0, -10372, 0, -14091, 0, -10371, 0, -14090, 0, -10367, 0, -14089, 0, -10360, 0, -14088, 0, -10359, 0, -14087, 0, -10356, 0, -14086, 0, -10352, 0, -14085, 0, -10344, 0, -14084, 0, -10343, 0, -14083, 0, -10341, 0, -14082, 0, -10339, 0, -13663, 0, 20285, 0, -13662, 0, 20339, 0, -13661, 0, 20551, 0, -13660, 0, 20729, 0, -13659, 0, 21152, 0, -13658, 0, 21487, 0, -13657, 0, 21621, 0, -13656, 0, 21733, 0, -13655, 0, 22025, 0, -13654, 0, 23233, 0, -13653, 0, 23478, 0, -13652, 0, 26247, 0, -13651, 0, 26550, 0, -13650, 0, 26551, 0, -13649, 0, 26607, 0, -13648, 0, 27468, 0, -13647, 0, 29634, 0, -13646, 0, 30146, 0, -13645, 0, 31292, 0, -13644, 0, -32037, 0, -13643, 0, -31996, 0, -13642, 0, -30633, 0, -13641, 0, -30584, 0, -13640, 0, -30154, 0, -13639, 0, -29496, 0, -13638, 0, -29233, 0, -13637, 0, -28933, 0, -13636, 0, -28698, 0, -13635, 0, -26155, 0, -13634, 0, 21051, 0, -13633, 0, 21364, 0, -13632, 0, 21508, 0, -13631, 0, 24682, 0, -13630, 0, 24932, 0, -13629, 0, 27580, 0, -13628, 0, 29647, 0, -13627, 0, -32486, 0, -13626, 0, -30278, 0, -13625, 0, -30254, 0, -13624, 0, -27229, 0, -13623, 0, 20355, 0, -13622, 0, 21002, 0, -13621, 0, 22718, 0, -13620, 0, 22904, 0, -13619, 0, 23014, 0, -13618, 0, 24178, 0, -13617, 0, 24185, 0, -13616, 0, 25031, 0, -13615, 0, 25536, 0, -13614, 0, 26438, 0, -13613, 0, 26604, 0, -13612, 0, 26751, 0, -13611, 0, 28567, 0, -13610, 0, 30286, 0, -13609, 0, 30475, 0, -13608, 0, 30965, 0, -13607, 0, 31240, 0, -13606, 0, 31487, 0, -13605, 0, 31777, 0, -13604, 0, -32611, 0, -13603, 0, -32146, 0, -13602, 0, -32143, 0, -13601, 0, -29973, 0, -13600, 0, -27245, 0, -13599, 0, 20075, 0, -13598, 0, 21917, 0, -13597, 0, 26359, 0, -13596, 0, 28212, 0, -13595, 0, 30883, 0, -13594, 0, 31469, 0, -13593, 0, -31653, 0, -13592, 0, -30448, 0, -13591, 0, -30898, 0, -13590, 0, -26712, 0, -13589, 0, 21208, 0, -13588, 0, 22350, 0, -13587, 0, 22570, 0, -13586, 0, 23884, 0, -13585, 0, 24863, 0, -13584, 0, 25022, 0, -13583, 0, 25121, 0, -13582, 0, 25954, 0, -13581, 0, 26577, 0, -13580, 0, 27204, 0, -13579, 0, 28187, 0, -13578, 0, 29976, 0, -13577, 0, 30131, 0, -13576, 0, 30435, 0, -13575, 0, 30640, 0, -13574, 0, 32058, 0, -13573, 0, -28497, 0, -13572, 0, -27567, 0, -13571, 0, -27566, 0, -13570, 0, -24683, 0, -13407, 0, 21283, 0, -13406, 0, 23724, 0, -13405, 0, 30002, 0, -13404, 0, -32549, 0, -13403, 0, -28096, 0, -13402, 0, -27240, 0, -13401, 0, 21083, 0, -13400, 0, 22536, 0, -13399, 0, 23004, 0, -13398, 0, 23713, 0, -13397, 0, 23831, 0, -13396, 0, 24247, 0, -13395, 0, 24378, 0, -13394, 0, 24394, 0, -13393, 0, 24951, 0, -13392, 0, 27743, 0, -13391, 0, 30074, 0, -13390, 0, 30086, 0, -13389, 0, 31968, 0, -13388, 0, 32115, 0, -13387, 0, 32177, 0, -13386, 0, 32652, 0, -13385, 0, -32428, 0, -13384, 0, -32223, 0, -13383, 0, -31343, 0, -13382, 0, -30399, 0, -13381, 0, -29925, 0, -13380, 0, -27908, 0, -13379, 0, -1527, 0, -13378, 0, -25529, 0, -13377, 0, 20171, 0, -13376, 0, 20215, 0, -13375, 0, 20491, 0, -13374, 0, 20977, 0, -13373, 0, 22607, 0, -13372, 0, 24887, 0, -13371, 0, 24894, 0, -13370, 0, 24936, 0, -13369, 0, 25913, 0, -13368, 0, 27114, 0, -13367, 0, 28433, 0, -13366, 0, 30117, 0, -13365, 0, 30342, 0, -13364, 0, 30422, 0, -13363, 0, 31623, 0, -13362, 0, -32091, 0, -13361, 0, -31541, 0, -13360, 0, -29624, 0, -13359, 0, -27737, 0, -13358, 0, -27253, 0, -13357, 0, 21888, 0, -13356, 0, 23458, 0, -13355, 0, 22353, 0, -13354, 0, -1791, 0, -13353, 0, 31923, 0, -13352, 0, 32697, 0, -13351, 0, -28235, 0, -13350, 0, 20520, 0, -13349, 0, 21435, 0, -13348, 0, 23621, 0, -13347, 0, 24040, 0, -13346, 0, 25298, 0, -13345, 0, 25454, 0, -13344, 0, 25818, 0, -13343, 0, 25831, 0, -13342, 0, 28192, 0, -13341, 0, 28844, 0, -13340, 0, 31067, 0, -13339, 0, -29219, 0, -13338, 0, -29154, 0, -13337, 0, -28982, 0, -13336, 0, -28547, 0, -13335, 0, -28091, 0, -13334, 0, -27912, 0, -13333, 0, 20094, 0, -13332, 0, 20214, 0, -13331, 0, 20581, 0, -13330, 0, 24062, 0, -13329, 0, 24314, 0, -13328, 0, 24838, 0, -13327, 0, 26967, 0, -13326, 0, -32399, 0, -13325, 0, -31148, 0, -13324, 0, -29113, 0, -13323, 0, -27787, 0, -13322, 0, -26069, 0, -13321, 0, 20062, 0, -13320, 0, 20625, 0, -13319, 0, 26480, 0, -13318, 0, 26688, 0, -13317, 0, 20745, 0, -13316, 0, 21133, 0, -13315, 0, 21138, 0, -13314, 0, 27298, 0, -13151, 0, 30652, 0, -13150, 0, -28144, 0, -13149, 0, -24876, 0, -13148, 0, 21163, 0, -13147, 0, 24623, 0, -13146, 0, -28686, 0, -13145, 0, 20552, 0, -13144, 0, 25001, 0, -13143, 0, 25581, 0, -13142, 0, 25802, 0, -13141, 0, 26684, 0, -13140, 0, 27268, 0, -13139, 0, 28608, 0, -13138, 0, -32376, 0, -13137, 0, -30303, 0, -13136, 0, -26988, 0, -13135, 0, 22533, 0, -13134, 0, 29309, 0, -13133, 0, 29356, 0, -13132, 0, 29956, 0, -13131, 0, 32121, 0, -13130, 0, 32365, 0, -13129, 0, -32599, 0, -13128, 0, -30325, 0, -13127, 0, -29836, 0, -13126, 0, -28573, 0, -13125, 0, -25263, 0, -13124, 0, 25225, 0, -13123, 0, 27770, 0, -13122, 0, 28500, 0, -13121, 0, 32080, 0, -13120, 0, 32570, 0, -13119, 0, -30173, 0, -13118, 0, 20860, 0, -13117, 0, 24906, 0, -13116, 0, 31645, 0, -13115, 0, -29927, 0, -13114, 0, -28073, 0, -13113, 0, -27764, 0, -13112, 0, 20140, 0, -13111, 0, 20435, 0, -13110, 0, 20510, 0, -13109, 0, 20670, 0, -13108, 0, 20742, 0, -13107, 0, 21185, 0, -13106, 0, 21197, 0, -13105, 0, 21375, 0, -13104, 0, 22384, 0, -13103, 0, 22659, 0, -13102, 0, 24218, 0, -13101, 0, 24465, 0, -13100, 0, 24950, 0, -13099, 0, 25004, 0, -13098, 0, 25806, 0, -13097, 0, 25964, 0, -13096, 0, 26223, 0, -13095, 0, 26299, 0, -13094, 0, -1791, 0, -13093, 0, 26775, 0, -13092, 0, 28039, 0, -13091, 0, 28805, 0, -13090, 0, 28913, 0, -13089, 0, 29855, 0, -13088, 0, 29861, 0, -13087, 0, 29898, 0, -13086, 0, 30169, 0, -13085, 0, 30828, 0, -13084, 0, 30956, 0, -13083, 0, 31455, 0, -13082, 0, 31478, 0, -13081, 0, 32069, 0, -13080, 0, 32147, 0, -13079, 0, -32747, 0, -13078, 0, -32705, 0, -13077, 0, -32485, 0, -13076, 0, -31850, 0, -13075, 0, -29850, 0, -13074, 0, -28907, 0, -13073, 0, -28651, 0, -13072, 0, -27679, 0, -13071, 0, -26621, 0, -13070, 0, -26568, 0, -13069, 0, -26022, 0, -13068, 0, -25624, 0, -13067, 0, 20418, 0, -13066, 0, 21843, 0, -13065, 0, 22586, 0, -13064, 0, -1783, 0, -13063, 0, 23395, 0, -13062, 0, 23622, 0, -13061, 0, 24760, 0, -13060, 0, 25106, 0, -13059, 0, 26690, 0, -13058, 0, 26800, 0, -12895, 0, 26856, 0, -12894, 0, 28330, 0, -12893, 0, 30028, 0, -12892, 0, 30328, 0, -12891, 0, 30926, 0, -12890, 0, 31293, 0, -12889, 0, 31995, 0, -12888, 0, 32363, 0, -12887, 0, 32380, 0, -12886, 0, -30200, 0, -12885, 0, -30047, 0, -12884, 0, -29633, 0, -12883, 0, -26994, 0, -12882, 0, -25148, 0, -12881, 0, 21476, 0, -12880, 0, 21481, 0, -12879, 0, 21578, 0, -12878, 0, 21617, 0, -12877, 0, 22266, 0, -12876, 0, 22993, 0, -12875, 0, 23396, 0, -12874, 0, 23611, 0, -12873, 0, 24235, 0, -12872, 0, 25335, 0, -12871, 0, 25911, 0, -12870, 0, 25925, 0, -12869, 0, 25970, 0, -12868, 0, 26272, 0, -12867, 0, 26543, 0, -12866, 0, 27073, 0, -12865, 0, 27837, 0, -12864, 0, 30204, 0, -12863, 0, 30352, 0, -12862, 0, 30590, 0, -12861, 0, 31295, 0, -12860, 0, 32660, 0, -12859, 0, -32765, 0, -12858, 0, -32607, 0, -12857, 0, -32369, 0, -12856, 0, -32026, 0, -12855, 0, -32003, 0, -12854, 0, -31760, 0, -12853, 0, -31295, 0, -12852, 0, -30671, 0, -12851, 0, -30540, 0, -12850, 0, -30043, 0, -12849, 0, -29496, 0, -12848, 0, -28772, 0, -12847, 0, -27858, 0, -12846, 0, -26937, 0, -12845, 0, -26521, 0, -12844, 0, -25896, 0, -12843, 0, -24813, 0, -12842, 0, 21741, 0, -12841, 0, 26011, 0, -12840, 0, 26354, 0, -12839, 0, 26767, 0, -12838, 0, 31296, 0, -12837, 0, -29641, 0, -12836, 0, -25248, 0, -12835, 0, 22256, 0, -12834, 0, 22372, 0, -12833, 0, 23825, 0, -12832, 0, 26118, 0, -12831, 0, 26801, 0, -12830, 0, 26829, 0, -12829, 0, 28414, 0, -12828, 0, 29736, 0, -12827, 0, -30562, 0, -12826, 0, -25628, 0, -12825, 0, 27752, 0, -12824, 0, 28369, 0, -12823, 0, -25944, 0, -12822, 0, 20379, 0, -12821, 0, 20844, 0, -12820, 0, 20849, 0, -12819, 0, 21151, 0, -12818, 0, 23380, 0, -12817, 0, 24037, 0, -12816, 0, 24656, 0, -12815, 0, 24685, 0, -12814, 0, 25329, 0, -12813, 0, 25511, 0, -12812, 0, 25915, 0, -12811, 0, 29657, 0, -12810, 0, 31354, 0, -12809, 0, -31069, 0, -12808, 0, -29534, 0, -12807, 0, -26737, 0, -12806, 0, -1787, 0, -12805, 0, 23521, 0, -12804, 0, 25096, 0, -12803, 0, 26524, 0, -12802, 0, 29916, 0, -12639, 0, 31185, 0, -12638, 0, -31789, 0, -12637, 0, -30073, 0, -12636, 0, -30030, 0, -12635, 0, -29208, 0, -12634, 0, -28594, 0, -12633, 0, -27829, 0, -12632, 0, -26554, 0, -12631, 0, 24275, 0, -12630, 0, 27112, 0, -12629, 0, -31233, 0, -12628, 0, -28435, 0, -12627, 0, -1787, 0, -12626, 0, 20896, 0, -12625, 0, 23448, 0, -12624, 0, 23532, 0, -12623, 0, 24931, 0, -12622, 0, 26874, 0, -12621, 0, 27454, 0, -12620, 0, 28748, 0, -12619, 0, 29743, 0, -12618, 0, 29912, 0, -12617, 0, 31649, 0, -12616, 0, 32592, 0, -12615, 0, -31803, 0, -12614, 0, -30272, 0, -12613, 0, -29525, 0, -12612, 0, -27172, 0, -12611, 0, -26328, 0, -12610, 0, 21038, 0, -12609, 0, 24669, 0, -12608, 0, 25324, 0, -12607, 0, -28670, 0, -12606, 0, 20362, 0, -12605, 0, 20809, 0, -12604, 0, 21281, 0, -12603, 0, 22745, 0, -12602, 0, 24291, 0, -12601, 0, 26336, 0, -12600, 0, 27960, 0, -12599, 0, 28826, 0, -12598, 0, 29378, 0, -12597, 0, 29654, 0, -12596, 0, 31568, 0, -12595, 0, -32527, 0, -12594, 0, -27557, 0, -12593, 0, 21350, 0, -12592, 0, 25499, 0, -12591, 0, 32619, 0, -12590, 0, 20054, 0, -12589, 0, 20608, 0, -12588, 0, 22602, 0, -12587, 0, 22750, 0, -12586, 0, 24618, 0, -12585, 0, 24871, 0, -12584, 0, 25296, 0, -12583, 0, 27088, 0, -12582, 0, -25791, 0, -12581, 0, 23439, 0, -12580, 0, 32024, 0, -12579, 0, -32591, 0, -12578, 0, -28833, 0, -12577, 0, 20132, 0, -12576, 0, 20689, 0, -12575, 0, 21676, 0, -12574, 0, 21932, 0, -12573, 0, 23308, 0, -12572, 0, 23968, 0, -12571, 0, 24039, 0, -12570, 0, 25898, 0, -12569, 0, 25934, 0, -12568, 0, 26657, 0, -12567, 0, 27211, 0, -12566, 0, 29409, 0, -12565, 0, 30350, 0, -12564, 0, 30703, 0, -12563, 0, 32094, 0, -12562, 0, 32761, 0, -12561, 0, -32352, 0, -12560, 0, -31410, 0, -12559, 0, -31009, 0, -12558, 0, -28925, 0, -12557, 0, -28850, 0, -12556, 0, -28470, 0, -12555, 0, -26365, 0, -12554, 0, -26027, 0, -12553, 0, -25685, 0, -12552, 0, 19992, 0, -12551, 0, 20037, 0, -12550, 0, 20061, 0, -12549, 0, 20167, 0, -12548, 0, 20465, 0, -12547, 0, 20855, 0, -12546, 0, 21246, 0, -12383, 0, 21312, 0, -12382, 0, 21475, 0, -12381, 0, 21477, 0, -12380, 0, 21646, 0, -12379, 0, 22036, 0, -12378, 0, 22389, 0, -12377, 0, 22434, 0, -12376, 0, 23495, 0, -12375, 0, 23943, 0, -12374, 0, 24272, 0, -12373, 0, 25084, 0, -12372, 0, 25304, 0, -12371, 0, 25937, 0, -12370, 0, 26552, 0, -12369, 0, 26601, 0, -12368, 0, 27083, 0, -12367, 0, 27472, 0, -12366, 0, 27590, 0, -12365, 0, 27628, 0, -12364, 0, 27714, 0, -12363, 0, 28317, 0, -12362, 0, 28792, 0, -12361, 0, 29399, 0, -12360, 0, 29590, 0, -12359, 0, 29699, 0, -12358, 0, 30655, 0, -12357, 0, 30697, 0, -12356, 0, 31350, 0, -12355, 0, 32127, 0, -12354, 0, -32759, 0, -12353, 0, -32260, 0, -12352, 0, -32251, 0, -12351, 0, -32246, 0, -12350, 0, -32033, 0, -12349, 0, -30622, 0, -12348, 0, -29901, 0, -12347, 0, -29444, 0, -12346, 0, -28992, 0, -12345, 0, -28655, 0, -12344, 0, -28495, 0, -12343, 0, -28060, 0, -12342, 0, -27978, 0, -12341, 0, -26158, 0, -12340, 0, -26043, 0, -12339, 0, -25367, 0, -12338, 0, -25129, 0, -12337, 0, -1785, 0, -12336, 0, 22283, 0, -12335, 0, 23616, 0, -12334, 0, -31798, 0, -12333, 0, -26720, 0, -12332, 0, -26709, 0, -12331, 0, -24908, 0, -12330, 0, 21531, 0, -12329, 0, 31384, 0, -12328, 0, 32676, 0, -12327, 0, -30503, 0, -12326, 0, -28979, 0, -12325, 0, -28447, 0, -12324, 0, 22528, 0, -12323, 0, 23624, 0, -12322, 0, 25496, 0, -12321, 0, 31391, 0, -12320, 0, 23470, 0, -12319, 0, 24339, 0, -12318, 0, 31353, 0, -12317, 0, 31406, 0, -12316, 0, -32114, 0, -12315, 0, -29012, 0, -12314, 0, 20518, 0, -12313, 0, 21048, 0, -12312, 0, 21240, 0, -12311, 0, 21367, 0, -12310, 0, 22280, 0, -12309, 0, 25331, 0, -12308, 0, 25458, 0, -12307, 0, 27402, 0, -12306, 0, 28099, 0, -12305, 0, 30519, 0, -12304, 0, 21413, 0, -12303, 0, 29527, 0, -12302, 0, -31384, 0, -12301, 0, -29066, 0, -12300, 0, -27179, 0, -12299, 0, 26426, 0, -12298, 0, 27331, 0, -12297, 0, 28528, 0, -12296, 0, -30099, 0, -12295, 0, -28980, 0, -12294, 0, -26293, 0, -12293, 0, 21477, 0, -12292, 0, 26231, 0, -12291, 0, 27512, 0, -12290, 0, -29516, 0, -12127, 0, -25796, 0, -12126, 0, -1785, 0, -12125, 0, 21483, 0, -12124, 0, 22317, 0, -12123, 0, 22862, 0, -12122, 0, 25542, 0, -12121, 0, 27131, 0, -12120, 0, 29674, 0, -12119, 0, 30789, 0, -12118, 0, 31418, 0, -12117, 0, 31429, 0, -12116, 0, 31998, 0, -12115, 0, -31627, 0, -12114, 0, -30321, 0, -12113, 0, -29325, 0, -12112, 0, -28619, 0, -12111, 0, -27224, 0, -12110, 0, 21243, 0, -12109, 0, 22343, 0, -12108, 0, 30023, 0, -12107, 0, 31584, 0, -12106, 0, -31796, 0, -12105, 0, -28130, 0, -12104, 0, -1785, 0, -12103, 0, 27224, 0, -12102, 0, 20811, 0, -12101, 0, 21067, 0, -12100, 0, 21127, 0, -12099, 0, 25119, 0, -12098, 0, 26840, 0, -12097, 0, 26997, 0, -12096, 0, -26983, 0, -12095, 0, 20677, 0, -12094, 0, 21156, 0, -12093, 0, 21220, 0, -12092, 0, 25027, 0, -12091, 0, 26020, 0, -12090, 0, 26681, 0, -12089, 0, 27135, 0, -12088, 0, 29822, 0, -12087, 0, 31563, 0, -12086, 0, -32071, 0, -12085, 0, -31765, 0, -12084, 0, -30286, 0, -12083, 0, -29895, 0, -12082, 0, -28719, 0, -12081, 0, -26295, 0, -12080, 0, -1783, 0, -12079, 0, 20170, 0, -12078, 0, 22935, 0, -12077, 0, 25810, 0, -12076, 0, 26129, 0, -12075, 0, 27278, 0, -12074, 0, 29748, 0, -12073, 0, 31105, 0, -12072, 0, 31165, 0, -12071, 0, -32087, 0, -12070, 0, -30594, 0, -12069, 0, -30593, 0, -12068, 0, -30369, 0, -12067, 0, -28207, 0, -12066, 0, -27866, 0, -12065, 0, 20235, 0, -12064, 0, 21450, 0, -12063, 0, 24613, 0, -12062, 0, 25201, 0, -12061, 0, 27762, 0, -12060, 0, 32026, 0, -12059, 0, 32102, 0, -12058, 0, 20120, 0, -12057, 0, 20834, 0, -12056, 0, 30684, 0, -12055, 0, -32593, 0, -12054, 0, 20225, 0, -12053, 0, 20238, 0, -12052, 0, 20854, 0, -12051, 0, 20864, 0, -12050, 0, 21980, 0, -12049, 0, 22120, 0, -12048, 0, 22331, 0, -12047, 0, 22522, 0, -12046, 0, 22524, 0, -12045, 0, 22804, 0, -12044, 0, 22855, 0, -12043, 0, 22931, 0, -12042, 0, 23492, 0, -12041, 0, 23696, 0, -12040, 0, 23822, 0, -12039, 0, 24049, 0, -12038, 0, 24190, 0, -12037, 0, 24524, 0, -12036, 0, 25216, 0, -12035, 0, 26071, 0, -12034, 0, 26083, 0, -11871, 0, 26398, 0, -11870, 0, 26399, 0, -11869, 0, 26462, 0, -11868, 0, 26827, 0, -11867, 0, 26820, 0, -11866, 0, 27231, 0, -11865, 0, 27450, 0, -11864, 0, 27683, 0, -11863, 0, 27773, 0, -11862, 0, 27778, 0, -11861, 0, 28103, 0, -11860, 0, 29592, 0, -11859, 0, 29734, 0, -11858, 0, 29738, 0, -11857, 0, 29826, 0, -11856, 0, 29859, 0, -11855, 0, 30072, 0, -11854, 0, 30079, 0, -11853, 0, 30849, 0, -11852, 0, 30959, 0, -11851, 0, 31041, 0, -11850, 0, 31047, 0, -11849, 0, 31048, 0, -11848, 0, 31098, 0, -11847, 0, 31637, 0, -11846, 0, 32000, 0, -11845, 0, 32186, 0, -11844, 0, 32648, 0, -11843, 0, -32762, 0, -11842, 0, -32723, 0, -11841, 0, -32628, 0, -11840, 0, -30184, 0, -11839, 0, -29873, 0, -11838, 0, -29624, 0, -11837, 0, -29321, 0, -11836, 0, -27871, 0, -11835, 0, -27868, 0, -11834, 0, -26398, 0, -11833, 0, -26287, 0, -11832, 0, -26098, 0, -11831, 0, -26097, 0, -11830, 0, -26011, 0, -11829, 0, -24942, 0, -11828, 0, 32202, 0, -11827, 0, 20342, 0, -11826, 0, 21513, 0, -11825, 0, 25326, 0, -11824, 0, 26708, 0, -11823, 0, -28207, 0, -11822, 0, 21931, 0, -11821, 0, 20794, 0, -11820, 0, -1781, 0, -11819, 0, 22856, 0, -11818, 0, 23068, 0, -11817, 0, 25062, 0, -11816, 0, -1779, 0, -11815, 0, 25295, 0, -11814, 0, 25343, 0, -11813, 0, -1778, 0, -11812, 0, -1777, 0, -11811, 0, -31169, 0, -11810, 0, -30790, 0, -11809, 0, -30472, 0, -11808, 0, -28529, 0, -11807, 0, -28509, 0, -11806, 0, -1700, 0, -11805, 0, 27931, 0, -11804, 0, 28889, 0, -11803, 0, 29662, 0, -11802, 0, -31683, 0, -11801, 0, -1699, 0, -11800, 0, -28310, 0, -11799, 0, -26127, 0, -11798, 0, 20098, 0, -11797, 0, 21365, 0, -11796, 0, 26262, 0, -11795, 0, 27396, 0, -11794, 0, 29014, 0, -11793, 0, 29211, 0, -11792, 0, -31187, 0, -11791, 0, -26909, 0, -11790, 0, -25058, 0, -11789, 0, 25423, 0, -11788, 0, 25466, 0, -11787, 0, 21335, 0, -11786, 0, 23888, 0, -11785, 0, 26511, 0, -11784, 0, 26976, 0, -11783, 0, 28275, 0, -11782, 0, 28651, 0, -11781, 0, 30007, 0, -11780, 0, -31283, 0, -11779, 0, -30364, 0, -11778, 0, 25289, 0, -11615, 0, 32013, 0, -11614, 0, -1754, 0, -11613, 0, -1753, 0, -11612, 0, -30606, 0, -11611, 0, 22218, 0, -11610, 0, 23064, 0, -11609, 0, -1752, 0, -11608, 0, -1751, 0, -11607, 0, -1750, 0, -11606, 0, -1749, 0, -11605, 0, -1748, 0, -11604, 0, 20035, 0, -11603, 0, -1747, 0, -11602, 0, 20839, 0, -11601, 0, 22856, 0, -11600, 0, 26608, 0, -11599, 0, -32752, 0, -11598, 0, -1746, 0, -11597, 0, 22899, 0, -11596, 0, 24180, 0, -11595, 0, 25754, 0, -11594, 0, 31178, 0, -11593, 0, 24565, 0, -11592, 0, 24684, 0, -11591, 0, 25288, 0, -11590, 0, 25467, 0, -11589, 0, -1622, 0, -11588, 0, 23511, 0, -11587, 0, 21162, 0, -11586, 0, -1745, 0, -11585, 0, 22900, 0, -11584, 0, 24361, 0, -11583, 0, 24594, 0, -11582, 0, -1744, 0, -11581, 0, -1743, 0, -11580, 0, -1742, 0, -11579, 0, 29785, 0, -11578, 0, -1741, 0, -11577, 0, -1740, 0, -11576, 0, -1739, 0, -11575, 0, -1738, 0, -11574, 0, -1737, 0, -11573, 0, -1736, 0, -11572, 0, -26159, 0, -11571, 0, -1735, 0, -11570, 0, -1734, 0, -11569, 0, -1733, 0, -11568, 0, -1732, 0, -11567, 0, -1731, 0, -11566, 0, -1730, 0, -11565, 0, -1729, 0, -11564, 0, -1728, 0, -11563, 0, -1727, 0, -11562, 0, -1726, 0, -11561, 0, -1725, 0, -11560, 0, 28611, 0, -11559, 0, -1724, 0, -11558, 0, -1723, 0, -11557, 0, -32321, 0, -11556, 0, -28750, 0, -11555, 0, 24817, 0, -11554, 0, -1722, 0, -11553, 0, -1721, 0, -11552, 0, -32410, 0, -11551, 0, -1720, 0, -11550, 0, -1719, 0, -11549, 0, 23615, 0, -11548, 0, 22744, 0, -11547, 0, 23650, 0, -11546, 0, 27155, 0, -11545, 0, 28122, 0, -11544, 0, 28431, 0, -11543, 0, 32047, 0, -11542, 0, 32311, 0, -11541, 0, -27061, 0, -11540, 0, 23273, 0, -11539, 0, -30171, 0, -11538, 0, 26491, 0, -11537, 0, -1585, 0, -11536, 0, 21202, 0, -11535, 0, -32629, 0, -11534, 0, 20956, 0, -11533, 0, 20940, 0, -11532, 0, 31260, 0, -11531, 0, 32190, 0, -11530, 0, -32515, 0, -11529, 0, -31759, 0, -11528, 0, -27019, 0, -11527, 0, 23612, 0, -11526, 0, -1565, 0, -11525, 0, -1557, 0, -11524, 0, -1556, 0, -11523, 0, 22810, 0, -11522, 0, -1538, 0, -11359, 0, 20025, 0, -11358, 0, 20150, 0, -11357, 0, 20294, 0, -11356, 0, 21934, 0, -11355, 0, 22296, 0, -11354, 0, 22727, 0, -11353, 0, 24406, 0, -11352, 0, 26039, 0, -11351, 0, 26086, 0, -11350, 0, 27264, 0, -11349, 0, 27573, 0, -11348, 0, 28237, 0, -11347, 0, 30701, 0, -11346, 0, 31471, 0, -11345, 0, 31774, 0, -11344, 0, 32222, 0, -11343, 0, -31029, 0, -11342, 0, -30574, 0, -11341, 0, -28366, 0, -11340, 0, -27813, 0, -11339, 0, 25787, 0, -11338, 0, 28606, 0, -11337, 0, 29562, 0, -11336, 0, 30136, 0, -11335, 0, -28588, 0, -11334, 0, 21846, 0, -11333, 0, 22349, 0, -11332, 0, 25018, 0, -11331, 0, 25812, 0, -11330, 0, 26311, 0, -11329, 0, 28129, 0, -11328, 0, 28251, 0, -11327, 0, 28525, 0, -11326, 0, 28601, 0, -11325, 0, 30192, 0, -11324, 0, -32701, 0, -11323, 0, -32323, 0, -11322, 0, -31423, 0, -11321, 0, -30333, 0, -11320, 0, -30009, 0, -11319, 0, -29862, 0, -11318, 0, -27873, 0, -11317, 0, 27795, 0, -11316, 0, 30035, 0, -11315, 0, 31572, 0, -11314, 0, -29169, 0, -11313, 0, -28579, 0, -11312, 0, 21776, 0, -11311, 0, 22530, 0, -11310, 0, 22616, 0, -11309, 0, 24162, 0, -11308, 0, 25095, 0, -11307, 0, 25758, 0, -11306, 0, 26848, 0, -11305, 0, 30070, 0, -11304, 0, -1533, 0, -11303, 0, -30797, 0, -11302, 0, -24856, 0, -11301, 0, 20195, 0, -11300, 0, 22408, 0, -11299, 0, 22382, 0, -11298, 0, 22823, 0, -11297, 0, 23565, 0, -11296, 0, 23729, 0, -11295, 0, 24118, 0, -11294, 0, 24453, 0, -11293, 0, 25140, 0, -11292, 0, 25825, 0, -11291, 0, 29619, 0, -11290, 0, -32262, 0, -11289, 0, -30581, 0, -11288, 0, -29512, 0, -11287, 0, -26998, 0, -11286, 0, -24869, 0, -11285, 0, -1532, 0, -11284, 0, 24503, 0, -11283, 0, 24755, 0, -11282, 0, 20498, 0, -11281, 0, 20992, 0, -11280, 0, 21040, 0, -11279, 0, 22294, 0, -11278, 0, 22581, 0, -11277, 0, 22615, 0, -11276, 0, 23566, 0, -11275, 0, 23648, 0, -11274, 0, 23798, 0, -11273, 0, 23947, 0, -11272, 0, -1535, 0, -11271, 0, 24466, 0, -11270, 0, 24764, 0, -11269, 0, 25361, 0, -11268, 0, 25481, 0, -11267, 0, 25623, 0, -11266, 0, 26691, 0, -11103, 0, 26873, 0, -11102, 0, 27330, 0, -11101, 0, 28120, 0, -11100, 0, 28193, 0, -11099, 0, 28372, 0, -11098, 0, 28644, 0, -11097, 0, 29182, 0, -11096, 0, 30428, 0, -11095, 0, 30585, 0, -11094, 0, 31153, 0, -11093, 0, 31291, 0, -11092, 0, -31740, 0, -11091, 0, -30295, 0, -11090, 0, -29459, 0, -11089, 0, -29197, 0, -11088, 0, -29112, 0, -11087, 0, -28669, 0, -11086, 0, -28652, 0, -11085, 0, -28589, 0, -11084, 0, -28419, 0, -11083, 0, -27827, 0, -11082, 0, -27018, 0, -11081, 0, -26660, 0, -11080, 0, 27602, 0, -11079, 0, 28678, 0, -11078, 0, 29272, 0, -11077, 0, 29346, 0, -11076, 0, 29544, 0, -11075, 0, 30563, 0, -11074, 0, 31167, 0, -11073, 0, 31716, 0, -11072, 0, 32411, 0, -11071, 0, -29824, 0, -11070, 0, 22697, 0, -11069, 0, 24775, 0, -11068, 0, 25958, 0, -11067, 0, 26109, 0, -11066, 0, 26302, 0, -11065, 0, 27788, 0, -11064, 0, 28958, 0, -11063, 0, 29129, 0, -11062, 0, -29606, 0, -11061, 0, -26605, 0, -11060, 0, 20077, 0, -11059, 0, 31361, 0, -11058, 0, 20189, 0, -11057, 0, 20908, 0, -11056, 0, 20941, 0, -11055, 0, 21205, 0, -11054, 0, 21516, 0, -11053, 0, 24999, 0, -11052, 0, 26481, 0, -11051, 0, 26704, 0, -11050, 0, 26847, 0, -11049, 0, -1531, 0, -11048, 0, 28540, 0, -11047, 0, 30140, 0, -11046, 0, 30643, 0, -11045, 0, 31461, 0, -11044, 0, -32524, 0, -11043, 0, -31645, 0, -11042, 0, -28027, 0, -11041, 0, 20828, 0, -11040, 0, 26007, 0, -11039, 0, 26460, 0, -11038, 0, 26515, 0, -11037, 0, 30168, 0, -11036, 0, 31431, 0, -11035, 0, -31885, 0, -11034, 0, -29824, 0, -11033, 0, -29626, 0, -11032, 0, -28649, 0, -11031, 0, -26579, 0, -11030, 0, 23663, 0, -11029, 0, -32320, 0, -11028, 0, -32102, 0, -11027, 0, -28607, 0, -11026, 0, -28561, 0, -11025, 0, -28147, 0, -11024, 0, 24471, 0, -11023, 0, 23965, 0, -11022, 0, 27225, 0, -11021, 0, 29128, 0, -11020, 0, 30331, 0, -11019, 0, 31561, 0, -11018, 0, -31260, 0, -11017, 0, -29948, 0, -11016, 0, -28377, 0, -11015, 0, -26064, 0, -11014, 0, -1781, 0, -11013, 0, -1779, 0, -11012, 0, 25295, 0, -11011, 0, -1778, 0, -11010, 0, -1777, 0, -10847, 0, -31169, 0, -10846, 0, -30790, 0, -10845, 0, -30472, 0, -10844, 0, -28529, 0, -10843, 0, -1700, 0, -10842, 0, 27931, 0, -10841, 0, 28889, 0, -10840, 0, 29662, 0, -10839, 0, 32097, 0, -10838, 0, -31683, 0, -10837, 0, -1699, 0, -10836, 0, -28310, 0, -10835, 0, -26127, 0, -10834, 0, 20025, 0, -10833, 0, 20098, 0, -10832, 0, 21365, 0, -10831, 0, 27396, 0, -10830, 0, 27410, 0, -10829, 0, 28734, 0, -10828, 0, 29211, 0, -10827, 0, -31187, 0, -10826, 0, -25058, 0, -10825, 0, 21068, 0, -10824, 0, -28765, 0, -10823, 0, 23888, 0, -10822, 0, 25829, 0, -10821, 0, 25900, 0, -10820, 0, 27414, 0, -10819, 0, 28651, 0, -10818, 0, 31811, 0, -10817, 0, 32412, 0, -10816, 0, -31283, 0, -10815, 0, -30364, 0, -10814, 0, -30275, 0, -10813, 0, 25289, 0, -10812, 0, -1754, 0, -10811, 0, -1753, 0, -10810, 0, -1752, 0, -10809, 0, -1751, 0, -10808, 0, -1750, 0, -10807, 0, -1749, 0, -10806, 0, 29701, 0, -10805, 0, 29807, 0, -10804, 0, -30846, 0, -10803, 0, -1748, 0, -10802, 0, -1747, 0, -10801, 0, 23821, 0, -10800, 0, 24480, 0, -10799, 0, -31734, 0, -10798, 0, -1746, 0, -10797, 0, -1675, 0, -10796, 0, -1674, 0, -10795, 0, -1673, 0, -10794, 0, 20486, 0, -10793, 0, -1672, 0, -10792, 0, -1671, 0, -10791, 0, -1670, 0, -10790, 0, 27153, 0, -10789, 0, 31918, 0, -10788, 0, 31921, 0, -10787, 0, -1669, 0, -10786, 0, -1668, 0, -10785, 0, -1667, 0, -10784, 0, -28901, 0, -10783, 0, -1666, 0, -10782, 0, 20406, 0, -10781, 0, 20791, 0, -10780, 0, 21237, 0, -10779, 0, 21570, 0, -10778, 0, 24300, 0, -10777, 0, 24942, 0, -10776, 0, 25150, 0, -10775, 0, -1661, 0, -10774, 0, 27354, 0, -10773, 0, -1660, 0, -10772, 0, -1659, 0, -10771, 0, -31268, 0, -10770, 0, -30685, 0, -10769, 0, -1658, 0, -10768, 0, -26014, 0, -10767, 0, -1657, 0, -10766, 0, -1656, 0, -10765, 0, -1655, 0, -10764, 0, -1654, 0, -10763, 0, -1653, 0, -10762, 0, -1652, 0, -10761, 0, 28701, 0, -10760, 0, 31019, 0, -10759, 0, -1651, 0, -10758, 0, -26814, 0, -10757, 0, -1649, 0, -10756, 0, -1648, 0, -10755, 0, 25891, 0, -10754, 0, -1646, 0, -10591, 0, 29001, 0, -10590, 0, 29833, 0, -10589, 0, 32244, 0, -10588, 0, -32657, 0, -10587, 0, -31506, 0, -10586, 0, -28890, 0, -10585, 0, -28637, 0, -10584, 0, -27830, 0, -10583, 0, 20925, 0, -10582, 0, 21015, 0, -10581, 0, 21155, 0, -10580, 0, 27916, 0, -10579, 0, 28872, 0, -10578, 0, -30526, 0, -10577, 0, 24265, 0, -10576, 0, 25986, 0, -10575, 0, 27566, 0, -10574, 0, 28610, 0, -10573, 0, -1626, 0, -10572, 0, -1625, 0, -10571, 0, -1624, 0, -10570, 0, 20278, 0, -10569, 0, -1623, 0, -10568, 0, -1622, 0, -10567, 0, 23738, 0, -10566, 0, -1621, 0, -10565, 0, -1620, 0, -10564, 0, 29618, 0, -10563, 0, 31533, 0, -10562, 0, 32666, 0, -10561, 0, 32718, 0, -10560, 0, -32698, 0, -10559, 0, -28642, 0, -10558, 0, -28108, 0, -10557, 0, -26890, 0, -10556, 0, -26808, 0, -10555, 0, -26600, 0, -10554, 0, -24735, 0, -10553, 0, 20363, 0, -10552, 0, 28583, 0, -10551, 0, 31150, 0, -10550, 0, -28236, 0, -10549, 0, -26953, 0, -10548, 0, -1745, 0, -10547, 0, 24594, 0, -10546, 0, 25736, 0, -10545, 0, -1744, 0, -10544, 0, -1743, 0, -10543, 0, 28510, 0, -10542, 0, 28696, 0, -10541, 0, -1742, 0, -10540, 0, -1741, 0, -10539, 0, -1740, 0, -10538, 0, -1739, 0, -10537, 0, -1738, 0, -10536, 0, -1737, 0, -10535, 0, -28923, 0, -10534, 0, -1736, 0, -10533, 0, -1735, 0, -10532, 0, -1734, 0, -10531, 0, -24971, 0, -10530, 0, -1733, 0, -10529, 0, -1732, 0, -10528, 0, -1731, 0, -10527, 0, -1730, 0, -10526, 0, -1729, 0, -10525, 0, -1728, 0, -10524, 0, -24941, 0, -10523, 0, -1727, 0, -10522, 0, -1726, 0, -10521, 0, -1725, 0, -10520, 0, 26407, 0, -10519, 0, 28711, 0, -10518, 0, 29903, 0, -10517, 0, -1724, 0, -10516, 0, -1723, 0, -10515, 0, 20769, 0, -10514, 0, 28712, 0, -10513, 0, -1722, 0, -10512, 0, -1721, 0, -10511, 0, -1720, 0, -10510, 0, -29478, 0, -10509, 0, -29452, 0, -10508, 0, -1719, 0, -10507, 0, -1606, 0, -10506, 0, -1605, 0, -10505, 0, -1604, 0, -10504, 0, 24278, 0, -10503, 0, -1602, 0, -10502, 0, 29134, 0, -10501, 0, 30274, 0, -10500, 0, 30637, 0, -10499, 0, -32694, 0, -10498, 0, -1598, 0, -10335, 0, -28548, 0, -10334, 0, -25817, 0, -10333, 0, -24691, 0, -10332, 0, 22744, 0, -10331, 0, 23105, 0, -10330, 0, 23650, 0, -10329, 0, 27155, 0, -10328, 0, 28122, 0, -10327, 0, 28431, 0, -10326, 0, 30267, 0, -10325, 0, 32047, 0, -10324, 0, 32311, 0, -10323, 0, -31458, 0, -10322, 0, -30408, 0, -10321, 0, -27676, 0, -10320, 0, -27061, 0, -10319, 0, 21129, 0, -10318, 0, 26066, 0, -10317, 0, 26611, 0, -10316, 0, 27060, 0, -10315, 0, 27969, 0, -10314, 0, 28316, 0, -10313, 0, 28687, 0, -10312, 0, -1588, 0, -10311, 0, 29792, 0, -10310, 0, -1587, 0, -10309, 0, 30244, 0, -10308, 0, -1586, 0, -10307, 0, -29908, 0, -10306, 0, -1584, 0, -10305, 0, -1583, 0, -10304, 0, -1582, 0, -10303, 0, -27016, 0, -10302, 0, 20374, 0, -10301, 0, -1580, 0, -10300, 0, 23833, 0, -10299, 0, 28138, 0, -10298, 0, 32184, 0, -10297, 0, -28886, 0, -10296, 0, 24459, 0, -10295, 0, 24900, 0, -10294, 0, 26647, 0, -10293, 0, -1695, 0, -10292, 0, -27002, 0, -10291, 0, 21202, 0, -10290, 0, -32629, 0, -10289, 0, 20956, 0, -10288, 0, 20940, 0, -10287, 0, 26974, 0, -10286, 0, 31260, 0, -10285, 0, 32190, 0, -10284, 0, -31759, 0, -10283, 0, -27019, 0, -10282, 0, 20442, 0, -10281, 0, -1571, 0, -10280, 0, 21400, 0, -10279, 0, -1570, 0, -10278, 0, 21774, 0, -10277, 0, -1569, 0, -10276, 0, 24743, 0, -10275, 0, -1567, 0, -10274, 0, -1566, 0, -10273, 0, 28012, 0, -10272, 0, 29313, 0, -10271, 0, 29432, 0, -10270, 0, -1564, 0, -10269, 0, 29827, 0, -10268, 0, 30064, 0, -10267, 0, -1563, 0, -10266, 0, 31852, 0, -10265, 0, -1562, 0, -10264, 0, 32696, 0, -10263, 0, -31863, 0, -10262, 0, -1561, 0, -10261, 0, -1560, 0, -10260, 0, -1559, 0, -10259, 0, -28208, 0, -10258, 0, -1558, 0, -10257, 0, -25655, 0, -10256, 0, -1555, 0, -10255, 0, 28542, 0, -10254, 0, -1554, 0, -10253, 0, -1553, 0, -10252, 0, -1552, 0, -10251, 0, -29014, 0, -10250, 0, -1551, 0, -10249, 0, -1550, 0, -10248, 0, -1549, 0, -10247, 0, -1548, 0, -10246, 0, -1547, 0, -10245, 0, 29747, 0, -10244, 0, -1546, 0, -10243, 0, -26858, 0, -10242, 0, 30764, 0, -10079, 0, 31435, 0, -10078, 0, 31520, 0, -10077, 0, 31890, 0, -10076, 0, 25705, 0, -10075, 0, 29802, 0, -10074, 0, 30194, 0, -10073, 0, 30908, 0, -10072, 0, 30952, 0, -10071, 0, -26196, 0, -10070, 0, -25772, 0, -10069, 0, -24901, 0, -10068, 0, 23518, 0, -10067, 0, 24149, 0, -10066, 0, 28448, 0, -10065, 0, -32356, 0, -10064, 0, -31829, 0, -10063, 0, -28536, 0, -10062, 0, 19975, 0, -10061, 0, 21325, 0, -10060, 0, 23081, 0, -10059, 0, 24018, 0, -10058, 0, 24398, 0, -10057, 0, 24930, 0, -10056, 0, 25405, 0, -10055, 0, 26217, 0, -10054, 0, 26364, 0, -10053, 0, 28415, 0, -10052, 0, 28459, 0, -10051, 0, 28771, 0, -10050, 0, 30622, 0, -10049, 0, -31700, 0, -10048, 0, -31469, 0, -10047, 0, -30661, 0, -10046, 0, -28909, 0, -10045, 0, -26299, 0, -10044, 0, -25541, 0, -10043, 0, 21788, 0, -10042, 0, 25273, 0, -10041, 0, 26411, 0, -10040, 0, 27819, 0, -10039, 0, -31991, 0, -10038, 0, -30358, 0, -10037, 0, -26758, 0, -10036, 0, 20129, 0, -10035, 0, 22916, 0, -10034, 0, 24536, 0, -10033, 0, 24537, 0, -10032, 0, 26395, 0, -10031, 0, 32178, 0, -10030, 0, 32596, 0, -10029, 0, -32110, 0, -10028, 0, -31957, 0, -10027, 0, -31811, 0, -10026, 0, -28898, 0, -10025, 0, -28519, 0, -10024, 0, 22475, 0, -10023, 0, 22969, 0, -10022, 0, 23186, 0, -10021, 0, 23504, 0, -10020, 0, 26151, 0, -10019, 0, 26522, 0, -10018, 0, 26757, 0, -10017, 0, 27599, 0, -10016, 0, 29028, 0, -10015, 0, 32629, 0, -10014, 0, -29513, 0, -10013, 0, -29469, 0, -10012, 0, -28543, 0, -10011, 0, -25787, 0, -10010, 0, -32504, 0, -10009, 0, -29558, 0, -10008, 0, -27060, 0, -10007, 0, -26048, 0, -10006, 0, -24923, 0, -10005, 0, 23391, 0, -10004, 0, 27667, 0, -10003, 0, 29467, 0, -10002, 0, 30450, 0, -10001, 0, 30431, 0, -10000, 0, -31732, 0, -9999, 0, 20906, 0, -9998, 0, -30317, 0, -9997, 0, 20813, 0, -9996, 0, 20885, 0, -9995, 0, 21193, 0, -9994, 0, 26825, 0, -9993, 0, 27796, 0, -9992, 0, 30468, 0, -9991, 0, 30496, 0, -9990, 0, 32191, 0, -9989, 0, 32236, 0, -9988, 0, -26782, 0, -9987, 0, -24907, 0, -9986, 0, 28357, 0, -9823, 0, -31471, 0, -9822, 0, 20901, 0, -9821, 0, 21517, 0, -9820, 0, 21629, 0, -9819, 0, 26126, 0, -9818, 0, 26269, 0, -9817, 0, 26919, 0, -9816, 0, 28319, 0, -9815, 0, 30399, 0, -9814, 0, 30609, 0, -9813, 0, -31977, 0, -9812, 0, -31550, 0, -9811, 0, -30817, 0, -9810, 0, -28311, 0, -9809, 0, -28008, 0, -9808, 0, -25356, 0, -9807, 0, -30590, 0, -9806, 0, 20398, 0, -9805, 0, 20882, 0, -9804, 0, 21215, 0, -9803, 0, 22982, 0, -9802, 0, 24125, 0, -9801, 0, 24917, 0, -9800, 0, 25720, 0, -9799, 0, 25721, 0, -9798, 0, 26286, 0, -9797, 0, 26576, 0, -9796, 0, 27169, 0, -9795, 0, 27597, 0, -9794, 0, 27611, 0, -9793, 0, 29279, 0, -9792, 0, 29281, 0, -9791, 0, 29761, 0, -9790, 0, 30520, 0, -9789, 0, 30683, 0, -9788, 0, -32745, 0, -9787, 0, -32068, 0, -9786, 0, -31995, 0, -9785, 0, -29952, 0, -9784, 0, -29912, 0, -9783, 0, -29556, 0, -9782, 0, 26408, 0, -9781, 0, 27792, 0, -9780, 0, 29287, 0, -9779, 0, 30446, 0, -9778, 0, 30566, 0, -9777, 0, 31302, 0, -9776, 0, -25175, 0, -9775, 0, 27519, 0, -9774, 0, 27794, 0, -9773, 0, 22818, 0, -9772, 0, 26406, 0, -9771, 0, -31591, 0, -9770, 0, 21359, 0, -9769, 0, 22675, 0, -9768, 0, 22937, 0, -9767, 0, 24287, 0, -9766, 0, 25551, 0, -9765, 0, 26164, 0, -9764, 0, 26483, 0, -9763, 0, 28218, 0, -9762, 0, 29483, 0, -9761, 0, 31447, 0, -9760, 0, -32041, 0, -9759, 0, -27864, 0, -9758, 0, 21209, 0, -9757, 0, 24043, 0, -9756, 0, 25006, 0, -9755, 0, 25035, 0, -9754, 0, 25098, 0, -9753, 0, 25287, 0, -9752, 0, 25771, 0, -9751, 0, 26080, 0, -9750, 0, 26969, 0, -9749, 0, 27494, 0, -9748, 0, 27595, 0, -9747, 0, 28961, 0, -9746, 0, 29687, 0, -9745, 0, 30045, 0, -9744, 0, 32326, 0, -9743, 0, -32226, 0, -9742, 0, -31998, 0, -9741, 0, -31382, 0, -9740, 0, -30045, 0, -9739, 0, -29505, 0, -9738, 0, -26841, 0, -9737, 0, -25247, 0, -9736, 0, 22696, 0, -9735, 0, -24872, 0, -9734, 0, 20497, 0, -9733, 0, 21006, 0, -9732, 0, 21563, 0, -9731, 0, 21839, 0, -9730, 0, 25991, 0, -9567, 0, 27766, 0, -9566, 0, 32010, 0, -9565, 0, 32011, 0, -9564, 0, -32674, 0, -9563, 0, -31094, 0, -9562, 0, -27264, 0, -9561, 0, -26897, 0, -9560, 0, 21247, 0, -9559, 0, 27797, 0, -9558, 0, 29289, 0, -9557, 0, 21619, 0, -9556, 0, 23194, 0, -9555, 0, 23614, 0, -9554, 0, 23883, 0, -9553, 0, 24396, 0, -9552, 0, 24494, 0, -9551, 0, 26410, 0, -9550, 0, 26806, 0, -9549, 0, 26979, 0, -9548, 0, 28220, 0, -9547, 0, 28228, 0, -9546, 0, 30473, 0, -9545, 0, 31859, 0, -9544, 0, 32654, 0, -9543, 0, -31353, 0, -9542, 0, -29938, 0, -9541, 0, -28681, 0, -9540, 0, -26783, 0, -9539, 0, -24844, 0, -9538, 0, 23735, 0, -9537, 0, 24758, 0, -9536, 0, 24845, 0, -9535, 0, 25003, 0, -9534, 0, 25935, 0, -9533, 0, 26107, 0, -9532, 0, 26108, 0, -9531, 0, 27665, 0, -9530, 0, 27887, 0, -9529, 0, 29599, 0, -9528, 0, 29641, 0, -9527, 0, 32225, 0, -9526, 0, -27244, 0, -9525, 0, 23494, 0, -9524, 0, -30948, 0, -9523, 0, -29936, 0, -9522, 0, 21085, 0, -9521, 0, 21338, 0, -9520, 0, 25293, 0, -9519, 0, 25615, 0, -9518, 0, 25778, 0, -9517, 0, 26420, 0, -9516, 0, 27192, 0, -9515, 0, 27850, 0, -9514, 0, 29632, 0, -9513, 0, 29854, 0, -9512, 0, 31636, 0, -9511, 0, 31893, 0, -9510, 0, 32283, 0, -9509, 0, -32374, 0, -9508, 0, -32202, 0, -9507, 0, -31356, 0, -9506, 0, -28693, 0, -9505, 0, -26887, 0, -9504, 0, -26175, 0, -9503, 0, 20276, 0, -9502, 0, 21322, 0, -9501, 0, 21453, 0, -9500, 0, 21467, 0, -9499, 0, 25292, 0, -9498, 0, 25644, 0, -9497, 0, 25856, 0, -9496, 0, 26001, 0, -9495, 0, 27075, 0, -9494, 0, 27886, 0, -9493, 0, 28504, 0, -9492, 0, 29677, 0, -9491, 0, 30036, 0, -9490, 0, 30242, 0, -9489, 0, 30436, 0, -9488, 0, 30460, 0, -9487, 0, 30928, 0, -9486, 0, -1692, 0, -9485, 0, 31020, 0, -9484, 0, 32070, 0, -9483, 0, -32212, 0, -9482, 0, -30752, 0, -9481, 0, -28716, 0, -9480, 0, -26606, 0, -9479, 0, -26385, 0, -9478, 0, 21187, 0, -9477, 0, 25300, 0, -9476, 0, 25765, 0, -9475, 0, 28196, 0, -9474, 0, 28497, 0, -9311, 0, 30332, 0, -9310, 0, -29237, 0, -9309, 0, -28239, 0, -9308, 0, -28062, 0, -9307, 0, -25874, 0, -9306, 0, -25789, 0, -9305, 0, 20515, 0, -9304, 0, 20621, 0, -9303, 0, 22346, 0, -9302, 0, 22952, 0, -9301, 0, 23592, 0, -9300, 0, 24135, 0, -9299, 0, 24439, 0, -9298, 0, 25151, 0, -9297, 0, 25918, 0, -9296, 0, 26041, 0, -9295, 0, 26049, 0, -9294, 0, 26121, 0, -9293, 0, 26507, 0, -9292, 0, 27036, 0, -9291, 0, 28354, 0, -9290, 0, 30917, 0, -9289, 0, 32033, 0, -9288, 0, -32598, 0, -9287, 0, -32384, 0, -9286, 0, -32213, 0, -9285, 0, -32077, 0, -9284, 0, -31583, 0, -9283, 0, -31092, 0, -9282, 0, -30166, 0, -9281, 0, -29929, 0, -9280, 0, -28506, 0, -9279, 0, -27086, 0, -9278, 0, -24688, 0, -9277, 0, 20493, 0, -9276, 0, 20467, 0, -9275, 0, 21271, 0, -9274, 0, 22521, 0, -9273, 0, 24472, 0, -9272, 0, 25308, 0, -9271, 0, 25490, 0, -9270, 0, 26479, 0, -9269, 0, 28227, 0, -9268, 0, 28953, 0, -9267, 0, 30403, 0, -9266, 0, -32564, 0, -9265, 0, -32550, 0, -9264, 0, -30476, 0, -9263, 0, -30475, 0, -9262, 0, -30439, 0, -9261, 0, -29472, 0, -9260, 0, -28887, 0, -9259, 0, -28339, 0, -9258, 0, -27030, 0, -9257, 0, 20271, 0, -9256, 0, 20336, 0, -9255, 0, 24091, 0, -9254, 0, 26575, 0, -9253, 0, 26658, 0, -9252, 0, 30333, 0, -9251, 0, 30334, 0, -9250, 0, -25788, 0, -9249, 0, 24161, 0, -9248, 0, 27146, 0, -9247, 0, 29033, 0, -9246, 0, 29140, 0, -9245, 0, 30058, 0, -9244, 0, -1692, 0, -9243, 0, 32321, 0, -9242, 0, -31421, 0, -9241, 0, -31255, 0, -9240, 0, -26404, 0, -9239, 0, 20240, 0, -9238, 0, 31567, 0, -9237, 0, 32624, 0, -9236, 0, -27227, 0, -9235, 0, 20961, 0, -9234, 0, 24070, 0, -9233, 0, 26805, 0, -9232, 0, 27710, 0, -9231, 0, 27726, 0, -9230, 0, 27867, 0, -9229, 0, 29359, 0, -9228, 0, 31684, 0, -9227, 0, -31997, 0, -9226, 0, 27861, 0, -9225, 0, 29754, 0, -9224, 0, 20731, 0, -9223, 0, 21128, 0, -9222, 0, 22721, 0, -9221, 0, 25816, 0, -9220, 0, 27287, 0, -9219, 0, 29863, 0, -9218, 0, 30294, 0, -9055, 0, 30887, 0, -9054, 0, -31209, 0, -9053, 0, -27166, 0, -9052, 0, -26823, 0, -9051, 0, -1691, 0, -9050, 0, 21342, 0, -9049, 0, 24321, 0, -9048, 0, -29814, 0, -9047, 0, -28760, 0, -9046, 0, -28753, 0, -9045, 0, -28534, 0, -9044, 0, 21029, 0, -9043, 0, 30629, 0, -9042, 0, -25527, 0, -9041, 0, -24824, 0, -9040, 0, 19993, 0, -9039, 0, 20482, 0, -9038, 0, 20853, 0, -9037, 0, 23643, 0, -9036, 0, 24183, 0, -9035, 0, 26142, 0, -9034, 0, 26170, 0, -9033, 0, 26564, 0, -9032, 0, 26821, 0, -9031, 0, 28851, 0, -9030, 0, 29953, 0, -9029, 0, 30149, 0, -9028, 0, 31177, 0, -9027, 0, 31453, 0, -9026, 0, -28889, 0, -9025, 0, -26336, 0, -9024, 0, -26104, 0, -9023, 0, 20445, 0, -9022, 0, 22561, 0, -9021, 0, 22577, 0, -9020, 0, 23542, 0, -9019, 0, 26222, 0, -9018, 0, 27493, 0, -9017, 0, 27921, 0, -9016, 0, 28282, 0, -9015, 0, 28541, 0, -9014, 0, 29668, 0, -9013, 0, 29995, 0, -9012, 0, -31767, 0, -9011, 0, -30500, 0, -9010, 0, -30445, 0, -9009, 0, -29860, 0, -9008, 0, -28908, 0, -9007, 0, 20239, 0, -9006, 0, 20693, 0, -9005, 0, 21264, 0, -9004, 0, 21340, 0, -9003, 0, 23443, 0, -9002, 0, -1690, 0, -9001, 0, 26381, 0, -9000, 0, 31119, 0, -8999, 0, -32391, 0, -8998, 0, -31953, 0, -8997, 0, -31468, 0, -8996, 0, -30457, 0, -8995, 0, -30330, 0, -8994, 0, -28871, 0, -8993, 0, -28869, 0, -8992, 0, -26203, 0, -8991, 0, -25582, 0, -8990, 0, 26412, 0, -8989, 0, 20086, 0, -8988, 0, 20472, 0, -8987, 0, 22857, 0, -8986, 0, 23553, 0, -8985, 0, 23791, 0, -8984, 0, 23792, 0, -8983, 0, 25447, 0, -8982, 0, 26834, 0, -8981, 0, 28925, 0, -8980, 0, 29090, 0, -8979, 0, 29739, 0, -8978, 0, 32299, 0, -8977, 0, -31508, 0, -8976, 0, -30974, 0, -8975, 0, -28638, 0, -8974, 0, -27950, 0, -8973, 0, -25357, 0, -8972, 0, -1689, 0, -8971, 0, 20184, 0, -8970, 0, 20463, 0, -8969, 0, 20613, 0, -8968, 0, 21078, 0, -8967, 0, 21103, 0, -8966, 0, 21542, 0, -8965, 0, 21648, 0, -8964, 0, 22496, 0, -8963, 0, 22827, 0, -8962, 0, 23142, 0, -8799, 0, 23386, 0, -8798, 0, 23413, 0, -8797, 0, 23500, 0, -8796, 0, 24220, 0, -8795, 0, -1690, 0, -8794, 0, 25206, 0, -8793, 0, 25975, 0, -8792, 0, 26023, 0, -8791, 0, 28014, 0, -8790, 0, 28325, 0, -8789, 0, 29238, 0, -8788, 0, 31526, 0, -8787, 0, 31807, 0, -8786, 0, 32566, 0, -8785, 0, -32432, 0, -8784, 0, -32431, 0, -8783, 0, -32358, 0, -8782, 0, -32192, 0, -8781, 0, -32103, 0, -8780, 0, -31831, 0, -8779, 0, -30205, 0, -8778, 0, -29536, 0, -8777, 0, -29466, 0, -8776, 0, -29445, 0, -8775, 0, -29324, 0, -8774, 0, -29254, 0, -8773, 0, -28440, 0, -8772, 0, -28196, 0, -8771, 0, -27108, 0, -8770, 0, -27068, 0, -8769, 0, -26151, 0, -8768, 0, -25369, 0, -8767, 0, 21271, 0, -8766, 0, 20998, 0, -8765, 0, 21545, 0, -8764, 0, 22132, 0, -8763, 0, 22707, 0, -8762, 0, 22868, 0, -8761, 0, 22894, 0, -8760, 0, 24575, 0, -8759, 0, 24996, 0, -8758, 0, 25198, 0, -8757, 0, 26128, 0, -8756, 0, 27774, 0, -8755, 0, 28954, 0, -8754, 0, 30406, 0, -8753, 0, 31881, 0, -8752, 0, 31966, 0, -8751, 0, 32027, 0, -8750, 0, -32084, 0, -8749, 0, -29503, 0, -8748, 0, -26896, 0, -8747, 0, -1689, 0, -8746, 0, 20315, 0, -8745, 0, 24343, 0, -8744, 0, 24447, 0, -8743, 0, 25282, 0, -8742, 0, 23849, 0, -8741, 0, 26379, 0, -8740, 0, 26842, 0, -8739, 0, 30844, 0, -8738, 0, 32323, 0, -8737, 0, -25236, 0, -8736, 0, 19989, 0, -8735, 0, 20633, 0, -8734, 0, 21269, 0, -8733, 0, 21290, 0, -8732, 0, 21329, 0, -8731, 0, 22915, 0, -8730, 0, 23138, 0, -8729, 0, 24199, 0, -8728, 0, 24754, 0, -8727, 0, 24970, 0, -8726, 0, 25161, 0, -8725, 0, 25209, 0, -8724, 0, 26000, 0, -8723, 0, 26503, 0, -8722, 0, 27047, 0, -8721, 0, 27604, 0, -8720, 0, 27606, 0, -8719, 0, 27607, 0, -8718, 0, 27608, 0, -8717, 0, 27832, 0, -8716, 0, 27852, 0, -8715, 0, 29749, 0, -8714, 0, 30202, 0, -8713, 0, 30738, 0, -8712, 0, 30865, 0, -8711, 0, 31189, 0, -8710, 0, 31192, 0, -8709, 0, 31875, 0, -8708, 0, 32203, 0, -8707, 0, 32737, 0, -8706, 0, -32603, 0, -8543, 0, -32450, 0, -8542, 0, -32318, 0, -8541, 0, -31758, 0, -8540, 0, -30950, 0, -8539, 0, -30488, 0, -8538, 0, -30023, 0, -8537, 0, -29844, 0, -8536, 0, -29509, 0, -8535, 0, -28391, 0, -8534, 0, -26786, 0, -8533, 0, -26405, 0, -8532, 0, -24773, 0, -8531, 0, 22188, 0, -8530, 0, 23338, 0, -8529, 0, 24428, 0, -8528, 0, 25996, 0, -8527, 0, 27315, 0, -8526, 0, 27567, 0, -8525, 0, 27996, 0, -8524, 0, 28657, 0, -8523, 0, 28693, 0, -8522, 0, 29277, 0, -8521, 0, 29613, 0, -8520, 0, -29529, 0, -8519, 0, -29485, 0, -8518, 0, -26565, 0, -8517, 0, 24977, 0, -8516, 0, 27703, 0, -8515, 0, -32680, 0, -8514, 0, -26111, 0, -8513, 0, 20045, 0, -8512, 0, 20107, 0, -8511, 0, 20123, 0, -8510, 0, 20181, 0, -8509, 0, 20282, 0, -8508, 0, 20284, 0, -8507, 0, 20351, 0, -8506, 0, 20447, 0, -8505, 0, 20735, 0, -8504, 0, 21490, 0, -8503, 0, 21496, 0, -8502, 0, 21766, 0, -8501, 0, 21987, 0, -8500, 0, 22235, 0, -8499, 0, 22763, 0, -8498, 0, 22882, 0, -8497, 0, 23057, 0, -8496, 0, 23531, 0, -8495, 0, 23546, 0, -8494, 0, 23556, 0, -8493, 0, 24051, 0, -8492, 0, 24107, 0, -8491, 0, 24473, 0, -8490, 0, 24605, 0, -8489, 0, 25448, 0, -8488, 0, 26012, 0, -8487, 0, 26031, 0, -8486, 0, 26614, 0, -8485, 0, 26619, 0, -8484, 0, 26797, 0, -8483, 0, 27515, 0, -8482, 0, 27801, 0, -8481, 0, 27863, 0, -8480, 0, 28195, 0, -8479, 0, 28681, 0, -8478, 0, 29509, 0, -8477, 0, 30722, 0, -8476, 0, 31038, 0, -8475, 0, 31040, 0, -8474, 0, 31072, 0, -8473, 0, 31169, 0, -8472, 0, 31721, 0, -8471, 0, 32023, 0, -8470, 0, 32114, 0, -8469, 0, -32634, 0, -8468, 0, -32243, 0, -8467, 0, -31858, 0, -8466, 0, -31535, 0, -8465, 0, -31033, 0, -8464, 0, -30497, 0, -8463, 0, -30128, 0, -8462, 0, -30114, 0, -8461, 0, -29923, 0, -8460, 0, -29476, 0, -8459, 0, -29338, 0, -8458, 0, -28755, 0, -8457, 0, -28502, 0, -8456, 0, -26372, 0, -8455, 0, -26145, 0, -8454, 0, -24931, 0, -8453, 0, 21066, 0, -8452, 0, 25976, 0, -8451, 0, 26388, 0, -8450, 0, 32034, 0, -8287, 0, 20632, 0, -8286, 0, 21034, 0, -8285, 0, 23665, 0, -8284, 0, 25955, 0, -8283, 0, 27733, 0, -8282, 0, 29642, 0, -8281, 0, 29987, 0, -8280, 0, 30109, 0, -8279, 0, 31639, 0, -8278, 0, -31588, 0, -8277, 0, -28296, 0, -8276, 0, -26832, 0, -8275, 0, 20087, 0, -8274, 0, 25746, 0, -8273, 0, 27578, 0, -8272, 0, 29022, 0, -8271, 0, -31319, 0, -8270, 0, 19977, 0, -8269, 0, -1685, 0, -8268, 0, 26441, 0, -8267, 0, 26862, 0, -8266, 0, 28183, 0, -8265, 0, -32097, 0, -8264, 0, -31464, 0, -8263, 0, -30613, 0, -8262, 0, 25591, 0, -8261, 0, 28545, 0, -8260, 0, -28142, 0, -8259, 0, -26449, 0, -8258, 0, 19978, 0, -8257, 0, 20663, 0, -8256, 0, 20687, 0, -8255, 0, 20767, 0, -8254, 0, 21830, 0, -8253, 0, 21930, 0, -8252, 0, 22039, 0, -8251, 0, 23360, 0, -8250, 0, 23577, 0, -8249, 0, 23776, 0, -8248, 0, 24120, 0, -8247, 0, 24202, 0, -8246, 0, 24224, 0, -8245, 0, 24258, 0, -8244, 0, 24819, 0, -8243, 0, 26705, 0, -8242, 0, 27233, 0, -8241, 0, 28248, 0, -8240, 0, 29245, 0, -8239, 0, 29248, 0, -8238, 0, 29376, 0, -8237, 0, 30456, 0, -8236, 0, 31077, 0, -8235, 0, 31665, 0, -8234, 0, 32724, 0, -8233, 0, -30477, 0, -8232, 0, -30220, 0, -8231, 0, -30093, 0, -8230, 0, -29599, 0, -8229, 0, -29474, 0, -8228, 0, -26852, 0, -8227, 0, 22622, 0, -8226, 0, 29885, 0, -8225, 0, -29443, 0, -8224, 0, 21959, 0, -8223, 0, 22622, 0, -8222, 0, 31329, 0, -8221, 0, 32034, 0, -8220, 0, -32142, 0, -8219, 0, 29298, 0, -8218, 0, 29983, 0, -8217, 0, 29989, 0, -8216, 0, -1683, 0, -8215, 0, 31513, 0, -8214, 0, 22661, 0, -8213, 0, 22779, 0, -8212, 0, 23996, 0, -8211, 0, 24207, 0, -8210, 0, 24246, 0, -8209, 0, 24464, 0, -8208, 0, 24661, 0, -8207, 0, 25234, 0, -8206, 0, 25471, 0, -8205, 0, 25933, 0, -8204, 0, 26257, 0, -8203, 0, 26329, 0, -8202, 0, 26360, 0, -8201, 0, 26646, 0, -8200, 0, 26866, 0, -8199, 0, 29312, 0, -8198, 0, 29790, 0, -8197, 0, 31598, 0, -8196, 0, 32110, 0, -8195, 0, 32214, 0, -8194, 0, 32626, 0, -8031, 0, -32539, 0, -8030, 0, -32238, 0, -8029, 0, -31313, 0, -8028, 0, -30337, 0, -8027, 0, -30061, 0, -8026, 0, -28643, 0, -8025, 0, -27932, 0, -8024, 0, -24883, 0, -8023, 0, -24800, 0, -8022, 0, 22805, 0, -8021, 0, 22893, 0, -8020, 0, 24109, 0, -8019, 0, 24796, 0, -8018, 0, 26132, 0, -8017, 0, 26227, 0, -8016, 0, 26512, 0, -8015, 0, 27728, 0, -8014, 0, 28101, 0, -8013, 0, 28511, 0, -8012, 0, 30707, 0, -8011, 0, 30889, 0, -8010, 0, -31546, 0, -8009, 0, -28213, 0, -8008, 0, -27861, 0, -8007, 0, 20185, 0, -8006, 0, 20682, 0, -8005, 0, 20808, 0, -8004, 0, 21892, 0, -8003, 0, 23307, 0, -8002, 0, 23459, 0, -8001, 0, 25159, 0, -8000, 0, 25982, 0, -7999, 0, 26059, 0, -7998, 0, 28210, 0, -7997, 0, 29053, 0, -7996, 0, 29697, 0, -7995, 0, 29764, 0, -7994, 0, 29831, 0, -7993, 0, 29887, 0, -7992, 0, 30316, 0, -7991, 0, 31146, 0, -7990, 0, 32218, 0, -7989, 0, 32341, 0, -7988, 0, 32680, 0, -7987, 0, -32390, 0, -7986, 0, -32333, 0, -7985, 0, -32199, 0, -7984, 0, -31206, 0, -7983, 0, -30740, 0, -7982, 0, -30091, 0, -7981, 0, -29213, 0, -7980, 0, -28552, 0, -7979, 0, -28015, 0, -7978, 0, -27611, 0, -7977, 0, -26291, 0, -7976, 0, -25682, 0, -7975, 0, 21352, 0, -7974, 0, 23633, 0, -7973, 0, 26964, 0, -7972, 0, 27844, 0, -7971, 0, 27945, 0, -7970, 0, 28203, 0, -7969, 0, -32244, 0, -7968, 0, -31333, 0, -7967, 0, -30405, 0, -7966, 0, -30163, 0, -7965, 0, -1681, 0, -7964, 0, -26902, 0, -7963, 0, -24729, 0, -7962, 0, 21089, 0, -7961, 0, 26297, 0, -7960, 0, 27570, 0, -7959, 0, 32406, 0, -7958, 0, -30722, 0, -7957, 0, -29427, 0, -7956, 0, -27261, 0, -7955, 0, -27043, 0, -7954, 0, 25885, 0, -7953, 0, 28041, 0, -7952, 0, 29166, 0, -7951, 0, -31671, 0, -7950, 0, 22478, 0, -7949, 0, 22995, 0, -7948, 0, 23468, 0, -7947, 0, 24615, 0, -7946, 0, 24826, 0, -7945, 0, 25104, 0, -7944, 0, 26143, 0, -7943, 0, 26207, 0, -7942, 0, 29481, 0, -7941, 0, 29689, 0, -7940, 0, 30427, 0, -7939, 0, -1683, 0, -7938, 0, 31596, 0, -7775, 0, -32682, 0, -7774, 0, -32654, 0, -7773, 0, -32411, 0, -7772, 0, -30048, 0, -7771, 0, -28270, 0, -7770, 0, 19990, 0, -7769, 0, 21218, 0, -7768, 0, 27506, 0, -7767, 0, 27927, 0, -7766, 0, 31237, 0, -7765, 0, 31545, 0, -7764, 0, 32048, 0, -7763, 0, -1681, 0, -7762, 0, -29520, 0, -7761, 0, 21484, 0, -7760, 0, 22063, 0, -7759, 0, 22609, 0, -7758, 0, 23477, 0, -7757, 0, 23567, 0, -7756, 0, 23569, 0, -7755, 0, 24034, 0, -7754, 0, 25152, 0, -7753, 0, 25475, 0, -7752, 0, 25620, 0, -7751, 0, 26157, 0, -7750, 0, 26803, 0, -7749, 0, 27836, 0, -7748, 0, 28040, 0, -7747, 0, 28335, 0, -7746, 0, 28703, 0, -7745, 0, 28836, 0, -7744, 0, 29138, 0, -7743, 0, 29990, 0, -7742, 0, 30095, 0, -7741, 0, 30094, 0, -7740, 0, 30233, 0, -7739, 0, 31505, 0, -7738, 0, 31712, 0, -7737, 0, 31787, 0, -7736, 0, 32032, 0, -7735, 0, 32057, 0, -7734, 0, -31444, 0, -7733, 0, -31379, 0, -7732, 0, -31225, 0, -7731, 0, -30156, 0, -7730, 0, -28659, 0, -7729, 0, -28575, 0, -7728, 0, -28491, 0, -7727, 0, -27977, 0, -7726, 0, -26634, 0, -7725, 0, -26057, 0, -7724, 0, 20439, 0, -7723, 0, 23660, 0, -7722, 0, 26463, 0, -7721, 0, 28049, 0, -7720, 0, 31903, 0, -7719, 0, 32396, 0, -7718, 0, -29930, 0, -7717, 0, -29418, 0, -7716, 0, -28641, 0, -7715, 0, 23403, 0, -7714, 0, 24061, 0, -7713, 0, 25613, 0, -7712, 0, -31552, 0, -7711, 0, -28580, 0, -7710, 0, -26399, 0, -7709, 0, -1695, 0, -7708, 0, 23435, 0, -7707, 0, 24730, 0, -7706, 0, 26494, 0, -7705, 0, 28126, 0, -7704, 0, -30177, 0, -7703, 0, -30042, 0, -7702, 0, -28671, 0, -7701, 0, -26612, 0, -7700, 0, 21047, 0, -7699, 0, 27578, 0, -7698, 0, 28753, 0, -7697, 0, 30862, 0, -7696, 0, -27754, 0, -7695, 0, -30608, 0, -7694, 0, -28201, 0, -7693, 0, 20462, 0, -7692, 0, 21463, 0, -7691, 0, 22013, 0, -7690, 0, 22234, 0, -7689, 0, 22402, 0, -7688, 0, 22781, 0, -7687, 0, 23234, 0, -7686, 0, 23432, 0, -7685, 0, 23723, 0, -7684, 0, 23744, 0, -7683, 0, 24101, 0, -7682, 0, 24833, 0, -7519, 0, 25101, 0, -7518, 0, 25163, 0, -7517, 0, 25480, 0, -7516, 0, 25628, 0, -7515, 0, 25910, 0, -7514, 0, 25976, 0, -7513, 0, 27193, 0, -7512, 0, 27530, 0, -7511, 0, 27700, 0, -7510, 0, 27929, 0, -7509, 0, 28465, 0, -7508, 0, 29159, 0, -7507, 0, 29417, 0, -7506, 0, 29560, 0, -7505, 0, 29703, 0, -7504, 0, 29874, 0, -7503, 0, 30246, 0, -7502, 0, 30561, 0, -7501, 0, 31168, 0, -7500, 0, 31319, 0, -7499, 0, 31466, 0, -7498, 0, 31929, 0, -7497, 0, 32143, 0, -7496, 0, 32172, 0, -7495, 0, 32353, 0, -7494, 0, 32670, 0, -7493, 0, -32471, 0, -7492, 0, -31951, 0, -7491, 0, -31600, 0, -7490, 0, -31526, 0, -7489, 0, -31254, 0, -7488, 0, -30570, 0, -7487, 0, -30032, 0, -7486, 0, -29808, 0, -7485, 0, -28872, 0, -7484, 0, -28606, 0, -7483, 0, -28541, 0, -7482, 0, -28308, 0, -7481, 0, -28010, 0, -7480, 0, -27975, 0, -7479, 0, -26997, 0, -7478, 0, -26969, 0, -7477, 0, -26968, 0, -7476, 0, -26922, 0, -7475, 0, -26880, 0, -7474, 0, -26616, 0, -7473, 0, -26218, 0, -7472, 0, -25901, 0, -7471, 0, -25830, 0, -7470, 0, 21460, 0, -7469, 0, 22654, 0, -7468, 0, 22809, 0, -7467, 0, 23408, 0, -7466, 0, 23487, 0, -7465, 0, 28113, 0, -7464, 0, 28506, 0, -7463, 0, 29087, 0, -7462, 0, 29729, 0, -7461, 0, 29881, 0, -7460, 0, -32635, 0, -7459, 0, -31747, 0, -7458, 0, 24033, 0, -7457, 0, 24455, 0, -7456, 0, 24490, 0, -7455, 0, 24642, 0, -7454, 0, 26092, 0, -7453, 0, 26642, 0, -7452, 0, 26991, 0, -7451, 0, 27219, 0, -7450, 0, 27529, 0, -7449, 0, 27957, 0, -7448, 0, 28147, 0, -7447, 0, 29667, 0, -7446, 0, 30462, 0, -7445, 0, 30636, 0, -7444, 0, 31565, 0, -7443, 0, 32020, 0, -7442, 0, -32477, 0, -7441, 0, -32228, 0, -7440, 0, -31936, 0, -7439, 0, -31500, 0, -7438, 0, -31389, 0, -7437, 0, -30110, 0, -7436, 0, -30012, 0, -7435, 0, -28281, 0, -7434, 0, -27874, 0, -7433, 0, -26618, 0, -7432, 0, -26188, 0, -7431, 0, 25100, 0, -7430, 0, -30637, 0, -7429, 0, -28688, 0, -7428, 0, -28059, 0, -7427, 0, 23815, 0, -7426, 0, 23847, 0, -7263, 0, 23913, 0, -7262, 0, 29791, 0, -7261, 0, -32355, 0, -7260, 0, -30872, 0, -7259, 0, 28629, 0, -7258, 0, 25342, 0, -7257, 0, 32722, 0, -7256, 0, -30410, 0, -7255, 0, -30350, 0, -7254, 0, 19998, 0, -7253, 0, 20056, 0, -7252, 0, 20711, 0, -7251, 0, 21213, 0, -7250, 0, 21319, 0, -7249, 0, 25215, 0, -7248, 0, 26119, 0, -7247, 0, 32361, 0, -7246, 0, -30715, 0, -7245, 0, -27042, 0, -7244, 0, 20365, 0, -7243, 0, 21273, 0, -7242, 0, 22070, 0, -7241, 0, 22987, 0, -7240, 0, 23204, 0, -7239, 0, 23608, 0, -7238, 0, 23630, 0, -7237, 0, 23629, 0, -7236, 0, 24066, 0, -7235, 0, 24337, 0, -7234, 0, 24643, 0, -7233, 0, 26045, 0, -7232, 0, 26159, 0, -7231, 0, 26178, 0, -7230, 0, 26558, 0, -7229, 0, 26612, 0, -7228, 0, 29468, 0, -7227, 0, 30690, 0, -7226, 0, 31034, 0, -7225, 0, 32709, 0, -7224, 0, -31596, 0, -7223, 0, -31539, 0, -7222, 0, -30314, 0, -7221, 0, -30106, 0, -7220, 0, -30103, 0, -7219, 0, -29983, 0, -7218, 0, -29611, 0, -7217, 0, -29574, 0, -7216, 0, 22516, 0, -7215, 0, 23508, 0, -7214, 0, 24335, 0, -7213, 0, 24687, 0, -7212, 0, 25325, 0, -7211, 0, 26893, 0, -7210, 0, 27542, 0, -7209, 0, 28252, 0, -7208, 0, 29060, 0, -7207, 0, 31698, 0, -7206, 0, -30891, 0, -7205, 0, -1540, 0, -7204, 0, -28930, 0, -7203, 0, -26401, 0, -7202, 0, -26370, 0, -7201, 0, 20280, 0, -7200, 0, 20353, 0, -7199, 0, 20449, 0, -7198, 0, 21627, 0, -7197, 0, 23072, 0, -7196, 0, 23480, 0, -7195, 0, 24892, 0, -7194, 0, 26032, 0, -7193, 0, 26216, 0, -7192, 0, 29180, 0, -7191, 0, 30003, 0, -7190, 0, 31070, 0, -7189, 0, 32051, 0, -7188, 0, -32434, 0, -7187, 0, -32285, 0, -7186, 0, -31848, 0, -7185, 0, -31318, 0, -7184, 0, -31282, 0, -7183, 0, -30973, 0, -7182, 0, -30198, 0, -7181, 0, -29013, 0, -7180, 0, -28773, 0, -7179, 0, -28752, 0, -7178, 0, -28731, 0, -7177, 0, 22833, 0, -7176, 0, 23460, 0, -7175, 0, 23526, 0, -7174, 0, 24713, 0, -7173, 0, 23529, 0, -7172, 0, 23563, 0, -7171, 0, 24515, 0, -7170, 0, 27777, 0, -7007, 0, -1678, 0, -7006, 0, 28145, 0, -7005, 0, 28683, 0, -7004, 0, 29978, 0, -7003, 0, -32081, 0, -7002, 0, -29962, 0, -7001, 0, 20160, 0, -7000, 0, 21313, 0, -6999, 0, 25342, 0, -6998, 0, -26919, 0, -6997, 0, 27663, 0, -6996, 0, 20126, 0, -6995, 0, 20420, 0, -6994, 0, 20818, 0, -6993, 0, 21854, 0, -6992, 0, 23077, 0, -6991, 0, 23784, 0, -6990, 0, 25105, 0, -6989, 0, 29273, 0, -6988, 0, -32067, 0, -6987, 0, -31830, 0, -6986, 0, -30978, 0, -6985, 0, -30631, 0, -6984, 0, -30179, 0, -6983, 0, -27073, 0, -6982, 0, -26939, 0, -6981, 0, -26349, 0, -6980, 0, -25335, 0, -6979, 0, -25251, 0, -6978, 0, 22538, 0, -6977, 0, 23731, 0, -6976, 0, 23997, 0, -6975, 0, 24132, 0, -6974, 0, 24801, 0, -6973, 0, 24853, 0, -6972, 0, 25569, 0, -6971, 0, -1700, 0, -6970, 0, 28197, 0, -6969, 0, -28414, 0, -6968, 0, -27820, 0, -6967, 0, -26546, 0, -6966, 0, -25584, 0, -6965, 0, -24713, 0, -6964, 0, 23433, 0, -6963, 0, 23736, 0, -6962, 0, 25353, 0, -6961, 0, 26191, 0, -6960, 0, 26696, 0, -6959, 0, 30524, 0, -6958, 0, -26943, 0, -6957, 0, -26739, 0, -6956, 0, -26540, 0, -6955, 0, -25697, 0, -6954, 0, 26017, 0, -6953, 0, -29951, 0, -6952, 0, -28981, 0, -6951, 0, -27204, 0, -6950, 0, 21813, 0, -6949, 0, 23721, 0, -6948, 0, 24022, 0, -6947, 0, 24245, 0, -6946, 0, 26263, 0, -6945, 0, 30284, 0, -6944, 0, -31756, 0, -6943, 0, -27193, 0, -6942, 0, 22739, 0, -6941, 0, 25276, 0, -6940, 0, 29390, 0, -6939, 0, -25304, 0, -6938, 0, 20208, 0, -6937, 0, 22830, 0, -6936, 0, 24591, 0, -6935, 0, 26171, 0, -6934, 0, 27523, 0, -6933, 0, 31207, 0, -6932, 0, -25306, 0, -6931, 0, 21395, 0, -6930, 0, 21696, 0, -6929, 0, 22467, 0, -6928, 0, 23830, 0, -6927, 0, 24859, 0, -6926, 0, 26326, 0, -6925, 0, 28079, 0, -6924, 0, 30861, 0, -6923, 0, -32130, 0, -6922, 0, -26984, 0, -6921, 0, -26812, 0, -6920, 0, 21380, 0, -6919, 0, 25212, 0, -6918, 0, 25494, 0, -6917, 0, 28082, 0, -6916, 0, 32266, 0, -6915, 0, -32437, 0, -6914, 0, -26547, 0, -6751, 0, 27387, 0, -6750, 0, 32588, 0, -6749, 0, -25169, 0, -6748, 0, -25062, 0, -6747, 0, 20063, 0, -6746, 0, 20539, 0, -6745, 0, 20918, 0, -6744, 0, 22812, 0, -6743, 0, 24825, 0, -6742, 0, 25590, 0, -6741, 0, 26928, 0, -6740, 0, 29242, 0, -6739, 0, -32714, 0, -6738, 0, -1676, 0, -6737, 0, -28210, 0, -6736, 0, 24369, 0, -6735, 0, -1675, 0, -6734, 0, -1674, 0, -6733, 0, 32004, 0, -6732, 0, -1676, 0, -6731, 0, -31633, 0, -6730, 0, -31557, 0, -6729, 0, -31259, 0, -6728, 0, -29043, 0, -6727, 0, -1673, 0, -6726, 0, 20335, 0, -6725, 0, -1672, 0, -6724, 0, -1671, 0, -6723, 0, 22756, 0, -6722, 0, 23363, 0, -6721, 0, 24665, 0, -6720, 0, 25562, 0, -6719, 0, 25880, 0, -6718, 0, 25965, 0, -6717, 0, 26264, 0, -6716, 0, -1670, 0, -6715, 0, 26954, 0, -6714, 0, 27171, 0, -6713, 0, 27915, 0, -6712, 0, 28673, 0, -6711, 0, 29036, 0, -6710, 0, 30162, 0, -6709, 0, 30221, 0, -6708, 0, 31155, 0, -6707, 0, 31344, 0, -6706, 0, -1669, 0, -6705, 0, 32650, 0, -6704, 0, -1668, 0, -6703, 0, -30396, 0, -6702, 0, -1667, 0, -6701, 0, -29805, 0, -6700, 0, -28224, 0, -6699, 0, -27011, 0, -6698, 0, -1666, 0, -6697, 0, -26358, 0, -6696, 0, 22276, 0, -6695, 0, 24481, 0, -6694, 0, 26044, 0, -6693, 0, 28417, 0, -6692, 0, 30208, 0, -6691, 0, 31142, 0, -6690, 0, -30050, 0, -6689, 0, -26195, 0, -6688, 0, -25766, 0, -6687, 0, -24724, 0, -6686, 0, 20740, 0, -6685, 0, 25014, 0, -6684, 0, 25233, 0, -6683, 0, 27277, 0, -6682, 0, -32314, 0, -6681, 0, 20547, 0, -6680, 0, 22576, 0, -6679, 0, 24422, 0, -6678, 0, 28937, 0, -6677, 0, -30208, 0, -6676, 0, -29958, 0, -6675, 0, 23420, 0, -6674, 0, -31210, 0, -6673, 0, 20474, 0, -6672, 0, 20796, 0, -6671, 0, 22196, 0, -6670, 0, 22852, 0, -6669, 0, 25513, 0, -6668, 0, 28153, 0, -6667, 0, 23978, 0, -6666, 0, 26989, 0, -6665, 0, 20870, 0, -6664, 0, 20104, 0, -6663, 0, 20313, 0, -6662, 0, 21237, 0, -6661, 0, 21570, 0, -6660, 0, 22899, 0, -6659, 0, 22914, 0, -6658, 0, 24300, 0, -6495, 0, -1661, 0, -6494, 0, 27487, 0, -6493, 0, 27741, 0, -6492, 0, -1660, 0, -6491, 0, 29877, 0, -6490, 0, 30998, 0, -6489, 0, -1659, 0, -6488, 0, -32249, 0, -6487, 0, -32187, 0, -6486, 0, -31943, 0, -6485, 0, -28865, 0, -6484, 0, -28835, 0, -6483, 0, -1658, 0, -6482, 0, -26344, 0, -6481, 0, -1657, 0, -6480, 0, -1656, 0, -6479, 0, -1655, 0, -6478, 0, 20134, 0, -6477, 0, -1654, 0, -6476, 0, 22495, 0, -6475, 0, 24441, 0, -6474, 0, -1568, 0, -6473, 0, -1653, 0, -6472, 0, -1652, 0, -6471, 0, 30123, 0, -6470, 0, 32377, 0, -6469, 0, -29841, 0, -6468, 0, -1651, 0, -6467, 0, -28666, 0, -6466, 0, -26021, 0, -6465, 0, 22181, 0, -6464, 0, 22567, 0, -6463, 0, 23032, 0, -6462, 0, 23071, 0, -6461, 0, 23476, 0, -6460, 0, 24180, 0, -6459, 0, 24310, 0, -6458, 0, -1649, 0, -6457, 0, -1648, 0, -6456, 0, 25424, 0, -6455, 0, 25403, 0, -6454, 0, 25754, 0, -6453, 0, 26941, 0, -6452, 0, 27783, 0, -6451, 0, 27839, 0, -6450, 0, 28046, 0, -6449, 0, 28051, 0, -6448, 0, 28149, 0, -6447, 0, 28436, 0, -6446, 0, -1646, 0, -6445, 0, 28895, 0, -6444, 0, 28982, 0, -6443, 0, 29017, 0, -6442, 0, 29001, 0, -6441, 0, 29123, 0, -6440, 0, 29141, 0, -6439, 0, 29833, 0, -6438, 0, 30799, 0, -6437, 0, 30831, 0, -6436, 0, 31178, 0, -6435, 0, 31605, 0, -6434, 0, 32227, 0, -6433, 0, 32244, 0, -6432, 0, 32303, 0, -6431, 0, -32657, 0, -6430, 0, -30643, 0, -6429, 0, -28961, 0, -6428, 0, -28890, 0, -6427, 0, -31506, 0, -6426, 0, -28637, 0, -6425, 0, -28069, 0, -6424, 0, -27830, 0, -6423, 0, -25354, 0, -6422, 0, 21015, 0, -6421, 0, 21155, 0, -6420, 0, 21693, 0, -6419, 0, 24709, 0, -6418, 0, 28037, 0, -6417, 0, 28872, 0, -6416, 0, 29105, 0, -6415, 0, -30526, 0, -6414, 0, -1681, 0, -6413, 0, -27215, 0, -6412, 0, 21421, 0, -6411, 0, 24265, 0, -6410, 0, 24565, 0, -6409, 0, 25467, 0, -6408, 0, 26579, 0, -6407, 0, 27566, 0, -6406, 0, 28814, 0, -6405, 0, 28976, 0, -6404, 0, 29744, 0, -6403, 0, -32138, 0, -6402, 0, -32046, 0, -6239, 0, -1626, 0, -6238, 0, -27205, 0, -6237, 0, -25883, 0, -6236, 0, -24963, 0, -6235, 0, 26308, 0, -6234, 0, -1625, 0, -6233, 0, 29121, 0, -6232, 0, -31671, 0, -6231, 0, -1624, 0, -6230, 0, -1623, 0, -6229, 0, 22603, 0, -6228, 0, -1622, 0, -6227, 0, -1621, 0, -6226, 0, 23992, 0, -6225, 0, 24433, 0, -6224, 0, -1620, 0, -6223, 0, 26144, 0, -6222, 0, 26254, 0, -6221, 0, 27001, 0, -6220, 0, 27054, 0, -6219, 0, 27704, 0, -6218, 0, 27891, 0, -6217, 0, 28214, 0, -6216, 0, 28481, 0, -6215, 0, 28634, 0, -6214, 0, 28699, 0, -6213, 0, 28719, 0, -6212, 0, 29008, 0, -6211, 0, 29151, 0, -6210, 0, 29552, 0, -6209, 0, 29618, 0, -6208, 0, 29787, 0, -6207, 0, 29801, 0, -6206, 0, 29908, 0, -6205, 0, 30408, 0, -6204, 0, 31310, 0, -6203, 0, 32403, 0, -6202, 0, 32666, 0, -6201, 0, -32698, 0, -6200, 0, -32015, 0, -6199, 0, -30112, 0, -6198, 0, -28722, 0, -6197, 0, -28108, 0, -6196, 0, -27832, 0, -6195, 0, -26890, 0, -6194, 0, -26855, 0, -6193, 0, -26808, 0, -6192, 0, -26600, 0, -6191, 0, 20034, 0, -6190, 0, 20522, 0, -6189, 0, 20363, 0, -6188, 0, 21000, 0, -6187, 0, 21473, 0, -6186, 0, 26355, 0, -6185, 0, 27757, 0, -6184, 0, 28618, 0, -6183, 0, 29450, 0, -6182, 0, 30591, 0, -6181, 0, 31330, 0, -6180, 0, -32082, 0, -6179, 0, -31267, 0, -6178, 0, -31230, 0, -6177, 0, 31150, 0, -6176, 0, -30508, 0, -6175, 0, -30109, 0, -6174, 0, -29827, 0, -6173, 0, -29589, 0, -6172, 0, -28236, 0, -6171, 0, -27981, 0, -6170, 0, -26953, 0, -6169, 0, -26861, 0, -6168, 0, -26608, 0, -6167, 0, 20116, 0, -6166, 0, 20237, 0, -6165, 0, 20425, 0, -6164, 0, 20658, 0, -6163, 0, 21320, 0, -6162, 0, 21566, 0, -6161, 0, 21555, 0, -6160, 0, 21978, 0, -6159, 0, 22626, 0, -6158, 0, 22714, 0, -6157, 0, 22887, 0, -6156, 0, 23067, 0, -6155, 0, 23524, 0, -6154, 0, 24735, 0, -6153, 0, 24801, 0, -6152, 0, 25034, 0, -6151, 0, 25942, 0, -6150, 0, 26111, 0, -6149, 0, 26212, 0, -6148, 0, 26791, 0, -6147, 0, 27738, 0, -6146, 0, 28595, 0, -5983, 0, 28879, 0, -5982, 0, 29100, 0, -5981, 0, 29522, 0, -5980, 0, 31613, 0, -5979, 0, -30968, 0, -5978, 0, -30044, 0, -5977, 0, -25550, 0, -5976, 0, -24825, 0, -5975, 0, 23627, 0, -5974, 0, 27779, 0, -5973, 0, 29508, 0, -5972, 0, 29577, 0, -5971, 0, -28102, 0, -5970, 0, 28331, 0, -5969, 0, 29797, 0, -5968, 0, 30239, 0, -5967, 0, 31337, 0, -5966, 0, 32277, 0, -5965, 0, -31222, 0, -5964, 0, 20800, 0, -5963, 0, 22725, 0, -5962, 0, 25793, 0, -5961, 0, 29934, 0, -5960, 0, 29973, 0, -5959, 0, 30320, 0, -5958, 0, 32705, 0, -5957, 0, -28523, 0, -5956, 0, -26931, 0, -5955, 0, -26284, 0, -5954, 0, 28198, 0, -5953, 0, 29926, 0, -5952, 0, 31401, 0, -5951, 0, 31402, 0, -5950, 0, -32283, 0, -5949, 0, -31015, 0, -5948, 0, -30856, 0, -5947, 0, -30181, 0, -5946, 0, 23113, 0, -5945, 0, 23436, 0, -5944, 0, 23451, 0, -5943, 0, 26785, 0, -5942, 0, 26880, 0, -5941, 0, 28003, 0, -5940, 0, 29609, 0, -5939, 0, 29715, 0, -5938, 0, 29740, 0, -5937, 0, 30871, 0, -5936, 0, 32233, 0, -5935, 0, 32747, 0, -5934, 0, -32488, 0, -5933, 0, -32427, 0, -5932, 0, -31842, 0, -5931, 0, -29620, 0, -5930, 0, -1594, 0, -5929, 0, -26607, 0, -5928, 0, 26352, 0, -5927, 0, 24448, 0, -5926, 0, 26106, 0, -5925, 0, 26505, 0, -5924, 0, 27754, 0, -5923, 0, 29579, 0, -5922, 0, 20525, 0, -5921, 0, 23043, 0, -5920, 0, 27498, 0, -5919, 0, 30702, 0, -5918, 0, 22806, 0, -5917, 0, 23916, 0, -5916, 0, 24013, 0, -5915, 0, 29477, 0, -5914, 0, 30031, 0, -5913, 0, -1606, 0, -5912, 0, -1605, 0, -5911, 0, 20709, 0, -5910, 0, 20985, 0, -5909, 0, 22575, 0, -5908, 0, 22829, 0, -5907, 0, 22934, 0, -5906, 0, 23002, 0, -5905, 0, 23525, 0, -5904, 0, -1604, 0, -5903, 0, 23615, 0, -5902, 0, 23970, 0, -5901, 0, 25303, 0, -5900, 0, 25622, 0, -5899, 0, 25747, 0, -5898, 0, 25854, 0, -5897, 0, -1602, 0, -5896, 0, 26332, 0, -5895, 0, -1700, 0, -5894, 0, 27208, 0, -5893, 0, 29134, 0, -5892, 0, 29183, 0, -5891, 0, 29796, 0, -5890, 0, 30274, 0, -5727, 0, 31368, 0, -5726, 0, 31407, 0, -5725, 0, 32327, 0, -5724, 0, 32350, 0, -5723, 0, -32768, 0, -5722, 0, -32400, 0, -5721, 0, -1598, 0, -5720, 0, -30737, 0, -5719, 0, -30335, 0, -5718, 0, -29920, 0, -5717, 0, -28583, 0, -5716, 0, -28548, 0, -5715, 0, -28544, 0, -5714, 0, -26286, 0, -5713, 0, 24958, 0, -5712, 0, 27442, 0, -5711, 0, 28020, 0, -5710, 0, 32287, 0, -5709, 0, -30427, 0, -5708, 0, -28751, 0, -5707, 0, 20433, 0, -5706, 0, 20653, 0, -5705, 0, 20887, 0, -5704, 0, 21191, 0, -5703, 0, 22471, 0, -5702, 0, 22665, 0, -5701, 0, 23481, 0, -5700, 0, 24248, 0, -5699, 0, 24898, 0, -5698, 0, 27029, 0, -5697, 0, 28044, 0, -5696, 0, 28263, 0, -5695, 0, 28342, 0, -5694, 0, 29076, 0, -5693, 0, 29794, 0, -5692, 0, 29992, 0, -5691, 0, 29996, 0, -5690, 0, -32653, 0, -5689, 0, -31944, 0, -5688, 0, -31543, 0, -5687, 0, -29174, 0, -5686, 0, -27756, 0, -5685, 0, -27682, 0, -5684, 0, -24691, 0, -5683, 0, 20110, 0, -5682, 0, 20305, 0, -5681, 0, 20598, 0, -5680, 0, 20778, 0, -5679, 0, 21448, 0, -5678, 0, 21451, 0, -5677, 0, 21491, 0, -5676, 0, 23431, 0, -5675, 0, 23507, 0, -5674, 0, 23588, 0, -5673, 0, 24858, 0, -5672, 0, 24962, 0, -5671, 0, 26100, 0, -5670, 0, 29275, 0, -5669, 0, 29591, 0, -5668, 0, 29760, 0, -5667, 0, 30402, 0, -5666, 0, 31056, 0, -5665, 0, 31121, 0, -5664, 0, 31161, 0, -5663, 0, 32006, 0, -5662, 0, 32701, 0, -5661, 0, -32117, 0, -5660, 0, -31275, 0, -5659, 0, -31138, 0, -5658, 0, -28734, 0, -5657, 0, -28601, 0, -5656, 0, -28427, 0, -5655, 0, -28182, 0, -5654, 0, -27003, 0, -5653, 0, -26904, 0, -5652, 0, -26903, 0, -5651, 0, 21206, 0, -5650, 0, 24423, 0, -5649, 0, 26093, 0, -5648, 0, 26161, 0, -5647, 0, 26671, 0, -5646, 0, 29020, 0, -5645, 0, 31286, 0, -5644, 0, -28479, 0, -5643, 0, -26614, 0, -5642, 0, 20113, 0, -5641, 0, 26248, 0, -5640, 0, 27218, 0, -5639, 0, 27550, 0, -5638, 0, 28560, 0, -5637, 0, 29065, 0, -5636, 0, -32744, 0, -5635, 0, -32072, 0, -5634, 0, -31405, 0, -5471, 0, -28597, 0, -5470, 0, -26987, 0, -5469, 0, -26894, 0, -5468, 0, -26629, 0, -5467, 0, -31462, 0, -5466, 0, -25807, 0, -5465, 0, 20112, 0, -5464, 0, 29066, 0, -5463, 0, -26940, 0, -5462, 0, 20803, 0, -5461, 0, 21407, 0, -5460, 0, 21729, 0, -5459, 0, 22291, 0, -5458, 0, 22290, 0, -5457, 0, 22435, 0, -5456, 0, 23195, 0, -5455, 0, 23236, 0, -5454, 0, 23491, 0, -5453, 0, 24616, 0, -5452, 0, 24895, 0, -5451, 0, 25588, 0, -5450, 0, 27781, 0, -5449, 0, 27961, 0, -5448, 0, 28274, 0, -5447, 0, 28304, 0, -5446, 0, 29232, 0, -5445, 0, 29503, 0, -5444, 0, 29783, 0, -5443, 0, -32047, 0, -5442, 0, -30591, 0, -5441, 0, -28859, 0, -5440, 0, -28576, 0, -5439, 0, -1594, 0, -5438, 0, -27038, 0, -5437, 0, -26536, 0, -5436, 0, -25317, 0, -5435, 0, 26376, 0, -5434, 0, -29302, 0, -5433, 0, -28066, 0, -5432, 0, 20301, 0, -5431, 0, 20553, 0, -5430, 0, 20702, 0, -5429, 0, 21361, 0, -5428, 0, 22285, 0, -5427, 0, 22996, 0, -5426, 0, 23041, 0, -5425, 0, 23561, 0, -5424, 0, 24944, 0, -5423, 0, 26256, 0, -5422, 0, 28205, 0, -5421, 0, 29234, 0, -5420, 0, 29771, 0, -5419, 0, 32239, 0, -5418, 0, -32573, 0, -5417, 0, -31730, 0, -5416, 0, -31642, 0, -5415, 0, -31425, 0, -5414, 0, -30881, 0, -5413, 0, -30629, 0, -5412, 0, -30440, 0, -5411, 0, -29950, 0, -5410, 0, -28587, 0, -5409, 0, -26677, 0, -5408, 0, -25777, 0, -5407, 0, 20083, 0, -5406, 0, 20369, 0, -5405, 0, 20754, 0, -5404, 0, 20842, 0, -5403, 0, 21129, 0, -5402, 0, 21807, 0, -5401, 0, 21929, 0, -5400, 0, 23418, 0, -5399, 0, 23461, 0, -5398, 0, 24188, 0, -5397, 0, 24189, 0, -5396, 0, 24254, 0, -5395, 0, 24736, 0, -5394, 0, 24799, 0, -5393, 0, 24840, 0, -5392, 0, 24841, 0, -5391, 0, 25540, 0, -5390, 0, 25912, 0, -5389, 0, 26377, 0, -5388, 0, 26491, 0, -5387, 0, 26580, 0, -5386, 0, 26586, 0, -5385, 0, 26611, 0, -5384, 0, 26977, 0, -5383, 0, 26978, 0, -5382, 0, 27833, 0, -5381, 0, 27943, 0, -5380, 0, 27969, 0, -5379, 0, 28216, 0, -5378, 0, 28316, 0, -5215, 0, 28641, 0, -5214, 0, 29494, 0, -5213, 0, 29495, 0, -5212, 0, -1588, 0, -5211, 0, 29788, 0, -5210, 0, 30001, 0, -5209, 0, -1587, 0, -5208, 0, 30290, 0, -5207, 0, -1586, 0, -5206, 0, -1585, 0, -5205, 0, 32173, 0, -5204, 0, -32258, 0, -5203, 0, -31688, 0, -5202, 0, -30507, 0, -5201, 0, -30056, 0, -5200, 0, -29989, 0, -5199, 0, -29971, 0, -5198, 0, -29136, 0, -5197, 0, -29118, 0, -5196, 0, -28598, 0, -5195, 0, -28610, 0, -5194, 0, -28550, 0, -5193, 0, -28343, 0, -5192, 0, -28215, 0, -5191, 0, -27794, 0, -5190, 0, -1584, 0, -5189, 0, -1583, 0, -5188, 0, 22537, 0, -5187, 0, -1582, 0, -5186, 0, 27603, 0, -5185, 0, -32631, 0, -5184, 0, -32590, 0, -5183, 0, -27016, 0, -5182, 0, -1580, 0, -5181, 0, 20801, 0, -5180, 0, 22891, 0, -5179, 0, 23609, 0, -5178, 0, 23833, 0, -5177, 0, 28138, 0, -5176, 0, 28516, 0, -5175, 0, 29607, 0, -5174, 0, -32540, 0, -5173, 0, -29433, 0, -5172, 0, -28886, 0, -5171, 0, -28137, 0, -5170, 0, -27249, 0, -5169, 0, 24459, 0, -5168, 0, 24900, 0, -5167, 0, 26647, 0, -5166, 0, -1695, 0, -5165, 0, -32641, 0, -5164, 0, 25102, 0, -5163, 0, 28700, 0, -5162, 0, 32104, 0, -5161, 0, -30835, 0, -5160, 0, -27002, 0, -5159, 0, 22432, 0, -5158, 0, 24681, 0, -5157, 0, 24903, 0, -5156, 0, 27575, 0, -5155, 0, -30018, 0, -5154, 0, -28032, 0, -5153, 0, -26959, 0, -5152, 0, 20057, 0, -5151, 0, 21535, 0, -5150, 0, 28139, 0, -5149, 0, -31443, 0, -5148, 0, -27024, 0, -5147, 0, -26637, 0, -5146, 0, -26386, 0, -5145, 0, 25558, 0, -5144, 0, 27875, 0, -5143, 0, -28527, 0, -5142, 0, 20957, 0, -5141, 0, 25033, 0, -5140, 0, -32326, 0, -5139, 0, -25095, 0, -5138, 0, 20381, 0, -5137, 0, 20506, 0, -5136, 0, 20736, 0, -5135, 0, 23452, 0, -5134, 0, 24847, 0, -5133, 0, 25087, 0, -5132, 0, 25836, 0, -5131, 0, 26885, 0, -5130, 0, 27589, 0, -5129, 0, 30097, 0, -5128, 0, 30691, 0, -5127, 0, 32681, 0, -5126, 0, -32156, 0, -5125, 0, -31345, 0, -5124, 0, -30725, 0, -5123, 0, -30621, 0, -5122, 0, -30020, 0, -4959, 0, -29840, 0, -4958, 0, -28245, 0, -4957, 0, 20108, 0, -4956, 0, 20197, 0, -4955, 0, 20234, 0, -4954, 0, -1571, 0, -4953, 0, -1570, 0, -4952, 0, 22839, 0, -4951, 0, 23016, 0, -4950, 0, -1569, 0, -4949, 0, 24050, 0, -4948, 0, 24347, 0, -4947, 0, 24411, 0, -4946, 0, 24609, 0, -4945, 0, -1568, 0, -4944, 0, -1567, 0, -4943, 0, -1566, 0, -4942, 0, -1565, 0, -4941, 0, 29246, 0, -4940, 0, 29669, 0, -4939, 0, -1564, 0, -4938, 0, 30064, 0, -4937, 0, 30157, 0, -4936, 0, -1563, 0, -4935, 0, 31227, 0, -4934, 0, -1562, 0, -4933, 0, -32756, 0, -4932, 0, -32717, 0, -4931, 0, -32636, 0, -4930, 0, -32031, 0, -4929, 0, -31919, 0, -4928, 0, -1561, 0, -4927, 0, -1560, 0, -4926, 0, -29507, 0, -4925, 0, -29517, 0, -4924, 0, -28537, 0, -4923, 0, -1559, 0, -4922, 0, -1558, 0, -4921, 0, -26380, 0, -4920, 0, -26356, 0, -4919, 0, -1557, 0, -4918, 0, -1556, 0, -4917, 0, 28727, 0, -4916, 0, 30410, 0, -4915, 0, 32714, 0, -4914, 0, 32716, 0, -4913, 0, 32764, 0, -4912, 0, -29926, 0, -4911, 0, 20154, 0, -4910, 0, 20161, 0, -4909, 0, 20995, 0, -4908, 0, 21360, 0, -4907, 0, -1555, 0, -4906, 0, 21693, 0, -4905, 0, 22240, 0, -4904, 0, 23035, 0, -4903, 0, 23493, 0, -4902, 0, 24341, 0, -4901, 0, 24525, 0, -4900, 0, 28270, 0, -4899, 0, -1554, 0, -4898, 0, -1553, 0, -4897, 0, 32106, 0, -4896, 0, -31947, 0, -4895, 0, -1552, 0, -4894, 0, -31085, 0, -4893, 0, -30067, 0, -4892, 0, -1551, 0, -4891, 0, -26771, 0, -4890, 0, -26761, 0, -4889, 0, -1550, 0, -4888, 0, -1549, 0, -4887, 0, 19968, 0, -4886, 0, 20314, 0, -4885, 0, 20350, 0, -4884, 0, 22777, 0, -4883, 0, 26085, 0, -4882, 0, 28322, 0, -4881, 0, -28616, 0, -4880, 0, -27728, 0, -4879, 0, -26183, 0, -4878, 0, 20219, 0, -4877, 0, 22764, 0, -4876, 0, 22922, 0, -4875, 0, 23001, 0, -4874, 0, 24641, 0, -4873, 0, -1548, 0, -4872, 0, -1547, 0, -4871, 0, 31252, 0, -4870, 0, -1546, 0, -4869, 0, -31921, 0, -4868, 0, -29501, 0, -4867, 0, 20837, 0, -4866, 0, 21316, 0, -4703, 0, 31435, 0, -4702, 0, 31520, 0, -4701, 0, 31890, 0, -4700, 0, 20173, 0, -4699, 0, 21097, 0, -4698, 0, 23381, 0, -4697, 0, -32065, 0, -4696, 0, 20180, 0, -4695, 0, -1537, 0, -4694, 0, 21672, 0, -4693, 0, 22985, 0, -4692, 0, 23039, 0, -4691, 0, 23376, 0, -4690, 0, 23383, 0, -4689, 0, 23388, 0, -4688, 0, 24675, 0, -4687, 0, 24904, 0, -4686, 0, 28363, 0, -4685, 0, 28825, 0, -4684, 0, 29038, 0, -4683, 0, 29574, 0, -4682, 0, 29943, 0, -4681, 0, 30133, 0, -4680, 0, 30913, 0, -4679, 0, 32043, 0, -4678, 0, -32763, 0, -4677, 0, -32278, 0, -4676, 0, -31960, 0, -4675, 0, -31465, 0, -4674, 0, -31287, 0, -4673, 0, -29970, 0, -4672, 0, -29497, 0, -4671, 0, -26932, 0, -4670, 0, 20316, 0, -4669, 0, 21242, 0, -4668, 0, 22204, 0, -4667, 0, 26027, 0, -4666, 0, 26152, 0, -4665, 0, 28796, 0, -4664, 0, 28856, 0, -4663, 0, 29237, 0, -4662, 0, 32189, 0, -4661, 0, -32115, 0, -4660, 0, -28340, 0, -4659, 0, -26944, 0, -4658, 0, -25230, 0, -4657, 0, 23409, 0, -4656, 0, 26855, 0, -4655, 0, 27544, 0, -4654, 0, 28538, 0, -4653, 0, 30430, 0, -4652, 0, 23697, 0, -4651, 0, 26283, 0, -4650, 0, 28507, 0, -4649, 0, 31668, 0, -4648, 0, 31786, 0, -4647, 0, -30666, 0, -4646, 0, -26916, 0, -4645, 0, 19976, 0, -4644, 0, 20183, 0, -4643, 0, 21280, 0, -4642, 0, 22580, 0, -4641, 0, 22715, 0, -4640, 0, 22767, 0, -4639, 0, 22892, 0, -4638, 0, 23559, 0, -4637, 0, 24115, 0, -4636, 0, 24196, 0, -4635, 0, 24373, 0, -4634, 0, 25484, 0, -4633, 0, 26290, 0, -4632, 0, 26454, 0, -4631, 0, 27167, 0, -4630, 0, 27299, 0, -4629, 0, 27404, 0, -4628, 0, 28479, 0, -4627, 0, 29254, 0, -4626, 0, 29376, 0, -4625, 0, 29520, 0, -4624, 0, 29835, 0, -4623, 0, 31456, 0, -4622, 0, 31911, 0, -4621, 0, -32392, 0, -4620, 0, -32289, 0, -4619, 0, -32281, 0, -4618, 0, -31862, 0, -4617, 0, -31636, 0, -4616, 0, -31453, 0, -4615, 0, -31340, 0, -4614, 0, -31281, 0, -4613, 0, -30499, 0, -4612, 0, -29421, 0, -4611, 0, -28244, 0, -4610, 0, -27273, 0, -4447, 0, -26980, 0, -4446, 0, 20877, 0, -4445, 0, 21705, 0, -4444, 0, 22312, 0, -4443, 0, 23472, 0, -4442, 0, 25165, 0, -4441, 0, 26448, 0, -4440, 0, 26685, 0, -4439, 0, 26771, 0, -4438, 0, 28221, 0, -4437, 0, 28371, 0, -4436, 0, 28797, 0, -4435, 0, 32289, 0, -4434, 0, -30527, 0, -4433, 0, -29535, 0, -4432, 0, -28919, 0, -4431, 0, -24757, 0, -4430, 0, -24754, 0, -4429, 0, 29229, 0, -4428, 0, 31631, 0, -4427, 0, -30003, 0, -4426, 0, -27878, 0, -4425, 0, 20295, 0, -4424, 0, 20302, 0, -4423, 0, 20786, 0, -4422, 0, 21632, 0, -4421, 0, 22992, 0, -4420, 0, 24213, 0, -4419, 0, 25269, 0, -4418, 0, 26485, 0, -4417, 0, 26990, 0, -4416, 0, 27159, 0, -4415, 0, 27822, 0, -4414, 0, 28186, 0, -4413, 0, 29401, 0, -4412, 0, 29482, 0, -4411, 0, 30141, 0, -4410, 0, 31672, 0, -4409, 0, 32053, 0, -4408, 0, -32025, 0, -4407, 0, -31751, 0, -4406, 0, -31657, 0, -4405, 0, -31241, 0, -4404, 0, -30117, 0, -4403, 0, -29521, 0, -4402, 0, -29049, 0, -4401, 0, -28647, 0, -4400, 0, -28488, 0, -4399, 0, -26930, 0, -4398, 0, -24737, 0, -4397, 0, 21219, 0, -4396, 0, 21514, 0, -4395, 0, 23265, 0, -4394, 0, 23490, 0, -4393, 0, 25688, 0, -4392, 0, 25973, 0, -4391, 0, 28404, 0, -4390, 0, 29380, 0, -4389, 0, 28825, 0, -4388, 0, 30340, 0, -4387, 0, 31309, 0, -4386, 0, 31515, 0, -4385, 0, 31821, 0, -4384, 0, 32318, 0, -4383, 0, 32735, 0, -4382, 0, -31877, 0, -4381, 0, -29909, 0, -4380, 0, -29494, 0, -4379, 0, -29340, 0, -4378, 0, -29215, 0, -4377, 0, -29089, 0, -4376, 0, -28694, 0, -4375, 0, -28679, 0, -4374, 0, -28567, 0, -4373, 0, -27695, 0, -4372, 0, 20291, 0, -4371, 0, 20346, 0, -4370, 0, 20659, 0, -4369, 0, 20840, 0, -4368, 0, 20856, 0, -4367, 0, 21069, 0, -4366, 0, 21098, 0, -4365, 0, 22625, 0, -4364, 0, 22652, 0, -4363, 0, 22880, 0, -4362, 0, 23560, 0, -4361, 0, 23637, 0, -4360, 0, 24283, 0, -4359, 0, 24731, 0, -4358, 0, 25136, 0, -4357, 0, 26643, 0, -4356, 0, 27583, 0, -4355, 0, 27656, 0, -4354, 0, 28593, 0, -4191, 0, 29006, 0, -4190, 0, 29728, 0, -4189, 0, 30000, 0, -4188, 0, 30008, 0, -4187, 0, 30033, 0, -4186, 0, 30322, 0, -4185, 0, 31564, 0, -4184, 0, 31627, 0, -4183, 0, 31661, 0, -4182, 0, 31686, 0, -4181, 0, 32399, 0, -4180, 0, -30098, 0, -4179, 0, -28866, 0, -4178, 0, -28855, 0, -4177, 0, -28097, 0, -4176, 0, -28013, 0, -4175, 0, -27870, 0, -4174, 0, -27605, 0, -4173, 0, -26885, 0, -4172, 0, -26534, 0, -4171, 0, -26517, 0, -4170, 0, -26338, 0, -4169, 0, 20999, 0, -4168, 0, 25130, 0, -4167, 0, 25240, 0, -4166, 0, 27993, 0, -4165, 0, 30308, 0, -4164, 0, 31434, 0, -4163, 0, 31680, 0, -4162, 0, 32118, 0, -4161, 0, 21344, 0, -4160, 0, 23742, 0, -4159, 0, 24215, 0, -4158, 0, 28472, 0, -4157, 0, 28857, 0, -4156, 0, 31896, 0, -4155, 0, -26863, 0, -4154, 0, -25714, 0, -4153, 0, -24866, 0, -4152, 0, 25509, 0, -4151, 0, 25722, 0, -4150, 0, -30858, 0, -4149, 0, 19969, 0, -4148, 0, 20117, 0, -4147, 0, 20141, 0, -4146, 0, 20572, 0, -4145, 0, 20597, 0, -4144, 0, 21576, 0, -4143, 0, 22979, 0, -4142, 0, 23450, 0, -4141, 0, 24128, 0, -4140, 0, 24237, 0, -4139, 0, 24311, 0, -4138, 0, 24449, 0, -4137, 0, 24773, 0, -4136, 0, 25402, 0, -4135, 0, 25919, 0, -4134, 0, 25972, 0, -4133, 0, 26060, 0, -4132, 0, 26230, 0, -4131, 0, 26232, 0, -4130, 0, 26622, 0, -4129, 0, 26984, 0, -4128, 0, 27273, 0, -4127, 0, 27491, 0, -4126, 0, 27712, 0, -4125, 0, 28096, 0, -4124, 0, 28136, 0, -4123, 0, 28191, 0, -4122, 0, 28254, 0, -4121, 0, 28702, 0, -4120, 0, 28833, 0, -4119, 0, 29582, 0, -4118, 0, 29693, 0, -4117, 0, 30010, 0, -4116, 0, 30555, 0, -4115, 0, 30855, 0, -4114, 0, 31118, 0, -4113, 0, 31243, 0, -4112, 0, 31357, 0, -4111, 0, 31934, 0, -4110, 0, 32142, 0, -4109, 0, -32185, 0, -4108, 0, -30206, 0, -4107, 0, -29974, 0, -4106, 0, -29538, 0, -4105, 0, -28371, 0, -4104, 0, -28342, 0, -4103, 0, -28200, 0, -4102, 0, -28058, 0, -4101, 0, -27956, 0, -4100, 0, -27872, 0, -4099, 0, -26874, 0, -4098, 0, -26794, 0, -3935, 0, -26788, 0, -3934, 0, -26622, 0, -3933, 0, -24818, 0, -3932, 0, 21046, 0, -3931, 0, 21137, 0, -3930, 0, 21884, 0, -3929, 0, 22564, 0, -3928, 0, 24093, 0, -3927, 0, 24351, 0, -3926, 0, 24716, 0, -3925, 0, 25552, 0, -3924, 0, 26799, 0, -3923, 0, 28639, 0, -3922, 0, 31085, 0, -3921, 0, 31532, 0, -3920, 0, -32307, 0, -3919, 0, -31302, 0, -3918, 0, -30467, 0, -3917, 0, -29960, 0, -3916, 0, -29116, 0, -3915, 0, -28275, 0, -3914, 0, -27036, 0, -3913, 0, -26981, 0, -3912, 0, -26819, 0, -3911, 0, -26548, 0, -3910, 0, -24758, 0, -3909, 0, 20430, 0, -3908, 0, 20806, 0, -3907, 0, 20939, 0, -3906, 0, 21161, 0, -3905, 0, 22066, 0, -3904, 0, 24340, 0, -3903, 0, 24427, 0, -3902, 0, 25514, 0, -3901, 0, 25805, 0, -3900, 0, 26089, 0, -3899, 0, 26177, 0, -3898, 0, 26362, 0, -3897, 0, 26361, 0, -3896, 0, 26397, 0, -3895, 0, 26781, 0, -3894, 0, 26839, 0, -3893, 0, 27133, 0, -3892, 0, 28437, 0, -3891, 0, 28526, 0, -3890, 0, 29031, 0, -3889, 0, 29157, 0, -3888, 0, 29226, 0, -3887, 0, 29866, 0, -3886, 0, 30522, 0, -3885, 0, 31062, 0, -3884, 0, 31066, 0, -3883, 0, 31199, 0, -3882, 0, 31264, 0, -3881, 0, 31381, 0, -3880, 0, 31895, 0, -3879, 0, 31967, 0, -3878, 0, 32068, 0, -3877, 0, 32368, 0, -3876, 0, -32633, 0, -3875, 0, -31237, 0, -3874, 0, -31068, 0, -3873, 0, -30124, 0, -3872, 0, -30017, 0, -3871, 0, -29287, 0, -3870, 0, -29055, 0, -3869, 0, -28640, 0, -3868, 0, -28563, 0, -3867, 0, -28189, 0, -3866, 0, -27077, 0, -3865, 0, -26923, 0, -3864, 0, -25371, 0, -3863, 0, 26063, 0, -3862, 0, 31751, 0, -3861, 0, -29261, 0, -3860, 0, -27709, 0, -3859, 0, 23384, 0, -3858, 0, 23562, 0, -3857, 0, 21330, 0, -3856, 0, 25305, 0, -3855, 0, 29469, 0, -3854, 0, 20519, 0, -3853, 0, 23447, 0, -3852, 0, 24478, 0, -3851, 0, 24752, 0, -3850, 0, 24939, 0, -3849, 0, 26837, 0, -3848, 0, 28121, 0, -3847, 0, 29742, 0, -3846, 0, 31278, 0, -3845, 0, 32066, 0, -3844, 0, 32156, 0, -3843, 0, 32305, 0, -3842, 0, -32405, 0, -3679, 0, -29142, 0, -3678, 0, -29131, 0, -3677, 0, -27778, 0, -3676, 0, -27624, 0, -3675, 0, 20304, 0, -3674, 0, 22352, 0, -3673, 0, 24038, 0, -3672, 0, 24231, 0, -3671, 0, 25387, 0, -3670, 0, 32618, 0, -3669, 0, 20027, 0, -3668, 0, 20303, 0, -3667, 0, 20367, 0, -3666, 0, 20570, 0, -3665, 0, 23005, 0, -3664, 0, -32572, 0, -3663, 0, 21610, 0, -3662, 0, 21608, 0, -3661, 0, 22014, 0, -3660, 0, 22863, 0, -3659, 0, 23449, 0, -3658, 0, 24030, 0, -3657, 0, 24282, 0, -3656, 0, 26205, 0, -3655, 0, 26417, 0, -3654, 0, 26609, 0, -3653, 0, 26666, 0, -3652, 0, 27880, 0, -3651, 0, 27954, 0, -3650, 0, 28234, 0, -3649, 0, 28557, 0, -3648, 0, 28855, 0, -3647, 0, 29664, 0, -3646, 0, 30087, 0, -3645, 0, 31820, 0, -3644, 0, 32002, 0, -3643, 0, 32044, 0, -3642, 0, 32162, 0, -3641, 0, -32225, 0, -3640, 0, -31013, 0, -3639, 0, -30149, 0, -3638, 0, -30075, 0, -3637, 0, -29328, 0, -3636, 0, -29046, 0, -3635, 0, -28877, 0, -3634, 0, -28623, 0, -3633, 0, -28338, 0, -3632, 0, -28334, 0, -3631, 0, -27580, 0, -3630, 0, -26160, 0, -3629, 0, 31481, 0, -3628, 0, 31909, 0, -3627, 0, 20426, 0, -3626, 0, 20737, 0, -3625, 0, 20934, 0, -3624, 0, 22472, 0, -3623, 0, 23535, 0, -3622, 0, 23803, 0, -3621, 0, 26201, 0, -3620, 0, 27197, 0, -3619, 0, 27994, 0, -3618, 0, 28310, 0, -3617, 0, 28652, 0, -3616, 0, 28940, 0, -3615, 0, 30063, 0, -3614, 0, 31459, 0, -3613, 0, -30686, 0, -3612, 0, -28639, 0, -3611, 0, -28555, 0, -3610, 0, -26933, 0, -3609, 0, -26113, 0, -3608, 0, -31999, 0, -3607, 0, 20013, 0, -3606, 0, 20210, 0, -3605, 0, -30650, 0, -3604, 0, -28211, 0, -3603, 0, 21373, 0, -3602, 0, 27355, 0, -3601, 0, 26987, 0, -3600, 0, 27713, 0, -3599, 0, -31622, 0, -3598, 0, 22686, 0, -3597, 0, 24974, 0, -3596, 0, 26366, 0, -3595, 0, 25327, 0, -3594, 0, 28893, 0, -3593, 0, 29969, 0, -3592, 0, 30151, 0, -3591, 0, 32338, 0, -3590, 0, -31560, 0, -3589, 0, -29879, 0, -3588, 0, -29432, 0, -3587, 0, 20043, 0, -3586, 0, 21482, 0, -3423, 0, 21675, 0, -3422, 0, 22320, 0, -3421, 0, 22336, 0, -3420, 0, 24535, 0, -3419, 0, 25345, 0, -3418, 0, 25351, 0, -3417, 0, 25711, 0, -3416, 0, 25903, 0, -3415, 0, 26088, 0, -3414, 0, 26234, 0, -3413, 0, 26525, 0, -3412, 0, 26547, 0, -3411, 0, 27490, 0, -3410, 0, 27744, 0, -3409, 0, 27802, 0, -3408, 0, 28460, 0, -3407, 0, 30693, 0, -3406, 0, 30757, 0, -3405, 0, 31049, 0, -3404, 0, 31063, 0, -3403, 0, 32025, 0, -3402, 0, -32606, 0, -3401, 0, -32510, 0, -3400, 0, -32269, 0, -3399, 0, -32099, 0, -3398, 0, -32073, 0, -3397, 0, -30952, 0, -3396, 0, -30068, 0, -3395, 0, -1540, 0, -3394, 0, -29436, 0, -3393, 0, -29250, 0, -3392, 0, -28558, 0, -3391, 0, 30452, 0, -3390, 0, 31257, 0, -3389, 0, 31287, 0, -3388, 0, 32340, 0, -3387, 0, -32649, 0, -3386, 0, 21767, 0, -3385, 0, 21972, 0, -3384, 0, 22645, 0, -3383, 0, 25391, 0, -3382, 0, 25634, 0, -3381, 0, 26185, 0, -3380, 0, 26187, 0, -3379, 0, 26733, 0, -3378, 0, 27035, 0, -3377, 0, 27524, 0, -3376, 0, 27941, 0, -3375, 0, 28337, 0, -3374, 0, 29645, 0, -3373, 0, 29800, 0, -3372, 0, 29857, 0, -3371, 0, 30043, 0, -3370, 0, 30137, 0, -3369, 0, 30433, 0, -3368, 0, 30494, 0, -3367, 0, 30603, 0, -3366, 0, 31206, 0, -3365, 0, 32265, 0, -3364, 0, 32285, 0, -3363, 0, -32261, 0, -3362, 0, -31441, 0, -3361, 0, -30569, 0, -3360, 0, -30150, 0, -3359, 0, -29487, 0, -3358, 0, -28949, 0, -3357, 0, -28752, 0, -3356, 0, -28622, 0, -3355, 0, -27731, 0, -3354, 0, -27037, 0, -3353, 0, -27021, 0, -3352, 0, -26873, 0, -3351, 0, 20356, 0, -3350, 0, 21489, 0, -3349, 0, 23018, 0, -3348, 0, 23241, 0, -3347, 0, 24089, 0, -3346, 0, 26702, 0, -3345, 0, 29894, 0, -3344, 0, 30142, 0, -3343, 0, 31209, 0, -3342, 0, 31378, 0, -3341, 0, -32349, 0, -3340, 0, -30995, 0, -3339, 0, -29462, 0, -3338, 0, -29236, 0, -3337, 0, -28691, 0, -3336, 0, 26015, 0, -3335, 0, 26389, 0, -3334, 0, 20160, 0, -3333, 0, 22519, 0, -3332, 0, 28503, 0, -3331, 0, 32221, 0, -3330, 0, -28881, 0, -3167, 0, -27658, 0, -3166, 0, -26938, 0, -3165, 0, 24501, 0, -3164, 0, 25074, 0, -3163, 0, 28548, 0, -3162, 0, 19988, 0, -3161, 0, 20376, 0, -3160, 0, 20511, 0, -3159, 0, 21449, 0, -3158, 0, 21983, 0, -3157, 0, 23919, 0, -3156, 0, 24046, 0, -3155, 0, 27425, 0, -3154, 0, 27492, 0, -3153, 0, 30923, 0, -3152, 0, 31642, 0, -3151, 0, -1538, 0, -3150, 0, -29111, 0, -3149, 0, -28982, 0, -3148, 0, -28562, 0, -3147, 0, 25417, 0, -3146, 0, 25662, 0, -3145, 0, 30528, 0, -3144, 0, 31364, 0, -3143, 0, -27857, 0, -3142, 0, -27521, 0, -3141, 0, -24726, 0, -3140, 0, 25776, 0, -3139, 0, 28591, 0, -3138, 0, 29158, 0, -3137, 0, 29864, 0, -3136, 0, 29914, 0, -3135, 0, 31428, 0, -3134, 0, 31762, 0, -3133, 0, 32386, 0, -3132, 0, 31922, 0, -3131, 0, 32408, 0, -3130, 0, -29798, 0, -3129, 0, -29430, 0, -3128, 0, -27523, 0, -3127, 0, -26352, 0, -3126, 0, -26292, 0, -3125, 0, 21049, 0, -3124, 0, 23519, 0, -3123, 0, 25830, 0, -3122, 0, 26413, 0, -3121, 0, 32046, 0, -3120, 0, 20717, 0, -3119, 0, -1685, 0, -3118, 0, 22649, 0, -3117, 0, 24920, 0, -3116, 0, 24921, 0, -3115, 0, 25082, 0, -3114, 0, 26028, 0, -3113, 0, 31449, 0, -3112, 0, -29806, 0, -3111, 0, -29802, 0, -3110, 0, 20489, 0, -3109, 0, 20513, 0, -3108, 0, 21109, 0, -3107, 0, 21809, 0, -3106, 0, 23100, 0, -3105, 0, 24288, 0, -3104, 0, 24432, 0, -3103, 0, 24884, 0, -3102, 0, 25950, 0, -3101, 0, 26124, 0, -3100, 0, 26166, 0, -3099, 0, 26274, 0, -3098, 0, 27085, 0, -3097, 0, 28356, 0, -3096, 0, 28466, 0, -3095, 0, 29462, 0, -3094, 0, 30241, 0, -3093, 0, 31379, 0, -3092, 0, -32455, 0, -3091, 0, -32167, 0, -3090, 0, -31786, 0, -3089, 0, -31556, 0, -3088, 0, 20661, 0, -3087, 0, 22512, 0, -3086, 0, 23488, 0, -3085, 0, 23528, 0, -3084, 0, 24425, 0, -3083, 0, 25505, 0, -3082, 0, 30758, 0, -3081, 0, 32181, 0, -3080, 0, -31780, 0, -3079, 0, -31455, 0, -3078, 0, -28217, 0, -3077, 0, -28171, 0, -3076, 0, 20874, 0, -3075, 0, 26613, 0, -3074, 0, 31574, 0, -2911, 0, -29524, 0, -2910, 0, 20932, 0, -2909, 0, 22971, 0, -2908, 0, 24765, 0, -2907, 0, -31147, 0, -2906, 0, 20508, 0, -2905, 0, -1537, 0, -2904, 0, 21076, 0, -2903, 0, 23610, 0, -2902, 0, 24957, 0, -2901, 0, 25114, 0, -2900, 0, 25299, 0, -2899, 0, 25842, 0, -2898, 0, 26021, 0, -2897, 0, 28364, 0, -2896, 0, 30240, 0, -2895, 0, -32502, 0, -2894, 0, -29088, 0, -2893, 0, -27041, 0, -2892, 0, -26949, 0, -2891, 0, 20191, 0, -2890, 0, 21315, 0, -2889, 0, 21912, 0, -2888, 0, 22825, 0, -2887, 0, 24029, 0, -2886, 0, 25797, 0, -2885, 0, 27849, 0, -2884, 0, 28154, 0, -2883, 0, 29588, 0, -2882, 0, 31359, 0, -2881, 0, -32229, 0, -2880, 0, -31322, 0, -2879, 0, -29468, 0, -2878, 0, -29168, 0, -2877, 0, -28553, 0, -2876, 0, -28185, 0, -2875, 0, -27167, 0, -2874, 0, -27103, 0, -2873, 0, -26682, 0, -2872, 0, 20984, 0, -2871, 0, 21746, 0, -2870, 0, 21894, 0, -2869, 0, 24505, 0, -2868, 0, 25764, 0, -2867, 0, 28552, 0, -2866, 0, 32180, 0, -2865, 0, -28897, 0, -2864, 0, -28851, 0, -2863, 0, -27595, 0, -2862, 0, 20681, 0, -2861, 0, 23574, 0, -2860, 0, 27838, 0, -2859, 0, 28155, 0, -2858, 0, 29979, 0, -2857, 0, 30651, 0, -2856, 0, 31805, 0, -2855, 0, 31844, 0, -2854, 0, -30087, 0, -2853, 0, -30014, 0, -2852, 0, 22558, 0, -2851, 0, 22974, 0, -2850, 0, 24086, 0, -2849, 0, 25463, 0, -2848, 0, 29266, 0, -2847, 0, 30090, 0, -2846, 0, 30571, 0, -2845, 0, -29988, 0, -2844, 0, -29508, 0, -2843, 0, -28910, 0, -2842, 0, 24307, 0, -2841, 0, 26228, 0, -2840, 0, 28152, 0, -2839, 0, -32643, 0, -2838, 0, -31807, 0, -2837, 0, -30005, 0, -2836, 0, -26799, 0, -2835, 0, -25642, 0, -2834, 0, 20999, 0, -2833, 0, 21059, 0, -2832, 0, 26367, 0, -2831, 0, 28053, 0, -2830, 0, 28399, 0, -2829, 0, 32224, 0, -2828, 0, -29978, 0, -2827, 0, -28626, 0, -2826, 0, -28578, 0, -2825, 0, -25900, 0, -2824, 0, 21021, 0, -2823, 0, 21119, 0, -2822, 0, 21736, 0, -2821, 0, 24980, 0, -2820, 0, 25220, 0, -2819, 0, 25307, 0, -2818, 0, 26786, 0, -2655, 0, 26898, 0, -2654, 0, 26970, 0, -2653, 0, 27189, 0, -2652, 0, 28818, 0, -2651, 0, 28966, 0, -2650, 0, 30813, 0, -2649, 0, 30977, 0, -2648, 0, 30990, 0, -2647, 0, 31186, 0, -2646, 0, 31245, 0, -2645, 0, -32618, 0, -2644, 0, -32136, 0, -2643, 0, -32043, 0, -2642, 0, -31927, 0, -2641, 0, -31415, 0, -2640, 0, -29566, 0, -2639, 0, -29307, 0, -2638, 0, -28318, 0, -2637, 0, -28277, 0, -2636, 0, -28242, 0, -2635, 0, 20419, 0, -2634, 0, 22225, 0, -2633, 0, 29165, 0, -2632, 0, 30679, 0, -2631, 0, -30976, 0, -2630, 0, -30216, 0, -2629, 0, 23544, 0, -2628, 0, 24534, 0, -2627, 0, 26449, 0, -2626, 0, -28504, 0, -2625, 0, 21474, 0, -2624, 0, 22618, 0, -2623, 0, 23541, 0, -2622, 0, 24740, 0, -2621, 0, 24961, 0, -2620, 0, 25696, 0, -2619, 0, 32317, 0, -2618, 0, -32656, 0, -2617, 0, -31451, 0, -2616, 0, -28029, 0, -2615, 0, 25774, 0, -2614, 0, 20652, 0, -2613, 0, 23828, 0, -2612, 0, 26368, 0, -2611, 0, 22684, 0, -2610, 0, 25277, 0, -2609, 0, 25512, 0, -2608, 0, 26894, 0, -2607, 0, 27000, 0, -2606, 0, 27166, 0, -2605, 0, 28267, 0, -2604, 0, 30394, 0, -2603, 0, 31179, 0, -2602, 0, -32069, 0, -2601, 0, -31703, 0, -2600, 0, -30001, 0, -2599, 0, -29272, 0, -2598, 0, -28675, 0, -2597, 0, -28398, 0, -2596, 0, -28341, 0, -2595, 0, -28260, 0, -2594, 0, -27888, 0, -2593, 0, -27880, 0, -2592, 0, -27750, 0, -2591, 0, -26917, 0, -2590, 0, -26058, 0, -2589, 0, -25587, 0, -2588, 0, 19985, 0, -2587, 0, 30044, 0, -2586, 0, 31069, 0, -2585, 0, 31482, 0, -2584, 0, 31569, 0, -2583, 0, 31689, 0, -2582, 0, 32302, 0, -2581, 0, -31548, 0, -2580, 0, -29095, 0, -2579, 0, -29068, 0, -2578, 0, -28936, 0, -2577, 0, -28656, 0, -2576, 0, 26149, 0, -2575, 0, 26943, 0, -2574, 0, 29763, 0, -2573, 0, 20986, 0, -2572, 0, 26414, 0, -2571, 0, -24868, 0, -2570, 0, 20805, 0, -2569, 0, 24544, 0, -2568, 0, 27798, 0, -2567, 0, -30734, 0, -2566, 0, -30627, 0, -2565, 0, -30601, 0, -2564, 0, 24756, 0, -2563, 0, -32331, 0, -2562, 0, -31741, 0, -2399, 0, -29435, 0, -2398, 0, 21462, 0, -2397, 0, 21561, 0, -2396, 0, 22068, 0, -2395, 0, 23094, 0, -2394, 0, 23601, 0, -2393, 0, 28810, 0, -2392, 0, 32736, 0, -2391, 0, -32678, 0, -2390, 0, -32506, 0, -2389, 0, -32275, 0, -2388, 0, -29277, 0, -2387, 0, -28279, 0, -2386, 0, -26017, 0, -2385, 0, -25102, 0, -2384, 0, 20596, 0, -2383, 0, 20164, 0, -2382, 0, 21408, 0, -2381, 0, 24827, 0, -2380, 0, 28204, 0, -2379, 0, 23652, 0, -2378, 0, 20360, 0, -2377, 0, 20516, 0, -2376, 0, 21988, 0, -2375, 0, 23769, 0, -2374, 0, 24159, 0, -2373, 0, 24677, 0, -2372, 0, 26772, 0, -2371, 0, 27835, 0, -2370, 0, 28100, 0, -2369, 0, 29118, 0, -2368, 0, 30164, 0, -2367, 0, 30196, 0, -2366, 0, 30305, 0, -2365, 0, 31258, 0, -2364, 0, 31305, 0, -2363, 0, 32199, 0, -2362, 0, 32251, 0, -2361, 0, 32622, 0, -2360, 0, -32268, 0, -2359, 0, -31063, 0, -2358, 0, -28900, 0, -2357, 0, -26935, 0, -2356, 0, -26189, 0, -2355, 0, -24750, 0, -2354, 0, 21063, 0, -2353, 0, 21189, 0, -2352, 0, -26387, 0, -2351, 0, -30294, 0, -2350, 0, 19971, 0, -2349, 0, 26578, 0, -2348, 0, 28422, 0, -2347, 0, 20405, 0, -2346, 0, 23522, 0, -2345, 0, 26517, 0, -2344, 0, -1678, 0, -2343, 0, 28024, 0, -2342, 0, 29723, 0, -2341, 0, 30759, 0, -2340, 0, -28195, 0, -2339, 0, -27780, 0, -2338, 0, -30780, 0, -2337, 0, 31204, 0, -2336, 0, 31281, 0, -2335, 0, 24555, 0, -2334, 0, 20182, 0, -2333, 0, 21668, 0, -2332, 0, 21822, 0, -2331, 0, 22702, 0, -2330, 0, 22949, 0, -2329, 0, 24816, 0, -2328, 0, 25171, 0, -2327, 0, 25302, 0, -2326, 0, 26422, 0, -2325, 0, 26965, 0, -2324, 0, -32203, 0, -2323, 0, -27072, 0, -2322, 0, -26191, 0, -2321, 0, -26147, 0, -2320, 0, 20524, 0, -2319, 0, 21331, 0, -2318, 0, 21828, 0, -2317, 0, 22396, 0, -2316, 0, -1535, 0, -2315, 0, 25176, 0, -2314, 0, 25299, 0, -2313, 0, 25826, 0, -2312, 0, 26219, 0, -2311, 0, 26589, 0, -2310, 0, 28609, 0, -2309, 0, 28655, 0, -2308, 0, 29730, 0, -2307, 0, 29752, 0, -2306, 0, -30185, 0, -2143, 0, -27592, 0, -2142, 0, 21585, 0, -2141, 0, 22022, 0, -2140, 0, 22374, 0, -2139, 0, 24392, 0, -2138, 0, 24986, 0, -2137, 0, 27470, 0, -2136, 0, 28760, 0, -2135, 0, 28845, 0, -2134, 0, 32187, 0, -2133, 0, -30059, 0, -2132, 0, 22890, 0, -2131, 0, -32469, 0, -2130, 0, 25506, 0, -2129, 0, 30472, 0, -2128, 0, -32707, 0, -2127, 0, -29526, 0, -2126, 0, 22612, 0, -2125, 0, 25645, 0, -2124, 0, 27067, 0, -2123, 0, 23445, 0, -2122, 0, 24081, 0, -2121, 0, 28271, 0, -2120, 0, -1533, 0, -2119, 0, -31383, 0, -2118, 0, 20812, 0, -2117, 0, 21488, 0, -2116, 0, 22826, 0, -2115, 0, 24608, 0, -2114, 0, 24907, 0, -2113, 0, 27526, 0, -2112, 0, 27760, 0, -2111, 0, 27888, 0, -2110, 0, 31518, 0, -2109, 0, -32562, 0, -2108, 0, -32044, 0, -2107, 0, -29242, 0, -2106, 0, -28496, 0, -2105, 0, -26447, 0, -2104, 0, -1532, 0, -2103, 0, 25799, 0, -2102, 0, 28580, 0, -2101, 0, 25745, 0, -2100, 0, 25860, 0, -2099, 0, 20814, 0, -2098, 0, 21520, 0, -2097, 0, 22303, 0, -2096, 0, -30194, 0, -2095, 0, 24927, 0, -2094, 0, 26742, 0, -2093, 0, -1531, 0, -2092, 0, 30171, 0, -2091, 0, 31570, 0, -2090, 0, 32113, 0, -2089, 0, -28646, 0, -2088, 0, 22534, 0, -2087, 0, 27084, 0, -2086, 0, -32385, 0, -2085, 0, -30422, 0, -2084, 0, -28672, 0, -2083, 0, -26567, 0, -2082, 0, 20600, 0, -2081, 0, 22871, 0, -2080, 0, 22956, 0, -2079, 0, 25237, 0, -2078, 0, -28657, 0, -2077, 0, -25814, 0, -2076, 0, 24925, 0, -2075, 0, 29305, 0, -2074, 0, -27178, 0, -2073, 0, 22369, 0, -2072, 0, 23110, 0, -2071, 0, 24052, 0, -2070, 0, 25226, 0, -2069, 0, 25773, 0, -2068, 0, 25850, 0, -2067, 0, 26487, 0, -2066, 0, 27874, 0, -2065, 0, 27966, 0, -2064, 0, 29228, 0, -2063, 0, 29750, 0, -2062, 0, 30772, 0, -2061, 0, 32631, 0, -2060, 0, -32083, 0, -2059, 0, -29221, 0, -2058, 0, -26601, 0, -2057, 0, 21028, 0, -2056, 0, 22338, 0, -2055, 0, 26495, 0, -2054, 0, 29256, 0, -2053, 0, 29923, 0, -2052, 0, -29527, 0, -2051, 0, -28762, 0, -2050, 0, -28143, 0, -1887, 0, -27094, 0, -1886, 0, 20843, 0, -1885, 0, 21485, 0, -1884, 0, 25420, 0, -1883, 0, 20329, 0, -1882, 0, 21764, 0, -1881, 0, 24726, 0, -1880, 0, 25943, 0, -1879, 0, 27803, 0, -1878, 0, 28031, 0, -1877, 0, 29260, 0, -1876, 0, 29437, 0, -1875, 0, 31255, 0, -1874, 0, -30329, 0, -1873, 0, -29539, 0, -1872, 0, 24429, 0, -1871, 0, 28558, 0, -1870, 0, 28921, 0, -1869, 0, -32344, 0, -1868, 0, 24846, 0, -1867, 0, -1691, 0, -1866, 0, 20559, 0, -1865, 0, 25153, 0, -1864, 0, 29255, 0, -1863, 0, 31687, 0, -1862, 0, 32232, 0, -1861, 0, 32745, 0, -1860, 0, -28595, 0, -1859, 0, -26707, 0, -1858, 0, -26087, 0, -1857, 0, -29514, 0, -1856, 0, 22378, 0, -1855, 0, 24179, 0, -1854, 0, 26544, 0, -1853, 0, -31731, 0, -1852, 0, -30123, 0, -1851, 0, 21536, 0, -1850, 0, 23318, 0, -1849, 0, 24163, 0, -1848, 0, 24290, 0, -1847, 0, 24330, 0, -1846, 0, 25987, 0, -1845, 0, -32582, 0, -1844, 0, -31427, 0, -1843, 0, -27255, 0, -1842, 0, -27045, 0, -1841, 0, 20296, 0, -1840, 0, 21253, 0, -1839, 0, 21261, 0, -1838, 0, 21263, 0, -1837, 0, 21638, 0, -1836, 0, 21754, 0, -1835, 0, 22275, 0, -1834, 0, 24067, 0, -1833, 0, 24598, 0, -1832, 0, 25243, 0, -1831, 0, 25265, 0, -1830, 0, 25429, 0, -1829, 0, -1530, 0, -1828, 0, 27873, 0, -1827, 0, 28006, 0, -1826, 0, 30129, 0, -1825, 0, 30770, 0, -1824, 0, -32546, 0, -1823, 0, -32465, 0, -1822, 0, -32034, 0, -1821, 0, -31647, 0, -1820, 0, -31566, 0, -1819, 0, -30579, 0, -1818, 0, -30446, 0, -1817, 0, -28661, 0, -1816, 0, -27926, 0, -1815, 0, -26371, 0, -1814, 0, -25711, 0, -1813, 0, 24133, 0, -1812, 0, -1530, 0, -1811, 0, 26333, 0, -1810, 0, 28689, 0, -1809, 0, 29190, 0, -1808, 0, -28869, 0, -1807, 0, 20469, 0, -1806, 0, 21117, 0, -1805, 0, 24426, 0, -1804, 0, 24915, 0, -1803, 0, 26451, 0, -1802, 0, 27161, 0, -1801, 0, 28418, 0, -1800, 0, 29922, 0, -1799, 0, 31080, 0, -1798, 0, -30616, 0, -1797, 0, -29575, 0, -1796, 0, -26425, 0, -1795, 0, -26428, 0, -1794, 0, -26045, 0, -1631, 0, 21697, 0, -1630, 0, 31263, 0, -1629, 0, 26963, 0, -1628, 0, -29961, 0, -1627, 0, -29622, 0, -1626, 0, -26456, 0, -1625, 0, -26194, 0, -1624, 0, 24444, 0, -1623, 0, 25259, 0, -1622, 0, 30130, 0, -1621, 0, 30382, 0, -1620, 0, -30549, 0, -1619, 0, -28545, 0, -1618, 0, -27070, 0, -1617, 0, 21305, 0, -1616, 0, 24380, 0, -1615, 0, 24517, 0, -1614, 0, 27852, 0, -1613, 0, 29644, 0, -1612, 0, 30050, 0, -1611, 0, 30091, 0, -1610, 0, 31558, 0, -1609, 0, -32002, 0, -1608, 0, -26211, 0, -1607, 0, 20047, 0, -1606, 0, -28612, 0, -1605, 0, 19979, 0, -1604, 0, 20309, 0, -1603, 0, 21414, 0, -1602, 0, 22799, 0, -1601, 0, 24264, 0, -1600, 0, 26160, 0, -1599, 0, 27827, 0, -1598, 0, 29781, 0, -1597, 0, -31881, 0, -1596, 0, -30874, 0, -1595, 0, -29504, 0, -1594, 0, -28592, 0, -1593, 0, -26850, 0, -1592, 0, -25579, 0, -1591, 0, 22737, 0, -1590, 0, 23416, 0, -1589, 0, -31152, 0, -1588, 0, -29932, 0, -1587, 0, -25164, 0, -1586, 0, 23506, 0, -1585, 0, 24680, 0, -1584, 0, 24717, 0, -1583, 0, 26097, 0, -1582, 0, 27735, 0, -1581, 0, 28450, 0, -1580, 0, 28579, 0, -1579, 0, 28698, 0, -1578, 0, 32597, 0, -1577, 0, 32752, 0, -1576, 0, -27247, 0, -1575, 0, -27246, 0, -1574, 0, -27056, 0, -1573, 0, -26669, 0, -1572, 0, 21106, 0, -1571, 0, -28860, 0, -1570, 0, 20989, 0, -1569, 0, 21547, 0, -1568, 0, 21688, 0, -1567, 0, 21859, 0, -1566, 0, 21898, 0, -1565, 0, 27323, 0, -1564, 0, 28085, 0, -1563, 0, 32216, 0, -1562, 0, -32154, 0, -1561, 0, -28004, 0, -1560, 0, -27017, 0, -1559, 0, -24967, 0, -1558, 0, 21512, 0, -1557, 0, 21704, 0, -1556, 0, 30418, 0, -1555, 0, -31004, 0, -1554, 0, -27228, 0, -1553, 0, -27180, 0, -1552, 0, -27044, 0, -1551, 0, 20130, 0, -1550, 0, 20233, 0, -1549, 0, 23022, 0, -1548, 0, 23270, 0, -1547, 0, 24055, 0, -1546, 0, 24658, 0, -1545, 0, 25239, 0, -1544, 0, 26477, 0, -1543, 0, 26689, 0, -1542, 0, 27782, 0, -1541, 0, 28207, 0, -1540, 0, 32568, 0, -1539, 0, -32613, 0, -1538, 0, -32214, 0, -1375, 0, -1528, 0, -1374, 0, -1527, 0, -1373, 0, -26619, 0, -1372, 0, 20133, 0, -1371, 0, 20565, 0, -1370, 0, 21683, 0, -1369, 0, 22419, 0, -1368, 0, 22874, 0, -1367, 0, 23401, 0, -1366, 0, 23475, 0, -1365, 0, 25032, 0, -1364, 0, 26999, 0, -1363, 0, 28023, 0, -1362, 0, 28707, 0, -1361, 0, -30727, 0, -1360, 0, -30237, 0, -1359, 0, -30094, 0, -1358, 0, -29977, 0, -1357, 0, -28542, 0, -1356, 0, -26131, 0, -1355, 0, -25928, 0, -1354, 0, 21182, 0, -1353, 0, 26680, 0, -1352, 0, 20502, 0, -1351, 0, 24184, 0, -1350, 0, 26447, 0, -1349, 0, -31929, 0, -1348, 0, -1528, 0, -1347, 0, 20139, 0, -1346, 0, 21521, 0, -1345, 0, 22190, 0, -1344, 0, 29670, 0, -1343, 0, -28395, 0, -1342, 0, -26625, 0, -1341, 0, -26359, 0, -1340, 0, -26281, 0, -1339, 0, -26215, 0, -1338, 0, 22099, 0, -1337, 0, 22687, 0, -1336, 0, -31141, 0, -1335, 0, -30159, 0, -1334, 0, 25010, 0, -1333, 0, 27382, 0, -1332, 0, 29563, 0, -1331, 0, -28974, 0, -1330, 0, 27463, 0, -1329, 0, -26966, 0, -1328, 0, -26025, 0, -1327, 0, 22869, 0, -1326, 0, 29184, 0, -1325, 0, -29333, 0, -1324, 0, -26775, 0, -1323, 0, 20436, 0, -1322, 0, 23796, 0, -1321, 0, 24358, 0, -1320, 0, 25080, 0, -1319, 0, 26203, 0, -1318, 0, 27883, 0, -1317, 0, 28843, 0, -1316, 0, 29572, 0, -1315, 0, 29625, 0, -1314, 0, 29694, 0, -1313, 0, 30505, 0, -1312, 0, 30541, 0, -1311, 0, 32067, 0, -1310, 0, 32098, 0, -1309, 0, 32291, 0, -1308, 0, -32201, 0, -1307, 0, -30638, 0, -1306, 0, -30325, 0, -1305, 0, -29470, 0, -1304, 0, -28087, 0, -1303, 0, -26513, 0, -1302, 0, 23377, 0, -1301, 0, 31348, 0, -1300, 0, -30656, 0, -1299, 0, -26623, 0, -1298, 0, 23244, 0, -1297, 0, 20448, 0, -1296, 0, 21332, 0, -1295, 0, 22846, 0, -1294, 0, 23805, 0, -1293, 0, 25406, 0, -1292, 0, 28025, 0, -1291, 0, 29433, 0, -1290, 0, -32507, 0, -1289, 0, -32505, 0, -1288, 0, -31838, 0, -1287, 0, -27953, 0, -1286, 0, -26576, 0, -1285, 0, 20136, 0, -1284, 0, 20804, 0, -1283, 0, 21009, 0, -1282, 0, 22411, 0, -1119, 0, 24418, 0, -1118, 0, 27842, 0, -1117, 0, 28366, 0, -1116, 0, 28677, 0, -1115, 0, 28752, 0, -1114, 0, 28847, 0, -1113, 0, 29074, 0, -1112, 0, 29673, 0, -1111, 0, 29801, 0, -1110, 0, -31926, 0, -1109, 0, -30814, 0, -1108, 0, -30623, 0, -1107, 0, -28664, 0, -1106, 0, -28510, 0, -1105, 0, -27741, 0, -1104, 0, -26200, 0, -1103, 0, 20846, 0, -1102, 0, 24407, 0, -1101, 0, 24800, 0, -1100, 0, 24935, 0, -1099, 0, 26291, 0, -1098, 0, -31399, 0, -1097, 0, -29110, 0, -1096, 0, -28241, 0, -1095, 0, -26741, 0, -1094, 0, 20046, 0, -1093, 0, 20114, 0, -1092, 0, 21628, 0, -1091, 0, 22741, 0, -1090, 0, 22778, 0, -1089, 0, 22909, 0, -1088, 0, 23733, 0, -1087, 0, 24359, 0, -1086, 0, 25142, 0, -1085, 0, 25160, 0, -1084, 0, 26122, 0, -1083, 0, 26215, 0, -1082, 0, 27627, 0, -1081, 0, 28009, 0, -1080, 0, 28111, 0, -1079, 0, 28246, 0, -1078, 0, 28408, 0, -1077, 0, 28564, 0, -1076, 0, 28640, 0, -1075, 0, 28649, 0, -1074, 0, 28765, 0, -1073, 0, 29392, 0, -1072, 0, 29733, 0, -1071, 0, 29786, 0, -1070, 0, 29920, 0, -1069, 0, 30355, 0, -1068, 0, 31068, 0, -1067, 0, 31946, 0, -1066, 0, 32286, 0, -1065, 0, -32543, 0, -1064, 0, -32090, 0, -1063, 0, -31637, 0, -1062, 0, -31553, 0, -1061, 0, -31154, 0, -1060, 0, -31137, 0, -1059, 0, -30860, 0, -1058, 0, -29833, 0, -1057, 0, -29590, 0, -1056, 0, -27732, 0, -1055, 0, -26624, 0, -1054, 0, -26523, 0, -1053, 0, 24785, 0, -1052, 0, 25110, 0, -1051, 0, -28297, 0, -1050, 0, 23130, 0, -1049, 0, 26127, 0, -1048, 0, 28151, 0, -1047, 0, 28222, 0, -1046, 0, 29759, 0, -1045, 0, -25790, 0, -1044, 0, 24573, 0, -1043, 0, 24794, 0, -1042, 0, 31503, 0, -1041, 0, 21700, 0, -1040, 0, 24344, 0, -1039, 0, 27742, 0, -1038, 0, 27859, 0, -1037, 0, 27946, 0, -1036, 0, 28888, 0, -1035, 0, 32005, 0, -1034, 0, -31111, 0, -1033, 0, -30196, 0, -1032, 0, -25285, 0, -1031, 0, 21270, 0, -1030, 0, 21644, 0, -1029, 0, 23301, 0, -1028, 0, 27194, 0, -1027, 0, 28779, 0, -1026, 0, 30069, 0, -863, 0, 31117, 0, -862, 0, 31166, 0, -861, 0, -32079, 0, -860, 0, -31761, 0, -859, 0, -30095, 0, -858, 0, -29887, 0, -857, 0, -29528, 0, -856, 0, -26764, 0, -855, 0, 24275, 0, -854, 0, 25844, 0, -853, 0, 25899, 0, -852, 0, 30906, 0, -851, 0, 30907, 0, -850, 0, 31339, 0, -849, 0, 20024, 0, -848, 0, 21914, 0, -847, 0, 22864, 0, -846, 0, 23462, 0, -845, 0, 24187, 0, -844, 0, 24739, 0, -843, 0, 25563, 0, -842, 0, 27489, 0, -841, 0, 26213, 0, -840, 0, 26707, 0, -839, 0, 28185, 0, -838, 0, 29029, 0, -837, 0, 29872, 0, -836, 0, 32008, 0, -835, 0, -28540, 0, -834, 0, -26007, 0, -833, 0, -25563, 0, -832, 0, 27963, 0, -831, 0, 28369, 0, -830, 0, 29502, 0, -829, 0, -29631, 0, -828, 0, -27190, 0, -827, 0, 20976, 0, -826, 0, 24140, 0, -825, 0, 24488, 0, -824, 0, 24653, 0, -823, 0, 24822, 0, -822, 0, 24880, 0, -821, 0, 24908, 0, -820, 0, 26179, 0, -819, 0, 26180, 0, -818, 0, 27045, 0, -817, 0, 27841, 0, -816, 0, 28255, 0, -815, 0, 28361, 0, -814, 0, 28514, 0, -813, 0, 29004, 0, -812, 0, 29852, 0, -811, 0, 30343, 0, -810, 0, 31681, 0, -809, 0, 31783, 0, -808, 0, -31918, 0, -807, 0, -30889, 0, -806, 0, -28591, 0, -805, 0, -26995, 0, -804, 0, -24893, 0, -803, 0, 21295, 0, -802, 0, 22238, 0, -801, 0, 24315, 0, -800, 0, 24458, 0, -799, 0, 24674, 0, -798, 0, 24724, 0, -797, 0, 25079, 0, -796, 0, 26214, 0, -795, 0, 26371, 0, -794, 0, 27292, 0, -793, 0, 28142, 0, -792, 0, 28590, 0, -791, 0, 28784, 0, -790, 0, 29546, 0, -789, 0, 32362, 0, -788, 0, -32322, 0, -787, 0, -31948, 0, -786, 0, -31020, 0, -785, 0, -30040, 0, -784, 0, -29500, 0, -783, 0, 21123, 0, -782, 0, 29554, 0, -781, 0, 23446, 0, -780, 0, 27243, 0, -779, 0, -27644, 0, -778, 0, 21742, 0, -777, 0, 22150, 0, -776, 0, 23389, 0, -775, 0, 25928, 0, -774, 0, 25989, 0, -773, 0, 26313, 0, -772, 0, 26783, 0, -771, 0, 28045, 0, -770, 0, 28102, 0, -607, 0, 29243, 0, -606, 0, -32588, 0, -605, 0, -28299, 0, -604, 0, -26035, 0, -603, 0, 20399, 0, -602, 0, 20505, 0, -601, 0, 21402, 0, -600, 0, 21518, 0, -599, 0, 21564, 0, -598, 0, 21897, 0, -597, 0, 21957, 0, -596, 0, 24127, 0, -595, 0, 24460, 0, -594, 0, 26429, 0, -593, 0, 29030, 0, -592, 0, 29661, 0, -591, 0, -28667, 0, -590, 0, 21211, 0, -589, 0, 21235, 0, -588, 0, 22628, 0, -587, 0, 22734, 0, -586, 0, 28932, 0, -585, 0, 29071, 0, -584, 0, 29179, 0, -583, 0, -31312, 0, -582, 0, -30189, 0, -581, 0, 26248, 0, -580, 0, -31320, 0, -579, 0, 21927, 0, -578, 0, 26244, 0, -577, 0, 29002, 0, -576, 0, -31695, 0, -575, 0, 21321, 0, -574, 0, 21913, 0, -573, 0, 27585, 0, -572, 0, 24409, 0, -571, 0, 24509, 0, -570, 0, 25582, 0, -569, 0, 26249, 0, -568, 0, 28999, 0, -567, 0, -29967, 0, -566, 0, -28899, 0, -565, 0, -24898, 0, -564, 0, 20241, 0, -563, 0, 25658, 0, -562, 0, 28875, 0, -561, 0, 30054, 0, -560, 0, -31129, 0, -559, 0, 24676, 0, -558, 0, -29874, 0, -557, 0, -25096, 0, -556, 0, 20807, 0, -555, 0, 20982, 0, -554, 0, 21256, 0, -553, 0, 27958, 0, -552, 0, -32520, 0, -551, 0, -24879, 0, -550, 0, 26133, 0, -549, 0, 27427, 0, -548, 0, 28824, 0, -547, 0, 30165, 0, -546, 0, 21507, 0, -545, 0, 23673, 0, -544, 0, 32007, 0, -543, 0, -30186, 0, -542, 0, 27424, 0, -541, 0, 27453, 0, -540, 0, 27462, 0, -539, 0, 21560, 0, -538, 0, 24688, 0, -537, 0, 27965, 0, -536, 0, 32725, 0, -535, 0, -32248, 0, -534, 0, 20694, 0, -533, 0, 20958, 0, -532, 0, 21916, 0, -531, 0, 22123, 0, -530, 0, 22221, 0, -529, 0, 23020, 0, -528, 0, 23305, 0, -527, 0, 24076, 0, -526, 0, 24985, 0, -525, 0, 24984, 0, -524, 0, 25137, 0, -523, 0, 26206, 0, -522, 0, 26342, 0, -521, 0, 29081, 0, -520, 0, 29113, 0, -519, 0, 29114, 0, -518, 0, 29351, 0, -517, 0, 31143, 0, -516, 0, 31232, 0, -515, 0, 32690, 0, -514, 0, -30096, 0, -1, 0, -1, 0], ["i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0], ALLOC_STATIC);
STRING_TABLE.__str51098=allocate([65,100,111,98,101,0] /* Adobe\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str61099=allocate([75,111,114,101,97,49,0] /* Korea1\00 */, "i8", ALLOC_STATIC);
_KSC_EUC_AddCodeSpaceRange_code_space_range1=allocate([0, 0, 128, 0, 0, 0], ["i16",0,"i16",0,"i16",0], ALLOC_STATIC);
_KSC_EUC_AddCodeSpaceRange_code_space_range2=allocate([-24159, 0, -258, 0, 0, 0], ["i16",0,"i16",0,"i16",0], ALLOC_STATIC);
_CMAP_ARRAY_KSCms_UHC_HW_H=allocate([32, 0, 126, 0, 8094, 0, -32447, 0, -32422, 0, 9333, 0, -32415, 0, -32390, 0, 9359, 0, -32383, 0, -32258, 0, 9385, 0, -32191, 0, -32166, 0, 9511, 0, -32159, 0, -32134, 0, 9537, 0, -32127, 0, -32002, 0, 9563, 0, -31935, 0, -31910, 0, 9689, 0, -31903, 0, -31878, 0, 9715, 0, -31871, 0, -31746, 0, 9741, 0, -31679, 0, -31654, 0, 9867, 0, -31647, 0, -31622, 0, 9893, 0, -31615, 0, -31490, 0, 9919, 0, -31423, 0, -31398, 0, 10045, 0, -31391, 0, -31366, 0, 10071, 0, -31359, 0, -31234, 0, 10097, 0, -31167, 0, -31142, 0, 10223, 0, -31135, 0, -31110, 0, 10249, 0, -31103, 0, -30978, 0, 10275, 0, -30911, 0, -30886, 0, 10401, 0, -30879, 0, -30854, 0, 10427, 0, -30847, 0, -30722, 0, 10453, 0, -30655, 0, -30630, 0, 10579, 0, -30623, 0, -30598, 0, 10605, 0, -30591, 0, -30466, 0, 10631, 0, -30399, 0, -30374, 0, 10757, 0, -30367, 0, -30342, 0, 10783, 0, -30335, 0, -30210, 0, 10809, 0, -30143, 0, -30118, 0, 10935, 0, -30111, 0, -30086, 0, 10961, 0, -30079, 0, -29954, 0, 10987, 0, -29887, 0, -29862, 0, 11113, 0, -29855, 0, -29830, 0, 11139, 0, -29823, 0, -29698, 0, 11165, 0, -29631, 0, -29606, 0, 11291, 0, -29599, 0, -29574, 0, 11317, 0, -29567, 0, -29442, 0, 11343, 0, -29375, 0, -29350, 0, 11469, 0, -29343, 0, -29318, 0, 11495, 0, -29311, 0, -29186, 0, 11521, 0, -29119, 0, -29094, 0, 11647, 0, -29087, 0, -29062, 0, 11673, 0, -29055, 0, -28930, 0, 11699, 0, -28863, 0, -28838, 0, 11825, 0, -28831, 0, -28806, 0, 11851, 0, -28799, 0, -28674, 0, 11877, 0, -28607, 0, -28582, 0, 12003, 0, -28575, 0, -28550, 0, 12029, 0, -28543, 0, -28418, 0, 12055, 0, -28351, 0, -28326, 0, 12181, 0, -28319, 0, -28294, 0, 12207, 0, -28287, 0, -28162, 0, 12233, 0, -28095, 0, -28070, 0, 12359, 0, -28063, 0, -28038, 0, 12385, 0, -28031, 0, -27906, 0, 12411, 0, -27839, 0, -27814, 0, 12537, 0, -27807, 0, -27782, 0, 12563, 0, -27775, 0, -27650, 0, 12589, 0, -27583, 0, -27558, 0, 12715, 0, -27551, 0, -27526, 0, 12741, 0, -27519, 0, -27394, 0, 12767, 0, -27327, 0, -27302, 0, 12893, 0, -27295, 0, -27270, 0, 12919, 0, -27263, 0, -27138, 0, 12945, 0, -27071, 0, -27046, 0, 13071, 0, -27039, 0, -27014, 0, 13097, 0, -27007, 0, -26882, 0, 13123, 0, -26815, 0, -26790, 0, 13249, 0, -26783, 0, -26758, 0, 13275, 0, -26751, 0, -26626, 0, 13301, 0, -26559, 0, -26534, 0, 13427, 0, -26527, 0, -26502, 0, 13453, 0, -26495, 0, -26370, 0, 13479, 0, -26303, 0, -26278, 0, 13605, 0, -26271, 0, -26246, 0, 13631, 0, -26239, 0, -26114, 0, 13657, 0, -26047, 0, -26022, 0, 13783, 0, -26015, 0, -25990, 0, 13809, 0, -25983, 0, -25858, 0, 13835, 0, -25791, 0, -25766, 0, 13961, 0, -25759, 0, -25734, 0, 13987, 0, -25727, 0, -25602, 0, 14013, 0, -25535, 0, -25510, 0, 14139, 0, -25503, 0, -25478, 0, 14165, 0, -25471, 0, -25346, 0, 14191, 0, -25279, 0, -25254, 0, 14317, 0, -25247, 0, -25222, 0, 14343, 0, -25215, 0, -25090, 0, 14369, 0, -25023, 0, -24998, 0, 14495, 0, -24991, 0, -24966, 0, 14521, 0, -24959, 0, -24834, 0, 14547, 0, -24767, 0, -24742, 0, 14673, 0, -24735, 0, -24710, 0, 14699, 0, -24703, 0, -24578, 0, 14725, 0, -24511, 0, -24486, 0, 14851, 0, -24479, 0, -24454, 0, 14877, 0, -24447, 0, -24322, 0, 14903, 0, -24255, 0, -24230, 0, 15029, 0, -24223, 0, -24198, 0, 15055, 0, -24191, 0, -24160, 0, 15081, 0, -24159, 0, -24066, 0, 101, 0, -23999, 0, -23974, 0, 15113, 0, -23967, 0, -23942, 0, 15139, 0, -23935, 0, -23904, 0, 15165, 0, -23903, 0, -23835, 0, 195, 0, -23743, 0, -23718, 0, 15197, 0, -23711, 0, -23686, 0, 15223, 0, -23679, 0, -23648, 0, 15249, 0, -23647, 0, -23554, 0, 264, 0, -23487, 0, -23462, 0, 15281, 0, -23455, 0, -23430, 0, 15307, 0, -23423, 0, -23392, 0, 15333, 0, -23391, 0, -23341, 0, 358, 0, -23339, 0, -23298, 0, 409, 0, -23231, 0, -23206, 0, 15365, 0, -23199, 0, -23174, 0, 15391, 0, -23167, 0, -23136, 0, 15417, 0, -23135, 0, -23126, 0, 451, 0, -23120, 0, -23111, 0, 461, 0, -23103, 0, -23080, 0, 471, 0, -23071, 0, -23048, 0, 495, 0, -22975, 0, -22950, 0, 15449, 0, -22943, 0, -22918, 0, 15475, 0, -22911, 0, -22880, 0, 15501, 0, -22879, 0, -22812, 0, 519, 0, -22719, 0, -22694, 0, 15533, 0, -22687, 0, -22662, 0, 15559, 0, -22655, 0, -22624, 0, 15585, 0, -22623, 0, -22545, 0, 587, 0, -22463, 0, -22438, 0, 15617, 0, -22431, 0, -22406, 0, 15643, 0, -22399, 0, -22368, 0, 15669, 0, -22367, 0, -22364, 0, 666, 0, -22362, 0, -22362, 0, 670, 0, -22360, 0, -22353, 0, 671, 0, -22351, 0, -22274, 0, 679, 0, -22207, 0, -22182, 0, 15701, 0, -22175, 0, -22150, 0, 15727, 0, -22143, 0, -22112, 0, 15753, 0, -22111, 0, -22018, 0, 757, 0, -21951, 0, -21926, 0, 15785, 0, -21919, 0, -21894, 0, 15811, 0, -21887, 0, -21856, 0, 15837, 0, -21855, 0, -21773, 0, 851, 0, -21695, 0, -21670, 0, 15869, 0, -21663, 0, -21638, 0, 15895, 0, -21631, 0, -21600, 0, 15921, 0, -21599, 0, -21514, 0, 934, 0, -21439, 0, -21414, 0, 15953, 0, -21407, 0, -21382, 0, 15979, 0, -21375, 0, -21344, 0, 16005, 0, -21343, 0, -21311, 0, 1020, 0, -21295, 0, -21263, 0, 1053, 0, -21183, 0, -21158, 0, 16037, 0, -21151, 0, -21126, 0, 16063, 0, -21119, 0, -21088, 0, 16089, 0, -20927, 0, -20902, 0, 16121, 0, -20895, 0, -20870, 0, 16147, 0, -20863, 0, -20832, 0, 16173, 0, -20671, 0, -20646, 0, 16205, 0, -20639, 0, -20614, 0, 16231, 0, -20607, 0, -20576, 0, 16257, 0, -20415, 0, -20390, 0, 16289, 0, -20383, 0, -20358, 0, 16315, 0, -20351, 0, -20320, 0, 16341, 0, -20319, 0, -20226, 0, 1086, 0, -20159, 0, -20134, 0, 16373, 0, -20127, 0, -20102, 0, 16399, 0, -20095, 0, -20064, 0, 16425, 0, -20063, 0, -19970, 0, 1180, 0, -19903, 0, -19878, 0, 16457, 0, -19871, 0, -19846, 0, 16483, 0, -19839, 0, -19808, 0, 16509, 0, -19807, 0, -19714, 0, 1274, 0, -19647, 0, -19622, 0, 16541, 0, -19615, 0, -19590, 0, 16567, 0, -19583, 0, -19552, 0, 16593, 0, -19551, 0, -19458, 0, 1368, 0, -19391, 0, -19366, 0, 16625, 0, -19359, 0, -19334, 0, 16651, 0, -19327, 0, -19296, 0, 16677, 0, -19295, 0, -19202, 0, 1462, 0, -19135, 0, -19110, 0, 16709, 0, -19103, 0, -19078, 0, 16735, 0, -19071, 0, -19040, 0, 16761, 0, -19039, 0, -18946, 0, 1556, 0, -18879, 0, -18854, 0, 16793, 0, -18847, 0, -18822, 0, 16819, 0, -18815, 0, -18784, 0, 16845, 0, -18783, 0, -18690, 0, 1650, 0, -18623, 0, -18598, 0, 16877, 0, -18591, 0, -18566, 0, 16903, 0, -18559, 0, -18528, 0, 16929, 0, -18527, 0, -18434, 0, 1744, 0, -18367, 0, -18342, 0, 16961, 0, -18335, 0, -18310, 0, 16987, 0, -18303, 0, -18272, 0, 17013, 0, -18271, 0, -18178, 0, 1838, 0, -18111, 0, -18086, 0, 17045, 0, -18079, 0, -18054, 0, 17071, 0, -18047, 0, -18016, 0, 17097, 0, -18015, 0, -17922, 0, 1932, 0, -17855, 0, -17830, 0, 17129, 0, -17823, 0, -17798, 0, 17155, 0, -17791, 0, -17760, 0, 17181, 0, -17759, 0, -17666, 0, 2026, 0, -17599, 0, -17574, 0, 17213, 0, -17567, 0, -17542, 0, 17239, 0, -17535, 0, -17504, 0, 17265, 0, -17503, 0, -17410, 0, 2120, 0, -17343, 0, -17318, 0, 17297, 0, -17311, 0, -17286, 0, 17323, 0, -17279, 0, -17248, 0, 17349, 0, -17247, 0, -17154, 0, 2214, 0, -17087, 0, -17062, 0, 17381, 0, -17055, 0, -17030, 0, 17407, 0, -17023, 0, -16992, 0, 17433, 0, -16991, 0, -16898, 0, 2308, 0, -16831, 0, -16806, 0, 17465, 0, -16799, 0, -16774, 0, 17491, 0, -16767, 0, -16736, 0, 17517, 0, -16735, 0, -16642, 0, 2402, 0, -16575, 0, -16550, 0, 17549, 0, -16543, 0, -16518, 0, 17575, 0, -16511, 0, -16480, 0, 17601, 0, -16479, 0, -16386, 0, 2496, 0, -16319, 0, -16294, 0, 17633, 0, -16287, 0, -16262, 0, 17659, 0, -16255, 0, -16224, 0, 17685, 0, -16223, 0, -16130, 0, 2590, 0, -16063, 0, -16038, 0, 17717, 0, -16031, 0, -16006, 0, 17743, 0, -15999, 0, -15968, 0, 17769, 0, -15967, 0, -15874, 0, 2684, 0, -15807, 0, -15782, 0, 17801, 0, -15775, 0, -15750, 0, 17827, 0, -15743, 0, -15712, 0, 17853, 0, -15711, 0, -15618, 0, 2778, 0, -15551, 0, -15526, 0, 17885, 0, -15519, 0, -15494, 0, 17911, 0, -15487, 0, -15456, 0, 17937, 0, -15455, 0, -15362, 0, 2872, 0, -15295, 0, -15270, 0, 17969, 0, -15263, 0, -15238, 0, 17995, 0, -15231, 0, -15200, 0, 18021, 0, -15199, 0, -15106, 0, 2966, 0, -15039, 0, -15014, 0, 18053, 0, -15007, 0, -14982, 0, 18079, 0, -14975, 0, -14944, 0, 18105, 0, -14943, 0, -14850, 0, 3060, 0, -14783, 0, -14766, 0, 18137, 0, -14687, 0, -14594, 0, 3154, 0, -14431, 0, -14338, 0, 3248, 0, -14175, 0, -14082, 0, 3342, 0, -13663, 0, -13570, 0, 3436, 0, -13407, 0, -13361, 0, 3530, 0, -13360, 0, -13360, 0, 4116, 0, -13359, 0, -13355, 0, 3577, 0, -13354, 0, -13354, 0, 3678, 0, -13353, 0, -13338, 0, 3582, 0, -13337, 0, -13337, 0, 7053, 0, -13336, 0, -13314, 0, 3598, 0, -13151, 0, -13058, 0, 3621, 0, -12895, 0, -12850, 0, 3715, 0, -12849, 0, -12849, 0, 3460, 0, -12848, 0, -12825, 0, 3761, 0, -12824, 0, -12824, 0, 7900, 0, -12823, 0, -12802, 0, 3785, 0, -12639, 0, -12628, 0, 3807, 0, -12627, 0, -12627, 0, 3802, 0, -12626, 0, -12546, 0, 3819, 0, -12383, 0, -12294, 0, 3900, 0, -12293, 0, -12293, 0, 3902, 0, -12292, 0, -12290, 0, 3990, 0, -12127, 0, -12127, 0, 3993, 0, -12126, 0, -12126, 0, 3946, 0, -12125, 0, -12105, 0, 3994, 0, -12104, 0, -12104, 0, 3946, 0, -12103, 0, -12081, 0, 4015, 0, -12080, 0, -12080, 0, 3708, 0, -12079, 0, -12068, 0, 4038, 0, -12067, 0, -12067, 0, 4131, 0, -12066, 0, -12034, 0, 4050, 0, -11871, 0, -11821, 0, 4083, 0, -11820, 0, -11820, 0, 4374, 0, -11819, 0, -11819, 0, 4156, 0, -11818, 0, -11817, 0, 4134, 0, -11816, 0, -11816, 0, 4375, 0, -11815, 0, -11814, 0, 4136, 0, -11813, 0, -11808, 0, 4376, 0, -11807, 0, -11807, 0, 4138, 0, -11806, 0, -11806, 0, 5800, 0, -11805, 0, -11803, 0, 4382, 0, -11802, 0, -11802, 0, 4386, 0, -11801, 0, -11801, 0, 4139, 0, -11800, 0, -11797, 0, 4387, 0, -11796, 0, -11796, 0, 4140, 0, -11795, 0, -11795, 0, 4391, 0, -11794, 0, -11794, 0, 4141, 0, -11793, 0, -11792, 0, 4394, 0, -11791, 0, -11791, 0, 4142, 0, -11790, 0, -11790, 0, 4396, 0, -11789, 0, -11787, 0, 4143, 0, -11786, 0, -11786, 0, 4399, 0, -11785, 0, -11783, 0, 4146, 0, -11782, 0, -11782, 0, 4403, 0, -11781, 0, -11781, 0, 4149, 0, -11780, 0, -11779, 0, 4406, 0, -11778, 0, -11778, 0, 4409, 0, -11615, 0, -11615, 0, 4150, 0, -11614, 0, -11613, 0, 4410, 0, -11612, 0, -11610, 0, 4151, 0, -11609, 0, -11606, 0, 4412, 0, -11605, 0, -11605, 0, 4419, 0, -11604, 0, -11604, 0, 4154, 0, -11603, 0, -11603, 0, 4420, 0, -11602, 0, -11599, 0, 4155, 0, -11598, 0, -11598, 0, 4424, 0, -11597, 0, -11587, 0, 4159, 0, -11586, 0, -11586, 0, 4511, 0, -11585, 0, -11583, 0, 4170, 0, -11582, 0, -11581, 0, 4513, 0, -11580, 0, -11580, 0, 4517, 0, -11579, 0, -11579, 0, 4173, 0, -11578, 0, -11574, 0, 4518, 0, -11573, 0, -11573, 0, 4524, 0, -11572, 0, -11572, 0, 4174, 0, -11571, 0, -11570, 0, 4525, 0, -11569, 0, -11564, 0, 4528, 0, -11563, 0, -11561, 0, 4535, 0, -11560, 0, -11560, 0, 4175, 0, -11559, 0, -11558, 0, 4541, 0, -11557, 0, -11555, 0, 4176, 0, -11554, 0, -11553, 0, 4545, 0, -11552, 0, -11552, 0, 4179, 0, -11551, 0, -11551, 0, 4547, 0, -11550, 0, -11550, 0, 4550, 0, -11549, 0, -11549, 0, 4180, 0, -11548, 0, -11548, 0, 4564, 0, -11547, 0, -11544, 0, 4566, 0, -11543, 0, -11542, 0, 4571, 0, -11541, 0, -11541, 0, 4576, 0, -11540, 0, -11537, 0, 4181, 0, -11536, 0, -11533, 0, 4604, 0, -11532, 0, -11531, 0, 4609, 0, -11530, 0, -11530, 0, 4185, 0, -11529, 0, -11528, 0, 4611, 0, -11527, 0, -11522, 0, 4186, 0, -11359, 0, -11266, 0, 4192, 0, -11103, 0, -11035, 0, 4286, 0, -11034, 0, -11034, 0, 4318, 0, -11033, 0, -11013, 0, 4355, 0, -11012, 0, -11012, 0, 4136, 0, -11011, 0, -11010, 0, 4376, 0, -10847, 0, -10844, 0, 4378, 0, -10843, 0, -10843, 0, 5800, 0, -10842, 0, -10838, 0, 4382, 0, -10837, 0, -10837, 0, 4139, 0, -10836, 0, -10835, 0, 4387, 0, -10834, 0, -10834, 0, 4192, 0, -10833, 0, -10754, 0, 4389, 0, -10591, 0, -10569, 0, 4469, 0, -10568, 0, -10568, 0, 4167, 0, -10567, 0, -10548, 0, 4492, 0, -10547, 0, -10547, 0, 4172, 0, -10546, 0, -10498, 0, 4512, 0, -10335, 0, -10294, 0, 4561, 0, -10293, 0, -10293, 0, 5552, 0, -10292, 0, -10269, 0, 4603, 0, -10268, 0, -10268, 0, 6424, 0, -10267, 0, -10242, 0, 4627, 0, -10079, 0, -9986, 0, 4653, 0, -9823, 0, -9730, 0, 4747, 0, -9567, 0, -9474, 0, 4841, 0, -9311, 0, -9276, 0, 4935, 0, -9275, 0, -9275, 0, 5151, 0, -9274, 0, -9245, 0, 4971, 0, -9244, 0, -9244, 0, 4922, 0, -9243, 0, -9218, 0, 5001, 0, -9055, 0, -9052, 0, 5027, 0, -9051, 0, -9051, 0, 7518, 0, -9050, 0, -8962, 0, 5031, 0, -8799, 0, -8796, 0, 5120, 0, -8795, 0, -8795, 0, 5079, 0, -8794, 0, -8748, 0, 5124, 0, -8747, 0, -8747, 0, 5109, 0, -8746, 0, -8717, 0, 5171, 0, -8716, 0, -8716, 0, 7607, 0, -8715, 0, -8706, 0, 5201, 0, -8543, 0, -8453, 0, 5211, 0, -8452, 0, -8452, 0, 5584, 0, -8451, 0, -8451, 0, 5302, 0, -8450, 0, -8450, 0, 5367, 0, -8287, 0, -8270, 0, 5303, 0, -8269, 0, -8269, 0, 7083, 0, -8268, 0, -8224, 0, 5321, 0, -8223, 0, -8223, 0, 5362, 0, -8222, 0, -8217, 0, 5366, 0, -8216, 0, -8216, 0, 5485, 0, -8215, 0, -8194, 0, 5372, 0, -8031, 0, -7952, 0, 5394, 0, -7951, 0, -7951, 0, 6001, 0, -7950, 0, -7938, 0, 5474, 0, -7775, 0, -7764, 0, 5487, 0, -7763, 0, -7763, 0, 5460, 0, -7762, 0, -7700, 0, 5499, 0, -7699, 0, -7699, 0, 5317, 0, -7698, 0, -7682, 0, 5562, 0, -7519, 0, -7426, 0, 5579, 0, -7263, 0, -7180, 0, 5673, 0, -7179, 0, -7179, 0, 7009, 0, -7178, 0, -7170, 0, 5757, 0, -7007, 0, -7007, 0, 7370, 0, -7006, 0, -7000, 0, 5766, 0, -6999, 0, -6999, 0, 5678, 0, -6998, 0, -6914, 0, 5773, 0, -6751, 0, -6739, 0, 5858, 0, -6738, 0, -6738, 0, 5874, 0, -6737, 0, -6736, 0, 5871, 0, -6735, 0, -6734, 0, 4425, 0, -6733, 0, -6728, 0, 5873, 0, -6727, 0, -6727, 0, 4427, 0, -6726, 0, -6726, 0, 5879, 0, -6725, 0, -6724, 0, 4429, 0, -6723, 0, -6717, 0, 5880, 0, -6716, 0, -6716, 0, 4431, 0, -6715, 0, -6707, 0, 5887, 0, -6706, 0, -6706, 0, 4435, 0, -6705, 0, -6705, 0, 5896, 0, -6704, 0, -6704, 0, 4436, 0, -6703, 0, -6703, 0, 5897, 0, -6702, 0, -6702, 0, 4437, 0, -6701, 0, -6699, 0, 5898, 0, -6698, 0, -6698, 0, 4439, 0, -6697, 0, -6663, 0, 5901, 0, -6662, 0, -6661, 0, 4442, 0, -6660, 0, -6660, 0, 4159, 0, -6659, 0, -6659, 0, 5936, 0, -6658, 0, -6658, 0, 4444, 0, -6495, 0, -6495, 0, 4447, 0, -6494, 0, -6493, 0, 5937, 0, -6492, 0, -6492, 0, 4449, 0, -6491, 0, -6490, 0, 5939, 0, -6489, 0, -6489, 0, 4450, 0, -6488, 0, -6484, 0, 5941, 0, -6483, 0, -6483, 0, 4453, 0, -6482, 0, -6482, 0, 5946, 0, -6481, 0, -6479, 0, 4455, 0, -6478, 0, -6478, 0, 5947, 0, -6477, 0, -6477, 0, 4458, 0, -6476, 0, -6474, 0, 5948, 0, -6473, 0, -6472, 0, 4459, 0, -6471, 0, -6469, 0, 5951, 0, -6468, 0, -6468, 0, 4463, 0, -6467, 0, -6461, 0, 5954, 0, -6460, 0, -6460, 0, 4160, 0, -6459, 0, -6459, 0, 5961, 0, -6458, 0, -6457, 0, 4465, 0, -6456, 0, -6455, 0, 5962, 0, -6454, 0, -6454, 0, 4161, 0, -6453, 0, -6447, 0, 5964, 0, -6446, 0, -6446, 0, 4468, 0, -6445, 0, -6443, 0, 5971, 0, -6442, 0, -6442, 0, 4469, 0, -6441, 0, -6440, 0, 5974, 0, -6439, 0, -6439, 0, 4470, 0, -6438, 0, -6437, 0, 5976, 0, -6436, 0, -6436, 0, 4162, 0, -6435, 0, -6434, 0, 5978, 0, -6433, 0, -6433, 0, 4471, 0, -6432, 0, -6432, 0, 5980, 0, -6431, 0, -6431, 0, 4472, 0, -6430, 0, -6429, 0, 5981, 0, -6428, 0, -6428, 0, 4474, 0, -6427, 0, -6427, 0, 4473, 0, -6426, 0, -6426, 0, 4475, 0, -6425, 0, -6425, 0, 5983, 0, -6424, 0, -6424, 0, 4476, 0, -6423, 0, -6423, 0, 5984, 0, -6422, 0, -6421, 0, 4478, 0, -6420, 0, -6420, 0, 6447, 0, -6419, 0, -6418, 0, 5985, 0, -6417, 0, -6417, 0, 4481, 0, -6416, 0, -6416, 0, 5987, 0, -6415, 0, -6415, 0, 4482, 0, -6414, 0, -6414, 0, 5460, 0, -6413, 0, -6412, 0, 5988, 0, -6411, 0, -6411, 0, 4483, 0, -6410, 0, -6410, 0, 4163, 0, -6409, 0, -6409, 0, 4166, 0, -6408, 0, -6408, 0, 5990, 0, -6407, 0, -6407, 0, 4485, 0, -6406, 0, -6402, 0, 5991, 0, -6239, 0, -6239, 0, 4487, 0, -6238, 0, -6235, 0, 5996, 0, -6234, 0, -6234, 0, 4488, 0, -6233, 0, -6232, 0, 6000, 0, -6231, 0, -6231, 0, 4489, 0, -6230, 0, -6230, 0, 4491, 0, -6229, 0, -6229, 0, 6002, 0, -6228, 0, -6228, 0, 4167, 0, -6227, 0, -6227, 0, 4493, 0, -6226, 0, -6225, 0, 6003, 0, -6224, 0, -6224, 0, 4494, 0, -6223, 0, -6210, 0, 6005, 0, -6209, 0, -6209, 0, 4495, 0, -6208, 0, -6208, 0, 6019, 0, -6207, 0, -6207, 0, 7783, 0, -6206, 0, -6203, 0, 6020, 0, -6202, 0, -6202, 0, 4497, 0, -6201, 0, -6201, 0, 4499, 0, -6200, 0, -6198, 0, 6024, 0, -6197, 0, -6197, 0, 4501, 0, -6196, 0, -6196, 0, 6027, 0, -6195, 0, -6195, 0, 4502, 0, -6194, 0, -6194, 0, 6028, 0, -6193, 0, -6192, 0, 4503, 0, -6191, 0, -6190, 0, 6029, 0, -6189, 0, -6189, 0, 4506, 0, -6188, 0, -6178, 0, 6031, 0, -6177, 0, -6177, 0, 4508, 0, -6176, 0, -6173, 0, 6042, 0, -6172, 0, -6172, 0, 4509, 0, -6171, 0, -6171, 0, 6046, 0, -6170, 0, -6170, 0, 4510, 0, -6169, 0, -6154, 0, 6047, 0, -6153, 0, -6153, 0, 5797, 0, -6152, 0, -6146, 0, 6063, 0, -5983, 0, -5914, 0, 6070, 0, -5913, 0, -5912, 0, 4551, 0, -5911, 0, -5905, 0, 6140, 0, -5904, 0, -5904, 0, 4553, 0, -5903, 0, -5903, 0, 4180, 0, -5902, 0, -5898, 0, 6147, 0, -5897, 0, -5897, 0, 4555, 0, -5896, 0, -5896, 0, 6152, 0, -5895, 0, -5895, 0, 5800, 0, -5894, 0, -5894, 0, 6153, 0, -5893, 0, -5893, 0, 4556, 0, -5892, 0, -5891, 0, 6154, 0, -5890, 0, -5890, 0, 4557, 0, -5727, 0, -5722, 0, 6156, 0, -5721, 0, -5721, 0, 4560, 0, -5720, 0, -5717, 0, 6162, 0, -5716, 0, -5716, 0, 4561, 0, -5715, 0, -5685, 0, 6166, 0, -5684, 0, -5684, 0, 4563, 0, -5683, 0, -5642, 0, 6197, 0, -5641, 0, -5641, 0, 7988, 0, -5640, 0, -5634, 0, 6239, 0, -5471, 0, -5440, 0, 6246, 0, -5439, 0, -5439, 0, 6123, 0, -5438, 0, -5404, 0, 6278, 0, -5403, 0, -5403, 0, 4577, 0, -5402, 0, -5389, 0, 6313, 0, -5388, 0, -5388, 0, 4183, 0, -5387, 0, -5386, 0, 6327, 0, -5385, 0, -5385, 0, 4579, 0, -5384, 0, -5381, 0, 6329, 0, -5380, 0, -5380, 0, 4581, 0, -5379, 0, -5379, 0, 6333, 0, -5378, 0, -5378, 0, 4582, 0, -5215, 0, -5213, 0, 6334, 0, -5212, 0, -5212, 0, 4584, 0, -5211, 0, -5210, 0, 6337, 0, -5209, 0, -5209, 0, 4586, 0, -5208, 0, -5208, 0, 6339, 0, -5207, 0, -5207, 0, 4588, 0, -5206, 0, -5206, 0, 4184, 0, -5205, 0, -5191, 0, 6340, 0, -5190, 0, -5189, 0, 4590, 0, -5188, 0, -5188, 0, 6355, 0, -5187, 0, -5187, 0, 4592, 0, -5186, 0, -5184, 0, 6356, 0, -5183, 0, -5183, 0, 4593, 0, -5182, 0, -5182, 0, 4595, 0, -5181, 0, -5179, 0, 6359, 0, -5178, 0, -5177, 0, 4596, 0, -5176, 0, -5173, 0, 6362, 0, -5172, 0, -5172, 0, 4599, 0, -5171, 0, -5170, 0, 6366, 0, -5169, 0, -5167, 0, 4600, 0, -5166, 0, -5166, 0, 5552, 0, -5165, 0, -5161, 0, 6368, 0, -5160, 0, -5160, 0, 4603, 0, -5159, 0, -5122, 0, 6373, 0, -4959, 0, -4955, 0, 6411, 0, -4954, 0, -4954, 0, 4614, 0, -4953, 0, -4953, 0, 4616, 0, -4952, 0, -4951, 0, 6416, 0, -4950, 0, -4950, 0, 4618, 0, -4949, 0, -4946, 0, 6418, 0, -4945, 0, -4945, 0, 5950, 0, -4944, 0, -4943, 0, 4620, 0, -4942, 0, -4942, 0, 4187, 0, -4941, 0, -4940, 0, 6422, 0, -4939, 0, -4939, 0, 4625, 0, -4938, 0, -4937, 0, 6424, 0, -4936, 0, -4936, 0, 4627, 0, -4935, 0, -4935, 0, 6426, 0, -4934, 0, -4934, 0, 4629, 0, -4933, 0, -4929, 0, 6427, 0, -4928, 0, -4927, 0, 4632, 0, -4926, 0, -4924, 0, 6432, 0, -4923, 0, -4923, 0, 4634, 0, -4922, 0, -4922, 0, 4636, 0, -4921, 0, -4920, 0, 6435, 0, -4919, 0, -4918, 0, 4188, 0, -4917, 0, -4908, 0, 6437, 0, -4907, 0, -4907, 0, 4638, 0, -4906, 0, -4900, 0, 6447, 0, -4899, 0, -4898, 0, 4640, 0, -4897, 0, -4896, 0, 6454, 0, -4895, 0, -4895, 0, 4642, 0, -4894, 0, -4893, 0, 6456, 0, -4892, 0, -4892, 0, 4644, 0, -4891, 0, -4890, 0, 6458, 0, -4889, 0, -4888, 0, 4645, 0, -4887, 0, -4874, 0, 6460, 0, -4873, 0, -4872, 0, 4647, 0, -4871, 0, -4871, 0, 6474, 0, -4870, 0, -4870, 0, 4650, 0, -4869, 0, -4866, 0, 6475, 0, -4703, 0, -4701, 0, 4653, 0, -4700, 0, -4627, 0, 6479, 0, -4626, 0, -4626, 0, 5351, 0, -4625, 0, -4610, 0, 6553, 0, -4447, 0, -4390, 0, 6569, 0, -4389, 0, -4389, 0, 6494, 0, -4388, 0, -4354, 0, 6627, 0, -4191, 0, -4098, 0, 6662, 0, -3935, 0, -3842, 0, 6756, 0, -3679, 0, -3586, 0, 6850, 0, -3423, 0, -3396, 0, 6944, 0, -3395, 0, -3395, 0, 5731, 0, -3394, 0, -3335, 0, 6972, 0, -3334, 0, -3334, 0, 5771, 0, -3333, 0, -3330, 0, 7032, 0, -3167, 0, -3152, 0, 7036, 0, -3151, 0, -3151, 0, 4191, 0, -3150, 0, -3074, 0, 7052, 0, -2911, 0, -2906, 0, 7129, 0, -2905, 0, -2905, 0, 6484, 0, -2904, 0, -2835, 0, 7135, 0, -2834, 0, -2834, 0, 6684, 0, -2833, 0, -2818, 0, 7205, 0, -2655, 0, -2562, 0, 7221, 0, -2399, 0, -2317, 0, 7315, 0, -2316, 0, -2316, 0, 4279, 0, -2315, 0, -2315, 0, 7398, 0, -2314, 0, -2314, 0, 7139, 0, -2313, 0, -2306, 0, 7399, 0, -2143, 0, -2121, 0, 7407, 0, -2120, 0, -2120, 0, 4247, 0, -2119, 0, -2105, 0, 7430, 0, -2104, 0, -2104, 0, 4266, 0, -2103, 0, -2094, 0, 7445, 0, -2093, 0, -2093, 0, 4340, 0, -2092, 0, -2050, 0, 7455, 0, -1887, 0, -1830, 0, 7498, 0, -1829, 0, -1829, 0, 7572, 0, -1828, 0, -1809, 0, 7556, 0, -1808, 0, -1808, 0, 5088, 0, -1807, 0, -1794, 0, 7576, 0, -1631, 0, -1538, 0, 7590, 0, -1375, 0, -1375, 0, 7709, 0, -1374, 0, -1374, 0, 3558, 0, -1373, 0, -1307, 0, 7684, 0, -1306, 0, -1306, 0, 3644, 0, -1305, 0, -1282, 0, 7751, 0, -1119, 0, -1026, 0, 7775, 0, -863, 0, -856, 0, 7869, 0, -855, 0, -855, 0, 3815, 0, -854, 0, -770, 0, 7877, 0, -1, 0, -1, 0, 0, 0], ["i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0], ALLOC_STATIC);
_CMAP_ARRAY_KSCms_UHC_HW_V=allocate([-24158, 0, -24157, 0, 8056, 0, -24155, 0, -24155, 0, 8058, 0, -24154, 0, -24154, 0, 8320, 0, -24151, 0, -24149, 0, 8059, 0, -24147, 0, -24147, 0, 8062, 0, -24142, 0, -24131, 0, 8063, 0, -24085, 0, -24085, 0, 8075, 0, -23647, 0, -23647, 0, 8076, 0, -23640, 0, -23639, 0, 8077, 0, -23636, 0, -23636, 0, 8079, 0, -23634, 0, -23634, 0, 8080, 0, -23622, 0, -23617, 0, 8081, 0, -23589, 0, -23589, 0, 8087, 0, -23587, 0, -23587, 0, 8088, 0, -23585, 0, -23585, 0, 8089, 0, -23557, 0, -23554, 0, 8090, 0, -1, 0, -1, 0, 0, 0], ["i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0], ALLOC_STATIC);
_KSCms_UHC_HW_NOTDEF_RANGE=allocate([0, 0, 31, 0, 8094, 0], ["i16",0,"i16",0,"i16",0], ALLOC_STATIC);
_CP949_UNICODE_ARRAY=allocate([0, 0, 0, 0, 1, 0, 1, 0, 2, 0, 2, 0, 3, 0, 3, 0, 4, 0, 4, 0, 5, 0, 5, 0, 6, 0, 6, 0, 7, 0, 7, 0, 8, 0, 8, 0, 9, 0, 9, 0, 10, 0, 10, 0, 11, 0, 11, 0, 12, 0, 12, 0, 13, 0, 13, 0, 14, 0, 14, 0, 15, 0, 15, 0, 16, 0, 16, 0, 17, 0, 17, 0, 18, 0, 18, 0, 19, 0, 19, 0, 20, 0, 20, 0, 21, 0, 21, 0, 22, 0, 22, 0, 23, 0, 23, 0, 24, 0, 24, 0, 25, 0, 25, 0, 26, 0, 26, 0, 27, 0, 27, 0, 28, 0, 28, 0, 29, 0, 29, 0, 30, 0, 30, 0, 31, 0, 31, 0, 32, 0, 32, 0, 33, 0, 33, 0, 34, 0, 34, 0, 35, 0, 35, 0, 36, 0, 36, 0, 37, 0, 37, 0, 38, 0, 38, 0, 39, 0, 39, 0, 40, 0, 40, 0, 41, 0, 41, 0, 42, 0, 42, 0, 43, 0, 43, 0, 44, 0, 44, 0, 45, 0, 45, 0, 46, 0, 46, 0, 47, 0, 47, 0, 48, 0, 48, 0, 49, 0, 49, 0, 50, 0, 50, 0, 51, 0, 51, 0, 52, 0, 52, 0, 53, 0, 53, 0, 54, 0, 54, 0, 55, 0, 55, 0, 56, 0, 56, 0, 57, 0, 57, 0, 58, 0, 58, 0, 59, 0, 59, 0, 60, 0, 60, 0, 61, 0, 61, 0, 62, 0, 62, 0, 63, 0, 63, 0, 64, 0, 64, 0, 65, 0, 65, 0, 66, 0, 66, 0, 67, 0, 67, 0, 68, 0, 68, 0, 69, 0, 69, 0, 70, 0, 70, 0, 71, 0, 71, 0, 72, 0, 72, 0, 73, 0, 73, 0, 74, 0, 74, 0, 75, 0, 75, 0, 76, 0, 76, 0, 77, 0, 77, 0, 78, 0, 78, 0, 79, 0, 79, 0, 80, 0, 80, 0, 81, 0, 81, 0, 82, 0, 82, 0, 83, 0, 83, 0, 84, 0, 84, 0, 85, 0, 85, 0, 86, 0, 86, 0, 87, 0, 87, 0, 88, 0, 88, 0, 89, 0, 89, 0, 90, 0, 90, 0, 91, 0, 91, 0, 92, 0, 92, 0, 93, 0, 93, 0, 94, 0, 94, 0, 95, 0, 95, 0, 96, 0, 96, 0, 97, 0, 97, 0, 98, 0, 98, 0, 99, 0, 99, 0, 100, 0, 100, 0, 101, 0, 101, 0, 102, 0, 102, 0, 103, 0, 103, 0, 104, 0, 104, 0, 105, 0, 105, 0, 106, 0, 106, 0, 107, 0, 107, 0, 108, 0, 108, 0, 109, 0, 109, 0, 110, 0, 110, 0, 111, 0, 111, 0, 112, 0, 112, 0, 113, 0, 113, 0, 114, 0, 114, 0, 115, 0, 115, 0, 116, 0, 116, 0, 117, 0, 117, 0, 118, 0, 118, 0, 119, 0, 119, 0, 120, 0, 120, 0, 121, 0, 121, 0, 122, 0, 122, 0, 123, 0, 123, 0, 124, 0, 124, 0, 125, 0, 125, 0, 126, 0, 126, 0, 127, 0, 127, 0, 128, 0, 128, 0, 255, 0, -1801, 0, -32447, 0, -21502, 0, -32446, 0, -21501, 0, -32445, 0, -21499, 0, -32444, 0, -21498, 0, -32443, 0, -21493, 0, -32442, 0, -21492, 0, -32441, 0, -21491, 0, -32440, 0, -21490, 0, -32439, 0, -21489, 0, -32438, 0, -21480, 0, -32437, 0, -21474, 0, -32436, 0, -21473, 0, -32435, 0, -21471, 0, -32434, 0, -21470, 0, -32433, 0, -21469, 0, -32432, 0, -21467, 0, -32431, 0, -21466, 0, -32430, 0, -21465, 0, -32429, 0, -21464, 0, -32428, 0, -21463, 0, -32427, 0, -21462, 0, -32426, 0, -21461, 0, -32425, 0, -21458, 0, -32424, 0, -21454, 0, -32423, 0, -21453, 0, -32422, 0, -21452, 0, -32415, 0, -21451, 0, -32414, 0, -21450, 0, -32413, 0, -21449, 0, -32412, 0, -21446, 0, -32411, 0, -21445, 0, -32410, 0, -21443, 0, -32409, 0, -21442, 0, -32408, 0, -21441, 0, -32407, 0, -21439, 0, -32406, 0, -21438, 0, -32405, 0, -21437, 0, -32404, 0, -21436, 0, -32403, 0, -21435, 0, -32402, 0, -21434, 0, -32401, 0, -21433, 0, -32400, 0, -21432, 0, -32399, 0, -21431, 0, -32398, 0, -21430, 0, -32397, 0, -21428, 0, -32396, 0, -21426, 0, -32395, 0, -21425, 0, -32394, 0, -21424, 0, -32393, 0, -21423, 0, -32392, 0, -21422, 0, -32391, 0, -21421, 0, -32390, 0, -21419, 0, -32383, 0, -21418, 0, -32382, 0, -21417, 0, -32381, 0, -21415, 0, -32380, 0, -21414, 0, -32379, 0, -21413, 0, -32378, 0, -21411, 0, -32377, 0, -21410, 0, -32376, 0, -21409, 0, -32375, 0, -21408, 0, -32374, 0, -21407, 0, -32373, 0, -21406, 0, -32372, 0, -21405, 0, -32371, 0, -21404, 0, -32370, 0, -21403, 0, -32369, 0, -21402, 0, -32368, 0, -21401, 0, -32367, 0, -21400, 0, -32366, 0, -21399, 0, -32365, 0, -21398, 0, -32364, 0, -21397, 0, -32363, 0, -21396, 0, -32362, 0, -21395, 0, -32361, 0, -21394, 0, -32360, 0, -21393, 0, -32359, 0, -21390, 0, -32358, 0, -21389, 0, -32357, 0, -21387, 0, -32356, 0, -21386, 0, -32355, 0, -21383, 0, -32354, 0, -21381, 0, -32353, 0, -21380, 0, -32352, 0, -21379, 0, -32351, 0, -21378, 0, -32350, 0, -21377, 0, -32349, 0, -21374, 0, -32348, 0, -21369, 0, -32347, 0, -21368, 0, -32346, 0, -21363, 0, -32345, 0, -21362, 0, -32344, 0, -21361, 0, -32343, 0, -21359, 0, -32342, 0, -21358, 0, -32341, 0, -21357, 0, -32340, 0, -21355, 0, -32339, 0, -21354, 0, -32338, 0, -21353, 0, -32337, 0, -21352, 0, -32336, 0, -21351, 0, -32335, 0, -21350, 0, -32334, 0, -21349, 0, -32333, 0, -21346, 0, -32332, 0, -21342, 0, -32331, 0, -21341, 0, -32330, 0, -21340, 0, -32329, 0, -21339, 0, -32328, 0, -21338, 0, -32327, 0, -21337, 0, -32326, 0, -21333, 0, -32325, 0, -21331, 0, -32324, 0, -21330, 0, -32323, 0, -21327, 0, -32322, 0, -21326, 0, -32321, 0, -21325, 0, -32320, 0, -21324, 0, -32319, 0, -21323, 0, -32318, 0, -21322, 0, -32317, 0, -21321, 0, -32316, 0, -21318, 0, -32315, 0, -21314, 0, -32314, 0, -21313, 0, -32313, 0, -21312, 0, -32312, 0, -21310, 0, -32311, 0, -21309, 0, -32310, 0, -21307, 0, -32309, 0, -21306, 0, -32308, 0, -21305, 0, -32307, 0, -21303, 0, -32306, 0, -21302, 0, -32305, 0, -21301, 0, -32304, 0, -21299, 0, -32303, 0, -21298, 0, -32302, 0, -21297, 0, -32301, 0, -21296, 0, -32300, 0, -21295, 0, -32299, 0, -21294, 0, -32298, 0, -21293, 0, -32297, 0, -21292, 0, -32296, 0, -21290, 0, -32295, 0, -21288, 0, -32294, 0, -21287, 0, -32293, 0, -21286, 0, -32292, 0, -21285, 0, -32291, 0, -21284, 0, -32290, 0, -21283, 0, -32289, 0, -21282, 0, -32288, 0, -21281, 0, -32287, 0, -21278, 0, -32286, 0, -21277, 0, -32285, 0, -21275, 0, -32284, 0, -21274, 0, -32283, 0, -21271, 0, -32282, 0, -21269, 0, -32281, 0, -21267, 0, -32280, 0, -21266, 0, -32279, 0, -21262, 0, -32278, 0, -21260, 0, -32277, 0, -21257, 0, -32276, 0, -21256, 0, -32275, 0, -21255, 0, -32274, 0, -21254, 0, -32273, 0, -21253, 0, -32272, 0, -21250, 0, -32271, 0, -21249, 0, -32270, 0, -21247, 0, -32269, 0, -21246, 0, -32268, 0, -21245, 0, -32267, 0, -21243, 0, -32266, 0, -21241, 0, -32265, 0, -21240, 0, -32264, 0, -21239, 0, -32263, 0, -21238, 0, -32262, 0, -21237, 0, -32261, 0, -21234, 0, -32260, 0, -21232, 0, -32259, 0, -21230, 0, -32258, 0, -21229, 0, -32191, 0, -21228, 0, -32190, 0, -21227, 0, -32189, 0, -21226, 0, -32188, 0, -21225, 0, -32187, 0, -21223, 0, -32186, 0, -21222, 0, -32185, 0, -21221, 0, -32184, 0, -21219, 0, -32183, 0, -21218, 0, -32182, 0, -21217, 0, -32181, 0, -21215, 0, -32180, 0, -21214, 0, -32179, 0, -21213, 0, -32178, 0, -21212, 0, -32177, 0, -21211, 0, -32176, 0, -21210, 0, -32175, 0, -21209, 0, -32174, 0, -21208, 0, -32173, 0, -21206, 0, -32172, 0, -21205, 0, -32171, 0, -21202, 0, -32170, 0, -21201, 0, -32169, 0, -21200, 0, -32168, 0, -21199, 0, -32167, 0, -21198, 0, -32166, 0, -21197, 0, -32159, 0, -21194, 0, -32158, 0, -21193, 0, -32157, 0, -21191, 0, -32156, 0, -21190, 0, -32155, 0, -21189, 0, -32154, 0, -21187, 0, -32153, 0, -21186, 0, -32152, 0, -21185, 0, -32151, 0, -21184, 0, -32150, 0, -21183, 0, -32149, 0, -21182, 0, -32148, 0, -21181, 0, -32147, 0, -21178, 0, -32146, 0, -21176, 0, -32145, 0, -21174, 0, -32144, 0, -21173, 0, -32143, 0, -21172, 0, -32142, 0, -21171, 0, -32141, 0, -21170, 0, -32140, 0, -21169, 0, -32139, 0, -21167, 0, -32138, 0, -21166, 0, -32137, 0, -21165, 0, -32136, 0, -21163, 0, -32135, 0, -21162, 0, -32134, 0, -21161, 0, -32127, 0, -21159, 0, -32126, 0, -21158, 0, -32125, 0, -21157, 0, -32124, 0, -21156, 0, -32123, 0, -21155, 0, -32122, 0, -21154, 0, -32121, 0, -21153, 0, -32120, 0, -21152, 0, -32119, 0, -21150, 0, -32118, 0, -21148, 0, -32117, 0, -21147, 0, -32116, 0, -21146, 0, -32115, 0, -21145, 0, -32114, 0, -21144, 0, -32113, 0, -21143, 0, -32112, 0, -21142, 0, -32111, 0, -21141, 0, -32110, 0, -21138, 0, -32109, 0, -21137, 0, -32108, 0, -21135, 0, -32107, 0, -21134, 0, -32106, 0, -21129, 0, -32105, 0, -21128, 0, -32104, 0, -21127, 0, -32103, 0, -21126, 0, -32102, 0, -21122, 0, -32101, 0, -21120, 0, -32100, 0, -21117, 0, -32099, 0, -21116, 0, -32098, 0, -21115, 0, -32097, 0, -21114, 0, -32096, 0, -21113, 0, -32095, 0, -21110, 0, -32094, 0, -21109, 0, -32093, 0, -21107, 0, -32092, 0, -21106, 0, -32091, 0, -21105, 0, -32090, 0, -21103, 0, -32089, 0, -21102, 0, -32088, 0, -21101, 0, -32087, 0, -21100, 0, -32086, 0, -21099, 0, -32085, 0, -21098, 0, -32084, 0, -21097, 0, -32083, 0, -21096, 0, -32082, 0, -21095, 0, -32081, 0, -21094, 0, -32080, 0, -21093, 0, -32079, 0, -21090, 0, -32078, 0, -21089, 0, -32077, 0, -21088, 0, -32076, 0, -21087, 0, -32075, 0, -21086, 0, -32074, 0, -21085, 0, -32073, 0, -21083, 0, -32072, 0, -21082, 0, -32071, 0, -21081, 0, -32070, 0, -21080, 0, -32069, 0, -21079, 0, -32068, 0, -21078, 0, -32067, 0, -21077, 0, -32066, 0, -21076, 0, -32065, 0, -21075, 0, -32064, 0, -21074, 0, -32063, 0, -21073, 0, -32062, 0, -21072, 0, -32061, 0, -21071, 0, -32060, 0, -21070, 0, -32059, 0, -21069, 0, -32058, 0, -21068, 0, -32057, 0, -21067, 0, -32056, 0, -21066, 0, -32055, 0, -21064, 0, -32054, 0, -21063, 0, -32053, 0, -21062, 0, -32052, 0, -21061, 0, -32051, 0, -21060, 0, -32050, 0, -21059, 0, -32049, 0, -21058, 0, -32048, 0, -21057, 0, -32047, 0, -21054, 0, -32046, 0, -21053, 0, -32045, 0, -21051, 0, -32044, 0, -21050, 0, -32043, 0, -21049, 0, -32042, 0, -21047, 0, -32041, 0, -21046, 0, -32040, 0, -21045, 0, -32039, 0, -21044, 0, -32038, 0, -21043, 0, -32037, 0, -21042, 0, -32036, 0, -21041, 0, -32035, 0, -21038, 0, -32034, 0, -21036, 0, -32033, 0, -21035, 0, -32032, 0, -21034, 0, -32031, 0, -21033, 0, -32030, 0, -21032, 0, -32029, 0, -21031, 0, -32028, 0, -21030, 0, -32027, 0, -21029, 0, -32026, 0, -21027, 0, -32025, 0, -21026, 0, -32024, 0, -21025, 0, -32023, 0, -21023, 0, -32022, 0, -21022, 0, -32021, 0, -21021, 0, -32020, 0, -21019, 0, -32019, 0, -21018, 0, -32018, 0, -21017, 0, -32017, 0, -21016, 0, -32016, 0, -21015, 0, -32015, 0, -21014, 0, -32014, 0, -21013, 0, -32013, 0, -21012, 0, -32012, 0, -21011, 0, -32011, 0, -21010, 0, -32010, 0, -21009, 0, -32009, 0, -21008, 0, -32008, 0, -21007, 0, -32007, 0, -21006, 0, -32006, 0, -21005, 0, -32005, 0, -21004, 0, -32004, 0, -21003, 0, -32003, 0, -21002, 0, -32002, 0, -21001, 0, -31935, 0, -20998, 0, -31934, 0, -20997, 0, -31933, 0, -20995, 0, -31932, 0, -20994, 0, -31931, 0, -20990, 0, -31930, 0, -20989, 0, -31929, 0, -20988, 0, -31928, 0, -20987, 0, -31927, 0, -20986, 0, -31926, 0, -20985, 0, -31925, 0, -20982, 0, -31924, 0, -20980, 0, -31923, 0, -20978, 0, -31922, 0, -20977, 0, -31921, 0, -20976, 0, -31920, 0, -20975, 0, -31919, 0, -20974, 0, -31918, 0, -20973, 0, -31917, 0, -20971, 0, -31916, 0, -20970, 0, -31915, 0, -20969, 0, -31914, 0, -20968, 0, -31913, 0, -20967, 0, -31912, 0, -20966, 0, -31911, 0, -20965, 0, -31910, 0, -20964, 0, -31903, 0, -20963, 0, -31902, 0, -20962, 0, -31901, 0, -20961, 0, -31900, 0, -20960, 0, -31899, 0, -20959, 0, -31898, 0, -20958, 0, -31897, 0, -20957, 0, -31896, 0, -20956, 0, -31895, 0, -20955, 0, -31894, 0, -20954, 0, -31893, 0, -20953, 0, -31892, 0, -20952, 0, -31891, 0, -20951, 0, -31890, 0, -20950, 0, -31889, 0, -20949, 0, -31888, 0, -20948, 0, -31887, 0, -20947, 0, -31886, 0, -20946, 0, -31885, 0, -20945, 0, -31884, 0, -20942, 0, -31883, 0, -20941, 0, -31882, 0, -20939, 0, -31881, 0, -20938, 0, -31880, 0, -20935, 0, -31879, 0, -20933, 0, -31878, 0, -20932, 0, -31871, 0, -20931, 0, -31870, 0, -20930, 0, -31869, 0, -20929, 0, -31868, 0, -20926, 0, -31867, 0, -20924, 0, -31866, 0, -20921, 0, -31865, 0, -20920, 0, -31864, 0, -20919, 0, -31863, 0, -20917, 0, -31862, 0, -20913, 0, -31861, 0, -20911, 0, -31860, 0, -20910, 0, -31859, 0, -20909, 0, -31858, 0, -20907, 0, -31857, 0, -20905, 0, -31856, 0, -20904, 0, -31855, 0, -20903, 0, -31854, 0, -20902, 0, -31853, 0, -20901, 0, -31852, 0, -20898, 0, -31851, 0, -20894, 0, -31850, 0, -20893, 0, -31849, 0, -20892, 0, -31848, 0, -20890, 0, -31847, 0, -20889, 0, -31846, 0, -20886, 0, -31845, 0, -20885, 0, -31844, 0, -20883, 0, -31843, 0, -20882, 0, -31842, 0, -20881, 0, -31841, 0, -20879, 0, -31840, 0, -20878, 0, -31839, 0, -20877, 0, -31838, 0, -20876, 0, -31837, 0, -20875, 0, -31836, 0, -20874, 0, -31835, 0, -20873, 0, -31834, 0, -20870, 0, -31833, 0, -20866, 0, -31832, 0, -20865, 0, -31831, 0, -20864, 0, -31830, 0, -20863, 0, -31829, 0, -20862, 0, -31828, 0, -20861, 0, -31827, 0, -20858, 0, -31826, 0, -20857, 0, -31825, 0, -20856, 0, -31824, 0, -20855, 0, -31823, 0, -20854, 0, -31822, 0, -20853, 0, -31821, 0, -20851, 0, -31820, 0, -20850, 0, -31819, 0, -20849, 0, -31818, 0, -20848, 0, -31817, 0, -20847, 0, -31816, 0, -20846, 0, -31815, 0, -20845, 0, -31814, 0, -20844, 0, -31813, 0, -20843, 0, -31812, 0, -20842, 0, -31811, 0, -20841, 0, -31810, 0, -20840, 0, -31809, 0, -20839, 0, -31808, 0, -20838, 0, -31807, 0, -20837, 0, -31806, 0, -20836, 0, -31805, 0, -20835, 0, -31804, 0, -20834, 0, -31803, 0, -20833, 0, -31802, 0, -20832, 0, -31801, 0, -20831, 0, -31800, 0, -20830, 0, -31799, 0, -20829, 0, -31798, 0, -20828, 0, -31797, 0, -20827, 0, -31796, 0, -20826, 0, -31795, 0, -20825, 0, -31794, 0, -20824, 0, -31793, 0, -20823, 0, -31792, 0, -20822, 0, -31791, 0, -20821, 0, -31790, 0, -20820, 0, -31789, 0, -20819, 0, -31788, 0, -20818, 0, -31787, 0, -20817, 0, -31786, 0, -20816, 0, -31785, 0, -20815, 0, -31784, 0, -20814, 0, -31783, 0, -20813, 0, -31782, 0, -20812, 0, -31781, 0, -20811, 0, -31780, 0, -20810, 0, -31779, 0, -20809, 0, -31778, 0, -20808, 0, -31777, 0, -20807, 0, -31776, 0, -20806, 0, -31775, 0, -20805, 0, -31774, 0, -20801, 0, -31773, 0, -20799, 0, -31772, 0, -20798, 0, -31771, 0, -20797, 0, -31770, 0, -20795, 0, -31769, 0, -20794, 0, -31768, 0, -20793, 0, -31767, 0, -20792, 0, -31766, 0, -20791, 0, -31765, 0, -20790, 0, -31764, 0, -20789, 0, -31763, 0, -20786, 0, -31762, 0, -20782, 0, -31761, 0, -20781, 0, -31760, 0, -20780, 0, -31759, 0, -20779, 0, -31758, 0, -20778, 0, -31757, 0, -20777, 0, -31756, 0, -20774, 0, -31755, 0, -20773, 0, -31754, 0, -20771, 0, -31753, 0, -20770, 0, -31752, 0, -20769, 0, -31751, 0, -20768, 0, -31750, 0, -20767, 0, -31749, 0, -20766, 0, -31748, 0, -20765, 0, -31747, 0, -20764, 0, -31746, 0, -20763, 0, -31679, 0, -20762, 0, -31678, 0, -20761, 0, -31677, 0, -20759, 0, -31676, 0, -20758, 0, -31675, 0, -20756, 0, -31674, 0, -20754, 0, -31673, 0, -20753, 0, -31672, 0, -20752, 0, -31671, 0, -20751, 0, -31670, 0, -20750, 0, -31669, 0, -20749, 0, -31668, 0, -20747, 0, -31667, 0, -20746, 0, -31666, 0, -20745, 0, -31665, 0, -20743, 0, -31664, 0, -20742, 0, -31663, 0, -20741, 0, -31662, 0, -20739, 0, -31661, 0, -20738, 0, -31660, 0, -20737, 0, -31659, 0, -20736, 0, -31658, 0, -20735, 0, -31657, 0, -20734, 0, -31656, 0, -20733, 0, -31655, 0, -20732, 0, -31654, 0, -20731, 0, -31647, 0, -20730, 0, -31646, 0, -20727, 0, -31645, 0, -20726, 0, -31644, 0, -20725, 0, -31643, 0, -20724, 0, -31642, 0, -20722, 0, -31641, 0, -20721, 0, -31640, 0, -20719, 0, -31639, 0, -20718, 0, -31638, 0, -20717, 0, -31637, 0, -20716, 0, -31636, 0, -20715, 0, -31635, 0, -20714, 0, -31634, 0, -20713, 0, -31633, 0, -20712, 0, -31632, 0, -20711, 0, -31631, 0, -20710, 0, -31630, 0, -20709, 0, -31629, 0, -20708, 0, -31628, 0, -20707, 0, -31627, 0, -20706, 0, -31626, 0, -20705, 0, -31625, 0, -20704, 0, -31624, 0, -20703, 0, -31623, 0, -20702, 0, -31622, 0, -20701, 0, -31615, 0, -20700, 0, -31614, 0, -20699, 0, -31613, 0, -20698, 0, -31612, 0, -20697, 0, -31611, 0, -20696, 0, -31610, 0, -20695, 0, -31609, 0, -20694, 0, -31608, 0, -20693, 0, -31607, 0, -20690, 0, -31606, 0, -20689, 0, -31605, 0, -20687, 0, -31604, 0, -20685, 0, -31603, 0, -20683, 0, -31602, 0, -20682, 0, -31601, 0, -20681, 0, -31600, 0, -20680, 0, -31599, 0, -20679, 0, -31598, 0, -20678, 0, -31597, 0, -20677, 0, -31596, 0, -20674, 0, -31595, 0, -20672, 0, -31594, 0, -20668, 0, -31593, 0, -20667, 0, -31592, 0, -20666, 0, -31591, 0, -20665, 0, -31590, 0, -20662, 0, -31589, 0, -20661, 0, -31588, 0, -20660, 0, -31587, 0, -20659, 0, -31586, 0, -20658, 0, -31585, 0, -20657, 0, -31584, 0, -20655, 0, -31583, 0, -20654, 0, -31582, 0, -20653, 0, -31581, 0, -20652, 0, -31580, 0, -20651, 0, -31579, 0, -20650, 0, -31578, 0, -20649, 0, -31577, 0, -20648, 0, -31576, 0, -20647, 0, -31575, 0, -20646, 0, -31574, 0, -20645, 0, -31573, 0, -20642, 0, -31572, 0, -20641, 0, -31571, 0, -20640, 0, -31570, 0, -20639, 0, -31569, 0, -20638, 0, -31568, 0, -20637, 0, -31567, 0, -20634, 0, -31566, 0, -20633, 0, -31565, 0, -20632, 0, -31564, 0, -20631, 0, -31563, 0, -20630, 0, -31562, 0, -20629, 0, -31561, 0, -20628, 0, -31560, 0, -20627, 0, -31559, 0, -20626, 0, -31558, 0, -20625, 0, -31557, 0, -20624, 0, -31556, 0, -20623, 0, -31555, 0, -20622, 0, -31554, 0, -20621, 0, -31553, 0, -20620, 0, -31552, 0, -20619, 0, -31551, 0, -20618, 0, -31550, 0, -20617, 0, -31549, 0, -20616, 0, -31548, 0, -20614, 0, -31547, 0, -20613, 0, -31546, 0, -20612, 0, -31545, 0, -20611, 0, -31544, 0, -20610, 0, -31543, 0, -20609, 0, -31542, 0, -20607, 0, -31541, 0, -20606, 0, -31540, 0, -20605, 0, -31539, 0, -20603, 0, -31538, 0, -20602, 0, -31537, 0, -20601, 0, -31536, 0, -20599, 0, -31535, 0, -20598, 0, -31534, 0, -20597, 0, -31533, 0, -20596, 0, -31532, 0, -20595, 0, -31531, 0, -20594, 0, -31530, 0, -20593, 0, -31529, 0, -20590, 0, -31528, 0, -20589, 0, -31527, 0, -20588, 0, -31526, 0, -20586, 0, -31525, 0, -20585, 0, -31524, 0, -20584, 0, -31523, 0, -20583, 0, -31522, 0, -20582, 0, -31521, 0, -20581, 0, -31520, 0, -20579, 0, -31519, 0, -20578, 0, -31518, 0, -20577, 0, -31517, 0, -20576, 0, -31516, 0, -20575, 0, -31515, 0, -20574, 0, -31514, 0, -20573, 0, -31513, 0, -20572, 0, -31512, 0, -20571, 0, -31511, 0, -20570, 0, -31510, 0, -20569, 0, -31509, 0, -20568, 0, -31508, 0, -20567, 0, -31507, 0, -20566, 0, -31506, 0, -20565, 0, -31505, 0, -20564, 0, -31504, 0, -20563, 0, -31503, 0, -20562, 0, -31502, 0, -20561, 0, -31501, 0, -20560, 0, -31500, 0, -20559, 0, -31499, 0, -20558, 0, -31498, 0, -20557, 0, -31497, 0, -20556, 0, -31496, 0, -20555, 0, -31495, 0, -20554, 0, -31494, 0, -20553, 0, -31493, 0, -20550, 0, -31492, 0, -20549, 0, -31491, 0, -20547, 0, -31490, 0, -20546, 0, -31423, 0, -20545, 0, -31422, 0, -20543, 0, -31421, 0, -20542, 0, -31420, 0, -20541, 0, -31419, 0, -20540, 0, -31418, 0, -20539, 0, -31417, 0, -20538, 0, -31416, 0, -20534, 0, -31415, 0, -20532, 0, -31414, 0, -20529, 0, -31413, 0, -20528, 0, -31412, 0, -20527, 0, -31411, 0, -20526, 0, -31410, 0, -20525, 0, -31409, 0, -20523, 0, -31408, 0, -20522, 0, -31407, 0, -20521, 0, -31406, 0, -20520, 0, -31405, 0, -20519, 0, -31404, 0, -20518, 0, -31403, 0, -20517, 0, -31402, 0, -20515, 0, -31401, 0, -20514, 0, -31400, 0, -20513, 0, -31399, 0, -20512, 0, -31398, 0, -20511, 0, -31391, 0, -20510, 0, -31390, 0, -20509, 0, -31389, 0, -20508, 0, -31388, 0, -20507, 0, -31387, 0, -20506, 0, -31386, 0, -20505, 0, -31385, 0, -20502, 0, -31384, 0, -20501, 0, -31383, 0, -20500, 0, -31382, 0, -20499, 0, -31381, 0, -20498, 0, -31380, 0, -20497, 0, -31379, 0, -20494, 0, -31378, 0, -20493, 0, -31377, 0, -20491, 0, -31376, 0, -20490, 0, -31375, 0, -20489, 0, -31374, 0, -20487, 0, -31373, 0, -20486, 0, -31372, 0, -20485, 0, -31371, 0, -20484, 0, -31370, 0, -20483, 0, -31369, 0, -20482, 0, -31368, 0, -20481, 0, -31367, 0, -20478, 0, -31366, 0, -20477, 0, -31359, 0, -20475, 0, -31358, 0, -20474, 0, -31357, 0, -20473, 0, -31356, 0, -20472, 0, -31355, 0, -20471, 0, -31354, 0, -20470, 0, -31353, 0, -20469, 0, -31352, 0, -20467, 0, -31351, 0, -20466, 0, -31350, 0, -20465, 0, -31349, 0, -20463, 0, -31348, 0, -20462, 0, -31347, 0, -20461, 0, -31346, 0, -20459, 0, -31345, 0, -20458, 0, -31344, 0, -20457, 0, -31343, 0, -20456, 0, -31342, 0, -20455, 0, -31341, 0, -20454, 0, -31340, 0, -20453, 0, -31339, 0, -20450, 0, -31338, 0, -20449, 0, -31337, 0, -20448, 0, -31336, 0, -20447, 0, -31335, 0, -20446, 0, -31334, 0, -20445, 0, -31333, 0, -20444, 0, -31332, 0, -20443, 0, -31331, 0, -20442, 0, -31330, 0, -20441, 0, -31329, 0, -20439, 0, -31328, 0, -20438, 0, -31327, 0, -20437, 0, -31326, 0, -20436, 0, -31325, 0, -20435, 0, -31324, 0, -20434, 0, -31323, 0, -20433, 0, -31322, 0, -20432, 0, -31321, 0, -20431, 0, -31320, 0, -20430, 0, -31319, 0, -20429, 0, -31318, 0, -20428, 0, -31317, 0, -20427, 0, -31316, 0, -20426, 0, -31315, 0, -20425, 0, -31314, 0, -20424, 0, -31313, 0, -20423, 0, -31312, 0, -20422, 0, -31311, 0, -20421, 0, -31310, 0, -20420, 0, -31309, 0, -20419, 0, -31308, 0, -20418, 0, -31307, 0, -20417, 0, -31306, 0, -20416, 0, -31305, 0, -20415, 0, -31304, 0, -20414, 0, -31303, 0, -20413, 0, -31302, 0, -20410, 0, -31301, 0, -20409, 0, -31300, 0, -20407, 0, -31299, 0, -20405, 0, -31298, 0, -20403, 0, -31297, 0, -20401, 0, -31296, 0, -20400, 0, -31295, 0, -20399, 0, -31294, 0, -20398, 0, -31293, 0, -20394, 0, -31292, 0, -20392, 0, -31291, 0, -20390, 0, -31290, 0, -20389, 0, -31289, 0, -20388, 0, -31288, 0, -20386, 0, -31287, 0, -20385, 0, -31286, 0, -20384, 0, -31285, 0, -20383, 0, -31284, 0, -20382, 0, -31283, 0, -20381, 0, -31282, 0, -20380, 0, -31281, 0, -20379, 0, -31280, 0, -20378, 0, -31279, 0, -20377, 0, -31278, 0, -20376, 0, -31277, 0, -20375, 0, -31276, 0, -20374, 0, -31275, 0, -20373, 0, -31274, 0, -20372, 0, -31273, 0, -20371, 0, -31272, 0, -20370, 0, -31271, 0, -20369, 0, -31270, 0, -20368, 0, -31269, 0, -20367, 0, -31268, 0, -20366, 0, -31267, 0, -20365, 0, -31266, 0, -20364, 0, -31265, 0, -20363, 0, -31264, 0, -20362, 0, -31263, 0, -20361, 0, -31262, 0, -20360, 0, -31261, 0, -20359, 0, -31260, 0, -20358, 0, -31259, 0, -20357, 0, -31258, 0, -20354, 0, -31257, 0, -20353, 0, -31256, 0, -20351, 0, -31255, 0, -20350, 0, -31254, 0, -20349, 0, -31253, 0, -20347, 0, -31252, 0, -20346, 0, -31251, 0, -20345, 0, -31250, 0, -20344, 0, -31249, 0, -20343, 0, -31248, 0, -20342, 0, -31247, 0, -20341, 0, -31246, 0, -20338, 0, -31245, 0, -20336, 0, -31244, 0, -20334, 0, -31243, 0, -20333, 0, -31242, 0, -20332, 0, -31241, 0, -20331, 0, -31240, 0, -20330, 0, -31239, 0, -20329, 0, -31238, 0, -20325, 0, -31237, 0, -20323, 0, -31236, 0, -20322, 0, -31235, 0, -20317, 0, -31234, 0, -20316, 0, -31167, 0, -20315, 0, -31166, 0, -20314, 0, -31165, 0, -20313, 0, -31164, 0, -20310, 0, -31163, 0, -20304, 0, -31162, 0, -20302, 0, -31161, 0, -20298, 0, -31160, 0, -20297, 0, -31159, 0, -20295, 0, -31158, 0, -20294, 0, -31157, 0, -20293, 0, -31156, 0, -20291, 0, -31155, 0, -20290, 0, -31154, 0, -20289, 0, -31153, 0, -20288, 0, -31152, 0, -20287, 0, -31151, 0, -20286, 0, -31150, 0, -20285, 0, -31149, 0, -20282, 0, -31148, 0, -20278, 0, -31147, 0, -20277, 0, -31146, 0, -20276, 0, -31145, 0, -20275, 0, -31144, 0, -20274, 0, -31143, 0, -20273, 0, -31142, 0, -20270, 0, -31135, 0, -20269, 0, -31134, 0, -20267, 0, -31133, 0, -20266, 0, -31132, 0, -20265, 0, -31131, 0, -20263, 0, -31130, 0, -20262, 0, -31129, 0, -20261, 0, -31128, 0, -20260, 0, -31127, 0, -20259, 0, -31126, 0, -20258, 0, -31125, 0, -20257, 0, -31124, 0, -20255, 0, -31123, 0, -20254, 0, -31122, 0, -20253, 0, -31121, 0, -20252, 0, -31120, 0, -20250, 0, -31119, 0, -20249, 0, -31118, 0, -20248, 0, -31117, 0, -20247, 0, -31116, 0, -20246, 0, -31115, 0, -20245, 0, -31114, 0, -20244, 0, -31113, 0, -20243, 0, -31112, 0, -20242, 0, -31111, 0, -20241, 0, -31110, 0, -20240, 0, -31103, 0, -20239, 0, -31102, 0, -20238, 0, -31101, 0, -20237, 0, -31100, 0, -20236, 0, -31099, 0, -20235, 0, -31098, 0, -20234, 0, -31097, 0, -20233, 0, -31096, 0, -20232, 0, -31095, 0, -20231, 0, -31094, 0, -20230, 0, -31093, 0, -20229, 0, -31092, 0, -20228, 0, -31091, 0, -20227, 0, -31090, 0, -20226, 0, -31089, 0, -20225, 0, -31088, 0, -20224, 0, -31087, 0, -20223, 0, -31086, 0, -20222, 0, -31085, 0, -20221, 0, -31084, 0, -20220, 0, -31083, 0, -20219, 0, -31082, 0, -20218, 0, -31081, 0, -20217, 0, -31080, 0, -20214, 0, -31079, 0, -20211, 0, -31078, 0, -20210, 0, -31077, 0, -20209, 0, -31076, 0, -20207, 0, -31075, 0, -20204, 0, -31074, 0, -20203, 0, -31073, 0, -20202, 0, -31072, 0, -20201, 0, -31071, 0, -20198, 0, -31070, 0, -20194, 0, -31069, 0, -20193, 0, -31068, 0, -20192, 0, -31067, 0, -20191, 0, -31066, 0, -20190, 0, -31065, 0, -20186, 0, -31064, 0, -20185, 0, -31063, 0, -20183, 0, -31062, 0, -20182, 0, -31061, 0, -20181, 0, -31060, 0, -20179, 0, -31059, 0, -20178, 0, -31058, 0, -20177, 0, -31057, 0, -20176, 0, -31056, 0, -20175, 0, -31055, 0, -20174, 0, -31054, 0, -20173, 0, -31053, 0, -20170, 0, -31052, 0, -20166, 0, -31051, 0, -20165, 0, -31050, 0, -20164, 0, -31049, 0, -20163, 0, -31048, 0, -20162, 0, -31047, 0, -20161, 0, -31046, 0, -20158, 0, -31045, 0, -20157, 0, -31044, 0, -20155, 0, -31043, 0, -20154, 0, -31042, 0, -20153, 0, -31041, 0, -20151, 0, -31040, 0, -20150, 0, -31039, 0, -20149, 0, -31038, 0, -20148, 0, -31037, 0, -20147, 0, -31036, 0, -20146, 0, -31035, 0, -20145, 0, -31034, 0, -20142, 0, -31033, 0, -20141, 0, -31032, 0, -20138, 0, -31031, 0, -20137, 0, -31030, 0, -20135, 0, -31029, 0, -20134, 0, -31028, 0, -20133, 0, -31027, 0, -20131, 0, -31026, 0, -20130, 0, -31025, 0, -20129, 0, -31024, 0, -20127, 0, -31023, 0, -20126, 0, -31022, 0, -20125, 0, -31021, 0, -20124, 0, -31020, 0, -20123, 0, -31019, 0, -20122, 0, -31018, 0, -20121, 0, -31017, 0, -20120, 0, -31016, 0, -20119, 0, -31015, 0, -20118, 0, -31014, 0, -20117, 0, -31013, 0, -20116, 0, -31012, 0, -20115, 0, -31011, 0, -20114, 0, -31010, 0, -20113, 0, -31009, 0, -20112, 0, -31008, 0, -20111, 0, -31007, 0, -20110, 0, -31006, 0, -20109, 0, -31005, 0, -20108, 0, -31004, 0, -20107, 0, -31003, 0, -20106, 0, -31002, 0, -20105, 0, -31001, 0, -20102, 0, -31000, 0, -20101, 0, -30999, 0, -20099, 0, -30998, 0, -20098, 0, -30997, 0, -20097, 0, -30996, 0, -20095, 0, -30995, 0, -20093, 0, -30994, 0, -20092, 0, -30993, 0, -20091, 0, -30992, 0, -20090, 0, -30991, 0, -20089, 0, -30990, 0, -20086, 0, -30989, 0, -20084, 0, -30988, 0, -20082, 0, -30987, 0, -20081, 0, -30986, 0, -20080, 0, -30985, 0, -20079, 0, -30984, 0, -20075, 0, -30983, 0, -20074, 0, -30982, 0, -20073, 0, -30981, 0, -20071, 0, -30980, 0, -20070, 0, -30979, 0, -20069, 0, -30978, 0, -20067, 0, -30911, 0, -20066, 0, -30910, 0, -20065, 0, -30909, 0, -20064, 0, -30908, 0, -20063, 0, -30907, 0, -20062, 0, -30906, 0, -20061, 0, -30905, 0, -20060, 0, -30904, 0, -20059, 0, -30903, 0, -20058, 0, -30902, 0, -20057, 0, -30901, 0, -20055, 0, -30900, 0, -20054, 0, -30899, 0, -20053, 0, -30898, 0, -20052, 0, -30897, 0, -20051, 0, -30896, 0, -20050, 0, -30895, 0, -20049, 0, -30894, 0, -20048, 0, -30893, 0, -20047, 0, -30892, 0, -20046, 0, -30891, 0, -20045, 0, -30890, 0, -20044, 0, -30889, 0, -20043, 0, -30888, 0, -20042, 0, -30887, 0, -20041, 0, -30886, 0, -20040, 0, -30879, 0, -20039, 0, -30878, 0, -20038, 0, -30877, 0, -20037, 0, -30876, 0, -20036, 0, -30875, 0, -20035, 0, -30874, 0, -20034, 0, -30873, 0, -20033, 0, -30872, 0, -20032, 0, -30871, 0, -20031, 0, -30870, 0, -20030, 0, -30869, 0, -20029, 0, -30868, 0, -20028, 0, -30867, 0, -20027, 0, -30866, 0, -20026, 0, -30865, 0, -20025, 0, -30864, 0, -20024, 0, -30863, 0, -20023, 0, -30862, 0, -20022, 0, -30861, 0, -20021, 0, -30860, 0, -20019, 0, -30859, 0, -20018, 0, -30858, 0, -20017, 0, -30857, 0, -20015, 0, -30856, 0, -20014, 0, -30855, 0, -20013, 0, -30854, 0, -20011, 0, -30847, 0, -20010, 0, -30846, 0, -20009, 0, -30845, 0, -20008, 0, -30844, 0, -20007, 0, -30843, 0, -20006, 0, -30842, 0, -20005, 0, -30841, 0, -20002, 0, -30840, 0, -20000, 0, -30839, 0, -19999, 0, -30838, 0, -19998, 0, -30837, 0, -19997, 0, -30836, 0, -19996, 0, -30835, 0, -19995, 0, -30834, 0, -19994, 0, -30833, 0, -19993, 0, -30832, 0, -19990, 0, -30831, 0, -19989, 0, -30830, 0, -19987, 0, -30829, 0, -19986, 0, -30828, 0, -19985, 0, -30827, 0, -19983, 0, -30826, 0, -19982, 0, -30825, 0, -19981, 0, -30824, 0, -19980, 0, -30823, 0, -19979, 0, -30822, 0, -19978, 0, -30821, 0, -19977, 0, -30820, 0, -19976, 0, -30819, 0, -19974, 0, -30818, 0, -19972, 0, -30817, 0, -19970, 0, -30816, 0, -19969, 0, -30815, 0, -19968, 0, -30814, 0, -19967, 0, -30813, 0, -19966, 0, -30812, 0, -19965, 0, -30811, 0, -19962, 0, -30810, 0, -19961, 0, -30809, 0, -19959, 0, -30808, 0, -19958, 0, -30807, 0, -19955, 0, -30806, 0, -19954, 0, -30805, 0, -19953, 0, -30804, 0, -19952, 0, -30803, 0, -19951, 0, -30802, 0, -19950, 0, -30801, 0, -19949, 0, -30800, 0, -19946, 0, -30799, 0, -19944, 0, -30798, 0, -19942, 0, -30797, 0, -19941, 0, -30796, 0, -19940, 0, -30795, 0, -19939, 0, -30794, 0, -19938, 0, -30793, 0, -19937, 0, -30792, 0, -19935, 0, -30791, 0, -19934, 0, -30790, 0, -19933, 0, -30789, 0, -19932, 0, -30788, 0, -19931, 0, -30787, 0, -19930, 0, -30786, 0, -19929, 0, -30785, 0, -19928, 0, -30784, 0, -19927, 0, -30783, 0, -19926, 0, -30782, 0, -19925, 0, -30781, 0, -19924, 0, -30780, 0, -19923, 0, -30779, 0, -19922, 0, -30778, 0, -19921, 0, -30777, 0, -19920, 0, -30776, 0, -19919, 0, -30775, 0, -19918, 0, -30774, 0, -19917, 0, -30773, 0, -19915, 0, -30772, 0, -19914, 0, -30771, 0, -19913, 0, -30770, 0, -19912, 0, -30769, 0, -19911, 0, -30768, 0, -19910, 0, -30767, 0, -19909, 0, -30766, 0, -19907, 0, -30765, 0, -19906, 0, -30764, 0, -19905, 0, -30763, 0, -19904, 0, -30762, 0, -19903, 0, -30761, 0, -19902, 0, -30760, 0, -19901, 0, -30759, 0, -19900, 0, -30758, 0, -19899, 0, -30757, 0, -19898, 0, -30756, 0, -19897, 0, -30755, 0, -19896, 0, -30754, 0, -19895, 0, -30753, 0, -19894, 0, -30752, 0, -19893, 0, -30751, 0, -19892, 0, -30750, 0, -19891, 0, -30749, 0, -19890, 0, -30748, 0, -19889, 0, -30747, 0, -19888, 0, -30746, 0, -19887, 0, -30745, 0, -19886, 0, -30744, 0, -19885, 0, -30743, 0, -19884, 0, -30742, 0, -19883, 0, -30741, 0, -19882, 0, -30740, 0, -19881, 0, -30739, 0, -19879, 0, -30738, 0, -19878, 0, -30737, 0, -19877, 0, -30736, 0, -19875, 0, -30735, 0, -19874, 0, -30734, 0, -19873, 0, -30733, 0, -19871, 0, -30732, 0, -19870, 0, -30731, 0, -19869, 0, -30730, 0, -19868, 0, -30729, 0, -19867, 0, -30728, 0, -19866, 0, -30727, 0, -19865, 0, -30726, 0, -19862, 0, -30725, 0, -19861, 0, -30724, 0, -19860, 0, -30723, 0, -19859, 0, -30722, 0, -19858, 0, -30655, 0, -19857, 0, -30654, 0, -19856, 0, -30653, 0, -19855, 0, -30652, 0, -19854, 0, -30651, 0, -19853, 0, -30650, 0, -19850, 0, -30649, 0, -19849, 0, -30648, 0, -19848, 0, -30647, 0, -19847, 0, -30646, 0, -19846, 0, -30645, 0, -19845, 0, -30644, 0, -19843, 0, -30643, 0, -19842, 0, -30642, 0, -19841, 0, -30641, 0, -19840, 0, -30640, 0, -19839, 0, -30639, 0, -19838, 0, -30638, 0, -19837, 0, -30637, 0, -19834, 0, -30636, 0, -19833, 0, -30635, 0, -19832, 0, -30634, 0, -19830, 0, -30633, 0, -19829, 0, -30632, 0, -19828, 0, -30631, 0, -19827, 0, -30630, 0, -19826, 0, -30623, 0, -19825, 0, -30622, 0, -19822, 0, -30621, 0, -19821, 0, -30620, 0, -19819, 0, -30619, 0, -19818, 0, -30618, 0, -19817, 0, -30617, 0, -19813, 0, -30616, 0, -19812, 0, -30615, 0, -19811, 0, -30614, 0, -19810, 0, -30613, 0, -19809, 0, -30612, 0, -19806, 0, -30611, 0, -19804, 0, -30610, 0, -19801, 0, -30609, 0, -19800, 0, -30608, 0, -19799, 0, -30607, 0, -19797, 0, -30606, 0, -19795, 0, -30605, 0, -19794, 0, -30604, 0, -19793, 0, -30603, 0, -19791, 0, -30602, 0, -19790, 0, -30601, 0, -19789, 0, -30600, 0, -19787, 0, -30599, 0, -19786, 0, -30598, 0, -19785, 0, -30591, 0, -19784, 0, -30590, 0, -19783, 0, -30589, 0, -19782, 0, -30588, 0, -19781, 0, -30587, 0, -19780, 0, -30586, 0, -19779, 0, -30585, 0, -19778, 0, -30584, 0, -19777, 0, -30583, 0, -19776, 0, -30582, 0, -19775, 0, -30581, 0, -19774, 0, -30580, 0, -19773, 0, -30579, 0, -19772, 0, -30578, 0, -19771, 0, -30577, 0, -19770, 0, -30576, 0, -19769, 0, -30575, 0, -19766, 0, -30574, 0, -19765, 0, -30573, 0, -19763, 0, -30572, 0, -19762, 0, -30571, 0, -19761, 0, -30570, 0, -19759, 0, -30569, 0, -19757, 0, -30568, 0, -19756, 0, -30567, 0, -19755, 0, -30566, 0, -19754, 0, -30565, 0, -19753, 0, -30564, 0, -19750, 0, -30563, 0, -19748, 0, -30562, 0, -19746, 0, -30561, 0, -19745, 0, -30560, 0, -19744, 0, -30559, 0, -19743, 0, -30558, 0, -19741, 0, -30557, 0, -19737, 0, -30556, 0, -19735, 0, -30555, 0, -19734, 0, -30554, 0, -19728, 0, -30553, 0, -19727, 0, -30552, 0, -19726, 0, -30551, 0, -19722, 0, -30550, 0, -19716, 0, -30549, 0, -19715, 0, -30548, 0, -19714, 0, -30547, 0, -19710, 0, -30546, 0, -19709, 0, -30545, 0, -19707, 0, -30544, 0, -19706, 0, -30543, 0, -19705, 0, -30542, 0, -19703, 0, -30541, 0, -19702, 0, -30540, 0, -19701, 0, -30539, 0, -19700, 0, -30538, 0, -19699, 0, -30537, 0, -19698, 0, -30536, 0, -19697, 0, -30535, 0, -19694, 0, -30534, 0, -19690, 0, -30533, 0, -19689, 0, -30532, 0, -19688, 0, -30531, 0, -19687, 0, -30530, 0, -19686, 0, -30529, 0, -19685, 0, -30528, 0, -19683, 0, -30527, 0, -19682, 0, -30526, 0, -19681, 0, -30525, 0, -19680, 0, -30524, 0, -19679, 0, -30523, 0, -19678, 0, -30522, 0, -19677, 0, -30521, 0, -19676, 0, -30520, 0, -19675, 0, -30519, 0, -19674, 0, -30518, 0, -19673, 0, -30517, 0, -19672, 0, -30516, 0, -19671, 0, -30515, 0, -19670, 0, -30514, 0, -19669, 0, -30513, 0, -19668, 0, -30512, 0, -19667, 0, -30511, 0, -19666, 0, -30510, 0, -19665, 0, -30509, 0, -19664, 0, -30508, 0, -19663, 0, -30507, 0, -19662, 0, -30506, 0, -19661, 0, -30505, 0, -19660, 0, -30504, 0, -19659, 0, -30503, 0, -19658, 0, -30502, 0, -19657, 0, -30501, 0, -19656, 0, -30500, 0, -19655, 0, -30499, 0, -19654, 0, -30498, 0, -19653, 0, -30497, 0, -19652, 0, -30496, 0, -19651, 0, -30495, 0, -19650, 0, -30494, 0, -19649, 0, -30493, 0, -19648, 0, -30492, 0, -19647, 0, -30491, 0, -19646, 0, -30490, 0, -19645, 0, -30489, 0, -19644, 0, -30488, 0, -19643, 0, -30487, 0, -19642, 0, -30486, 0, -19641, 0, -30485, 0, -19640, 0, -30484, 0, -19639, 0, -30483, 0, -19638, 0, -30482, 0, -19637, 0, -30481, 0, -19636, 0, -30480, 0, -19635, 0, -30479, 0, -19634, 0, -30478, 0, -19633, 0, -30477, 0, -19632, 0, -30476, 0, -19631, 0, -30475, 0, -19630, 0, -30474, 0, -19629, 0, -30473, 0, -19625, 0, -30472, 0, -19623, 0, -30471, 0, -19622, 0, -30470, 0, -19619, 0, -30469, 0, -19616, 0, -30468, 0, -19615, 0, -30467, 0, -19614, 0, -30466, 0, -19613, 0, -30399, 0, -19610, 0, -30398, 0, -19608, 0, -30397, 0, -19606, 0, -30396, 0, -19604, 0, -30395, 0, -19603, 0, -30394, 0, -19601, 0, -30393, 0, -19598, 0, -30392, 0, -19597, 0, -30391, 0, -19595, 0, -30390, 0, -19594, 0, -30389, 0, -19593, 0, -30388, 0, -19591, 0, -30387, 0, -19590, 0, -30386, 0, -19589, 0, -30385, 0, -19588, 0, -30384, 0, -19587, 0, -30383, 0, -19586, 0, -30382, 0, -19585, 0, -30381, 0, -19582, 0, -30380, 0, -19578, 0, -30379, 0, -19577, 0, -30378, 0, -19576, 0, -30377, 0, -19575, 0, -30376, 0, -19574, 0, -30375, 0, -19573, 0, -30374, 0, -19571, 0, -30367, 0, -19570, 0, -30366, 0, -19569, 0, -30365, 0, -19567, 0, -30364, 0, -19566, 0, -30363, 0, -19565, 0, -30362, 0, -19563, 0, -30361, 0, -19562, 0, -30360, 0, -19561, 0, -30359, 0, -19560, 0, -30358, 0, -19559, 0, -30357, 0, -19558, 0, -30356, 0, -19557, 0, -30355, 0, -19556, 0, -30354, 0, -19555, 0, -30353, 0, -19554, 0, -30352, 0, -19553, 0, -30351, 0, -19550, 0, -30350, 0, -19549, 0, -30349, 0, -19548, 0, -30348, 0, -19547, 0, -30347, 0, -19546, 0, -30346, 0, -19545, 0, -30345, 0, -19543, 0, -30344, 0, -19542, 0, -30343, 0, -19541, 0, -30342, 0, -19539, 0, -30335, 0, -19538, 0, -30334, 0, -19537, 0, -30333, 0, -19536, 0, -30332, 0, -19535, 0, -30331, 0, -19534, 0, -30330, 0, -19533, 0, -30329, 0, -19532, 0, -30328, 0, -19531, 0, -30327, 0, -19530, 0, -30326, 0, -19529, 0, -30325, 0, -19528, 0, -30324, 0, -19527, 0, -30323, 0, -19526, 0, -30322, 0, -19525, 0, -30321, 0, -19524, 0, -30320, 0, -19523, 0, -30319, 0, -19522, 0, -30318, 0, -19521, 0, -30317, 0, -19520, 0, -30316, 0, -19519, 0, -30315, 0, -19518, 0, -30314, 0, -19517, 0, -30313, 0, -19514, 0, -30312, 0, -19513, 0, -30311, 0, -19511, 0, -30310, 0, -19510, 0, -30309, 0, -19507, 0, -30308, 0, -19505, 0, -30307, 0, -19503, 0, -30306, 0, -19502, 0, -30305, 0, -19501, 0, -30304, 0, -19498, 0, -30303, 0, -19496, 0, -30302, 0, -19494, 0, -30301, 0, -19492, 0, -30300, 0, -19490, 0, -30299, 0, -19489, 0, -30298, 0, -19487, 0, -30297, 0, -19486, 0, -30296, 0, -19485, 0, -30295, 0, -19483, 0, -30294, 0, -19482, 0, -30293, 0, -19481, 0, -30292, 0, -19479, 0, -30291, 0, -19478, 0, -30290, 0, -19477, 0, -30289, 0, -19476, 0, -30288, 0, -19475, 0, -30287, 0, -19474, 0, -30286, 0, -19473, 0, -30285, 0, -19472, 0, -30284, 0, -19471, 0, -30283, 0, -19470, 0, -30282, 0, -19469, 0, -30281, 0, -19468, 0, -30280, 0, -19467, 0, -30279, 0, -19466, 0, -30278, 0, -19465, 0, -30277, 0, -19464, 0, -30276, 0, -19463, 0, -30275, 0, -19462, 0, -30274, 0, -19461, 0, -30273, 0, -19459, 0, -30272, 0, -19458, 0, -30271, 0, -19457, 0, -30270, 0, -19456, 0, -30269, 0, -19455, 0, -30268, 0, -19454, 0, -30267, 0, -19453, 0, -30266, 0, -19452, 0, -30265, 0, -19451, 0, -30264, 0, -19450, 0, -30263, 0, -19449, 0, -30262, 0, -19448, 0, -30261, 0, -19447, 0, -30260, 0, -19446, 0, -30259, 0, -19445, 0, -30258, 0, -19444, 0, -30257, 0, -19443, 0, -30256, 0, -19442, 0, -30255, 0, -19441, 0, -30254, 0, -19439, 0, -30253, 0, -19438, 0, -30252, 0, -19437, 0, -30251, 0, -19436, 0, -30250, 0, -19435, 0, -30249, 0, -19434, 0, -30248, 0, -19433, 0, -30247, 0, -19431, 0, -30246, 0, -19430, 0, -30245, 0, -19429, 0, -30244, 0, -19427, 0, -30243, 0, -19426, 0, -30242, 0, -19425, 0, -30241, 0, -19423, 0, -30240, 0, -19422, 0, -30239, 0, -19421, 0, -30238, 0, -19420, 0, -30237, 0, -19419, 0, -30236, 0, -19418, 0, -30235, 0, -19417, 0, -30234, 0, -19414, 0, -30233, 0, -19412, 0, -30232, 0, -19411, 0, -30231, 0, -19410, 0, -30230, 0, -19409, 0, -30229, 0, -19408, 0, -30228, 0, -19407, 0, -30227, 0, -19406, 0, -30226, 0, -19405, 0, -30225, 0, -19403, 0, -30224, 0, -19402, 0, -30223, 0, -19401, 0, -30222, 0, -19400, 0, -30221, 0, -19399, 0, -30220, 0, -19398, 0, -30219, 0, -19397, 0, -30218, 0, -19396, 0, -30217, 0, -19395, 0, -30216, 0, -19394, 0, -30215, 0, -19393, 0, -30214, 0, -19392, 0, -30213, 0, -19391, 0, -30212, 0, -19390, 0, -30211, 0, -19389, 0, -30210, 0, -19388, 0, -30143, 0, -19387, 0, -30142, 0, -19386, 0, -30141, 0, -19385, 0, -30140, 0, -19384, 0, -30139, 0, -19383, 0, -30138, 0, -19382, 0, -30137, 0, -19381, 0, -30136, 0, -19380, 0, -30135, 0, -19379, 0, -30134, 0, -19378, 0, -30133, 0, -19377, 0, -30132, 0, -19374, 0, -30131, 0, -19373, 0, -30130, 0, -19371, 0, -30129, 0, -19370, 0, -30128, 0, -19369, 0, -30127, 0, -19367, 0, -30126, 0, -19366, 0, -30125, 0, -19365, 0, -30124, 0, -19364, 0, -30123, 0, -19363, 0, -30122, 0, -19362, 0, -30121, 0, -19361, 0, -30120, 0, -19358, 0, -30119, 0, -19356, 0, -30118, 0, -19354, 0, -30111, 0, -19353, 0, -30110, 0, -19352, 0, -30109, 0, -19351, 0, -30108, 0, -19350, 0, -30107, 0, -19349, 0, -30106, 0, -19347, 0, -30105, 0, -19346, 0, -30104, 0, -19345, 0, -30103, 0, -19344, 0, -30102, 0, -19343, 0, -30101, 0, -19342, 0, -30100, 0, -19341, 0, -30099, 0, -19340, 0, -30098, 0, -19339, 0, -30097, 0, -19338, 0, -30096, 0, -19337, 0, -30095, 0, -19336, 0, -30094, 0, -19335, 0, -30093, 0, -19334, 0, -30092, 0, -19333, 0, -30091, 0, -19332, 0, -30090, 0, -19331, 0, -30089, 0, -19330, 0, -30088, 0, -19329, 0, -30087, 0, -19327, 0, -30086, 0, -19326, 0, -30079, 0, -19325, 0, -30078, 0, -19324, 0, -30077, 0, -19323, 0, -30076, 0, -19322, 0, -30075, 0, -19321, 0, -30074, 0, -19319, 0, -30073, 0, -19318, 0, -30072, 0, -19317, 0, -30071, 0, -19316, 0, -30070, 0, -19315, 0, -30069, 0, -19314, 0, -30068, 0, -19313, 0, -30067, 0, -19312, 0, -30066, 0, -19311, 0, -30065, 0, -19310, 0, -30064, 0, -19309, 0, -30063, 0, -19308, 0, -30062, 0, -19307, 0, -30061, 0, -19306, 0, -30060, 0, -19305, 0, -30059, 0, -19304, 0, -30058, 0, -19303, 0, -30057, 0, -19302, 0, -30056, 0, -19301, 0, -30055, 0, -19300, 0, -30054, 0, -19298, 0, -30053, 0, -19297, 0, -30052, 0, -19296, 0, -30051, 0, -19295, 0, -30050, 0, -19294, 0, -30049, 0, -19293, 0, -30048, 0, -19291, 0, -30047, 0, -19290, 0, -30046, 0, -19289, 0, -30045, 0, -19287, 0, -30044, 0, -19286, 0, -30043, 0, -19285, 0, -30042, 0, -19283, 0, -30041, 0, -19282, 0, -30040, 0, -19281, 0, -30039, 0, -19280, 0, -30038, 0, -19279, 0, -30037, 0, -19278, 0, -30036, 0, -19277, 0, -30035, 0, -19276, 0, -30034, 0, -19274, 0, -30033, 0, -19272, 0, -30032, 0, -19270, 0, -30031, 0, -19269, 0, -30030, 0, -19268, 0, -30029, 0, -19267, 0, -30028, 0, -19266, 0, -30027, 0, -19265, 0, -30026, 0, -19263, 0, -30025, 0, -19262, 0, -30024, 0, -19261, 0, -30023, 0, -19259, 0, -30022, 0, -19258, 0, -30021, 0, -19257, 0, -30020, 0, -19255, 0, -30019, 0, -19254, 0, -30018, 0, -19253, 0, -30017, 0, -19252, 0, -30016, 0, -19251, 0, -30015, 0, -19250, 0, -30014, 0, -19249, 0, -30013, 0, -19247, 0, -30012, 0, -19246, 0, -30011, 0, -19245, 0, -30010, 0, -19244, 0, -30009, 0, -19242, 0, -30008, 0, -19241, 0, -30007, 0, -19240, 0, -30006, 0, -19239, 0, -30005, 0, -19238, 0, -30004, 0, -19237, 0, -30003, 0, -19234, 0, -30002, 0, -19233, 0, -30001, 0, -19231, 0, -30000, 0, -19230, 0, -29999, 0, -19227, 0, -29998, 0, -19225, 0, -29997, 0, -19224, 0, -29996, 0, -19223, 0, -29995, 0, -19222, 0, -29994, 0, -19221, 0, -29993, 0, -19218, 0, -29992, 0, -19216, 0, -29991, 0, -19214, 0, -29990, 0, -19213, 0, -29989, 0, -19212, 0, -29988, 0, -19211, 0, -29987, 0, -19210, 0, -29986, 0, -19209, 0, -29985, 0, -19207, 0, -29984, 0, -19206, 0, -29983, 0, -19205, 0, -29982, 0, -19204, 0, -29981, 0, -19203, 0, -29980, 0, -19202, 0, -29979, 0, -19201, 0, -29978, 0, -19200, 0, -29977, 0, -19199, 0, -29976, 0, -19198, 0, -29975, 0, -19197, 0, -29974, 0, -19196, 0, -29973, 0, -19195, 0, -29972, 0, -19194, 0, -29971, 0, -19193, 0, -29970, 0, -19192, 0, -29969, 0, -19191, 0, -29968, 0, -19190, 0, -29967, 0, -19189, 0, -29966, 0, -19188, 0, -29965, 0, -19187, 0, -29964, 0, -19186, 0, -29963, 0, -19185, 0, -29962, 0, -19184, 0, -29961, 0, -19183, 0, -29960, 0, -19182, 0, -29959, 0, -19181, 0, -29958, 0, -19178, 0, -29957, 0, -19177, 0, -29956, 0, -19175, 0, -29955, 0, -19174, 0, -29954, 0, -19171, 0, -29887, 0, -19170, 0, -29886, 0, -19169, 0, -29885, 0, -19168, 0, -29884, 0, -19167, 0, -29883, 0, -19166, 0, -29882, 0, -19165, 0, -29881, 0, -19162, 0, -29880, 0, -19157, 0, -29879, 0, -19156, 0, -29878, 0, -19155, 0, -29877, 0, -19154, 0, -29876, 0, -19153, 0, -29875, 0, -19150, 0, -29874, 0, -19149, 0, -29873, 0, -19147, 0, -29872, 0, -19146, 0, -29871, 0, -19145, 0, -29870, 0, -19143, 0, -29869, 0, -19142, 0, -29868, 0, -19141, 0, -29867, 0, -19140, 0, -29866, 0, -19139, 0, -29865, 0, -19138, 0, -29864, 0, -19137, 0, -29863, 0, -19134, 0, -29862, 0, -19130, 0, -29855, 0, -19129, 0, -29854, 0, -19128, 0, -29853, 0, -19127, 0, -29852, 0, -19126, 0, -29851, 0, -19122, 0, -29850, 0, -19121, 0, -29849, 0, -19119, 0, -29848, 0, -19118, 0, -29847, 0, -19117, 0, -29846, 0, -19115, 0, -29845, 0, -19114, 0, -29844, 0, -19113, 0, -29843, 0, -19112, 0, -29842, 0, -19111, 0, -29841, 0, -19110, 0, -29840, 0, -19109, 0, -29839, 0, -19106, 0, -29838, 0, -19102, 0, -29837, 0, -19101, 0, -29836, 0, -19100, 0, -29835, 0, -19099, 0, -29834, 0, -19098, 0, -29833, 0, -19097, 0, -29832, 0, -19096, 0, -29831, 0, -19095, 0, -29830, 0, -19094, 0, -29823, 0, -19093, 0, -29822, 0, -19092, 0, -29821, 0, -19091, 0, -29820, 0, -19090, 0, -29819, 0, -19089, 0, -29818, 0, -19088, 0, -29817, 0, -19087, 0, -29816, 0, -19086, 0, -29815, 0, -19085, 0, -29814, 0, -19084, 0, -29813, 0, -19083, 0, -29812, 0, -19082, 0, -29811, 0, -19081, 0, -29810, 0, -19080, 0, -29809, 0, -19079, 0, -29808, 0, -19078, 0, -29807, 0, -19077, 0, -29806, 0, -19076, 0, -29805, 0, -19075, 0, -29804, 0, -19074, 0, -29803, 0, -19073, 0, -29802, 0, -19072, 0, -29801, 0, -19071, 0, -29800, 0, -19070, 0, -29799, 0, -19069, 0, -29798, 0, -19068, 0, -29797, 0, -19067, 0, -29796, 0, -19066, 0, -29795, 0, -19065, 0, -29794, 0, -19064, 0, -29793, 0, -19063, 0, -29792, 0, -19062, 0, -29791, 0, -19061, 0, -29790, 0, -19060, 0, -29789, 0, -19059, 0, -29788, 0, -19058, 0, -29787, 0, -19057, 0, -29786, 0, -19056, 0, -29785, 0, -19055, 0, -29784, 0, -19054, 0, -29783, 0, -19053, 0, -29782, 0, -19052, 0, -29781, 0, -19051, 0, -29780, 0, -19050, 0, -29779, 0, -19049, 0, -29778, 0, -19048, 0, -29777, 0, -19047, 0, -29776, 0, -19046, 0, -29775, 0, -19045, 0, -29774, 0, -19044, 0, -29773, 0, -19043, 0, -29772, 0, -19042, 0, -29771, 0, -19041, 0, -29770, 0, -19038, 0, -29769, 0, -19037, 0, -29768, 0, -19035, 0, -29767, 0, -19034, 0, -29766, 0, -19033, 0, -29765, 0, -19031, 0, -29764, 0, -19028, 0, -29763, 0, -19027, 0, -29762, 0, -19026, 0, -29761, 0, -19025, 0, -29760, 0, -19022, 0, -29759, 0, -19018, 0, -29758, 0, -19017, 0, -29757, 0, -19016, 0, -29756, 0, -19015, 0, -29755, 0, -19014, 0, -29754, 0, -19010, 0, -29753, 0, -19009, 0, -29752, 0, -19007, 0, -29751, 0, -19006, 0, -29750, 0, -19005, 0, -29749, 0, -19003, 0, -29748, 0, -19002, 0, -29747, 0, -19001, 0, -29746, 0, -19000, 0, -29745, 0, -18999, 0, -29744, 0, -18998, 0, -29743, 0, -18997, 0, -29742, 0, -18994, 0, -29741, 0, -18990, 0, -29740, 0, -18989, 0, -29739, 0, -18988, 0, -29738, 0, -18987, 0, -29737, 0, -18986, 0, -29736, 0, -18985, 0, -29735, 0, -18983, 0, -29734, 0, -18982, 0, -29733, 0, -18981, 0, -29732, 0, -18980, 0, -29731, 0, -18979, 0, -29730, 0, -18978, 0, -29729, 0, -18977, 0, -29728, 0, -18976, 0, -29727, 0, -18975, 0, -29726, 0, -18974, 0, -29725, 0, -18973, 0, -29724, 0, -18972, 0, -29723, 0, -18971, 0, -29722, 0, -18970, 0, -29721, 0, -18969, 0, -29720, 0, -18968, 0, -29719, 0, -18967, 0, -29718, 0, -18966, 0, -29717, 0, -18965, 0, -29716, 0, -18963, 0, -29715, 0, -18962, 0, -29714, 0, -18961, 0, -29713, 0, -18960, 0, -29712, 0, -18959, 0, -29711, 0, -18958, 0, -29710, 0, -18957, 0, -29709, 0, -18956, 0, -29708, 0, -18955, 0, -29707, 0, -18954, 0, -29706, 0, -18953, 0, -29705, 0, -18952, 0, -29704, 0, -18951, 0, -29703, 0, -18950, 0, -29702, 0, -18949, 0, -29701, 0, -18948, 0, -29700, 0, -18947, 0, -29699, 0, -18946, 0, -29698, 0, -18945, 0, -29631, 0, -18944, 0, -29630, 0, -18943, 0, -29629, 0, -18942, 0, -29628, 0, -18941, 0, -29627, 0, -18940, 0, -29626, 0, -18939, 0, -29625, 0, -18938, 0, -29624, 0, -18937, 0, -29623, 0, -18936, 0, -29622, 0, -18935, 0, -29621, 0, -18934, 0, -29620, 0, -18933, 0, -29619, 0, -18932, 0, -29618, 0, -18931, 0, -29617, 0, -18930, 0, -29616, 0, -18929, 0, -29615, 0, -18926, 0, -29614, 0, -18925, 0, -29613, 0, -18923, 0, -29612, 0, -18922, 0, -29611, 0, -18921, 0, -29610, 0, -18919, 0, -29609, 0, -18918, 0, -29608, 0, -18917, 0, -29607, 0, -18916, 0, -29606, 0, -18915, 0, -29599, 0, -18914, 0, -29598, 0, -18913, 0, -29597, 0, -18912, 0, -29596, 0, -18911, 0, -29595, 0, -18910, 0, -29594, 0, -18909, 0, -29593, 0, -18908, 0, -29592, 0, -18906, 0, -29591, 0, -18905, 0, -29590, 0, -18904, 0, -29589, 0, -18903, 0, -29588, 0, -18902, 0, -29587, 0, -18901, 0, -29586, 0, -18899, 0, -29585, 0, -18898, 0, -29584, 0, -18897, 0, -29583, 0, -18896, 0, -29582, 0, -18895, 0, -29581, 0, -18894, 0, -29580, 0, -18893, 0, -29579, 0, -18891, 0, -29578, 0, -18890, 0, -29577, 0, -18889, 0, -29576, 0, -18888, 0, -29575, 0, -18887, 0, -29574, 0, -18886, 0, -29567, 0, -18885, 0, -29566, 0, -18884, 0, -29565, 0, -18883, 0, -29564, 0, -18882, 0, -29563, 0, -18881, 0, -29562, 0, -18880, 0, -29561, 0, -18879, 0, -29560, 0, -18878, 0, -29559, 0, -18877, 0, -29558, 0, -18876, 0, -29557, 0, -18875, 0, -29556, 0, -18874, 0, -29555, 0, -18873, 0, -29554, 0, -18871, 0, -29553, 0, -18870, 0, -29552, 0, -18869, 0, -29551, 0, -18868, 0, -29550, 0, -18867, 0, -29549, 0, -18866, 0, -29548, 0, -18865, 0, -29547, 0, -18864, 0, -29546, 0, -18863, 0, -29545, 0, -18862, 0, -29544, 0, -18861, 0, -29543, 0, -18860, 0, -29542, 0, -18859, 0, -29541, 0, -18858, 0, -29540, 0, -18857, 0, -29539, 0, -18856, 0, -29538, 0, -18855, 0, -29537, 0, -18854, 0, -29536, 0, -18853, 0, -29535, 0, -18852, 0, -29534, 0, -18851, 0, -29533, 0, -18850, 0, -29532, 0, -18849, 0, -29531, 0, -18848, 0, -29530, 0, -18847, 0, -29529, 0, -18846, 0, -29528, 0, -18845, 0, -29527, 0, -18843, 0, -29526, 0, -18842, 0, -29525, 0, -18841, 0, -29524, 0, -18839, 0, -29523, 0, -18838, 0, -29522, 0, -18837, 0, -29521, 0, -18836, 0, -29520, 0, -18835, 0, -29519, 0, -18834, 0, -29518, 0, -18833, 0, -29517, 0, -18832, 0, -29516, 0, -18831, 0, -29515, 0, -18830, 0, -29514, 0, -18829, 0, -29513, 0, -18828, 0, -29512, 0, -18827, 0, -29511, 0, -18826, 0, -29510, 0, -18825, 0, -29509, 0, -18824, 0, -29508, 0, -18823, 0, -29507, 0, -18822, 0, -29506, 0, -18821, 0, -29505, 0, -18820, 0, -29504, 0, -18819, 0, -29503, 0, -18818, 0, -29502, 0, -18817, 0, -29501, 0, -18816, 0, -29500, 0, -18815, 0, -29499, 0, -18814, 0, -29498, 0, -18813, 0, -29497, 0, -18812, 0, -29496, 0, -18811, 0, -29495, 0, -18810, 0, -29494, 0, -18809, 0, -29493, 0, -18808, 0, -29492, 0, -18807, 0, -29491, 0, -18806, 0, -29490, 0, -18805, 0, -29489, 0, -18804, 0, -29488, 0, -18803, 0, -29487, 0, -18802, 0, -29486, 0, -18801, 0, -29485, 0, -18800, 0, -29484, 0, -18799, 0, -29483, 0, -18798, 0, -29482, 0, -18797, 0, -29481, 0, -18796, 0, -29480, 0, -18795, 0, -29479, 0, -18794, 0, -29478, 0, -18793, 0, -29477, 0, -18792, 0, -29476, 0, -18791, 0, -29475, 0, -18790, 0, -29474, 0, -18789, 0, -29473, 0, -18786, 0, -29472, 0, -18785, 0, -29471, 0, -18783, 0, -29470, 0, -18782, 0, -29469, 0, -18781, 0, -29468, 0, -18779, 0, -29467, 0, -18778, 0, -29466, 0, -18777, 0, -29465, 0, -18776, 0, -29464, 0, -18775, 0, -29463, 0, -18774, 0, -29462, 0, -18771, 0, -29461, 0, -18770, 0, -29460, 0, -18769, 0, -29459, 0, -18768, 0, -29458, 0, -18766, 0, -29457, 0, -18765, 0, -29456, 0, -18764, 0, -29455, 0, -18763, 0, -29454, 0, -18762, 0, -29453, 0, -18761, 0, -29452, 0, -18760, 0, -29451, 0, -18759, 0, -29450, 0, -18758, 0, -29449, 0, -18757, 0, -29448, 0, -18756, 0, -29447, 0, -18755, 0, -29446, 0, -18754, 0, -29445, 0, -18753, 0, -29444, 0, -18752, 0, -29443, 0, -18751, 0, -29442, 0, -18750, 0, -29375, 0, -18749, 0, -29374, 0, -18748, 0, -29373, 0, -18747, 0, -29372, 0, -18746, 0, -29371, 0, -18745, 0, -29370, 0, -18744, 0, -29369, 0, -18743, 0, -29368, 0, -18742, 0, -29367, 0, -18741, 0, -29366, 0, -18740, 0, -29365, 0, -18739, 0, -29364, 0, -18738, 0, -29363, 0, -18737, 0, -29362, 0, -18736, 0, -29361, 0, -18735, 0, -29360, 0, -18734, 0, -29359, 0, -18733, 0, -29358, 0, -18731, 0, -29357, 0, -18730, 0, -29356, 0, -18729, 0, -29355, 0, -18728, 0, -29354, 0, -18727, 0, -29353, 0, -18726, 0, -29352, 0, -18725, 0, -29351, 0, -18724, 0, -29350, 0, -18723, 0, -29343, 0, -18722, 0, -29342, 0, -18721, 0, -29341, 0, -18720, 0, -29340, 0, -18719, 0, -29339, 0, -18718, 0, -29338, 0, -18717, 0, -29337, 0, -18716, 0, -29336, 0, -18715, 0, -29335, 0, -18714, 0, -29334, 0, -18713, 0, -29333, 0, -18712, 0, -29332, 0, -18711, 0, -29331, 0, -18710, 0, -29330, 0, -18709, 0, -29329, 0, -18708, 0, -29328, 0, -18707, 0, -29327, 0, -18706, 0, -29326, 0, -18705, 0, -29325, 0, -18703, 0, -29324, 0, -18702, 0, -29323, 0, -18701, 0, -29322, 0, -18699, 0, -29321, 0, -18698, 0, -29320, 0, -18697, 0, -29319, 0, -18695, 0, -29318, 0, -18694, 0, -29311, 0, -18693, 0, -29310, 0, -18692, 0, -29309, 0, -18691, 0, -29308, 0, -18690, 0, -29307, 0, -18689, 0, -29306, 0, -18686, 0, -29305, 0, -18685, 0, -29304, 0, -18684, 0, -29303, 0, -18682, 0, -29302, 0, -18681, 0, -29301, 0, -18680, 0, -29300, 0, -18679, 0, -29299, 0, -18678, 0, -29298, 0, -18677, 0, -29297, 0, -18676, 0, -29296, 0, -18675, 0, -29295, 0, -18674, 0, -29294, 0, -18673, 0, -29293, 0, -18672, 0, -29292, 0, -18671, 0, -29291, 0, -18670, 0, -29290, 0, -18669, 0, -29289, 0, -18668, 0, -29288, 0, -18667, 0, -29287, 0, -18666, 0, -29286, 0, -18665, 0, -29285, 0, -18664, 0, -29284, 0, -18663, 0, -29283, 0, -18662, 0, -29282, 0, -18661, 0, -29281, 0, -18660, 0, -29280, 0, -18659, 0, -29279, 0, -18658, 0, -29278, 0, -18657, 0, -29277, 0, -18656, 0, -29276, 0, -18655, 0, -29275, 0, -18654, 0, -29274, 0, -18653, 0, -29273, 0, -18652, 0, -29272, 0, -18651, 0, -29271, 0, -18650, 0, -29270, 0, -18649, 0, -29269, 0, -18646, 0, -29268, 0, -18645, 0, -29267, 0, -18643, 0, -29266, 0, -18642, 0, -29265, 0, -18639, 0, -29264, 0, -18638, 0, -29263, 0, -18637, 0, -29262, 0, -18636, 0, -29261, 0, -18635, 0, -29260, 0, -18634, 0, -29259, 0, -18633, 0, -29258, 0, -18630, 0, -29257, 0, -18628, 0, -29256, 0, -18627, 0, -29255, 0, -18626, 0, -29254, 0, -18625, 0, -29253, 0, -18624, 0, -29252, 0, -18623, 0, -29251, 0, -18622, 0, -29250, 0, -18621, 0, -29249, 0, -18619, 0, -29248, 0, -18618, 0, -29247, 0, -18617, 0, -29246, 0, -18615, 0, -29245, 0, -18614, 0, -29244, 0, -18613, 0, -29243, 0, -18611, 0, -29242, 0, -18610, 0, -29241, 0, -18609, 0, -29240, 0, -18608, 0, -29239, 0, -18607, 0, -29238, 0, -18606, 0, -29237, 0, -18605, 0, -29236, 0, -18602, 0, -29235, 0, -18601, 0, -29234, 0, -18600, 0, -29233, 0, -18599, 0, -29232, 0, -18598, 0, -29231, 0, -18597, 0, -29230, 0, -18596, 0, -29229, 0, -18595, 0, -29228, 0, -18594, 0, -29227, 0, -18593, 0, -29226, 0, -18591, 0, -29225, 0, -18590, 0, -29224, 0, -18589, 0, -29223, 0, -18587, 0, -29222, 0, -18586, 0, -29221, 0, -18585, 0, -29220, 0, -18583, 0, -29219, 0, -18582, 0, -29218, 0, -18581, 0, -29217, 0, -18580, 0, -29216, 0, -18579, 0, -29215, 0, -18578, 0, -29214, 0, -18577, 0, -29213, 0, -18574, 0, -29212, 0, -18572, 0, -29211, 0, -18570, 0, -29210, 0, -18569, 0, -29209, 0, -18568, 0, -29208, 0, -18567, 0, -29207, 0, -18566, 0, -29206, 0, -18565, 0, -29205, 0, -18562, 0, -29204, 0, -18561, 0, -29203, 0, -18559, 0, -29202, 0, -18558, 0, -29201, 0, -18557, 0, -29200, 0, -18555, 0, -29199, 0, -18554, 0, -29198, 0, -18553, 0, -29197, 0, -18552, 0, -29196, 0, -18551, 0, -29195, 0, -18550, 0, -29194, 0, -18549, 0, -29193, 0, -18546, 0, -29192, 0, -18541, 0, -29191, 0, -18540, 0, -29190, 0, -18539, 0, -29189, 0, -18534, 0, -29188, 0, -18533, 0, -29187, 0, -18531, 0, -29186, 0, -18530, 0, -29119, 0, -18529, 0, -29118, 0, -18527, 0, -29117, 0, -18526, 0, -29116, 0, -18525, 0, -29115, 0, -18524, 0, -29114, 0, -18523, 0, -29113, 0, -18522, 0, -29112, 0, -18521, 0, -29111, 0, -18518, 0, -29110, 0, -18514, 0, -29109, 0, -18513, 0, -29108, 0, -18512, 0, -29107, 0, -18511, 0, -29106, 0, -18510, 0, -29105, 0, -18509, 0, -29104, 0, -18506, 0, -29103, 0, -18505, 0, -29102, 0, -18503, 0, -29101, 0, -18502, 0, -29100, 0, -18501, 0, -29099, 0, -18500, 0, -29098, 0, -18499, 0, -29097, 0, -18498, 0, -29096, 0, -18497, 0, -29095, 0, -18496, 0, -29094, 0, -18495, 0, -29087, 0, -18494, 0, -29086, 0, -18493, 0, -29085, 0, -18492, 0, -29084, 0, -18491, 0, -29083, 0, -18490, 0, -29082, 0, -18488, 0, -29081, 0, -18486, 0, -29080, 0, -18485, 0, -29079, 0, -18484, 0, -29078, 0, -18483, 0, -29077, 0, -18482, 0, -29076, 0, -18481, 0, -29075, 0, -18480, 0, -29074, 0, -18479, 0, -29073, 0, -18478, 0, -29072, 0, -18477, 0, -29071, 0, -18476, 0, -29070, 0, -18475, 0, -29069, 0, -18474, 0, -29068, 0, -18473, 0, -29067, 0, -18472, 0, -29066, 0, -18471, 0, -29065, 0, -18470, 0, -29064, 0, -18469, 0, -29063, 0, -18468, 0, -29062, 0, -18467, 0, -29055, 0, -18466, 0, -29054, 0, -18465, 0, -29053, 0, -18464, 0, -29052, 0, -18463, 0, -29051, 0, -18462, 0, -29050, 0, -18461, 0, -29049, 0, -18460, 0, -29048, 0, -18459, 0, -29047, 0, -18458, 0, -29046, 0, -18457, 0, -29045, 0, -18456, 0, -29044, 0, -18455, 0, -29043, 0, -18454, 0, -29042, 0, -18453, 0, -29041, 0, -18450, 0, -29040, 0, -18449, 0, -29039, 0, -18447, 0, -29038, 0, -18446, 0, -29037, 0, -18445, 0, -29036, 0, -18443, 0, -29035, 0, -18442, 0, -29034, 0, -18441, 0, -29033, 0, -18440, 0, -29032, 0, -18439, 0, -29031, 0, -18438, 0, -29030, 0, -18437, 0, -29029, 0, -18434, 0, -29028, 0, -18430, 0, -29027, 0, -18429, 0, -29026, 0, -18428, 0, -29025, 0, -18427, 0, -29024, 0, -18426, 0, -29023, 0, -18422, 0, -29022, 0, -18421, 0, -29021, 0, -18419, 0, -29020, 0, -18418, 0, -29019, 0, -18417, 0, -29018, 0, -18415, 0, -29017, 0, -18414, 0, -29016, 0, -18413, 0, -29015, 0, -18412, 0, -29014, 0, -18411, 0, -29013, 0, -18410, 0, -29012, 0, -18409, 0, -29011, 0, -18406, 0, -29010, 0, -18404, 0, -29009, 0, -18402, 0, -29008, 0, -18401, 0, -29007, 0, -18400, 0, -29006, 0, -18399, 0, -29005, 0, -18398, 0, -29004, 0, -18397, 0, -29003, 0, -18394, 0, -29002, 0, -18393, 0, -29001, 0, -18391, 0, -29000, 0, -18390, 0, -28999, 0, -18389, 0, -28998, 0, -18387, 0, -28997, 0, -18386, 0, -28996, 0, -18385, 0, -28995, 0, -18384, 0, -28994, 0, -18383, 0, -28993, 0, -18382, 0, -28992, 0, -18381, 0, -28991, 0, -18378, 0, -28990, 0, -18374, 0, -28989, 0, -18373, 0, -28988, 0, -18372, 0, -28987, 0, -18371, 0, -28986, 0, -18370, 0, -28985, 0, -18369, 0, -28984, 0, -18367, 0, -28983, 0, -18366, 0, -28982, 0, -18365, 0, -28981, 0, -18363, 0, -28980, 0, -18362, 0, -28979, 0, -18361, 0, -28978, 0, -18360, 0, -28977, 0, -18359, 0, -28976, 0, -18358, 0, -28975, 0, -18357, 0, -28974, 0, -18356, 0, -28973, 0, -18355, 0, -28972, 0, -18354, 0, -28971, 0, -18353, 0, -28970, 0, -18352, 0, -28969, 0, -18350, 0, -28968, 0, -18348, 0, -28967, 0, -18347, 0, -28966, 0, -18346, 0, -28965, 0, -18345, 0, -28964, 0, -18344, 0, -28963, 0, -18343, 0, -28962, 0, -18342, 0, -28961, 0, -18341, 0, -28960, 0, -18338, 0, -28959, 0, -18337, 0, -28958, 0, -18335, 0, -28957, 0, -18334, 0, -28956, 0, -18333, 0, -28955, 0, -18331, 0, -28954, 0, -18330, 0, -28953, 0, -18329, 0, -28952, 0, -18328, 0, -28951, 0, -18327, 0, -28950, 0, -18326, 0, -28949, 0, -18325, 0, -28948, 0, -18322, 0, -28947, 0, -18320, 0, -28946, 0, -18318, 0, -28945, 0, -18317, 0, -28944, 0, -18316, 0, -28943, 0, -18315, 0, -28942, 0, -18314, 0, -28941, 0, -18313, 0, -28940, 0, -18311, 0, -28939, 0, -18310, 0, -28938, 0, -18309, 0, -28937, 0, -18307, 0, -28936, 0, -18306, 0, -28935, 0, -18305, 0, -28934, 0, -18304, 0, -28933, 0, -18303, 0, -28932, 0, -18302, 0, -28931, 0, -18301, 0, -28930, 0, -18300, 0, -28863, 0, -18299, 0, -28862, 0, -18298, 0, -28861, 0, -18297, 0, -28860, 0, -18296, 0, -28859, 0, -18295, 0, -28858, 0, -18294, 0, -28857, 0, -18293, 0, -28856, 0, -18292, 0, -28855, 0, -18290, 0, -28854, 0, -18289, 0, -28853, 0, -18288, 0, -28852, 0, -18287, 0, -28851, 0, -18286, 0, -28850, 0, -18285, 0, -28849, 0, -18284, 0, -28848, 0, -18283, 0, -28847, 0, -18282, 0, -28846, 0, -18281, 0, -28845, 0, -18280, 0, -28844, 0, -18279, 0, -28843, 0, -18278, 0, -28842, 0, -18277, 0, -28841, 0, -18276, 0, -28840, 0, -18275, 0, -28839, 0, -18274, 0, -28838, 0, -18273, 0, -28831, 0, -18272, 0, -28830, 0, -18271, 0, -28829, 0, -18270, 0, -28828, 0, -18269, 0, -28827, 0, -18268, 0, -28826, 0, -18267, 0, -28825, 0, -18266, 0, -28824, 0, -18265, 0, -28823, 0, -18263, 0, -28822, 0, -18262, 0, -28821, 0, -18261, 0, -28820, 0, -18260, 0, -28819, 0, -18259, 0, -28818, 0, -18258, 0, -28817, 0, -18257, 0, -28816, 0, -18255, 0, -28815, 0, -18254, 0, -28814, 0, -18253, 0, -28813, 0, -18251, 0, -28812, 0, -18250, 0, -28811, 0, -18249, 0, -28810, 0, -18247, 0, -28809, 0, -18246, 0, -28808, 0, -18245, 0, -28807, 0, -18244, 0, -28806, 0, -18243, 0, -28799, 0, -18242, 0, -28798, 0, -18241, 0, -28797, 0, -18238, 0, -28796, 0, -18236, 0, -28795, 0, -18234, 0, -28794, 0, -18233, 0, -28793, 0, -18232, 0, -28792, 0, -18231, 0, -28791, 0, -18230, 0, -28790, 0, -18229, 0, -28789, 0, -18227, 0, -28788, 0, -18226, 0, -28787, 0, -18225, 0, -28786, 0, -18223, 0, -28785, 0, -18222, 0, -28784, 0, -18221, 0, -28783, 0, -18219, 0, -28782, 0, -18218, 0, -28781, 0, -18217, 0, -28780, 0, -18216, 0, -28779, 0, -18215, 0, -28778, 0, -18214, 0, -28777, 0, -18213, 0, -28776, 0, -18212, 0, -28775, 0, -18210, 0, -28774, 0, -18208, 0, -28773, 0, -18206, 0, -28772, 0, -18205, 0, -28771, 0, -18204, 0, -28770, 0, -18203, 0, -28769, 0, -18202, 0, -28768, 0, -18201, 0, -28767, 0, -18198, 0, -28766, 0, -18197, 0, -28765, 0, -18195, 0, -28764, 0, -18194, 0, -28763, 0, -18193, 0, -28762, 0, -18191, 0, -28761, 0, -18190, 0, -28760, 0, -18189, 0, -28759, 0, -18188, 0, -28758, 0, -18187, 0, -28757, 0, -18186, 0, -28756, 0, -18185, 0, -28755, 0, -18182, 0, -28754, 0, -18180, 0, -28753, 0, -18178, 0, -28752, 0, -18177, 0, -28751, 0, -18176, 0, -28750, 0, -18175, 0, -28749, 0, -18174, 0, -28748, 0, -18173, 0, -28747, 0, -18171, 0, -28746, 0, -18170, 0, -28745, 0, -18169, 0, -28744, 0, -18168, 0, -28743, 0, -18167, 0, -28742, 0, -18166, 0, -28741, 0, -18165, 0, -28740, 0, -18164, 0, -28739, 0, -18163, 0, -28738, 0, -18162, 0, -28737, 0, -18161, 0, -28736, 0, -18160, 0, -28735, 0, -18159, 0, -28734, 0, -18158, 0, -28733, 0, -18157, 0, -28732, 0, -18156, 0, -28731, 0, -18155, 0, -28730, 0, -18154, 0, -28729, 0, -18153, 0, -28728, 0, -18151, 0, -28727, 0, -18150, 0, -28726, 0, -18149, 0, -28725, 0, -18148, 0, -28724, 0, -18147, 0, -28723, 0, -18146, 0, -28722, 0, -18145, 0, -28721, 0, -18143, 0, -28720, 0, -18142, 0, -28719, 0, -18141, 0, -28718, 0, -18140, 0, -28717, 0, -18139, 0, -28716, 0, -18138, 0, -28715, 0, -18137, 0, -28714, 0, -18136, 0, -28713, 0, -18135, 0, -28712, 0, -18134, 0, -28711, 0, -18133, 0, -28710, 0, -18132, 0, -28709, 0, -18131, 0, -28708, 0, -18130, 0, -28707, 0, -18129, 0, -28706, 0, -18128, 0, -28705, 0, -18127, 0, -28704, 0, -18126, 0, -28703, 0, -18125, 0, -28702, 0, -18124, 0, -28701, 0, -18123, 0, -28700, 0, -18122, 0, -28699, 0, -18121, 0, -28698, 0, -18120, 0, -28697, 0, -18119, 0, -28696, 0, -18118, 0, -28695, 0, -18117, 0, -28694, 0, -18114, 0, -28693, 0, -18113, 0, -28692, 0, -18111, 0, -28691, 0, -18110, 0, -28690, 0, -18109, 0, -28689, 0, -18107, 0, -28688, 0, -18106, 0, -28687, 0, -18105, 0, -28686, 0, -18104, 0, -28685, 0, -18103, 0, -28684, 0, -18102, 0, -28683, 0, -18101, 0, -28682, 0, -18099, 0, -28681, 0, -18098, 0, -28680, 0, -18096, 0, -28679, 0, -18094, 0, -28678, 0, -18093, 0, -28677, 0, -18092, 0, -28676, 0, -18091, 0, -28675, 0, -18090, 0, -28674, 0, -18089, 0, -28607, 0, -18086, 0, -28606, 0, -18085, 0, -28605, 0, -18083, 0, -28604, 0, -18082, 0, -28603, 0, -18081, 0, -28602, 0, -18079, 0, -28601, 0, -18078, 0, -28600, 0, -18077, 0, -28599, 0, -18076, 0, -28598, 0, -18075, 0, -28597, 0, -18074, 0, -28596, 0, -18073, 0, -28595, 0, -18070, 0, -28594, 0, -18068, 0, -28593, 0, -18066, 0, -28592, 0, -18065, 0, -28591, 0, -18064, 0, -28590, 0, -18063, 0, -28589, 0, -18062, 0, -28588, 0, -18061, 0, -28587, 0, -18058, 0, -28586, 0, -18057, 0, -28585, 0, -18055, 0, -28584, 0, -18054, 0, -28583, 0, -18053, 0, -28582, 0, -18051, 0, -28575, 0, -18050, 0, -28574, 0, -18049, 0, -28573, 0, -18048, 0, -28572, 0, -18047, 0, -28571, 0, -18046, 0, -28570, 0, -18045, 0, -28569, 0, -18042, 0, -28568, 0, -18040, 0, -28567, 0, -18037, 0, -28566, 0, -18036, 0, -28565, 0, -18033, 0, -28564, 0, -18032, 0, -28563, 0, -18031, 0, -28562, 0, -18030, 0, -28561, 0, -18029, 0, -28560, 0, -18028, 0, -28559, 0, -18027, 0, -28558, 0, -18026, 0, -28557, 0, -18025, 0, -28556, 0, -18024, 0, -28555, 0, -18023, 0, -28554, 0, -18022, 0, -28553, 0, -18021, 0, -28552, 0, -18020, 0, -28551, 0, -18019, 0, -28550, 0, -18018, 0, -28543, 0, -18017, 0, -28542, 0, -18016, 0, -28541, 0, -18015, 0, -28540, 0, -18014, 0, -28539, 0, -18013, 0, -28538, 0, -18012, 0, -28537, 0, -18011, 0, -28536, 0, -18010, 0, -28535, 0, -18009, 0, -28534, 0, -18008, 0, -28533, 0, -18007, 0, -28532, 0, -18006, 0, -28531, 0, -18005, 0, -28530, 0, -18002, 0, -28529, 0, -18001, 0, -28528, 0, -17999, 0, -28527, 0, -17998, 0, -28526, 0, -17997, 0, -28525, 0, -17995, 0, -28524, 0, -17994, 0, -28523, 0, -17993, 0, -28522, 0, -17992, 0, -28521, 0, -17991, 0, -28520, 0, -17990, 0, -28519, 0, -17989, 0, -28518, 0, -17986, 0, -28517, 0, -17984, 0, -28516, 0, -17982, 0, -28515, 0, -17981, 0, -28514, 0, -17980, 0, -28513, 0, -17979, 0, -28512, 0, -17978, 0, -28511, 0, -17977, 0, -28510, 0, -17974, 0, -28509, 0, -17973, 0, -28508, 0, -17971, 0, -28507, 0, -17965, 0, -28506, 0, -17964, 0, -28505, 0, -17963, 0, -28504, 0, -17962, 0, -28503, 0, -17961, 0, -28502, 0, -17958, 0, -28501, 0, -17956, 0, -28500, 0, -17953, 0, -28499, 0, -17952, 0, -28498, 0, -17950, 0, -28497, 0, -17946, 0, -28496, 0, -17945, 0, -28495, 0, -17943, 0, -28494, 0, -17942, 0, -28493, 0, -17941, 0, -28492, 0, -17939, 0, -28491, 0, -17938, 0, -28490, 0, -17937, 0, -28489, 0, -17936, 0, -28488, 0, -17935, 0, -28487, 0, -17934, 0, -28486, 0, -17933, 0, -28485, 0, -17930, 0, -28484, 0, -17925, 0, -28483, 0, -17924, 0, -28482, 0, -17923, 0, -28481, 0, -17922, 0, -28480, 0, -17921, 0, -28479, 0, -17918, 0, -28478, 0, -17917, 0, -28477, 0, -17916, 0, -28476, 0, -17915, 0, -28475, 0, -17914, 0, -28474, 0, -17913, 0, -28473, 0, -17911, 0, -28472, 0, -17910, 0, -28471, 0, -17909, 0, -28470, 0, -17908, 0, -28469, 0, -17907, 0, -28468, 0, -17906, 0, -28467, 0, -17905, 0, -28466, 0, -17904, 0, -28465, 0, -17903, 0, -28464, 0, -17902, 0, -28463, 0, -17901, 0, -28462, 0, -17900, 0, -28461, 0, -17898, 0, -28460, 0, -17897, 0, -28459, 0, -17896, 0, -28458, 0, -17895, 0, -28457, 0, -17894, 0, -28456, 0, -17893, 0, -28455, 0, -17892, 0, -28454, 0, -17891, 0, -28453, 0, -17890, 0, -28452, 0, -17889, 0, -28451, 0, -17888, 0, -28450, 0, -17887, 0, -28449, 0, -17886, 0, -28448, 0, -17885, 0, -28447, 0, -17884, 0, -28446, 0, -17883, 0, -28445, 0, -17882, 0, -28444, 0, -17881, 0, -28443, 0, -17880, 0, -28442, 0, -17879, 0, -28441, 0, -17878, 0, -28440, 0, -17877, 0, -28439, 0, -17876, 0, -28438, 0, -17875, 0, -28437, 0, -17874, 0, -28436, 0, -17873, 0, -28435, 0, -17872, 0, -28434, 0, -17871, 0, -28433, 0, -17870, 0, -28432, 0, -17869, 0, -28431, 0, -17868, 0, -28430, 0, -17867, 0, -28429, 0, -17866, 0, -28428, 0, -17865, 0, -28427, 0, -17862, 0, -28426, 0, -17861, 0, -28425, 0, -17859, 0, -28424, 0, -17858, 0, -28423, 0, -17857, 0, -28422, 0, -17855, 0, -28421, 0, -17853, 0, -28420, 0, -17852, 0, -28419, 0, -17851, 0, -28418, 0, -17850, 0, -28351, 0, -17849, 0, -28350, 0, -17846, 0, -28349, 0, -17844, 0, -28348, 0, -17841, 0, -28347, 0, -17840, 0, -28346, 0, -17839, 0, -28345, 0, -17838, 0, -28344, 0, -17834, 0, -28343, 0, -17833, 0, -28342, 0, -17831, 0, -28341, 0, -17830, 0, -28340, 0, -17829, 0, -28339, 0, -17827, 0, -28338, 0, -17826, 0, -28337, 0, -17825, 0, -28336, 0, -17824, 0, -28335, 0, -17823, 0, -28334, 0, -17822, 0, -28333, 0, -17821, 0, -28332, 0, -17818, 0, -28331, 0, -17814, 0, -28330, 0, -17813, 0, -28329, 0, -17812, 0, -28328, 0, -17811, 0, -28327, 0, -17810, 0, -28326, 0, -17809, 0, -28319, 0, -17806, 0, -28318, 0, -17805, 0, -28317, 0, -17803, 0, -28316, 0, -17802, 0, -28315, 0, -17801, 0, -28314, 0, -17799, 0, -28313, 0, -17798, 0, -28312, 0, -17797, 0, -28311, 0, -17796, 0, -28310, 0, -17795, 0, -28309, 0, -17794, 0, -28308, 0, -17793, 0, -28307, 0, -17792, 0, -28306, 0, -17791, 0, -28305, 0, -17790, 0, -28304, 0, -17786, 0, -28303, 0, -17784, 0, -28302, 0, -17783, 0, -28301, 0, -17782, 0, -28300, 0, -17781, 0, -28299, 0, -17779, 0, -28298, 0, -17778, 0, -28297, 0, -17777, 0, -28296, 0, -17776, 0, -28295, 0, -17775, 0, -28294, 0, -17774, 0, -28287, 0, -17773, 0, -28286, 0, -17772, 0, -28285, 0, -17771, 0, -28284, 0, -17770, 0, -28283, 0, -17769, 0, -28282, 0, -17768, 0, -28281, 0, -17767, 0, -28280, 0, -17766, 0, -28279, 0, -17765, 0, -28278, 0, -17764, 0, -28277, 0, -17763, 0, -28276, 0, -17762, 0, -28275, 0, -17761, 0, -28274, 0, -17760, 0, -28273, 0, -17759, 0, -28272, 0, -17758, 0, -28271, 0, -17757, 0, -28270, 0, -17756, 0, -28269, 0, -17755, 0, -28268, 0, -17754, 0, -28267, 0, -17753, 0, -28266, 0, -17750, 0, -28265, 0, -17747, 0, -28264, 0, -17746, 0, -28263, 0, -17745, 0, -28262, 0, -17743, 0, -28261, 0, -17741, 0, -28260, 0, -17740, 0, -28259, 0, -17739, 0, -28258, 0, -17738, 0, -28257, 0, -17737, 0, -28256, 0, -17734, 0, -28255, 0, -17732, 0, -28254, 0, -17730, 0, -28253, 0, -17729, 0, -28252, 0, -17728, 0, -28251, 0, -17727, 0, -28250, 0, -17726, 0, -28249, 0, -17725, 0, -28248, 0, -17723, 0, -28247, 0, -17722, 0, -28246, 0, -17721, 0, -28245, 0, -17719, 0, -28244, 0, -17718, 0, -28243, 0, -17717, 0, -28242, 0, -17716, 0, -28241, 0, -17715, 0, -28240, 0, -17714, 0, -28239, 0, -17713, 0, -28238, 0, -17712, 0, -28237, 0, -17711, 0, -28236, 0, -17710, 0, -28235, 0, -17709, 0, -28234, 0, -17708, 0, -28233, 0, -17707, 0, -28232, 0, -17706, 0, -28231, 0, -17705, 0, -28230, 0, -17702, 0, -28229, 0, -17701, 0, -28228, 0, -17700, 0, -28227, 0, -17699, 0, -28226, 0, -17698, 0, -28225, 0, -17697, 0, -28224, 0, -17696, 0, -28223, 0, -17695, 0, -28222, 0, -17694, 0, -28221, 0, -17693, 0, -28220, 0, -17692, 0, -28219, 0, -17691, 0, -28218, 0, -17690, 0, -28217, 0, -17689, 0, -28216, 0, -17688, 0, -28215, 0, -17687, 0, -28214, 0, -17686, 0, -28213, 0, -17685, 0, -28212, 0, -17684, 0, -28211, 0, -17683, 0, -28210, 0, -17682, 0, -28209, 0, -17681, 0, -28208, 0, -17680, 0, -28207, 0, -17679, 0, -28206, 0, -17678, 0, -28205, 0, -17677, 0, -28204, 0, -17676, 0, -28203, 0, -17675, 0, -28202, 0, -17674, 0, -28201, 0, -17673, 0, -28200, 0, -17672, 0, -28199, 0, -17671, 0, -28198, 0, -17670, 0, -28197, 0, -17669, 0, -28196, 0, -17667, 0, -28195, 0, -17666, 0, -28194, 0, -17665, 0, -28193, 0, -17663, 0, -28192, 0, -17662, 0, -28191, 0, -17661, 0, -28190, 0, -17659, 0, -28189, 0, -17658, 0, -28188, 0, -17657, 0, -28187, 0, -17656, 0, -28186, 0, -17655, 0, -28185, 0, -17654, 0, -28184, 0, -17653, 0, -28183, 0, -17652, 0, -28182, 0, -17650, 0, -28181, 0, -17648, 0, -28180, 0, -17646, 0, -28179, 0, -17645, 0, -28178, 0, -17644, 0, -28177, 0, -17643, 0, -28176, 0, -17642, 0, -28175, 0, -17641, 0, -28174, 0, -17639, 0, -28173, 0, -17638, 0, -28172, 0, -17637, 0, -28171, 0, -17635, 0, -28170, 0, -17634, 0, -28169, 0, -17633, 0, -28168, 0, -17631, 0, -28167, 0, -17630, 0, -28166, 0, -17629, 0, -28165, 0, -17628, 0, -28164, 0, -17627, 0, -28163, 0, -17626, 0, -28162, 0, -17625, 0, -28095, 0, -17624, 0, -28094, 0, -17622, 0, -28093, 0, -17620, 0, -28092, 0, -17619, 0, -28091, 0, -17618, 0, -28090, 0, -17617, 0, -28089, 0, -17616, 0, -28088, 0, -17615, 0, -28087, 0, -17614, 0, -28086, 0, -17613, 0, -28085, 0, -17609, 0, -28084, 0, -17607, 0, -28083, 0, -17606, 0, -28082, 0, -17601, 0, -28081, 0, -17600, 0, -28080, 0, -17599, 0, -28079, 0, -17598, 0, -28078, 0, -17597, 0, -28077, 0, -17594, 0, -28076, 0, -17592, 0, -28075, 0, -17590, 0, -28074, 0, -17589, 0, -28073, 0, -17588, 0, -28072, 0, -17586, 0, -28071, 0, -17583, 0, -28070, 0, -17582, 0, -28063, 0, -17581, 0, -28062, 0, -17579, 0, -28061, 0, -17578, 0, -28060, 0, -17577, 0, -28059, 0, -17575, 0, -28058, 0, -17574, 0, -28057, 0, -17573, 0, -28056, 0, -17572, 0, -28055, 0, -17571, 0, -28054, 0, -17570, 0, -28053, 0, -17569, 0, -28052, 0, -17568, 0, -28051, 0, -17566, 0, -28050, 0, -17564, 0, -28049, 0, -17563, 0, -28048, 0, -17562, 0, -28047, 0, -17561, 0, -28046, 0, -17560, 0, -28045, 0, -17559, 0, -28044, 0, -17558, 0, -28043, 0, -17557, 0, -28042, 0, -17555, 0, -28041, 0, -17554, 0, -28040, 0, -17553, 0, -28039, 0, -17552, 0, -28038, 0, -17551, 0, -28031, 0, -17550, 0, -28030, 0, -17549, 0, -28029, 0, -17548, 0, -28028, 0, -17547, 0, -28027, 0, -17546, 0, -28026, 0, -17545, 0, -28025, 0, -17544, 0, -28024, 0, -17543, 0, -28023, 0, -17542, 0, -28022, 0, -17541, 0, -28021, 0, -17540, 0, -28020, 0, -17539, 0, -28019, 0, -17538, 0, -28018, 0, -17537, 0, -28017, 0, -17536, 0, -28016, 0, -17535, 0, -28015, 0, -17534, 0, -28014, 0, -17533, 0, -28013, 0, -17532, 0, -28012, 0, -17531, 0, -28011, 0, -17530, 0, -28010, 0, -17529, 0, -28009, 0, -17527, 0, -28008, 0, -17526, 0, -28007, 0, -17525, 0, -28006, 0, -17523, 0, -28005, 0, -17522, 0, -28004, 0, -17521, 0, -28003, 0, -17519, 0, -28002, 0, -17518, 0, -28001, 0, -17517, 0, -28000, 0, -17516, 0, -27999, 0, -17515, 0, -27998, 0, -17514, 0, -27997, 0, -17513, 0, -27996, 0, -17512, 0, -27995, 0, -17511, 0, -27994, 0, -17510, 0, -27993, 0, -17509, 0, -27992, 0, -17508, 0, -27991, 0, -17507, 0, -27990, 0, -17506, 0, -27989, 0, -17505, 0, -27988, 0, -17504, 0, -27987, 0, -17503, 0, -27986, 0, -17502, 0, -27985, 0, -17501, 0, -27984, 0, -17499, 0, -27983, 0, -17498, 0, -27982, 0, -17497, 0, -27981, 0, -17495, 0, -27980, 0, -17494, 0, -27979, 0, -17493, 0, -27978, 0, -17491, 0, -27977, 0, -17490, 0, -27976, 0, -17489, 0, -27975, 0, -17488, 0, -27974, 0, -17487, 0, -27973, 0, -17486, 0, -27972, 0, -17485, 0, -27971, 0, -17483, 0, -27970, 0, -17482, 0, -27969, 0, -17480, 0, -27968, 0, -17479, 0, -27967, 0, -17478, 0, -27966, 0, -17477, 0, -27965, 0, -17476, 0, -27964, 0, -17475, 0, -27963, 0, -17474, 0, -27962, 0, -17473, 0, -27961, 0, -17471, 0, -27960, 0, -17470, 0, -27959, 0, -17469, 0, -27958, 0, -17467, 0, -27957, 0, -17466, 0, -27956, 0, -17465, 0, -27955, 0, -17463, 0, -27954, 0, -17462, 0, -27953, 0, -17461, 0, -27952, 0, -17460, 0, -27951, 0, -17459, 0, -27950, 0, -17458, 0, -27949, 0, -17457, 0, -27948, 0, -17455, 0, -27947, 0, -17454, 0, -27946, 0, -17452, 0, -27945, 0, -17451, 0, -27944, 0, -17450, 0, -27943, 0, -17449, 0, -27942, 0, -17448, 0, -27941, 0, -17447, 0, -27940, 0, -17446, 0, -27939, 0, -17445, 0, -27938, 0, -17444, 0, -27937, 0, -17443, 0, -27936, 0, -17442, 0, -27935, 0, -17441, 0, -27934, 0, -17440, 0, -27933, 0, -17439, 0, -27932, 0, -17438, 0, -27931, 0, -17437, 0, -27930, 0, -17436, 0, -27929, 0, -17435, 0, -27928, 0, -17434, 0, -27927, 0, -17433, 0, -27926, 0, -17432, 0, -27925, 0, -17431, 0, -27924, 0, -17430, 0, -27923, 0, -17429, 0, -27922, 0, -17428, 0, -27921, 0, -17427, 0, -27920, 0, -17426, 0, -27919, 0, -17425, 0, -27918, 0, -17424, 0, -27917, 0, -17423, 0, -27916, 0, -17422, 0, -27915, 0, -17421, 0, -27914, 0, -17420, 0, -27913, 0, -17419, 0, -27912, 0, -17418, 0, -27911, 0, -17417, 0, -27910, 0, -17414, 0, -27909, 0, -17413, 0, -27908, 0, -17411, 0, -27907, 0, -17410, 0, -27906, 0, -17407, 0, -27839, 0, -17405, 0, -27838, 0, -17404, 0, -27837, 0, -17403, 0, -27836, 0, -17402, 0, -27835, 0, -17401, 0, -27834, 0, -17398, 0, -27833, 0, -17394, 0, -27832, 0, -17392, 0, -27831, 0, -17390, 0, -27830, 0, -17389, 0, -27829, 0, -17383, 0, -27828, 0, -17382, 0, -27827, 0, -17376, 0, -27826, 0, -17375, 0, -27825, 0, -17374, 0, -27824, 0, -17373, 0, -27823, 0, -17370, 0, -27822, 0, -17368, 0, -27821, 0, -17366, 0, -27820, 0, -17365, 0, -27819, 0, -17364, 0, -27818, 0, -17362, 0, -27817, 0, -17361, 0, -27816, 0, -17358, 0, -27815, 0, -17357, 0, -27814, 0, -17355, 0, -27807, 0, -17354, 0, -27806, 0, -17353, 0, -27805, 0, -17351, 0, -27804, 0, -17350, 0, -27803, 0, -17349, 0, -27802, 0, -17348, 0, -27801, 0, -17347, 0, -27800, 0, -17346, 0, -27799, 0, -17345, 0, -27798, 0, -17342, 0, -27797, 0, -17338, 0, -27796, 0, -17337, 0, -27795, 0, -17336, 0, -27794, 0, -17334, 0, -27793, 0, -17333, 0, -27792, 0, -17330, 0, -27791, 0, -17329, 0, -27790, 0, -17327, 0, -27789, 0, -17326, 0, -27788, 0, -17325, 0, -27787, 0, -17324, 0, -27786, 0, -17323, 0, -27785, 0, -17322, 0, -27784, 0, -17321, 0, -27783, 0, -17320, 0, -27782, 0, -17319, 0, -27775, 0, -17318, 0, -27774, 0, -17317, 0, -27773, 0, -17316, 0, -27772, 0, -17314, 0, -27771, 0, -17313, 0, -27770, 0, -17312, 0, -27769, 0, -17311, 0, -27768, 0, -17310, 0, -27767, 0, -17309, 0, -27766, 0, -17308, 0, -27765, 0, -17307, 0, -27764, 0, -17306, 0, -27763, 0, -17305, 0, -27762, 0, -17304, 0, -27761, 0, -17303, 0, -27760, 0, -17302, 0, -27759, 0, -17301, 0, -27758, 0, -17300, 0, -27757, 0, -17299, 0, -27756, 0, -17298, 0, -27755, 0, -17297, 0, -27754, 0, -17296, 0, -27753, 0, -17295, 0, -27752, 0, -17294, 0, -27751, 0, -17293, 0, -27750, 0, -17292, 0, -27749, 0, -17291, 0, -27748, 0, -17290, 0, -27747, 0, -17289, 0, -27746, 0, -17288, 0, -27745, 0, -17287, 0, -27744, 0, -17286, 0, -27743, 0, -17285, 0, -27742, 0, -17284, 0, -27741, 0, -17283, 0, -27740, 0, -17282, 0, -27739, 0, -17281, 0, -27738, 0, -17280, 0, -27737, 0, -17279, 0, -27736, 0, -17278, 0, -27735, 0, -17277, 0, -27734, 0, -17274, 0, -27733, 0, -17273, 0, -27732, 0, -17271, 0, -27731, 0, -17270, 0, -27730, 0, -17267, 0, -27729, 0, -17265, 0, -27728, 0, -17264, 0, -27727, 0, -17263, 0, -27726, 0, -17262, 0, -27725, 0, -17261, 0, -27724, 0, -17258, 0, -27723, 0, -17256, 0, -27722, 0, -17253, 0, -27721, 0, -17252, 0, -27720, 0, -17251, 0, -27719, 0, -17250, 0, -27718, 0, -17249, 0, -27717, 0, -17246, 0, -27716, 0, -17245, 0, -27715, 0, -17243, 0, -27714, 0, -17242, 0, -27713, 0, -17239, 0, -27712, 0, -17238, 0, -27711, 0, -17237, 0, -27710, 0, -17236, 0, -27709, 0, -17235, 0, -27708, 0, -17234, 0, -27707, 0, -17233, 0, -27706, 0, -17230, 0, -27705, 0, -17226, 0, -27704, 0, -17225, 0, -27703, 0, -17224, 0, -27702, 0, -17223, 0, -27701, 0, -17222, 0, -27700, 0, -17221, 0, -27699, 0, -17218, 0, -27698, 0, -17217, 0, -27697, 0, -17215, 0, -27696, 0, -17214, 0, -27695, 0, -17213, 0, -27694, 0, -17211, 0, -27693, 0, -17210, 0, -27692, 0, -17209, 0, -27691, 0, -17208, 0, -27690, 0, -17207, 0, -27689, 0, -17206, 0, -27688, 0, -17205, 0, -27687, 0, -17204, 0, -27686, 0, -17202, 0, -27685, 0, -17198, 0, -27684, 0, -17197, 0, -27683, 0, -17196, 0, -27682, 0, -17194, 0, -27681, 0, -17193, 0, -27680, 0, -17191, 0, -27679, 0, -17190, 0, -27678, 0, -17189, 0, -27677, 0, -17187, 0, -27676, 0, -17186, 0, -27675, 0, -17185, 0, -27674, 0, -17184, 0, -27673, 0, -17183, 0, -27672, 0, -17182, 0, -27671, 0, -17181, 0, -27670, 0, -17180, 0, -27669, 0, -17179, 0, -27668, 0, -17178, 0, -27667, 0, -17177, 0, -27666, 0, -17176, 0, -27665, 0, -17175, 0, -27664, 0, -17174, 0, -27663, 0, -17173, 0, -27662, 0, -17172, 0, -27661, 0, -17171, 0, -27660, 0, -17170, 0, -27659, 0, -17169, 0, -27658, 0, -17168, 0, -27657, 0, -17167, 0, -27656, 0, -17166, 0, -27655, 0, -17165, 0, -27654, 0, -17161, 0, -27653, 0, -17159, 0, -27652, 0, -17158, 0, -27651, 0, -17157, 0, -27650, 0, -17155, 0, -27583, 0, -17154, 0, -27582, 0, -17153, 0, -27581, 0, -17152, 0, -27580, 0, -17151, 0, -27579, 0, -17150, 0, -27578, 0, -17149, 0, -27577, 0, -17146, 0, -27576, 0, -17144, 0, -27575, 0, -17142, 0, -27574, 0, -17141, 0, -27573, 0, -17140, 0, -27572, 0, -17139, 0, -27571, 0, -17138, 0, -27570, 0, -17137, 0, -27569, 0, -17135, 0, -27568, 0, -17134, 0, -27567, 0, -17133, 0, -27566, 0, -17131, 0, -27565, 0, -17130, 0, -27564, 0, -17129, 0, -27563, 0, -17128, 0, -27562, 0, -17127, 0, -27561, 0, -17126, 0, -27560, 0, -17125, 0, -27559, 0, -17124, 0, -27558, 0, -17123, 0, -27551, 0, -17122, 0, -27550, 0, -17121, 0, -27549, 0, -17120, 0, -27548, 0, -17119, 0, -27547, 0, -17118, 0, -27546, 0, -17117, 0, -27545, 0, -17115, 0, -27544, 0, -17114, 0, -27543, 0, -17113, 0, -27542, 0, -17112, 0, -27541, 0, -17111, 0, -27540, 0, -17110, 0, -27539, 0, -17109, 0, -27538, 0, -17107, 0, -27537, 0, -17106, 0, -27536, 0, -17105, 0, -27535, 0, -17104, 0, -27534, 0, -17103, 0, -27533, 0, -17102, 0, -27532, 0, -17101, 0, -27531, 0, -17100, 0, -27530, 0, -17099, 0, -27529, 0, -17098, 0, -27528, 0, -17097, 0, -27527, 0, -17096, 0, -27526, 0, -17095, 0, -27519, 0, -17094, 0, -27518, 0, -17093, 0, -27517, 0, -17092, 0, -27516, 0, -17091, 0, -27515, 0, -17090, 0, -27514, 0, -17089, 0, -27513, 0, -17087, 0, -27512, 0, -17086, 0, -27511, 0, -17085, 0, -27510, 0, -17084, 0, -27509, 0, -17083, 0, -27508, 0, -17082, 0, -27507, 0, -17081, 0, -27506, 0, -17078, 0, -27505, 0, -17077, 0, -27504, 0, -17075, 0, -27503, 0, -17074, 0, -27502, 0, -17073, 0, -27501, 0, -17071, 0, -27500, 0, -17070, 0, -27499, 0, -17069, 0, -27498, 0, -17068, 0, -27497, 0, -17067, 0, -27496, 0, -17066, 0, -27495, 0, -17065, 0, -27494, 0, -17062, 0, -27493, 0, -17061, 0, -27492, 0, -17060, 0, -27491, 0, -17059, 0, -27490, 0, -17058, 0, -27489, 0, -17057, 0, -27488, 0, -17056, 0, -27487, 0, -17055, 0, -27486, 0, -17054, 0, -27485, 0, -17053, 0, -27484, 0, -17051, 0, -27483, 0, -17050, 0, -27482, 0, -17049, 0, -27481, 0, -17047, 0, -27480, 0, -17046, 0, -27479, 0, -17045, 0, -27478, 0, -17044, 0, -27477, 0, -17043, 0, -27476, 0, -17042, 0, -27475, 0, -17041, 0, -27474, 0, -17040, 0, -27473, 0, -17039, 0, -27472, 0, -17038, 0, -27471, 0, -17037, 0, -27470, 0, -17036, 0, -27469, 0, -17035, 0, -27468, 0, -17034, 0, -27467, 0, -17033, 0, -27466, 0, -17032, 0, -27465, 0, -17031, 0, -27464, 0, -17030, 0, -27463, 0, -17029, 0, -27462, 0, -17028, 0, -27461, 0, -17027, 0, -27460, 0, -17026, 0, -27459, 0, -17025, 0, -27458, 0, -17022, 0, -27457, 0, -17021, 0, -27456, 0, -17019, 0, -27455, 0, -17018, 0, -27454, 0, -17013, 0, -27453, 0, -17012, 0, -27452, 0, -17011, 0, -27451, 0, -17010, 0, -27450, 0, -17009, 0, -27449, 0, -17006, 0, -27448, 0, -17004, 0, -27447, 0, -17002, 0, -27446, 0, -17001, 0, -27445, 0, -17000, 0, -27444, 0, -16997, 0, -27443, 0, -16995, 0, -27442, 0, -16994, 0, -27441, 0, -16993, 0, -27440, 0, -16992, 0, -27439, 0, -16991, 0, -27438, 0, -16990, 0, -27437, 0, -16989, 0, -27436, 0, -16987, 0, -27435, 0, -16986, 0, -27434, 0, -16985, 0, -27433, 0, -16984, 0, -27432, 0, -16983, 0, -27431, 0, -16982, 0, -27430, 0, -16981, 0, -27429, 0, -16980, 0, -27428, 0, -16979, 0, -27427, 0, -16978, 0, -27426, 0, -16977, 0, -27425, 0, -16975, 0, -27424, 0, -16974, 0, -27423, 0, -16973, 0, -27422, 0, -16972, 0, -27421, 0, -16971, 0, -27420, 0, -16970, 0, -27419, 0, -16969, 0, -27418, 0, -16967, 0, -27417, 0, -16966, 0, -27416, 0, -16965, 0, -27415, 0, -16964, 0, -27414, 0, -16963, 0, -27413, 0, -16962, 0, -27412, 0, -16961, 0, -27411, 0, -16960, 0, -27410, 0, -16959, 0, -27409, 0, -16958, 0, -27408, 0, -16957, 0, -27407, 0, -16956, 0, -27406, 0, -16955, 0, -27405, 0, -16954, 0, -27404, 0, -16953, 0, -27403, 0, -16952, 0, -27402, 0, -16951, 0, -27401, 0, -16950, 0, -27400, 0, -16949, 0, -27399, 0, -16948, 0, -27398, 0, -16947, 0, -27397, 0, -16946, 0, -27396, 0, -16945, 0, -27395, 0, -16944, 0, -27394, 0, -16943, 0, -27327, 0, -16942, 0, -27326, 0, -16941, 0, -27325, 0, -16938, 0, -27324, 0, -16937, 0, -27323, 0, -16935, 0, -27322, 0, -16934, 0, -27321, 0, -16933, 0, -27320, 0, -16931, 0, -27319, 0, -16930, 0, -27318, 0, -16929, 0, -27317, 0, -16928, 0, -27316, 0, -16927, 0, -27315, 0, -16926, 0, -27314, 0, -16925, 0, -27313, 0, -16924, 0, -27312, 0, -16923, 0, -27311, 0, -16922, 0, -27310, 0, -16921, 0, -27309, 0, -16920, 0, -27308, 0, -16918, 0, -27307, 0, -16917, 0, -27306, 0, -16916, 0, -27305, 0, -16915, 0, -27304, 0, -16914, 0, -27303, 0, -16913, 0, -27302, 0, -16911, 0, -27295, 0, -16910, 0, -27294, 0, -16909, 0, -27293, 0, -16907, 0, -27292, 0, -16906, 0, -27291, 0, -16905, 0, -27290, 0, -16903, 0, -27289, 0, -16902, 0, -27288, 0, -16901, 0, -27287, 0, -16900, 0, -27286, 0, -16899, 0, -27285, 0, -16898, 0, -27284, 0, -16897, 0, -27283, 0, -16895, 0, -27282, 0, -16894, 0, -27281, 0, -16892, 0, -27280, 0, -16890, 0, -27279, 0, -16889, 0, -27278, 0, -16888, 0, -27277, 0, -16887, 0, -27276, 0, -16886, 0, -27275, 0, -16885, 0, -27274, 0, -16882, 0, -27273, 0, -16881, 0, -27272, 0, -16879, 0, -27271, 0, -16878, 0, -27270, 0, -16877, 0, -27263, 0, -16875, 0, -27262, 0, -16874, 0, -27261, 0, -16873, 0, -27260, 0, -16872, 0, -27259, 0, -16871, 0, -27258, 0, -16870, 0, -27257, 0, -16869, 0, -27256, 0, -16866, 0, -27255, 0, -16864, 0, -27254, 0, -16863, 0, -27253, 0, -16862, 0, -27252, 0, -16861, 0, -27251, 0, -16860, 0, -27250, 0, -16859, 0, -27249, 0, -16858, 0, -27248, 0, -16857, 0, -27247, 0, -16856, 0, -27246, 0, -16855, 0, -27245, 0, -16854, 0, -27244, 0, -16853, 0, -27243, 0, -16852, 0, -27242, 0, -16851, 0, -27241, 0, -16850, 0, -27240, 0, -16849, 0, -27239, 0, -16848, 0, -27238, 0, -16847, 0, -27237, 0, -16846, 0, -27236, 0, -16845, 0, -27235, 0, -16844, 0, -27234, 0, -16843, 0, -27233, 0, -16842, 0, -27232, 0, -16841, 0, -27231, 0, -16840, 0, -27230, 0, -16839, 0, -27229, 0, -16838, 0, -27228, 0, -16837, 0, -27227, 0, -16836, 0, -27226, 0, -16835, 0, -27225, 0, -16834, 0, -27224, 0, -16833, 0, -27223, 0, -16832, 0, -27222, 0, -16831, 0, -27221, 0, -16830, 0, -27220, 0, -16829, 0, -27219, 0, -16826, 0, -27218, 0, -16825, 0, -27217, 0, -16823, 0, -27216, 0, -16822, 0, -27215, 0, -16821, 0, -27214, 0, -16819, 0, -27213, 0, -16817, 0, -27212, 0, -16816, 0, -27211, 0, -16815, 0, -27210, 0, -16814, 0, -27209, 0, -16813, 0, -27208, 0, -16810, 0, -27207, 0, -16808, 0, -27206, 0, -16804, 0, -27205, 0, -16803, 0, -27204, 0, -16802, 0, -27203, 0, -16801, 0, -27202, 0, -16798, 0, -27201, 0, -16797, 0, -27200, 0, -16795, 0, -27199, 0, -16794, 0, -27198, 0, -16793, 0, -27197, 0, -16791, 0, -27196, 0, -16789, 0, -27195, 0, -16788, 0, -27194, 0, -16787, 0, -27193, 0, -16786, 0, -27192, 0, -16785, 0, -27191, 0, -16782, 0, -27190, 0, -16778, 0, -27189, 0, -16777, 0, -27188, 0, -16776, 0, -27187, 0, -16775, 0, -27186, 0, -16774, 0, -27185, 0, -16770, 0, -27184, 0, -16769, 0, -27183, 0, -16767, 0, -27182, 0, -16766, 0, -27181, 0, -16765, 0, -27180, 0, -16763, 0, -27179, 0, -16762, 0, -27178, 0, -16761, 0, -27177, 0, -16760, 0, -27176, 0, -16759, 0, -27175, 0, -16758, 0, -27174, 0, -16757, 0, -27173, 0, -16754, 0, -27172, 0, -16750, 0, -27171, 0, -16749, 0, -27170, 0, -16748, 0, -27169, 0, -16747, 0, -27168, 0, -16746, 0, -27167, 0, -16745, 0, -27166, 0, -16742, 0, -27165, 0, -16741, 0, -27164, 0, -16740, 0, -27163, 0, -16739, 0, -27162, 0, -16738, 0, -27161, 0, -16737, 0, -27160, 0, -16736, 0, -27159, 0, -16735, 0, -27158, 0, -16734, 0, -27157, 0, -16733, 0, -27156, 0, -16732, 0, -27155, 0, -16731, 0, -27154, 0, -16730, 0, -27153, 0, -16729, 0, -27152, 0, -16727, 0, -27151, 0, -16726, 0, -27150, 0, -16725, 0, -27149, 0, -16724, 0, -27148, 0, -16723, 0, -27147, 0, -16722, 0, -27146, 0, -16721, 0, -27145, 0, -16720, 0, -27144, 0, -16719, 0, -27143, 0, -16718, 0, -27142, 0, -16717, 0, -27141, 0, -16716, 0, -27140, 0, -16715, 0, -27139, 0, -16714, 0, -27138, 0, -16713, 0, -27071, 0, -16712, 0, -27070, 0, -16711, 0, -27069, 0, -16710, 0, -27068, 0, -16709, 0, -27067, 0, -16708, 0, -27066, 0, -16707, 0, -27065, 0, -16706, 0, -27064, 0, -16705, 0, -27063, 0, -16704, 0, -27062, 0, -16703, 0, -27061, 0, -16702, 0, -27060, 0, -16701, 0, -27059, 0, -16700, 0, -27058, 0, -16699, 0, -27057, 0, -16698, 0, -27056, 0, -16697, 0, -27055, 0, -16696, 0, -27054, 0, -16695, 0, -27053, 0, -16694, 0, -27052, 0, -16693, 0, -27051, 0, -16692, 0, -27050, 0, -16691, 0, -27049, 0, -16690, 0, -27048, 0, -16689, 0, -27047, 0, -16686, 0, -27046, 0, -16685, 0, -27039, 0, -16683, 0, -27038, 0, -16682, 0, -27037, 0, -16679, 0, -27036, 0, -16678, 0, -27035, 0, -16677, 0, -27034, 0, -16676, 0, -27033, 0, -16675, 0, -27032, 0, -16674, 0, -27031, 0, -16673, 0, -27030, 0, -16671, 0, -27029, 0, -16670, 0, -27028, 0, -16666, 0, -27027, 0, -16665, 0, -27026, 0, -16664, 0, -27025, 0, -16663, 0, -27024, 0, -16662, 0, -27023, 0, -16661, 0, -27022, 0, -16659, 0, -27021, 0, -16658, 0, -27020, 0, -16657, 0, -27019, 0, -16656, 0, -27018, 0, -16655, 0, -27017, 0, -16654, 0, -27016, 0, -16653, 0, -27015, 0, -16652, 0, -27014, 0, -16651, 0, -27007, 0, -16650, 0, -27006, 0, -16649, 0, -27005, 0, -16648, 0, -27004, 0, -16647, 0, -27003, 0, -16646, 0, -27002, 0, -16645, 0, -27001, 0, -16644, 0, -27000, 0, -16643, 0, -26999, 0, -16642, 0, -26998, 0, -16641, 0, -26997, 0, -16640, 0, -26996, 0, -16638, 0, -26995, 0, -16637, 0, -26994, 0, -16636, 0, -26993, 0, -16635, 0, -26992, 0, -16634, 0, -26991, 0, -16633, 0, -26990, 0, -16630, 0, -26989, 0, -16629, 0, -26988, 0, -16628, 0, -26987, 0, -16627, 0, -26986, 0, -16626, 0, -26985, 0, -16625, 0, -26984, 0, -16624, 0, -26983, 0, -16623, 0, -26982, 0, -16622, 0, -26981, 0, -16621, 0, -26980, 0, -16620, 0, -26979, 0, -16619, 0, -26978, 0, -16618, 0, -26977, 0, -16617, 0, -26976, 0, -16614, 0, -26975, 0, -16610, 0, -26974, 0, -16609, 0, -26973, 0, -16608, 0, -26972, 0, -16607, 0, -26971, 0, -16606, 0, -26970, 0, -16605, 0, -26969, 0, -16604, 0, -26968, 0, -16603, 0, -26967, 0, -16602, 0, -26966, 0, -16601, 0, -26965, 0, -16600, 0, -26964, 0, -16599, 0, -26963, 0, -16598, 0, -26962, 0, -16597, 0, -26961, 0, -16596, 0, -26960, 0, -16595, 0, -26959, 0, -16594, 0, -26958, 0, -16593, 0, -26957, 0, -16592, 0, -26956, 0, -16591, 0, -26955, 0, -16590, 0, -26954, 0, -16589, 0, -26953, 0, -16588, 0, -26952, 0, -16587, 0, -26951, 0, -16586, 0, -26950, 0, -16585, 0, -26949, 0, -16584, 0, -26948, 0, -16583, 0, -26947, 0, -16582, 0, -26946, 0, -16581, 0, -26945, 0, -16580, 0, -26944, 0, -16579, 0, -26943, 0, -16578, 0, -26942, 0, -16577, 0, -26941, 0, -16574, 0, -26940, 0, -16573, 0, -26939, 0, -16571, 0, -26938, 0, -16570, 0, -26937, 0, -16569, 0, -26936, 0, -16567, 0, -26935, 0, -16566, 0, -26934, 0, -16565, 0, -26933, 0, -16564, 0, -26932, 0, -16563, 0, -26931, 0, -16562, 0, -26930, 0, -16561, 0, -26929, 0, -16558, 0, -26928, 0, -16557, 0, -26927, 0, -16556, 0, -26926, 0, -16554, 0, -26925, 0, -16553, 0, -26924, 0, -16552, 0, -26923, 0, -16551, 0, -26922, 0, -16550, 0, -26921, 0, -16549, 0, -26920, 0, -16548, 0, -26919, 0, -16547, 0, -26918, 0, -16546, 0, -26917, 0, -16545, 0, -26916, 0, -16544, 0, -26915, 0, -16543, 0, -26914, 0, -16542, 0, -26913, 0, -16541, 0, -26912, 0, -16540, 0, -26911, 0, -16539, 0, -26910, 0, -16538, 0, -26909, 0, -16537, 0, -26908, 0, -16536, 0, -26907, 0, -16535, 0, -26906, 0, -16534, 0, -26905, 0, -16533, 0, -26904, 0, -16532, 0, -26903, 0, -16531, 0, -26902, 0, -16530, 0, -26901, 0, -16529, 0, -26900, 0, -16528, 0, -26899, 0, -16527, 0, -26898, 0, -16526, 0, -26897, 0, -16525, 0, -26896, 0, -16524, 0, -26895, 0, -16523, 0, -26894, 0, -16522, 0, -26893, 0, -16521, 0, -26892, 0, -16520, 0, -26891, 0, -16519, 0, -26890, 0, -16518, 0, -26889, 0, -16517, 0, -26888, 0, -16516, 0, -26887, 0, -16515, 0, -26886, 0, -16514, 0, -26885, 0, -16513, 0, -26884, 0, -16512, 0, -26883, 0, -16511, 0, -26882, 0, -16510, 0, -26815, 0, -16509, 0, -26814, 0, -16508, 0, -26813, 0, -16507, 0, -26812, 0, -16506, 0, -26811, 0, -16505, 0, -26810, 0, -16504, 0, -26809, 0, -16503, 0, -26808, 0, -16502, 0, -26807, 0, -16501, 0, -26806, 0, -16500, 0, -26805, 0, -16499, 0, -26804, 0, -16498, 0, -26803, 0, -16497, 0, -26802, 0, -16496, 0, -26801, 0, -16495, 0, -26800, 0, -16494, 0, -26799, 0, -16493, 0, -26798, 0, -16491, 0, -26797, 0, -16490, 0, -26796, 0, -16489, 0, -26795, 0, -16488, 0, -26794, 0, -16487, 0, -26793, 0, -16486, 0, -26792, 0, -16485, 0, -26791, 0, -16484, 0, -26790, 0, -16483, 0, -26783, 0, -16482, 0, -26782, 0, -16481, 0, -26781, 0, -16480, 0, -26780, 0, -16479, 0, -26779, 0, -16478, 0, -26778, 0, -16477, 0, -26777, 0, -16476, 0, -26776, 0, -16475, 0, -26775, 0, -16474, 0, -26774, 0, -16473, 0, -26773, 0, -16472, 0, -26772, 0, -16471, 0, -26771, 0, -16470, 0, -26770, 0, -16469, 0, -26769, 0, -16468, 0, -26768, 0, -16467, 0, -26767, 0, -16466, 0, -26766, 0, -16465, 0, -26765, 0, -16463, 0, -26764, 0, -16462, 0, -26763, 0, -16461, 0, -26762, 0, -16460, 0, -26761, 0, -16459, 0, -26760, 0, -16458, 0, -26759, 0, -16457, 0, -26758, 0, -16456, 0, -26751, 0, -16455, 0, -26750, 0, -16454, 0, -26749, 0, -16453, 0, -26748, 0, -16452, 0, -26747, 0, -16451, 0, -26746, 0, -16450, 0, -26745, 0, -16449, 0, -26744, 0, -16448, 0, -26743, 0, -16447, 0, -26742, 0, -16446, 0, -26741, 0, -16445, 0, -26740, 0, -16444, 0, -26739, 0, -16442, 0, -26738, 0, -16441, 0, -26737, 0, -16440, 0, -26736, 0, -16439, 0, -26735, 0, -16438, 0, -26734, 0, -16437, 0, -26733, 0, -16434, 0, -26732, 0, -16433, 0, -26731, 0, -16431, 0, -26730, 0, -16430, 0, -26729, 0, -16429, 0, -26728, 0, -16427, 0, -26727, 0, -16426, 0, -26726, 0, -16425, 0, -26725, 0, -16424, 0, -26724, 0, -16423, 0, -26723, 0, -16422, 0, -26722, 0, -16421, 0, -26721, 0, -16419, 0, -26720, 0, -16418, 0, -26719, 0, -16416, 0, -26718, 0, -16414, 0, -26717, 0, -16413, 0, -26716, 0, -16412, 0, -26715, 0, -16411, 0, -26714, 0, -16410, 0, -26713, 0, -16409, 0, -26712, 0, -16408, 0, -26711, 0, -16407, 0, -26710, 0, -16406, 0, -26709, 0, -16405, 0, -26708, 0, -16404, 0, -26707, 0, -16403, 0, -26706, 0, -16402, 0, -26705, 0, -16401, 0, -26704, 0, -16400, 0, -26703, 0, -16399, 0, -26702, 0, -16398, 0, -26701, 0, -16397, 0, -26700, 0, -16396, 0, -26699, 0, -16395, 0, -26698, 0, -16394, 0, -26697, 0, -16393, 0, -26696, 0, -16392, 0, -26695, 0, -16391, 0, -26694, 0, -16390, 0, -26693, 0, -16389, 0, -26692, 0, -16388, 0, -26691, 0, -16387, 0, -26690, 0, -16386, 0, -26689, 0, -16385, 0, -26688, 0, -16384, 0, -26687, 0, -16383, 0, -26686, 0, -16382, 0, -26685, 0, -16381, 0, -26684, 0, -16380, 0, -26683, 0, -16379, 0, -26682, 0, -16378, 0, -26681, 0, -16377, 0, -26680, 0, -16376, 0, -26679, 0, -16375, 0, -26678, 0, -16374, 0, -26677, 0, -16373, 0, -26676, 0, -16372, 0, -26675, 0, -16371, 0, -26674, 0, -16370, 0, -26673, 0, -16369, 0, -26672, 0, -16368, 0, -26671, 0, -16367, 0, -26670, 0, -16366, 0, -26669, 0, -16365, 0, -26668, 0, -16364, 0, -26667, 0, -16363, 0, -26666, 0, -16362, 0, -26665, 0, -16361, 0, -26664, 0, -16360, 0, -26663, 0, -16359, 0, -26662, 0, -16358, 0, -26661, 0, -16357, 0, -26660, 0, -16356, 0, -26659, 0, -16355, 0, -26658, 0, -16354, 0, -26657, 0, -16353, 0, -26656, 0, -16352, 0, -26655, 0, -16351, 0, -26654, 0, -16350, 0, -26653, 0, -16349, 0, -26652, 0, -16348, 0, -26651, 0, -16347, 0, -26650, 0, -16346, 0, -26649, 0, -16345, 0, -26648, 0, -16344, 0, -26647, 0, -16343, 0, -26646, 0, -16342, 0, -26645, 0, -16341, 0, -26644, 0, -16340, 0, -26643, 0, -16339, 0, -26642, 0, -16338, 0, -26641, 0, -16337, 0, -26640, 0, -16336, 0, -26639, 0, -16335, 0, -26638, 0, -16334, 0, -26637, 0, -16333, 0, -26636, 0, -16332, 0, -26635, 0, -16331, 0, -26634, 0, -16330, 0, -26633, 0, -16329, 0, -26632, 0, -16328, 0, -26631, 0, -16327, 0, -26630, 0, -16326, 0, -26629, 0, -16325, 0, -26628, 0, -16323, 0, -26627, 0, -16322, 0, -26626, 0, -16321, 0, -26559, 0, -16320, 0, -26558, 0, -16319, 0, -26557, 0, -16318, 0, -26556, 0, -16317, 0, -26555, 0, -16316, 0, -26554, 0, -16315, 0, -26553, 0, -16314, 0, -26552, 0, -16313, 0, -26551, 0, -16312, 0, -26550, 0, -16311, 0, -26549, 0, -16310, 0, -26548, 0, -16309, 0, -26547, 0, -16308, 0, -26546, 0, -16307, 0, -26545, 0, -16306, 0, -26544, 0, -16305, 0, -26543, 0, -16304, 0, -26542, 0, -16302, 0, -26541, 0, -16301, 0, -26540, 0, -16300, 0, -26539, 0, -16299, 0, -26538, 0, -16298, 0, -26537, 0, -16297, 0, -26536, 0, -16295, 0, -26535, 0, -16294, 0, -26534, 0, -16293, 0, -26527, 0, -16291, 0, -26526, 0, -16290, 0, -26525, 0, -16289, 0, -26524, 0, -16287, 0, -26523, 0, -16286, 0, -26522, 0, -16285, 0, -26521, 0, -16284, 0, -26520, 0, -16283, 0, -26519, 0, -16282, 0, -26518, 0, -16281, 0, -26517, 0, -16278, 0, -26516, 0, -16277, 0, -26515, 0, -16276, 0, -26514, 0, -16275, 0, -26513, 0, -16274, 0, -26512, 0, -16273, 0, -26511, 0, -16272, 0, -26510, 0, -16271, 0, -26509, 0, -16270, 0, -26508, 0, -16269, 0, -26507, 0, -16268, 0, -26506, 0, -16267, 0, -26505, 0, -16266, 0, -26504, 0, -16265, 0, -26503, 0, -16264, 0, -26502, 0, -16263, 0, -26495, 0, -16262, 0, -26494, 0, -16261, 0, -26493, 0, -16260, 0, -26492, 0, -16259, 0, -26491, 0, -16258, 0, -26490, 0, -16257, 0, -26489, 0, -16256, 0, -26488, 0, -16255, 0, -26487, 0, -16254, 0, -26486, 0, -16253, 0, -26485, 0, -16252, 0, -26484, 0, -16251, 0, -26483, 0, -16250, 0, -26482, 0, -16249, 0, -26481, 0, -16248, 0, -26480, 0, -16247, 0, -26479, 0, -16246, 0, -26478, 0, -16245, 0, -26477, 0, -16244, 0, -26476, 0, -16243, 0, -26475, 0, -16242, 0, -26474, 0, -16241, 0, -26473, 0, -16238, 0, -26472, 0, -16237, 0, -26471, 0, -16235, 0, -26470, 0, -16234, 0, -26469, 0, -16233, 0, -26468, 0, -16231, 0, -26467, 0, -16230, 0, -26466, 0, -16229, 0, -26465, 0, -16228, 0, -26464, 0, -16227, 0, -26463, 0, -16226, 0, -26462, 0, -16225, 0, -26461, 0, -16222, 0, -26460, 0, -16220, 0, -26459, 0, -16218, 0, -26458, 0, -16217, 0, -26457, 0, -16216, 0, -26456, 0, -16215, 0, -26455, 0, -16214, 0, -26454, 0, -16213, 0, -26453, 0, -16210, 0, -26452, 0, -16207, 0, -26451, 0, -16206, 0, -26450, 0, -16201, 0, -26449, 0, -16200, 0, -26448, 0, -16199, 0, -26447, 0, -16198, 0, -26446, 0, -16197, 0, -26445, 0, -16194, 0, -26444, 0, -16190, 0, -26443, 0, -16189, 0, -26442, 0, -16188, 0, -26441, 0, -16186, 0, -26440, 0, -16185, 0, -26439, 0, -16182, 0, -26438, 0, -16181, 0, -26437, 0, -16179, 0, -26436, 0, -16178, 0, -26435, 0, -16177, 0, -26434, 0, -16175, 0, -26433, 0, -16174, 0, -26432, 0, -16173, 0, -26431, 0, -16172, 0, -26430, 0, -16171, 0, -26429, 0, -16170, 0, -26428, 0, -16169, 0, -26427, 0, -16166, 0, -26426, 0, -16162, 0, -26425, 0, -16161, 0, -26424, 0, -16160, 0, -26423, 0, -16159, 0, -26422, 0, -16158, 0, -26421, 0, -16157, 0, -26420, 0, -16154, 0, -26419, 0, -16153, 0, -26418, 0, -16151, 0, -26417, 0, -16150, 0, -26416, 0, -16149, 0, -26415, 0, -16147, 0, -26414, 0, -16146, 0, -26413, 0, -16145, 0, -26412, 0, -16144, 0, -26411, 0, -16143, 0, -26410, 0, -16142, 0, -26409, 0, -16141, 0, -26408, 0, -16138, 0, -26407, 0, -16136, 0, -26406, 0, -16134, 0, -26405, 0, -16133, 0, -26404, 0, -16132, 0, -26403, 0, -16131, 0, -26402, 0, -16130, 0, -26401, 0, -16129, 0, -26400, 0, -16127, 0, -26399, 0, -16126, 0, -26398, 0, -16125, 0, -26397, 0, -16123, 0, -26396, 0, -16122, 0, -26395, 0, -16121, 0, -26394, 0, -16119, 0, -26393, 0, -16118, 0, -26392, 0, -16117, 0, -26391, 0, -16116, 0, -26390, 0, -16115, 0, -26389, 0, -16114, 0, -26388, 0, -16113, 0, -26387, 0, -16111, 0, -26386, 0, -16110, 0, -26385, 0, -16109, 0, -26384, 0, -16108, 0, -26383, 0, -16106, 0, -26382, 0, -16105, 0, -26381, 0, -16104, 0, -26380, 0, -16103, 0, -26379, 0, -16102, 0, -26378, 0, -16101, 0, -26377, 0, -16095, 0, -26376, 0, -16094, 0, -26375, 0, -16091, 0, -26374, 0, -16088, 0, -26373, 0, -16087, 0, -26372, 0, -16086, 0, -26371, 0, -16085, 0, -26370, 0, -16082, 0, -26303, 0, -16078, 0, -26302, 0, -16077, 0, -26301, 0, -16076, 0, -26300, 0, -16075, 0, -26299, 0, -16073, 0, -26298, 0, -16070, 0, -26297, 0, -16069, 0, -26296, 0, -16067, 0, -26295, 0, -16066, 0, -26294, 0, -16065, 0, -26293, 0, -16063, 0, -26292, 0, -16062, 0, -26291, 0, -16061, 0, -26290, 0, -16060, 0, -26289, 0, -16059, 0, -26288, 0, -16058, 0, -26287, 0, -16057, 0, -26286, 0, -16054, 0, -26285, 0, -16050, 0, -26284, 0, -16049, 0, -26283, 0, -16048, 0, -26282, 0, -16047, 0, -26281, 0, -16046, 0, -26280, 0, -16045, 0, -26279, 0, -16042, 0, -26278, 0, -16041, 0, -26271, 0, -16039, 0, -26270, 0, -16038, 0, -26269, 0, -16037, 0, -26268, 0, -16035, 0, -26267, 0, -16034, 0, -26266, 0, -16033, 0, -26265, 0, -16032, 0, -26264, 0, -16031, 0, -26263, 0, -16030, 0, -26262, 0, -16029, 0, -26261, 0, -16026, 0, -26260, 0, -16022, 0, -26259, 0, -16021, 0, -26258, 0, -16020, 0, -26257, 0, -16019, 0, -26256, 0, -16018, 0, -26255, 0, -16017, 0, -26254, 0, -16015, 0, -26253, 0, -16014, 0, -26252, 0, -16013, 0, -26251, 0, -16011, 0, -26250, 0, -16010, 0, -26249, 0, -16009, 0, -26248, 0, -16007, 0, -26247, 0, -16006, 0, -26246, 0, -16005, 0, -26239, 0, -16004, 0, -26238, 0, -16003, 0, -26237, 0, -16002, 0, -26236, 0, -16001, 0, -26235, 0, -16000, 0, -26234, 0, -15999, 0, -26233, 0, -15998, 0, -26232, 0, -15997, 0, -26231, 0, -15996, 0, -26230, 0, -15994, 0, -26229, 0, -15993, 0, -26228, 0, -15992, 0, -26227, 0, -15991, 0, -26226, 0, -15990, 0, -26225, 0, -15989, 0, -26224, 0, -15985, 0, -26223, 0, -15983, 0, -26222, 0, -15982, 0, -26221, 0, -15981, 0, -26220, 0, -15979, 0, -26219, 0, -15977, 0, -26218, 0, -15976, 0, -26217, 0, -15975, 0, -26216, 0, -15974, 0, -26215, 0, -15973, 0, -26214, 0, -15970, 0, -26213, 0, -15968, 0, -26212, 0, -15966, 0, -26211, 0, -15965, 0, -26210, 0, -15964, 0, -26209, 0, -15962, 0, -26208, 0, -15961, 0, -26207, 0, -15958, 0, -26206, 0, -15957, 0, -26205, 0, -15955, 0, -26204, 0, -15954, 0, -26203, 0, -15953, 0, -26202, 0, -15951, 0, -26201, 0, -15950, 0, -26200, 0, -15949, 0, -26199, 0, -15948, 0, -26198, 0, -15947, 0, -26197, 0, -15946, 0, -26196, 0, -15945, 0, -26195, 0, -15944, 0, -26194, 0, -15943, 0, -26193, 0, -15942, 0, -26192, 0, -15941, 0, -26191, 0, -15940, 0, -26190, 0, -15938, 0, -26189, 0, -15937, 0, -26188, 0, -15936, 0, -26187, 0, -15935, 0, -26186, 0, -15934, 0, -26185, 0, -15933, 0, -26184, 0, -15931, 0, -26183, 0, -15930, 0, -26182, 0, -15929, 0, -26181, 0, -15927, 0, -26180, 0, -15926, 0, -26179, 0, -15925, 0, -26178, 0, -15923, 0, -26177, 0, -15922, 0, -26176, 0, -15921, 0, -26175, 0, -15920, 0, -26174, 0, -15919, 0, -26173, 0, -15918, 0, -26172, 0, -15917, 0, -26171, 0, -15915, 0, -26170, 0, -15914, 0, -26169, 0, -15911, 0, -26168, 0, -15910, 0, -26167, 0, -15909, 0, -26166, 0, -15908, 0, -26165, 0, -15907, 0, -26164, 0, -15906, 0, -26163, 0, -15905, 0, -26162, 0, -15903, 0, -26161, 0, -15902, 0, -26160, 0, -15901, 0, -26159, 0, -15899, 0, -26158, 0, -15898, 0, -26157, 0, -15897, 0, -26156, 0, -15895, 0, -26155, 0, -15894, 0, -26154, 0, -15893, 0, -26153, 0, -15892, 0, -26152, 0, -15891, 0, -26151, 0, -15890, 0, -26150, 0, -15889, 0, -26149, 0, -15886, 0, -26148, 0, -15884, 0, -26147, 0, -15883, 0, -26146, 0, -15882, 0, -26145, 0, -15881, 0, -26144, 0, -15880, 0, -26143, 0, -15879, 0, -26142, 0, -15878, 0, -26141, 0, -15877, 0, -26140, 0, -15874, 0, -26139, 0, -15873, 0, -26138, 0, -15871, 0, -26137, 0, -15870, 0, -26136, 0, -15869, 0, -26135, 0, -15867, 0, -26134, 0, -15866, 0, -26133, 0, -15865, 0, -26132, 0, -15864, 0, -26131, 0, -15863, 0, -26130, 0, -15862, 0, -26129, 0, -15861, 0, -26128, 0, -15858, 0, -26127, 0, -15856, 0, -26126, 0, -15854, 0, -26125, 0, -15853, 0, -26124, 0, -15852, 0, -26123, 0, -15851, 0, -26122, 0, -15850, 0, -26121, 0, -15849, 0, -26120, 0, -15846, 0, -26119, 0, -15845, 0, -26118, 0, -15843, 0, -26117, 0, -15842, 0, -26116, 0, -15839, 0, -26115, 0, -15838, 0, -26114, 0, -15837, 0, -26047, 0, -15836, 0, -26046, 0, -15835, 0, -26045, 0, -15834, 0, -26044, 0, -15833, 0, -26043, 0, -15830, 0, -26042, 0, -15828, 0, -26041, 0, -15826, 0, -26040, 0, -15824, 0, -26039, 0, -15821, 0, -26038, 0, -15819, 0, -26037, 0, -15818, 0, -26036, 0, -15817, 0, -26035, 0, -15816, 0, -26034, 0, -15815, 0, -26033, 0, -15814, 0, -26032, 0, -15813, 0, -26031, 0, -15812, 0, -26030, 0, -15811, 0, -26029, 0, -15810, 0, -26028, 0, -15809, 0, -26027, 0, -15808, 0, -26026, 0, -15807, 0, -26025, 0, -15806, 0, -26024, 0, -15805, 0, -26023, 0, -15804, 0, -26022, 0, -15803, 0, -26015, 0, -15802, 0, -26014, 0, -15801, 0, -26013, 0, -15799, 0, -26012, 0, -15798, 0, -26011, 0, -15797, 0, -26010, 0, -15796, 0, -26009, 0, -15795, 0, -26008, 0, -15794, 0, -26007, 0, -15793, 0, -26006, 0, -15790, 0, -26005, 0, -15789, 0, -26004, 0, -15787, 0, -26003, 0, -15786, 0, -26002, 0, -15785, 0, -26001, 0, -15783, 0, -26000, 0, -15782, 0, -25999, 0, -15781, 0, -25998, 0, -15780, 0, -25997, 0, -15779, 0, -25996, 0, -15778, 0, -25995, 0, -15777, 0, -25994, 0, -15775, 0, -25993, 0, -15774, 0, -25992, 0, -15773, 0, -25991, 0, -15772, 0, -25990, 0, -15770, 0, -25983, 0, -15769, 0, -25982, 0, -15768, 0, -25981, 0, -15767, 0, -25980, 0, -15766, 0, -25979, 0, -15765, 0, -25978, 0, -15762, 0, -25977, 0, -15761, 0, -25976, 0, -15759, 0, -25975, 0, -15758, 0, -25974, 0, -15757, 0, -25973, 0, -15755, 0, -25972, 0, -15754, 0, -25971, 0, -15753, 0, -25970, 0, -15752, 0, -25969, 0, -15751, 0, -25968, 0, -15750, 0, -25967, 0, -15749, 0, -25966, 0, -15746, 0, -25965, 0, -15744, 0, -25964, 0, -15742, 0, -25963, 0, -15741, 0, -25962, 0, -15740, 0, -25961, 0, -15739, 0, -25960, 0, -15738, 0, -25959, 0, -15737, 0, -25958, 0, -15734, 0, -25957, 0, -15733, 0, -25956, 0, -15732, 0, -25955, 0, -15731, 0, -25954, 0, -15730, 0, -25953, 0, -15729, 0, -25952, 0, -15727, 0, -25951, 0, -15726, 0, -25950, 0, -15725, 0, -25949, 0, -15724, 0, -25948, 0, -15723, 0, -25947, 0, -15722, 0, -25946, 0, -15721, 0, -25945, 0, -15719, 0, -25944, 0, -15718, 0, -25943, 0, -15716, 0, -25942, 0, -15714, 0, -25941, 0, -15713, 0, -25940, 0, -15712, 0, -25939, 0, -15711, 0, -25938, 0, -15710, 0, -25937, 0, -15709, 0, -25936, 0, -15706, 0, -25935, 0, -15705, 0, -25934, 0, -15703, 0, -25933, 0, -15702, 0, -25932, 0, -15701, 0, -25931, 0, -15698, 0, -25930, 0, -15697, 0, -25929, 0, -15696, 0, -25928, 0, -15695, 0, -25927, 0, -15694, 0, -25926, 0, -15693, 0, -25925, 0, -15690, 0, -25924, 0, -15688, 0, -25923, 0, -15686, 0, -25922, 0, -15685, 0, -25921, 0, -15684, 0, -25920, 0, -15683, 0, -25919, 0, -15682, 0, -25918, 0, -15681, 0, -25917, 0, -15680, 0, -25916, 0, -15679, 0, -25915, 0, -15678, 0, -25914, 0, -15677, 0, -25913, 0, -15676, 0, -25912, 0, -15675, 0, -25911, 0, -15674, 0, -25910, 0, -15673, 0, -25909, 0, -15672, 0, -25908, 0, -15671, 0, -25907, 0, -15670, 0, -25906, 0, -15669, 0, -25905, 0, -15668, 0, -25904, 0, -15667, 0, -25903, 0, -15666, 0, -25902, 0, -15665, 0, -25901, 0, -15664, 0, -25900, 0, -15663, 0, -25899, 0, -15662, 0, -25898, 0, -15661, 0, -25897, 0, -15660, 0, -25896, 0, -15659, 0, -25895, 0, -15658, 0, -25894, 0, -15657, 0, -25893, 0, -15656, 0, -25892, 0, -15655, 0, -25891, 0, -15654, 0, -25890, 0, -15653, 0, -25889, 0, -15650, 0, -25888, 0, -15649, 0, -25887, 0, -15647, 0, -25886, 0, -15646, 0, -25885, 0, -15643, 0, -25884, 0, -15642, 0, -25883, 0, -15641, 0, -25882, 0, -15640, 0, -25881, 0, -15639, 0, -25880, 0, -15638, 0, -25879, 0, -15634, 0, -25878, 0, -15632, 0, -25877, 0, -15630, 0, -25876, 0, -15629, 0, -25875, 0, -15628, 0, -25874, 0, -15627, 0, -25873, 0, -15625, 0, -25872, 0, -15622, 0, -25871, 0, -15619, 0, -25870, 0, -15618, 0, -25869, 0, -15617, 0, -25868, 0, -15615, 0, -25867, 0, -15614, 0, -25866, 0, -15613, 0, -25865, 0, -15612, 0, -25864, 0, -15611, 0, -25863, 0, -15610, 0, -25862, 0, -15609, 0, -25861, 0, -15606, 0, -25860, 0, -15605, 0, -25859, 0, -15602, 0, -25858, 0, -15601, 0, -25791, 0, -15600, 0, -25790, 0, -15599, 0, -25789, 0, -15598, 0, -25788, 0, -15594, 0, -25787, 0, -15593, 0, -25786, 0, -15591, 0, -25785, 0, -15590, 0, -25784, 0, -15589, 0, -25783, 0, -15587, 0, -25782, 0, -15586, 0, -25781, 0, -15585, 0, -25780, 0, -15584, 0, -25779, 0, -15583, 0, -25778, 0, -15582, 0, -25777, 0, -15581, 0, -25776, 0, -15578, 0, -25775, 0, -15577, 0, -25774, 0, -15574, 0, -25773, 0, -15573, 0, -25772, 0, -15572, 0, -25771, 0, -15571, 0, -25770, 0, -15570, 0, -25769, 0, -15569, 0, -25768, 0, -15568, 0, -25767, 0, -15567, 0, -25766, 0, -15566, 0, -25759, 0, -15565, 0, -25758, 0, -15564, 0, -25757, 0, -15563, 0, -25756, 0, -15562, 0, -25755, 0, -15561, 0, -25754, 0, -15560, 0, -25753, 0, -15559, 0, -25752, 0, -15558, 0, -25751, 0, -15557, 0, -25750, 0, -15556, 0, -25749, 0, -15555, 0, -25748, 0, -15554, 0, -25747, 0, -15553, 0, -25746, 0, -15552, 0, -25745, 0, -15551, 0, -25744, 0, -15550, 0, -25743, 0, -15549, 0, -25742, 0, -15548, 0, -25741, 0, -15546, 0, -25740, 0, -15545, 0, -25739, 0, -15544, 0, -25738, 0, -15543, 0, -25737, 0, -15542, 0, -25736, 0, -15541, 0, -25735, 0, -15540, 0, -25734, 0, -15539, 0, -25727, 0, -15538, 0, -25726, 0, -15537, 0, -25725, 0, -15536, 0, -25724, 0, -15535, 0, -25723, 0, -15534, 0, -25722, 0, -15533, 0, -25721, 0, -15532, 0, -25720, 0, -15531, 0, -25719, 0, -15530, 0, -25718, 0, -15529, 0, -25717, 0, -15528, 0, -25716, 0, -15527, 0, -25715, 0, -15526, 0, -25714, 0, -15525, 0, -25713, 0, -15524, 0, -25712, 0, -15523, 0, -25711, 0, -15522, 0, -25710, 0, -15521, 0, -25709, 0, -15520, 0, -25708, 0, -15519, 0, -25707, 0, -15518, 0, -25706, 0, -15517, 0, -25705, 0, -15516, 0, -25704, 0, -15515, 0, -25703, 0, -15514, 0, -25702, 0, -15513, 0, -25701, 0, -15510, 0, -25700, 0, -15509, 0, -25699, 0, -15507, 0, -25698, 0, -15506, 0, -25697, 0, -15505, 0, -25696, 0, -15503, 0, -25695, 0, -15501, 0, -25694, 0, -15500, 0, -25693, 0, -15499, 0, -25692, 0, -15498, 0, -25691, 0, -15497, 0, -25690, 0, -15494, 0, -25689, 0, -15493, 0, -25688, 0, -15490, 0, -25687, 0, -15489, 0, -25686, 0, -15488, 0, -25685, 0, -15487, 0, -25684, 0, -15486, 0, -25683, 0, -15485, 0, -25682, 0, -15483, 0, -25681, 0, -15482, 0, -25680, 0, -15481, 0, -25679, 0, -15479, 0, -25678, 0, -15478, 0, -25677, 0, -15477, 0, -25676, 0, -15475, 0, -25675, 0, -15474, 0, -25674, 0, -15473, 0, -25673, 0, -15472, 0, -25672, 0, -15471, 0, -25671, 0, -15470, 0, -25670, 0, -15469, 0, -25669, 0, -15468, 0, -25668, 0, -15467, 0, -25667, 0, -15466, 0, -25666, 0, -15465, 0, -25665, 0, -15464, 0, -25664, 0, -15463, 0, -25663, 0, -15462, 0, -25662, 0, -15461, 0, -25661, 0, -15460, 0, -25660, 0, -15459, 0, -25659, 0, -15458, 0, -25658, 0, -15457, 0, -25657, 0, -15456, 0, -25656, 0, -15455, 0, -25655, 0, -15454, 0, -25654, 0, -15453, 0, -25653, 0, -15452, 0, -25652, 0, -15451, 0, -25651, 0, -15450, 0, -25650, 0, -15449, 0, -25649, 0, -15448, 0, -25648, 0, -15447, 0, -25647, 0, -15446, 0, -25646, 0, -15445, 0, -25645, 0, -15444, 0, -25644, 0, -15443, 0, -25643, 0, -15442, 0, -25642, 0, -15441, 0, -25641, 0, -15440, 0, -25640, 0, -15439, 0, -25639, 0, -15438, 0, -25638, 0, -15437, 0, -25637, 0, -15436, 0, -25636, 0, -15435, 0, -25635, 0, -15434, 0, -25634, 0, -15433, 0, -25633, 0, -15432, 0, -25632, 0, -15431, 0, -25631, 0, -15430, 0, -25630, 0, -15429, 0, -25629, 0, -15428, 0, -25628, 0, -15427, 0, -25627, 0, -15426, 0, -25626, 0, -15425, 0, -25625, 0, -15423, 0, -25624, 0, -15422, 0, -25623, 0, -15421, 0, -25622, 0, -15420, 0, -25621, 0, -15419, 0, -25620, 0, -15418, 0, -25619, 0, -15417, 0, -25618, 0, -15416, 0, -25617, 0, -15415, 0, -25616, 0, -15414, 0, -25615, 0, -15413, 0, -25614, 0, -15412, 0, -25613, 0, -15411, 0, -25612, 0, -15410, 0, -25611, 0, -15409, 0, -25610, 0, -15408, 0, -25609, 0, -15407, 0, -25608, 0, -15406, 0, -25607, 0, -15405, 0, -25606, 0, -15404, 0, -25605, 0, -15403, 0, -25604, 0, -15402, 0, -25603, 0, -15401, 0, -25602, 0, -15398, 0, -25535, 0, -15397, 0, -25534, 0, -15395, 0, -25533, 0, -15394, 0, -25532, 0, -15391, 0, -25531, 0, -15389, 0, -25530, 0, -15388, 0, -25529, 0, -15387, 0, -25528, 0, -15386, 0, -25527, 0, -15385, 0, -25526, 0, -15382, 0, -25525, 0, -15381, 0, -25524, 0, -15380, 0, -25523, 0, -15378, 0, -25522, 0, -15377, 0, -25521, 0, -15376, 0, -25520, 0, -15375, 0, -25519, 0, -15374, 0, -25518, 0, -15373, 0, -25517, 0, -15370, 0, -25516, 0, -15369, 0, -25515, 0, -15367, 0, -25514, 0, -15366, 0, -25513, 0, -15365, 0, -25512, 0, -15364, 0, -25511, 0, -15363, 0, -25510, 0, -15362, 0, -25503, 0, -15361, 0, -25502, 0, -15360, 0, -25501, 0, -15359, 0, -25500, 0, -15358, 0, -25499, 0, -15357, 0, -25498, 0, -15356, 0, -25497, 0, -15355, 0, -25496, 0, -15354, 0, -25495, 0, -15353, 0, -25494, 0, -15351, 0, -25493, 0, -15350, 0, -25492, 0, -15349, 0, -25491, 0, -15348, 0, -25490, 0, -15347, 0, -25489, 0, -15346, 0, -25488, 0, -15345, 0, -25487, 0, -15343, 0, -25486, 0, -15342, 0, -25485, 0, -15341, 0, -25484, 0, -15340, 0, -25483, 0, -15339, 0, -25482, 0, -15338, 0, -25481, 0, -15337, 0, -25480, 0, -15336, 0, -25479, 0, -15335, 0, -25478, 0, -15334, 0, -25471, 0, -15333, 0, -25470, 0, -15332, 0, -25469, 0, -15331, 0, -25468, 0, -15330, 0, -25467, 0, -15329, 0, -25466, 0, -15328, 0, -25465, 0, -15327, 0, -25464, 0, -15326, 0, -25463, 0, -15325, 0, -25462, 0, -15323, 0, -25461, 0, -15322, 0, -25460, 0, -15321, 0, -25459, 0, -15320, 0, -25458, 0, -15319, 0, -25457, 0, -15318, 0, -25456, 0, -15317, 0, -25455, 0, -15315, 0, -25454, 0, -15314, 0, -25453, 0, -15313, 0, -25452, 0, -15311, 0, -25451, 0, -15310, 0, -25450, 0, -15309, 0, -25449, 0, -15307, 0, -25448, 0, -15306, 0, -25447, 0, -15305, 0, -25446, 0, -15304, 0, -25445, 0, -15303, 0, -25444, 0, -15302, 0, -25443, 0, -15301, 0, -25442, 0, -15298, 0, -25441, 0, -15297, 0, -25440, 0, -15296, 0, -25439, 0, -15295, 0, -25438, 0, -15294, 0, -25437, 0, -15293, 0, -25436, 0, -15292, 0, -25435, 0, -15291, 0, -25434, 0, -15290, 0, -25433, 0, -15289, 0, -25432, 0, -15287, 0, -25431, 0, -15286, 0, -25430, 0, -15285, 0, -25429, 0, -15284, 0, -25428, 0, -15283, 0, -25427, 0, -15282, 0, -25426, 0, -15281, 0, -25425, 0, -15280, 0, -25424, 0, -15279, 0, -25423, 0, -15278, 0, -25422, 0, -15277, 0, -25421, 0, -15276, 0, -25420, 0, -15275, 0, -25419, 0, -15274, 0, -25418, 0, -15273, 0, -25417, 0, -15272, 0, -25416, 0, -15271, 0, -25415, 0, -15270, 0, -25414, 0, -15269, 0, -25413, 0, -15268, 0, -25412, 0, -15267, 0, -25411, 0, -15266, 0, -25410, 0, -15265, 0, -25409, 0, -15264, 0, -25408, 0, -15263, 0, -25407, 0, -15262, 0, -25406, 0, -15261, 0, -25405, 0, -15258, 0, -25404, 0, -15257, 0, -25403, 0, -15255, 0, -25402, 0, -15254, 0, -25401, 0, -15253, 0, -25400, 0, -15251, 0, -25399, 0, -15250, 0, -25398, 0, -15249, 0, -25397, 0, -15248, 0, -25396, 0, -15247, 0, -25395, 0, -15246, 0, -25394, 0, -15245, 0, -25393, 0, -15242, 0, -25392, 0, -15241, 0, -25391, 0, -15240, 0, -25390, 0, -15238, 0, -25389, 0, -15237, 0, -25388, 0, -15236, 0, -25387, 0, -15235, 0, -25386, 0, -15234, 0, -25385, 0, -15233, 0, -25384, 0, -15231, 0, -25383, 0, -15230, 0, -25382, 0, -15229, 0, -25381, 0, -15228, 0, -25380, 0, -15227, 0, -25379, 0, -15226, 0, -25378, 0, -15225, 0, -25377, 0, -15224, 0, -25376, 0, -15223, 0, -25375, 0, -15222, 0, -25374, 0, -15221, 0, -25373, 0, -15220, 0, -25372, 0, -15219, 0, -25371, 0, -15218, 0, -25370, 0, -15217, 0, -25369, 0, -15216, 0, -25368, 0, -15215, 0, -25367, 0, -15214, 0, -25366, 0, -15213, 0, -25365, 0, -15211, 0, -25364, 0, -15210, 0, -25363, 0, -15209, 0, -25362, 0, -15208, 0, -25361, 0, -15207, 0, -25360, 0, -15206, 0, -25359, 0, -15205, 0, -25358, 0, -15203, 0, -25357, 0, -15202, 0, -25356, 0, -15201, 0, -25355, 0, -15200, 0, -25354, 0, -15199, 0, -25353, 0, -15198, 0, -25352, 0, -15197, 0, -25351, 0, -15196, 0, -25350, 0, -15195, 0, -25349, 0, -15194, 0, -25348, 0, -15193, 0, -25347, 0, -15192, 0, -25346, 0, -15191, 0, -25279, 0, -15190, 0, -25278, 0, -15189, 0, -25277, 0, -15188, 0, -25276, 0, -15187, 0, -25275, 0, -15186, 0, -25274, 0, -15185, 0, -25273, 0, -15184, 0, -25272, 0, -15183, 0, -25271, 0, -15182, 0, -25270, 0, -15181, 0, -25269, 0, -15180, 0, -25268, 0, -15179, 0, -25267, 0, -15178, 0, -25266, 0, -15177, 0, -25265, 0, -15175, 0, -25264, 0, -15174, 0, -25263, 0, -15173, 0, -25262, 0, -15171, 0, -25261, 0, -15170, 0, -25260, 0, -15169, 0, -25259, 0, -15168, 0, -25258, 0, -15167, 0, -25257, 0, -15166, 0, -25256, 0, -15165, 0, -25255, 0, -15164, 0, -25254, 0, -15163, 0, -25247, 0, -15162, 0, -25246, 0, -15161, 0, -25245, 0, -15160, 0, -25244, 0, -15159, 0, -25243, 0, -15158, 0, -25242, 0, -15157, 0, -25241, 0, -15156, 0, -25240, 0, -15155, 0, -25239, 0, -15154, 0, -25238, 0, -15153, 0, -25237, 0, -15152, 0, -25236, 0, -15151, 0, -25235, 0, -15150, 0, -25234, 0, -15149, 0, -25233, 0, -15148, 0, -25232, 0, -15147, 0, -25231, 0, -15146, 0, -25230, 0, -15145, 0, -25229, 0, -15144, 0, -25228, 0, -15143, 0, -25227, 0, -15142, 0, -25226, 0, -15141, 0, -25225, 0, -15140, 0, -25224, 0, -15139, 0, -25223, 0, -15138, 0, -25222, 0, -15137, 0, -25215, 0, -15136, 0, -25214, 0, -15135, 0, -25213, 0, -15134, 0, -25212, 0, -15133, 0, -25211, 0, -15132, 0, -25210, 0, -15131, 0, -25209, 0, -15130, 0, -25208, 0, -15129, 0, -25207, 0, -15128, 0, -25206, 0, -15126, 0, -25205, 0, -15125, 0, -25204, 0, -15124, 0, -25203, 0, -15123, 0, -25202, 0, -15122, 0, -25201, 0, -15121, 0, -25200, 0, -15118, 0, -25199, 0, -15117, 0, -25198, 0, -15115, 0, -25197, 0, -15114, 0, -25196, 0, -15113, 0, -25195, 0, -15111, 0, -25194, 0, -15109, 0, -25193, 0, -15108, 0, -25192, 0, -15107, 0, -25191, 0, -15106, 0, -25190, 0, -15102, 0, -25189, 0, -15101, 0, -25188, 0, -15100, 0, -25187, 0, -15099, 0, -25186, 0, -15098, 0, -25185, 0, -15097, 0, -25184, 0, -15096, 0, -25183, 0, -15095, 0, -25182, 0, -15094, 0, -25181, 0, -15093, 0, -25180, 0, -15091, 0, -25179, 0, -15090, 0, -25178, 0, -15089, 0, -25177, 0, -15087, 0, -25176, 0, -15086, 0, -25175, 0, -15085, 0, -25174, 0, -15083, 0, -25173, 0, -15082, 0, -25172, 0, -15081, 0, -25171, 0, -15080, 0, -25170, 0, -15079, 0, -25169, 0, -15078, 0, -25168, 0, -15077, 0, -25167, 0, -15075, 0, -25166, 0, -15074, 0, -25165, 0, -15073, 0, -25164, 0, -15072, 0, -25163, 0, -15071, 0, -25162, 0, -15070, 0, -25161, 0, -15069, 0, -25160, 0, -15068, 0, -25159, 0, -15067, 0, -25158, 0, -15066, 0, -25157, 0, -15065, 0, -25156, 0, -15062, 0, -25155, 0, -15061, 0, -25154, 0, -15059, 0, -25153, 0, -15058, 0, -25152, 0, -15057, 0, -25151, 0, -15055, 0, -25150, 0, -15054, 0, -25149, 0, -15053, 0, -25148, 0, -15052, 0, -25147, 0, -15051, 0, -25146, 0, -15050, 0, -25145, 0, -15049, 0, -25144, 0, -15046, 0, -25143, 0, -15044, 0, -25142, 0, -15042, 0, -25141, 0, -15041, 0, -25140, 0, -15040, 0, -25139, 0, -15039, 0, -25138, 0, -15038, 0, -25137, 0, -15037, 0, -25136, 0, -15034, 0, -25135, 0, -15033, 0, -25134, 0, -15029, 0, -25133, 0, -15025, 0, -25132, 0, -15024, 0, -25131, 0, -15023, 0, -25130, 0, -15022, 0, -25129, 0, -15018, 0, -25128, 0, -15014, 0, -25127, 0, -15013, 0, -25126, 0, -15012, 0, -25125, 0, -15009, 0, -25124, 0, -15006, 0, -25123, 0, -15005, 0, -25122, 0, -15003, 0, -25121, 0, -15002, 0, -25120, 0, -15001, 0, -25119, 0, -14999, 0, -25118, 0, -14998, 0, -25117, 0, -14997, 0, -25116, 0, -14996, 0, -25115, 0, -14995, 0, -25114, 0, -14994, 0, -25113, 0, -14993, 0, -25112, 0, -14990, 0, -25111, 0, -14986, 0, -25110, 0, -14985, 0, -25109, 0, -14984, 0, -25108, 0, -14983, 0, -25107, 0, -14982, 0, -25106, 0, -14981, 0, -25105, 0, -14978, 0, -25104, 0, -14977, 0, -25103, 0, -14975, 0, -25102, 0, -14974, 0, -25101, 0, -14973, 0, -25100, 0, -14971, 0, -25099, 0, -14970, 0, -25098, 0, -14968, 0, -25097, 0, -14967, 0, -25096, 0, -14966, 0, -25095, 0, -14965, 0, -25094, 0, -14962, 0, -25093, 0, -14960, 0, -25092, 0, -14958, 0, -25091, 0, -14957, 0, -25090, 0, -14956, 0, -25023, 0, -14954, 0, -25022, 0, -14951, 0, -25021, 0, -14950, 0, -25020, 0, -14949, 0, -25019, 0, -14947, 0, -25018, 0, -14946, 0, -25017, 0, -14945, 0, -25016, 0, -14943, 0, -25015, 0, -14942, 0, -25014, 0, -14941, 0, -25013, 0, -14940, 0, -25012, 0, -14939, 0, -25011, 0, -14938, 0, -25010, 0, -14937, 0, -25009, 0, -14936, 0, -25008, 0, -14934, 0, -25007, 0, -14933, 0, -25006, 0, -14932, 0, -25005, 0, -14931, 0, -25004, 0, -14930, 0, -25003, 0, -14929, 0, -25002, 0, -14928, 0, -25001, 0, -14927, 0, -25000, 0, -14926, 0, -24999, 0, -14925, 0, -24998, 0, -14922, 0, -24991, 0, -14921, 0, -24990, 0, -14918, 0, -24989, 0, -14913, 0, -24988, 0, -14912, 0, -24987, 0, -14911, 0, -24986, 0, -14910, 0, -24985, 0, -14909, 0, -24984, 0, -14901, 0, -24983, 0, -14899, 0, -24982, 0, -14897, 0, -24981, 0, -14894, 0, -24980, 0, -14893, 0, -24979, 0, -14891, 0, -24978, 0, -14890, 0, -24977, 0, -14889, 0, -24976, 0, -14887, 0, -24975, 0, -14886, 0, -24974, 0, -14885, 0, -24973, 0, -14884, 0, -24972, 0, -14883, 0, -24971, 0, -14882, 0, -24970, 0, -14881, 0, -24969, 0, -14878, 0, -24968, 0, -14876, 0, -24967, 0, -14874, 0, -24966, 0, -14873, 0, -24959, 0, -14872, 0, -24958, 0, -14871, 0, -24957, 0, -14870, 0, -24956, 0, -14869, 0, -24955, 0, -14865, 0, -24954, 0, -14863, 0, -24953, 0, -14862, 0, -24952, 0, -14861, 0, -24951, 0, -14859, 0, -24950, 0, -14856, 0, -24949, 0, -14855, 0, -24948, 0, -14854, 0, -24947, 0, -14853, 0, -24946, 0, -14846, 0, -24945, 0, -14845, 0, -24944, 0, -14844, 0, -24943, 0, -14839, 0, -24942, 0, -14838, 0, -24941, 0, -14837, 0, -24940, 0, -14835, 0, -24939, 0, -14834, 0, -24938, 0, -14833, 0, -24937, 0, -14831, 0, -24936, 0, -14830, 0, -24935, 0, -14829, 0, -24934, 0, -14828, 0, -24933, 0, -14827, 0, -24932, 0, -14826, 0, -24931, 0, -14825, 0, -24930, 0, -14822, 0, -24929, 0, -14819, 0, -24928, 0, -14818, 0, -24927, 0, -14817, 0, -24926, 0, -14816, 0, -24925, 0, -14815, 0, -24924, 0, -14814, 0, -24923, 0, -14813, 0, -24922, 0, -14810, 0, -24921, 0, -14809, 0, -24920, 0, -14807, 0, -24919, 0, -14806, 0, -24918, 0, -14805, 0, -24917, 0, -14801, 0, -24916, 0, -14799, 0, -24915, 0, -14798, 0, -24914, 0, -14794, 0, -24913, 0, -14792, 0, -24912, 0, -14790, 0, -24911, 0, -14788, 0, -24910, 0, -14787, 0, -24909, 0, -14786, 0, -24908, 0, -14785, 0, -24907, 0, -14782, 0, -24906, 0, -14781, 0, -24905, 0, -14779, 0, -24904, 0, -14778, 0, -24903, 0, -14777, 0, -24902, 0, -14775, 0, -24901, 0, -14774, 0, -24900, 0, -14773, 0, -24899, 0, -14772, 0, -24898, 0, -14771, 0, -24897, 0, -14770, 0, -24896, 0, -14769, 0, -24895, 0, -14766, 0, -24894, 0, -14762, 0, -24893, 0, -14761, 0, -24892, 0, -14760, 0, -24891, 0, -14759, 0, -24890, 0, -14758, 0, -24889, 0, -14757, 0, -24888, 0, -14754, 0, -24887, 0, -14753, 0, -24886, 0, -14751, 0, -24885, 0, -14750, 0, -24884, 0, -14749, 0, -24883, 0, -14748, 0, -24882, 0, -14747, 0, -24881, 0, -14746, 0, -24880, 0, -14745, 0, -24879, 0, -14744, 0, -24878, 0, -14743, 0, -24877, 0, -14742, 0, -24876, 0, -14741, 0, -24875, 0, -14739, 0, -24874, 0, -14738, 0, -24873, 0, -14736, 0, -24872, 0, -14734, 0, -24871, 0, -14733, 0, -24870, 0, -14732, 0, -24869, 0, -14731, 0, -24868, 0, -14730, 0, -24867, 0, -14729, 0, -24866, 0, -14726, 0, -24865, 0, -14725, 0, -24864, 0, -14723, 0, -24863, 0, -14722, 0, -24862, 0, -14721, 0, -24861, 0, -14719, 0, -24860, 0, -14718, 0, -24859, 0, -14717, 0, -24858, 0, -14716, 0, -24857, 0, -14715, 0, -24856, 0, -14714, 0, -24855, 0, -14713, 0, -24854, 0, -14710, 0, -24853, 0, -14708, 0, -24852, 0, -14706, 0, -24851, 0, -14705, 0, -24850, 0, -14704, 0, -24849, 0, -14703, 0, -24848, 0, -14702, 0, -24847, 0, -14701, 0, -24846, 0, -14698, 0, -24845, 0, -14697, 0, -24844, 0, -14695, 0, -24843, 0, -14694, 0, -24842, 0, -14693, 0, -24841, 0, -14691, 0, -24840, 0, -14690, 0, -24839, 0, -14689, 0, -24838, 0, -14688, 0, -24837, 0, -14687, 0, -24836, 0, -14686, 0, -24835, 0, -14685, 0, -24834, 0, -14682, 0, -24767, 0, -14680, 0, -24766, 0, -14678, 0, -24765, 0, -14677, 0, -24764, 0, -14676, 0, -24763, 0, -14675, 0, -24762, 0, -14674, 0, -24761, 0, -14673, 0, -24760, 0, -14670, 0, -24759, 0, -14669, 0, -24758, 0, -14667, 0, -24757, 0, -14666, 0, -24756, 0, -14665, 0, -24755, 0, -14661, 0, -24754, 0, -14660, 0, -24753, 0, -14659, 0, -24752, 0, -14658, 0, -24751, 0, -14657, 0, -24750, 0, -14654, 0, -24749, 0, -14652, 0, -24748, 0, -14650, 0, -24747, 0, -14649, 0, -24746, 0, -14648, 0, -24745, 0, -14647, 0, -24744, 0, -14646, 0, -24743, 0, -14645, 0, -24742, 0, -14642, 0, -24735, 0, -14641, 0, -24734, 0, -14639, 0, -24733, 0, -14638, 0, -24732, 0, -14637, 0, -24731, 0, -14635, 0, -24730, 0, -14634, 0, -24729, 0, -14633, 0, -24728, 0, -14632, 0, -24727, 0, -14631, 0, -24726, 0, -14630, 0, -24725, 0, -14629, 0, -24724, 0, -14626, 0, -24723, 0, -14625, 0, -24722, 0, -14622, 0, -24721, 0, -14621, 0, -24720, 0, -14620, 0, -24719, 0, -14619, 0, -24718, 0, -14618, 0, -24717, 0, -14617, 0, -24716, 0, -14614, 0, -24715, 0, -14613, 0, -24714, 0, -14611, 0, -24713, 0, -14610, 0, -24712, 0, -14609, 0, -24711, 0, -14607, 0, -24710, 0, -14606, 0, -24703, 0, -14605, 0, -24702, 0, -14604, 0, -24701, 0, -14603, 0, -24700, 0, -14602, 0, -24699, 0, -14601, 0, -24698, 0, -14598, 0, -24697, 0, -14597, 0, -24696, 0, -14596, 0, -24695, 0, -14594, 0, -24694, 0, -14593, 0, -24693, 0, -14592, 0, -24692, 0, -14591, 0, -24691, 0, -14590, 0, -24690, 0, -14589, 0, -24689, 0, -14586, 0, -24688, 0, -14585, 0, -24687, 0, -14583, 0, -24686, 0, -14582, 0, -24685, 0, -14581, 0, -24684, 0, -14579, 0, -24683, 0, -14578, 0, -24682, 0, -14577, 0, -24681, 0, -14576, 0, -24680, 0, -14575, 0, -24679, 0, -14574, 0, -24678, 0, -14573, 0, -24677, 0, -14570, 0, -24676, 0, -14568, 0, -24675, 0, -14566, 0, -24674, 0, -14565, 0, -24673, 0, -14564, 0, -24672, 0, -14563, 0, -24671, 0, -14562, 0, -24670, 0, -14561, 0, -24669, 0, -14558, 0, -24668, 0, -14557, 0, -24667, 0, -14555, 0, -24666, 0, -14554, 0, -24665, 0, -14553, 0, -24664, 0, -14551, 0, -24663, 0, -14550, 0, -24662, 0, -14549, 0, -24661, 0, -14548, 0, -24660, 0, -14547, 0, -24659, 0, -14546, 0, -24658, 0, -14545, 0, -24657, 0, -14542, 0, -24656, 0, -14540, 0, -24655, 0, -14538, 0, -24654, 0, -14536, 0, -24653, 0, -14535, 0, -24652, 0, -14534, 0, -24651, 0, -14533, 0, -24650, 0, -14530, 0, -24649, 0, -14529, 0, -24648, 0, -14527, 0, -24647, 0, -14526, 0, -24646, 0, -14525, 0, -24645, 0, -14523, 0, -24644, 0, -14522, 0, -24643, 0, -14521, 0, -24642, 0, -14520, 0, -24641, 0, -14519, 0, -24640, 0, -14517, 0, -24639, 0, -14514, 0, -24638, 0, -14512, 0, -24637, 0, -14503, 0, -24636, 0, -14502, 0, -24635, 0, -14501, 0, -24634, 0, -14499, 0, -24633, 0, -14498, 0, -24632, 0, -14497, 0, -24631, 0, -14495, 0, -24630, 0, -14494, 0, -24629, 0, -14493, 0, -24628, 0, -14492, 0, -24627, 0, -14491, 0, -24626, 0, -14490, 0, -24625, 0, -14489, 0, -24624, 0, -14487, 0, -24623, 0, -14486, 0, -24622, 0, -14484, 0, -24621, 0, -14483, 0, -24620, 0, -14482, 0, -24619, 0, -14481, 0, -24618, 0, -14480, 0, -24617, 0, -14479, 0, -24616, 0, -14478, 0, -24615, 0, -14477, 0, -24614, 0, -14474, 0, -24613, 0, -14473, 0, -24612, 0, -14471, 0, -24611, 0, -14470, 0, -24610, 0, -14469, 0, -24609, 0, -14465, 0, -24608, 0, -14464, 0, -24607, 0, -14463, 0, -24606, 0, -14462, 0, -24605, 0, -14458, 0, -24604, 0, -14453, 0, -24603, 0, -14452, 0, -24602, 0, -14451, 0, -24601, 0, -14449, 0, -24600, 0, -14446, 0, -24599, 0, -14445, 0, -24598, 0, -14443, 0, -24597, 0, -14439, 0, -24596, 0, -14437, 0, -24595, 0, -14436, 0, -24594, 0, -14435, 0, -24593, 0, -14434, 0, -24592, 0, -14433, 0, -24591, 0, -14430, 0, -24590, 0, -14425, 0, -24589, 0, -14424, 0, -24588, 0, -14423, 0, -24587, 0, -14422, 0, -24586, 0, -14421, 0, -24585, 0, -14418, 0, -24584, 0, -14417, 0, -24583, 0, -14415, 0, -24582, 0, -14414, 0, -24581, 0, -14413, 0, -24580, 0, -14411, 0, -24579, 0, -14410, 0, -24578, 0, -14409, 0, -24511, 0, -14408, 0, -24510, 0, -14407, 0, -24509, 0, -14406, 0, -24508, 0, -14405, 0, -24507, 0, -14402, 0, -24506, 0, -14398, 0, -24505, 0, -14397, 0, -24504, 0, -14396, 0, -24503, 0, -14395, 0, -24502, 0, -14394, 0, -24501, 0, -14393, 0, -24500, 0, -14390, 0, -24499, 0, -14389, 0, -24498, 0, -14387, 0, -24497, 0, -14385, 0, -24496, 0, -14383, 0, -24495, 0, -14382, 0, -24494, 0, -14381, 0, -24493, 0, -14380, 0, -24492, 0, -14379, 0, -24491, 0, -14378, 0, -24490, 0, -14377, 0, -24489, 0, -14375, 0, -24488, 0, -14374, 0, -24487, 0, -14373, 0, -24486, 0, -14372, 0, -24479, 0, -14370, 0, -24478, 0, -14369, 0, -24477, 0, -14368, 0, -24476, 0, -14367, 0, -24475, 0, -14366, 0, -24474, 0, -14365, 0, -24473, 0, -14363, 0, -24472, 0, -14362, 0, -24471, 0, -14361, 0, -24470, 0, -14359, 0, -24469, 0, -14358, 0, -24468, 0, -14357, 0, -24467, 0, -14355, 0, -24466, 0, -14354, 0, -24465, 0, -14353, 0, -24464, 0, -14352, 0, -24463, 0, -14351, 0, -24462, 0, -14350, 0, -24461, 0, -14349, 0, -24460, 0, -14348, 0, -24459, 0, -14347, 0, -24458, 0, -14346, 0, -24457, 0, -14345, 0, -24456, 0, -14344, 0, -24455, 0, -14343, 0, -24454, 0, -14342, 0, -24447, 0, -14341, 0, -24446, 0, -14340, 0, -24445, 0, -14339, 0, -24444, 0, -14338, 0, -24443, 0, -14337, 0, -24442, 0, -14334, 0, -24441, 0, -14333, 0, -24440, 0, -14331, 0, -24439, 0, -14330, 0, -24438, 0, -14329, 0, -24437, 0, -14327, 0, -24436, 0, -14325, 0, -24435, 0, -14324, 0, -24434, 0, -14323, 0, -24433, 0, -14322, 0, -24432, 0, -14321, 0, -24431, 0, -14318, 0, -24430, 0, -14316, 0, -24429, 0, -14313, 0, -24428, 0, -14312, 0, -24427, 0, -14311, 0, -24426, 0, -14310, 0, -24425, 0, -14309, 0, -24424, 0, -14306, 0, -24423, 0, -14305, 0, -24422, 0, -14303, 0, -24421, 0, -14302, 0, -24420, 0, -14301, 0, -24419, 0, -14299, 0, -24418, 0, -14298, 0, -24417, 0, -14297, 0, -24416, 0, -14296, 0, -24415, 0, -14295, 0, -24414, 0, -14294, 0, -24413, 0, -14293, 0, -24412, 0, -14290, 0, -24411, 0, -14288, 0, -24410, 0, -14286, 0, -24409, 0, -14285, 0, -24408, 0, -14284, 0, -24407, 0, -14283, 0, -24406, 0, -14282, 0, -24405, 0, -14281, 0, -24404, 0, -14279, 0, -24403, 0, -14278, 0, -24402, 0, -14277, 0, -24401, 0, -14275, 0, -24400, 0, -14274, 0, -24399, 0, -14273, 0, -24398, 0, -14271, 0, -24397, 0, -14270, 0, -24396, 0, -14269, 0, -24395, 0, -14268, 0, -24394, 0, -14267, 0, -24393, 0, -14266, 0, -24392, 0, -14265, 0, -24391, 0, -14262, 0, -24390, 0, -14261, 0, -24389, 0, -14258, 0, -24388, 0, -14257, 0, -24387, 0, -14256, 0, -24386, 0, -14255, 0, -24385, 0, -14254, 0, -24384, 0, -14253, 0, -24383, 0, -14251, 0, -24382, 0, -14250, 0, -24381, 0, -14249, 0, -24380, 0, -14248, 0, -24379, 0, -14247, 0, -24378, 0, -14246, 0, -24377, 0, -14245, 0, -24376, 0, -14244, 0, -24375, 0, -14243, 0, -24374, 0, -14242, 0, -24373, 0, -14241, 0, -24372, 0, -14240, 0, -24371, 0, -14239, 0, -24370, 0, -14238, 0, -24369, 0, -14237, 0, -24368, 0, -14236, 0, -24367, 0, -14235, 0, -24366, 0, -14234, 0, -24365, 0, -14233, 0, -24364, 0, -14232, 0, -24363, 0, -14231, 0, -24362, 0, -14230, 0, -24361, 0, -14229, 0, -24360, 0, -14228, 0, -24359, 0, -14227, 0, -24358, 0, -14226, 0, -24357, 0, -14225, 0, -24356, 0, -14222, 0, -24355, 0, -14221, 0, -24354, 0, -14219, 0, -24353, 0, -14218, 0, -24352, 0, -14217, 0, -24351, 0, -14215, 0, -24350, 0, -14213, 0, -24349, 0, -14212, 0, -24348, 0, -14211, 0, -24347, 0, -14210, 0, -24346, 0, -14209, 0, -24345, 0, -14206, 0, -24344, 0, -14204, 0, -24343, 0, -14200, 0, -24342, 0, -14199, 0, -24341, 0, -14198, 0, -24340, 0, -14194, 0, -24339, 0, -14193, 0, -24338, 0, -14192, 0, -24337, 0, -14191, 0, -24336, 0, -14190, 0, -24335, 0, -14189, 0, -24334, 0, -14187, 0, -24333, 0, -14186, 0, -24332, 0, -14185, 0, -24331, 0, -14184, 0, -24330, 0, -14183, 0, -24329, 0, -14182, 0, -24328, 0, -14181, 0, -24327, 0, -14180, 0, -24326, 0, -14178, 0, -24325, 0, -14176, 0, -24324, 0, -14174, 0, -24323, 0, -14173, 0, -24322, 0, -14172, 0, -24255, 0, -14171, 0, -24254, 0, -14170, 0, -24253, 0, -14169, 0, -24252, 0, -14167, 0, -24251, 0, -14166, 0, -24250, 0, -14165, 0, -24249, 0, -14164, 0, -24248, 0, -14163, 0, -24247, 0, -14162, 0, -24246, 0, -14161, 0, -24245, 0, -14160, 0, -24244, 0, -14159, 0, -24243, 0, -14158, 0, -24242, 0, -14157, 0, -24241, 0, -14156, 0, -24240, 0, -14155, 0, -24239, 0, -14154, 0, -24238, 0, -14153, 0, -24237, 0, -14152, 0, -24236, 0, -14151, 0, -24235, 0, -14150, 0, -24234, 0, -14149, 0, -24233, 0, -14146, 0, -24232, 0, -14145, 0, -24231, 0, -14144, 0, -24230, 0, -14143, 0, -24223, 0, -14142, 0, -24222, 0, -14141, 0, -24221, 0, -14139, 0, -24220, 0, -14138, 0, -24219, 0, -14137, 0, -24218, 0, -14135, 0, -24217, 0, -14134, 0, -24216, 0, -14133, 0, -24215, 0, -14131, 0, -24214, 0, -14130, 0, -24213, 0, -14129, 0, -24212, 0, -14128, 0, -24211, 0, -14127, 0, -24210, 0, -14126, 0, -24209, 0, -14125, 0, -24208, 0, -14122, 0, -24207, 0, -14120, 0, -24206, 0, -14118, 0, -24205, 0, -14117, 0, -24204, 0, -14116, 0, -24203, 0, -14115, 0, -24202, 0, -14114, 0, -24201, 0, -14113, 0, -24200, 0, -14110, 0, -24199, 0, -14109, 0, -24198, 0, -14107, 0, -24191, 0, -14106, 0, -24190, 0, -14105, 0, -24189, 0, -14104, 0, -24188, 0, -14103, 0, -24187, 0, -14102, 0, -24186, 0, -14101, 0, -24185, 0, -14100, 0, -24184, 0, -14099, 0, -24183, 0, -14098, 0, -24182, 0, -14097, 0, -24181, 0, -14096, 0, -24180, 0, -14095, 0, -24179, 0, -14094, 0, -24178, 0, -14093, 0, -24177, 0, -14092, 0, -24176, 0, -14090, 0, -24175, 0, -14089, 0, -24174, 0, -14088, 0, -24173, 0, -14087, 0, -24172, 0, -14086, 0, -24171, 0, -14085, 0, -24170, 0, -14082, 0, -24169, 0, -14081, 0, -24168, 0, -14079, 0, -24167, 0, -14078, 0, -24166, 0, -14077, 0, -24165, 0, -14073, 0, -24164, 0, -14072, 0, -24163, 0, -14071, 0, -24162, 0, -14070, 0, -24161, 0, -14069, 0, -24160, 0, -14066, 0, -24159, 0, 12288, 0, -24158, 0, 12289, 0, -24157, 0, 12290, 0, -24156, 0, 183, 0, -24155, 0, 8229, 0, -24154, 0, 8230, 0, -24153, 0, 168, 0, -24152, 0, 12291, 0, -24151, 0, 0, 0, -24150, 0, 8213, 0, -24149, 0, 8741, 0, -24148, 0, -196, 0, -24147, 0, 8764, 0, -24146, 0, 8216, 0, -24145, 0, 8217, 0, -24144, 0, 8220, 0, -24143, 0, 8221, 0, -24142, 0, 12308, 0, -24141, 0, 12309, 0, -24140, 0, 12296, 0, -24139, 0, 12297, 0, -24138, 0, 12298, 0, -24137, 0, 12299, 0, -24136, 0, 12300, 0, -24135, 0, 12301, 0, -24134, 0, 12302, 0, -24133, 0, 12303, 0, -24132, 0, 12304, 0, -24131, 0, 12305, 0, -24130, 0, 177, 0, -24129, 0, 215, 0, -24128, 0, 247, 0, -24127, 0, 8800, 0, -24126, 0, 8804, 0, -24125, 0, 8805, 0, -24124, 0, 8734, 0, -24123, 0, 8756, 0, -24122, 0, 176, 0, -24121, 0, 8242, 0, -24120, 0, 8243, 0, -24119, 0, 8451, 0, -24118, 0, 8491, 0, -24117, 0, -32, 0, -24116, 0, -31, 0, -24115, 0, -27, 0, -24114, 0, 9794, 0, -24113, 0, 9792, 0, -24112, 0, 8736, 0, -24111, 0, 8869, 0, -24110, 0, 8978, 0, -24109, 0, 8706, 0, -24108, 0, 8711, 0, -24107, 0, 8801, 0, -24106, 0, 8786, 0, -24105, 0, 167, 0, -24104, 0, 8251, 0, -24103, 0, 9734, 0, -24102, 0, 9733, 0, -24101, 0, 9675, 0, -24100, 0, 9679, 0, -24099, 0, 9678, 0, -24098, 0, 9671, 0, -24097, 0, 9670, 0, -24096, 0, 9633, 0, -24095, 0, 9632, 0, -24094, 0, 9651, 0, -24093, 0, 9650, 0, -24092, 0, 9661, 0, -24091, 0, 9660, 0, -24090, 0, 8594, 0, -24089, 0, 8592, 0, -24088, 0, 8593, 0, -24087, 0, 8595, 0, -24086, 0, 8596, 0, -24085, 0, 12307, 0, -24084, 0, 8810, 0, -24083, 0, 8811, 0, -24082, 0, 8730, 0, -24081, 0, 8765, 0, -24080, 0, 8733, 0, -24079, 0, 8757, 0, -24078, 0, 8747, 0, -24077, 0, 8748, 0, -24076, 0, 8712, 0, -24075, 0, 8715, 0, -24074, 0, 8838, 0, -24073, 0, 8839, 0, -24072, 0, 8834, 0, -24071, 0, 8835, 0, -24070, 0, 8746, 0, -24069, 0, 8745, 0, -24068, 0, 8743, 0, -24067, 0, 8744, 0, -24066, 0, -30, 0, -23999, 0, -14064, 0, -23998, 0, -14062, 0, -23997, 0, -14061, 0, -23996, 0, -14060, 0, -23995, 0, -14059, 0, -23994, 0, -14058, 0, -23993, 0, -14057, 0, -23992, 0, -14055, 0, -23991, 0, -14054, 0, -23990, 0, -14053, 0, -23989, 0, -14052, 0, -23988, 0, -14051, 0, -23987, 0, -14050, 0, -23986, 0, -14049, 0, -23985, 0, -14048, 0, -23984, 0, -14047, 0, -23983, 0, -14046, 0, -23982, 0, -14045, 0, -23981, 0, -14044, 0, -23980, 0, -14043, 0, -23979, 0, -14042, 0, -23978, 0, -14041, 0, -23977, 0, -14040, 0, -23976, 0, -14039, 0, -23975, 0, -14038, 0, -23974, 0, -14037, 0, -23967, 0, -14035, 0, -23966, 0, -14034, 0, -23965, 0, -14033, 0, -23964, 0, -14032, 0, -23963, 0, -14031, 0, -23962, 0, -14030, 0, -23961, 0, -14029, 0, -23960, 0, -14027, 0, -23959, 0, -14026, 0, -23958, 0, -14025, 0, -23957, 0, -14024, 0, -23956, 0, -14023, 0, -23955, 0, -14022, 0, -23954, 0, -14021, 0, -23953, 0, -14020, 0, -23952, 0, -14019, 0, -23951, 0, -14018, 0, -23950, 0, -14017, 0, -23949, 0, -14016, 0, -23948, 0, -14015, 0, -23947, 0, -14014, 0, -23946, 0, -14013, 0, -23945, 0, -14012, 0, -23944, 0, -14011, 0, -23943, 0, -14010, 0, -23942, 0, -14009, 0, -23935, 0, -14008, 0, -23934, 0, -14007, 0, -23933, 0, -14006, 0, -23932, 0, -14005, 0, -23931, 0, -14004, 0, -23930, 0, -14003, 0, -23929, 0, -14002, 0, -23928, 0, -14001, 0, -23927, 0, -13998, 0, -23926, 0, -13997, 0, -23925, 0, -13995, 0, -23924, 0, -13994, 0, -23923, 0, -13993, 0, -23922, 0, -13991, 0, -23921, 0, -13990, 0, -23920, 0, -13989, 0, -23919, 0, -13988, 0, -23918, 0, -13987, 0, -23917, 0, -13986, 0, -23916, 0, -13985, 0, -23915, 0, -13982, 0, -23914, 0, -13980, 0, -23913, 0, -13979, 0, -23912, 0, -13978, 0, -23911, 0, -13977, 0, -23910, 0, -13976, 0, -23909, 0, -13975, 0, -23908, 0, -13974, 0, -23907, 0, -13973, 0, -23906, 0, -13971, 0, -23905, 0, -13970, 0, -23904, 0, -13969, 0, -23903, 0, 8658, 0, -23902, 0, 8660, 0, -23901, 0, 8704, 0, -23900, 0, 8707, 0, -23899, 0, 180, 0, -23898, 0, -162, 0, -23897, 0, 711, 0, -23896, 0, 728, 0, -23895, 0, 733, 0, -23894, 0, 730, 0, -23893, 0, 729, 0, -23892, 0, 184, 0, -23891, 0, 731, 0, -23890, 0, 161, 0, -23889, 0, 191, 0, -23888, 0, 720, 0, -23887, 0, 8750, 0, -23886, 0, 8721, 0, -23885, 0, 8719, 0, -23884, 0, 164, 0, -23883, 0, 8457, 0, -23882, 0, 8240, 0, -23881, 0, 9665, 0, -23880, 0, 9664, 0, -23879, 0, 9655, 0, -23878, 0, 9654, 0, -23877, 0, 9828, 0, -23876, 0, 9824, 0, -23875, 0, 9825, 0, -23874, 0, 9829, 0, -23873, 0, 9831, 0, -23872, 0, 9827, 0, -23871, 0, 8857, 0, -23870, 0, 9672, 0, -23869, 0, 9635, 0, -23868, 0, 9680, 0, -23867, 0, 9681, 0, -23866, 0, 9618, 0, -23865, 0, 9636, 0, -23864, 0, 9637, 0, -23863, 0, 9640, 0, -23862, 0, 9639, 0, -23861, 0, 9638, 0, -23860, 0, 9641, 0, -23859, 0, 9832, 0, -23858, 0, 9743, 0, -23857, 0, 9742, 0, -23856, 0, 9756, 0, -23855, 0, 9758, 0, -23854, 0, 182, 0, -23853, 0, 8224, 0, -23852, 0, 8225, 0, -23851, 0, 8597, 0, -23850, 0, 8599, 0, -23849, 0, 8601, 0, -23848, 0, 8598, 0, -23847, 0, 8600, 0, -23846, 0, 9837, 0, -23845, 0, 9833, 0, -23844, 0, 9834, 0, -23843, 0, 9836, 0, -23842, 0, 12927, 0, -23841, 0, 12828, 0, -23840, 0, 8470, 0, -23839, 0, 13255, 0, -23838, 0, 8482, 0, -23837, 0, 13250, 0, -23836, 0, 13272, 0, -23835, 0, 8481, 0, -23743, 0, -13967, 0, -23742, 0, -13966, 0, -23741, 0, -13965, 0, -23740, 0, -13963, 0, -23739, 0, -13962, 0, -23738, 0, -13961, 0, -23737, 0, -13960, 0, -23736, 0, -13959, 0, -23735, 0, -13958, 0, -23734, 0, -13957, 0, -23733, 0, -13955, 0, -23732, 0, -13954, 0, -23731, 0, -13953, 0, -23730, 0, -13952, 0, -23729, 0, -13951, 0, -23728, 0, -13950, 0, -23727, 0, -13949, 0, -23726, 0, -13948, 0, -23725, 0, -13947, 0, -23724, 0, -13946, 0, -23723, 0, -13945, 0, -23722, 0, -13942, 0, -23721, 0, -13941, 0, -23720, 0, -13939, 0, -23719, 0, -13938, 0, -23718, 0, -13937, 0, -23711, 0, -13935, 0, -23710, 0, -13934, 0, -23709, 0, -13933, 0, -23708, 0, -13932, 0, -23707, 0, -13931, 0, -23706, 0, -13930, 0, -23705, 0, -13929, 0, -23704, 0, -13926, 0, -23703, 0, -13924, 0, -23702, 0, -13922, 0, -23701, 0, -13921, 0, -23700, 0, -13920, 0, -23699, 0, -13919, 0, -23698, 0, -13918, 0, -23697, 0, -13917, 0, -23696, 0, -13916, 0, -23695, 0, -13915, 0, -23694, 0, -13914, 0, -23693, 0, -13913, 0, -23692, 0, -13912, 0, -23691, 0, -13911, 0, -23690, 0, -13910, 0, -23689, 0, -13909, 0, -23688, 0, -13908, 0, -23687, 0, -13907, 0, -23686, 0, -13906, 0, -23679, 0, -13905, 0, -23678, 0, -13904, 0, -23677, 0, -13903, 0, -23676, 0, -13902, 0, -23675, 0, -13901, 0, -23674, 0, -13900, 0, -23673, 0, -13899, 0, -23672, 0, -13898, 0, -23671, 0, -13897, 0, -23670, 0, -13896, 0, -23669, 0, -13895, 0, -23668, 0, -13894, 0, -23667, 0, -13893, 0, -23666, 0, -13892, 0, -23665, 0, -13891, 0, -23664, 0, -13890, 0, -23663, 0, -13889, 0, -23662, 0, -13886, 0, -23661, 0, -13885, 0, -23660, 0, -13883, 0, -23659, 0, -13882, 0, -23658, 0, -13879, 0, -23657, 0, -13877, 0, -23656, 0, -13876, 0, -23655, 0, -13875, 0, -23654, 0, -13874, 0, -23653, 0, -13873, 0, -23652, 0, -13870, 0, -23651, 0, -13868, 0, -23650, 0, -13865, 0, -23649, 0, -13864, 0, -23648, 0, -13861, 0, -23647, 0, -255, 0, -23646, 0, -254, 0, -23645, 0, -253, 0, -23644, 0, -252, 0, -23643, 0, -251, 0, -23642, 0, -250, 0, -23641, 0, -249, 0, -23640, 0, -248, 0, -23639, 0, -247, 0, -23638, 0, -246, 0, -23637, 0, -245, 0, -23636, 0, -244, 0, -23635, 0, -243, 0, -23634, 0, -242, 0, -23633, 0, -241, 0, -23632, 0, -240, 0, -23631, 0, -239, 0, -23630, 0, -238, 0, -23629, 0, -237, 0, -23628, 0, -236, 0, -23627, 0, -235, 0, -23626, 0, -234, 0, -23625, 0, -233, 0, -23624, 0, -232, 0, -23623, 0, -231, 0, -23622, 0, -230, 0, -23621, 0, -229, 0, -23620, 0, -228, 0, -23619, 0, -227, 0, -23618, 0, -226, 0, -23617, 0, -225, 0, -23616, 0, -224, 0, -23615, 0, -223, 0, -23614, 0, -222, 0, -23613, 0, -221, 0, -23612, 0, -220, 0, -23611, 0, -219, 0, -23610, 0, -218, 0, -23609, 0, -217, 0, -23608, 0, -216, 0, -23607, 0, -215, 0, -23606, 0, -214, 0, -23605, 0, -213, 0, -23604, 0, -212, 0, -23603, 0, -211, 0, -23602, 0, -210, 0, -23601, 0, -209, 0, -23600, 0, -208, 0, -23599, 0, -207, 0, -23598, 0, -206, 0, -23597, 0, -205, 0, -23596, 0, -204, 0, -23595, 0, -203, 0, -23594, 0, -202, 0, -23593, 0, -201, 0, -23592, 0, -200, 0, -23591, 0, -199, 0, -23590, 0, -198, 0, -23589, 0, -197, 0, -23588, 0, -26, 0, -23587, 0, -195, 0, -23586, 0, -194, 0, -23585, 0, -193, 0, -23584, 0, -192, 0, -23583, 0, -191, 0, -23582, 0, -190, 0, -23581, 0, -189, 0, -23580, 0, -188, 0, -23579, 0, -187, 0, -23578, 0, -186, 0, -23577, 0, -185, 0, -23576, 0, -184, 0, -23575, 0, -183, 0, -23574, 0, -182, 0, -23573, 0, -181, 0, -23572, 0, -180, 0, -23571, 0, -179, 0, -23570, 0, -178, 0, -23569, 0, -177, 0, -23568, 0, -176, 0, -23567, 0, -175, 0, -23566, 0, -174, 0, -23565, 0, -173, 0, -23564, 0, -172, 0, -23563, 0, -171, 0, -23562, 0, -170, 0, -23561, 0, -169, 0, -23560, 0, -168, 0, -23559, 0, -167, 0, -23558, 0, -166, 0, -23557, 0, -165, 0, -23556, 0, -164, 0, -23555, 0, -163, 0, -23554, 0, -29, 0, -23487, 0, -13858, 0, -23486, 0, -13857, 0, -23485, 0, -13855, 0, -23484, 0, -13853, 0, -23483, 0, -13851, 0, -23482, 0, -13850, 0, -23481, 0, -13848, 0, -23480, 0, -13847, 0, -23479, 0, -13846, 0, -23478, 0, -13845, 0, -23477, 0, -13842, 0, -23476, 0, -13838, 0, -23475, 0, -13837, 0, -23474, 0, -13836, 0, -23473, 0, -13835, 0, -23472, 0, -13834, 0, -23471, 0, -13833, 0, -23470, 0, -13830, 0, -23469, 0, -13829, 0, -23468, 0, -13827, 0, -23467, 0, -13826, 0, -23466, 0, -13825, 0, -23465, 0, -13823, 0, -23464, 0, -13822, 0, -23463, 0, -13821, 0, -23462, 0, -13820, 0, -23455, 0, -13819, 0, -23454, 0, -13818, 0, -23453, 0, -13817, 0, -23452, 0, -13814, 0, -23451, 0, -13810, 0, -23450, 0, -13809, 0, -23449, 0, -13808, 0, -23448, 0, -13807, 0, -23447, 0, -13806, 0, -23446, 0, -13805, 0, -23445, 0, -13803, 0, -23444, 0, -13802, 0, -23443, 0, -13801, 0, -23442, 0, -13799, 0, -23441, 0, -13798, 0, -23440, 0, -13797, 0, -23439, 0, -13796, 0, -23438, 0, -13795, 0, -23437, 0, -13794, 0, -23436, 0, -13793, 0, -23435, 0, -13792, 0, -23434, 0, -13791, 0, -23433, 0, -13790, 0, -23432, 0, -13789, 0, -23431, 0, -13788, 0, -23430, 0, -13787, 0, -23423, 0, -13786, 0, -23422, 0, -13785, 0, -23421, 0, -13784, 0, -23420, 0, -13782, 0, -23419, 0, -13781, 0, -23418, 0, -13780, 0, -23417, 0, -13779, 0, -23416, 0, -13778, 0, -23415, 0, -13777, 0, -23414, 0, -13776, 0, -23413, 0, -13775, 0, -23412, 0, -13774, 0, -23411, 0, -13773, 0, -23410, 0, -13772, 0, -23409, 0, -13771, 0, -23408, 0, -13770, 0, -23407, 0, -13769, 0, -23406, 0, -13768, 0, -23405, 0, -13767, 0, -23404, 0, -13766, 0, -23403, 0, -13765, 0, -23402, 0, -13764, 0, -23401, 0, -13763, 0, -23400, 0, -13762, 0, -23399, 0, -13761, 0, -23398, 0, -13760, 0, -23397, 0, -13759, 0, -23396, 0, -13758, 0, -23395, 0, -13757, 0, -23394, 0, -13756, 0, -23393, 0, -13755, 0, -23392, 0, -13754, 0, -23391, 0, 12593, 0, -23390, 0, 12594, 0, -23389, 0, 12595, 0, -23388, 0, 12596, 0, -23387, 0, 12597, 0, -23386, 0, 12598, 0, -23385, 0, 12599, 0, -23384, 0, 12600, 0, -23383, 0, 12601, 0, -23382, 0, 12602, 0, -23381, 0, 12603, 0, -23380, 0, 12604, 0, -23379, 0, 12605, 0, -23378, 0, 12606, 0, -23377, 0, 12607, 0, -23376, 0, 12608, 0, -23375, 0, 12609, 0, -23374, 0, 12610, 0, -23373, 0, 12611, 0, -23372, 0, 12612, 0, -23371, 0, 12613, 0, -23370, 0, 12614, 0, -23369, 0, 12615, 0, -23368, 0, 12616, 0, -23367, 0, 12617, 0, -23366, 0, 12618, 0, -23365, 0, 12619, 0, -23364, 0, 12620, 0, -23363, 0, 12621, 0, -23362, 0, 12622, 0, -23361, 0, 12623, 0, -23360, 0, 12624, 0, -23359, 0, 12625, 0, -23358, 0, 12626, 0, -23357, 0, 12627, 0, -23356, 0, 12628, 0, -23355, 0, 12629, 0, -23354, 0, 12630, 0, -23353, 0, 12631, 0, -23352, 0, 12632, 0, -23351, 0, 12633, 0, -23350, 0, 12634, 0, -23349, 0, 12635, 0, -23348, 0, 12636, 0, -23347, 0, 12637, 0, -23346, 0, 12638, 0, -23345, 0, 12639, 0, -23344, 0, 12640, 0, -23343, 0, 12641, 0, -23342, 0, 12642, 0, -23341, 0, 12643, 0, -23340, 0, 12644, 0, -23339, 0, 12645, 0, -23338, 0, 12646, 0, -23337, 0, 12647, 0, -23336, 0, 12648, 0, -23335, 0, 12649, 0, -23334, 0, 12650, 0, -23333, 0, 12651, 0, -23332, 0, 12652, 0, -23331, 0, 12653, 0, -23330, 0, 12654, 0, -23329, 0, 12655, 0, -23328, 0, 12656, 0, -23327, 0, 12657, 0, -23326, 0, 12658, 0, -23325, 0, 12659, 0, -23324, 0, 12660, 0, -23323, 0, 12661, 0, -23322, 0, 12662, 0, -23321, 0, 12663, 0, -23320, 0, 12664, 0, -23319, 0, 12665, 0, -23318, 0, 12666, 0, -23317, 0, 12667, 0, -23316, 0, 12668, 0, -23315, 0, 12669, 0, -23314, 0, 12670, 0, -23313, 0, 12671, 0, -23312, 0, 12672, 0, -23311, 0, 12673, 0, -23310, 0, 12674, 0, -23309, 0, 12675, 0, -23308, 0, 12676, 0, -23307, 0, 12677, 0, -23306, 0, 12678, 0, -23305, 0, 12679, 0, -23304, 0, 12680, 0, -23303, 0, 12681, 0, -23302, 0, 12682, 0, -23301, 0, 12683, 0, -23300, 0, 12684, 0, -23299, 0, 12685, 0, -23298, 0, 12686, 0, -23231, 0, -13753, 0, -23230, 0, -13752, 0, -23229, 0, -13751, 0, -23228, 0, -13750, 0, -23227, 0, -13749, 0, -23226, 0, -13746, 0, -23225, 0, -13745, 0, -23224, 0, -13743, 0, -23223, 0, -13742, 0, -23222, 0, -13741, 0, -23221, 0, -13739, 0, -23220, 0, -13738, 0, -23219, 0, -13737, 0, -23218, 0, -13736, 0, -23217, 0, -13735, 0, -23216, 0, -13734, 0, -23215, 0, -13733, 0, -23214, 0, -13730, 0, -23213, 0, -13726, 0, -23212, 0, -13725, 0, -23211, 0, -13724, 0, -23210, 0, -13723, 0, -23209, 0, -13722, 0, -23208, 0, -13721, 0, -23207, 0, -13719, 0, -23206, 0, -13718, 0, -23199, 0, -13717, 0, -23198, 0, -13716, 0, -23197, 0, -13715, 0, -23196, 0, -13714, 0, -23195, 0, -13713, 0, -23194, 0, -13712, 0, -23193, 0, -13711, 0, -23192, 0, -13710, 0, -23191, 0, -13709, 0, -23190, 0, -13708, 0, -23189, 0, -13707, 0, -23188, 0, -13706, 0, -23187, 0, -13705, 0, -23186, 0, -13704, 0, -23185, 0, -13703, 0, -23184, 0, -13702, 0, -23183, 0, -13701, 0, -23182, 0, -13700, 0, -23181, 0, -13698, 0, -23180, 0, -13697, 0, -23179, 0, -13696, 0, -23178, 0, -13695, 0, -23177, 0, -13694, 0, -23176, 0, -13693, 0, -23175, 0, -13691, 0, -23174, 0, -13690, 0, -23167, 0, -13689, 0, -23166, 0, -13688, 0, -23165, 0, -13687, 0, -23164, 0, -13686, 0, -23163, 0, -13685, 0, -23162, 0, -13684, 0, -23161, 0, -13683, 0, -23160, 0, -13682, 0, -23159, 0, -13681, 0, -23158, 0, -13680, 0, -23157, 0, -13679, 0, -23156, 0, -13678, 0, -23155, 0, -13677, 0, -23154, 0, -13676, 0, -23153, 0, -13675, 0, -23152, 0, -13674, 0, -23151, 0, -13673, 0, -23150, 0, -13671, 0, -23149, 0, -13670, 0, -23148, 0, -13669, 0, -23147, 0, -13668, 0, -23146, 0, -13667, 0, -23145, 0, -13666, 0, -23144, 0, -13665, 0, -23143, 0, -13664, 0, -23142, 0, -13663, 0, -23141, 0, -13662, 0, -23140, 0, -13661, 0, -23139, 0, -13660, 0, -23138, 0, -13659, 0, -23137, 0, -13658, 0, -23136, 0, -13657, 0, -23135, 0, 8560, 0, -23134, 0, 8561, 0, -23133, 0, 8562, 0, -23132, 0, 8563, 0, -23131, 0, 8564, 0, -23130, 0, 8565, 0, -23129, 0, 8566, 0, -23128, 0, 8567, 0, -23127, 0, 8568, 0, -23126, 0, 8569, 0, -23120, 0, 8544, 0, -23119, 0, 8545, 0, -23118, 0, 8546, 0, -23117, 0, 8547, 0, -23116, 0, 8548, 0, -23115, 0, 8549, 0, -23114, 0, 8550, 0, -23113, 0, 8551, 0, -23112, 0, 8552, 0, -23111, 0, 8553, 0, -23103, 0, 913, 0, -23102, 0, 914, 0, -23101, 0, 915, 0, -23100, 0, 916, 0, -23099, 0, 917, 0, -23098, 0, 918, 0, -23097, 0, 919, 0, -23096, 0, 920, 0, -23095, 0, 921, 0, -23094, 0, 922, 0, -23093, 0, 923, 0, -23092, 0, 924, 0, -23091, 0, 925, 0, -23090, 0, 926, 0, -23089, 0, 927, 0, -23088, 0, 928, 0, -23087, 0, 929, 0, -23086, 0, 931, 0, -23085, 0, 932, 0, -23084, 0, 933, 0, -23083, 0, 934, 0, -23082, 0, 935, 0, -23081, 0, 936, 0, -23080, 0, 937, 0, -23071, 0, 945, 0, -23070, 0, 946, 0, -23069, 0, 947, 0, -23068, 0, 948, 0, -23067, 0, 949, 0, -23066, 0, 950, 0, -23065, 0, 951, 0, -23064, 0, 952, 0, -23063, 0, 953, 0, -23062, 0, 954, 0, -23061, 0, 955, 0, -23060, 0, 956, 0, -23059, 0, 957, 0, -23058, 0, 958, 0, -23057, 0, 959, 0, -23056, 0, 960, 0, -23055, 0, 961, 0, -23054, 0, 963, 0, -23053, 0, 964, 0, -23052, 0, 965, 0, -23051, 0, 966, 0, -23050, 0, 967, 0, -23049, 0, 968, 0, -23048, 0, 969, 0, -22975, 0, -13656, 0, -22974, 0, -13655, 0, -22973, 0, -13654, 0, -22972, 0, -13653, 0, -22971, 0, -13652, 0, -22970, 0, -13651, 0, -22969, 0, -13650, 0, -22968, 0, -13649, 0, -22967, 0, -13648, 0, -22966, 0, -13647, 0, -22965, 0, -13646, 0, -22964, 0, -13645, 0, -22963, 0, -13644, 0, -22962, 0, -13643, 0, -22961, 0, -13642, 0, -22960, 0, -13641, 0, -22959, 0, -13640, 0, -22958, 0, -13639, 0, -22957, 0, -13638, 0, -22956, 0, -13637, 0, -22955, 0, -13634, 0, -22954, 0, -13633, 0, -22953, 0, -13631, 0, -22952, 0, -13630, 0, -22951, 0, -13629, 0, -22950, 0, -13627, 0, -22943, 0, -13626, 0, -22942, 0, -13625, 0, -22941, 0, -13624, 0, -22940, 0, -13623, 0, -22939, 0, -13622, 0, -22938, 0, -13621, 0, -22937, 0, -13618, 0, -22936, 0, -13616, 0, -22935, 0, -13614, 0, -22934, 0, -13612, 0, -22933, 0, -13611, 0, -22932, 0, -13610, 0, -22931, 0, -13609, 0, -22930, 0, -13606, 0, -22929, 0, -13605, 0, -22928, 0, -13604, 0, -22927, 0, -13603, 0, -22926, 0, -13602, 0, -22925, 0, -13601, 0, -22924, 0, -13599, 0, -22923, 0, -13598, 0, -22922, 0, -13597, 0, -22921, 0, -13596, 0, -22920, 0, -13595, 0, -22919, 0, -13594, 0, -22918, 0, -13593, 0, -22911, 0, -13592, 0, -22910, 0, -13591, 0, -22909, 0, -13590, 0, -22908, 0, -13589, 0, -22907, 0, -13587, 0, -22906, 0, -13586, 0, -22905, 0, -13585, 0, -22904, 0, -13584, 0, -22903, 0, -13583, 0, -22902, 0, -13582, 0, -22901, 0, -13581, 0, -22900, 0, -13579, 0, -22899, 0, -13578, 0, -22898, 0, -13577, 0, -22897, 0, -13576, 0, -22896, 0, -13575, 0, -22895, 0, -13574, 0, -22894, 0, -13573, 0, -22893, 0, -13572, 0, -22892, 0, -13571, 0, -22891, 0, -13570, 0, -22890, 0, -13569, 0, -22889, 0, -13568, 0, -22888, 0, -13567, 0, -22887, 0, -13566, 0, -22886, 0, -13565, 0, -22885, 0, -13564, 0, -22884, 0, -13563, 0, -22883, 0, -13562, 0, -22882, 0, -13561, 0, -22881, 0, -13559, 0, -22880, 0, -13558, 0, -22879, 0, 9472, 0, -22878, 0, 9474, 0, -22877, 0, 9484, 0, -22876, 0, 9488, 0, -22875, 0, 9496, 0, -22874, 0, 9492, 0, -22873, 0, 9500, 0, -22872, 0, 9516, 0, -22871, 0, 9508, 0, -22870, 0, 9524, 0, -22869, 0, 9532, 0, -22868, 0, 9473, 0, -22867, 0, 9475, 0, -22866, 0, 9487, 0, -22865, 0, 9491, 0, -22864, 0, 9499, 0, -22863, 0, 9495, 0, -22862, 0, 9507, 0, -22861, 0, 9523, 0, -22860, 0, 9515, 0, -22859, 0, 9531, 0, -22858, 0, 9547, 0, -22857, 0, 9504, 0, -22856, 0, 9519, 0, -22855, 0, 9512, 0, -22854, 0, 9527, 0, -22853, 0, 9535, 0, -22852, 0, 9501, 0, -22851, 0, 9520, 0, -22850, 0, 9509, 0, -22849, 0, 9528, 0, -22848, 0, 9538, 0, -22847, 0, 9490, 0, -22846, 0, 9489, 0, -22845, 0, 9498, 0, -22844, 0, 9497, 0, -22843, 0, 9494, 0, -22842, 0, 9493, 0, -22841, 0, 9486, 0, -22840, 0, 9485, 0, -22839, 0, 9502, 0, -22838, 0, 9503, 0, -22837, 0, 9505, 0, -22836, 0, 9506, 0, -22835, 0, 9510, 0, -22834, 0, 9511, 0, -22833, 0, 9513, 0, -22832, 0, 9514, 0, -22831, 0, 9517, 0, -22830, 0, 9518, 0, -22829, 0, 9521, 0, -22828, 0, 9522, 0, -22827, 0, 9525, 0, -22826, 0, 9526, 0, -22825, 0, 9529, 0, -22824, 0, 9530, 0, -22823, 0, 9533, 0, -22822, 0, 9534, 0, -22821, 0, 9536, 0, -22820, 0, 9537, 0, -22819, 0, 9539, 0, -22818, 0, 9540, 0, -22817, 0, 9541, 0, -22816, 0, 9542, 0, -22815, 0, 9543, 0, -22814, 0, 9544, 0, -22813, 0, 9545, 0, -22812, 0, 9546, 0, -22719, 0, -13557, 0, -22718, 0, -13556, 0, -22717, 0, -13555, 0, -22716, 0, -13554, 0, -22715, 0, -13553, 0, -22714, 0, -13551, 0, -22713, 0, -13550, 0, -22712, 0, -13549, 0, -22711, 0, -13547, 0, -22710, 0, -13546, 0, -22709, 0, -13545, 0, -22708, 0, -13543, 0, -22707, 0, -13542, 0, -22706, 0, -13541, 0, -22705, 0, -13540, 0, -22704, 0, -13539, 0, -22703, 0, -13538, 0, -22702, 0, -13537, 0, -22701, 0, -13534, 0, -22700, 0, -13533, 0, -22699, 0, -13532, 0, -22698, 0, -13531, 0, -22697, 0, -13530, 0, -22696, 0, -13529, 0, -22695, 0, -13528, 0, -22694, 0, -13527, 0, -22687, 0, -13526, 0, -22686, 0, -13525, 0, -22685, 0, -13524, 0, -22684, 0, -13523, 0, -22683, 0, -13522, 0, -22682, 0, -13521, 0, -22681, 0, -13520, 0, -22680, 0, -13519, 0, -22679, 0, -13518, 0, -22678, 0, -13517, 0, -22677, 0, -13516, 0, -22676, 0, -13515, 0, -22675, 0, -13514, 0, -22674, 0, -13513, 0, -22673, 0, -13512, 0, -22672, 0, -13511, 0, -22671, 0, -13510, 0, -22670, 0, -13509, 0, -22669, 0, -13508, 0, -22668, 0, -13507, 0, -22667, 0, -13506, 0, -22666, 0, -13505, 0, -22665, 0, -13504, 0, -22664, 0, -13502, 0, -22663, 0, -13501, 0, -22662, 0, -13500, 0, -22655, 0, -13499, 0, -22654, 0, -13498, 0, -22653, 0, -13497, 0, -22652, 0, -13494, 0, -22651, 0, -13493, 0, -22650, 0, -13491, 0, -22649, 0, -13490, 0, -22648, 0, -13489, 0, -22647, 0, -13487, 0, -22646, 0, -13486, 0, -22645, 0, -13485, 0, -22644, 0, -13484, 0, -22643, 0, -13483, 0, -22642, 0, -13482, 0, -22641, 0, -13481, 0, -22640, 0, -13478, 0, -22639, 0, -13477, 0, -22638, 0, -13476, 0, -22637, 0, -13474, 0, -22636, 0, -13473, 0, -22635, 0, -13472, 0, -22634, 0, -13471, 0, -22633, 0, -13470, 0, -22632, 0, -13469, 0, -22631, 0, -13467, 0, -22630, 0, -13466, 0, -22629, 0, -13465, 0, -22628, 0, -13464, 0, -22627, 0, -13463, 0, -22626, 0, -13462, 0, -22625, 0, -13461, 0, -22624, 0, -13460, 0, -22623, 0, 13205, 0, -22622, 0, 13206, 0, -22621, 0, 13207, 0, -22620, 0, 8467, 0, -22619, 0, 13208, 0, -22618, 0, 13252, 0, -22617, 0, 13219, 0, -22616, 0, 13220, 0, -22615, 0, 13221, 0, -22614, 0, 13222, 0, -22613, 0, 13209, 0, -22612, 0, 13210, 0, -22611, 0, 13211, 0, -22610, 0, 13212, 0, -22609, 0, 13213, 0, -22608, 0, 13214, 0, -22607, 0, 13215, 0, -22606, 0, 13216, 0, -22605, 0, 13217, 0, -22604, 0, 13218, 0, -22603, 0, 13258, 0, -22602, 0, 13197, 0, -22601, 0, 13198, 0, -22600, 0, 13199, 0, -22599, 0, 13263, 0, -22598, 0, 13192, 0, -22597, 0, 13193, 0, -22596, 0, 13256, 0, -22595, 0, 13223, 0, -22594, 0, 13224, 0, -22593, 0, 13232, 0, -22592, 0, 13233, 0, -22591, 0, 13234, 0, -22590, 0, 13235, 0, -22589, 0, 13236, 0, -22588, 0, 13237, 0, -22587, 0, 13238, 0, -22586, 0, 13239, 0, -22585, 0, 13240, 0, -22584, 0, 13241, 0, -22583, 0, 13184, 0, -22582, 0, 13185, 0, -22581, 0, 13186, 0, -22580, 0, 13187, 0, -22579, 0, 13188, 0, -22578, 0, 13242, 0, -22577, 0, 13243, 0, -22576, 0, 13244, 0, -22575, 0, 13245, 0, -22574, 0, 13246, 0, -22573, 0, 13247, 0, -22572, 0, 13200, 0, -22571, 0, 13201, 0, -22570, 0, 13202, 0, -22569, 0, 13203, 0, -22568, 0, 13204, 0, -22567, 0, 8486, 0, -22566, 0, 13248, 0, -22565, 0, 13249, 0, -22564, 0, 13194, 0, -22563, 0, 13195, 0, -22562, 0, 13196, 0, -22561, 0, 13270, 0, -22560, 0, 13253, 0, -22559, 0, 13229, 0, -22558, 0, 13230, 0, -22557, 0, 13231, 0, -22556, 0, 13275, 0, -22555, 0, 13225, 0, -22554, 0, 13226, 0, -22553, 0, 13227, 0, -22552, 0, 13228, 0, -22551, 0, 13277, 0, -22550, 0, 13264, 0, -22549, 0, 13267, 0, -22548, 0, 13251, 0, -22547, 0, 13257, 0, -22546, 0, 13276, 0, -22545, 0, 13254, 0, -22463, 0, -13459, 0, -22462, 0, -13458, 0, -22461, 0, -13457, 0, -22460, 0, -13456, 0, -22459, 0, -13455, 0, -22458, 0, -13454, 0, -22457, 0, -13453, 0, -22456, 0, -13452, 0, -22455, 0, -13451, 0, -22454, 0, -13450, 0, -22453, 0, -13449, 0, -22452, 0, -13446, 0, -22451, 0, -13445, 0, -22450, 0, -13444, 0, -22449, 0, -13443, 0, -22448, 0, -13442, 0, -22447, 0, -13441, 0, -22446, 0, -13440, 0, -22445, 0, -13439, 0, -22444, 0, -13438, 0, -22443, 0, -13437, 0, -22442, 0, -13436, 0, -22441, 0, -13435, 0, -22440, 0, -13434, 0, -22439, 0, -13433, 0, -22438, 0, -13432, 0, -22431, 0, -13431, 0, -22430, 0, -13430, 0, -22429, 0, -13429, 0, -22428, 0, -13428, 0, -22427, 0, -13427, 0, -22426, 0, -13426, 0, -22425, 0, -13425, 0, -22424, 0, -13424, 0, -22423, 0, -13423, 0, -22422, 0, -13422, 0, -22421, 0, -13421, 0, -22420, 0, -13420, 0, -22419, 0, -13419, 0, -22418, 0, -13418, 0, -22417, 0, -13417, 0, -22416, 0, -13416, 0, -22415, 0, -13415, 0, -22414, 0, -13414, 0, -22413, 0, -13413, 0, -22412, 0, -13411, 0, -22411, 0, -13410, 0, -22410, 0, -13409, 0, -22409, 0, -13408, 0, -22408, 0, -13407, 0, -22407, 0, -13406, 0, -22406, 0, -13405, 0, -22399, 0, -13404, 0, -22398, 0, -13403, 0, -22397, 0, -13402, 0, -22396, 0, -13401, 0, -22395, 0, -13400, 0, -22394, 0, -13399, 0, -22393, 0, -13398, 0, -22392, 0, -13397, 0, -22391, 0, -13396, 0, -22390, 0, -13395, 0, -22389, 0, -13394, 0, -22388, 0, -13393, 0, -22387, 0, -13392, 0, -22386, 0, -13391, 0, -22385, 0, -13390, 0, -22384, 0, -13389, 0, -22383, 0, -13388, 0, -22382, 0, -13387, 0, -22381, 0, -13386, 0, -22380, 0, -13385, 0, -22379, 0, -13383, 0, -22378, 0, -13382, 0, -22377, 0, -13381, 0, -22376, 0, -13380, 0, -22375, 0, -13379, 0, -22374, 0, -13378, 0, -22373, 0, -13377, 0, -22372, 0, -13376, 0, -22371, 0, -13375, 0, -22370, 0, -13374, 0, -22369, 0, -13373, 0, -22368, 0, -13372, 0, -22367, 0, 198, 0, -22366, 0, 208, 0, -22365, 0, 170, 0, -22364, 0, 294, 0, -22362, 0, 306, 0, -22360, 0, 319, 0, -22359, 0, 321, 0, -22358, 0, 216, 0, -22357, 0, 338, 0, -22356, 0, 186, 0, -22355, 0, 222, 0, -22354, 0, 358, 0, -22353, 0, 330, 0, -22351, 0, 12896, 0, -22350, 0, 12897, 0, -22349, 0, 12898, 0, -22348, 0, 12899, 0, -22347, 0, 12900, 0, -22346, 0, 12901, 0, -22345, 0, 12902, 0, -22344, 0, 12903, 0, -22343, 0, 12904, 0, -22342, 0, 12905, 0, -22341, 0, 12906, 0, -22340, 0, 12907, 0, -22339, 0, 12908, 0, -22338, 0, 12909, 0, -22337, 0, 12910, 0, -22336, 0, 12911, 0, -22335, 0, 12912, 0, -22334, 0, 12913, 0, -22333, 0, 12914, 0, -22332, 0, 12915, 0, -22331, 0, 12916, 0, -22330, 0, 12917, 0, -22329, 0, 12918, 0, -22328, 0, 12919, 0, -22327, 0, 12920, 0, -22326, 0, 12921, 0, -22325, 0, 12922, 0, -22324, 0, 12923, 0, -22323, 0, 9424, 0, -22322, 0, 9425, 0, -22321, 0, 9426, 0, -22320, 0, 9427, 0, -22319, 0, 9428, 0, -22318, 0, 9429, 0, -22317, 0, 9430, 0, -22316, 0, 9431, 0, -22315, 0, 9432, 0, -22314, 0, 9433, 0, -22313, 0, 9434, 0, -22312, 0, 9435, 0, -22311, 0, 9436, 0, -22310, 0, 9437, 0, -22309, 0, 9438, 0, -22308, 0, 9439, 0, -22307, 0, 9440, 0, -22306, 0, 9441, 0, -22305, 0, 9442, 0, -22304, 0, 9443, 0, -22303, 0, 9444, 0, -22302, 0, 9445, 0, -22301, 0, 9446, 0, -22300, 0, 9447, 0, -22299, 0, 9448, 0, -22298, 0, 9449, 0, -22297, 0, 9312, 0, -22296, 0, 9313, 0, -22295, 0, 9314, 0, -22294, 0, 9315, 0, -22293, 0, 9316, 0, -22292, 0, 9317, 0, -22291, 0, 9318, 0, -22290, 0, 9319, 0, -22289, 0, 9320, 0, -22288, 0, 9321, 0, -22287, 0, 9322, 0, -22286, 0, 9323, 0, -22285, 0, 9324, 0, -22284, 0, 9325, 0, -22283, 0, 9326, 0, -22282, 0, 189, 0, -22281, 0, 8531, 0, -22280, 0, 8532, 0, -22279, 0, 188, 0, -22278, 0, 190, 0, -22277, 0, 8539, 0, -22276, 0, 8540, 0, -22275, 0, 8541, 0, -22274, 0, 8542, 0, -22207, 0, -13371, 0, -22206, 0, -13370, 0, -22205, 0, -13369, 0, -22204, 0, -13368, 0, -22203, 0, -13367, 0, -22202, 0, -13366, 0, -22201, 0, -13365, 0, -22200, 0, -13364, 0, -22199, 0, -13363, 0, -22198, 0, -13362, 0, -22197, 0, -13361, 0, -22196, 0, -13360, 0, -22195, 0, -13359, 0, -22194, 0, -13358, 0, -22193, 0, -13357, 0, -22192, 0, -13355, 0, -22191, 0, -13354, 0, -22190, 0, -13353, 0, -22189, 0, -13352, 0, -22188, 0, -13351, 0, -22187, 0, -13350, 0, -22186, 0, -13349, 0, -22185, 0, -13348, 0, -22184, 0, -13347, 0, -22183, 0, -13346, 0, -22182, 0, -13345, 0, -22175, 0, -13344, 0, -22174, 0, -13343, 0, -22173, 0, -13342, 0, -22172, 0, -13341, 0, -22171, 0, -13339, 0, -22170, 0, -13338, 0, -22169, 0, -13336, 0, -22168, 0, -13334, 0, -22167, 0, -13333, 0, -22166, 0, -13332, 0, -22165, 0, -13331, 0, -22164, 0, -13330, 0, -22163, 0, -13329, 0, -22162, 0, -13328, 0, -22161, 0, -13327, 0, -22160, 0, -13326, 0, -22159, 0, -13325, 0, -22158, 0, -13324, 0, -22157, 0, -13323, 0, -22156, 0, -13322, 0, -22155, 0, -13321, 0, -22154, 0, -13320, 0, -22153, 0, -13319, 0, -22152, 0, -13318, 0, -22151, 0, -13317, 0, -22150, 0, -13316, 0, -22143, 0, -13315, 0, -22142, 0, -13314, 0, -22141, 0, -13313, 0, -22140, 0, -13312, 0, -22139, 0, -13311, 0, -22138, 0, -13310, 0, -22137, 0, -13309, 0, -22136, 0, -13308, 0, -22135, 0, -13307, 0, -22134, 0, -13306, 0, -22133, 0, -13305, 0, -22132, 0, -13304, 0, -22131, 0, -13303, 0, -22130, 0, -13302, 0, -22129, 0, -13301, 0, -22128, 0, -13298, 0, -22127, 0, -13297, 0, -22126, 0, -13295, 0, -22125, 0, -13294, 0, -22124, 0, -13293, 0, -22123, 0, -13291, 0, -22122, 0, -13290, 0, -22121, 0, -13289, 0, -22120, 0, -13288, 0, -22119, 0, -13287, 0, -22118, 0, -13286, 0, -22117, 0, -13285, 0, -22116, 0, -13282, 0, -22115, 0, -13281, 0, -22114, 0, -13280, 0, -22113, 0, -13277, 0, -22112, 0, -13276, 0, -22111, 0, 230, 0, -22110, 0, 273, 0, -22109, 0, 240, 0, -22108, 0, 295, 0, -22107, 0, 305, 0, -22106, 0, 307, 0, -22105, 0, 312, 0, -22104, 0, 320, 0, -22103, 0, 322, 0, -22102, 0, 248, 0, -22101, 0, 339, 0, -22100, 0, 223, 0, -22099, 0, 254, 0, -22098, 0, 359, 0, -22097, 0, 331, 0, -22096, 0, 329, 0, -22095, 0, 12800, 0, -22094, 0, 12801, 0, -22093, 0, 12802, 0, -22092, 0, 12803, 0, -22091, 0, 12804, 0, -22090, 0, 12805, 0, -22089, 0, 12806, 0, -22088, 0, 12807, 0, -22087, 0, 12808, 0, -22086, 0, 12809, 0, -22085, 0, 12810, 0, -22084, 0, 12811, 0, -22083, 0, 12812, 0, -22082, 0, 12813, 0, -22081, 0, 12814, 0, -22080, 0, 12815, 0, -22079, 0, 12816, 0, -22078, 0, 12817, 0, -22077, 0, 12818, 0, -22076, 0, 12819, 0, -22075, 0, 12820, 0, -22074, 0, 12821, 0, -22073, 0, 12822, 0, -22072, 0, 12823, 0, -22071, 0, 12824, 0, -22070, 0, 12825, 0, -22069, 0, 12826, 0, -22068, 0, 12827, 0, -22067, 0, 9372, 0, -22066, 0, 9373, 0, -22065, 0, 9374, 0, -22064, 0, 9375, 0, -22063, 0, 9376, 0, -22062, 0, 9377, 0, -22061, 0, 9378, 0, -22060, 0, 9379, 0, -22059, 0, 9380, 0, -22058, 0, 9381, 0, -22057, 0, 9382, 0, -22056, 0, 9383, 0, -22055, 0, 9384, 0, -22054, 0, 9385, 0, -22053, 0, 9386, 0, -22052, 0, 9387, 0, -22051, 0, 9388, 0, -22050, 0, 9389, 0, -22049, 0, 9390, 0, -22048, 0, 9391, 0, -22047, 0, 9392, 0, -22046, 0, 9393, 0, -22045, 0, 9394, 0, -22044, 0, 9395, 0, -22043, 0, 9396, 0, -22042, 0, 9397, 0, -22041, 0, 9332, 0, -22040, 0, 9333, 0, -22039, 0, 9334, 0, -22038, 0, 9335, 0, -22037, 0, 9336, 0, -22036, 0, 9337, 0, -22035, 0, 9338, 0, -22034, 0, 9339, 0, -22033, 0, 9340, 0, -22032, 0, 9341, 0, -22031, 0, 9342, 0, -22030, 0, 9343, 0, -22029, 0, 9344, 0, -22028, 0, 9345, 0, -22027, 0, 9346, 0, -22026, 0, 185, 0, -22025, 0, 178, 0, -22024, 0, 179, 0, -22023, 0, 8308, 0, -22022, 0, 8319, 0, -22021, 0, 8321, 0, -22020, 0, 8322, 0, -22019, 0, 8323, 0, -22018, 0, 8324, 0, -21951, 0, -13275, 0, -21950, 0, -13274, 0, -21949, 0, -13270, 0, -21948, 0, -13269, 0, -21947, 0, -13267, 0, -21946, 0, -13265, 0, -21945, 0, -13263, 0, -21944, 0, -13262, 0, -21943, 0, -13261, 0, -21942, 0, -13260, 0, -21941, 0, -13259, 0, -21940, 0, -13258, 0, -21939, 0, -13257, 0, -21938, 0, -13254, 0, -21937, 0, -13249, 0, -21936, 0, -13248, 0, -21935, 0, -13247, 0, -21934, 0, -13246, 0, -21933, 0, -13245, 0, -21932, 0, -13242, 0, -21931, 0, -13241, 0, -21930, 0, -13239, 0, -21929, 0, -13238, 0, -21928, 0, -13237, 0, -21927, 0, -13235, 0, -21926, 0, -13234, 0, -21919, 0, -13233, 0, -21918, 0, -13232, 0, -21917, 0, -13231, 0, -21916, 0, -13230, 0, -21915, 0, -13229, 0, -21914, 0, -13226, 0, -21913, 0, -13222, 0, -21912, 0, -13221, 0, -21911, 0, -13220, 0, -21910, 0, -13219, 0, -21909, 0, -13218, 0, -21908, 0, -13217, 0, -21907, 0, -13215, 0, -21906, 0, -13214, 0, -21905, 0, -13213, 0, -21904, 0, -13211, 0, -21903, 0, -13209, 0, -21902, 0, -13207, 0, -21901, 0, -13206, 0, -21900, 0, -13205, 0, -21899, 0, -13204, 0, -21898, 0, -13203, 0, -21897, 0, -13202, 0, -21896, 0, -13201, 0, -21895, 0, -13199, 0, -21894, 0, -13198, 0, -21887, 0, -13197, 0, -21886, 0, -13196, 0, -21885, 0, -13194, 0, -21884, 0, -13193, 0, -21883, 0, -13192, 0, -21882, 0, -13191, 0, -21881, 0, -13190, 0, -21880, 0, -13189, 0, -21879, 0, -13188, 0, -21878, 0, -13187, 0, -21877, 0, -13186, 0, -21876, 0, -13185, 0, -21875, 0, -13184, 0, -21874, 0, -13183, 0, -21873, 0, -13182, 0, -21872, 0, -13181, 0, -21871, 0, -13180, 0, -21870, 0, -13179, 0, -21869, 0, -13178, 0, -21868, 0, -13177, 0, -21867, 0, -13176, 0, -21866, 0, -13175, 0, -21865, 0, -13174, 0, -21864, 0, -13173, 0, -21863, 0, -13172, 0, -21862, 0, -13171, 0, -21861, 0, -13170, 0, -21860, 0, -13169, 0, -21859, 0, -13168, 0, -21858, 0, -13167, 0, -21857, 0, -13166, 0, -21856, 0, -13165, 0, -21855, 0, 12353, 0, -21854, 0, 12354, 0, -21853, 0, 12355, 0, -21852, 0, 12356, 0, -21851, 0, 12357, 0, -21850, 0, 12358, 0, -21849, 0, 12359, 0, -21848, 0, 12360, 0, -21847, 0, 12361, 0, -21846, 0, 12362, 0, -21845, 0, 12363, 0, -21844, 0, 12364, 0, -21843, 0, 12365, 0, -21842, 0, 12366, 0, -21841, 0, 12367, 0, -21840, 0, 12368, 0, -21839, 0, 12369, 0, -21838, 0, 12370, 0, -21837, 0, 12371, 0, -21836, 0, 12372, 0, -21835, 0, 12373, 0, -21834, 0, 12374, 0, -21833, 0, 12375, 0, -21832, 0, 12376, 0, -21831, 0, 12377, 0, -21830, 0, 12378, 0, -21829, 0, 12379, 0, -21828, 0, 12380, 0, -21827, 0, 12381, 0, -21826, 0, 12382, 0, -21825, 0, 12383, 0, -21824, 0, 12384, 0, -21823, 0, 12385, 0, -21822, 0, 12386, 0, -21821, 0, 12387, 0, -21820, 0, 12388, 0, -21819, 0, 12389, 0, -21818, 0, 12390, 0, -21817, 0, 12391, 0, -21816, 0, 12392, 0, -21815, 0, 12393, 0, -21814, 0, 12394, 0, -21813, 0, 12395, 0, -21812, 0, 12396, 0, -21811, 0, 12397, 0, -21810, 0, 12398, 0, -21809, 0, 12399, 0, -21808, 0, 12400, 0, -21807, 0, 12401, 0, -21806, 0, 12402, 0, -21805, 0, 12403, 0, -21804, 0, 12404, 0, -21803, 0, 12405, 0, -21802, 0, 12406, 0, -21801, 0, 12407, 0, -21800, 0, 12408, 0, -21799, 0, 12409, 0, -21798, 0, 12410, 0, -21797, 0, 12411, 0, -21796, 0, 12412, 0, -21795, 0, 12413, 0, -21794, 0, 12414, 0, -21793, 0, 12415, 0, -21792, 0, 12416, 0, -21791, 0, 12417, 0, -21790, 0, 12418, 0, -21789, 0, 12419, 0, -21788, 0, 12420, 0, -21787, 0, 12421, 0, -21786, 0, 12422, 0, -21785, 0, 12423, 0, -21784, 0, 12424, 0, -21783, 0, 12425, 0, -21782, 0, 12426, 0, -21781, 0, 12427, 0, -21780, 0, 12428, 0, -21779, 0, 12429, 0, -21778, 0, 12430, 0, -21777, 0, 12431, 0, -21776, 0, 12432, 0, -21775, 0, 12433, 0, -21774, 0, 12434, 0, -21773, 0, 12435, 0, -21695, 0, -13164, 0, -21694, 0, -13163, 0, -21693, 0, -13162, 0, -21692, 0, -13161, 0, -21691, 0, -13158, 0, -21690, 0, -13157, 0, -21689, 0, -13155, 0, -21688, 0, -13154, 0, -21687, 0, -13153, 0, -21686, 0, -13151, 0, -21685, 0, -13150, 0, -21684, 0, -13149, 0, -21683, 0, -13148, 0, -21682, 0, -13147, 0, -21681, 0, -13146, 0, -21680, 0, -13145, 0, -21679, 0, -13142, 0, -21678, 0, -13138, 0, -21677, 0, -13137, 0, -21676, 0, -13136, 0, -21675, 0, -13135, 0, -21674, 0, -13134, 0, -21673, 0, -13133, 0, -21672, 0, -13130, 0, -21671, 0, -13129, 0, -21670, 0, -13127, 0, -21663, 0, -13126, 0, -21662, 0, -13125, 0, -21661, 0, -13123, 0, -21660, 0, -13122, 0, -21659, 0, -13121, 0, -21658, 0, -13120, 0, -21657, 0, -13119, 0, -21656, 0, -13118, 0, -21655, 0, -13117, 0, -21654, 0, -13114, 0, -21653, 0, -13112, 0, -21652, 0, -13110, 0, -21651, 0, -13109, 0, -21650, 0, -13108, 0, -21649, 0, -13107, 0, -21648, 0, -13106, 0, -21647, 0, -13105, 0, -21646, 0, -13103, 0, -21645, 0, -13102, 0, -21644, 0, -13101, 0, -21643, 0, -13099, 0, -21642, 0, -13098, 0, -21641, 0, -13097, 0, -21640, 0, -13096, 0, -21639, 0, -13095, 0, -21638, 0, -13094, 0, -21631, 0, -13093, 0, -21630, 0, -13092, 0, -21629, 0, -13091, 0, -21628, 0, -13090, 0, -21627, 0, -13089, 0, -21626, 0, -13088, 0, -21625, 0, -13087, 0, -21624, 0, -13086, 0, -21623, 0, -13085, 0, -21622, 0, -13083, 0, -21621, 0, -13082, 0, -21620, 0, -13081, 0, -21619, 0, -13080, 0, -21618, 0, -13079, 0, -21617, 0, -13078, 0, -21616, 0, -13077, 0, -21615, 0, -13075, 0, -21614, 0, -13074, 0, -21613, 0, -13073, 0, -21612, 0, -13071, 0, -21611, 0, -13070, 0, -21610, 0, -13069, 0, -21609, 0, -13068, 0, -21608, 0, -13067, 0, -21607, 0, -13066, 0, -21606, 0, -13065, 0, -21605, 0, -13064, 0, -21604, 0, -13063, 0, -21603, 0, -13062, 0, -21602, 0, -13061, 0, -21601, 0, -13060, 0, -21600, 0, -13059, 0, -21599, 0, 12449, 0, -21598, 0, 12450, 0, -21597, 0, 12451, 0, -21596, 0, 12452, 0, -21595, 0, 12453, 0, -21594, 0, 12454, 0, -21593, 0, 12455, 0, -21592, 0, 12456, 0, -21591, 0, 12457, 0, -21590, 0, 12458, 0, -21589, 0, 12459, 0, -21588, 0, 12460, 0, -21587, 0, 12461, 0, -21586, 0, 12462, 0, -21585, 0, 12463, 0, -21584, 0, 12464, 0, -21583, 0, 12465, 0, -21582, 0, 12466, 0, -21581, 0, 12467, 0, -21580, 0, 12468, 0, -21579, 0, 12469, 0, -21578, 0, 12470, 0, -21577, 0, 12471, 0, -21576, 0, 12472, 0, -21575, 0, 12473, 0, -21574, 0, 12474, 0, -21573, 0, 12475, 0, -21572, 0, 12476, 0, -21571, 0, 12477, 0, -21570, 0, 12478, 0, -21569, 0, 12479, 0, -21568, 0, 12480, 0, -21567, 0, 12481, 0, -21566, 0, 12482, 0, -21565, 0, 12483, 0, -21564, 0, 12484, 0, -21563, 0, 12485, 0, -21562, 0, 12486, 0, -21561, 0, 12487, 0, -21560, 0, 12488, 0, -21559, 0, 12489, 0, -21558, 0, 12490, 0, -21557, 0, 12491, 0, -21556, 0, 12492, 0, -21555, 0, 12493, 0, -21554, 0, 12494, 0, -21553, 0, 12495, 0, -21552, 0, 12496, 0, -21551, 0, 12497, 0, -21550, 0, 12498, 0, -21549, 0, 12499, 0, -21548, 0, 12500, 0, -21547, 0, 12501, 0, -21546, 0, 12502, 0, -21545, 0, 12503, 0, -21544, 0, 12504, 0, -21543, 0, 12505, 0, -21542, 0, 12506, 0, -21541, 0, 12507, 0, -21540, 0, 12508, 0, -21539, 0, 12509, 0, -21538, 0, 12510, 0, -21537, 0, 12511, 0, -21536, 0, 12512, 0, -21535, 0, 12513, 0, -21534, 0, 12514, 0, -21533, 0, 12515, 0, -21532, 0, 12516, 0, -21531, 0, 12517, 0, -21530, 0, 12518, 0, -21529, 0, 12519, 0, -21528, 0, 12520, 0, -21527, 0, 12521, 0, -21526, 0, 12522, 0, -21525, 0, 12523, 0, -21524, 0, 12524, 0, -21523, 0, 12525, 0, -21522, 0, 12526, 0, -21521, 0, 12527, 0, -21520, 0, 12528, 0, -21519, 0, 12529, 0, -21518, 0, 12530, 0, -21517, 0, 12531, 0, -21516, 0, 12532, 0, -21515, 0, 12533, 0, -21514, 0, 12534, 0, -21439, 0, -13058, 0, -21438, 0, -13057, 0, -21437, 0, -13056, 0, -21436, 0, -13054, 0, -21435, 0, -13053, 0, -21434, 0, -13052, 0, -21433, 0, -13051, 0, -21432, 0, -13050, 0, -21431, 0, -13049, 0, -21430, 0, -13046, 0, -21429, 0, -13045, 0, -21428, 0, -13043, 0, -21427, 0, -13042, 0, -21426, 0, -13041, 0, -21425, 0, -13039, 0, -21424, 0, -13038, 0, -21423, 0, -13037, 0, -21422, 0, -13036, 0, -21421, 0, -13035, 0, -21420, 0, -13034, 0, -21419, 0, -13033, 0, -21418, 0, -13030, 0, -21417, 0, -13028, 0, -21416, 0, -13026, 0, -21415, 0, -13025, 0, -21414, 0, -13024, 0, -21407, 0, -13023, 0, -21406, 0, -13022, 0, -21405, 0, -13021, 0, -21404, 0, -13019, 0, -21403, 0, -13018, 0, -21402, 0, -13017, 0, -21401, 0, -13015, 0, -21400, 0, -13014, 0, -21399, 0, -13013, 0, -21398, 0, -13011, 0, -21397, 0, -13010, 0, -21396, 0, -13009, 0, -21395, 0, -13008, 0, -21394, 0, -13007, 0, -21393, 0, -13006, 0, -21392, 0, -13005, 0, -21391, 0, -13004, 0, -21390, 0, -13003, 0, -21389, 0, -13002, 0, -21388, 0, -13001, 0, -21387, 0, -13000, 0, -21386, 0, -12998, 0, -21385, 0, -12997, 0, -21384, 0, -12996, 0, -21383, 0, -12995, 0, -21382, 0, -12994, 0, -21375, 0, -12993, 0, -21374, 0, -12992, 0, -21373, 0, -12991, 0, -21372, 0, -12990, 0, -21371, 0, -12989, 0, -21370, 0, -12988, 0, -21369, 0, -12987, 0, -21368, 0, -12986, 0, -21367, 0, -12985, 0, -21366, 0, -12984, 0, -21365, 0, -12983, 0, -21364, 0, -12982, 0, -21363, 0, -12981, 0, -21362, 0, -12980, 0, -21361, 0, -12979, 0, -21360, 0, -12978, 0, -21359, 0, -12977, 0, -21358, 0, -12976, 0, -21357, 0, -12975, 0, -21356, 0, -12974, 0, -21355, 0, -12973, 0, -21354, 0, -12972, 0, -21353, 0, -12971, 0, -21352, 0, -12970, 0, -21351, 0, -12969, 0, -21350, 0, -12968, 0, -21349, 0, -12967, 0, -21348, 0, -12966, 0, -21347, 0, -12965, 0, -21346, 0, -12963, 0, -21345, 0, -12962, 0, -21344, 0, -12961, 0, -21343, 0, 1040, 0, -21342, 0, 1041, 0, -21341, 0, 1042, 0, -21340, 0, 1043, 0, -21339, 0, 1044, 0, -21338, 0, 1045, 0, -21337, 0, 1025, 0, -21336, 0, 1046, 0, -21335, 0, 1047, 0, -21334, 0, 1048, 0, -21333, 0, 1049, 0, -21332, 0, 1050, 0, -21331, 0, 1051, 0, -21330, 0, 1052, 0, -21329, 0, 1053, 0, -21328, 0, 1054, 0, -21327, 0, 1055, 0, -21326, 0, 1056, 0, -21325, 0, 1057, 0, -21324, 0, 1058, 0, -21323, 0, 1059, 0, -21322, 0, 1060, 0, -21321, 0, 1061, 0, -21320, 0, 1062, 0, -21319, 0, 1063, 0, -21318, 0, 1064, 0, -21317, 0, 1065, 0, -21316, 0, 1066, 0, -21315, 0, 1067, 0, -21314, 0, 1068, 0, -21313, 0, 1069, 0, -21312, 0, 1070, 0, -21311, 0, 1071, 0, -21295, 0, 1072, 0, -21294, 0, 1073, 0, -21293, 0, 1074, 0, -21292, 0, 1075, 0, -21291, 0, 1076, 0, -21290, 0, 1077, 0, -21289, 0, 1105, 0, -21288, 0, 1078, 0, -21287, 0, 1079, 0, -21286, 0, 1080, 0, -21285, 0, 1081, 0, -21284, 0, 1082, 0, -21283, 0, 1083, 0, -21282, 0, 1084, 0, -21281, 0, 1085, 0, -21280, 0, 1086, 0, -21279, 0, 1087, 0, -21278, 0, 1088, 0, -21277, 0, 1089, 0, -21276, 0, 1090, 0, -21275, 0, 1091, 0, -21274, 0, 1092, 0, -21273, 0, 1093, 0, -21272, 0, 1094, 0, -21271, 0, 1095, 0, -21270, 0, 1096, 0, -21269, 0, 1097, 0, -21268, 0, 1098, 0, -21267, 0, 1099, 0, -21266, 0, 1100, 0, -21265, 0, 1101, 0, -21264, 0, 1102, 0, -21263, 0, 1103, 0, -21183, 0, -12959, 0, -21182, 0, -12958, 0, -21181, 0, -12957, 0, -21180, 0, -12955, 0, -21179, 0, -12954, 0, -21178, 0, -12953, 0, -21177, 0, -12952, 0, -21176, 0, -12951, 0, -21175, 0, -12950, 0, -21174, 0, -12949, 0, -21173, 0, -12946, 0, -21172, 0, -12944, 0, -21171, 0, -12942, 0, -21170, 0, -12941, 0, -21169, 0, -12940, 0, -21168, 0, -12939, 0, -21167, 0, -12938, 0, -21166, 0, -12937, 0, -21165, 0, -12935, 0, -21164, 0, -12934, 0, -21163, 0, -12933, 0, -21162, 0, -12932, 0, -21161, 0, -12931, 0, -21160, 0, -12930, 0, -21159, 0, -12929, 0, -21158, 0, -12928, 0, -21151, 0, -12927, 0, -21150, 0, -12926, 0, -21149, 0, -12925, 0, -21148, 0, -12924, 0, -21147, 0, -12923, 0, -21146, 0, -12922, 0, -21145, 0, -12921, 0, -21144, 0, -12919, 0, -21143, 0, -12918, 0, -21142, 0, -12917, 0, -21141, 0, -12916, 0, -21140, 0, -12915, 0, -21139, 0, -12914, 0, -21138, 0, -12913, 0, -21137, 0, -12912, 0, -21136, 0, -12911, 0, -21135, 0, -12910, 0, -21134, 0, -12909, 0, -21133, 0, -12906, 0, -21132, 0, -12905, 0, -21131, 0, -12903, 0, -21130, 0, -12902, 0, -21129, 0, -12901, 0, -21128, 0, -12899, 0, -21127, 0, -12898, 0, -21126, 0, -12897, 0, -21119, 0, -12896, 0, -21118, 0, -12895, 0, -21117, 0, -12894, 0, -21116, 0, -12893, 0, -21115, 0, -12890, 0, -21114, 0, -12888, 0, -21113, 0, -12886, 0, -21112, 0, -12885, 0, -21111, 0, -12884, 0, -21110, 0, -12883, 0, -21109, 0, -12882, 0, -21108, 0, -12881, 0, -21107, 0, -12879, 0, -21106, 0, -12878, 0, -21105, 0, -12877, 0, -21104, 0, -12876, 0, -21103, 0, -12875, 0, -21102, 0, -12874, 0, -21101, 0, -12873, 0, -21100, 0, -12872, 0, -21099, 0, -12871, 0, -21098, 0, -12870, 0, -21097, 0, -12869, 0, -21096, 0, -12868, 0, -21095, 0, -12867, 0, -21094, 0, -12866, 0, -21093, 0, -12865, 0, -21092, 0, -12864, 0, -21091, 0, -12863, 0, -21090, 0, -12862, 0, -21089, 0, -12861, 0, -21088, 0, -12859, 0, -20927, 0, -12858, 0, -20926, 0, -12857, 0, -20925, 0, -12856, 0, -20924, 0, -12855, 0, -20923, 0, -12854, 0, -20922, 0, -12853, 0, -20921, 0, -12851, 0, -20920, 0, -12850, 0, -20919, 0, -12849, 0, -20918, 0, -12847, 0, -20917, 0, -12846, 0, -20916, 0, -12845, 0, -20915, 0, -12844, 0, -20914, 0, -12843, 0, -20913, 0, -12842, 0, -20912, 0, -12841, 0, -20911, 0, -12840, 0, -20910, 0, -12839, 0, -20909, 0, -12838, 0, -20908, 0, -12837, 0, -20907, 0, -12836, 0, -20906, 0, -12835, 0, -20905, 0, -12834, 0, -20904, 0, -12833, 0, -20903, 0, -12832, 0, -20902, 0, -12831, 0, -20895, 0, -12830, 0, -20894, 0, -12829, 0, -20893, 0, -12828, 0, -20892, 0, -12827, 0, -20891, 0, -12826, 0, -20890, 0, -12825, 0, -20889, 0, -12823, 0, -20888, 0, -12822, 0, -20887, 0, -12821, 0, -20886, 0, -12819, 0, -20885, 0, -12818, 0, -20884, 0, -12817, 0, -20883, 0, -12815, 0, -20882, 0, -12814, 0, -20881, 0, -12813, 0, -20880, 0, -12812, 0, -20879, 0, -12811, 0, -20878, 0, -12810, 0, -20877, 0, -12809, 0, -20876, 0, -12806, 0, -20875, 0, -12804, 0, -20874, 0, -12802, 0, -20873, 0, -12801, 0, -20872, 0, -12800, 0, -20871, 0, -12799, 0, -20870, 0, -12798, 0, -20863, 0, -12797, 0, -20862, 0, -12795, 0, -20861, 0, -12794, 0, -20860, 0, -12793, 0, -20859, 0, -12791, 0, -20858, 0, -12790, 0, -20857, 0, -12789, 0, -20856, 0, -12787, 0, -20855, 0, -12786, 0, -20854, 0, -12785, 0, -20853, 0, -12784, 0, -20852, 0, -12783, 0, -20851, 0, -12782, 0, -20850, 0, -12781, 0, -20849, 0, -12779, 0, -20848, 0, -12778, 0, -20847, 0, -12777, 0, -20846, 0, -12776, 0, -20845, 0, -12774, 0, -20844, 0, -12773, 0, -20843, 0, -12772, 0, -20842, 0, -12771, 0, -20841, 0, -12770, 0, -20840, 0, -12769, 0, -20839, 0, -12766, 0, -20838, 0, -12765, 0, -20837, 0, -12763, 0, -20836, 0, -12762, 0, -20835, 0, -12761, 0, -20834, 0, -12759, 0, -20833, 0, -12758, 0, -20832, 0, -12757, 0, -20671, 0, -12756, 0, -20670, 0, -12755, 0, -20669, 0, -12754, 0, -20668, 0, -12753, 0, -20667, 0, -12750, 0, -20666, 0, -12748, 0, -20665, 0, -12746, 0, -20664, 0, -12745, 0, -20663, 0, -12744, 0, -20662, 0, -12743, 0, -20661, 0, -12742, 0, -20660, 0, -12741, 0, -20659, 0, -12740, 0, -20658, 0, -12739, 0, -20657, 0, -12738, 0, -20656, 0, -12737, 0, -20655, 0, -12736, 0, -20654, 0, -12735, 0, -20653, 0, -12734, 0, -20652, 0, -12733, 0, -20651, 0, -12732, 0, -20650, 0, -12731, 0, -20649, 0, -12730, 0, -20648, 0, -12729, 0, -20647, 0, -12728, 0, -20646, 0, -12727, 0, -20639, 0, -12726, 0, -20638, 0, -12725, 0, -20637, 0, -12724, 0, -20636, 0, -12723, 0, -20635, 0, -12722, 0, -20634, 0, -12721, 0, -20633, 0, -12720, 0, -20632, 0, -12719, 0, -20631, 0, -12718, 0, -20630, 0, -12717, 0, -20629, 0, -12716, 0, -20628, 0, -12715, 0, -20627, 0, -12714, 0, -20626, 0, -12713, 0, -20625, 0, -12710, 0, -20624, 0, -12709, 0, -20623, 0, -12707, 0, -20622, 0, -12706, 0, -20621, 0, -12702, 0, -20620, 0, -12701, 0, -20619, 0, -12700, 0, -20618, 0, -12699, 0, -20617, 0, -12698, 0, -20616, 0, -12697, 0, -20615, 0, -12694, 0, -20614, 0, -12692, 0, -20607, 0, -12690, 0, -20606, 0, -12689, 0, -20605, 0, -12688, 0, -20604, 0, -12687, 0, -20603, 0, -12686, 0, -20602, 0, -12685, 0, -20601, 0, -12682, 0, -20600, 0, -12681, 0, -20599, 0, -12679, 0, -20598, 0, -12678, 0, -20597, 0, -12677, 0, -20596, 0, -12675, 0, -20595, 0, -12674, 0, -20594, 0, -12673, 0, -20593, 0, -12672, 0, -20592, 0, -12671, 0, -20591, 0, -12670, 0, -20590, 0, -12669, 0, -20589, 0, -12666, 0, -20588, 0, -12664, 0, -20587, 0, -12662, 0, -20586, 0, -12661, 0, -20585, 0, -12660, 0, -20584, 0, -12659, 0, -20583, 0, -12658, 0, -20582, 0, -12657, 0, -20581, 0, -12654, 0, -20580, 0, -12653, 0, -20579, 0, -12651, 0, -20578, 0, -12650, 0, -20577, 0, -12649, 0, -20576, 0, -12647, 0, -20415, 0, -12646, 0, -20414, 0, -12645, 0, -20413, 0, -12644, 0, -20412, 0, -12643, 0, -20411, 0, -12642, 0, -20410, 0, -12641, 0, -20409, 0, -12638, 0, -20408, 0, -12634, 0, -20407, 0, -12633, 0, -20406, 0, -12632, 0, -20405, 0, -12631, 0, -20404, 0, -12630, 0, -20403, 0, -12629, 0, -20402, 0, -12626, 0, -20401, 0, -12625, 0, -20400, 0, -12624, 0, -20399, 0, -12623, 0, -20398, 0, -12622, 0, -20397, 0, -12621, 0, -20396, 0, -12620, 0, -20395, 0, -12619, 0, -20394, 0, -12618, 0, -20393, 0, -12617, 0, -20392, 0, -12616, 0, -20391, 0, -12615, 0, -20390, 0, -12614, 0, -20383, 0, -12613, 0, -20382, 0, -12612, 0, -20381, 0, -12611, 0, -20380, 0, -12610, 0, -20379, 0, -12609, 0, -20378, 0, -12608, 0, -20377, 0, -12606, 0, -20376, 0, -12605, 0, -20375, 0, -12604, 0, -20374, 0, -12603, 0, -20373, 0, -12602, 0, -20372, 0, -12601, 0, -20371, 0, -12600, 0, -20370, 0, -12599, 0, -20369, 0, -12598, 0, -20368, 0, -12597, 0, -20367, 0, -12596, 0, -20366, 0, -12595, 0, -20365, 0, -12594, 0, -20364, 0, -12593, 0, -20363, 0, -12592, 0, -20362, 0, -12591, 0, -20361, 0, -12590, 0, -20360, 0, -12589, 0, -20359, 0, -12588, 0, -20358, 0, -12587, 0, -20351, 0, -12586, 0, -20350, 0, -12585, 0, -20349, 0, -12584, 0, -20348, 0, -12583, 0, -20347, 0, -12582, 0, -20346, 0, -12581, 0, -20345, 0, -12580, 0, -20344, 0, -12579, 0, -20343, 0, -12578, 0, -20342, 0, -12577, 0, -20341, 0, -12576, 0, -20340, 0, -12575, 0, -20339, 0, -12574, 0, -20338, 0, -12573, 0, -20337, 0, -12570, 0, -20336, 0, -12569, 0, -20335, 0, -12567, 0, -20334, 0, -12566, 0, -20333, 0, -12563, 0, -20332, 0, -12562, 0, -20331, 0, -12561, 0, -20330, 0, -12560, 0, -20329, 0, -12559, 0, -20328, 0, -12558, 0, -20327, 0, -12557, 0, -20326, 0, -12554, 0, -20325, 0, -12550, 0, -20324, 0, -12549, 0, -20323, 0, -12548, 0, -20322, 0, -12547, 0, -20321, 0, -12546, 0, -20320, 0, -12545, 0, -20319, 0, -21504, 0, -20318, 0, -21503, 0, -20317, 0, -21500, 0, -20316, 0, -21497, 0, -20315, 0, -21496, 0, -20314, 0, -21495, 0, -20313, 0, -21494, 0, -20312, 0, -21488, 0, -20311, 0, -21487, 0, -20310, 0, -21486, 0, -20309, 0, -21485, 0, -20308, 0, -21484, 0, -20307, 0, -21483, 0, -20306, 0, -21482, 0, -20305, 0, -21481, 0, -20304, 0, -21479, 0, -20303, 0, -21478, 0, -20302, 0, -21477, 0, -20301, 0, -21476, 0, -20300, 0, -21475, 0, -20299, 0, -21472, 0, -20298, 0, -21468, 0, -20297, 0, -21460, 0, -20296, 0, -21459, 0, -20295, 0, -21457, 0, -20294, 0, -21456, 0, -20293, 0, -21455, 0, -20292, 0, -21448, 0, -20291, 0, -21447, 0, -20290, 0, -21444, 0, -20289, 0, -21440, 0, -20288, 0, -21429, 0, -20287, 0, -21427, 0, -20286, 0, -21420, 0, -20285, 0, -21416, 0, -20284, 0, -21412, 0, -20283, 0, -21392, 0, -20282, 0, -21391, 0, -20281, 0, -21388, 0, -20280, 0, -21385, 0, -20279, 0, -21384, 0, -20278, 0, -21382, 0, -20277, 0, -21376, 0, -20276, 0, -21375, 0, -20275, 0, -21373, 0, -20274, 0, -21372, 0, -20273, 0, -21371, 0, -20272, 0, -21370, 0, -20271, 0, -21367, 0, -20270, 0, -21366, 0, -20269, 0, -21365, 0, -20268, 0, -21364, 0, -20267, 0, -21360, 0, -20266, 0, -21356, 0, -20265, 0, -21348, 0, -20264, 0, -21347, 0, -20263, 0, -21345, 0, -20262, 0, -21344, 0, -20261, 0, -21343, 0, -20260, 0, -21336, 0, -20259, 0, -21335, 0, -20258, 0, -21334, 0, -20257, 0, -21332, 0, -20256, 0, -21329, 0, -20255, 0, -21328, 0, -20254, 0, -21320, 0, -20253, 0, -21319, 0, -20252, 0, -21317, 0, -20251, 0, -21316, 0, -20250, 0, -21315, 0, -20249, 0, -21311, 0, -20248, 0, -21308, 0, -20247, 0, -21304, 0, -20246, 0, -21300, 0, -20245, 0, -21291, 0, -20244, 0, -21289, 0, -20243, 0, -21280, 0, -20242, 0, -21279, 0, -20241, 0, -21276, 0, -20240, 0, -21273, 0, -20239, 0, -21272, 0, -20238, 0, -21270, 0, -20237, 0, -21268, 0, -20236, 0, -21265, 0, -20235, 0, -21264, 0, -20234, 0, -21263, 0, -20233, 0, -21261, 0, -20232, 0, -21259, 0, -20231, 0, -21258, 0, -20230, 0, -21252, 0, -20229, 0, -21251, 0, -20228, 0, -21248, 0, -20227, 0, -21244, 0, -20226, 0, -21242, 0, -20159, 0, -12542, 0, -20158, 0, -12541, 0, -20157, 0, -12539, 0, -20156, 0, -12538, 0, -20155, 0, -12537, 0, -20154, 0, -12535, 0, -20153, 0, -12534, 0, -20152, 0, -12533, 0, -20151, 0, -12532, 0, -20150, 0, -12531, 0, -20149, 0, -12530, 0, -20148, 0, -12529, 0, -20147, 0, -12526, 0, -20146, 0, -12524, 0, -20145, 0, -12522, 0, -20144, 0, -12521, 0, -20143, 0, -12520, 0, -20142, 0, -12519, 0, -20141, 0, -12518, 0, -20140, 0, -12517, 0, -20139, 0, -12515, 0, -20138, 0, -12514, 0, -20137, 0, -12513, 0, -20136, 0, -12511, 0, -20135, 0, -12510, 0, -20134, 0, -12509, 0, -20127, 0, -12507, 0, -20126, 0, -12506, 0, -20125, 0, -12505, 0, -20124, 0, -12504, 0, -20123, 0, -12503, 0, -20122, 0, -12502, 0, -20121, 0, -12501, 0, -20120, 0, -12498, 0, -20119, 0, -12494, 0, -20118, 0, -12493, 0, -20117, 0, -12492, 0, -20116, 0, -12491, 0, -20115, 0, -12490, 0, -20114, 0, -12489, 0, -20113, 0, -12487, 0, -20112, 0, -12486, 0, -20111, 0, -12485, 0, -20110, 0, -12484, 0, -20109, 0, -12483, 0, -20108, 0, -12482, 0, -20107, 0, -12481, 0, -20106, 0, -12480, 0, -20105, 0, -12479, 0, -20104, 0, -12478, 0, -20103, 0, -12477, 0, -20102, 0, -12476, 0, -20095, 0, -12475, 0, -20094, 0, -12474, 0, -20093, 0, -12473, 0, -20092, 0, -12472, 0, -20091, 0, -12471, 0, -20090, 0, -12470, 0, -20089, 0, -12469, 0, -20088, 0, -12468, 0, -20087, 0, -12467, 0, -20086, 0, -12466, 0, -20085, 0, -12465, 0, -20084, 0, -12464, 0, -20083, 0, -12463, 0, -20082, 0, -12462, 0, -20081, 0, -12461, 0, -20080, 0, -12458, 0, -20079, 0, -12457, 0, -20078, 0, -12455, 0, -20077, 0, -12454, 0, -20076, 0, -12453, 0, -20075, 0, -12451, 0, -20074, 0, -12450, 0, -20073, 0, -12449, 0, -20072, 0, -12448, 0, -20071, 0, -12447, 0, -20070, 0, -12446, 0, -20069, 0, -12445, 0, -20068, 0, -12442, 0, -20067, 0, -12440, 0, -20066, 0, -12438, 0, -20065, 0, -12437, 0, -20064, 0, -12436, 0, -20063, 0, -21236, 0, -20062, 0, -21235, 0, -20061, 0, -21233, 0, -20060, 0, -21231, 0, -20059, 0, -21224, 0, -20058, 0, -21220, 0, -20057, 0, -21216, 0, -20056, 0, -21207, 0, -20055, 0, -21204, 0, -20054, 0, -21203, 0, -20053, 0, -21196, 0, -20052, 0, -21195, 0, -20051, 0, -21192, 0, -20050, 0, -21188, 0, -20049, 0, -21180, 0, -20048, 0, -21179, 0, -20047, 0, -21177, 0, -20046, 0, -21175, 0, -20045, 0, -21168, 0, -20044, 0, -21164, 0, -20043, 0, -21160, 0, -20042, 0, -21151, 0, -20041, 0, -21149, 0, -20040, 0, -21140, 0, -20039, 0, -21139, 0, -20038, 0, -21136, 0, -20037, 0, -21133, 0, -20036, 0, -21132, 0, -20035, 0, -21131, 0, -20034, 0, -21130, 0, -20033, 0, -21125, 0, -20032, 0, -21124, 0, -20031, 0, -21123, 0, -20030, 0, -21121, 0, -20029, 0, -21119, 0, -20028, 0, -21118, 0, -20027, 0, -21112, 0, -20026, 0, -21111, 0, -20025, 0, -21108, 0, -20024, 0, -21104, 0, -20023, 0, -21092, 0, -20022, 0, -21091, 0, -20021, 0, -21084, 0, -20020, 0, -21065, 0, -20019, 0, -21056, 0, -20018, 0, -21055, 0, -20017, 0, -21052, 0, -20016, 0, -21048, 0, -20015, 0, -21040, 0, -20014, 0, -21039, 0, -20013, 0, -21037, 0, -20012, 0, -21028, 0, -20011, 0, -21024, 0, -20010, 0, -21020, 0, -20009, 0, -21000, 0, -20008, 0, -20999, 0, -20007, 0, -20996, 0, -20006, 0, -20993, 0, -20005, 0, -20992, 0, -20004, 0, -20991, 0, -20003, 0, -20984, 0, -20002, 0, -20983, 0, -20001, 0, -20981, 0, -20000, 0, -20979, 0, -19999, 0, -20972, 0, -19998, 0, -20944, 0, -19997, 0, -20943, 0, -19996, 0, -20940, 0, -19995, 0, -20937, 0, -19994, 0, -20936, 0, -19993, 0, -20934, 0, -19992, 0, -20928, 0, -19991, 0, -20927, 0, -19990, 0, -20925, 0, -19989, 0, -20923, 0, -19988, 0, -20922, 0, -19987, 0, -20918, 0, -19986, 0, -20916, 0, -19985, 0, -20915, 0, -19984, 0, -20914, 0, -19983, 0, -20912, 0, -19982, 0, -20908, 0, -19981, 0, -20906, 0, -19980, 0, -20900, 0, -19979, 0, -20899, 0, -19978, 0, -20897, 0, -19977, 0, -20896, 0, -19976, 0, -20895, 0, -19975, 0, -20891, 0, -19974, 0, -20888, 0, -19973, 0, -20887, 0, -19972, 0, -20884, 0, -19971, 0, -20880, 0, -19970, 0, -20872, 0, -19903, 0, -12435, 0, -19902, 0, -12434, 0, -19901, 0, -12433, 0, -19900, 0, -12430, 0, -19899, 0, -12429, 0, -19898, 0, -12427, 0, -19897, 0, -12426, 0, -19896, 0, -12425, 0, -19895, 0, -12423, 0, -19894, 0, -12422, 0, -19893, 0, -12421, 0, -19892, 0, -12420, 0, -19891, 0, -12419, 0, -19890, 0, -12418, 0, -19889, 0, -12417, 0, -19888, 0, -12415, 0, -19887, 0, -12414, 0, -19886, 0, -12413, 0, -19885, 0, -12412, 0, -19884, 0, -12410, 0, -19883, 0, -12409, 0, -19882, 0, -12408, 0, -19881, 0, -12407, 0, -19880, 0, -12406, 0, -19879, 0, -12405, 0, -19878, 0, -12403, 0, -19871, 0, -12402, 0, -19870, 0, -12401, 0, -19869, 0, -12400, 0, -19868, 0, -12399, 0, -19867, 0, -12398, 0, -19866, 0, -12397, 0, -19865, 0, -12396, 0, -19864, 0, -12395, 0, -19863, 0, -12394, 0, -19862, 0, -12393, 0, -19861, 0, -12392, 0, -19860, 0, -12391, 0, -19859, 0, -12390, 0, -19858, 0, -12389, 0, -19857, 0, -12388, 0, -19856, 0, -12387, 0, -19855, 0, -12386, 0, -19854, 0, -12385, 0, -19853, 0, -12384, 0, -19852, 0, -12382, 0, -19851, 0, -12381, 0, -19850, 0, -12380, 0, -19849, 0, -12379, 0, -19848, 0, -12378, 0, -19847, 0, -12377, 0, -19846, 0, -12375, 0, -19839, 0, -12374, 0, -19838, 0, -12373, 0, -19837, 0, -12372, 0, -19836, 0, -12371, 0, -19835, 0, -12370, 0, -19834, 0, -12369, 0, -19833, 0, -12367, 0, -19832, 0, -12366, 0, -19831, 0, -12365, 0, -19830, 0, -12364, 0, -19829, 0, -12363, 0, -19828, 0, -12362, 0, -19827, 0, -12361, 0, -19826, 0, -12360, 0, -19825, 0, -12359, 0, -19824, 0, -12358, 0, -19823, 0, -12357, 0, -19822, 0, -12356, 0, -19821, 0, -12355, 0, -19820, 0, -12354, 0, -19819, 0, -12353, 0, -19818, 0, -12352, 0, -19817, 0, -12351, 0, -19816, 0, -12350, 0, -19815, 0, -12349, 0, -19814, 0, -12347, 0, -19813, 0, -12346, 0, -19812, 0, -12345, 0, -19811, 0, -12344, 0, -19810, 0, -12343, 0, -19809, 0, -12342, 0, -19808, 0, -12341, 0, -19807, 0, -20871, 0, -19806, 0, -20869, 0, -19805, 0, -20868, 0, -19804, 0, -20867, 0, -19803, 0, -20860, 0, -19802, 0, -20859, 0, -19801, 0, -20852, 0, -19800, 0, -20804, 0, -19799, 0, -20803, 0, -19798, 0, -20802, 0, -19797, 0, -20800, 0, -19796, 0, -20796, 0, -19795, 0, -20788, 0, -19794, 0, -20787, 0, -19793, 0, -20785, 0, -19792, 0, -20784, 0, -19791, 0, -20783, 0, -19790, 0, -20776, 0, -19789, 0, -20775, 0, -19788, 0, -20772, 0, -19787, 0, -20760, 0, -19786, 0, -20757, 0, -19785, 0, -20755, 0, -19784, 0, -20748, 0, -19783, 0, -20744, 0, -19782, 0, -20740, 0, -19781, 0, -20729, 0, -19780, 0, -20728, 0, -19779, 0, -20723, 0, -19778, 0, -20720, 0, -19777, 0, -20692, 0, -19776, 0, -20691, 0, -19775, 0, -20688, 0, -19774, 0, -20686, 0, -19773, 0, -20684, 0, -19772, 0, -20676, 0, -19771, 0, -20675, 0, -19770, 0, -20673, 0, -19769, 0, -20671, 0, -19768, 0, -20670, 0, -19767, 0, -20669, 0, -19766, 0, -20664, 0, -19765, 0, -20663, 0, -19764, 0, -20656, 0, -19763, 0, -20644, 0, -19762, 0, -20643, 0, -19761, 0, -20636, 0, -19760, 0, -20635, 0, -19759, 0, -20615, 0, -19758, 0, -20608, 0, -19757, 0, -20604, 0, -19756, 0, -20600, 0, -19755, 0, -20592, 0, -19754, 0, -20591, 0, -19753, 0, -20587, 0, -19752, 0, -20580, 0, -19751, 0, -20552, 0, -19750, 0, -20551, 0, -19749, 0, -20548, 0, -19748, 0, -20544, 0, -19747, 0, -20537, 0, -19746, 0, -20536, 0, -19745, 0, -20535, 0, -19744, 0, -20533, 0, -19743, 0, -20531, 0, -19742, 0, -20530, 0, -19741, 0, -20524, 0, -19740, 0, -20516, 0, -19739, 0, -20504, 0, -19738, 0, -20503, 0, -19737, 0, -20496, 0, -19736, 0, -20495, 0, -19735, 0, -20492, 0, -19734, 0, -20488, 0, -19733, 0, -20480, 0, -19732, 0, -20479, 0, -19731, 0, -20476, 0, -19730, 0, -20468, 0, -19729, 0, -20464, 0, -19728, 0, -20460, 0, -19727, 0, -20452, 0, -19726, 0, -20451, 0, -19725, 0, -20440, 0, -19724, 0, -20412, 0, -19723, 0, -20411, 0, -19722, 0, -20408, 0, -19721, 0, -20406, 0, -19720, 0, -20404, 0, -19719, 0, -20402, 0, -19718, 0, -20397, 0, -19717, 0, -20396, 0, -19716, 0, -20395, 0, -19715, 0, -20393, 0, -19714, 0, -20391, 0, -19647, 0, -12340, 0, -19646, 0, -12339, 0, -19645, 0, -12338, 0, -19644, 0, -12337, 0, -19643, 0, -12336, 0, -19642, 0, -12335, 0, -19641, 0, -12334, 0, -19640, 0, -12333, 0, -19639, 0, -12332, 0, -19638, 0, -12331, 0, -19637, 0, -12330, 0, -19636, 0, -12329, 0, -19635, 0, -12328, 0, -19634, 0, -12327, 0, -19633, 0, -12326, 0, -19632, 0, -12325, 0, -19631, 0, -12324, 0, -19630, 0, -12323, 0, -19629, 0, -12322, 0, -19628, 0, -12321, 0, -19627, 0, -12318, 0, -19626, 0, -12317, 0, -19625, 0, -12315, 0, -19624, 0, -12314, 0, -19623, 0, -12313, 0, -19622, 0, -12311, 0, -19615, 0, -12310, 0, -19614, 0, -12309, 0, -19613, 0, -12308, 0, -19612, 0, -12307, 0, -19611, 0, -12306, 0, -19610, 0, -12305, 0, -19609, 0, -12302, 0, -19608, 0, -12300, 0, -19607, 0, -12298, 0, -19606, 0, -12297, 0, -19605, 0, -12296, 0, -19604, 0, -12295, 0, -19603, 0, -12294, 0, -19602, 0, -12293, 0, -19601, 0, -12291, 0, -19600, 0, -12290, 0, -19599, 0, -12289, 0, -19598, 0, -12287, 0, -19597, 0, -12286, 0, -19596, 0, -12285, 0, -19595, 0, -12283, 0, -19594, 0, -12282, 0, -19593, 0, -12281, 0, -19592, 0, -12280, 0, -19591, 0, -12279, 0, -19590, 0, -12278, 0, -19583, 0, -12277, 0, -19582, 0, -12276, 0, -19581, 0, -12275, 0, -19580, 0, -12274, 0, -19579, 0, -12273, 0, -19578, 0, -12272, 0, -19577, 0, -12270, 0, -19576, 0, -12269, 0, -19575, 0, -12268, 0, -19574, 0, -12267, 0, -19573, 0, -12266, 0, -19572, 0, -12265, 0, -19571, 0, -12263, 0, -19570, 0, -12262, 0, -19569, 0, -12261, 0, -19568, 0, -12260, 0, -19567, 0, -12259, 0, -19566, 0, -12258, 0, -19565, 0, -12257, 0, -19564, 0, -12256, 0, -19563, 0, -12255, 0, -19562, 0, -12254, 0, -19561, 0, -12253, 0, -19560, 0, -12252, 0, -19559, 0, -12251, 0, -19558, 0, -12250, 0, -19557, 0, -12249, 0, -19556, 0, -12248, 0, -19555, 0, -12247, 0, -19554, 0, -12246, 0, -19553, 0, -12245, 0, -19552, 0, -12244, 0, -19551, 0, -20387, 0, -19550, 0, -20356, 0, -19549, 0, -20355, 0, -19548, 0, -20352, 0, -19547, 0, -20348, 0, -19546, 0, -20340, 0, -19545, 0, -20339, 0, -19544, 0, -20337, 0, -19543, 0, -20335, 0, -19542, 0, -20328, 0, -19541, 0, -20327, 0, -19540, 0, -20326, 0, -19539, 0, -20324, 0, -19538, 0, -20321, 0, -19537, 0, -20320, 0, -19536, 0, -20319, 0, -19535, 0, -20318, 0, -19534, 0, -20312, 0, -19533, 0, -20311, 0, -19532, 0, -20309, 0, -19531, 0, -20308, 0, -19530, 0, -20307, 0, -19529, 0, -20306, 0, -19528, 0, -20305, 0, -19527, 0, -20303, 0, -19526, 0, -20301, 0, -19525, 0, -20300, 0, -19524, 0, -20299, 0, -19523, 0, -20296, 0, -19522, 0, -20292, 0, -19521, 0, -20284, 0, -19520, 0, -20283, 0, -19519, 0, -20281, 0, -19518, 0, -20280, 0, -19517, 0, -20279, 0, -19516, 0, -20272, 0, -19515, 0, -20271, 0, -19514, 0, -20268, 0, -19513, 0, -20264, 0, -19512, 0, -20256, 0, -19511, 0, -20251, 0, -19510, 0, -20216, 0, -19509, 0, -20215, 0, -19508, 0, -20213, 0, -19507, 0, -20212, 0, -19506, 0, -20208, 0, -19505, 0, -20206, 0, -19504, 0, -20205, 0, -19503, 0, -20200, 0, -19502, 0, -20199, 0, -19501, 0, -20197, 0, -19500, 0, -20196, 0, -19499, 0, -20195, 0, -19498, 0, -20189, 0, -19497, 0, -20188, 0, -19496, 0, -20187, 0, -19495, 0, -20184, 0, -19494, 0, -20180, 0, -19493, 0, -20172, 0, -19492, 0, -20171, 0, -19491, 0, -20169, 0, -19490, 0, -20168, 0, -19489, 0, -20167, 0, -19488, 0, -20160, 0, -19487, 0, -20159, 0, -19486, 0, -20156, 0, -19485, 0, -20152, 0, -19484, 0, -20144, 0, -19483, 0, -20143, 0, -19482, 0, -20140, 0, -19481, 0, -20139, 0, -19480, 0, -20136, 0, -19479, 0, -20132, 0, -19478, 0, -20128, 0, -19477, 0, -20104, 0, -19476, 0, -20103, 0, -19475, 0, -20100, 0, -19474, 0, -20096, 0, -19473, 0, -20094, 0, -19472, 0, -20088, 0, -19471, 0, -20087, 0, -19470, 0, -20085, 0, -19469, 0, -20083, 0, -19468, 0, -20078, 0, -19467, 0, -20077, 0, -19466, 0, -20076, 0, -19465, 0, -20072, 0, -19464, 0, -20068, 0, -19463, 0, -20056, 0, -19462, 0, -20020, 0, -19461, 0, -20016, 0, -19460, 0, -20012, 0, -19459, 0, -20004, 0, -19458, 0, -20003, 0, -19391, 0, -12242, 0, -19390, 0, -12241, 0, -19389, 0, -12240, 0, -19388, 0, -12239, 0, -19387, 0, -12238, 0, -19386, 0, -12237, 0, -19385, 0, -12234, 0, -19384, 0, -12233, 0, -19383, 0, -12231, 0, -19382, 0, -12230, 0, -19381, 0, -12229, 0, -19380, 0, -12227, 0, -19379, 0, -12226, 0, -19378, 0, -12225, 0, -19377, 0, -12224, 0, -19376, 0, -12223, 0, -19375, 0, -12222, 0, -19374, 0, -12221, 0, -19373, 0, -12218, 0, -19372, 0, -12216, 0, -19371, 0, -12214, 0, -19370, 0, -12213, 0, -19369, 0, -12212, 0, -19368, 0, -12211, 0, -19367, 0, -12210, 0, -19366, 0, -12209, 0, -19359, 0, -12207, 0, -19358, 0, -12206, 0, -19357, 0, -12205, 0, -19356, 0, -12203, 0, -19355, 0, -12202, 0, -19354, 0, -12201, 0, -19353, 0, -12199, 0, -19352, 0, -12198, 0, -19351, 0, -12197, 0, -19350, 0, -12196, 0, -19349, 0, -12195, 0, -19348, 0, -12194, 0, -19347, 0, -12193, 0, -19346, 0, -12191, 0, -19345, 0, -12190, 0, -19344, 0, -12189, 0, -19343, 0, -12188, 0, -19342, 0, -12187, 0, -19341, 0, -12186, 0, -19340, 0, -12185, 0, -19339, 0, -12184, 0, -19338, 0, -12183, 0, -19337, 0, -12182, 0, -19336, 0, -12181, 0, -19335, 0, -12178, 0, -19334, 0, -12177, 0, -19327, 0, -12175, 0, -19326, 0, -12174, 0, -19325, 0, -12173, 0, -19324, 0, -12171, 0, -19323, 0, -12170, 0, -19322, 0, -12169, 0, -19321, 0, -12168, 0, -19320, 0, -12167, 0, -19319, 0, -12166, 0, -19318, 0, -12165, 0, -19317, 0, -12162, 0, -19316, 0, -12161, 0, -19315, 0, -12160, 0, -19314, 0, -12158, 0, -19313, 0, -12157, 0, -19312, 0, -12156, 0, -19311, 0, -12155, 0, -19310, 0, -12154, 0, -19309, 0, -12153, 0, -19308, 0, -12152, 0, -19307, 0, -12151, 0, -19306, 0, -12150, 0, -19305, 0, -12149, 0, -19304, 0, -12148, 0, -19303, 0, -12147, 0, -19302, 0, -12146, 0, -19301, 0, -12145, 0, -19300, 0, -12144, 0, -19299, 0, -12143, 0, -19298, 0, -12142, 0, -19297, 0, -12141, 0, -19296, 0, -12140, 0, -19295, 0, -20001, 0, -19294, 0, -19992, 0, -19293, 0, -19991, 0, -19292, 0, -19988, 0, -19291, 0, -19984, 0, -19290, 0, -19975, 0, -19289, 0, -19973, 0, -19288, 0, -19971, 0, -19287, 0, -19964, 0, -19286, 0, -19963, 0, -19285, 0, -19960, 0, -19284, 0, -19957, 0, -19283, 0, -19956, 0, -19282, 0, -19948, 0, -19281, 0, -19947, 0, -19280, 0, -19945, 0, -19279, 0, -19943, 0, -19278, 0, -19936, 0, -19277, 0, -19916, 0, -19276, 0, -19908, 0, -19275, 0, -19880, 0, -19274, 0, -19876, 0, -19273, 0, -19872, 0, -19272, 0, -19864, 0, -19271, 0, -19863, 0, -19270, 0, -19852, 0, -19269, 0, -19851, 0, -19268, 0, -19844, 0, -19267, 0, -19836, 0, -19266, 0, -19835, 0, -19265, 0, -19831, 0, -19264, 0, -19824, 0, -19263, 0, -19823, 0, -19262, 0, -19820, 0, -19261, 0, -19816, 0, -19260, 0, -19815, 0, -19259, 0, -19814, 0, -19258, 0, -19808, 0, -19257, 0, -19807, 0, -19256, 0, -19805, 0, -19255, 0, -19803, 0, -19254, 0, -19802, 0, -19253, 0, -19798, 0, -19252, 0, -19796, 0, -19251, 0, -19792, 0, -19250, 0, -19788, 0, -19249, 0, -19768, 0, -19248, 0, -19767, 0, -19247, 0, -19764, 0, -19246, 0, -19760, 0, -19245, 0, -19758, 0, -19244, 0, -19752, 0, -19243, 0, -19751, 0, -19242, 0, -19749, 0, -19241, 0, -19747, 0, -19240, 0, -19742, 0, -19239, 0, -19740, 0, -19238, 0, -19739, 0, -19237, 0, -19738, 0, -19236, 0, -19736, 0, -19235, 0, -19733, 0, -19234, 0, -19732, 0, -19233, 0, -19731, 0, -19232, 0, -19730, 0, -19231, 0, -19729, 0, -19230, 0, -19725, 0, -19229, 0, -19724, 0, -19228, 0, -19723, 0, -19227, 0, -19721, 0, -19226, 0, -19720, 0, -19225, 0, -19719, 0, -19224, 0, -19718, 0, -19223, 0, -19717, 0, -19222, 0, -19713, 0, -19221, 0, -19712, 0, -19220, 0, -19711, 0, -19219, 0, -19708, 0, -19218, 0, -19704, 0, -19217, 0, -19696, 0, -19216, 0, -19695, 0, -19215, 0, -19693, 0, -19214, 0, -19692, 0, -19213, 0, -19691, 0, -19212, 0, -19684, 0, -19211, 0, -19628, 0, -19210, 0, -19627, 0, -19209, 0, -19626, 0, -19208, 0, -19624, 0, -19207, 0, -19621, 0, -19206, 0, -19620, 0, -19205, 0, -19618, 0, -19204, 0, -19617, 0, -19203, 0, -19612, 0, -19202, 0, -19611, 0, -19135, 0, -12139, 0, -19134, 0, -12138, 0, -19133, 0, -12137, 0, -19132, 0, -12136, 0, -19131, 0, -12135, 0, -19130, 0, -12134, 0, -19129, 0, -12133, 0, -19128, 0, -12132, 0, -19127, 0, -12131, 0, -19126, 0, -12130, 0, -19125, 0, -12129, 0, -19124, 0, -12128, 0, -19123, 0, -12127, 0, -19122, 0, -12126, 0, -19121, 0, -12125, 0, -19120, 0, -12122, 0, -19119, 0, -12121, 0, -19118, 0, -12119, 0, -19117, 0, -12118, 0, -19116, 0, -12117, 0, -19115, 0, -12115, 0, -19114, 0, -12114, 0, -19113, 0, -12113, 0, -19112, 0, -12112, 0, -19111, 0, -12111, 0, -19110, 0, -12110, 0, -19103, 0, -12109, 0, -19102, 0, -12106, 0, -19101, 0, -12104, 0, -19100, 0, -12102, 0, -19099, 0, -12101, 0, -19098, 0, -12100, 0, -19097, 0, -12099, 0, -19096, 0, -12098, 0, -19095, 0, -12097, 0, -19094, 0, -12094, 0, -19093, 0, -12093, 0, -19092, 0, -12091, 0, -19091, 0, -12090, 0, -19090, 0, -12089, 0, -19089, 0, -12086, 0, -19088, 0, -12085, 0, -19087, 0, -12084, 0, -19086, 0, -12083, 0, -19085, 0, -12082, 0, -19084, 0, -12081, 0, -19083, 0, -12078, 0, -19082, 0, -12074, 0, -19081, 0, -12073, 0, -19080, 0, -12072, 0, -19079, 0, -12071, 0, -19078, 0, -12070, 0, -19071, 0, -12069, 0, -19070, 0, -12066, 0, -19069, 0, -12065, 0, -19068, 0, -12063, 0, -19067, 0, -12062, 0, -19066, 0, -12061, 0, -19065, 0, -12059, 0, -19064, 0, -12058, 0, -19063, 0, -12057, 0, -19062, 0, -12056, 0, -19061, 0, -12055, 0, -19060, 0, -12054, 0, -19059, 0, -12053, 0, -19058, 0, -12050, 0, -19057, 0, -12046, 0, -19056, 0, -12045, 0, -19055, 0, -12044, 0, -19054, 0, -12043, 0, -19053, 0, -12042, 0, -19052, 0, -12041, 0, -19051, 0, -12039, 0, -19050, 0, -12038, 0, -19049, 0, -12037, 0, -19048, 0, -12036, 0, -19047, 0, -12035, 0, -19046, 0, -12034, 0, -19045, 0, -12033, 0, -19044, 0, -12032, 0, -19043, 0, -12031, 0, -19042, 0, -12030, 0, -19041, 0, -12029, 0, -19040, 0, -12028, 0, -19039, 0, -19609, 0, -19038, 0, -19607, 0, -19037, 0, -19605, 0, -19036, 0, -19602, 0, -19035, 0, -19600, 0, -19034, 0, -19599, 0, -19033, 0, -19596, 0, -19032, 0, -19592, 0, -19031, 0, -19584, 0, -19030, 0, -19583, 0, -19029, 0, -19581, 0, -19028, 0, -19580, 0, -19027, 0, -19579, 0, -19026, 0, -19572, 0, -19025, 0, -19568, 0, -19024, 0, -19564, 0, -19023, 0, -19552, 0, -19022, 0, -19551, 0, -19021, 0, -19544, 0, -19020, 0, -19540, 0, -19019, 0, -19516, 0, -19018, 0, -19515, 0, -19017, 0, -19512, 0, -19016, 0, -19509, 0, -19015, 0, -19508, 0, -19014, 0, -19506, 0, -19013, 0, -19504, 0, -19012, 0, -19500, 0, -19011, 0, -19499, 0, -19010, 0, -19497, 0, -19009, 0, -19495, 0, -19008, 0, -19493, 0, -19007, 0, -19491, 0, -19006, 0, -19488, 0, -19005, 0, -19484, 0, -19004, 0, -19480, 0, -19003, 0, -19460, 0, -19002, 0, -19440, 0, -19001, 0, -19432, 0, -19000, 0, -19428, 0, -18999, 0, -19424, 0, -18998, 0, -19416, 0, -18997, 0, -19415, 0, -18996, 0, -19413, 0, -18995, 0, -19404, 0, -18994, 0, -19376, 0, -18993, 0, -19375, 0, -18992, 0, -19372, 0, -18991, 0, -19368, 0, -18990, 0, -19360, 0, -18989, 0, -19359, 0, -18988, 0, -19357, 0, -18987, 0, -19355, 0, -18986, 0, -19348, 0, -18985, 0, -19328, 0, -18984, 0, -19320, 0, -18983, 0, -19299, 0, -18982, 0, -19292, 0, -18981, 0, -19288, 0, -18980, 0, -19284, 0, -18979, 0, -19275, 0, -18978, 0, -19273, 0, -18977, 0, -19271, 0, -18976, 0, -19264, 0, -18975, 0, -19260, 0, -18974, 0, -19256, 0, -18973, 0, -19248, 0, -18972, 0, -19243, 0, -18971, 0, -19236, 0, -18970, 0, -19235, 0, -18969, 0, -19232, 0, -18968, 0, -19229, 0, -18967, 0, -19228, 0, -18966, 0, -19226, 0, -18965, 0, -19220, 0, -18964, 0, -19219, 0, -18963, 0, -19217, 0, -18962, 0, -19215, 0, -18961, 0, -19208, 0, -18960, 0, -19180, 0, -18959, 0, -19179, 0, -18958, 0, -19176, 0, -18957, 0, -19173, 0, -18956, 0, -19172, 0, -18955, 0, -19164, 0, -18954, 0, -19163, 0, -18953, 0, -19161, 0, -18952, 0, -19160, 0, -18951, 0, -19159, 0, -18950, 0, -19158, 0, -18949, 0, -19152, 0, -18948, 0, -19151, 0, -18947, 0, -19148, 0, -18946, 0, -19144, 0, -18879, 0, -12027, 0, -18878, 0, -12026, 0, -18877, 0, -12025, 0, -18876, 0, -12024, 0, -18875, 0, -12023, 0, -18874, 0, -12022, 0, -18873, 0, -12021, 0, -18872, 0, -12020, 0, -18871, 0, -12018, 0, -18870, 0, -12017, 0, -18869, 0, -12016, 0, -18868, 0, -12015, 0, -18867, 0, -12014, 0, -18866, 0, -12013, 0, -18865, 0, -12012, 0, -18864, 0, -12011, 0, -18863, 0, -12010, 0, -18862, 0, -12009, 0, -18861, 0, -12008, 0, -18860, 0, -12007, 0, -18859, 0, -12006, 0, -18858, 0, -12005, 0, -18857, 0, -12004, 0, -18856, 0, -12003, 0, -18855, 0, -12002, 0, -18854, 0, -12001, 0, -18847, 0, -12000, 0, -18846, 0, -11999, 0, -18845, 0, -11998, 0, -18844, 0, -11997, 0, -18843, 0, -11996, 0, -18842, 0, -11995, 0, -18841, 0, -11994, 0, -18840, 0, -11993, 0, -18839, 0, -11992, 0, -18838, 0, -11991, 0, -18837, 0, -11990, 0, -18836, 0, -11989, 0, -18835, 0, -11988, 0, -18834, 0, -11987, 0, -18833, 0, -11986, 0, -18832, 0, -11985, 0, -18831, 0, -11982, 0, -18830, 0, -11981, 0, -18829, 0, -11979, 0, -18828, 0, -11978, 0, -18827, 0, -11977, 0, -18826, 0, -11975, 0, -18825, 0, -11973, 0, -18824, 0, -11972, 0, -18823, 0, -11971, 0, -18822, 0, -11970, 0, -18815, 0, -11969, 0, -18814, 0, -11966, 0, -18813, 0, -11962, 0, -18812, 0, -11961, 0, -18811, 0, -11960, 0, -18810, 0, -11959, 0, -18809, 0, -11958, 0, -18808, 0, -11957, 0, -18807, 0, -11954, 0, -18806, 0, -11953, 0, -18805, 0, -11951, 0, -18804, 0, -11950, 0, -18803, 0, -11949, 0, -18802, 0, -11947, 0, -18801, 0, -11946, 0, -18800, 0, -11945, 0, -18799, 0, -11944, 0, -18798, 0, -11943, 0, -18797, 0, -11942, 0, -18796, 0, -11941, 0, -18795, 0, -11938, 0, -18794, 0, -11936, 0, -18793, 0, -11934, 0, -18792, 0, -11933, 0, -18791, 0, -11932, 0, -18790, 0, -11931, 0, -18789, 0, -11930, 0, -18788, 0, -11929, 0, -18787, 0, -11927, 0, -18786, 0, -11926, 0, -18785, 0, -11925, 0, -18784, 0, -11923, 0, -18783, 0, -19136, 0, -18782, 0, -19135, 0, -18781, 0, -19133, 0, -18780, 0, -19132, 0, -18779, 0, -19131, 0, -18778, 0, -19125, 0, -18777, 0, -19124, 0, -18776, 0, -19123, 0, -18775, 0, -19120, 0, -18774, 0, -19116, 0, -18773, 0, -19108, 0, -18772, 0, -19107, 0, -18771, 0, -19105, 0, -18770, 0, -19104, 0, -18769, 0, -19103, 0, -18768, 0, -19040, 0, -18767, 0, -19039, 0, -18766, 0, -19036, 0, -18765, 0, -19032, 0, -18764, 0, -19030, 0, -18763, 0, -19029, 0, -18762, 0, -19024, 0, -18761, 0, -19023, 0, -18760, 0, -19021, 0, -18759, 0, -19020, 0, -18758, 0, -19019, 0, -18757, 0, -19013, 0, -18756, 0, -19012, 0, -18755, 0, -19011, 0, -18754, 0, -19008, 0, -18753, 0, -19004, 0, -18752, 0, -18996, 0, -18751, 0, -18995, 0, -18750, 0, -18993, 0, -18749, 0, -18992, 0, -18748, 0, -18991, 0, -18747, 0, -18984, 0, -18746, 0, -18964, 0, -18745, 0, -18928, 0, -18744, 0, -18927, 0, -18743, 0, -18924, 0, -18742, 0, -18920, 0, -18741, 0, -18907, 0, -18740, 0, -18900, 0, -18739, 0, -18892, 0, -18738, 0, -18872, 0, -18737, 0, -18844, 0, -18736, 0, -18840, 0, -18735, 0, -18788, 0, -18734, 0, -18787, 0, -18733, 0, -18784, 0, -18732, 0, -18780, 0, -18731, 0, -18773, 0, -18730, 0, -18772, 0, -18729, 0, -18767, 0, -18728, 0, -18732, 0, -18727, 0, -18704, 0, -18726, 0, -18700, 0, -18725, 0, -18696, 0, -18724, 0, -18688, 0, -18723, 0, -18687, 0, -18722, 0, -18683, 0, -18721, 0, -18648, 0, -18720, 0, -18647, 0, -18719, 0, -18644, 0, -18718, 0, -18641, 0, -18717, 0, -18640, 0, -18716, 0, -18632, 0, -18715, 0, -18631, 0, -18714, 0, -18629, 0, -18713, 0, -18620, 0, -18712, 0, -18616, 0, -18711, 0, -18612, 0, -18710, 0, -18604, 0, -18709, 0, -18603, 0, -18708, 0, -18592, 0, -18707, 0, -18588, 0, -18706, 0, -18584, 0, -18705, 0, -18576, 0, -18704, 0, -18575, 0, -18703, 0, -18573, 0, -18702, 0, -18571, 0, -18701, 0, -18564, 0, -18700, 0, -18563, 0, -18699, 0, -18560, 0, -18698, 0, -18556, 0, -18697, 0, -18548, 0, -18696, 0, -18547, 0, -18695, 0, -18545, 0, -18694, 0, -18544, 0, -18693, 0, -18543, 0, -18692, 0, -18542, 0, -18691, 0, -18538, 0, -18690, 0, -18537, 0, -18623, 0, -11922, 0, -18622, 0, -11921, 0, -18621, 0, -11920, 0, -18620, 0, -11919, 0, -18619, 0, -11918, 0, -18618, 0, -11917, 0, -18617, 0, -11916, 0, -18616, 0, -11915, 0, -18615, 0, -11914, 0, -18614, 0, -11913, 0, -18613, 0, -11912, 0, -18612, 0, -11911, 0, -18611, 0, -11910, 0, -18610, 0, -11909, 0, -18609, 0, -11907, 0, -18608, 0, -11906, 0, -18607, 0, -11905, 0, -18606, 0, -11904, 0, -18605, 0, -11903, 0, -18604, 0, -11902, 0, -18603, 0, -11901, 0, -18602, 0, -11899, 0, -18601, 0, -11898, 0, -18600, 0, -11897, 0, -18599, 0, -11895, 0, -18598, 0, -11894, 0, -18591, 0, -11893, 0, -18590, 0, -11892, 0, -18589, 0, -11891, 0, -18588, 0, -11890, 0, -18587, 0, -11889, 0, -18586, 0, -11888, 0, -18585, 0, -11887, 0, -18584, 0, -11886, 0, -18583, 0, -11885, 0, -18582, 0, -11884, 0, -18581, 0, -11883, 0, -18580, 0, -11882, 0, -18579, 0, -11881, 0, -18578, 0, -11880, 0, -18577, 0, -11879, 0, -18576, 0, -11878, 0, -18575, 0, -11877, 0, -18574, 0, -11876, 0, -18573, 0, -11875, 0, -18572, 0, -11874, 0, -18571, 0, -11873, 0, -18570, 0, -11870, 0, -18569, 0, -11869, 0, -18568, 0, -11867, 0, -18567, 0, -11866, 0, -18566, 0, -11865, 0, -18559, 0, -11863, 0, -18558, 0, -11862, 0, -18557, 0, -11861, 0, -18556, 0, -11860, 0, -18555, 0, -11859, 0, -18554, 0, -11858, 0, -18553, 0, -11857, 0, -18552, 0, -11854, 0, -18551, 0, -11852, 0, -18550, 0, -11850, 0, -18549, 0, -11849, 0, -18548, 0, -11848, 0, -18547, 0, -11847, 0, -18546, 0, -11845, 0, -18545, 0, -11843, 0, -18544, 0, -11842, 0, -18543, 0, -11841, 0, -18542, 0, -11839, 0, -18541, 0, -11838, 0, -18540, 0, -11837, 0, -18539, 0, -11836, 0, -18538, 0, -11835, 0, -18537, 0, -11834, 0, -18536, 0, -11833, 0, -18535, 0, -11832, 0, -18534, 0, -11831, 0, -18533, 0, -11830, 0, -18532, 0, -11829, 0, -18531, 0, -11828, 0, -18530, 0, -11827, 0, -18529, 0, -11826, 0, -18528, 0, -11825, 0, -18527, 0, -18536, 0, -18526, 0, -18535, 0, -18525, 0, -18532, 0, -18524, 0, -18528, 0, -18523, 0, -18520, 0, -18522, 0, -18519, 0, -18521, 0, -18517, 0, -18520, 0, -18516, 0, -18519, 0, -18515, 0, -18518, 0, -18508, 0, -18517, 0, -18507, 0, -18516, 0, -18504, 0, -18515, 0, -18489, 0, -18514, 0, -18487, 0, -18513, 0, -18452, 0, -18512, 0, -18451, 0, -18511, 0, -18448, 0, -18510, 0, -18444, 0, -18509, 0, -18436, 0, -18508, 0, -18435, 0, -18507, 0, -18433, 0, -18506, 0, -18432, 0, -18505, 0, -18431, 0, -18504, 0, -18425, 0, -18503, 0, -18424, 0, -18502, 0, -18423, 0, -18501, 0, -18420, 0, -18500, 0, -18416, 0, -18499, 0, -18408, 0, -18498, 0, -18407, 0, -18497, 0, -18405, 0, -18496, 0, -18403, 0, -18495, 0, -18396, 0, -18494, 0, -18395, 0, -18493, 0, -18392, 0, -18492, 0, -18388, 0, -18491, 0, -18380, 0, -18490, 0, -18379, 0, -18489, 0, -18377, 0, -18488, 0, -18376, 0, -18487, 0, -18375, 0, -18486, 0, -18368, 0, -18485, 0, -18364, 0, -18484, 0, -18351, 0, -18483, 0, -18349, 0, -18482, 0, -18340, 0, -18481, 0, -18339, 0, -18480, 0, -18336, 0, -18479, 0, -18332, 0, -18478, 0, -18324, 0, -18477, 0, -18323, 0, -18476, 0, -18321, 0, -18475, 0, -18319, 0, -18474, 0, -18312, 0, -18473, 0, -18308, 0, -18472, 0, -18291, 0, -18471, 0, -18264, 0, -18470, 0, -18256, 0, -18469, 0, -18252, 0, -18468, 0, -18248, 0, -18467, 0, -18240, 0, -18466, 0, -18239, 0, -18465, 0, -18237, 0, -18464, 0, -18235, 0, -18463, 0, -18228, 0, -18462, 0, -18224, 0, -18461, 0, -18220, 0, -18460, 0, -18211, 0, -18459, 0, -18209, 0, -18458, 0, -18207, 0, -18457, 0, -18200, 0, -18456, 0, -18199, 0, -18455, 0, -18196, 0, -18454, 0, -18192, 0, -18453, 0, -18184, 0, -18452, 0, -18183, 0, -18451, 0, -18181, 0, -18450, 0, -18179, 0, -18449, 0, -18172, 0, -18448, 0, -18152, 0, -18447, 0, -18144, 0, -18446, 0, -18116, 0, -18445, 0, -18115, 0, -18444, 0, -18112, 0, -18443, 0, -18108, 0, -18442, 0, -18100, 0, -18441, 0, -18097, 0, -18440, 0, -18095, 0, -18439, 0, -18088, 0, -18438, 0, -18087, 0, -18437, 0, -18084, 0, -18436, 0, -18080, 0, -18435, 0, -18072, 0, -18434, 0, -18071, 0, -18367, 0, -11824, 0, -18366, 0, -11823, 0, -18365, 0, -11822, 0, -18364, 0, -11821, 0, -18363, 0, -11820, 0, -18362, 0, -11819, 0, -18361, 0, -11818, 0, -18360, 0, -11817, 0, -18359, 0, -11815, 0, -18358, 0, -11814, 0, -18357, 0, -11813, 0, -18356, 0, -11812, 0, -18355, 0, -11811, 0, -18354, 0, -11810, 0, -18353, 0, -11809, 0, -18352, 0, -11808, 0, -18351, 0, -11807, 0, -18350, 0, -11806, 0, -18349, 0, -11805, 0, -18348, 0, -11804, 0, -18347, 0, -11803, 0, -18346, 0, -11802, 0, -18345, 0, -11801, 0, -18344, 0, -11800, 0, -18343, 0, -11799, 0, -18342, 0, -11798, 0, -18335, 0, -11797, 0, -18334, 0, -11796, 0, -18333, 0, -11795, 0, -18332, 0, -11794, 0, -18331, 0, -11793, 0, -18330, 0, -11792, 0, -18329, 0, -11791, 0, -18328, 0, -11790, 0, -18327, 0, -11789, 0, -18326, 0, -11787, 0, -18325, 0, -11786, 0, -18324, 0, -11785, 0, -18323, 0, -11783, 0, -18322, 0, -11782, 0, -18321, 0, -11781, 0, -18320, 0, -11780, 0, -18319, 0, -11779, 0, -18318, 0, -11778, 0, -18317, 0, -11777, 0, -18316, 0, -11776, 0, -18315, 0, -11775, 0, -18314, 0, -11774, 0, -18313, 0, -11773, 0, -18312, 0, -11772, 0, -18311, 0, -11771, 0, -18310, 0, -11770, 0, -18303, 0, -11768, 0, -18302, 0, -11766, 0, -18301, 0, -11765, 0, -18300, 0, -11764, 0, -18299, 0, -11763, 0, -18298, 0, -11762, 0, -18297, 0, -11761, 0, -18296, 0, -11759, 0, -18295, 0, -11758, 0, -18294, 0, -11757, 0, -18293, 0, -11756, 0, -18292, 0, -11755, 0, -18291, 0, -11754, 0, -18290, 0, -11753, 0, -18289, 0, -11752, 0, -18288, 0, -11751, 0, -18287, 0, -11750, 0, -18286, 0, -11749, 0, -18285, 0, -11748, 0, -18284, 0, -11747, 0, -18283, 0, -11746, 0, -18282, 0, -11745, 0, -18281, 0, -11744, 0, -18280, 0, -11743, 0, -18279, 0, -11742, 0, -18278, 0, -11741, 0, -18277, 0, -11740, 0, -18276, 0, -11739, 0, -18275, 0, -11738, 0, -18274, 0, -11737, 0, -18273, 0, -11736, 0, -18272, 0, -11735, 0, -18271, 0, -18069, 0, -18270, 0, -18067, 0, -18269, 0, -18060, 0, -18268, 0, -18059, 0, -18267, 0, -18056, 0, -18266, 0, -18052, 0, -18265, 0, -18044, 0, -18264, 0, -18043, 0, -18263, 0, -18041, 0, -18262, 0, -18039, 0, -18261, 0, -18038, 0, -18260, 0, -18035, 0, -18259, 0, -18034, 0, -18258, 0, -18004, 0, -18257, 0, -18003, 0, -18256, 0, -18000, 0, -18255, 0, -17996, 0, -18254, 0, -17988, 0, -18253, 0, -17987, 0, -18252, 0, -17985, 0, -18251, 0, -17983, 0, -18250, 0, -17976, 0, -18249, 0, -17975, 0, -18248, 0, -17972, 0, -18247, 0, -17970, 0, -18246, 0, -17969, 0, -18245, 0, -17968, 0, -18244, 0, -17967, 0, -18243, 0, -17966, 0, -18242, 0, -17960, 0, -18241, 0, -17959, 0, -18240, 0, -17957, 0, -18239, 0, -17955, 0, -18238, 0, -17954, 0, -18237, 0, -17951, 0, -18236, 0, -17949, 0, -18235, 0, -17948, 0, -18234, 0, -17947, 0, -18233, 0, -17944, 0, -18232, 0, -17940, 0, -18231, 0, -17932, 0, -18230, 0, -17931, 0, -18229, 0, -17929, 0, -18228, 0, -17928, 0, -18227, 0, -17927, 0, -18226, 0, -17926, 0, -18225, 0, -17920, 0, -18224, 0, -17919, 0, -18223, 0, -17912, 0, -18222, 0, -17899, 0, -18221, 0, -17864, 0, -18220, 0, -17863, 0, -18219, 0, -17860, 0, -18218, 0, -17856, 0, -18217, 0, -17854, 0, -18216, 0, -17848, 0, -18215, 0, -17847, 0, -18214, 0, -17845, 0, -18213, 0, -17843, 0, -18212, 0, -17842, 0, -18211, 0, -17837, 0, -18210, 0, -17836, 0, -18209, 0, -17835, 0, -18208, 0, -17832, 0, -18207, 0, -17828, 0, -18206, 0, -17820, 0, -18205, 0, -17819, 0, -18204, 0, -17817, 0, -18203, 0, -17816, 0, -18202, 0, -17815, 0, -18201, 0, -17808, 0, -18200, 0, -17807, 0, -18199, 0, -17804, 0, -18198, 0, -17800, 0, -18197, 0, -17789, 0, -18196, 0, -17788, 0, -18195, 0, -17787, 0, -18194, 0, -17785, 0, -18193, 0, -17780, 0, -18192, 0, -17752, 0, -18191, 0, -17751, 0, -18190, 0, -17749, 0, -18189, 0, -17748, 0, -18188, 0, -17744, 0, -18187, 0, -17742, 0, -18186, 0, -17736, 0, -18185, 0, -17735, 0, -18184, 0, -17733, 0, -18183, 0, -17731, 0, -18182, 0, -17724, 0, -18181, 0, -17720, 0, -18180, 0, -17704, 0, -18179, 0, -17703, 0, -18178, 0, -17668, 0, -18111, 0, -11734, 0, -18110, 0, -11733, 0, -18109, 0, -11730, 0, -18108, 0, -11729, 0, -18107, 0, -11727, 0, -18106, 0, -11726, 0, -18105, 0, -11725, 0, -18104, 0, -11723, 0, -18103, 0, -11722, 0, -18102, 0, -11721, 0, -18101, 0, -11720, 0, -18100, 0, -11719, 0, -18099, 0, -11718, 0, -18098, 0, -11717, 0, -18097, 0, -11714, 0, -18096, 0, -11712, 0, -18095, 0, -11710, 0, -18094, 0, -11709, 0, -18093, 0, -11708, 0, -18092, 0, -11707, 0, -18091, 0, -11706, 0, -18090, 0, -11705, 0, -18089, 0, -11703, 0, -18088, 0, -11702, 0, -18087, 0, -11701, 0, -18086, 0, -11700, 0, -18079, 0, -11699, 0, -18078, 0, -11698, 0, -18077, 0, -11697, 0, -18076, 0, -11696, 0, -18075, 0, -11695, 0, -18074, 0, -11694, 0, -18073, 0, -11693, 0, -18072, 0, -11692, 0, -18071, 0, -11691, 0, -18070, 0, -11690, 0, -18069, 0, -11689, 0, -18068, 0, -11688, 0, -18067, 0, -11687, 0, -18066, 0, -11686, 0, -18065, 0, -11685, 0, -18064, 0, -11683, 0, -18063, 0, -11682, 0, -18062, 0, -11681, 0, -18061, 0, -11680, 0, -18060, 0, -11679, 0, -18059, 0, -11678, 0, -18058, 0, -11677, 0, -18057, 0, -11675, 0, -18056, 0, -11674, 0, -18055, 0, -11673, 0, -18054, 0, -11672, 0, -18047, 0, -11671, 0, -18046, 0, -11670, 0, -18045, 0, -11669, 0, -18044, 0, -11668, 0, -18043, 0, -11667, 0, -18042, 0, -11666, 0, -18041, 0, -11665, 0, -18040, 0, -11664, 0, -18039, 0, -11663, 0, -18038, 0, -11662, 0, -18037, 0, -11661, 0, -18036, 0, -11660, 0, -18035, 0, -11659, 0, -18034, 0, -11658, 0, -18033, 0, -11657, 0, -18032, 0, -11656, 0, -18031, 0, -11655, 0, -18030, 0, -11654, 0, -18029, 0, -11653, 0, -18028, 0, -11652, 0, -18027, 0, -11651, 0, -18026, 0, -11650, 0, -18025, 0, -11649, 0, -18024, 0, -11646, 0, -18023, 0, -11645, 0, -18022, 0, -11643, 0, -18021, 0, -11642, 0, -18020, 0, -11641, 0, -18019, 0, -11639, 0, -18018, 0, -11638, 0, -18017, 0, -11637, 0, -18016, 0, -11636, 0, -18015, 0, -17664, 0, -18014, 0, -17660, 0, -18013, 0, -17651, 0, -18012, 0, -17649, 0, -18011, 0, -17647, 0, -18010, 0, -17640, 0, -18009, 0, -17636, 0, -18008, 0, -17632, 0, -18007, 0, -17623, 0, -18006, 0, -17621, 0, -18005, 0, -17612, 0, -18004, 0, -17611, 0, -18003, 0, -17610, 0, -18002, 0, -17608, 0, -18001, 0, -17605, 0, -18000, 0, -17604, 0, -17999, 0, -17603, 0, -17998, 0, -17602, 0, -17997, 0, -17596, 0, -17996, 0, -17595, 0, -17995, 0, -17593, 0, -17994, 0, -17591, 0, -17993, 0, -17587, 0, -17992, 0, -17585, 0, -17991, 0, -17584, 0, -17990, 0, -17580, 0, -17989, 0, -17576, 0, -17988, 0, -17567, 0, -17987, 0, -17565, 0, -17986, 0, -17556, 0, -17985, 0, -17528, 0, -17984, 0, -17524, 0, -17983, 0, -17520, 0, -17982, 0, -17500, 0, -17981, 0, -17496, 0, -17980, 0, -17492, 0, -17979, 0, -17484, 0, -17978, 0, -17481, 0, -17977, 0, -17472, 0, -17976, 0, -17468, 0, -17975, 0, -17464, 0, -17974, 0, -17456, 0, -17973, 0, -17453, 0, -17972, 0, -17416, 0, -17971, 0, -17415, 0, -17970, 0, -17412, 0, -17969, 0, -17409, 0, -17968, 0, -17408, 0, -17967, 0, -17406, 0, -17966, 0, -17400, 0, -17965, 0, -17399, 0, -17964, 0, -17397, 0, -17963, 0, -17396, 0, -17962, 0, -17395, 0, -17961, 0, -17393, 0, -17960, 0, -17391, 0, -17959, 0, -17388, 0, -17958, 0, -17387, 0, -17957, 0, -17386, 0, -17956, 0, -17385, 0, -17955, 0, -17384, 0, -17954, 0, -17381, 0, -17953, 0, -17380, 0, -17952, 0, -17379, 0, -17951, 0, -17378, 0, -17950, 0, -17377, 0, -17949, 0, -17372, 0, -17948, 0, -17371, 0, -17947, 0, -17369, 0, -17946, 0, -17367, 0, -17945, 0, -17363, 0, -17944, 0, -17360, 0, -17943, 0, -17359, 0, -17942, 0, -17356, 0, -17941, 0, -17352, 0, -17940, 0, -17344, 0, -17939, 0, -17343, 0, -17938, 0, -17341, 0, -17937, 0, -17340, 0, -17936, 0, -17339, 0, -17935, 0, -17335, 0, -17934, 0, -17332, 0, -17933, 0, -17331, 0, -17932, 0, -17328, 0, -17931, 0, -17315, 0, -17930, 0, -17276, 0, -17929, 0, -17275, 0, -17928, 0, -17272, 0, -17927, 0, -17269, 0, -17926, 0, -17268, 0, -17925, 0, -17266, 0, -17924, 0, -17260, 0, -17923, 0, -17259, 0, -17922, 0, -17257, 0, -17855, 0, -11635, 0, -17854, 0, -11634, 0, -17853, 0, -11633, 0, -17852, 0, -11630, 0, -17851, 0, -11629, 0, -17850, 0, -11628, 0, -17849, 0, -11626, 0, -17848, 0, -11625, 0, -17847, 0, -11624, 0, -17846, 0, -11623, 0, -17845, 0, -11622, 0, -17844, 0, -11621, 0, -17843, 0, -11619, 0, -17842, 0, -11618, 0, -17841, 0, -11617, 0, -17840, 0, -11615, 0, -17839, 0, -11614, 0, -17838, 0, -11613, 0, -17837, 0, -11611, 0, -17836, 0, -11610, 0, -17835, 0, -11609, 0, -17834, 0, -11608, 0, -17833, 0, -11607, 0, -17832, 0, -11606, 0, -17831, 0, -11605, 0, -17830, 0, -11603, 0, -17823, 0, -11602, 0, -17822, 0, -11601, 0, -17821, 0, -11600, 0, -17820, 0, -11598, 0, -17819, 0, -11597, 0, -17818, 0, -11596, 0, -17817, 0, -11595, 0, -17816, 0, -11594, 0, -17815, 0, -11593, 0, -17814, 0, -11590, 0, -17813, 0, -11589, 0, -17812, 0, -11587, 0, -17811, 0, -11586, 0, -17810, 0, -11583, 0, -17809, 0, -11581, 0, -17808, 0, -11580, 0, -17807, 0, -11579, 0, -17806, 0, -11578, 0, -17805, 0, -11577, 0, -17804, 0, -11574, 0, -17803, 0, -11572, 0, -17802, 0, -11571, 0, -17801, 0, -11570, 0, -17800, 0, -11569, 0, -17799, 0, -11568, 0, -17798, 0, -11567, 0, -17791, 0, -11566, 0, -17790, 0, -11565, 0, -17789, 0, -11563, 0, -17788, 0, -11562, 0, -17787, 0, -11561, 0, -17786, 0, -11559, 0, -17785, 0, -11558, 0, -17784, 0, -11557, 0, -17783, 0, -11555, 0, -17782, 0, -11554, 0, -17781, 0, -11553, 0, -17780, 0, -11552, 0, -17779, 0, -11551, 0, -17778, 0, -11550, 0, -17777, 0, -11549, 0, -17776, 0, -11546, 0, -17775, 0, -11545, 0, -17774, 0, -11544, 0, -17773, 0, -11543, 0, -17772, 0, -11542, 0, -17771, 0, -11541, 0, -17770, 0, -11540, 0, -17769, 0, -11539, 0, -17768, 0, -11538, 0, -17767, 0, -11537, 0, -17766, 0, -11534, 0, -17765, 0, -11533, 0, -17764, 0, -11531, 0, -17763, 0, -11530, 0, -17762, 0, -11529, 0, -17761, 0, -11527, 0, -17760, 0, -11526, 0, -17759, 0, -17255, 0, -17758, 0, -17254, 0, -17757, 0, -17248, 0, -17756, 0, -17247, 0, -17755, 0, -17244, 0, -17754, 0, -17241, 0, -17753, 0, -17240, 0, -17752, 0, -17232, 0, -17751, 0, -17231, 0, -17750, 0, -17229, 0, -17749, 0, -17228, 0, -17748, 0, -17227, 0, -17747, 0, -17220, 0, -17746, 0, -17219, 0, -17745, 0, -17216, 0, -17744, 0, -17212, 0, -17743, 0, -17203, 0, -17742, 0, -17201, 0, -17741, 0, -17200, 0, -17740, 0, -17199, 0, -17739, 0, -17195, 0, -17738, 0, -17192, 0, -17737, 0, -17188, 0, -17736, 0, -17164, 0, -17735, 0, -17163, 0, -17734, 0, -17162, 0, -17733, 0, -17160, 0, -17732, 0, -17156, 0, -17731, 0, -17148, 0, -17730, 0, -17147, 0, -17729, 0, -17145, 0, -17728, 0, -17143, 0, -17727, 0, -17136, 0, -17726, 0, -17132, 0, -17725, 0, -17116, 0, -17724, 0, -17108, 0, -17723, 0, -17088, 0, -17722, 0, -17080, 0, -17721, 0, -17079, 0, -17720, 0, -17076, 0, -17719, 0, -17072, 0, -17718, 0, -17064, 0, -17717, 0, -17063, 0, -17716, 0, -17052, 0, -17715, 0, -17048, 0, -17714, 0, -17024, 0, -17713, 0, -17023, 0, -17712, 0, -17020, 0, -17711, 0, -17017, 0, -17710, 0, -17016, 0, -17709, 0, -17015, 0, -17708, 0, -17014, 0, -17707, 0, -17008, 0, -17706, 0, -17007, 0, -17705, 0, -17005, 0, -17704, 0, -17003, 0, -17703, 0, -16999, 0, -17702, 0, -16998, 0, -17701, 0, -16996, 0, -17700, 0, -16988, 0, -17699, 0, -16976, 0, -17698, 0, -16968, 0, -17697, 0, -16940, 0, -17696, 0, -16939, 0, -17695, 0, -16936, 0, -17694, 0, -16932, 0, -17693, 0, -16919, 0, -17692, 0, -16912, 0, -17691, 0, -16908, 0, -17690, 0, -16904, 0, -17689, 0, -16896, 0, -17688, 0, -16893, 0, -17687, 0, -16891, 0, -17686, 0, -16884, 0, -17685, 0, -16883, 0, -17684, 0, -16880, 0, -17683, 0, -16876, 0, -17682, 0, -16868, 0, -17681, 0, -16867, 0, -17680, 0, -16865, 0, -17679, 0, -16828, 0, -17678, 0, -16827, 0, -17677, 0, -16824, 0, -17676, 0, -16820, 0, -17675, 0, -16818, 0, -17674, 0, -16812, 0, -17673, 0, -16811, 0, -17672, 0, -16809, 0, -17671, 0, -16807, 0, -17670, 0, -16806, 0, -17669, 0, -16805, 0, -17668, 0, -16800, 0, -17667, 0, -16799, 0, -17666, 0, -16796, 0, -17599, 0, -11525, 0, -17598, 0, -11524, 0, -17597, 0, -11523, 0, -17596, 0, -11522, 0, -17595, 0, -11521, 0, -17594, 0, -11518, 0, -17593, 0, -11516, 0, -17592, 0, -11514, 0, -17591, 0, -11513, 0, -17590, 0, -11512, 0, -17589, 0, -11511, 0, -17588, 0, -11510, 0, -17587, 0, -11509, 0, -17586, 0, -11505, 0, -17585, 0, -11503, 0, -17584, 0, -11502, 0, -17583, 0, -11501, 0, -17582, 0, -11499, 0, -17581, 0, -11497, 0, -17580, 0, -11496, 0, -17579, 0, -11495, 0, -17578, 0, -11494, 0, -17577, 0, -11493, 0, -17576, 0, -11490, 0, -17575, 0, -11486, 0, -17574, 0, -11485, 0, -17567, 0, -11484, 0, -17566, 0, -11482, 0, -17565, 0, -11481, 0, -17564, 0, -11478, 0, -17563, 0, -11477, 0, -17562, 0, -11475, 0, -17561, 0, -11474, 0, -17560, 0, -11473, 0, -17559, 0, -11471, 0, -17558, 0, -11470, 0, -17557, 0, -11469, 0, -17556, 0, -11468, 0, -17555, 0, -11467, 0, -17554, 0, -11466, 0, -17553, 0, -11465, 0, -17552, 0, -11462, 0, -17551, 0, -11458, 0, -17550, 0, -11457, 0, -17549, 0, -11456, 0, -17548, 0, -11455, 0, -17547, 0, -11454, 0, -17546, 0, -11453, 0, -17545, 0, -11450, 0, -17544, 0, -11449, 0, -17543, 0, -11448, 0, -17542, 0, -11447, 0, -17535, 0, -11446, 0, -17534, 0, -11445, 0, -17533, 0, -11444, 0, -17532, 0, -11443, 0, -17531, 0, -11442, 0, -17530, 0, -11441, 0, -17529, 0, -11440, 0, -17528, 0, -11439, 0, -17527, 0, -11438, 0, -17526, 0, -11437, 0, -17525, 0, -11436, 0, -17524, 0, -11435, 0, -17523, 0, -11434, 0, -17522, 0, -11433, 0, -17521, 0, -11432, 0, -17520, 0, -11431, 0, -17519, 0, -11430, 0, -17518, 0, -11429, 0, -17517, 0, -11428, 0, -17516, 0, -11427, 0, -17515, 0, -11426, 0, -17514, 0, -11425, 0, -17513, 0, -11424, 0, -17512, 0, -11423, 0, -17511, 0, -11422, 0, -17510, 0, -11421, 0, -17509, 0, -11420, 0, -17508, 0, -11419, 0, -17507, 0, -11418, 0, -17506, 0, -11417, 0, -17505, 0, -11416, 0, -17504, 0, -11415, 0, -17503, 0, -16792, 0, -17502, 0, -16790, 0, -17501, 0, -16784, 0, -17500, 0, -16783, 0, -17499, 0, -16781, 0, -17498, 0, -16780, 0, -17497, 0, -16779, 0, -17496, 0, -16773, 0, -17495, 0, -16772, 0, -17494, 0, -16771, 0, -17493, 0, -16768, 0, -17492, 0, -16764, 0, -17491, 0, -16756, 0, -17490, 0, -16755, 0, -17489, 0, -16753, 0, -17488, 0, -16752, 0, -17487, 0, -16751, 0, -17486, 0, -16744, 0, -17485, 0, -16743, 0, -17484, 0, -16728, 0, -17483, 0, -16688, 0, -17482, 0, -16687, 0, -17481, 0, -16684, 0, -17480, 0, -16681, 0, -17479, 0, -16680, 0, -17478, 0, -16672, 0, -17477, 0, -16669, 0, -17476, 0, -16668, 0, -17475, 0, -16667, 0, -17474, 0, -16660, 0, -17473, 0, -16639, 0, -17472, 0, -16632, 0, -17471, 0, -16631, 0, -17470, 0, -16616, 0, -17469, 0, -16615, 0, -17468, 0, -16613, 0, -17467, 0, -16612, 0, -17466, 0, -16611, 0, -17465, 0, -16576, 0, -17464, 0, -16575, 0, -17463, 0, -16572, 0, -17462, 0, -16568, 0, -17461, 0, -16560, 0, -17460, 0, -16559, 0, -17459, 0, -16555, 0, -17458, 0, -16492, 0, -17457, 0, -16464, 0, -17456, 0, -16443, 0, -17455, 0, -16436, 0, -17454, 0, -16435, 0, -17453, 0, -16432, 0, -17452, 0, -16428, 0, -17451, 0, -16420, 0, -17450, 0, -16417, 0, -17449, 0, -16415, 0, -17448, 0, -16324, 0, -17447, 0, -16303, 0, -17446, 0, -16296, 0, -17445, 0, -16292, 0, -17444, 0, -16288, 0, -17443, 0, -16280, 0, -17442, 0, -16279, 0, -17441, 0, -16240, 0, -17440, 0, -16239, 0, -17439, 0, -16236, 0, -17438, 0, -16232, 0, -17437, 0, -16224, 0, -17436, 0, -16223, 0, -17435, 0, -16221, 0, -17434, 0, -16219, 0, -17433, 0, -16212, 0, -17432, 0, -16211, 0, -17431, 0, -16209, 0, -17430, 0, -16208, 0, -17429, 0, -16205, 0, -17428, 0, -16204, 0, -17427, 0, -16203, 0, -17426, 0, -16202, 0, -17425, 0, -16196, 0, -17424, 0, -16195, 0, -17423, 0, -16193, 0, -17422, 0, -16192, 0, -17421, 0, -16191, 0, -17420, 0, -16187, 0, -17419, 0, -16184, 0, -17418, 0, -16183, 0, -17417, 0, -16180, 0, -17416, 0, -16176, 0, -17415, 0, -16168, 0, -17414, 0, -16167, 0, -17413, 0, -16165, 0, -17412, 0, -16164, 0, -17411, 0, -16163, 0, -17410, 0, -16156, 0, -17343, 0, -11414, 0, -17342, 0, -11413, 0, -17341, 0, -11412, 0, -17340, 0, -11411, 0, -17339, 0, -11410, 0, -17338, 0, -11409, 0, -17337, 0, -11408, 0, -17336, 0, -11407, 0, -17335, 0, -11406, 0, -17334, 0, -11405, 0, -17333, 0, -11404, 0, -17332, 0, -11403, 0, -17331, 0, -11402, 0, -17330, 0, -11401, 0, -17329, 0, -11400, 0, -17328, 0, -11399, 0, -17327, 0, -11398, 0, -17326, 0, -11397, 0, -17325, 0, -11394, 0, -17324, 0, -11393, 0, -17323, 0, -11391, 0, -17322, 0, -11390, 0, -17321, 0, -11389, 0, -17320, 0, -11387, 0, -17319, 0, -11386, 0, -17318, 0, -11385, 0, -17311, 0, -11384, 0, -17310, 0, -11383, 0, -17309, 0, -11382, 0, -17308, 0, -11381, 0, -17307, 0, -11378, 0, -17306, 0, -11374, 0, -17305, 0, -11373, 0, -17304, 0, -11372, 0, -17303, 0, -11371, 0, -17302, 0, -11370, 0, -17301, 0, -11369, 0, -17300, 0, -11366, 0, -17299, 0, -11365, 0, -17298, 0, -11363, 0, -17297, 0, -11362, 0, -17296, 0, -11361, 0, -17295, 0, -11359, 0, -17294, 0, -11358, 0, -17293, 0, -11357, 0, -17292, 0, -11356, 0, -17291, 0, -11355, 0, -17290, 0, -11354, 0, -17289, 0, -11353, 0, -17288, 0, -11350, 0, -17287, 0, -11348, 0, -17286, 0, -11346, 0, -17279, 0, -11345, 0, -17278, 0, -11344, 0, -17277, 0, -11343, 0, -17276, 0, -11342, 0, -17275, 0, -11341, 0, -17274, 0, -11339, 0, -17273, 0, -11338, 0, -17272, 0, -11337, 0, -17271, 0, -11335, 0, -17270, 0, -11334, 0, -17269, 0, -11333, 0, -17268, 0, -11331, 0, -17267, 0, -11330, 0, -17266, 0, -11329, 0, -17265, 0, -11328, 0, -17264, 0, -11327, 0, -17263, 0, -11326, 0, -17262, 0, -11325, 0, -17261, 0, -11322, 0, -17260, 0, -11321, 0, -17259, 0, -11318, 0, -17258, 0, -11317, 0, -17257, 0, -11316, 0, -17256, 0, -11315, 0, -17255, 0, -11314, 0, -17254, 0, -11313, 0, -17253, 0, -11311, 0, -17252, 0, -11310, 0, -17251, 0, -11309, 0, -17250, 0, -11308, 0, -17249, 0, -11307, 0, -17248, 0, -11306, 0, -17247, 0, -16155, 0, -17246, 0, -16152, 0, -17245, 0, -16148, 0, -17244, 0, -16140, 0, -17243, 0, -16139, 0, -17242, 0, -16137, 0, -17241, 0, -16135, 0, -17240, 0, -16128, 0, -17239, 0, -16124, 0, -17238, 0, -16120, 0, -17237, 0, -16112, 0, -17236, 0, -16107, 0, -17235, 0, -16100, 0, -17234, 0, -16099, 0, -17233, 0, -16098, 0, -17232, 0, -16097, 0, -17231, 0, -16096, 0, -17230, 0, -16093, 0, -17229, 0, -16092, 0, -17228, 0, -16090, 0, -17227, 0, -16089, 0, -17226, 0, -16084, 0, -17225, 0, -16083, 0, -17224, 0, -16081, 0, -17223, 0, -16080, 0, -17222, 0, -16079, 0, -17221, 0, -16074, 0, -17220, 0, -16072, 0, -17219, 0, -16071, 0, -17218, 0, -16068, 0, -17217, 0, -16064, 0, -17216, 0, -16056, 0, -17215, 0, -16055, 0, -17214, 0, -16053, 0, -17213, 0, -16052, 0, -17212, 0, -16051, 0, -17211, 0, -16044, 0, -17210, 0, -16043, 0, -17209, 0, -16040, 0, -17208, 0, -16036, 0, -17207, 0, -16028, 0, -17206, 0, -16027, 0, -17205, 0, -16025, 0, -17204, 0, -16024, 0, -17203, 0, -16023, 0, -17202, 0, -16016, 0, -17201, 0, -16012, 0, -17200, 0, -16008, 0, -17199, 0, -15995, 0, -17198, 0, -15988, 0, -17197, 0, -15987, 0, -17196, 0, -15986, 0, -17195, 0, -15984, 0, -17194, 0, -15980, 0, -17193, 0, -15978, 0, -17192, 0, -15972, 0, -17191, 0, -15971, 0, -17190, 0, -15969, 0, -17189, 0, -15967, 0, -17188, 0, -15963, 0, -17187, 0, -15960, 0, -17186, 0, -15959, 0, -17185, 0, -15956, 0, -17184, 0, -15952, 0, -17183, 0, -15939, 0, -17182, 0, -15932, 0, -17181, 0, -15928, 0, -17180, 0, -15924, 0, -17179, 0, -15916, 0, -17178, 0, -15913, 0, -17177, 0, -15912, 0, -17176, 0, -15904, 0, -17175, 0, -15900, 0, -17174, 0, -15896, 0, -17173, 0, -15888, 0, -17172, 0, -15887, 0, -17171, 0, -15885, 0, -17170, 0, -15876, 0, -17169, 0, -15875, 0, -17168, 0, -15872, 0, -17167, 0, -15868, 0, -17166, 0, -15860, 0, -17165, 0, -15859, 0, -17164, 0, -15857, 0, -17163, 0, -15855, 0, -17162, 0, -15848, 0, -17161, 0, -15847, 0, -17160, 0, -15844, 0, -17159, 0, -15841, 0, -17158, 0, -15840, 0, -17157, 0, -15832, 0, -17156, 0, -15831, 0, -17155, 0, -15829, 0, -17154, 0, -15827, 0, -17087, 0, -11305, 0, -17086, 0, -11303, 0, -17085, 0, -11302, 0, -17084, 0, -11301, 0, -17083, 0, -11300, 0, -17082, 0, -11299, 0, -17081, 0, -11298, 0, -17080, 0, -11297, 0, -17079, 0, -11296, 0, -17078, 0, -11294, 0, -17077, 0, -11292, 0, -17076, 0, -11291, 0, -17075, 0, -11290, 0, -17074, 0, -11289, 0, -17073, 0, -11288, 0, -17072, 0, -11287, 0, -17071, 0, -11286, 0, -17070, 0, -11285, 0, -17069, 0, -11282, 0, -17068, 0, -11281, 0, -17067, 0, -11279, 0, -17066, 0, -11278, 0, -17065, 0, -11277, 0, -17064, 0, -11275, 0, -17063, 0, -11274, 0, -17062, 0, -11273, 0, -17055, 0, -11272, 0, -17054, 0, -11271, 0, -17053, 0, -11270, 0, -17052, 0, -11269, 0, -17051, 0, -11266, 0, -17050, 0, -11264, 0, -17049, 0, -11262, 0, -17048, 0, -11261, 0, -17047, 0, -11260, 0, -17046, 0, -11259, 0, -17045, 0, -11258, 0, -17044, 0, -11257, 0, -17043, 0, -11255, 0, -17042, 0, -11254, 0, -17041, 0, -11253, 0, -17040, 0, -11252, 0, -17039, 0, -11251, 0, -17038, 0, -11250, 0, -17037, 0, -11249, 0, -17036, 0, -11248, 0, -17035, 0, -11247, 0, -17034, 0, -11246, 0, -17033, 0, -11245, 0, -17032, 0, -11244, 0, -17031, 0, -11243, 0, -17030, 0, -11242, 0, -17023, 0, -11241, 0, -17022, 0, -11240, 0, -17021, 0, -11239, 0, -17020, 0, -11238, 0, -17019, 0, -11237, 0, -17018, 0, -11236, 0, -17017, 0, -11234, 0, -17016, 0, -11233, 0, -17015, 0, -11232, 0, -17014, 0, -11231, 0, -17013, 0, -11230, 0, -17012, 0, -11229, 0, -17011, 0, -11228, 0, -17010, 0, -11227, 0, -17009, 0, -11226, 0, -17008, 0, -11225, 0, -17007, 0, -11224, 0, -17006, 0, -11223, 0, -17005, 0, -11222, 0, -17004, 0, -11221, 0, -17003, 0, -11220, 0, -17002, 0, -11219, 0, -17001, 0, -11218, 0, -17000, 0, -11217, 0, -16999, 0, -11216, 0, -16998, 0, -11215, 0, -16997, 0, -11214, 0, -16996, 0, -11213, 0, -16995, 0, -11212, 0, -16994, 0, -11211, 0, -16993, 0, -11210, 0, -16992, 0, -11209, 0, -16991, 0, -15825, 0, -16990, 0, -15823, 0, -16989, 0, -15822, 0, -16988, 0, -15820, 0, -16987, 0, -15800, 0, -16986, 0, -15792, 0, -16985, 0, -15791, 0, -16984, 0, -15788, 0, -16983, 0, -15784, 0, -16982, 0, -15776, 0, -16981, 0, -15771, 0, -16980, 0, -15764, 0, -16979, 0, -15763, 0, -16978, 0, -15760, 0, -16977, 0, -15756, 0, -16976, 0, -15748, 0, -16975, 0, -15747, 0, -16974, 0, -15745, 0, -16973, 0, -15743, 0, -16972, 0, -15736, 0, -16971, 0, -15735, 0, -16970, 0, -15728, 0, -16969, 0, -15720, 0, -16968, 0, -15717, 0, -16967, 0, -15715, 0, -16966, 0, -15708, 0, -16965, 0, -15707, 0, -16964, 0, -15704, 0, -16963, 0, -15700, 0, -16962, 0, -15699, 0, -16961, 0, -15692, 0, -16960, 0, -15691, 0, -16959, 0, -15689, 0, -16958, 0, -15687, 0, -16957, 0, -15652, 0, -16956, 0, -15651, 0, -16955, 0, -15648, 0, -16954, 0, -15645, 0, -16953, 0, -15644, 0, -16952, 0, -15637, 0, -16951, 0, -15636, 0, -16950, 0, -15635, 0, -16949, 0, -15633, 0, -16948, 0, -15631, 0, -16947, 0, -15626, 0, -16946, 0, -15624, 0, -16945, 0, -15623, 0, -16944, 0, -15621, 0, -16943, 0, -15620, 0, -16942, 0, -15616, 0, -16941, 0, -15608, 0, -16940, 0, -15607, 0, -16939, 0, -15604, 0, -16938, 0, -15603, 0, -16937, 0, -15597, 0, -16936, 0, -15596, 0, -16935, 0, -15595, 0, -16934, 0, -15592, 0, -16933, 0, -15588, 0, -16932, 0, -15580, 0, -16931, 0, -15579, 0, -16930, 0, -15576, 0, -16929, 0, -15575, 0, -16928, 0, -15547, 0, -16927, 0, -15512, 0, -16926, 0, -15511, 0, -16925, 0, -15508, 0, -16924, 0, -15504, 0, -16923, 0, -15502, 0, -16922, 0, -15496, 0, -16921, 0, -15495, 0, -16920, 0, -15492, 0, -16919, 0, -15491, 0, -16918, 0, -15484, 0, -16917, 0, -15480, 0, -16916, 0, -15476, 0, -16915, 0, -15424, 0, -16914, 0, -15400, 0, -16913, 0, -15399, 0, -16912, 0, -15396, 0, -16911, 0, -15393, 0, -16910, 0, -15392, 0, -16909, 0, -15390, 0, -16908, 0, -15384, 0, -16907, 0, -15383, 0, -16906, 0, -15379, 0, -16905, 0, -15372, 0, -16904, 0, -15371, 0, -16903, 0, -15368, 0, -16902, 0, -15352, 0, -16901, 0, -15344, 0, -16900, 0, -15324, 0, -16899, 0, -15316, 0, -16898, 0, -15312, 0, -16831, 0, -11208, 0, -16830, 0, -11207, 0, -16829, 0, -11206, 0, -16828, 0, -11205, 0, -16827, 0, -11204, 0, -16826, 0, -11203, 0, -16825, 0, -11202, 0, -16824, 0, -11201, 0, -16823, 0, -11199, 0, -16822, 0, -11198, 0, -16821, 0, -11197, 0, -16820, 0, -11195, 0, -16819, 0, -11194, 0, -16818, 0, -11193, 0, -16817, 0, -11192, 0, -16816, 0, -11191, 0, -16815, 0, -11190, 0, -16814, 0, -11189, 0, -16813, 0, -11188, 0, -16812, 0, -11187, 0, -16811, 0, -11186, 0, -16810, 0, -11185, 0, -16809, 0, -11184, 0, -16808, 0, -11183, 0, -16807, 0, -11182, 0, -16806, 0, -11181, 0, -16799, 0, -11180, 0, -16798, 0, -11179, 0, -16797, 0, -11178, 0, -16796, 0, -11177, 0, -16795, 0, -11176, 0, -16794, 0, -11175, 0, -16793, 0, -11174, 0, -16792, 0, -11173, 0, -16791, 0, -11171, 0, -16790, 0, -11170, 0, -16789, 0, -11169, 0, -16788, 0, -11167, 0, -16787, 0, -11166, 0, -16786, 0, -11165, 0, -16785, 0, -11163, 0, -16784, 0, -11162, 0, -16783, 0, -11161, 0, -16782, 0, -11160, 0, -16781, 0, -11159, 0, -16780, 0, -11158, 0, -16779, 0, -11157, 0, -16778, 0, -11156, 0, -16777, 0, -11154, 0, -16776, 0, -11152, 0, -16775, 0, -11151, 0, -16774, 0, -11150, 0, -16767, 0, -11149, 0, -16766, 0, -11148, 0, -16765, 0, -11147, 0, -16764, 0, -11146, 0, -16763, 0, -11145, 0, -16762, 0, -11142, 0, -16761, 0, -11141, 0, -16760, 0, -11139, 0, -16759, 0, -11138, 0, -16758, 0, -11135, 0, -16757, 0, -11133, 0, -16756, 0, -11132, 0, -16755, 0, -11131, 0, -16754, 0, -11130, 0, -16753, 0, -11129, 0, -16752, 0, -11126, 0, -16751, 0, -11124, 0, -16750, 0, -11122, 0, -16749, 0, -11121, 0, -16748, 0, -11120, 0, -16747, 0, -11119, 0, -16746, 0, -11118, 0, -16745, 0, -11117, 0, -16744, 0, -11115, 0, -16743, 0, -11114, 0, -16742, 0, -11113, 0, -16741, 0, -11112, 0, -16740, 0, -11111, 0, -16739, 0, -11110, 0, -16738, 0, -11109, 0, -16737, 0, -11108, 0, -16736, 0, -11107, 0, -16735, 0, -15308, 0, -16734, 0, -15300, 0, -16733, 0, -15299, 0, -16732, 0, -15288, 0, -16731, 0, -15260, 0, -16730, 0, -15259, 0, -16729, 0, -15256, 0, -16728, 0, -15252, 0, -16727, 0, -15244, 0, -16726, 0, -15243, 0, -16725, 0, -15239, 0, -16724, 0, -15232, 0, -16723, 0, -15212, 0, -16722, 0, -15204, 0, -16721, 0, -15176, 0, -16720, 0, -15172, 0, -16719, 0, -15127, 0, -16718, 0, -15120, 0, -16717, 0, -15119, 0, -16716, 0, -15116, 0, -16715, 0, -15112, 0, -16714, 0, -15110, 0, -16713, 0, -15105, 0, -16712, 0, -15104, 0, -16711, 0, -15103, 0, -16710, 0, -15092, 0, -16709, 0, -15088, 0, -16708, 0, -15084, 0, -16707, 0, -15076, 0, -16706, 0, -15064, 0, -16705, 0, -15063, 0, -16704, 0, -15060, 0, -16703, 0, -15056, 0, -16702, 0, -15048, 0, -16701, 0, -15047, 0, -16700, 0, -15045, 0, -16699, 0, -15043, 0, -16698, 0, -15036, 0, -16697, 0, -15035, 0, -16696, 0, -15032, 0, -16695, 0, -15031, 0, -16694, 0, -15030, 0, -16693, 0, -15028, 0, -16692, 0, -15027, 0, -16691, 0, -15026, 0, -16690, 0, -15021, 0, -16689, 0, -15020, 0, -16688, 0, -15019, 0, -16687, 0, -15017, 0, -16686, 0, -15016, 0, -16685, 0, -15015, 0, -16684, 0, -15011, 0, -16683, 0, -15010, 0, -16682, 0, -15008, 0, -16681, 0, -15007, 0, -16680, 0, -15004, 0, -16679, 0, -15000, 0, -16678, 0, -14992, 0, -16677, 0, -14991, 0, -16676, 0, -14989, 0, -16675, 0, -14988, 0, -16674, 0, -14987, 0, -16673, 0, -14980, 0, -16672, 0, -14979, 0, -16671, 0, -14976, 0, -16670, 0, -14972, 0, -16669, 0, -14969, 0, -16668, 0, -14964, 0, -16667, 0, -14963, 0, -16666, 0, -14961, 0, -16665, 0, -14959, 0, -16664, 0, -14955, 0, -16663, 0, -14953, 0, -16662, 0, -14952, 0, -16661, 0, -14948, 0, -16660, 0, -14944, 0, -16659, 0, -14935, 0, -16658, 0, -14924, 0, -16657, 0, -14923, 0, -16656, 0, -14920, 0, -16655, 0, -14919, 0, -16654, 0, -14917, 0, -16653, 0, -14916, 0, -16652, 0, -14915, 0, -16651, 0, -14914, 0, -16650, 0, -14908, 0, -16649, 0, -14907, 0, -16648, 0, -14906, 0, -16647, 0, -14905, 0, -16646, 0, -14904, 0, -16645, 0, -14903, 0, -16644, 0, -14902, 0, -16643, 0, -14900, 0, -16642, 0, -14898, 0, -16575, 0, -11106, 0, -16574, 0, -11105, 0, -16573, 0, -11104, 0, -16572, 0, -11103, 0, -16571, 0, -11102, 0, -16570, 0, -11101, 0, -16569, 0, -11100, 0, -16568, 0, -11099, 0, -16567, 0, -11098, 0, -16566, 0, -11097, 0, -16565, 0, -11096, 0, -16564, 0, -11094, 0, -16563, 0, -11093, 0, -16562, 0, -11092, 0, -16561, 0, -11091, 0, -16560, 0, -11090, 0, -16559, 0, -11089, 0, -16558, 0, -11088, 0, -16557, 0, -11087, 0, -16556, 0, -11086, 0, -16555, 0, -11085, 0, -16554, 0, -11084, 0, -16553, 0, -11083, 0, -16552, 0, -11082, 0, -16551, 0, -11081, 0, -16550, 0, -11080, 0, -16543, 0, -11079, 0, -16542, 0, -11078, 0, -16541, 0, -11077, 0, -16540, 0, -11076, 0, -16539, 0, -11075, 0, -16538, 0, -11074, 0, -16537, 0, -11073, 0, -16536, 0, -11072, 0, -16535, 0, -11071, 0, -16534, 0, -11070, 0, -16533, 0, -11069, 0, -16532, 0, -11068, 0, -16531, 0, -11067, 0, -16530, 0, -11066, 0, -16529, 0, -11065, 0, -16528, 0, -11064, 0, -16527, 0, -11063, 0, -16526, 0, -11062, 0, -16525, 0, -11061, 0, -16524, 0, -11059, 0, -16523, 0, -11058, 0, -16522, 0, -11057, 0, -16521, 0, -11055, 0, -16520, 0, -11054, 0, -16519, 0, -11053, 0, -16518, 0, -11051, 0, -16511, 0, -11050, 0, -16510, 0, -11049, 0, -16509, 0, -11048, 0, -16508, 0, -11047, 0, -16507, 0, -11046, 0, -16506, 0, -11045, 0, -16505, 0, -11043, 0, -16504, 0, -11042, 0, -16503, 0, -11040, 0, -16502, 0, -11039, 0, -16501, 0, -11038, 0, -16500, 0, -11037, 0, -16499, 0, -11036, 0, -16498, 0, -11035, 0, -16497, 0, -11034, 0, -16496, 0, -11033, 0, -16495, 0, -11031, 0, -16494, 0, -11030, 0, -16493, 0, -11029, 0, -16492, 0, -11027, 0, -16491, 0, -11026, 0, -16490, 0, -11025, 0, -16489, 0, -11023, 0, -16488, 0, -11022, 0, -16487, 0, -11021, 0, -16486, 0, -11020, 0, -16485, 0, -11019, 0, -16484, 0, -11018, 0, -16483, 0, -11017, 0, -16482, 0, -11015, 0, -16481, 0, -11014, 0, -16480, 0, -11012, 0, -16479, 0, -14896, 0, -16478, 0, -14895, 0, -16477, 0, -14892, 0, -16476, 0, -14888, 0, -16475, 0, -14880, 0, -16474, 0, -14879, 0, -16473, 0, -14877, 0, -16472, 0, -14875, 0, -16471, 0, -14868, 0, -16470, 0, -14867, 0, -16469, 0, -14866, 0, -16468, 0, -14864, 0, -16467, 0, -14860, 0, -16466, 0, -14858, 0, -16465, 0, -14857, 0, -16464, 0, -14852, 0, -16463, 0, -14851, 0, -16462, 0, -14850, 0, -16461, 0, -14849, 0, -16460, 0, -14848, 0, -16459, 0, -14847, 0, -16458, 0, -14843, 0, -16457, 0, -14842, 0, -16456, 0, -14841, 0, -16455, 0, -14840, 0, -16454, 0, -14836, 0, -16453, 0, -14832, 0, -16452, 0, -14824, 0, -16451, 0, -14823, 0, -16450, 0, -14821, 0, -16449, 0, -14820, 0, -16448, 0, -14812, 0, -16447, 0, -14811, 0, -16446, 0, -14808, 0, -16445, 0, -14804, 0, -16444, 0, -14803, 0, -16443, 0, -14802, 0, -16442, 0, -14800, 0, -16441, 0, -14797, 0, -16440, 0, -14796, 0, -16439, 0, -14795, 0, -16438, 0, -14793, 0, -16437, 0, -14791, 0, -16436, 0, -14789, 0, -16435, 0, -14784, 0, -16434, 0, -14783, 0, -16433, 0, -14780, 0, -16432, 0, -14776, 0, -16431, 0, -14768, 0, -16430, 0, -14767, 0, -16429, 0, -14765, 0, -16428, 0, -14764, 0, -16427, 0, -14763, 0, -16426, 0, -14756, 0, -16425, 0, -14755, 0, -16424, 0, -14752, 0, -16423, 0, -14740, 0, -16422, 0, -14737, 0, -16421, 0, -14735, 0, -16420, 0, -14728, 0, -16419, 0, -14727, 0, -16418, 0, -14724, 0, -16417, 0, -14720, 0, -16416, 0, -14712, 0, -16415, 0, -14711, 0, -16414, 0, -14709, 0, -16413, 0, -14707, 0, -16412, 0, -14700, 0, -16411, 0, -14699, 0, -16410, 0, -14696, 0, -16409, 0, -14692, 0, -16408, 0, -14684, 0, -16407, 0, -14683, 0, -16406, 0, -14681, 0, -16405, 0, -14679, 0, -16404, 0, -14672, 0, -16403, 0, -14671, 0, -16402, 0, -14668, 0, -16401, 0, -14664, 0, -16400, 0, -14663, 0, -16399, 0, -14662, 0, -16398, 0, -14656, 0, -16397, 0, -14655, 0, -16396, 0, -14653, 0, -16395, 0, -14651, 0, -16394, 0, -14644, 0, -16393, 0, -14643, 0, -16392, 0, -14640, 0, -16391, 0, -14636, 0, -16390, 0, -14628, 0, -16389, 0, -14627, 0, -16388, 0, -14624, 0, -16387, 0, -14623, 0, -16386, 0, -14616, 0, -16319, 0, -11010, 0, -16318, 0, -11009, 0, -16317, 0, -11008, 0, -16316, 0, -11007, 0, -16315, 0, -11006, 0, -16314, 0, -11005, 0, -16313, 0, -11003, 0, -16312, 0, -11002, 0, -16311, 0, -11001, 0, -16310, 0, -10999, 0, -16309, 0, -10998, 0, -16308, 0, -10997, 0, -16307, 0, -10995, 0, -16306, 0, -10994, 0, -16305, 0, -10993, 0, -16304, 0, -10992, 0, -16303, 0, -10991, 0, -16302, 0, -10990, 0, -16301, 0, -10989, 0, -16300, 0, -10986, 0, -16299, 0, -10984, 0, -16298, 0, -10983, 0, -16297, 0, -10982, 0, -16296, 0, -10981, 0, -16295, 0, -10980, 0, -16294, 0, -10979, 0, -16287, 0, -10978, 0, -16286, 0, -10977, 0, -16285, 0, -10976, 0, -16284, 0, -10975, 0, -16283, 0, -10974, 0, -16282, 0, -10973, 0, -16281, 0, -10972, 0, -16280, 0, -10971, 0, -16279, 0, -10970, 0, -16278, 0, -10969, 0, -16277, 0, -10968, 0, -16276, 0, -10967, 0, -16275, 0, -10966, 0, -16274, 0, -10965, 0, -16273, 0, -10964, 0, -16272, 0, -10963, 0, -16271, 0, -10962, 0, -16270, 0, -10961, 0, -16269, 0, -10960, 0, -16268, 0, -10959, 0, -16267, 0, -10958, 0, -16266, 0, -10957, 0, -16265, 0, -10956, 0, -16264, 0, -10955, 0, -16263, 0, -10954, 0, -16262, 0, -10953, 0, -16255, 0, -10952, 0, -16254, 0, -10951, 0, -16253, 0, -10950, 0, -16252, 0, -10949, 0, -16251, 0, -10946, 0, -16250, 0, -10945, 0, -16249, 0, -10943, 0, -16248, 0, -10942, 0, -16247, 0, -10941, 0, -16246, 0, -10939, 0, -16245, 0, -10938, 0, -16244, 0, -10937, 0, -16243, 0, -10936, 0, -16242, 0, -10935, 0, -16241, 0, -10934, 0, -16240, 0, -10933, 0, -16239, 0, -10930, 0, -16238, 0, -10928, 0, -16237, 0, -10926, 0, -16236, 0, -10925, 0, -16235, 0, -10924, 0, -16234, 0, -10923, 0, -16233, 0, -10922, 0, -16232, 0, -10921, 0, -16231, 0, -10918, 0, -16230, 0, -10917, 0, -16229, 0, -10915, 0, -16228, 0, -10914, 0, -16227, 0, -10913, 0, -16226, 0, -10911, 0, -16225, 0, -10910, 0, -16224, 0, -10909, 0, -16223, 0, -14615, 0, -16222, 0, -14612, 0, -16221, 0, -14608, 0, -16220, 0, -14600, 0, -16219, 0, -14599, 0, -16218, 0, -14595, 0, -16217, 0, -14588, 0, -16216, 0, -14587, 0, -16215, 0, -14584, 0, -16214, 0, -14580, 0, -16213, 0, -14572, 0, -16212, 0, -14571, 0, -16211, 0, -14569, 0, -16210, 0, -14567, 0, -16209, 0, -14560, 0, -16208, 0, -14559, 0, -16207, 0, -14556, 0, -16206, 0, -14552, 0, -16205, 0, -14544, 0, -16204, 0, -14543, 0, -16203, 0, -14541, 0, -16202, 0, -14539, 0, -16201, 0, -14537, 0, -16200, 0, -14532, 0, -16199, 0, -14531, 0, -16198, 0, -14528, 0, -16197, 0, -14524, 0, -16196, 0, -14518, 0, -16195, 0, -14516, 0, -16194, 0, -14515, 0, -16193, 0, -14513, 0, -16192, 0, -14511, 0, -16191, 0, -14510, 0, -16190, 0, -14509, 0, -16189, 0, -14508, 0, -16188, 0, -14507, 0, -16187, 0, -14506, 0, -16186, 0, -14505, 0, -16185, 0, -14504, 0, -16184, 0, -14500, 0, -16183, 0, -14496, 0, -16182, 0, -14488, 0, -16181, 0, -14485, 0, -16180, 0, -14476, 0, -16179, 0, -14475, 0, -16178, 0, -14472, 0, -16177, 0, -14468, 0, -16176, 0, -14467, 0, -16175, 0, -14466, 0, -16174, 0, -14461, 0, -16173, 0, -14460, 0, -16172, 0, -14459, 0, -16171, 0, -14457, 0, -16170, 0, -14456, 0, -16169, 0, -14455, 0, -16168, 0, -14454, 0, -16167, 0, -14450, 0, -16166, 0, -14448, 0, -16165, 0, -14447, 0, -16164, 0, -14444, 0, -16163, 0, -14442, 0, -16162, 0, -14441, 0, -16161, 0, -14440, 0, -16160, 0, -14438, 0, -16159, 0, -14432, 0, -16158, 0, -14431, 0, -16157, 0, -14429, 0, -16156, 0, -14428, 0, -16155, 0, -14427, 0, -16154, 0, -14426, 0, -16153, 0, -14420, 0, -16152, 0, -14419, 0, -16151, 0, -14416, 0, -16150, 0, -14412, 0, -16149, 0, -14404, 0, -16148, 0, -14403, 0, -16147, 0, -14401, 0, -16146, 0, -14400, 0, -16145, 0, -14399, 0, -16144, 0, -14392, 0, -16143, 0, -14391, 0, -16142, 0, -14388, 0, -16141, 0, -14386, 0, -16140, 0, -14384, 0, -16139, 0, -14376, 0, -16138, 0, -14371, 0, -16137, 0, -14364, 0, -16136, 0, -14360, 0, -16135, 0, -14356, 0, -16134, 0, -14336, 0, -16133, 0, -14335, 0, -16132, 0, -14332, 0, -16131, 0, -14328, 0, -16130, 0, -14326, 0, -16063, 0, -10908, 0, -16062, 0, -10906, 0, -16061, 0, -10905, 0, -16060, 0, -10902, 0, -16059, 0, -10900, 0, -16058, 0, -10898, 0, -16057, 0, -10897, 0, -16056, 0, -10896, 0, -16055, 0, -10895, 0, -16054, 0, -10894, 0, -16053, 0, -10893, 0, -16052, 0, -10890, 0, -16051, 0, -10889, 0, -16050, 0, -10887, 0, -16049, 0, -10886, 0, -16048, 0, -10885, 0, -16047, 0, -10883, 0, -16046, 0, -10882, 0, -16045, 0, -10881, 0, -16044, 0, -10880, 0, -16043, 0, -10879, 0, -16042, 0, -10878, 0, -16041, 0, -10877, 0, -16040, 0, -10874, 0, -16039, 0, -10870, 0, -16038, 0, -10869, 0, -16031, 0, -10868, 0, -16030, 0, -10867, 0, -16029, 0, -10866, 0, -16028, 0, -10865, 0, -16027, 0, -10863, 0, -16026, 0, -10862, 0, -16025, 0, -10861, 0, -16024, 0, -10860, 0, -16023, 0, -10859, 0, -16022, 0, -10858, 0, -16021, 0, -10857, 0, -16020, 0, -10856, 0, -16019, 0, -10855, 0, -16018, 0, -10854, 0, -16017, 0, -10853, 0, -16016, 0, -10852, 0, -16015, 0, -10851, 0, -16014, 0, -10850, 0, -16013, 0, -10849, 0, -16012, 0, -10848, 0, -16011, 0, -10847, 0, -16010, 0, -10846, 0, -16009, 0, -10845, 0, -16008, 0, -10844, 0, -16007, 0, -10842, 0, -16006, 0, -10841, 0, -15999, 0, -10840, 0, -15998, 0, -10839, 0, -15997, 0, -10838, 0, -15996, 0, -10837, 0, -15995, 0, -10836, 0, -15994, 0, -10835, 0, -15993, 0, -10834, 0, -15992, 0, -10833, 0, -15991, 0, -10832, 0, -15990, 0, -10831, 0, -15989, 0, -10830, 0, -15988, 0, -10829, 0, -15987, 0, -10828, 0, -15986, 0, -10827, 0, -15985, 0, -10826, 0, -15984, 0, -10825, 0, -15983, 0, -10824, 0, -15982, 0, -10823, 0, -15981, 0, -10822, 0, -15980, 0, -10821, 0, -15979, 0, -10820, 0, -15978, 0, -10819, 0, -15977, 0, -10818, 0, -15976, 0, -10817, 0, -15975, 0, -10816, 0, -15974, 0, -10815, 0, -15973, 0, -10814, 0, -15972, 0, -10813, 0, -15971, 0, -10812, 0, -15970, 0, -10811, 0, -15969, 0, -10810, 0, -15968, 0, -10809, 0, -15967, 0, -14320, 0, -15966, 0, -14319, 0, -15965, 0, -14317, 0, -15964, 0, -14315, 0, -15963, 0, -14314, 0, -15962, 0, -14308, 0, -15961, 0, -14307, 0, -15960, 0, -14304, 0, -15959, 0, -14300, 0, -15958, 0, -14292, 0, -15957, 0, -14291, 0, -15956, 0, -14289, 0, -15955, 0, -14287, 0, -15954, 0, -14280, 0, -15953, 0, -14276, 0, -15952, 0, -14272, 0, -15951, 0, -14264, 0, -15950, 0, -14263, 0, -15949, 0, -14260, 0, -15948, 0, -14259, 0, -15947, 0, -14252, 0, -15946, 0, -14224, 0, -15945, 0, -14223, 0, -15944, 0, -14220, 0, -15943, 0, -14216, 0, -15942, 0, -14214, 0, -15941, 0, -14208, 0, -15940, 0, -14207, 0, -15939, 0, -14205, 0, -15938, 0, -14203, 0, -15937, 0, -14202, 0, -15936, 0, -14201, 0, -15935, 0, -14197, 0, -15934, 0, -14196, 0, -15933, 0, -14195, 0, -15932, 0, -14188, 0, -15931, 0, -14179, 0, -15930, 0, -14177, 0, -15929, 0, -14175, 0, -15928, 0, -14168, 0, -15927, 0, -14148, 0, -15926, 0, -14147, 0, -15925, 0, -14140, 0, -15924, 0, -14136, 0, -15923, 0, -14132, 0, -15922, 0, -14124, 0, -15921, 0, -14123, 0, -15920, 0, -14121, 0, -15919, 0, -14119, 0, -15918, 0, -14112, 0, -15917, 0, -14111, 0, -15916, 0, -14108, 0, -15915, 0, -14091, 0, -15914, 0, -14084, 0, -15913, 0, -14083, 0, -15912, 0, -14080, 0, -15911, 0, -14076, 0, -15910, 0, -14075, 0, -15909, 0, -14074, 0, -15908, 0, -14068, 0, -15907, 0, -14067, 0, -15906, 0, -14065, 0, -15905, 0, -14063, 0, -15904, 0, -14056, 0, -15903, 0, -14036, 0, -15902, 0, -14028, 0, -15901, 0, -14000, 0, -15900, 0, -13999, 0, -15899, 0, -13996, 0, -15898, 0, -13992, 0, -15897, 0, -13984, 0, -15896, 0, -13983, 0, -15895, 0, -13981, 0, -15894, 0, -13972, 0, -15893, 0, -13968, 0, -15892, 0, -13964, 0, -15891, 0, -13956, 0, -15890, 0, -13944, 0, -15889, 0, -13943, 0, -15888, 0, -13940, 0, -15887, 0, -13936, 0, -15886, 0, -13928, 0, -15885, 0, -13927, 0, -15884, 0, -13925, 0, -15883, 0, -13923, 0, -15882, 0, -13888, 0, -15881, 0, -13887, 0, -15880, 0, -13884, 0, -15879, 0, -13881, 0, -15878, 0, -13880, 0, -15877, 0, -13878, 0, -15876, 0, -13872, 0, -15875, 0, -13871, 0, -15874, 0, -13869, 0, -15807, 0, -10806, 0, -15806, 0, -10805, 0, -15805, 0, -10803, 0, -15804, 0, -10802, 0, -15803, 0, -10801, 0, -15802, 0, -10799, 0, -15801, 0, -10797, 0, -15800, 0, -10796, 0, -15799, 0, -10795, 0, -15798, 0, -10794, 0, -15797, 0, -10793, 0, -15796, 0, -10790, 0, -15795, 0, -10788, 0, -15794, 0, -10786, 0, -15793, 0, -10785, 0, -15792, 0, -10784, 0, -15791, 0, -10783, 0, -15790, 0, -10782, 0, -15789, 0, -10781, 0, -15788, 0, -10778, 0, -15787, 0, -10777, 0, -15786, 0, -10775, 0, -15785, 0, -10774, 0, -15784, 0, -10773, 0, -15783, 0, -10771, 0, -15782, 0, -10770, 0, -15775, 0, -10769, 0, -15774, 0, -10768, 0, -15773, 0, -10767, 0, -15772, 0, -10766, 0, -15771, 0, -10765, 0, -15770, 0, -10762, 0, -15769, 0, -10760, 0, -15768, 0, -10758, 0, -15767, 0, -10757, 0, -15766, 0, -10756, 0, -15765, 0, -10755, 0, -15764, 0, -10754, 0, -15763, 0, -10753, 0, -15762, 0, -10750, 0, -15761, 0, -10749, 0, -15760, 0, -10747, 0, -15759, 0, -10746, 0, -15758, 0, -10745, 0, -15757, 0, -10743, 0, -15756, 0, -10742, 0, -15755, 0, -10741, 0, -15754, 0, -10740, 0, -15753, 0, -10739, 0, -15752, 0, -10738, 0, -15751, 0, -10737, 0, -15750, 0, -10734, 0, -15743, 0, -10730, 0, -15742, 0, -10729, 0, -15741, 0, -10728, 0, -15740, 0, -10727, 0, -15739, 0, -10726, 0, -15738, 0, -10725, 0, -15737, 0, -10723, 0, -15736, 0, -10722, 0, -15735, 0, -10721, 0, -15734, 0, -10719, 0, -15733, 0, -10718, 0, -15732, 0, -10717, 0, -15731, 0, -10715, 0, -15730, 0, -10714, 0, -15729, 0, -10713, 0, -15728, 0, -10712, 0, -15727, 0, -10711, 0, -15726, 0, -10710, 0, -15725, 0, -10709, 0, -15724, 0, -10708, 0, -15723, 0, -10706, 0, -15722, 0, -10705, 0, -15721, 0, -10704, 0, -15720, 0, -10703, 0, -15719, 0, -10702, 0, -15718, 0, -10701, 0, -15717, 0, -10700, 0, -15716, 0, -10699, 0, -15715, 0, -10698, 0, -15714, 0, -10697, 0, -15713, 0, -10694, 0, -15712, 0, -10693, 0, -15711, 0, -13867, 0, -15710, 0, -13866, 0, -15709, 0, -13863, 0, -15708, 0, -13862, 0, -15707, 0, -13860, 0, -15706, 0, -13859, 0, -15705, 0, -13856, 0, -15704, 0, -13854, 0, -15703, 0, -13852, 0, -15702, 0, -13849, 0, -15701, 0, -13844, 0, -15700, 0, -13843, 0, -15699, 0, -13841, 0, -15698, 0, -13840, 0, -15697, 0, -13839, 0, -15696, 0, -13832, 0, -15695, 0, -13831, 0, -15694, 0, -13828, 0, -15693, 0, -13824, 0, -15692, 0, -13816, 0, -15691, 0, -13815, 0, -15690, 0, -13813, 0, -15689, 0, -13812, 0, -15688, 0, -13811, 0, -15687, 0, -13804, 0, -15686, 0, -13800, 0, -15685, 0, -13783, 0, -15684, 0, -13748, 0, -15683, 0, -13747, 0, -15682, 0, -13744, 0, -15681, 0, -13740, 0, -15680, 0, -13732, 0, -15679, 0, -13731, 0, -15678, 0, -13729, 0, -15677, 0, -13728, 0, -15676, 0, -13727, 0, -15675, 0, -13720, 0, -15674, 0, -13699, 0, -15673, 0, -13692, 0, -15672, 0, -13672, 0, -15671, 0, -13636, 0, -15670, 0, -13635, 0, -15669, 0, -13632, 0, -15668, 0, -13628, 0, -15667, 0, -13620, 0, -15666, 0, -13619, 0, -15665, 0, -13617, 0, -15664, 0, -13615, 0, -15663, 0, -13613, 0, -15662, 0, -13608, 0, -15661, 0, -13607, 0, -15660, 0, -13600, 0, -15659, 0, -13588, 0, -15658, 0, -13580, 0, -15657, 0, -13560, 0, -15656, 0, -13552, 0, -15655, 0, -13548, 0, -15654, 0, -13544, 0, -15653, 0, -13536, 0, -15652, 0, -13535, 0, -15651, 0, -13503, 0, -15650, 0, -13496, 0, -15649, 0, -13495, 0, -15648, 0, -13492, 0, -15647, 0, -13488, 0, -15646, 0, -13480, 0, -15645, 0, -13479, 0, -15644, 0, -13475, 0, -15643, 0, -13468, 0, -15642, 0, -13448, 0, -15641, 0, -13447, 0, -15640, 0, -13412, 0, -15639, 0, -13384, 0, -15638, 0, -13356, 0, -15637, 0, -13340, 0, -15636, 0, -13337, 0, -15635, 0, -13335, 0, -15634, 0, -13300, 0, -15633, 0, -13299, 0, -15632, 0, -13296, 0, -15631, 0, -13292, 0, -15630, 0, -13284, 0, -15629, 0, -13283, 0, -15628, 0, -13279, 0, -15627, 0, -13278, 0, -15626, 0, -13273, 0, -15625, 0, -13272, 0, -15624, 0, -13271, 0, -15623, 0, -13268, 0, -15622, 0, -13266, 0, -15621, 0, -13264, 0, -15620, 0, -13256, 0, -15619, 0, -13255, 0, -15618, 0, -13253, 0, -15551, 0, -10691, 0, -15550, 0, -10690, 0, -15549, 0, -10689, 0, -15548, 0, -10687, 0, -15547, 0, -10686, 0, -15546, 0, -10685, 0, -15545, 0, -10684, 0, -15544, 0, -10682, 0, -15543, 0, -10681, 0, -15542, 0, -10678, 0, -15541, 0, -10676, 0, -15540, 0, -10674, 0, -15539, 0, -10673, 0, -15538, 0, -10672, 0, -15537, 0, -10670, 0, -15536, 0, -10669, 0, -15535, 0, -10666, 0, -15534, 0, -10665, 0, -15533, 0, -10663, 0, -15532, 0, -10662, 0, -15531, 0, -10661, 0, -15530, 0, -10659, 0, -15529, 0, -10658, 0, -15528, 0, -10657, 0, -15527, 0, -10656, 0, -15526, 0, -10655, 0, -15519, 0, -10654, 0, -15518, 0, -10653, 0, -15517, 0, -10652, 0, -15516, 0, -10651, 0, -15515, 0, -10650, 0, -15514, 0, -10648, 0, -15513, 0, -10646, 0, -15512, 0, -10645, 0, -15511, 0, -10644, 0, -15510, 0, -10643, 0, -15509, 0, -10642, 0, -15508, 0, -10641, 0, -15507, 0, -10638, 0, -15506, 0, -10637, 0, -15505, 0, -10635, 0, -15504, 0, -10634, 0, -15503, 0, -10633, 0, -15502, 0, -10632, 0, -15501, 0, -10631, 0, -15500, 0, -10630, 0, -15499, 0, -10629, 0, -15498, 0, -10628, 0, -15497, 0, -10627, 0, -15496, 0, -10626, 0, -15495, 0, -10625, 0, -15494, 0, -10624, 0, -15487, 0, -10623, 0, -15486, 0, -10622, 0, -15485, 0, -10620, 0, -15484, 0, -10618, 0, -15483, 0, -10617, 0, -15482, 0, -10616, 0, -15481, 0, -10615, 0, -15480, 0, -10614, 0, -15479, 0, -10613, 0, -15478, 0, -10610, 0, -15477, 0, -10609, 0, -15476, 0, -10607, 0, -15475, 0, -10606, 0, -15474, 0, -10605, 0, -15473, 0, -10603, 0, -15472, 0, -10602, 0, -15471, 0, -10601, 0, -15470, 0, -10600, 0, -15469, 0, -10599, 0, -15468, 0, -10598, 0, -15467, 0, -10597, 0, -15466, 0, -10596, 0, -15465, 0, -10594, 0, -15464, 0, -10592, 0, -15463, 0, -10590, 0, -15462, 0, -10589, 0, -15461, 0, -10588, 0, -15460, 0, -10587, 0, -15459, 0, -10586, 0, -15458, 0, -10585, 0, -15457, 0, -10583, 0, -15456, 0, -10582, 0, -15455, 0, -13252, 0, -15454, 0, -13251, 0, -15453, 0, -13250, 0, -15452, 0, -13244, 0, -15451, 0, -13243, 0, -15450, 0, -13240, 0, -15449, 0, -13236, 0, -15448, 0, -13228, 0, -15447, 0, -13227, 0, -15446, 0, -13225, 0, -15445, 0, -13224, 0, -15444, 0, -13223, 0, -15443, 0, -13216, 0, -15442, 0, -13212, 0, -15441, 0, -13210, 0, -15440, 0, -13208, 0, -15439, 0, -13200, 0, -15438, 0, -13195, 0, -15437, 0, -13160, 0, -15436, 0, -13159, 0, -15435, 0, -13156, 0, -15434, 0, -13152, 0, -15433, 0, -13144, 0, -15432, 0, -13143, 0, -15431, 0, -13141, 0, -15430, 0, -13140, 0, -15429, 0, -13139, 0, -15428, 0, -13132, 0, -15427, 0, -13131, 0, -15426, 0, -13128, 0, -15425, 0, -13124, 0, -15424, 0, -13116, 0, -15423, 0, -13115, 0, -15422, 0, -13113, 0, -15421, 0, -13111, 0, -15420, 0, -13104, 0, -15419, 0, -13100, 0, -15418, 0, -13084, 0, -15417, 0, -13076, 0, -15416, 0, -13072, 0, -15415, 0, -13055, 0, -15414, 0, -13048, 0, -15413, 0, -13047, 0, -15412, 0, -13044, 0, -15411, 0, -13040, 0, -15410, 0, -13032, 0, -15409, 0, -13031, 0, -15408, 0, -13029, 0, -15407, 0, -13027, 0, -15406, 0, -13020, 0, -15405, 0, -13016, 0, -15404, 0, -13012, 0, -15403, 0, -12999, 0, -15402, 0, -12964, 0, -15401, 0, -12960, 0, -15400, 0, -12956, 0, -15399, 0, -12948, 0, -15398, 0, -12947, 0, -15397, 0, -12945, 0, -15396, 0, -12943, 0, -15395, 0, -12936, 0, -15394, 0, -12920, 0, -15393, 0, -12908, 0, -15392, 0, -12907, 0, -15391, 0, -12904, 0, -15390, 0, -12900, 0, -15389, 0, -12892, 0, -15388, 0, -12891, 0, -15387, 0, -12889, 0, -15386, 0, -12887, 0, -15385, 0, -12880, 0, -15384, 0, -12860, 0, -15383, 0, -12852, 0, -15382, 0, -12848, 0, -15381, 0, -12824, 0, -15380, 0, -12820, 0, -15379, 0, -12816, 0, -15378, 0, -12808, 0, -15377, 0, -12807, 0, -15376, 0, -12805, 0, -15375, 0, -12803, 0, -15374, 0, -12796, 0, -15373, 0, -12792, 0, -15372, 0, -12788, 0, -15371, 0, -12780, 0, -15370, 0, -12775, 0, -15369, 0, -12768, 0, -15368, 0, -12767, 0, -15367, 0, -12764, 0, -15366, 0, -12760, 0, -15365, 0, -12752, 0, -15364, 0, -12751, 0, -15363, 0, -12749, 0, -15362, 0, -12747, 0, -15295, 0, -10581, 0, -15294, 0, -10579, 0, -15293, 0, -10578, 0, -15292, 0, -10577, 0, -15291, 0, -10575, 0, -15290, 0, -10574, 0, -15289, 0, -10573, 0, -15288, 0, -10572, 0, -15287, 0, -10571, 0, -15286, 0, -10570, 0, -15285, 0, -10569, 0, -15284, 0, -10568, 0, -15283, 0, -10566, 0, -15282, 0, -10564, 0, -15281, 0, -10563, 0, -15280, 0, -10562, 0, -15279, 0, -10561, 0, -15278, 0, -10560, 0, -15277, 0, -10559, 0, -15276, 0, -10558, 0, -15275, 0, -10557, 0, -15274, 0, -10554, 0, -15273, 0, -10553, 0, -15272, 0, -10551, 0, -15271, 0, -10550, 0, -15270, 0, -10549, 0, -15263, 0, -10547, 0, -15262, 0, -10546, 0, -15261, 0, -10545, 0, -15260, 0, -10544, 0, -15259, 0, -10542, 0, -15258, 0, -10541, 0, -15257, 0, -10539, 0, -15256, 0, -10538, 0, -15255, 0, -10536, 0, -15254, 0, -10534, 0, -15253, 0, -10533, 0, -15252, 0, -10532, 0, -15251, 0, -10531, 0, -15250, 0, -10530, 0, -15249, 0, -10529, 0, -15248, 0, -10527, 0, -15247, 0, -10526, 0, -15246, 0, -10525, 0, -15245, 0, -10523, 0, -15244, 0, -10522, 0, -15243, 0, -10521, 0, -15242, 0, -10519, 0, -15241, 0, -10518, 0, -15240, 0, -10517, 0, -15239, 0, -10516, 0, -15238, 0, -10515, 0, -15231, 0, -10514, 0, -15230, 0, -10513, 0, -15229, 0, -10511, 0, -15228, 0, -10510, 0, -15227, 0, -10509, 0, -15226, 0, -10508, 0, -15225, 0, -10506, 0, -15224, 0, -10505, 0, -15223, 0, -10504, 0, -15222, 0, -10503, 0, -15221, 0, -10502, 0, -15220, 0, -10501, 0, -15219, 0, -10498, 0, -15218, 0, -10497, 0, -15217, 0, -10495, 0, -15216, 0, -10494, 0, -15215, 0, -10493, 0, -15214, 0, -10491, 0, -15213, 0, -10490, 0, -15212, 0, -10489, 0, -15211, 0, -10488, 0, -15210, 0, -10487, 0, -15209, 0, -10486, 0, -15208, 0, -10485, 0, -15207, 0, -10484, 0, -15206, 0, -10483, 0, -15205, 0, -10482, 0, -15204, 0, -10481, 0, -15203, 0, -10480, 0, -15202, 0, -10478, 0, -15201, 0, -10477, 0, -15200, 0, -10476, 0, -15199, 0, -12712, 0, -15198, 0, -12711, 0, -15197, 0, -12708, 0, -15196, 0, -12705, 0, -15195, 0, -12704, 0, -15194, 0, -12703, 0, -15193, 0, -12696, 0, -15192, 0, -12695, 0, -15191, 0, -12693, 0, -15190, 0, -12691, 0, -15189, 0, -12684, 0, -15188, 0, -12683, 0, -15187, 0, -12680, 0, -15186, 0, -12676, 0, -15185, 0, -12668, 0, -15184, 0, -12667, 0, -15183, 0, -12665, 0, -15182, 0, -12663, 0, -15181, 0, -12656, 0, -15180, 0, -12655, 0, -15179, 0, -12652, 0, -15178, 0, -12648, 0, -15177, 0, -12640, 0, -15176, 0, -12639, 0, -15175, 0, -12637, 0, -15174, 0, -12636, 0, -15173, 0, -12635, 0, -15172, 0, -12628, 0, -15171, 0, -12627, 0, -15170, 0, -12607, 0, -15169, 0, -12572, 0, -15168, 0, -12571, 0, -15167, 0, -12568, 0, -15166, 0, -12565, 0, -15165, 0, -12564, 0, -15164, 0, -12556, 0, -15163, 0, -12555, 0, -15162, 0, -12553, 0, -15161, 0, -12552, 0, -15160, 0, -12551, 0, -15159, 0, -12544, 0, -15158, 0, -12543, 0, -15157, 0, -12540, 0, -15156, 0, -12536, 0, -15155, 0, -12528, 0, -15154, 0, -12527, 0, -15153, 0, -12525, 0, -15152, 0, -12523, 0, -15151, 0, -12516, 0, -15150, 0, -12512, 0, -15149, 0, -12508, 0, -15148, 0, -12500, 0, -15147, 0, -12499, 0, -15146, 0, -12497, 0, -15145, 0, -12496, 0, -15144, 0, -12495, 0, -15143, 0, -12488, 0, -15142, 0, -12460, 0, -15141, 0, -12459, 0, -15140, 0, -12456, 0, -15139, 0, -12452, 0, -15138, 0, -12444, 0, -15137, 0, -12443, 0, -15136, 0, -12441, 0, -15135, 0, -12439, 0, -15134, 0, -12432, 0, -15133, 0, -12431, 0, -15132, 0, -12428, 0, -15131, 0, -12424, 0, -15130, 0, -12416, 0, -15129, 0, -12411, 0, -15128, 0, -12404, 0, -15127, 0, -12383, 0, -15126, 0, -12376, 0, -15125, 0, -12368, 0, -15124, 0, -12348, 0, -15123, 0, -12320, 0, -15122, 0, -12319, 0, -15121, 0, -12316, 0, -15120, 0, -12312, 0, -15119, 0, -12304, 0, -15118, 0, -12303, 0, -15117, 0, -12301, 0, -15116, 0, -12299, 0, -15115, 0, -12292, 0, -15114, 0, -12288, 0, -15113, 0, -12284, 0, -15112, 0, -12271, 0, -15111, 0, -12264, 0, -15110, 0, -12243, 0, -15109, 0, -12236, 0, -15108, 0, -12235, 0, -15107, 0, -12232, 0, -15106, 0, -12228, 0, -15039, 0, -10475, 0, -15038, 0, -10474, 0, -15037, 0, -10473, 0, -15036, 0, -10470, 0, -15035, 0, -10469, 0, -15034, 0, -10467, 0, -15033, 0, -10466, 0, -15032, 0, -10465, 0, -15031, 0, -10463, 0, -15030, 0, -10462, 0, -15029, 0, -10461, 0, -15028, 0, -10460, 0, -15027, 0, -10459, 0, -15026, 0, -10458, 0, -15025, 0, -10457, 0, -15024, 0, -10454, 0, -15023, 0, -10452, 0, -15022, 0, -10450, 0, -15021, 0, -10449, 0, -15020, 0, -10448, 0, -15019, 0, -10447, 0, -15018, 0, -10446, 0, -15017, 0, -10445, 0, -15016, 0, -10442, 0, -15015, 0, -10441, 0, -15014, 0, -10439, 0, -15007, 0, -10438, 0, -15006, 0, -10437, 0, -15005, 0, -10435, 0, -15004, 0, -10434, 0, -15003, 0, -10433, 0, -15002, 0, -10432, 0, -15001, 0, -10431, 0, -15000, 0, -10430, 0, -14999, 0, -10429, 0, -14998, 0, -10427, 0, -14997, 0, -10426, 0, -14996, 0, -10424, 0, -14995, 0, -10422, 0, -14994, 0, -10421, 0, -14993, 0, -10420, 0, -14992, 0, -10419, 0, -14991, 0, -10418, 0, -14990, 0, -10417, 0, -14989, 0, -10414, 0, -14988, 0, -10413, 0, -14987, 0, -10411, 0, -14986, 0, -10406, 0, -14985, 0, -10405, 0, -14984, 0, -10404, 0, -14983, 0, -10403, 0, -14982, 0, -10402, 0, -14975, 0, -10401, 0, -14974, 0, -10398, 0, -14973, 0, -10396, 0, -14972, 0, -10394, 0, -14971, 0, -10393, 0, -14970, 0, -10392, 0, -14969, 0, -10390, 0, -14968, 0, -10389, 0, -14967, 0, -10387, 0, -14966, 0, -10386, 0, -14965, 0, -10385, 0, -14964, 0, -10383, 0, -14963, 0, -10382, 0, -14962, 0, -10381, 0, -14961, 0, -10379, 0, -14960, 0, -10378, 0, -14959, 0, -10377, 0, -14958, 0, -10376, 0, -14957, 0, -10375, 0, -14956, 0, -10374, 0, -14955, 0, -10373, 0, -14954, 0, -10370, 0, -14953, 0, -10369, 0, -14952, 0, -10368, 0, -14951, 0, -10366, 0, -14950, 0, -10365, 0, -14949, 0, -10364, 0, -14948, 0, -10363, 0, -14947, 0, -10362, 0, -14946, 0, -10361, 0, -14945, 0, -10358, 0, -14944, 0, -10357, 0, -14943, 0, -12220, 0, -14942, 0, -12219, 0, -14941, 0, -12217, 0, -14940, 0, -12215, 0, -14939, 0, -12208, 0, -14938, 0, -12204, 0, -14937, 0, -12200, 0, -14936, 0, -12192, 0, -14935, 0, -12180, 0, -14934, 0, -12179, 0, -14933, 0, -12176, 0, -14932, 0, -12172, 0, -14931, 0, -12164, 0, -14930, 0, -12163, 0, -14929, 0, -12159, 0, -14928, 0, -12124, 0, -14927, 0, -12123, 0, -14926, 0, -12120, 0, -14925, 0, -12116, 0, -14924, 0, -12108, 0, -14923, 0, -12107, 0, -14922, 0, -12105, 0, -14921, 0, -12103, 0, -14920, 0, -12096, 0, -14919, 0, -12095, 0, -14918, 0, -12092, 0, -14917, 0, -12088, 0, -14916, 0, -12087, 0, -14915, 0, -12080, 0, -14914, 0, -12079, 0, -14913, 0, -12077, 0, -14912, 0, -12076, 0, -14911, 0, -12075, 0, -14910, 0, -12068, 0, -14909, 0, -12067, 0, -14908, 0, -12064, 0, -14907, 0, -12060, 0, -14906, 0, -12052, 0, -14905, 0, -12051, 0, -14904, 0, -12049, 0, -14903, 0, -12048, 0, -14902, 0, -12047, 0, -14901, 0, -12040, 0, -14900, 0, -12019, 0, -14899, 0, -11984, 0, -14898, 0, -11983, 0, -14897, 0, -11980, 0, -14896, 0, -11976, 0, -14895, 0, -11974, 0, -14894, 0, -11968, 0, -14893, 0, -11967, 0, -14892, 0, -11965, 0, -14891, 0, -11964, 0, -14890, 0, -11963, 0, -14889, 0, -11956, 0, -14888, 0, -11955, 0, -14887, 0, -11952, 0, -14886, 0, -11948, 0, -14885, 0, -11940, 0, -14884, 0, -11939, 0, -14883, 0, -11937, 0, -14882, 0, -11935, 0, -14881, 0, -11928, 0, -14880, 0, -11924, 0, -14879, 0, -11908, 0, -14878, 0, -11900, 0, -14877, 0, -11896, 0, -14876, 0, -11872, 0, -14875, 0, -11871, 0, -14874, 0, -11868, 0, -14873, 0, -11864, 0, -14872, 0, -11856, 0, -14871, 0, -11855, 0, -14870, 0, -11853, 0, -14869, 0, -11851, 0, -14868, 0, -11846, 0, -14867, 0, -11844, 0, -14866, 0, -11840, 0, -14865, 0, -11816, 0, -14864, 0, -11788, 0, -14863, 0, -11784, 0, -14862, 0, -11769, 0, -14861, 0, -11767, 0, -14860, 0, -11760, 0, -14859, 0, -11732, 0, -14858, 0, -11731, 0, -14857, 0, -11728, 0, -14856, 0, -11724, 0, -14855, 0, -11716, 0, -14854, 0, -11715, 0, -14853, 0, -11713, 0, -14852, 0, -11711, 0, -14851, 0, -11704, 0, -14850, 0, -11684, 0, -14783, 0, -10355, 0, -14782, 0, -10354, 0, -14781, 0, -10353, 0, -14780, 0, -10351, 0, -14779, 0, -10350, 0, -14778, 0, -10349, 0, -14777, 0, -10348, 0, -14776, 0, -10347, 0, -14775, 0, -10346, 0, -14774, 0, -10345, 0, -14773, 0, -10342, 0, -14772, 0, -10340, 0, -14771, 0, -10338, 0, -14770, 0, -10337, 0, -14769, 0, -10336, 0, -14768, 0, -10335, 0, -14767, 0, -10334, 0, -14766, 0, -10333, 0, -14687, 0, -11676, 0, -14686, 0, -11648, 0, -14685, 0, -11647, 0, -14684, 0, -11644, 0, -14683, 0, -11640, 0, -14682, 0, -11632, 0, -14681, 0, -11631, 0, -14680, 0, -11627, 0, -14679, 0, -11620, 0, -14678, 0, -11616, 0, -14677, 0, -11612, 0, -14676, 0, -11604, 0, -14675, 0, -11599, 0, -14674, 0, -11592, 0, -14673, 0, -11591, 0, -14672, 0, -11588, 0, -14671, 0, -11585, 0, -14670, 0, -11584, 0, -14669, 0, -11582, 0, -14668, 0, -11576, 0, -14667, 0, -11575, 0, -14666, 0, -11573, 0, -14665, 0, -11564, 0, -14664, 0, -11560, 0, -14663, 0, -11556, 0, -14662, 0, -11548, 0, -14661, 0, -11547, 0, -14660, 0, -11536, 0, -14659, 0, -11535, 0, -14658, 0, -11532, 0, -14657, 0, -11528, 0, -14656, 0, -11520, 0, -14655, 0, -11519, 0, -14654, 0, -11517, 0, -14653, 0, -11515, 0, -14652, 0, -11508, 0, -14651, 0, -11507, 0, -14650, 0, -11506, 0, -14649, 0, -11504, 0, -14648, 0, -11500, 0, -14647, 0, -11498, 0, -14646, 0, -11492, 0, -14645, 0, -11491, 0, -14644, 0, -11489, 0, -14643, 0, -11488, 0, -14642, 0, -11487, 0, -14641, 0, -11483, 0, -14640, 0, -11480, 0, -14639, 0, -11479, 0, -14638, 0, -11476, 0, -14637, 0, -11472, 0, -14636, 0, -11464, 0, -14635, 0, -11463, 0, -14634, 0, -11461, 0, -14633, 0, -11460, 0, -14632, 0, -11459, 0, -14631, 0, -11452, 0, -14630, 0, -11451, 0, -14629, 0, -11396, 0, -14628, 0, -11395, 0, -14627, 0, -11392, 0, -14626, 0, -11388, 0, -14625, 0, -11380, 0, -14624, 0, -11379, 0, -14623, 0, -11377, 0, -14622, 0, -11376, 0, -14621, 0, -11375, 0, -14620, 0, -11368, 0, -14619, 0, -11367, 0, -14618, 0, -11364, 0, -14617, 0, -11360, 0, -14616, 0, -11352, 0, -14615, 0, -11351, 0, -14614, 0, -11349, 0, -14613, 0, -11347, 0, -14612, 0, -11340, 0, -14611, 0, -11336, 0, -14610, 0, -11332, 0, -14609, 0, -11324, 0, -14608, 0, -11323, 0, -14607, 0, -11320, 0, -14606, 0, -11319, 0, -14605, 0, -11312, 0, -14604, 0, -11304, 0, -14603, 0, -11295, 0, -14602, 0, -11293, 0, -14601, 0, -11284, 0, -14600, 0, -11283, 0, -14599, 0, -11280, 0, -14598, 0, -11276, 0, -14597, 0, -11268, 0, -14596, 0, -11267, 0, -14595, 0, -11265, 0, -14594, 0, -11263, 0, -14431, 0, -11256, 0, -14430, 0, -11235, 0, -14429, 0, -11200, 0, -14428, 0, -11196, 0, -14427, 0, -11172, 0, -14426, 0, -11168, 0, -14425, 0, -11164, 0, -14424, 0, -11155, 0, -14423, 0, -11153, 0, -14422, 0, -11144, 0, -14421, 0, -11143, 0, -14420, 0, -11140, 0, -14419, 0, -11137, 0, -14418, 0, -11136, 0, -14417, 0, -11134, 0, -14416, 0, -11128, 0, -14415, 0, -11127, 0, -14414, 0, -11125, 0, -14413, 0, -11123, 0, -14412, 0, -11116, 0, -14411, 0, -11095, 0, -14410, 0, -11060, 0, -14409, 0, -11056, 0, -14408, 0, -11052, 0, -14407, 0, -11044, 0, -14406, 0, -11041, 0, -14405, 0, -11032, 0, -14404, 0, -11028, 0, -14403, 0, -11024, 0, -14402, 0, -11016, 0, -14401, 0, -11013, 0, -14400, 0, -11011, 0, -14399, 0, -11004, 0, -14398, 0, -11000, 0, -14397, 0, -10996, 0, -14396, 0, -10988, 0, -14395, 0, -10987, 0, -14394, 0, -10985, 0, -14393, 0, -10948, 0, -14392, 0, -10947, 0, -14391, 0, -10944, 0, -14390, 0, -10940, 0, -14389, 0, -10932, 0, -14388, 0, -10931, 0, -14387, 0, -10929, 0, -14386, 0, -10927, 0, -14385, 0, -10920, 0, -14384, 0, -10919, 0, -14383, 0, -10916, 0, -14382, 0, -10912, 0, -14381, 0, -10907, 0, -14380, 0, -10904, 0, -14379, 0, -10903, 0, -14378, 0, -10901, 0, -14377, 0, -10899, 0, -14376, 0, -10892, 0, -14375, 0, -10891, 0, -14374, 0, -10888, 0, -14373, 0, -10884, 0, -14372, 0, -10876, 0, -14371, 0, -10875, 0, -14370, 0, -10873, 0, -14369, 0, -10872, 0, -14368, 0, -10871, 0, -14367, 0, -10864, 0, -14366, 0, -10843, 0, -14365, 0, -10808, 0, -14364, 0, -10807, 0, -14363, 0, -10804, 0, -14362, 0, -10800, 0, -14361, 0, -10798, 0, -14360, 0, -10792, 0, -14359, 0, -10791, 0, -14358, 0, -10789, 0, -14357, 0, -10787, 0, -14356, 0, -10780, 0, -14355, 0, -10779, 0, -14354, 0, -10776, 0, -14353, 0, -10772, 0, -14352, 0, -10764, 0, -14351, 0, -10763, 0, -14350, 0, -10761, 0, -14349, 0, -10759, 0, -14348, 0, -10752, 0, -14347, 0, -10751, 0, -14346, 0, -10748, 0, -14345, 0, -10744, 0, -14344, 0, -10736, 0, -14343, 0, -10735, 0, -14342, 0, -10733, 0, -14341, 0, -10732, 0, -14340, 0, -10731, 0, -14339, 0, -10724, 0, -14338, 0, -10720, 0, -14175, 0, -10716, 0, -14174, 0, -10707, 0, -14173, 0, -10696, 0, -14172, 0, -10695, 0, -14171, 0, -10692, 0, -14170, 0, -10688, 0, -14169, 0, -10683, 0, -14168, 0, -10680, 0, -14167, 0, -10679, 0, -14166, 0, -10677, 0, -14165, 0, -10675, 0, -14164, 0, -10671, 0, -14163, 0, -10668, 0, -14162, 0, -10667, 0, -14161, 0, -10664, 0, -14160, 0, -10660, 0, -14159, 0, -10649, 0, -14158, 0, -10647, 0, -14157, 0, -10640, 0, -14156, 0, -10639, 0, -14155, 0, -10636, 0, -14154, 0, -10621, 0, -14153, 0, -10619, 0, -14152, 0, -10612, 0, -14151, 0, -10611, 0, -14150, 0, -10608, 0, -14149, 0, -10604, 0, -14148, 0, -10595, 0, -14147, 0, -10593, 0, -14146, 0, -10591, 0, -14145, 0, -10584, 0, -14144, 0, -10580, 0, -14143, 0, -10576, 0, -14142, 0, -10567, 0, -14141, 0, -10565, 0, -14140, 0, -10556, 0, -14139, 0, -10555, 0, -14138, 0, -10552, 0, -14137, 0, -10548, 0, -14136, 0, -10543, 0, -14135, 0, -10540, 0, -14134, 0, -10537, 0, -14133, 0, -10535, 0, -14132, 0, -10528, 0, -14131, 0, -10524, 0, -14130, 0, -10520, 0, -14129, 0, -10512, 0, -14128, 0, -10507, 0, -14127, 0, -10500, 0, -14126, 0, -10499, 0, -14125, 0, -10496, 0, -14124, 0, -10492, 0, -14123, 0, -10479, 0, -14122, 0, -10472, 0, -14121, 0, -10471, 0, -14120, 0, -10468, 0, -14119, 0, -10464, 0, -14118, 0, -10456, 0, -14117, 0, -10455, 0, -14116, 0, -10453, 0, -14115, 0, -10451, 0, -14114, 0, -10444, 0, -14113, 0, -10443, 0, -14112, 0, -10440, 0, -14111, 0, -10436, 0, -14110, 0, -10428, 0, -14109, 0, -10425, 0, -14108, 0, -10423, 0, -14107, 0, -10416, 0, -14106, 0, -10415, 0, -14105, 0, -10412, 0, -14104, 0, -10410, 0, -14103, 0, -10409, 0, -14102, 0, -10408, 0, -14101, 0, -10407, 0, -14100, 0, -10400, 0, -14099, 0, -10399, 0, -14098, 0, -10397, 0, -14097, 0, -10395, 0, -14096, 0, -10391, 0, -14095, 0, -10388, 0, -14094, 0, -10384, 0, -14093, 0, -10380, 0, -14092, 0, -10372, 0, -14091, 0, -10371, 0, -14090, 0, -10367, 0, -14089, 0, -10360, 0, -14088, 0, -10359, 0, -14087, 0, -10356, 0, -14086, 0, -10352, 0, -14085, 0, -10344, 0, -14084, 0, -10343, 0, -14083, 0, -10341, 0, -14082, 0, -10339, 0, -13919, 0, -8192, 0, -13918, 0, -8191, 0, -13917, 0, -8190, 0, -13916, 0, -8189, 0, -13915, 0, -8188, 0, -13914, 0, -8187, 0, -13913, 0, -8186, 0, -13912, 0, -8185, 0, -13911, 0, -8184, 0, -13910, 0, -8183, 0, -13909, 0, -8182, 0, -13908, 0, -8181, 0, -13907, 0, -8180, 0, -13906, 0, -8179, 0, -13905, 0, -8178, 0, -13904, 0, -8177, 0, -13903, 0, -8176, 0, -13902, 0, -8175, 0, -13901, 0, -8174, 0, -13900, 0, -8173, 0, -13899, 0, -8172, 0, -13898, 0, -8171, 0, -13897, 0, -8170, 0, -13896, 0, -8169, 0, -13895, 0, -8168, 0, -13894, 0, -8167, 0, -13893, 0, -8166, 0, -13892, 0, -8165, 0, -13891, 0, -8164, 0, -13890, 0, -8163, 0, -13889, 0, -8162, 0, -13888, 0, -8161, 0, -13887, 0, -8160, 0, -13886, 0, -8159, 0, -13885, 0, -8158, 0, -13884, 0, -8157, 0, -13883, 0, -8156, 0, -13882, 0, -8155, 0, -13881, 0, -8154, 0, -13880, 0, -8153, 0, -13879, 0, -8152, 0, -13878, 0, -8151, 0, -13877, 0, -8150, 0, -13876, 0, -8149, 0, -13875, 0, -8148, 0, -13874, 0, -8147, 0, -13873, 0, -8146, 0, -13872, 0, -8145, 0, -13871, 0, -8144, 0, -13870, 0, -8143, 0, -13869, 0, -8142, 0, -13868, 0, -8141, 0, -13867, 0, -8140, 0, -13866, 0, -8139, 0, -13865, 0, -8138, 0, -13864, 0, -8137, 0, -13863, 0, -8136, 0, -13862, 0, -8135, 0, -13861, 0, -8134, 0, -13860, 0, -8133, 0, -13859, 0, -8132, 0, -13858, 0, -8131, 0, -13857, 0, -8130, 0, -13856, 0, -8129, 0, -13855, 0, -8128, 0, -13854, 0, -8127, 0, -13853, 0, -8126, 0, -13852, 0, -8125, 0, -13851, 0, -8124, 0, -13850, 0, -8123, 0, -13849, 0, -8122, 0, -13848, 0, -8121, 0, -13847, 0, -8120, 0, -13846, 0, -8119, 0, -13845, 0, -8118, 0, -13844, 0, -8117, 0, -13843, 0, -8116, 0, -13842, 0, -8115, 0, -13841, 0, -8114, 0, -13840, 0, -8113, 0, -13839, 0, -8112, 0, -13838, 0, -8111, 0, -13837, 0, -8110, 0, -13836, 0, -8109, 0, -13835, 0, -8108, 0, -13834, 0, -8107, 0, -13833, 0, -8106, 0, -13832, 0, -8105, 0, -13831, 0, -8104, 0, -13830, 0, -8103, 0, -13829, 0, -8102, 0, -13828, 0, -8101, 0, -13827, 0, -8100, 0, -13826, 0, -8099, 0, -13663, 0, 20285, 0, -13662, 0, 20339, 0, -13661, 0, 20551, 0, -13660, 0, 20729, 0, -13659, 0, 21152, 0, -13658, 0, 21487, 0, -13657, 0, 21621, 0, -13656, 0, 21733, 0, -13655, 0, 22025, 0, -13654, 0, 23233, 0, -13653, 0, 23478, 0, -13652, 0, 26247, 0, -13651, 0, 26550, 0, -13650, 0, 26551, 0, -13649, 0, 26607, 0, -13648, 0, 27468, 0, -13647, 0, 29634, 0, -13646, 0, 30146, 0, -13645, 0, 31292, 0, -13644, 0, -32037, 0, -13643, 0, -31996, 0, -13642, 0, -30633, 0, -13641, 0, -30584, 0, -13640, 0, -30154, 0, -13639, 0, -29496, 0, -13638, 0, -29233, 0, -13637, 0, -28933, 0, -13636, 0, -28698, 0, -13635, 0, -26155, 0, -13634, 0, 21051, 0, -13633, 0, 21364, 0, -13632, 0, 21508, 0, -13631, 0, 24682, 0, -13630, 0, 24932, 0, -13629, 0, 27580, 0, -13628, 0, 29647, 0, -13627, 0, -32486, 0, -13626, 0, -30278, 0, -13625, 0, -30254, 0, -13624, 0, -27229, 0, -13623, 0, 20355, 0, -13622, 0, 21002, 0, -13621, 0, 22718, 0, -13620, 0, 22904, 0, -13619, 0, 23014, 0, -13618, 0, 24178, 0, -13617, 0, 24185, 0, -13616, 0, 25031, 0, -13615, 0, 25536, 0, -13614, 0, 26438, 0, -13613, 0, 26604, 0, -13612, 0, 26751, 0, -13611, 0, 28567, 0, -13610, 0, 30286, 0, -13609, 0, 30475, 0, -13608, 0, 30965, 0, -13607, 0, 31240, 0, -13606, 0, 31487, 0, -13605, 0, 31777, 0, -13604, 0, -32611, 0, -13603, 0, -32146, 0, -13602, 0, -32143, 0, -13601, 0, -29973, 0, -13600, 0, -27245, 0, -13599, 0, 20075, 0, -13598, 0, 21917, 0, -13597, 0, 26359, 0, -13596, 0, 28212, 0, -13595, 0, 30883, 0, -13594, 0, 31469, 0, -13593, 0, -31653, 0, -13592, 0, -30448, 0, -13591, 0, -30898, 0, -13590, 0, -26712, 0, -13589, 0, 21208, 0, -13588, 0, 22350, 0, -13587, 0, 22570, 0, -13586, 0, 23884, 0, -13585, 0, 24863, 0, -13584, 0, 25022, 0, -13583, 0, 25121, 0, -13582, 0, 25954, 0, -13581, 0, 26577, 0, -13580, 0, 27204, 0, -13579, 0, 28187, 0, -13578, 0, 29976, 0, -13577, 0, 30131, 0, -13576, 0, 30435, 0, -13575, 0, 30640, 0, -13574, 0, 32058, 0, -13573, 0, -28497, 0, -13572, 0, -27567, 0, -13571, 0, -27566, 0, -13570, 0, -24683, 0, -13407, 0, 21283, 0, -13406, 0, 23724, 0, -13405, 0, 30002, 0, -13404, 0, -32549, 0, -13403, 0, -28096, 0, -13402, 0, -27240, 0, -13401, 0, 21083, 0, -13400, 0, 22536, 0, -13399, 0, 23004, 0, -13398, 0, 23713, 0, -13397, 0, 23831, 0, -13396, 0, 24247, 0, -13395, 0, 24378, 0, -13394, 0, 24394, 0, -13393, 0, 24951, 0, -13392, 0, 27743, 0, -13391, 0, 30074, 0, -13390, 0, 30086, 0, -13389, 0, 31968, 0, -13388, 0, 32115, 0, -13387, 0, 32177, 0, -13386, 0, 32652, 0, -13385, 0, -32428, 0, -13384, 0, -32223, 0, -13383, 0, -31343, 0, -13382, 0, -30399, 0, -13381, 0, -29925, 0, -13380, 0, -27908, 0, -13379, 0, -27059, 0, -13378, 0, -25529, 0, -13377, 0, 20171, 0, -13376, 0, 20215, 0, -13375, 0, 20491, 0, -13374, 0, 20977, 0, -13373, 0, 22607, 0, -13372, 0, 24887, 0, -13371, 0, 24894, 0, -13370, 0, 24936, 0, -13369, 0, 25913, 0, -13368, 0, 27114, 0, -13367, 0, 28433, 0, -13366, 0, 30117, 0, -13365, 0, 30342, 0, -13364, 0, 30422, 0, -13363, 0, 31623, 0, -13362, 0, -32091, 0, -13361, 0, -31541, 0, -13360, 0, -1792, 0, -13359, 0, -27737, 0, -13358, 0, -27253, 0, -13357, 0, 21888, 0, -13356, 0, 23458, 0, -13355, 0, 22353, 0, -13354, 0, -1791, 0, -13353, 0, 31923, 0, -13352, 0, 32697, 0, -13351, 0, -28235, 0, -13350, 0, 20520, 0, -13349, 0, 21435, 0, -13348, 0, 23621, 0, -13347, 0, 24040, 0, -13346, 0, 25298, 0, -13345, 0, 25454, 0, -13344, 0, 25818, 0, -13343, 0, 25831, 0, -13342, 0, 28192, 0, -13341, 0, 28844, 0, -13340, 0, 31067, 0, -13339, 0, -29219, 0, -13338, 0, -29154, 0, -13337, 0, -1790, 0, -13336, 0, -28547, 0, -13335, 0, -28091, 0, -13334, 0, -27912, 0, -13333, 0, 20094, 0, -13332, 0, 20214, 0, -13331, 0, 20581, 0, -13330, 0, 24062, 0, -13329, 0, 24314, 0, -13328, 0, 24838, 0, -13327, 0, 26967, 0, -13326, 0, -32399, 0, -13325, 0, -31148, 0, -13324, 0, -29113, 0, -13323, 0, -27787, 0, -13322, 0, -26069, 0, -13321, 0, 20062, 0, -13320, 0, 20625, 0, -13319, 0, 26480, 0, -13318, 0, 26688, 0, -13317, 0, 20745, 0, -13316, 0, 21133, 0, -13315, 0, 21138, 0, -13314, 0, 27298, 0, -13151, 0, 30652, 0, -13150, 0, -28144, 0, -13149, 0, -24876, 0, -13148, 0, 21163, 0, -13147, 0, 24623, 0, -13146, 0, -28686, 0, -13145, 0, 20552, 0, -13144, 0, 25001, 0, -13143, 0, 25581, 0, -13142, 0, 25802, 0, -13141, 0, 26684, 0, -13140, 0, 27268, 0, -13139, 0, 28608, 0, -13138, 0, -32376, 0, -13137, 0, -30303, 0, -13136, 0, -26988, 0, -13135, 0, 22533, 0, -13134, 0, 29309, 0, -13133, 0, 29356, 0, -13132, 0, 29956, 0, -13131, 0, 32121, 0, -13130, 0, 32365, 0, -13129, 0, -32599, 0, -13128, 0, -30325, 0, -13127, 0, -29836, 0, -13126, 0, -28573, 0, -13125, 0, -25263, 0, -13124, 0, 25225, 0, -13123, 0, 27770, 0, -13122, 0, 28500, 0, -13121, 0, 32080, 0, -13120, 0, 32570, 0, -13119, 0, -30173, 0, -13118, 0, 20860, 0, -13117, 0, 24906, 0, -13116, 0, 31645, 0, -13115, 0, -29927, 0, -13114, 0, -28073, 0, -13113, 0, -27764, 0, -13112, 0, 20140, 0, -13111, 0, 20435, 0, -13110, 0, 20510, 0, -13109, 0, 20670, 0, -13108, 0, 20742, 0, -13107, 0, 21185, 0, -13106, 0, 21197, 0, -13105, 0, 21375, 0, -13104, 0, 22384, 0, -13103, 0, 22659, 0, -13102, 0, 24218, 0, -13101, 0, 24465, 0, -13100, 0, 24950, 0, -13099, 0, 25004, 0, -13098, 0, 25806, 0, -13097, 0, 25964, 0, -13096, 0, 26223, 0, -13095, 0, 26299, 0, -13094, 0, 26356, 0, -13093, 0, 26775, 0, -13092, 0, 28039, 0, -13091, 0, 28805, 0, -13090, 0, 28913, 0, -13089, 0, 29855, 0, -13088, 0, 29861, 0, -13087, 0, 29898, 0, -13086, 0, 30169, 0, -13085, 0, 30828, 0, -13084, 0, 30956, 0, -13083, 0, 31455, 0, -13082, 0, 31478, 0, -13081, 0, 32069, 0, -13080, 0, 32147, 0, -13079, 0, -32747, 0, -13078, 0, -32705, 0, -13077, 0, -32485, 0, -13076, 0, -31850, 0, -13075, 0, -29850, 0, -13074, 0, -28907, 0, -13073, 0, -28651, 0, -13072, 0, -27679, 0, -13071, 0, -26621, 0, -13070, 0, -26568, 0, -13069, 0, -26022, 0, -13068, 0, -25624, 0, -13067, 0, 20418, 0, -13066, 0, 21843, 0, -13065, 0, 22586, 0, -13064, 0, 22865, 0, -13063, 0, 23395, 0, -13062, 0, 23622, 0, -13061, 0, 24760, 0, -13060, 0, 25106, 0, -13059, 0, 26690, 0, -13058, 0, 26800, 0, -12895, 0, 26856, 0, -12894, 0, 28330, 0, -12893, 0, 30028, 0, -12892, 0, 30328, 0, -12891, 0, 30926, 0, -12890, 0, 31293, 0, -12889, 0, 31995, 0, -12888, 0, 32363, 0, -12887, 0, 32380, 0, -12886, 0, -30200, 0, -12885, 0, -30047, 0, -12884, 0, -29633, 0, -12883, 0, -26994, 0, -12882, 0, -25148, 0, -12881, 0, 21476, 0, -12880, 0, 21481, 0, -12879, 0, 21578, 0, -12878, 0, 21617, 0, -12877, 0, 22266, 0, -12876, 0, 22993, 0, -12875, 0, 23396, 0, -12874, 0, 23611, 0, -12873, 0, 24235, 0, -12872, 0, 25335, 0, -12871, 0, 25911, 0, -12870, 0, 25925, 0, -12869, 0, 25970, 0, -12868, 0, 26272, 0, -12867, 0, 26543, 0, -12866, 0, 27073, 0, -12865, 0, 27837, 0, -12864, 0, 30204, 0, -12863, 0, 30352, 0, -12862, 0, 30590, 0, -12861, 0, 31295, 0, -12860, 0, 32660, 0, -12859, 0, -32765, 0, -12858, 0, -32607, 0, -12857, 0, -32369, 0, -12856, 0, -32026, 0, -12855, 0, -32003, 0, -12854, 0, -31760, 0, -12853, 0, -31295, 0, -12852, 0, -30671, 0, -12851, 0, -30540, 0, -12850, 0, -30043, 0, -12849, 0, -1789, 0, -12848, 0, -28772, 0, -12847, 0, -27858, 0, -12846, 0, -26937, 0, -12845, 0, -26521, 0, -12844, 0, -25896, 0, -12843, 0, -24813, 0, -12842, 0, 21741, 0, -12841, 0, 26011, 0, -12840, 0, 26354, 0, -12839, 0, 26767, 0, -12838, 0, 31296, 0, -12837, 0, -29641, 0, -12836, 0, -25248, 0, -12835, 0, 22256, 0, -12834, 0, 22372, 0, -12833, 0, 23825, 0, -12832, 0, 26118, 0, -12831, 0, 26801, 0, -12830, 0, 26829, 0, -12829, 0, 28414, 0, -12828, 0, 29736, 0, -12827, 0, -30562, 0, -12826, 0, -25628, 0, -12825, 0, 27752, 0, -12824, 0, -1788, 0, -12823, 0, -25944, 0, -12822, 0, 20379, 0, -12821, 0, 20844, 0, -12820, 0, 20849, 0, -12819, 0, 21151, 0, -12818, 0, 23380, 0, -12817, 0, 24037, 0, -12816, 0, 24656, 0, -12815, 0, 24685, 0, -12814, 0, 25329, 0, -12813, 0, 25511, 0, -12812, 0, 25915, 0, -12811, 0, 29657, 0, -12810, 0, 31354, 0, -12809, 0, -31069, 0, -12808, 0, -29534, 0, -12807, 0, -26737, 0, -12806, 0, 20018, 0, -12805, 0, 23521, 0, -12804, 0, 25096, 0, -12803, 0, 26524, 0, -12802, 0, 29916, 0, -12639, 0, 31185, 0, -12638, 0, -31789, 0, -12637, 0, -30073, 0, -12636, 0, -30030, 0, -12635, 0, -29208, 0, -12634, 0, -28594, 0, -12633, 0, -27829, 0, -12632, 0, -26554, 0, -12631, 0, 24275, 0, -12630, 0, 27112, 0, -12629, 0, -31233, 0, -12628, 0, -28435, 0, -12627, 0, -1787, 0, -12626, 0, 20896, 0, -12625, 0, 23448, 0, -12624, 0, 23532, 0, -12623, 0, 24931, 0, -12622, 0, 26874, 0, -12621, 0, 27454, 0, -12620, 0, 28748, 0, -12619, 0, 29743, 0, -12618, 0, 29912, 0, -12617, 0, 31649, 0, -12616, 0, 32592, 0, -12615, 0, -31803, 0, -12614, 0, -30272, 0, -12613, 0, -29525, 0, -12612, 0, -27172, 0, -12611, 0, -26328, 0, -12610, 0, 21038, 0, -12609, 0, 24669, 0, -12608, 0, 25324, 0, -12607, 0, -28670, 0, -12606, 0, 20362, 0, -12605, 0, 20809, 0, -12604, 0, 21281, 0, -12603, 0, 22745, 0, -12602, 0, 24291, 0, -12601, 0, 26336, 0, -12600, 0, 27960, 0, -12599, 0, 28826, 0, -12598, 0, 29378, 0, -12597, 0, 29654, 0, -12596, 0, 31568, 0, -12595, 0, -32527, 0, -12594, 0, -27557, 0, -12593, 0, 21350, 0, -12592, 0, 25499, 0, -12591, 0, 32619, 0, -12590, 0, 20054, 0, -12589, 0, 20608, 0, -12588, 0, 22602, 0, -12587, 0, 22750, 0, -12586, 0, 24618, 0, -12585, 0, 24871, 0, -12584, 0, 25296, 0, -12583, 0, 27088, 0, -12582, 0, -25791, 0, -12581, 0, 23439, 0, -12580, 0, 32024, 0, -12579, 0, -32591, 0, -12578, 0, -28833, 0, -12577, 0, 20132, 0, -12576, 0, 20689, 0, -12575, 0, 21676, 0, -12574, 0, 21932, 0, -12573, 0, 23308, 0, -12572, 0, 23968, 0, -12571, 0, 24039, 0, -12570, 0, 25898, 0, -12569, 0, 25934, 0, -12568, 0, 26657, 0, -12567, 0, 27211, 0, -12566, 0, 29409, 0, -12565, 0, 30350, 0, -12564, 0, 30703, 0, -12563, 0, 32094, 0, -12562, 0, 32761, 0, -12561, 0, -32352, 0, -12560, 0, -31410, 0, -12559, 0, -31009, 0, -12558, 0, -28925, 0, -12557, 0, -28850, 0, -12556, 0, -28470, 0, -12555, 0, -26365, 0, -12554, 0, -26027, 0, -12553, 0, -25685, 0, -12552, 0, 19992, 0, -12551, 0, 20037, 0, -12550, 0, 20061, 0, -12549, 0, 20167, 0, -12548, 0, 20465, 0, -12547, 0, 20855, 0, -12546, 0, 21246, 0, -12383, 0, 21312, 0, -12382, 0, 21475, 0, -12381, 0, 21477, 0, -12380, 0, 21646, 0, -12379, 0, 22036, 0, -12378, 0, 22389, 0, -12377, 0, 22434, 0, -12376, 0, 23495, 0, -12375, 0, 23943, 0, -12374, 0, 24272, 0, -12373, 0, 25084, 0, -12372, 0, 25304, 0, -12371, 0, 25937, 0, -12370, 0, 26552, 0, -12369, 0, 26601, 0, -12368, 0, 27083, 0, -12367, 0, 27472, 0, -12366, 0, 27590, 0, -12365, 0, 27628, 0, -12364, 0, 27714, 0, -12363, 0, 28317, 0, -12362, 0, 28792, 0, -12361, 0, 29399, 0, -12360, 0, 29590, 0, -12359, 0, 29699, 0, -12358, 0, 30655, 0, -12357, 0, 30697, 0, -12356, 0, 31350, 0, -12355, 0, 32127, 0, -12354, 0, -32759, 0, -12353, 0, -32260, 0, -12352, 0, -32251, 0, -12351, 0, -32246, 0, -12350, 0, -32033, 0, -12349, 0, -30622, 0, -12348, 0, -29901, 0, -12347, 0, -29444, 0, -12346, 0, -28992, 0, -12345, 0, -28655, 0, -12344, 0, -28495, 0, -12343, 0, -28060, 0, -12342, 0, -27978, 0, -12341, 0, -26158, 0, -12340, 0, -26043, 0, -12339, 0, -25367, 0, -12338, 0, -25129, 0, -12337, 0, -24676, 0, -12336, 0, 22283, 0, -12335, 0, 23616, 0, -12334, 0, -31798, 0, -12333, 0, -26720, 0, -12332, 0, -26709, 0, -12331, 0, -24908, 0, -12330, 0, 21531, 0, -12329, 0, 31384, 0, -12328, 0, 32676, 0, -12327, 0, -30503, 0, -12326, 0, -28979, 0, -12325, 0, -28447, 0, -12324, 0, 22528, 0, -12323, 0, 23624, 0, -12322, 0, 25496, 0, -12321, 0, 31391, 0, -12320, 0, 23470, 0, -12319, 0, 24339, 0, -12318, 0, 31353, 0, -12317, 0, 31406, 0, -12316, 0, -32114, 0, -12315, 0, -29012, 0, -12314, 0, 20518, 0, -12313, 0, 21048, 0, -12312, 0, 21240, 0, -12311, 0, 21367, 0, -12310, 0, 22280, 0, -12309, 0, 25331, 0, -12308, 0, 25458, 0, -12307, 0, 27402, 0, -12306, 0, 28099, 0, -12305, 0, 30519, 0, -12304, 0, 21413, 0, -12303, 0, 29527, 0, -12302, 0, -31384, 0, -12301, 0, -29066, 0, -12300, 0, -27179, 0, -12299, 0, 26426, 0, -12298, 0, 27331, 0, -12297, 0, 28528, 0, -12296, 0, -30099, 0, -12295, 0, -28980, 0, -12294, 0, -26293, 0, -12293, 0, -1786, 0, -12292, 0, 26231, 0, -12291, 0, 27512, 0, -12290, 0, -29516, 0, -12127, 0, -25796, 0, -12126, 0, -1785, 0, -12125, 0, 21483, 0, -12124, 0, 22317, 0, -12123, 0, 22862, 0, -12122, 0, 25542, 0, -12121, 0, 27131, 0, -12120, 0, 29674, 0, -12119, 0, 30789, 0, -12118, 0, 31418, 0, -12117, 0, 31429, 0, -12116, 0, 31998, 0, -12115, 0, -31627, 0, -12114, 0, -30321, 0, -12113, 0, -29325, 0, -12112, 0, -28619, 0, -12111, 0, -27224, 0, -12110, 0, 21243, 0, -12109, 0, 22343, 0, -12108, 0, 30023, 0, -12107, 0, 31584, 0, -12106, 0, -31796, 0, -12105, 0, -28130, 0, -12104, 0, -1784, 0, -12103, 0, 27224, 0, -12102, 0, 20811, 0, -12101, 0, 21067, 0, -12100, 0, 21127, 0, -12099, 0, 25119, 0, -12098, 0, 26840, 0, -12097, 0, 26997, 0, -12096, 0, -26983, 0, -12095, 0, 20677, 0, -12094, 0, 21156, 0, -12093, 0, 21220, 0, -12092, 0, 25027, 0, -12091, 0, 26020, 0, -12090, 0, 26681, 0, -12089, 0, 27135, 0, -12088, 0, 29822, 0, -12087, 0, 31563, 0, -12086, 0, -32071, 0, -12085, 0, -31765, 0, -12084, 0, -30286, 0, -12083, 0, -29895, 0, -12082, 0, -28719, 0, -12081, 0, -26295, 0, -12080, 0, -1783, 0, -12079, 0, 20170, 0, -12078, 0, 22935, 0, -12077, 0, 25810, 0, -12076, 0, 26129, 0, -12075, 0, 27278, 0, -12074, 0, 29748, 0, -12073, 0, 31105, 0, -12072, 0, 31165, 0, -12071, 0, -32087, 0, -12070, 0, -30594, 0, -12069, 0, -30593, 0, -12068, 0, -30369, 0, -12067, 0, -1782, 0, -12066, 0, -27866, 0, -12065, 0, 20235, 0, -12064, 0, 21450, 0, -12063, 0, 24613, 0, -12062, 0, 25201, 0, -12061, 0, 27762, 0, -12060, 0, 32026, 0, -12059, 0, 32102, 0, -12058, 0, 20120, 0, -12057, 0, 20834, 0, -12056, 0, 30684, 0, -12055, 0, -32593, 0, -12054, 0, 20225, 0, -12053, 0, 20238, 0, -12052, 0, 20854, 0, -12051, 0, 20864, 0, -12050, 0, 21980, 0, -12049, 0, 22120, 0, -12048, 0, 22331, 0, -12047, 0, 22522, 0, -12046, 0, 22524, 0, -12045, 0, 22804, 0, -12044, 0, 22855, 0, -12043, 0, 22931, 0, -12042, 0, 23492, 0, -12041, 0, 23696, 0, -12040, 0, 23822, 0, -12039, 0, 24049, 0, -12038, 0, 24190, 0, -12037, 0, 24524, 0, -12036, 0, 25216, 0, -12035, 0, 26071, 0, -12034, 0, 26083, 0, -11871, 0, 26398, 0, -11870, 0, 26399, 0, -11869, 0, 26462, 0, -11868, 0, 26827, 0, -11867, 0, 26820, 0, -11866, 0, 27231, 0, -11865, 0, 27450, 0, -11864, 0, 27683, 0, -11863, 0, 27773, 0, -11862, 0, 27778, 0, -11861, 0, 28103, 0, -11860, 0, 29592, 0, -11859, 0, 29734, 0, -11858, 0, 29738, 0, -11857, 0, 29826, 0, -11856, 0, 29859, 0, -11855, 0, 30072, 0, -11854, 0, 30079, 0, -11853, 0, 30849, 0, -11852, 0, 30959, 0, -11851, 0, 31041, 0, -11850, 0, 31047, 0, -11849, 0, 31048, 0, -11848, 0, 31098, 0, -11847, 0, 31637, 0, -11846, 0, 32000, 0, -11845, 0, 32186, 0, -11844, 0, 32648, 0, -11843, 0, -32762, 0, -11842, 0, -32723, 0, -11841, 0, -32628, 0, -11840, 0, -30184, 0, -11839, 0, -29873, 0, -11838, 0, -29624, 0, -11837, 0, -29321, 0, -11836, 0, -27871, 0, -11835, 0, -27868, 0, -11834, 0, -26398, 0, -11833, 0, -26287, 0, -11832, 0, -26098, 0, -11831, 0, -26097, 0, -11830, 0, -26011, 0, -11829, 0, -24942, 0, -11828, 0, 32202, 0, -11827, 0, 20342, 0, -11826, 0, 21513, 0, -11825, 0, 25326, 0, -11824, 0, 26708, 0, -11823, 0, -28207, 0, -11822, 0, 21931, 0, -11821, 0, 20794, 0, -11820, 0, -1781, 0, -11819, 0, -1780, 0, -11818, 0, 23068, 0, -11817, 0, 25062, 0, -11816, 0, -1779, 0, -11815, 0, 25295, 0, -11814, 0, 25343, 0, -11813, 0, -1778, 0, -11812, 0, -1777, 0, -11811, 0, -1776, 0, -11810, 0, -1775, 0, -11809, 0, -1774, 0, -11808, 0, -1773, 0, -11807, 0, -28509, 0, -11806, 0, -1772, 0, -11805, 0, -1771, 0, -11804, 0, -1770, 0, -11803, 0, -1769, 0, -11802, 0, -1768, 0, -11801, 0, -29954, 0, -11800, 0, -1767, 0, -11799, 0, -1766, 0, -11798, 0, -1765, 0, -11797, 0, -1764, 0, -11796, 0, 26262, 0, -11795, 0, -1763, 0, -11794, 0, 29014, 0, -11793, 0, -1762, 0, -11792, 0, -1761, 0, -11791, 0, -26909, 0, -11790, 0, -1760, 0, -11789, 0, 25423, 0, -11788, 0, 25466, 0, -11787, 0, 21335, 0, -11786, 0, -1759, 0, -11785, 0, 26511, 0, -11784, 0, 26976, 0, -11783, 0, 28275, 0, -11782, 0, -1758, 0, -11781, 0, 30007, 0, -11780, 0, -1757, 0, -11779, 0, -1756, 0, -11778, 0, -1755, 0, -11615, 0, 32013, 0, -11614, 0, -1754, 0, -11613, 0, -1753, 0, -11612, 0, -30606, 0, -11611, 0, 22218, 0, -11610, 0, 23064, 0, -11609, 0, -1752, 0, -11608, 0, -1751, 0, -11607, 0, -1750, 0, -11606, 0, -1749, 0, -11605, 0, -1748, 0, -11604, 0, 20035, 0, -11603, 0, -1747, 0, -11602, 0, 20839, 0, -11601, 0, 22856, 0, -11600, 0, 26608, 0, -11599, 0, -32752, 0, -11598, 0, -1746, 0, -11597, 0, 22899, 0, -11596, 0, 24180, 0, -11595, 0, 25754, 0, -11594, 0, 31178, 0, -11593, 0, 24565, 0, -11592, 0, 24684, 0, -11591, 0, 25288, 0, -11590, 0, 25467, 0, -11589, 0, 23527, 0, -11588, 0, 23511, 0, -11587, 0, 21162, 0, -11586, 0, -1745, 0, -11585, 0, 22900, 0, -11584, 0, 24361, 0, -11583, 0, 24594, 0, -11582, 0, -1744, 0, -11581, 0, -1743, 0, -11580, 0, -1742, 0, -11579, 0, 29785, 0, -11578, 0, -1741, 0, -11577, 0, -1740, 0, -11576, 0, -1739, 0, -11575, 0, -1738, 0, -11574, 0, -1737, 0, -11573, 0, -1736, 0, -11572, 0, -26159, 0, -11571, 0, -1735, 0, -11570, 0, -1734, 0, -11569, 0, -1733, 0, -11568, 0, -1732, 0, -11567, 0, -1731, 0, -11566, 0, -1730, 0, -11565, 0, -1729, 0, -11564, 0, -1728, 0, -11563, 0, -1727, 0, -11562, 0, -1726, 0, -11561, 0, -1725, 0, -11560, 0, 28611, 0, -11559, 0, -1724, 0, -11558, 0, -1723, 0, -11557, 0, -32321, 0, -11556, 0, -28750, 0, -11555, 0, 24817, 0, -11554, 0, -1722, 0, -11553, 0, -1721, 0, -11552, 0, -32410, 0, -11551, 0, -1720, 0, -11550, 0, -1719, 0, -11549, 0, 23615, 0, -11548, 0, -1718, 0, -11547, 0, -1717, 0, -11546, 0, -1716, 0, -11545, 0, -1715, 0, -11544, 0, -1714, 0, -11543, 0, -1713, 0, -11542, 0, -1712, 0, -11541, 0, -1711, 0, -11540, 0, 23273, 0, -11539, 0, -30171, 0, -11538, 0, 26491, 0, -11537, 0, 32016, 0, -11536, 0, -1710, 0, -11535, 0, -1709, 0, -11534, 0, -1708, 0, -11533, 0, -1707, 0, -11532, 0, -1706, 0, -11531, 0, -1705, 0, -11530, 0, -32515, 0, -11529, 0, -1704, 0, -11528, 0, -1703, 0, -11527, 0, 23612, 0, -11526, 0, 27877, 0, -11525, 0, 21311, 0, -11524, 0, 28346, 0, -11523, 0, 22810, 0, -11522, 0, -31946, 0, -11359, 0, 20025, 0, -11358, 0, 20150, 0, -11357, 0, 20294, 0, -11356, 0, 21934, 0, -11355, 0, 22296, 0, -11354, 0, 22727, 0, -11353, 0, 24406, 0, -11352, 0, 26039, 0, -11351, 0, 26086, 0, -11350, 0, 27264, 0, -11349, 0, 27573, 0, -11348, 0, 28237, 0, -11347, 0, 30701, 0, -11346, 0, 31471, 0, -11345, 0, 31774, 0, -11344, 0, 32222, 0, -11343, 0, -31029, 0, -11342, 0, -30574, 0, -11341, 0, -28366, 0, -11340, 0, -27813, 0, -11339, 0, 25787, 0, -11338, 0, 28606, 0, -11337, 0, 29562, 0, -11336, 0, 30136, 0, -11335, 0, -28588, 0, -11334, 0, 21846, 0, -11333, 0, 22349, 0, -11332, 0, 25018, 0, -11331, 0, 25812, 0, -11330, 0, 26311, 0, -11329, 0, 28129, 0, -11328, 0, 28251, 0, -11327, 0, 28525, 0, -11326, 0, 28601, 0, -11325, 0, 30192, 0, -11324, 0, -32701, 0, -11323, 0, -32323, 0, -11322, 0, -31423, 0, -11321, 0, -30333, 0, -11320, 0, -30009, 0, -11319, 0, -29862, 0, -11318, 0, -27873, 0, -11317, 0, 27795, 0, -11316, 0, 30035, 0, -11315, 0, 31572, 0, -11314, 0, -29169, 0, -11313, 0, -28579, 0, -11312, 0, 21776, 0, -11311, 0, 22530, 0, -11310, 0, 22616, 0, -11309, 0, 24162, 0, -11308, 0, 25095, 0, -11307, 0, 25758, 0, -11306, 0, 26848, 0, -11305, 0, 30070, 0, -11304, 0, 31958, 0, -11303, 0, -30797, 0, -11302, 0, -24856, 0, -11301, 0, 20195, 0, -11300, 0, 22408, 0, -11299, 0, 22382, 0, -11298, 0, 22823, 0, -11297, 0, 23565, 0, -11296, 0, 23729, 0, -11295, 0, 24118, 0, -11294, 0, 24453, 0, -11293, 0, 25140, 0, -11292, 0, 25825, 0, -11291, 0, 29619, 0, -11290, 0, -32262, 0, -11289, 0, -30581, 0, -11288, 0, -29512, 0, -11287, 0, -26998, 0, -11286, 0, -24869, 0, -11285, 0, 23429, 0, -11284, 0, 24503, 0, -11283, 0, 24755, 0, -11282, 0, 20498, 0, -11281, 0, 20992, 0, -11280, 0, 21040, 0, -11279, 0, 22294, 0, -11278, 0, 22581, 0, -11277, 0, 22615, 0, -11276, 0, 23566, 0, -11275, 0, 23648, 0, -11274, 0, 23798, 0, -11273, 0, 23947, 0, -11272, 0, 24230, 0, -11271, 0, 24466, 0, -11270, 0, 24764, 0, -11269, 0, 25361, 0, -11268, 0, 25481, 0, -11267, 0, 25623, 0, -11266, 0, 26691, 0, -11103, 0, 26873, 0, -11102, 0, 27330, 0, -11101, 0, 28120, 0, -11100, 0, 28193, 0, -11099, 0, 28372, 0, -11098, 0, 28644, 0, -11097, 0, 29182, 0, -11096, 0, 30428, 0, -11095, 0, 30585, 0, -11094, 0, 31153, 0, -11093, 0, 31291, 0, -11092, 0, -31740, 0, -11091, 0, -30295, 0, -11090, 0, -29459, 0, -11089, 0, -29197, 0, -11088, 0, -29112, 0, -11087, 0, -28669, 0, -11086, 0, -28652, 0, -11085, 0, -28589, 0, -11084, 0, -28419, 0, -11083, 0, -27827, 0, -11082, 0, -27018, 0, -11081, 0, -26660, 0, -11080, 0, 27602, 0, -11079, 0, 28678, 0, -11078, 0, 29272, 0, -11077, 0, 29346, 0, -11076, 0, 29544, 0, -11075, 0, 30563, 0, -11074, 0, 31167, 0, -11073, 0, 31716, 0, -11072, 0, 32411, 0, -11071, 0, -29824, 0, -11070, 0, 22697, 0, -11069, 0, 24775, 0, -11068, 0, 25958, 0, -11067, 0, 26109, 0, -11066, 0, 26302, 0, -11065, 0, 27788, 0, -11064, 0, 28958, 0, -11063, 0, 29129, 0, -11062, 0, -29606, 0, -11061, 0, -26605, 0, -11060, 0, 20077, 0, -11059, 0, 31361, 0, -11058, 0, 20189, 0, -11057, 0, 20908, 0, -11056, 0, 20941, 0, -11055, 0, 21205, 0, -11054, 0, 21516, 0, -11053, 0, 24999, 0, -11052, 0, 26481, 0, -11051, 0, 26704, 0, -11050, 0, 26847, 0, -11049, 0, 27934, 0, -11048, 0, 28540, 0, -11047, 0, 30140, 0, -11046, 0, 30643, 0, -11045, 0, 31461, 0, -11044, 0, -32524, 0, -11043, 0, -31645, 0, -11042, 0, -28027, 0, -11041, 0, 20828, 0, -11040, 0, 26007, 0, -11039, 0, 26460, 0, -11038, 0, 26515, 0, -11037, 0, 30168, 0, -11036, 0, 31431, 0, -11035, 0, -31885, 0, -11034, 0, -1702, 0, -11033, 0, -29626, 0, -11032, 0, -28649, 0, -11031, 0, -26579, 0, -11030, 0, 23663, 0, -11029, 0, -32320, 0, -11028, 0, -32102, 0, -11027, 0, -28607, 0, -11026, 0, -28561, 0, -11025, 0, -28147, 0, -11024, 0, 24471, 0, -11023, 0, 23965, 0, -11022, 0, 27225, 0, -11021, 0, 29128, 0, -11020, 0, 30331, 0, -11019, 0, 31561, 0, -11018, 0, -31260, 0, -11017, 0, -29948, 0, -11016, 0, -28377, 0, -11015, 0, -26064, 0, -11014, 0, 21895, 0, -11013, 0, 25078, 0, -11012, 0, -1701, 0, -11011, 0, 30313, 0, -11010, 0, 32645, 0, -10847, 0, -31169, 0, -10846, 0, -30790, 0, -10845, 0, -30472, 0, -10844, 0, -28529, 0, -10843, 0, -1700, 0, -10842, 0, 27931, 0, -10841, 0, 28889, 0, -10840, 0, 29662, 0, -10839, 0, 32097, 0, -10838, 0, -31683, 0, -10837, 0, -1699, 0, -10836, 0, -28310, 0, -10835, 0, -26127, 0, -10834, 0, -1698, 0, -10833, 0, 20098, 0, -10832, 0, 21365, 0, -10831, 0, 27396, 0, -10830, 0, 27410, 0, -10829, 0, 28734, 0, -10828, 0, 29211, 0, -10827, 0, -31187, 0, -10826, 0, -25058, 0, -10825, 0, 21068, 0, -10824, 0, -28765, 0, -10823, 0, 23888, 0, -10822, 0, 25829, 0, -10821, 0, 25900, 0, -10820, 0, 27414, 0, -10819, 0, 28651, 0, -10818, 0, 31811, 0, -10817, 0, 32412, 0, -10816, 0, -31283, 0, -10815, 0, -30364, 0, -10814, 0, -30275, 0, -10813, 0, 25289, 0, -10812, 0, -32296, 0, -10811, 0, -30689, 0, -10810, 0, 24266, 0, -10809, 0, 26391, 0, -10808, 0, 28010, 0, -10807, 0, 29436, 0, -10806, 0, 29701, 0, -10805, 0, 29807, 0, -10804, 0, -30846, 0, -10803, 0, -28450, 0, -10802, 0, 20358, 0, -10801, 0, 23821, 0, -10800, 0, 24480, 0, -10799, 0, -31734, 0, -10798, 0, 20919, 0, -10797, 0, 25504, 0, -10796, 0, 30053, 0, -10795, 0, 20142, 0, -10794, 0, 20486, 0, -10793, 0, 20841, 0, -10792, 0, 20937, 0, -10791, 0, 26753, 0, -10790, 0, 27153, 0, -10789, 0, 31918, 0, -10788, 0, 31921, 0, -10787, 0, 31975, 0, -10786, 0, -32145, 0, -10785, 0, -29998, 0, -10784, 0, -28901, 0, -10783, 0, -28209, 0, -10782, 0, 20406, 0, -10781, 0, 20791, 0, -10780, 0, 21237, 0, -10779, 0, 21570, 0, -10778, 0, 24300, 0, -10777, 0, 24942, 0, -10776, 0, 25150, 0, -10775, 0, 26053, 0, -10774, 0, 27354, 0, -10773, 0, 28670, 0, -10772, 0, 31018, 0, -10771, 0, -31268, 0, -10770, 0, -30685, 0, -10769, 0, -27219, 0, -10768, 0, -26014, 0, -10767, 0, -26006, 0, -10766, 0, -24937, 0, -10765, 0, -24882, 0, -10764, 0, 21147, 0, -10763, 0, 26310, 0, -10762, 0, 27511, 0, -10761, 0, 28701, 0, -10760, 0, 31019, 0, -10759, 0, -28830, 0, -10758, 0, -26814, 0, -10757, 0, 24976, 0, -10756, 0, 25088, 0, -10755, 0, 25891, 0, -10754, 0, 28451, 0, -10591, 0, 29001, 0, -10590, 0, 29833, 0, -10589, 0, 32244, 0, -10588, 0, -32657, 0, -10587, 0, -31506, 0, -10586, 0, -28890, 0, -10585, 0, -28637, 0, -10584, 0, -27830, 0, -10583, 0, 20925, 0, -10582, 0, 21015, 0, -10581, 0, 21155, 0, -10580, 0, 27916, 0, -10579, 0, 28872, 0, -10578, 0, -30526, 0, -10577, 0, 24265, 0, -10576, 0, 25986, 0, -10575, 0, 27566, 0, -10574, 0, 28610, 0, -10573, 0, 31806, 0, -10572, 0, 29557, 0, -10571, 0, 20196, 0, -10570, 0, 20278, 0, -10569, 0, 22265, 0, -10568, 0, -1697, 0, -10567, 0, 23738, 0, -10566, 0, 23994, 0, -10565, 0, 24604, 0, -10564, 0, 29618, 0, -10563, 0, 31533, 0, -10562, 0, 32666, 0, -10561, 0, 32718, 0, -10560, 0, -32698, 0, -10559, 0, -28642, 0, -10558, 0, -28108, 0, -10557, 0, -26890, 0, -10556, 0, -26808, 0, -10555, 0, -26600, 0, -10554, 0, -24735, 0, -10553, 0, 20363, 0, -10552, 0, 28583, 0, -10551, 0, 31150, 0, -10550, 0, -28236, 0, -10549, 0, -26953, 0, -10548, 0, 21214, 0, -10547, 0, -1696, 0, -10546, 0, 25736, 0, -10545, 0, 25796, 0, -10544, 0, 27347, 0, -10543, 0, 28510, 0, -10542, 0, 28696, 0, -10541, 0, 29200, 0, -10540, 0, 30439, 0, -10539, 0, -32767, 0, -10538, 0, -31226, 0, -10537, 0, -31140, 0, -10536, 0, -29201, 0, -10535, 0, -28923, 0, -10534, 0, -26830, 0, -10533, 0, -25745, 0, -10532, 0, -25094, 0, -10531, 0, -24971, 0, -10530, 0, 30860, 0, -10529, 0, 31103, 0, -10528, 0, 32160, 0, -10527, 0, -31799, 0, -10526, 0, -27900, 0, -10525, 0, -24961, 0, -10524, 0, -24941, 0, -10523, 0, -29994, 0, -10522, 0, 22751, 0, -10521, 0, 24324, 0, -10520, 0, 26407, 0, -10519, 0, 28711, 0, -10518, 0, 29903, 0, -10517, 0, 31840, 0, -10516, 0, -32642, 0, -10515, 0, 20769, 0, -10514, 0, 28712, 0, -10513, 0, 29282, 0, -10512, 0, 30922, 0, -10511, 0, -29502, 0, -10510, 0, -29478, 0, -10509, 0, -29452, 0, -10508, 0, -26889, 0, -10507, 0, 20102, 0, -10506, 0, 20698, 0, -10505, 0, 23534, 0, -10504, 0, 24278, 0, -10503, 0, 26009, 0, -10502, 0, 29134, 0, -10501, 0, 30274, 0, -10500, 0, 30637, 0, -10499, 0, -32694, 0, -10498, 0, -31492, 0, -10335, 0, -28548, 0, -10334, 0, -25817, 0, -10333, 0, -24691, 0, -10332, 0, 22744, 0, -10331, 0, 23105, 0, -10330, 0, 23650, 0, -10329, 0, 27155, 0, -10328, 0, 28122, 0, -10327, 0, 28431, 0, -10326, 0, 30267, 0, -10325, 0, 32047, 0, -10324, 0, 32311, 0, -10323, 0, -31458, 0, -10322, 0, -30408, 0, -10321, 0, -27676, 0, -10320, 0, -27061, 0, -10319, 0, 21129, 0, -10318, 0, 26066, 0, -10317, 0, 26611, 0, -10316, 0, 27060, 0, -10315, 0, 27969, 0, -10314, 0, 28316, 0, -10313, 0, 28687, 0, -10312, 0, 29705, 0, -10311, 0, 29792, 0, -10310, 0, 30041, 0, -10309, 0, 30244, 0, -10308, 0, 30827, 0, -10307, 0, -29908, 0, -10306, 0, -26530, 0, -10305, 0, 20845, 0, -10304, 0, 25134, 0, -10303, 0, -27016, 0, -10302, 0, 20374, 0, -10301, 0, 20523, 0, -10300, 0, 23833, 0, -10299, 0, 28138, 0, -10298, 0, 32184, 0, -10297, 0, -28886, 0, -10296, 0, 24459, 0, -10295, 0, 24900, 0, -10294, 0, 26647, 0, -10293, 0, -1695, 0, -10292, 0, -27002, 0, -10291, 0, 21202, 0, -10290, 0, -32629, 0, -10289, 0, 20956, 0, -10288, 0, 20940, 0, -10287, 0, 26974, 0, -10286, 0, 31260, 0, -10285, 0, 32190, 0, -10284, 0, -31759, 0, -10283, 0, -27019, 0, -10282, 0, 20442, 0, -10281, 0, 21033, 0, -10280, 0, 21400, 0, -10279, 0, 21519, 0, -10278, 0, 21774, 0, -10277, 0, 23653, 0, -10276, 0, 24743, 0, -10275, 0, 26446, 0, -10274, 0, 26792, 0, -10273, 0, 28012, 0, -10272, 0, 29313, 0, -10271, 0, 29432, 0, -10270, 0, 29702, 0, -10269, 0, 29827, 0, -10268, 0, -1694, 0, -10267, 0, 30178, 0, -10266, 0, 31852, 0, -10265, 0, 32633, 0, -10264, 0, 32696, 0, -10263, 0, -31863, 0, -10262, 0, -30513, 0, -10261, 0, -30495, 0, -10260, 0, -28212, 0, -10259, 0, -28208, 0, -10258, 0, -26910, 0, -10257, 0, -25655, 0, -10256, 0, 21533, 0, -10255, 0, 28542, 0, -10254, 0, 29136, 0, -10253, 0, 29848, 0, -10252, 0, -31238, 0, -10251, 0, -29014, 0, -10250, 0, -26973, 0, -10249, 0, -25513, 0, -10248, 0, -24929, 0, -10247, 0, 26519, 0, -10246, 0, 28107, 0, -10245, 0, 29747, 0, -10244, 0, -32280, 0, -10243, 0, -26858, 0, -10242, 0, 30764, 0, -10079, 0, 31435, 0, -10078, 0, 31520, 0, -10077, 0, 31890, 0, -10076, 0, 25705, 0, -10075, 0, 29802, 0, -10074, 0, 30194, 0, -10073, 0, 30908, 0, -10072, 0, 30952, 0, -10071, 0, -26196, 0, -10070, 0, -25772, 0, -10069, 0, -24901, 0, -10068, 0, 23518, 0, -10067, 0, 24149, 0, -10066, 0, 28448, 0, -10065, 0, -32356, 0, -10064, 0, -31829, 0, -10063, 0, -28536, 0, -10062, 0, 19975, 0, -10061, 0, 21325, 0, -10060, 0, 23081, 0, -10059, 0, 24018, 0, -10058, 0, 24398, 0, -10057, 0, 24930, 0, -10056, 0, 25405, 0, -10055, 0, 26217, 0, -10054, 0, 26364, 0, -10053, 0, 28415, 0, -10052, 0, 28459, 0, -10051, 0, 28771, 0, -10050, 0, 30622, 0, -10049, 0, -31700, 0, -10048, 0, -31469, 0, -10047, 0, -30661, 0, -10046, 0, -28909, 0, -10045, 0, -26299, 0, -10044, 0, -25541, 0, -10043, 0, 21788, 0, -10042, 0, 25273, 0, -10041, 0, 26411, 0, -10040, 0, 27819, 0, -10039, 0, -31991, 0, -10038, 0, -30358, 0, -10037, 0, -26758, 0, -10036, 0, 20129, 0, -10035, 0, 22916, 0, -10034, 0, 24536, 0, -10033, 0, 24537, 0, -10032, 0, 26395, 0, -10031, 0, 32178, 0, -10030, 0, 32596, 0, -10029, 0, -32110, 0, -10028, 0, -31957, 0, -10027, 0, -31811, 0, -10026, 0, -28898, 0, -10025, 0, -28519, 0, -10024, 0, 22475, 0, -10023, 0, 22969, 0, -10022, 0, 23186, 0, -10021, 0, 23504, 0, -10020, 0, 26151, 0, -10019, 0, 26522, 0, -10018, 0, 26757, 0, -10017, 0, 27599, 0, -10016, 0, 29028, 0, -10015, 0, 32629, 0, -10014, 0, -29513, 0, -10013, 0, -29469, 0, -10012, 0, -28543, 0, -10011, 0, -25787, 0, -10010, 0, -32504, 0, -10009, 0, -29558, 0, -10008, 0, -27060, 0, -10007, 0, -26048, 0, -10006, 0, -24923, 0, -10005, 0, 23391, 0, -10004, 0, 27667, 0, -10003, 0, 29467, 0, -10002, 0, 30450, 0, -10001, 0, 30431, 0, -10000, 0, -31732, 0, -9999, 0, 20906, 0, -9998, 0, -30317, 0, -9997, 0, 20813, 0, -9996, 0, 20885, 0, -9995, 0, 21193, 0, -9994, 0, 26825, 0, -9993, 0, 27796, 0, -9992, 0, 30468, 0, -9991, 0, 30496, 0, -9990, 0, 32191, 0, -9989, 0, 32236, 0, -9988, 0, -26782, 0, -9987, 0, -24907, 0, -9986, 0, 28357, 0, -9823, 0, -31471, 0, -9822, 0, 20901, 0, -9821, 0, 21517, 0, -9820, 0, 21629, 0, -9819, 0, 26126, 0, -9818, 0, 26269, 0, -9817, 0, 26919, 0, -9816, 0, 28319, 0, -9815, 0, 30399, 0, -9814, 0, 30609, 0, -9813, 0, -31977, 0, -9812, 0, -31550, 0, -9811, 0, -30817, 0, -9810, 0, -28311, 0, -9809, 0, -28008, 0, -9808, 0, -25356, 0, -9807, 0, -30590, 0, -9806, 0, 20398, 0, -9805, 0, 20882, 0, -9804, 0, 21215, 0, -9803, 0, 22982, 0, -9802, 0, 24125, 0, -9801, 0, 24917, 0, -9800, 0, 25720, 0, -9799, 0, 25721, 0, -9798, 0, 26286, 0, -9797, 0, 26576, 0, -9796, 0, 27169, 0, -9795, 0, 27597, 0, -9794, 0, 27611, 0, -9793, 0, 29279, 0, -9792, 0, 29281, 0, -9791, 0, 29761, 0, -9790, 0, 30520, 0, -9789, 0, 30683, 0, -9788, 0, -32745, 0, -9787, 0, -32068, 0, -9786, 0, -31995, 0, -9785, 0, -29952, 0, -9784, 0, -29912, 0, -9783, 0, -29556, 0, -9782, 0, 26408, 0, -9781, 0, 27792, 0, -9780, 0, 29287, 0, -9779, 0, 30446, 0, -9778, 0, 30566, 0, -9777, 0, 31302, 0, -9776, 0, -25175, 0, -9775, 0, 27519, 0, -9774, 0, 27794, 0, -9773, 0, 22818, 0, -9772, 0, 26406, 0, -9771, 0, -31591, 0, -9770, 0, 21359, 0, -9769, 0, 22675, 0, -9768, 0, 22937, 0, -9767, 0, 24287, 0, -9766, 0, 25551, 0, -9765, 0, 26164, 0, -9764, 0, 26483, 0, -9763, 0, 28218, 0, -9762, 0, 29483, 0, -9761, 0, 31447, 0, -9760, 0, -32041, 0, -9759, 0, -27864, 0, -9758, 0, 21209, 0, -9757, 0, 24043, 0, -9756, 0, 25006, 0, -9755, 0, 25035, 0, -9754, 0, 25098, 0, -9753, 0, 25287, 0, -9752, 0, 25771, 0, -9751, 0, 26080, 0, -9750, 0, 26969, 0, -9749, 0, 27494, 0, -9748, 0, 27595, 0, -9747, 0, 28961, 0, -9746, 0, 29687, 0, -9745, 0, 30045, 0, -9744, 0, 32326, 0, -9743, 0, -32226, 0, -9742, 0, -31998, 0, -9741, 0, -31382, 0, -9740, 0, -30045, 0, -9739, 0, -29505, 0, -9738, 0, -26841, 0, -9737, 0, -25247, 0, -9736, 0, 22696, 0, -9735, 0, -24872, 0, -9734, 0, 20497, 0, -9733, 0, 21006, 0, -9732, 0, 21563, 0, -9731, 0, 21839, 0, -9730, 0, 25991, 0, -9567, 0, 27766, 0, -9566, 0, 32010, 0, -9565, 0, 32011, 0, -9564, 0, -32674, 0, -9563, 0, -31094, 0, -9562, 0, -27264, 0, -9561, 0, -26897, 0, -9560, 0, 21247, 0, -9559, 0, 27797, 0, -9558, 0, 29289, 0, -9557, 0, 21619, 0, -9556, 0, 23194, 0, -9555, 0, 23614, 0, -9554, 0, 23883, 0, -9553, 0, 24396, 0, -9552, 0, 24494, 0, -9551, 0, 26410, 0, -9550, 0, 26806, 0, -9549, 0, 26979, 0, -9548, 0, 28220, 0, -9547, 0, 28228, 0, -9546, 0, 30473, 0, -9545, 0, 31859, 0, -9544, 0, 32654, 0, -9543, 0, -31353, 0, -9542, 0, -29938, 0, -9541, 0, -28681, 0, -9540, 0, -26783, 0, -9539, 0, -24844, 0, -9538, 0, 23735, 0, -9537, 0, 24758, 0, -9536, 0, 24845, 0, -9535, 0, 25003, 0, -9534, 0, 25935, 0, -9533, 0, 26107, 0, -9532, 0, 26108, 0, -9531, 0, 27665, 0, -9530, 0, 27887, 0, -9529, 0, 29599, 0, -9528, 0, 29641, 0, -9527, 0, 32225, 0, -9526, 0, -27244, 0, -9525, 0, 23494, 0, -9524, 0, -30948, 0, -9523, 0, -29936, 0, -9522, 0, 21085, 0, -9521, 0, 21338, 0, -9520, 0, 25293, 0, -9519, 0, 25615, 0, -9518, 0, 25778, 0, -9517, 0, 26420, 0, -9516, 0, 27192, 0, -9515, 0, 27850, 0, -9514, 0, 29632, 0, -9513, 0, 29854, 0, -9512, 0, 31636, 0, -9511, 0, 31893, 0, -9510, 0, 32283, 0, -9509, 0, -32374, 0, -9508, 0, -32202, 0, -9507, 0, -31356, 0, -9506, 0, -28693, 0, -9505, 0, -26887, 0, -9504, 0, -26175, 0, -9503, 0, 20276, 0, -9502, 0, 21322, 0, -9501, 0, 21453, 0, -9500, 0, 21467, 0, -9499, 0, 25292, 0, -9498, 0, 25644, 0, -9497, 0, 25856, 0, -9496, 0, 26001, 0, -9495, 0, 27075, 0, -9494, 0, 27886, 0, -9493, 0, 28504, 0, -9492, 0, 29677, 0, -9491, 0, 30036, 0, -9490, 0, 30242, 0, -9489, 0, 30436, 0, -9488, 0, 30460, 0, -9487, 0, 30928, 0, -9486, 0, 30971, 0, -9485, 0, 31020, 0, -9484, 0, 32070, 0, -9483, 0, -32212, 0, -9482, 0, -30752, 0, -9481, 0, -28716, 0, -9480, 0, -26606, 0, -9479, 0, -26385, 0, -9478, 0, 21187, 0, -9477, 0, 25300, 0, -9476, 0, 25765, 0, -9475, 0, 28196, 0, -9474, 0, 28497, 0, -9311, 0, 30332, 0, -9310, 0, -29237, 0, -9309, 0, -28239, 0, -9308, 0, -28062, 0, -9307, 0, -25874, 0, -9306, 0, -25789, 0, -9305, 0, 20515, 0, -9304, 0, 20621, 0, -9303, 0, 22346, 0, -9302, 0, 22952, 0, -9301, 0, 23592, 0, -9300, 0, 24135, 0, -9299, 0, 24439, 0, -9298, 0, 25151, 0, -9297, 0, 25918, 0, -9296, 0, 26041, 0, -9295, 0, 26049, 0, -9294, 0, 26121, 0, -9293, 0, 26507, 0, -9292, 0, 27036, 0, -9291, 0, 28354, 0, -9290, 0, 30917, 0, -9289, 0, 32033, 0, -9288, 0, -32598, 0, -9287, 0, -32384, 0, -9286, 0, -32213, 0, -9285, 0, -32077, 0, -9284, 0, -31583, 0, -9283, 0, -31092, 0, -9282, 0, -30166, 0, -9281, 0, -29929, 0, -9280, 0, -28506, 0, -9279, 0, -27086, 0, -9278, 0, -24688, 0, -9277, 0, 20493, 0, -9276, 0, 20467, 0, -9275, 0, -1693, 0, -9274, 0, 22521, 0, -9273, 0, 24472, 0, -9272, 0, 25308, 0, -9271, 0, 25490, 0, -9270, 0, 26479, 0, -9269, 0, 28227, 0, -9268, 0, 28953, 0, -9267, 0, 30403, 0, -9266, 0, -32564, 0, -9265, 0, -32550, 0, -9264, 0, -30476, 0, -9263, 0, -30475, 0, -9262, 0, -30439, 0, -9261, 0, -29472, 0, -9260, 0, -28887, 0, -9259, 0, -28339, 0, -9258, 0, -27030, 0, -9257, 0, 20271, 0, -9256, 0, 20336, 0, -9255, 0, 24091, 0, -9254, 0, 26575, 0, -9253, 0, 26658, 0, -9252, 0, 30333, 0, -9251, 0, 30334, 0, -9250, 0, -25788, 0, -9249, 0, 24161, 0, -9248, 0, 27146, 0, -9247, 0, 29033, 0, -9246, 0, 29140, 0, -9245, 0, 30058, 0, -9244, 0, -1692, 0, -9243, 0, 32321, 0, -9242, 0, -31421, 0, -9241, 0, -31255, 0, -9240, 0, -26404, 0, -9239, 0, 20240, 0, -9238, 0, 31567, 0, -9237, 0, 32624, 0, -9236, 0, -27227, 0, -9235, 0, 20961, 0, -9234, 0, 24070, 0, -9233, 0, 26805, 0, -9232, 0, 27710, 0, -9231, 0, 27726, 0, -9230, 0, 27867, 0, -9229, 0, 29359, 0, -9228, 0, 31684, 0, -9227, 0, -31997, 0, -9226, 0, 27861, 0, -9225, 0, 29754, 0, -9224, 0, 20731, 0, -9223, 0, 21128, 0, -9222, 0, 22721, 0, -9221, 0, 25816, 0, -9220, 0, 27287, 0, -9219, 0, 29863, 0, -9218, 0, 30294, 0, -9055, 0, 30887, 0, -9054, 0, -31209, 0, -9053, 0, -27166, 0, -9052, 0, -26823, 0, -9051, 0, -1691, 0, -9050, 0, 21342, 0, -9049, 0, 24321, 0, -9048, 0, -29814, 0, -9047, 0, -28760, 0, -9046, 0, -28753, 0, -9045, 0, -28534, 0, -9044, 0, 21029, 0, -9043, 0, 30629, 0, -9042, 0, -25527, 0, -9041, 0, -24824, 0, -9040, 0, 19993, 0, -9039, 0, 20482, 0, -9038, 0, 20853, 0, -9037, 0, 23643, 0, -9036, 0, 24183, 0, -9035, 0, 26142, 0, -9034, 0, 26170, 0, -9033, 0, 26564, 0, -9032, 0, 26821, 0, -9031, 0, 28851, 0, -9030, 0, 29953, 0, -9029, 0, 30149, 0, -9028, 0, 31177, 0, -9027, 0, 31453, 0, -9026, 0, -28889, 0, -9025, 0, -26336, 0, -9024, 0, -26104, 0, -9023, 0, 20445, 0, -9022, 0, 22561, 0, -9021, 0, 22577, 0, -9020, 0, 23542, 0, -9019, 0, 26222, 0, -9018, 0, 27493, 0, -9017, 0, 27921, 0, -9016, 0, 28282, 0, -9015, 0, 28541, 0, -9014, 0, 29668, 0, -9013, 0, 29995, 0, -9012, 0, -31767, 0, -9011, 0, -30500, 0, -9010, 0, -30445, 0, -9009, 0, -29860, 0, -9008, 0, -28908, 0, -9007, 0, 20239, 0, -9006, 0, 20693, 0, -9005, 0, 21264, 0, -9004, 0, 21340, 0, -9003, 0, 23443, 0, -9002, 0, 24489, 0, -9001, 0, 26381, 0, -9000, 0, 31119, 0, -8999, 0, -32391, 0, -8998, 0, -31953, 0, -8997, 0, -31468, 0, -8996, 0, -30457, 0, -8995, 0, -30330, 0, -8994, 0, -28871, 0, -8993, 0, -28869, 0, -8992, 0, -26203, 0, -8991, 0, -25582, 0, -8990, 0, 26412, 0, -8989, 0, 20086, 0, -8988, 0, 20472, 0, -8987, 0, 22857, 0, -8986, 0, 23553, 0, -8985, 0, 23791, 0, -8984, 0, 23792, 0, -8983, 0, 25447, 0, -8982, 0, 26834, 0, -8981, 0, 28925, 0, -8980, 0, 29090, 0, -8979, 0, 29739, 0, -8978, 0, 32299, 0, -8977, 0, -31508, 0, -8976, 0, -30974, 0, -8975, 0, -28638, 0, -8974, 0, -27950, 0, -8973, 0, -25357, 0, -8972, 0, 19981, 0, -8971, 0, 20184, 0, -8970, 0, 20463, 0, -8969, 0, 20613, 0, -8968, 0, 21078, 0, -8967, 0, 21103, 0, -8966, 0, 21542, 0, -8965, 0, 21648, 0, -8964, 0, 22496, 0, -8963, 0, 22827, 0, -8962, 0, 23142, 0, -8799, 0, 23386, 0, -8798, 0, 23413, 0, -8797, 0, 23500, 0, -8796, 0, 24220, 0, -8795, 0, -1690, 0, -8794, 0, 25206, 0, -8793, 0, 25975, 0, -8792, 0, 26023, 0, -8791, 0, 28014, 0, -8790, 0, 28325, 0, -8789, 0, 29238, 0, -8788, 0, 31526, 0, -8787, 0, 31807, 0, -8786, 0, 32566, 0, -8785, 0, -32432, 0, -8784, 0, -32431, 0, -8783, 0, -32358, 0, -8782, 0, -32192, 0, -8781, 0, -32103, 0, -8780, 0, -31831, 0, -8779, 0, -30205, 0, -8778, 0, -29536, 0, -8777, 0, -29466, 0, -8776, 0, -29445, 0, -8775, 0, -29324, 0, -8774, 0, -29254, 0, -8773, 0, -28440, 0, -8772, 0, -28196, 0, -8771, 0, -27108, 0, -8770, 0, -27068, 0, -8769, 0, -26151, 0, -8768, 0, -25369, 0, -8767, 0, 21271, 0, -8766, 0, 20998, 0, -8765, 0, 21545, 0, -8764, 0, 22132, 0, -8763, 0, 22707, 0, -8762, 0, 22868, 0, -8761, 0, 22894, 0, -8760, 0, 24575, 0, -8759, 0, 24996, 0, -8758, 0, 25198, 0, -8757, 0, 26128, 0, -8756, 0, 27774, 0, -8755, 0, 28954, 0, -8754, 0, 30406, 0, -8753, 0, 31881, 0, -8752, 0, 31966, 0, -8751, 0, 32027, 0, -8750, 0, -32084, 0, -8749, 0, -29503, 0, -8748, 0, -26896, 0, -8747, 0, -1689, 0, -8746, 0, 20315, 0, -8745, 0, 24343, 0, -8744, 0, 24447, 0, -8743, 0, 25282, 0, -8742, 0, 23849, 0, -8741, 0, 26379, 0, -8740, 0, 26842, 0, -8739, 0, 30844, 0, -8738, 0, 32323, 0, -8737, 0, -25236, 0, -8736, 0, 19989, 0, -8735, 0, 20633, 0, -8734, 0, 21269, 0, -8733, 0, 21290, 0, -8732, 0, 21329, 0, -8731, 0, 22915, 0, -8730, 0, 23138, 0, -8729, 0, 24199, 0, -8728, 0, 24754, 0, -8727, 0, 24970, 0, -8726, 0, 25161, 0, -8725, 0, 25209, 0, -8724, 0, 26000, 0, -8723, 0, 26503, 0, -8722, 0, 27047, 0, -8721, 0, 27604, 0, -8720, 0, 27606, 0, -8719, 0, 27607, 0, -8718, 0, 27608, 0, -8717, 0, 27832, 0, -8716, 0, -1688, 0, -8715, 0, 29749, 0, -8714, 0, 30202, 0, -8713, 0, 30738, 0, -8712, 0, 30865, 0, -8711, 0, 31189, 0, -8710, 0, 31192, 0, -8709, 0, 31875, 0, -8708, 0, 32203, 0, -8707, 0, 32737, 0, -8706, 0, -32603, 0, -8543, 0, -32450, 0, -8542, 0, -32318, 0, -8541, 0, -31758, 0, -8540, 0, -30950, 0, -8539, 0, -30488, 0, -8538, 0, -30023, 0, -8537, 0, -29844, 0, -8536, 0, -29509, 0, -8535, 0, -28391, 0, -8534, 0, -26786, 0, -8533, 0, -26405, 0, -8532, 0, -24773, 0, -8531, 0, 22188, 0, -8530, 0, 23338, 0, -8529, 0, 24428, 0, -8528, 0, 25996, 0, -8527, 0, 27315, 0, -8526, 0, 27567, 0, -8525, 0, 27996, 0, -8524, 0, 28657, 0, -8523, 0, 28693, 0, -8522, 0, 29277, 0, -8521, 0, 29613, 0, -8520, 0, -29529, 0, -8519, 0, -29485, 0, -8518, 0, -26565, 0, -8517, 0, 24977, 0, -8516, 0, 27703, 0, -8515, 0, -32680, 0, -8514, 0, -26111, 0, -8513, 0, 20045, 0, -8512, 0, 20107, 0, -8511, 0, 20123, 0, -8510, 0, 20181, 0, -8509, 0, 20282, 0, -8508, 0, 20284, 0, -8507, 0, 20351, 0, -8506, 0, 20447, 0, -8505, 0, 20735, 0, -8504, 0, 21490, 0, -8503, 0, 21496, 0, -8502, 0, 21766, 0, -8501, 0, 21987, 0, -8500, 0, 22235, 0, -8499, 0, 22763, 0, -8498, 0, 22882, 0, -8497, 0, 23057, 0, -8496, 0, 23531, 0, -8495, 0, 23546, 0, -8494, 0, 23556, 0, -8493, 0, 24051, 0, -8492, 0, 24107, 0, -8491, 0, 24473, 0, -8490, 0, 24605, 0, -8489, 0, 25448, 0, -8488, 0, 26012, 0, -8487, 0, 26031, 0, -8486, 0, 26614, 0, -8485, 0, 26619, 0, -8484, 0, 26797, 0, -8483, 0, 27515, 0, -8482, 0, 27801, 0, -8481, 0, 27863, 0, -8480, 0, 28195, 0, -8479, 0, 28681, 0, -8478, 0, 29509, 0, -8477, 0, 30722, 0, -8476, 0, 31038, 0, -8475, 0, 31040, 0, -8474, 0, 31072, 0, -8473, 0, 31169, 0, -8472, 0, 31721, 0, -8471, 0, 32023, 0, -8470, 0, 32114, 0, -8469, 0, -32634, 0, -8468, 0, -32243, 0, -8467, 0, -31858, 0, -8466, 0, -31535, 0, -8465, 0, -31033, 0, -8464, 0, -30497, 0, -8463, 0, -30128, 0, -8462, 0, -30114, 0, -8461, 0, -29923, 0, -8460, 0, -29476, 0, -8459, 0, -29338, 0, -8458, 0, -28755, 0, -8457, 0, -28502, 0, -8456, 0, -26372, 0, -8455, 0, -26145, 0, -8454, 0, -24931, 0, -8453, 0, 21066, 0, -8452, 0, -1687, 0, -8451, 0, 26388, 0, -8450, 0, -1686, 0, -8287, 0, 20632, 0, -8286, 0, 21034, 0, -8285, 0, 23665, 0, -8284, 0, 25955, 0, -8283, 0, 27733, 0, -8282, 0, 29642, 0, -8281, 0, 29987, 0, -8280, 0, 30109, 0, -8279, 0, 31639, 0, -8278, 0, -31588, 0, -8277, 0, -28296, 0, -8276, 0, -26832, 0, -8275, 0, 20087, 0, -8274, 0, 25746, 0, -8273, 0, 27578, 0, -8272, 0, 29022, 0, -8271, 0, -31319, 0, -8270, 0, 19977, 0, -8269, 0, -1685, 0, -8268, 0, 26441, 0, -8267, 0, 26862, 0, -8266, 0, 28183, 0, -8265, 0, -32097, 0, -8264, 0, -31464, 0, -8263, 0, -30613, 0, -8262, 0, 25591, 0, -8261, 0, 28545, 0, -8260, 0, -28142, 0, -8259, 0, -26449, 0, -8258, 0, 19978, 0, -8257, 0, 20663, 0, -8256, 0, 20687, 0, -8255, 0, 20767, 0, -8254, 0, 21830, 0, -8253, 0, 21930, 0, -8252, 0, 22039, 0, -8251, 0, 23360, 0, -8250, 0, 23577, 0, -8249, 0, 23776, 0, -8248, 0, 24120, 0, -8247, 0, 24202, 0, -8246, 0, 24224, 0, -8245, 0, 24258, 0, -8244, 0, 24819, 0, -8243, 0, 26705, 0, -8242, 0, 27233, 0, -8241, 0, 28248, 0, -8240, 0, 29245, 0, -8239, 0, 29248, 0, -8238, 0, 29376, 0, -8237, 0, 30456, 0, -8236, 0, 31077, 0, -8235, 0, 31665, 0, -8234, 0, 32724, 0, -8233, 0, -30477, 0, -8232, 0, -30220, 0, -8231, 0, -30093, 0, -8230, 0, -29599, 0, -8229, 0, -29474, 0, -8228, 0, -26852, 0, -8227, 0, 22622, 0, -8226, 0, 29885, 0, -8225, 0, -29443, 0, -8224, 0, 21959, 0, -8223, 0, -1684, 0, -8222, 0, 31329, 0, -8221, 0, 32034, 0, -8220, 0, -32142, 0, -8219, 0, 29298, 0, -8218, 0, 29983, 0, -8217, 0, 29989, 0, -8216, 0, -1683, 0, -8215, 0, 31513, 0, -8214, 0, 22661, 0, -8213, 0, 22779, 0, -8212, 0, 23996, 0, -8211, 0, 24207, 0, -8210, 0, 24246, 0, -8209, 0, 24464, 0, -8208, 0, 24661, 0, -8207, 0, 25234, 0, -8206, 0, 25471, 0, -8205, 0, 25933, 0, -8204, 0, 26257, 0, -8203, 0, 26329, 0, -8202, 0, 26360, 0, -8201, 0, 26646, 0, -8200, 0, 26866, 0, -8199, 0, 29312, 0, -8198, 0, 29790, 0, -8197, 0, 31598, 0, -8196, 0, 32110, 0, -8195, 0, 32214, 0, -8194, 0, 32626, 0, -8031, 0, -32539, 0, -8030, 0, -32238, 0, -8029, 0, -31313, 0, -8028, 0, -30337, 0, -8027, 0, -30061, 0, -8026, 0, -28643, 0, -8025, 0, -27932, 0, -8024, 0, -24883, 0, -8023, 0, -24800, 0, -8022, 0, 22805, 0, -8021, 0, 22893, 0, -8020, 0, 24109, 0, -8019, 0, 24796, 0, -8018, 0, 26132, 0, -8017, 0, 26227, 0, -8016, 0, 26512, 0, -8015, 0, 27728, 0, -8014, 0, 28101, 0, -8013, 0, 28511, 0, -8012, 0, 30707, 0, -8011, 0, 30889, 0, -8010, 0, -31546, 0, -8009, 0, -28213, 0, -8008, 0, -27861, 0, -8007, 0, 20185, 0, -8006, 0, 20682, 0, -8005, 0, 20808, 0, -8004, 0, 21892, 0, -8003, 0, 23307, 0, -8002, 0, 23459, 0, -8001, 0, 25159, 0, -8000, 0, 25982, 0, -7999, 0, 26059, 0, -7998, 0, 28210, 0, -7997, 0, 29053, 0, -7996, 0, 29697, 0, -7995, 0, 29764, 0, -7994, 0, 29831, 0, -7993, 0, 29887, 0, -7992, 0, 30316, 0, -7991, 0, 31146, 0, -7990, 0, 32218, 0, -7989, 0, 32341, 0, -7988, 0, 32680, 0, -7987, 0, -32390, 0, -7986, 0, -32333, 0, -7985, 0, -32199, 0, -7984, 0, -31206, 0, -7983, 0, -30740, 0, -7982, 0, -30091, 0, -7981, 0, -29213, 0, -7980, 0, -28552, 0, -7979, 0, -28015, 0, -7978, 0, -27611, 0, -7977, 0, -26291, 0, -7976, 0, -25682, 0, -7975, 0, 21352, 0, -7974, 0, 23633, 0, -7973, 0, 26964, 0, -7972, 0, 27844, 0, -7971, 0, 27945, 0, -7970, 0, 28203, 0, -7969, 0, -32244, 0, -7968, 0, -31333, 0, -7967, 0, -30405, 0, -7966, 0, -30163, 0, -7965, 0, -30038, 0, -7964, 0, -26902, 0, -7963, 0, -24729, 0, -7962, 0, 21089, 0, -7961, 0, 26297, 0, -7960, 0, 27570, 0, -7959, 0, 32406, 0, -7958, 0, -30722, 0, -7957, 0, -29427, 0, -7956, 0, -27261, 0, -7955, 0, -27043, 0, -7954, 0, 25885, 0, -7953, 0, 28041, 0, -7952, 0, 29166, 0, -7951, 0, -1682, 0, -7950, 0, 22478, 0, -7949, 0, 22995, 0, -7948, 0, 23468, 0, -7947, 0, 24615, 0, -7946, 0, 24826, 0, -7945, 0, 25104, 0, -7944, 0, 26143, 0, -7943, 0, 26207, 0, -7942, 0, 29481, 0, -7941, 0, 29689, 0, -7940, 0, 30427, 0, -7939, 0, 30465, 0, -7938, 0, 31596, 0, -7775, 0, -32682, 0, -7774, 0, -32654, 0, -7773, 0, -32411, 0, -7772, 0, -30048, 0, -7771, 0, -28270, 0, -7770, 0, 19990, 0, -7769, 0, 21218, 0, -7768, 0, 27506, 0, -7767, 0, 27927, 0, -7766, 0, 31237, 0, -7765, 0, 31545, 0, -7764, 0, 32048, 0, -7763, 0, -1681, 0, -7762, 0, -29520, 0, -7761, 0, 21484, 0, -7760, 0, 22063, 0, -7759, 0, 22609, 0, -7758, 0, 23477, 0, -7757, 0, 23567, 0, -7756, 0, 23569, 0, -7755, 0, 24034, 0, -7754, 0, 25152, 0, -7753, 0, 25475, 0, -7752, 0, 25620, 0, -7751, 0, 26157, 0, -7750, 0, 26803, 0, -7749, 0, 27836, 0, -7748, 0, 28040, 0, -7747, 0, 28335, 0, -7746, 0, 28703, 0, -7745, 0, 28836, 0, -7744, 0, 29138, 0, -7743, 0, 29990, 0, -7742, 0, 30095, 0, -7741, 0, 30094, 0, -7740, 0, 30233, 0, -7739, 0, 31505, 0, -7738, 0, 31712, 0, -7737, 0, 31787, 0, -7736, 0, 32032, 0, -7735, 0, 32057, 0, -7734, 0, -31444, 0, -7733, 0, -31379, 0, -7732, 0, -31225, 0, -7731, 0, -30156, 0, -7730, 0, -28659, 0, -7729, 0, -28575, 0, -7728, 0, -28491, 0, -7727, 0, -27977, 0, -7726, 0, -26634, 0, -7725, 0, -26057, 0, -7724, 0, 20439, 0, -7723, 0, 23660, 0, -7722, 0, 26463, 0, -7721, 0, 28049, 0, -7720, 0, 31903, 0, -7719, 0, 32396, 0, -7718, 0, -29930, 0, -7717, 0, -29418, 0, -7716, 0, -28641, 0, -7715, 0, 23403, 0, -7714, 0, 24061, 0, -7713, 0, 25613, 0, -7712, 0, -31552, 0, -7711, 0, -28580, 0, -7710, 0, -26399, 0, -7709, 0, 29575, 0, -7708, 0, 23435, 0, -7707, 0, 24730, 0, -7706, 0, 26494, 0, -7705, 0, 28126, 0, -7704, 0, -30177, 0, -7703, 0, -30042, 0, -7702, 0, -28671, 0, -7701, 0, -26612, 0, -7700, 0, 21047, 0, -7699, 0, -1680, 0, -7698, 0, 28753, 0, -7697, 0, 30862, 0, -7696, 0, -27754, 0, -7695, 0, -30608, 0, -7694, 0, -28201, 0, -7693, 0, 20462, 0, -7692, 0, 21463, 0, -7691, 0, 22013, 0, -7690, 0, 22234, 0, -7689, 0, 22402, 0, -7688, 0, 22781, 0, -7687, 0, 23234, 0, -7686, 0, 23432, 0, -7685, 0, 23723, 0, -7684, 0, 23744, 0, -7683, 0, 24101, 0, -7682, 0, 24833, 0, -7519, 0, 25101, 0, -7518, 0, 25163, 0, -7517, 0, 25480, 0, -7516, 0, 25628, 0, -7515, 0, 25910, 0, -7514, 0, 25976, 0, -7513, 0, 27193, 0, -7512, 0, 27530, 0, -7511, 0, 27700, 0, -7510, 0, 27929, 0, -7509, 0, 28465, 0, -7508, 0, 29159, 0, -7507, 0, 29417, 0, -7506, 0, 29560, 0, -7505, 0, 29703, 0, -7504, 0, 29874, 0, -7503, 0, 30246, 0, -7502, 0, 30561, 0, -7501, 0, 31168, 0, -7500, 0, 31319, 0, -7499, 0, 31466, 0, -7498, 0, 31929, 0, -7497, 0, 32143, 0, -7496, 0, 32172, 0, -7495, 0, 32353, 0, -7494, 0, 32670, 0, -7493, 0, -32471, 0, -7492, 0, -31951, 0, -7491, 0, -31600, 0, -7490, 0, -31526, 0, -7489, 0, -31254, 0, -7488, 0, -30570, 0, -7487, 0, -30032, 0, -7486, 0, -29808, 0, -7485, 0, -28872, 0, -7484, 0, -28606, 0, -7483, 0, -28541, 0, -7482, 0, -28308, 0, -7481, 0, -28010, 0, -7480, 0, -27975, 0, -7479, 0, -26997, 0, -7478, 0, -26969, 0, -7477, 0, -26968, 0, -7476, 0, -26922, 0, -7475, 0, -26880, 0, -7474, 0, -26616, 0, -7473, 0, -26218, 0, -7472, 0, -25901, 0, -7471, 0, -25830, 0, -7470, 0, 21460, 0, -7469, 0, 22654, 0, -7468, 0, 22809, 0, -7467, 0, 23408, 0, -7466, 0, 23487, 0, -7465, 0, 28113, 0, -7464, 0, 28506, 0, -7463, 0, 29087, 0, -7462, 0, 29729, 0, -7461, 0, 29881, 0, -7460, 0, -32635, 0, -7459, 0, -31747, 0, -7458, 0, 24033, 0, -7457, 0, 24455, 0, -7456, 0, 24490, 0, -7455, 0, 24642, 0, -7454, 0, 26092, 0, -7453, 0, 26642, 0, -7452, 0, 26991, 0, -7451, 0, 27219, 0, -7450, 0, 27529, 0, -7449, 0, 27957, 0, -7448, 0, 28147, 0, -7447, 0, 29667, 0, -7446, 0, 30462, 0, -7445, 0, 30636, 0, -7444, 0, 31565, 0, -7443, 0, 32020, 0, -7442, 0, -32477, 0, -7441, 0, -32228, 0, -7440, 0, -31936, 0, -7439, 0, -31500, 0, -7438, 0, -31389, 0, -7437, 0, -30110, 0, -7436, 0, -30012, 0, -7435, 0, -28281, 0, -7434, 0, -27874, 0, -7433, 0, -26618, 0, -7432, 0, -26188, 0, -7431, 0, 25100, 0, -7430, 0, -30637, 0, -7429, 0, -28688, 0, -7428, 0, -28059, 0, -7427, 0, 23815, 0, -7426, 0, 23847, 0, -7263, 0, 23913, 0, -7262, 0, 29791, 0, -7261, 0, -32355, 0, -7260, 0, -30872, 0, -7259, 0, 28629, 0, -7258, 0, 25342, 0, -7257, 0, 32722, 0, -7256, 0, -30410, 0, -7255, 0, -30350, 0, -7254, 0, 19998, 0, -7253, 0, 20056, 0, -7252, 0, 20711, 0, -7251, 0, 21213, 0, -7250, 0, 21319, 0, -7249, 0, 25215, 0, -7248, 0, 26119, 0, -7247, 0, 32361, 0, -7246, 0, -30715, 0, -7245, 0, -27042, 0, -7244, 0, 20365, 0, -7243, 0, 21273, 0, -7242, 0, 22070, 0, -7241, 0, 22987, 0, -7240, 0, 23204, 0, -7239, 0, 23608, 0, -7238, 0, 23630, 0, -7237, 0, 23629, 0, -7236, 0, 24066, 0, -7235, 0, 24337, 0, -7234, 0, 24643, 0, -7233, 0, 26045, 0, -7232, 0, 26159, 0, -7231, 0, 26178, 0, -7230, 0, 26558, 0, -7229, 0, 26612, 0, -7228, 0, 29468, 0, -7227, 0, 30690, 0, -7226, 0, 31034, 0, -7225, 0, 32709, 0, -7224, 0, -31596, 0, -7223, 0, -31539, 0, -7222, 0, -30314, 0, -7221, 0, -30106, 0, -7220, 0, -30103, 0, -7219, 0, -29983, 0, -7218, 0, -29611, 0, -7217, 0, -29574, 0, -7216, 0, 22516, 0, -7215, 0, 23508, 0, -7214, 0, 24335, 0, -7213, 0, 24687, 0, -7212, 0, 25325, 0, -7211, 0, 26893, 0, -7210, 0, 27542, 0, -7209, 0, 28252, 0, -7208, 0, 29060, 0, -7207, 0, 31698, 0, -7206, 0, -30891, 0, -7205, 0, -29864, 0, -7204, 0, -28930, 0, -7203, 0, -26401, 0, -7202, 0, -26370, 0, -7201, 0, 20280, 0, -7200, 0, 20353, 0, -7199, 0, 20449, 0, -7198, 0, 21627, 0, -7197, 0, 23072, 0, -7196, 0, 23480, 0, -7195, 0, 24892, 0, -7194, 0, 26032, 0, -7193, 0, 26216, 0, -7192, 0, 29180, 0, -7191, 0, 30003, 0, -7190, 0, 31070, 0, -7189, 0, 32051, 0, -7188, 0, -32434, 0, -7187, 0, -32285, 0, -7186, 0, -31848, 0, -7185, 0, -31318, 0, -7184, 0, -31282, 0, -7183, 0, -30973, 0, -7182, 0, -30198, 0, -7181, 0, -29013, 0, -7180, 0, -28773, 0, -7179, 0, -1679, 0, -7178, 0, -28731, 0, -7177, 0, 22833, 0, -7176, 0, 23460, 0, -7175, 0, 23526, 0, -7174, 0, 24713, 0, -7173, 0, 23529, 0, -7172, 0, 23563, 0, -7171, 0, 24515, 0, -7170, 0, 27777, 0, -7007, 0, -1678, 0, -7006, 0, 28145, 0, -7005, 0, 28683, 0, -7004, 0, 29978, 0, -7003, 0, -32081, 0, -7002, 0, -29962, 0, -7001, 0, 20160, 0, -7000, 0, 21313, 0, -6999, 0, -1677, 0, -6998, 0, -26919, 0, -6997, 0, 27663, 0, -6996, 0, 20126, 0, -6995, 0, 20420, 0, -6994, 0, 20818, 0, -6993, 0, 21854, 0, -6992, 0, 23077, 0, -6991, 0, 23784, 0, -6990, 0, 25105, 0, -6989, 0, 29273, 0, -6988, 0, -32067, 0, -6987, 0, -31830, 0, -6986, 0, -30978, 0, -6985, 0, -30631, 0, -6984, 0, -30179, 0, -6983, 0, -27073, 0, -6982, 0, -26939, 0, -6981, 0, -26349, 0, -6980, 0, -25335, 0, -6979, 0, -25251, 0, -6978, 0, 22538, 0, -6977, 0, 23731, 0, -6976, 0, 23997, 0, -6975, 0, 24132, 0, -6974, 0, 24801, 0, -6973, 0, 24853, 0, -6972, 0, 25569, 0, -6971, 0, 27138, 0, -6970, 0, 28197, 0, -6969, 0, -28414, 0, -6968, 0, -27820, 0, -6967, 0, -26546, 0, -6966, 0, -25584, 0, -6965, 0, -24713, 0, -6964, 0, 23433, 0, -6963, 0, 23736, 0, -6962, 0, 25353, 0, -6961, 0, 26191, 0, -6960, 0, 26696, 0, -6959, 0, 30524, 0, -6958, 0, -26943, 0, -6957, 0, -26739, 0, -6956, 0, -26540, 0, -6955, 0, -25697, 0, -6954, 0, 26017, 0, -6953, 0, -29951, 0, -6952, 0, -28981, 0, -6951, 0, -27204, 0, -6950, 0, 21813, 0, -6949, 0, 23721, 0, -6948, 0, 24022, 0, -6947, 0, 24245, 0, -6946, 0, 26263, 0, -6945, 0, 30284, 0, -6944, 0, -31756, 0, -6943, 0, -27193, 0, -6942, 0, 22739, 0, -6941, 0, 25276, 0, -6940, 0, 29390, 0, -6939, 0, -25304, 0, -6938, 0, 20208, 0, -6937, 0, 22830, 0, -6936, 0, 24591, 0, -6935, 0, 26171, 0, -6934, 0, 27523, 0, -6933, 0, 31207, 0, -6932, 0, -25306, 0, -6931, 0, 21395, 0, -6930, 0, 21696, 0, -6929, 0, 22467, 0, -6928, 0, 23830, 0, -6927, 0, 24859, 0, -6926, 0, 26326, 0, -6925, 0, 28079, 0, -6924, 0, 30861, 0, -6923, 0, -32130, 0, -6922, 0, -26984, 0, -6921, 0, -26812, 0, -6920, 0, 21380, 0, -6919, 0, 25212, 0, -6918, 0, 25494, 0, -6917, 0, 28082, 0, -6916, 0, 32266, 0, -6915, 0, -32437, 0, -6914, 0, -26547, 0, -6751, 0, 27387, 0, -6750, 0, 32588, 0, -6749, 0, -25169, 0, -6748, 0, -25062, 0, -6747, 0, 20063, 0, -6746, 0, 20539, 0, -6745, 0, 20918, 0, -6744, 0, 22812, 0, -6743, 0, 24825, 0, -6742, 0, 25590, 0, -6741, 0, 26928, 0, -6740, 0, 29242, 0, -6739, 0, -32714, 0, -6738, 0, -1676, 0, -6737, 0, -28210, 0, -6736, 0, 24369, 0, -6735, 0, -1675, 0, -6734, 0, -1674, 0, -6733, 0, 32004, 0, -6732, 0, -32027, 0, -6731, 0, -31633, 0, -6730, 0, -31557, 0, -6729, 0, -31259, 0, -6728, 0, -29043, 0, -6727, 0, -1673, 0, -6726, 0, 20335, 0, -6725, 0, -1672, 0, -6724, 0, -1671, 0, -6723, 0, 22756, 0, -6722, 0, 23363, 0, -6721, 0, 24665, 0, -6720, 0, 25562, 0, -6719, 0, 25880, 0, -6718, 0, 25965, 0, -6717, 0, 26264, 0, -6716, 0, -1670, 0, -6715, 0, 26954, 0, -6714, 0, 27171, 0, -6713, 0, 27915, 0, -6712, 0, 28673, 0, -6711, 0, 29036, 0, -6710, 0, 30162, 0, -6709, 0, 30221, 0, -6708, 0, 31155, 0, -6707, 0, 31344, 0, -6706, 0, -1669, 0, -6705, 0, 32650, 0, -6704, 0, -1668, 0, -6703, 0, -30396, 0, -6702, 0, -1667, 0, -6701, 0, -29805, 0, -6700, 0, -28224, 0, -6699, 0, -27011, 0, -6698, 0, -1666, 0, -6697, 0, -26358, 0, -6696, 0, 22276, 0, -6695, 0, 24481, 0, -6694, 0, 26044, 0, -6693, 0, 28417, 0, -6692, 0, 30208, 0, -6691, 0, 31142, 0, -6690, 0, -30050, 0, -6689, 0, -26195, 0, -6688, 0, -25766, 0, -6687, 0, -24724, 0, -6686, 0, 20740, 0, -6685, 0, 25014, 0, -6684, 0, 25233, 0, -6683, 0, 27277, 0, -6682, 0, -32314, 0, -6681, 0, 20547, 0, -6680, 0, 22576, 0, -6679, 0, 24422, 0, -6678, 0, 28937, 0, -6677, 0, -30208, 0, -6676, 0, -29958, 0, -6675, 0, 23420, 0, -6674, 0, -31210, 0, -6673, 0, 20474, 0, -6672, 0, 20796, 0, -6671, 0, 22196, 0, -6670, 0, 22852, 0, -6669, 0, 25513, 0, -6668, 0, 28153, 0, -6667, 0, 23978, 0, -6666, 0, 26989, 0, -6665, 0, 20870, 0, -6664, 0, 20104, 0, -6663, 0, 20313, 0, -6662, 0, -1665, 0, -6661, 0, -1664, 0, -6660, 0, -1663, 0, -6659, 0, 22914, 0, -6658, 0, -1662, 0, -6495, 0, -1661, 0, -6494, 0, 27487, 0, -6493, 0, 27741, 0, -6492, 0, -1660, 0, -6491, 0, 29877, 0, -6490, 0, 30998, 0, -6489, 0, -1659, 0, -6488, 0, -32249, 0, -6487, 0, -32187, 0, -6486, 0, -31943, 0, -6485, 0, -28865, 0, -6484, 0, -28835, 0, -6483, 0, -1658, 0, -6482, 0, -26344, 0, -6481, 0, -1657, 0, -6480, 0, -1656, 0, -6479, 0, -1655, 0, -6478, 0, 20134, 0, -6477, 0, -1654, 0, -6476, 0, 22495, 0, -6475, 0, 24441, 0, -6474, 0, 26131, 0, -6473, 0, -1653, 0, -6472, 0, -1652, 0, -6471, 0, 30123, 0, -6470, 0, 32377, 0, -6469, 0, -29841, 0, -6468, 0, -1651, 0, -6467, 0, -28666, 0, -6466, 0, -26021, 0, -6465, 0, 22181, 0, -6464, 0, 22567, 0, -6463, 0, 23032, 0, -6462, 0, 23071, 0, -6461, 0, 23476, 0, -6460, 0, -1650, 0, -6459, 0, 24310, 0, -6458, 0, -1649, 0, -6457, 0, -1648, 0, -6456, 0, 25424, 0, -6455, 0, 25403, 0, -6454, 0, -1647, 0, -6453, 0, 26941, 0, -6452, 0, 27783, 0, -6451, 0, 27839, 0, -6450, 0, 28046, 0, -6449, 0, 28051, 0, -6448, 0, 28149, 0, -6447, 0, 28436, 0, -6446, 0, -1646, 0, -6445, 0, 28895, 0, -6444, 0, 28982, 0, -6443, 0, 29017, 0, -6442, 0, -1645, 0, -6441, 0, 29123, 0, -6440, 0, 29141, 0, -6439, 0, -1644, 0, -6438, 0, 30799, 0, -6437, 0, 30831, 0, -6436, 0, -1643, 0, -6435, 0, 31605, 0, -6434, 0, 32227, 0, -6433, 0, -1642, 0, -6432, 0, 32303, 0, -6431, 0, -1641, 0, -6430, 0, -30643, 0, -6429, 0, -28961, 0, -6428, 0, -1640, 0, -6427, 0, -1639, 0, -6426, 0, -1638, 0, -6425, 0, -28069, 0, -6424, 0, -1637, 0, -6423, 0, -25354, 0, -6422, 0, -1636, 0, -6421, 0, -1635, 0, -6420, 0, -1634, 0, -6419, 0, 24709, 0, -6418, 0, 28037, 0, -6417, 0, -1633, 0, -6416, 0, 29105, 0, -6415, 0, -1632, 0, -6414, 0, -1631, 0, -6413, 0, -27215, 0, -6412, 0, 21421, 0, -6411, 0, -1630, 0, -6410, 0, -1629, 0, -6409, 0, -1628, 0, -6408, 0, 26579, 0, -6407, 0, -1627, 0, -6406, 0, 28814, 0, -6405, 0, 28976, 0, -6404, 0, 29744, 0, -6403, 0, -32138, 0, -6402, 0, -32046, 0, -6239, 0, -1626, 0, -6238, 0, -27205, 0, -6237, 0, -25883, 0, -6236, 0, -24963, 0, -6235, 0, 26308, 0, -6234, 0, -1625, 0, -6233, 0, 29121, 0, -6232, 0, -31671, 0, -6231, 0, -1624, 0, -6230, 0, -1623, 0, -6229, 0, 22603, 0, -6228, 0, -1622, 0, -6227, 0, -1621, 0, -6226, 0, 23992, 0, -6225, 0, 24433, 0, -6224, 0, -1620, 0, -6223, 0, 26144, 0, -6222, 0, 26254, 0, -6221, 0, 27001, 0, -6220, 0, 27054, 0, -6219, 0, 27704, 0, -6218, 0, 27891, 0, -6217, 0, 28214, 0, -6216, 0, 28481, 0, -6215, 0, 28634, 0, -6214, 0, 28699, 0, -6213, 0, 28719, 0, -6212, 0, 29008, 0, -6211, 0, 29151, 0, -6210, 0, 29552, 0, -6209, 0, -1619, 0, -6208, 0, 29787, 0, -6207, 0, -1618, 0, -6206, 0, 29908, 0, -6205, 0, 30408, 0, -6204, 0, 31310, 0, -6203, 0, 32403, 0, -6202, 0, -1617, 0, -6201, 0, -1616, 0, -6200, 0, -32015, 0, -6199, 0, -30112, 0, -6198, 0, -28722, 0, -6197, 0, -1615, 0, -6196, 0, -27832, 0, -6195, 0, -1614, 0, -6194, 0, -26855, 0, -6193, 0, -1613, 0, -6192, 0, -1612, 0, -6191, 0, 20034, 0, -6190, 0, 20522, 0, -6189, 0, -1611, 0, -6188, 0, 21000, 0, -6187, 0, 21473, 0, -6186, 0, 26355, 0, -6185, 0, 27757, 0, -6184, 0, 28618, 0, -6183, 0, 29450, 0, -6182, 0, 30591, 0, -6181, 0, 31330, 0, -6180, 0, -32082, 0, -6179, 0, -31267, 0, -6178, 0, -31230, 0, -6177, 0, -1610, 0, -6176, 0, -30508, 0, -6175, 0, -30109, 0, -6174, 0, -29827, 0, -6173, 0, -29589, 0, -6172, 0, -1609, 0, -6171, 0, -27981, 0, -6170, 0, -1608, 0, -6169, 0, -26861, 0, -6168, 0, -26608, 0, -6167, 0, 20116, 0, -6166, 0, 20237, 0, -6165, 0, 20425, 0, -6164, 0, 20658, 0, -6163, 0, 21320, 0, -6162, 0, 21566, 0, -6161, 0, 21555, 0, -6160, 0, 21978, 0, -6159, 0, 22626, 0, -6158, 0, 22714, 0, -6157, 0, 22887, 0, -6156, 0, 23067, 0, -6155, 0, 23524, 0, -6154, 0, 24735, 0, -6153, 0, -1607, 0, -6152, 0, 25034, 0, -6151, 0, 25942, 0, -6150, 0, 26111, 0, -6149, 0, 26212, 0, -6148, 0, 26791, 0, -6147, 0, 27738, 0, -6146, 0, 28595, 0, -5983, 0, 28879, 0, -5982, 0, 29100, 0, -5981, 0, 29522, 0, -5980, 0, 31613, 0, -5979, 0, -30968, 0, -5978, 0, -30044, 0, -5977, 0, -25550, 0, -5976, 0, -24825, 0, -5975, 0, 23627, 0, -5974, 0, 27779, 0, -5973, 0, 29508, 0, -5972, 0, 29577, 0, -5971, 0, -28102, 0, -5970, 0, 28331, 0, -5969, 0, 29797, 0, -5968, 0, 30239, 0, -5967, 0, 31337, 0, -5966, 0, 32277, 0, -5965, 0, -31222, 0, -5964, 0, 20800, 0, -5963, 0, 22725, 0, -5962, 0, 25793, 0, -5961, 0, 29934, 0, -5960, 0, 29973, 0, -5959, 0, 30320, 0, -5958, 0, 32705, 0, -5957, 0, -28523, 0, -5956, 0, -26931, 0, -5955, 0, -26284, 0, -5954, 0, 28198, 0, -5953, 0, 29926, 0, -5952, 0, 31401, 0, -5951, 0, 31402, 0, -5950, 0, -32283, 0, -5949, 0, -31015, 0, -5948, 0, -30856, 0, -5947, 0, -30181, 0, -5946, 0, 23113, 0, -5945, 0, 23436, 0, -5944, 0, 23451, 0, -5943, 0, 26785, 0, -5942, 0, 26880, 0, -5941, 0, 28003, 0, -5940, 0, 29609, 0, -5939, 0, 29715, 0, -5938, 0, 29740, 0, -5937, 0, 30871, 0, -5936, 0, 32233, 0, -5935, 0, 32747, 0, -5934, 0, -32488, 0, -5933, 0, -32427, 0, -5932, 0, -31842, 0, -5931, 0, -29620, 0, -5930, 0, -27090, 0, -5929, 0, -26607, 0, -5928, 0, 26352, 0, -5927, 0, 24448, 0, -5926, 0, 26106, 0, -5925, 0, 26505, 0, -5924, 0, 27754, 0, -5923, 0, 29579, 0, -5922, 0, 20525, 0, -5921, 0, 23043, 0, -5920, 0, 27498, 0, -5919, 0, 30702, 0, -5918, 0, 22806, 0, -5917, 0, 23916, 0, -5916, 0, 24013, 0, -5915, 0, 29477, 0, -5914, 0, 30031, 0, -5913, 0, -1606, 0, -5912, 0, -1605, 0, -5911, 0, 20709, 0, -5910, 0, 20985, 0, -5909, 0, 22575, 0, -5908, 0, 22829, 0, -5907, 0, 22934, 0, -5906, 0, 23002, 0, -5905, 0, 23525, 0, -5904, 0, -1604, 0, -5903, 0, -1603, 0, -5902, 0, 23970, 0, -5901, 0, 25303, 0, -5900, 0, 25622, 0, -5899, 0, 25747, 0, -5898, 0, 25854, 0, -5897, 0, -1602, 0, -5896, 0, 26332, 0, -5895, 0, -1601, 0, -5894, 0, 27208, 0, -5893, 0, -1600, 0, -5892, 0, 29183, 0, -5891, 0, 29796, 0, -5890, 0, -1599, 0, -5727, 0, 31368, 0, -5726, 0, 31407, 0, -5725, 0, 32327, 0, -5724, 0, 32350, 0, -5723, 0, -32768, 0, -5722, 0, -32400, 0, -5721, 0, -1598, 0, -5720, 0, -30737, 0, -5719, 0, -30335, 0, -5718, 0, -29920, 0, -5717, 0, -28583, 0, -5716, 0, -1597, 0, -5715, 0, -28544, 0, -5714, 0, -26286, 0, -5713, 0, 24958, 0, -5712, 0, 27442, 0, -5711, 0, 28020, 0, -5710, 0, 32287, 0, -5709, 0, -30427, 0, -5708, 0, -28751, 0, -5707, 0, 20433, 0, -5706, 0, 20653, 0, -5705, 0, 20887, 0, -5704, 0, 21191, 0, -5703, 0, 22471, 0, -5702, 0, 22665, 0, -5701, 0, 23481, 0, -5700, 0, 24248, 0, -5699, 0, 24898, 0, -5698, 0, 27029, 0, -5697, 0, 28044, 0, -5696, 0, 28263, 0, -5695, 0, 28342, 0, -5694, 0, 29076, 0, -5693, 0, 29794, 0, -5692, 0, 29992, 0, -5691, 0, 29996, 0, -5690, 0, -32653, 0, -5689, 0, -31944, 0, -5688, 0, -31543, 0, -5687, 0, -29174, 0, -5686, 0, -27756, 0, -5685, 0, -27682, 0, -5684, 0, -1596, 0, -5683, 0, 20110, 0, -5682, 0, 20305, 0, -5681, 0, 20598, 0, -5680, 0, 20778, 0, -5679, 0, 21448, 0, -5678, 0, 21451, 0, -5677, 0, 21491, 0, -5676, 0, 23431, 0, -5675, 0, 23507, 0, -5674, 0, 23588, 0, -5673, 0, 24858, 0, -5672, 0, 24962, 0, -5671, 0, 26100, 0, -5670, 0, 29275, 0, -5669, 0, 29591, 0, -5668, 0, 29760, 0, -5667, 0, 30402, 0, -5666, 0, 31056, 0, -5665, 0, 31121, 0, -5664, 0, 31161, 0, -5663, 0, 32006, 0, -5662, 0, 32701, 0, -5661, 0, -32117, 0, -5660, 0, -31275, 0, -5659, 0, -31138, 0, -5658, 0, -28734, 0, -5657, 0, -28601, 0, -5656, 0, -28427, 0, -5655, 0, -28182, 0, -5654, 0, -27003, 0, -5653, 0, -26904, 0, -5652, 0, -26903, 0, -5651, 0, 21206, 0, -5650, 0, 24423, 0, -5649, 0, 26093, 0, -5648, 0, 26161, 0, -5647, 0, 26671, 0, -5646, 0, 29020, 0, -5645, 0, 31286, 0, -5644, 0, -28479, 0, -5643, 0, -26614, 0, -5642, 0, 20113, 0, -5641, 0, -1595, 0, -5640, 0, 27218, 0, -5639, 0, 27550, 0, -5638, 0, 28560, 0, -5637, 0, 29065, 0, -5636, 0, -32744, 0, -5635, 0, -32072, 0, -5634, 0, -31405, 0, -5471, 0, -28597, 0, -5470, 0, -26987, 0, -5469, 0, -26894, 0, -5468, 0, -26629, 0, -5467, 0, -31462, 0, -5466, 0, -25807, 0, -5465, 0, 20112, 0, -5464, 0, 29066, 0, -5463, 0, -26940, 0, -5462, 0, 20803, 0, -5461, 0, 21407, 0, -5460, 0, 21729, 0, -5459, 0, 22291, 0, -5458, 0, 22290, 0, -5457, 0, 22435, 0, -5456, 0, 23195, 0, -5455, 0, 23236, 0, -5454, 0, 23491, 0, -5453, 0, 24616, 0, -5452, 0, 24895, 0, -5451, 0, 25588, 0, -5450, 0, 27781, 0, -5449, 0, 27961, 0, -5448, 0, 28274, 0, -5447, 0, 28304, 0, -5446, 0, 29232, 0, -5445, 0, 29503, 0, -5444, 0, 29783, 0, -5443, 0, -32047, 0, -5442, 0, -30591, 0, -5441, 0, -28859, 0, -5440, 0, -28576, 0, -5439, 0, -1594, 0, -5438, 0, -27038, 0, -5437, 0, -26536, 0, -5436, 0, -25317, 0, -5435, 0, 26376, 0, -5434, 0, -29302, 0, -5433, 0, -28066, 0, -5432, 0, 20301, 0, -5431, 0, 20553, 0, -5430, 0, 20702, 0, -5429, 0, 21361, 0, -5428, 0, 22285, 0, -5427, 0, 22996, 0, -5426, 0, 23041, 0, -5425, 0, 23561, 0, -5424, 0, 24944, 0, -5423, 0, 26256, 0, -5422, 0, 28205, 0, -5421, 0, 29234, 0, -5420, 0, 29771, 0, -5419, 0, 32239, 0, -5418, 0, -32573, 0, -5417, 0, -31730, 0, -5416, 0, -31642, 0, -5415, 0, -31425, 0, -5414, 0, -30881, 0, -5413, 0, -30629, 0, -5412, 0, -30440, 0, -5411, 0, -29950, 0, -5410, 0, -28587, 0, -5409, 0, -26677, 0, -5408, 0, -25777, 0, -5407, 0, 20083, 0, -5406, 0, 20369, 0, -5405, 0, 20754, 0, -5404, 0, 20842, 0, -5403, 0, -1593, 0, -5402, 0, 21807, 0, -5401, 0, 21929, 0, -5400, 0, 23418, 0, -5399, 0, 23461, 0, -5398, 0, 24188, 0, -5397, 0, 24189, 0, -5396, 0, 24254, 0, -5395, 0, 24736, 0, -5394, 0, 24799, 0, -5393, 0, 24840, 0, -5392, 0, 24841, 0, -5391, 0, 25540, 0, -5390, 0, 25912, 0, -5389, 0, 26377, 0, -5388, 0, -1592, 0, -5387, 0, 26580, 0, -5386, 0, 26586, 0, -5385, 0, -1591, 0, -5384, 0, 26977, 0, -5383, 0, 26978, 0, -5382, 0, 27833, 0, -5381, 0, 27943, 0, -5380, 0, -1590, 0, -5379, 0, 28216, 0, -5378, 0, -1589, 0, -5215, 0, 28641, 0, -5214, 0, 29494, 0, -5213, 0, 29495, 0, -5212, 0, -1588, 0, -5211, 0, 29788, 0, -5210, 0, 30001, 0, -5209, 0, -1587, 0, -5208, 0, 30290, 0, -5207, 0, -1586, 0, -5206, 0, -1585, 0, -5205, 0, 32173, 0, -5204, 0, -32258, 0, -5203, 0, -31688, 0, -5202, 0, -30507, 0, -5201, 0, -30056, 0, -5200, 0, -29989, 0, -5199, 0, -29971, 0, -5198, 0, -29136, 0, -5197, 0, -29118, 0, -5196, 0, -28598, 0, -5195, 0, -28610, 0, -5194, 0, -28550, 0, -5193, 0, -28343, 0, -5192, 0, -28215, 0, -5191, 0, -27794, 0, -5190, 0, -1584, 0, -5189, 0, -1583, 0, -5188, 0, 22537, 0, -5187, 0, -1582, 0, -5186, 0, 27603, 0, -5185, 0, -32631, 0, -5184, 0, -32590, 0, -5183, 0, -1581, 0, -5182, 0, -1580, 0, -5181, 0, 20801, 0, -5180, 0, 22891, 0, -5179, 0, 23609, 0, -5178, 0, -1579, 0, -5177, 0, -1578, 0, -5176, 0, 28516, 0, -5175, 0, 29607, 0, -5174, 0, -32540, 0, -5173, 0, -29433, 0, -5172, 0, -1577, 0, -5171, 0, -28137, 0, -5170, 0, -27249, 0, -5169, 0, -1576, 0, -5168, 0, -1575, 0, -5167, 0, -1574, 0, -5166, 0, -1573, 0, -5165, 0, -32641, 0, -5164, 0, 25102, 0, -5163, 0, 28700, 0, -5162, 0, 32104, 0, -5161, 0, -30835, 0, -5160, 0, -1572, 0, -5159, 0, 22432, 0, -5158, 0, 24681, 0, -5157, 0, 24903, 0, -5156, 0, 27575, 0, -5155, 0, -30018, 0, -5154, 0, -28032, 0, -5153, 0, -26959, 0, -5152, 0, 20057, 0, -5151, 0, 21535, 0, -5150, 0, 28139, 0, -5149, 0, -31443, 0, -5148, 0, -27024, 0, -5147, 0, -26637, 0, -5146, 0, -26386, 0, -5145, 0, 25558, 0, -5144, 0, 27875, 0, -5143, 0, -28527, 0, -5142, 0, 20957, 0, -5141, 0, 25033, 0, -5140, 0, -32326, 0, -5139, 0, -25095, 0, -5138, 0, 20381, 0, -5137, 0, 20506, 0, -5136, 0, 20736, 0, -5135, 0, 23452, 0, -5134, 0, 24847, 0, -5133, 0, 25087, 0, -5132, 0, 25836, 0, -5131, 0, 26885, 0, -5130, 0, 27589, 0, -5129, 0, 30097, 0, -5128, 0, 30691, 0, -5127, 0, 32681, 0, -5126, 0, -32156, 0, -5125, 0, -31345, 0, -5124, 0, -30725, 0, -5123, 0, -30621, 0, -5122, 0, -30020, 0, -4959, 0, -29840, 0, -4958, 0, -28245, 0, -4957, 0, 20108, 0, -4956, 0, 20197, 0, -4955, 0, 20234, 0, -4954, 0, -1571, 0, -4953, 0, -1570, 0, -4952, 0, 22839, 0, -4951, 0, 23016, 0, -4950, 0, -1569, 0, -4949, 0, 24050, 0, -4948, 0, 24347, 0, -4947, 0, 24411, 0, -4946, 0, 24609, 0, -4945, 0, -1568, 0, -4944, 0, -1567, 0, -4943, 0, -1566, 0, -4942, 0, -1565, 0, -4941, 0, 29246, 0, -4940, 0, 29669, 0, -4939, 0, -1564, 0, -4938, 0, 30064, 0, -4937, 0, 30157, 0, -4936, 0, -1563, 0, -4935, 0, 31227, 0, -4934, 0, -1562, 0, -4933, 0, -32756, 0, -4932, 0, -32717, 0, -4931, 0, -32636, 0, -4930, 0, -32031, 0, -4929, 0, -31919, 0, -4928, 0, -1561, 0, -4927, 0, -1560, 0, -4926, 0, -29507, 0, -4925, 0, -29517, 0, -4924, 0, -28537, 0, -4923, 0, -1559, 0, -4922, 0, -1558, 0, -4921, 0, -26380, 0, -4920, 0, -26356, 0, -4919, 0, -1557, 0, -4918, 0, -1556, 0, -4917, 0, 28727, 0, -4916, 0, 30410, 0, -4915, 0, 32714, 0, -4914, 0, 32716, 0, -4913, 0, 32764, 0, -4912, 0, -29926, 0, -4911, 0, 20154, 0, -4910, 0, 20161, 0, -4909, 0, 20995, 0, -4908, 0, 21360, 0, -4907, 0, -1555, 0, -4906, 0, 21693, 0, -4905, 0, 22240, 0, -4904, 0, 23035, 0, -4903, 0, 23493, 0, -4902, 0, 24341, 0, -4901, 0, 24525, 0, -4900, 0, 28270, 0, -4899, 0, -1554, 0, -4898, 0, -1553, 0, -4897, 0, 32106, 0, -4896, 0, -31947, 0, -4895, 0, -1552, 0, -4894, 0, -31085, 0, -4893, 0, -30067, 0, -4892, 0, -1551, 0, -4891, 0, -26771, 0, -4890, 0, -26761, 0, -4889, 0, -1550, 0, -4888, 0, -1549, 0, -4887, 0, 19968, 0, -4886, 0, 20314, 0, -4885, 0, 20350, 0, -4884, 0, 22777, 0, -4883, 0, 26085, 0, -4882, 0, 28322, 0, -4881, 0, -28616, 0, -4880, 0, -27728, 0, -4879, 0, -26183, 0, -4878, 0, 20219, 0, -4877, 0, 22764, 0, -4876, 0, 22922, 0, -4875, 0, 23001, 0, -4874, 0, 24641, 0, -4873, 0, -1548, 0, -4872, 0, -1547, 0, -4871, 0, 31252, 0, -4870, 0, -1546, 0, -4869, 0, -31921, 0, -4868, 0, -29501, 0, -4867, 0, 20837, 0, -4866, 0, 21316, 0, -4703, 0, -1545, 0, -4702, 0, -1544, 0, -4701, 0, -1543, 0, -4700, 0, 20173, 0, -4699, 0, 21097, 0, -4698, 0, 23381, 0, -4697, 0, -32065, 0, -4696, 0, 20180, 0, -4695, 0, 21050, 0, -4694, 0, 21672, 0, -4693, 0, 22985, 0, -4692, 0, 23039, 0, -4691, 0, 23376, 0, -4690, 0, 23383, 0, -4689, 0, 23388, 0, -4688, 0, 24675, 0, -4687, 0, 24904, 0, -4686, 0, 28363, 0, -4685, 0, 28825, 0, -4684, 0, 29038, 0, -4683, 0, 29574, 0, -4682, 0, 29943, 0, -4681, 0, 30133, 0, -4680, 0, 30913, 0, -4679, 0, 32043, 0, -4678, 0, -32763, 0, -4677, 0, -32278, 0, -4676, 0, -31960, 0, -4675, 0, -31465, 0, -4674, 0, -31287, 0, -4673, 0, -29970, 0, -4672, 0, -29497, 0, -4671, 0, -26932, 0, -4670, 0, 20316, 0, -4669, 0, 21242, 0, -4668, 0, 22204, 0, -4667, 0, 26027, 0, -4666, 0, 26152, 0, -4665, 0, 28796, 0, -4664, 0, 28856, 0, -4663, 0, 29237, 0, -4662, 0, 32189, 0, -4661, 0, -32115, 0, -4660, 0, -28340, 0, -4659, 0, -26944, 0, -4658, 0, -25230, 0, -4657, 0, 23409, 0, -4656, 0, 26855, 0, -4655, 0, 27544, 0, -4654, 0, 28538, 0, -4653, 0, 30430, 0, -4652, 0, 23697, 0, -4651, 0, 26283, 0, -4650, 0, 28507, 0, -4649, 0, 31668, 0, -4648, 0, 31786, 0, -4647, 0, -30666, 0, -4646, 0, -26916, 0, -4645, 0, 19976, 0, -4644, 0, 20183, 0, -4643, 0, 21280, 0, -4642, 0, 22580, 0, -4641, 0, 22715, 0, -4640, 0, 22767, 0, -4639, 0, 22892, 0, -4638, 0, 23559, 0, -4637, 0, 24115, 0, -4636, 0, 24196, 0, -4635, 0, 24373, 0, -4634, 0, 25484, 0, -4633, 0, 26290, 0, -4632, 0, 26454, 0, -4631, 0, 27167, 0, -4630, 0, 27299, 0, -4629, 0, 27404, 0, -4628, 0, 28479, 0, -4627, 0, 29254, 0, -4626, 0, -1542, 0, -4625, 0, 29520, 0, -4624, 0, 29835, 0, -4623, 0, 31456, 0, -4622, 0, 31911, 0, -4621, 0, -32392, 0, -4620, 0, -32289, 0, -4619, 0, -32281, 0, -4618, 0, -31862, 0, -4617, 0, -31636, 0, -4616, 0, -31453, 0, -4615, 0, -31340, 0, -4614, 0, -31281, 0, -4613, 0, -30499, 0, -4612, 0, -29421, 0, -4611, 0, -28244, 0, -4610, 0, -27273, 0, -4447, 0, -26980, 0, -4446, 0, 20877, 0, -4445, 0, 21705, 0, -4444, 0, 22312, 0, -4443, 0, 23472, 0, -4442, 0, 25165, 0, -4441, 0, 26448, 0, -4440, 0, 26685, 0, -4439, 0, 26771, 0, -4438, 0, 28221, 0, -4437, 0, 28371, 0, -4436, 0, 28797, 0, -4435, 0, 32289, 0, -4434, 0, -30527, 0, -4433, 0, -29535, 0, -4432, 0, -28919, 0, -4431, 0, -24757, 0, -4430, 0, -24754, 0, -4429, 0, 29229, 0, -4428, 0, 31631, 0, -4427, 0, -30003, 0, -4426, 0, -27878, 0, -4425, 0, 20295, 0, -4424, 0, 20302, 0, -4423, 0, 20786, 0, -4422, 0, 21632, 0, -4421, 0, 22992, 0, -4420, 0, 24213, 0, -4419, 0, 25269, 0, -4418, 0, 26485, 0, -4417, 0, 26990, 0, -4416, 0, 27159, 0, -4415, 0, 27822, 0, -4414, 0, 28186, 0, -4413, 0, 29401, 0, -4412, 0, 29482, 0, -4411, 0, 30141, 0, -4410, 0, 31672, 0, -4409, 0, 32053, 0, -4408, 0, -32025, 0, -4407, 0, -31751, 0, -4406, 0, -31657, 0, -4405, 0, -31241, 0, -4404, 0, -30117, 0, -4403, 0, -29521, 0, -4402, 0, -29049, 0, -4401, 0, -28647, 0, -4400, 0, -28488, 0, -4399, 0, -26930, 0, -4398, 0, -24737, 0, -4397, 0, 21219, 0, -4396, 0, 21514, 0, -4395, 0, 23265, 0, -4394, 0, 23490, 0, -4393, 0, 25688, 0, -4392, 0, 25973, 0, -4391, 0, 28404, 0, -4390, 0, 29380, 0, -4389, 0, -1541, 0, -4388, 0, 30340, 0, -4387, 0, 31309, 0, -4386, 0, 31515, 0, -4385, 0, 31821, 0, -4384, 0, 32318, 0, -4383, 0, 32735, 0, -4382, 0, -31877, 0, -4381, 0, -29909, 0, -4380, 0, -29494, 0, -4379, 0, -29340, 0, -4378, 0, -29215, 0, -4377, 0, -29089, 0, -4376, 0, -28694, 0, -4375, 0, -28679, 0, -4374, 0, -28567, 0, -4373, 0, -27695, 0, -4372, 0, 20291, 0, -4371, 0, 20346, 0, -4370, 0, 20659, 0, -4369, 0, 20840, 0, -4368, 0, 20856, 0, -4367, 0, 21069, 0, -4366, 0, 21098, 0, -4365, 0, 22625, 0, -4364, 0, 22652, 0, -4363, 0, 22880, 0, -4362, 0, 23560, 0, -4361, 0, 23637, 0, -4360, 0, 24283, 0, -4359, 0, 24731, 0, -4358, 0, 25136, 0, -4357, 0, 26643, 0, -4356, 0, 27583, 0, -4355, 0, 27656, 0, -4354, 0, 28593, 0, -4191, 0, 29006, 0, -4190, 0, 29728, 0, -4189, 0, 30000, 0, -4188, 0, 30008, 0, -4187, 0, 30033, 0, -4186, 0, 30322, 0, -4185, 0, 31564, 0, -4184, 0, 31627, 0, -4183, 0, 31661, 0, -4182, 0, 31686, 0, -4181, 0, 32399, 0, -4180, 0, -30098, 0, -4179, 0, -28866, 0, -4178, 0, -28855, 0, -4177, 0, -28097, 0, -4176, 0, -28013, 0, -4175, 0, -27870, 0, -4174, 0, -27605, 0, -4173, 0, -26885, 0, -4172, 0, -26534, 0, -4171, 0, -26517, 0, -4170, 0, -26338, 0, -4169, 0, 20999, 0, -4168, 0, 25130, 0, -4167, 0, 25240, 0, -4166, 0, 27993, 0, -4165, 0, 30308, 0, -4164, 0, 31434, 0, -4163, 0, 31680, 0, -4162, 0, 32118, 0, -4161, 0, 21344, 0, -4160, 0, 23742, 0, -4159, 0, 24215, 0, -4158, 0, 28472, 0, -4157, 0, 28857, 0, -4156, 0, 31896, 0, -4155, 0, -26863, 0, -4154, 0, -25714, 0, -4153, 0, -24866, 0, -4152, 0, 25509, 0, -4151, 0, 25722, 0, -4150, 0, -30858, 0, -4149, 0, 19969, 0, -4148, 0, 20117, 0, -4147, 0, 20141, 0, -4146, 0, 20572, 0, -4145, 0, 20597, 0, -4144, 0, 21576, 0, -4143, 0, 22979, 0, -4142, 0, 23450, 0, -4141, 0, 24128, 0, -4140, 0, 24237, 0, -4139, 0, 24311, 0, -4138, 0, 24449, 0, -4137, 0, 24773, 0, -4136, 0, 25402, 0, -4135, 0, 25919, 0, -4134, 0, 25972, 0, -4133, 0, 26060, 0, -4132, 0, 26230, 0, -4131, 0, 26232, 0, -4130, 0, 26622, 0, -4129, 0, 26984, 0, -4128, 0, 27273, 0, -4127, 0, 27491, 0, -4126, 0, 27712, 0, -4125, 0, 28096, 0, -4124, 0, 28136, 0, -4123, 0, 28191, 0, -4122, 0, 28254, 0, -4121, 0, 28702, 0, -4120, 0, 28833, 0, -4119, 0, 29582, 0, -4118, 0, 29693, 0, -4117, 0, 30010, 0, -4116, 0, 30555, 0, -4115, 0, 30855, 0, -4114, 0, 31118, 0, -4113, 0, 31243, 0, -4112, 0, 31357, 0, -4111, 0, 31934, 0, -4110, 0, 32142, 0, -4109, 0, -32185, 0, -4108, 0, -30206, 0, -4107, 0, -29974, 0, -4106, 0, -29538, 0, -4105, 0, -28371, 0, -4104, 0, -28342, 0, -4103, 0, -28200, 0, -4102, 0, -28058, 0, -4101, 0, -27956, 0, -4100, 0, -27872, 0, -4099, 0, -26874, 0, -4098, 0, -26794, 0, -3935, 0, -26788, 0, -3934, 0, -26622, 0, -3933, 0, -24818, 0, -3932, 0, 21046, 0, -3931, 0, 21137, 0, -3930, 0, 21884, 0, -3929, 0, 22564, 0, -3928, 0, 24093, 0, -3927, 0, 24351, 0, -3926, 0, 24716, 0, -3925, 0, 25552, 0, -3924, 0, 26799, 0, -3923, 0, 28639, 0, -3922, 0, 31085, 0, -3921, 0, 31532, 0, -3920, 0, -32307, 0, -3919, 0, -31302, 0, -3918, 0, -30467, 0, -3917, 0, -29960, 0, -3916, 0, -29116, 0, -3915, 0, -28275, 0, -3914, 0, -27036, 0, -3913, 0, -26981, 0, -3912, 0, -26819, 0, -3911, 0, -26548, 0, -3910, 0, -24758, 0, -3909, 0, 20430, 0, -3908, 0, 20806, 0, -3907, 0, 20939, 0, -3906, 0, 21161, 0, -3905, 0, 22066, 0, -3904, 0, 24340, 0, -3903, 0, 24427, 0, -3902, 0, 25514, 0, -3901, 0, 25805, 0, -3900, 0, 26089, 0, -3899, 0, 26177, 0, -3898, 0, 26362, 0, -3897, 0, 26361, 0, -3896, 0, 26397, 0, -3895, 0, 26781, 0, -3894, 0, 26839, 0, -3893, 0, 27133, 0, -3892, 0, 28437, 0, -3891, 0, 28526, 0, -3890, 0, 29031, 0, -3889, 0, 29157, 0, -3888, 0, 29226, 0, -3887, 0, 29866, 0, -3886, 0, 30522, 0, -3885, 0, 31062, 0, -3884, 0, 31066, 0, -3883, 0, 31199, 0, -3882, 0, 31264, 0, -3881, 0, 31381, 0, -3880, 0, 31895, 0, -3879, 0, 31967, 0, -3878, 0, 32068, 0, -3877, 0, 32368, 0, -3876, 0, -32633, 0, -3875, 0, -31237, 0, -3874, 0, -31068, 0, -3873, 0, -30124, 0, -3872, 0, -30017, 0, -3871, 0, -29287, 0, -3870, 0, -29055, 0, -3869, 0, -28640, 0, -3868, 0, -28563, 0, -3867, 0, -28189, 0, -3866, 0, -27077, 0, -3865, 0, -26923, 0, -3864, 0, -25371, 0, -3863, 0, 26063, 0, -3862, 0, 31751, 0, -3861, 0, -29261, 0, -3860, 0, -27709, 0, -3859, 0, 23384, 0, -3858, 0, 23562, 0, -3857, 0, 21330, 0, -3856, 0, 25305, 0, -3855, 0, 29469, 0, -3854, 0, 20519, 0, -3853, 0, 23447, 0, -3852, 0, 24478, 0, -3851, 0, 24752, 0, -3850, 0, 24939, 0, -3849, 0, 26837, 0, -3848, 0, 28121, 0, -3847, 0, 29742, 0, -3846, 0, 31278, 0, -3845, 0, 32066, 0, -3844, 0, 32156, 0, -3843, 0, 32305, 0, -3842, 0, -32405, 0, -3679, 0, -29142, 0, -3678, 0, -29131, 0, -3677, 0, -27778, 0, -3676, 0, -27624, 0, -3675, 0, 20304, 0, -3674, 0, 22352, 0, -3673, 0, 24038, 0, -3672, 0, 24231, 0, -3671, 0, 25387, 0, -3670, 0, 32618, 0, -3669, 0, 20027, 0, -3668, 0, 20303, 0, -3667, 0, 20367, 0, -3666, 0, 20570, 0, -3665, 0, 23005, 0, -3664, 0, -32572, 0, -3663, 0, 21610, 0, -3662, 0, 21608, 0, -3661, 0, 22014, 0, -3660, 0, 22863, 0, -3659, 0, 23449, 0, -3658, 0, 24030, 0, -3657, 0, 24282, 0, -3656, 0, 26205, 0, -3655, 0, 26417, 0, -3654, 0, 26609, 0, -3653, 0, 26666, 0, -3652, 0, 27880, 0, -3651, 0, 27954, 0, -3650, 0, 28234, 0, -3649, 0, 28557, 0, -3648, 0, 28855, 0, -3647, 0, 29664, 0, -3646, 0, 30087, 0, -3645, 0, 31820, 0, -3644, 0, 32002, 0, -3643, 0, 32044, 0, -3642, 0, 32162, 0, -3641, 0, -32225, 0, -3640, 0, -31013, 0, -3639, 0, -30149, 0, -3638, 0, -30075, 0, -3637, 0, -29328, 0, -3636, 0, -29046, 0, -3635, 0, -28877, 0, -3634, 0, -28623, 0, -3633, 0, -28338, 0, -3632, 0, -28334, 0, -3631, 0, -27580, 0, -3630, 0, -26160, 0, -3629, 0, 31481, 0, -3628, 0, 31909, 0, -3627, 0, 20426, 0, -3626, 0, 20737, 0, -3625, 0, 20934, 0, -3624, 0, 22472, 0, -3623, 0, 23535, 0, -3622, 0, 23803, 0, -3621, 0, 26201, 0, -3620, 0, 27197, 0, -3619, 0, 27994, 0, -3618, 0, 28310, 0, -3617, 0, 28652, 0, -3616, 0, 28940, 0, -3615, 0, 30063, 0, -3614, 0, 31459, 0, -3613, 0, -30686, 0, -3612, 0, -28639, 0, -3611, 0, -28555, 0, -3610, 0, -26933, 0, -3609, 0, -26113, 0, -3608, 0, -31999, 0, -3607, 0, 20013, 0, -3606, 0, 20210, 0, -3605, 0, -30650, 0, -3604, 0, -28211, 0, -3603, 0, 21373, 0, -3602, 0, 27355, 0, -3601, 0, 26987, 0, -3600, 0, 27713, 0, -3599, 0, -31622, 0, -3598, 0, 22686, 0, -3597, 0, 24974, 0, -3596, 0, 26366, 0, -3595, 0, 25327, 0, -3594, 0, 28893, 0, -3593, 0, 29969, 0, -3592, 0, 30151, 0, -3591, 0, 32338, 0, -3590, 0, -31560, 0, -3589, 0, -29879, 0, -3588, 0, -29432, 0, -3587, 0, 20043, 0, -3586, 0, 21482, 0, -3423, 0, 21675, 0, -3422, 0, 22320, 0, -3421, 0, 22336, 0, -3420, 0, 24535, 0, -3419, 0, 25345, 0, -3418, 0, 25351, 0, -3417, 0, 25711, 0, -3416, 0, 25903, 0, -3415, 0, 26088, 0, -3414, 0, 26234, 0, -3413, 0, 26525, 0, -3412, 0, 26547, 0, -3411, 0, 27490, 0, -3410, 0, 27744, 0, -3409, 0, 27802, 0, -3408, 0, 28460, 0, -3407, 0, 30693, 0, -3406, 0, 30757, 0, -3405, 0, 31049, 0, -3404, 0, 31063, 0, -3403, 0, 32025, 0, -3402, 0, -32606, 0, -3401, 0, -32510, 0, -3400, 0, -32269, 0, -3399, 0, -32099, 0, -3398, 0, -32073, 0, -3397, 0, -30952, 0, -3396, 0, -30068, 0, -3395, 0, -1540, 0, -3394, 0, -29436, 0, -3393, 0, -29250, 0, -3392, 0, -28558, 0, -3391, 0, 30452, 0, -3390, 0, 31257, 0, -3389, 0, 31287, 0, -3388, 0, 32340, 0, -3387, 0, -32649, 0, -3386, 0, 21767, 0, -3385, 0, 21972, 0, -3384, 0, 22645, 0, -3383, 0, 25391, 0, -3382, 0, 25634, 0, -3381, 0, 26185, 0, -3380, 0, 26187, 0, -3379, 0, 26733, 0, -3378, 0, 27035, 0, -3377, 0, 27524, 0, -3376, 0, 27941, 0, -3375, 0, 28337, 0, -3374, 0, 29645, 0, -3373, 0, 29800, 0, -3372, 0, 29857, 0, -3371, 0, 30043, 0, -3370, 0, 30137, 0, -3369, 0, 30433, 0, -3368, 0, 30494, 0, -3367, 0, 30603, 0, -3366, 0, 31206, 0, -3365, 0, 32265, 0, -3364, 0, 32285, 0, -3363, 0, -32261, 0, -3362, 0, -31441, 0, -3361, 0, -30569, 0, -3360, 0, -30150, 0, -3359, 0, -29487, 0, -3358, 0, -28949, 0, -3357, 0, -28752, 0, -3356, 0, -28622, 0, -3355, 0, -27731, 0, -3354, 0, -27037, 0, -3353, 0, -27021, 0, -3352, 0, -26873, 0, -3351, 0, 20356, 0, -3350, 0, 21489, 0, -3349, 0, 23018, 0, -3348, 0, 23241, 0, -3347, 0, 24089, 0, -3346, 0, 26702, 0, -3345, 0, 29894, 0, -3344, 0, 30142, 0, -3343, 0, 31209, 0, -3342, 0, 31378, 0, -3341, 0, -32349, 0, -3340, 0, -30995, 0, -3339, 0, -29462, 0, -3338, 0, -29236, 0, -3337, 0, -28691, 0, -3336, 0, 26015, 0, -3335, 0, 26389, 0, -3334, 0, -1539, 0, -3333, 0, 22519, 0, -3332, 0, 28503, 0, -3331, 0, 32221, 0, -3330, 0, -28881, 0, -3167, 0, -27658, 0, -3166, 0, -26938, 0, -3165, 0, 24501, 0, -3164, 0, 25074, 0, -3163, 0, 28548, 0, -3162, 0, 19988, 0, -3161, 0, 20376, 0, -3160, 0, 20511, 0, -3159, 0, 21449, 0, -3158, 0, 21983, 0, -3157, 0, 23919, 0, -3156, 0, 24046, 0, -3155, 0, 27425, 0, -3154, 0, 27492, 0, -3153, 0, 30923, 0, -3152, 0, 31642, 0, -3151, 0, -1538, 0, -3150, 0, -29111, 0, -3149, 0, -28982, 0, -3148, 0, -28562, 0, -3147, 0, 25417, 0, -3146, 0, 25662, 0, -3145, 0, 30528, 0, -3144, 0, 31364, 0, -3143, 0, -27857, 0, -3142, 0, -27521, 0, -3141, 0, -24726, 0, -3140, 0, 25776, 0, -3139, 0, 28591, 0, -3138, 0, 29158, 0, -3137, 0, 29864, 0, -3136, 0, 29914, 0, -3135, 0, 31428, 0, -3134, 0, 31762, 0, -3133, 0, 32386, 0, -3132, 0, 31922, 0, -3131, 0, 32408, 0, -3130, 0, -29798, 0, -3129, 0, -29430, 0, -3128, 0, -27523, 0, -3127, 0, -26352, 0, -3126, 0, -26292, 0, -3125, 0, 21049, 0, -3124, 0, 23519, 0, -3123, 0, 25830, 0, -3122, 0, 26413, 0, -3121, 0, 32046, 0, -3120, 0, 20717, 0, -3119, 0, 21443, 0, -3118, 0, 22649, 0, -3117, 0, 24920, 0, -3116, 0, 24921, 0, -3115, 0, 25082, 0, -3114, 0, 26028, 0, -3113, 0, 31449, 0, -3112, 0, -29806, 0, -3111, 0, -29802, 0, -3110, 0, 20489, 0, -3109, 0, 20513, 0, -3108, 0, 21109, 0, -3107, 0, 21809, 0, -3106, 0, 23100, 0, -3105, 0, 24288, 0, -3104, 0, 24432, 0, -3103, 0, 24884, 0, -3102, 0, 25950, 0, -3101, 0, 26124, 0, -3100, 0, 26166, 0, -3099, 0, 26274, 0, -3098, 0, 27085, 0, -3097, 0, 28356, 0, -3096, 0, 28466, 0, -3095, 0, 29462, 0, -3094, 0, 30241, 0, -3093, 0, 31379, 0, -3092, 0, -32455, 0, -3091, 0, -32167, 0, -3090, 0, -31786, 0, -3089, 0, -31556, 0, -3088, 0, 20661, 0, -3087, 0, 22512, 0, -3086, 0, 23488, 0, -3085, 0, 23528, 0, -3084, 0, 24425, 0, -3083, 0, 25505, 0, -3082, 0, 30758, 0, -3081, 0, 32181, 0, -3080, 0, -31780, 0, -3079, 0, -31455, 0, -3078, 0, -28217, 0, -3077, 0, -28171, 0, -3076, 0, 20874, 0, -3075, 0, 26613, 0, -3074, 0, 31574, 0, -2911, 0, -29524, 0, -2910, 0, 20932, 0, -2909, 0, 22971, 0, -2908, 0, 24765, 0, -2907, 0, -31147, 0, -2906, 0, 20508, 0, -2905, 0, -1537, 0, -2904, 0, 21076, 0, -2903, 0, 23610, 0, -2902, 0, 24957, 0, -2901, 0, 25114, 0, -2900, 0, 25299, 0, -2899, 0, 25842, 0, -2898, 0, 26021, 0, -2897, 0, 28364, 0, -2896, 0, 30240, 0, -2895, 0, -32502, 0, -2894, 0, -29088, 0, -2893, 0, -27041, 0, -2892, 0, -26949, 0, -2891, 0, 20191, 0, -2890, 0, 21315, 0, -2889, 0, 21912, 0, -2888, 0, 22825, 0, -2887, 0, 24029, 0, -2886, 0, 25797, 0, -2885, 0, 27849, 0, -2884, 0, 28154, 0, -2883, 0, 29588, 0, -2882, 0, 31359, 0, -2881, 0, -32229, 0, -2880, 0, -31322, 0, -2879, 0, -29468, 0, -2878, 0, -29168, 0, -2877, 0, -28553, 0, -2876, 0, -28185, 0, -2875, 0, -27167, 0, -2874, 0, -27103, 0, -2873, 0, -26682, 0, -2872, 0, 20984, 0, -2871, 0, 21746, 0, -2870, 0, 21894, 0, -2869, 0, 24505, 0, -2868, 0, 25764, 0, -2867, 0, 28552, 0, -2866, 0, 32180, 0, -2865, 0, -28897, 0, -2864, 0, -28851, 0, -2863, 0, -27595, 0, -2862, 0, 20681, 0, -2861, 0, 23574, 0, -2860, 0, 27838, 0, -2859, 0, 28155, 0, -2858, 0, 29979, 0, -2857, 0, 30651, 0, -2856, 0, 31805, 0, -2855, 0, 31844, 0, -2854, 0, -30087, 0, -2853, 0, -30014, 0, -2852, 0, 22558, 0, -2851, 0, 22974, 0, -2850, 0, 24086, 0, -2849, 0, 25463, 0, -2848, 0, 29266, 0, -2847, 0, 30090, 0, -2846, 0, 30571, 0, -2845, 0, -29988, 0, -2844, 0, -29508, 0, -2843, 0, -28910, 0, -2842, 0, 24307, 0, -2841, 0, 26228, 0, -2840, 0, 28152, 0, -2839, 0, -32643, 0, -2838, 0, -31807, 0, -2837, 0, -30005, 0, -2836, 0, -26799, 0, -2835, 0, -25642, 0, -2834, 0, -1536, 0, -2833, 0, 21059, 0, -2832, 0, 26367, 0, -2831, 0, 28053, 0, -2830, 0, 28399, 0, -2829, 0, 32224, 0, -2828, 0, -29978, 0, -2827, 0, -28626, 0, -2826, 0, -28578, 0, -2825, 0, -25900, 0, -2824, 0, 21021, 0, -2823, 0, 21119, 0, -2822, 0, 21736, 0, -2821, 0, 24980, 0, -2820, 0, 25220, 0, -2819, 0, 25307, 0, -2818, 0, 26786, 0, -2655, 0, 26898, 0, -2654, 0, 26970, 0, -2653, 0, 27189, 0, -2652, 0, 28818, 0, -2651, 0, 28966, 0, -2650, 0, 30813, 0, -2649, 0, 30977, 0, -2648, 0, 30990, 0, -2647, 0, 31186, 0, -2646, 0, 31245, 0, -2645, 0, -32618, 0, -2644, 0, -32136, 0, -2643, 0, -32043, 0, -2642, 0, -31927, 0, -2641, 0, -31415, 0, -2640, 0, -29566, 0, -2639, 0, -29307, 0, -2638, 0, -28318, 0, -2637, 0, -28277, 0, -2636, 0, -28242, 0, -2635, 0, 20419, 0, -2634, 0, 22225, 0, -2633, 0, 29165, 0, -2632, 0, 30679, 0, -2631, 0, -30976, 0, -2630, 0, -30216, 0, -2629, 0, 23544, 0, -2628, 0, 24534, 0, -2627, 0, 26449, 0, -2626, 0, -28504, 0, -2625, 0, 21474, 0, -2624, 0, 22618, 0, -2623, 0, 23541, 0, -2622, 0, 24740, 0, -2621, 0, 24961, 0, -2620, 0, 25696, 0, -2619, 0, 32317, 0, -2618, 0, -32656, 0, -2617, 0, -31451, 0, -2616, 0, -28029, 0, -2615, 0, 25774, 0, -2614, 0, 20652, 0, -2613, 0, 23828, 0, -2612, 0, 26368, 0, -2611, 0, 22684, 0, -2610, 0, 25277, 0, -2609, 0, 25512, 0, -2608, 0, 26894, 0, -2607, 0, 27000, 0, -2606, 0, 27166, 0, -2605, 0, 28267, 0, -2604, 0, 30394, 0, -2603, 0, 31179, 0, -2602, 0, -32069, 0, -2601, 0, -31703, 0, -2600, 0, -30001, 0, -2599, 0, -29272, 0, -2598, 0, -28675, 0, -2597, 0, -28398, 0, -2596, 0, -28341, 0, -2595, 0, -28260, 0, -2594, 0, -27888, 0, -2593, 0, -27880, 0, -2592, 0, -27750, 0, -2591, 0, -26917, 0, -2590, 0, -26058, 0, -2589, 0, -25587, 0, -2588, 0, 19985, 0, -2587, 0, 30044, 0, -2586, 0, 31069, 0, -2585, 0, 31482, 0, -2584, 0, 31569, 0, -2583, 0, 31689, 0, -2582, 0, 32302, 0, -2581, 0, -31548, 0, -2580, 0, -29095, 0, -2579, 0, -29068, 0, -2578, 0, -28936, 0, -2577, 0, -28656, 0, -2576, 0, 26149, 0, -2575, 0, 26943, 0, -2574, 0, 29763, 0, -2573, 0, 20986, 0, -2572, 0, 26414, 0, -2571, 0, -24868, 0, -2570, 0, 20805, 0, -2569, 0, 24544, 0, -2568, 0, 27798, 0, -2567, 0, -30734, 0, -2566, 0, -30627, 0, -2565, 0, -30601, 0, -2564, 0, 24756, 0, -2563, 0, -32331, 0, -2562, 0, -31741, 0, -2399, 0, -29435, 0, -2398, 0, 21462, 0, -2397, 0, 21561, 0, -2396, 0, 22068, 0, -2395, 0, 23094, 0, -2394, 0, 23601, 0, -2393, 0, 28810, 0, -2392, 0, 32736, 0, -2391, 0, -32678, 0, -2390, 0, -32506, 0, -2389, 0, -32275, 0, -2388, 0, -29277, 0, -2387, 0, -28279, 0, -2386, 0, -26017, 0, -2385, 0, -25102, 0, -2384, 0, 20596, 0, -2383, 0, 20164, 0, -2382, 0, 21408, 0, -2381, 0, 24827, 0, -2380, 0, 28204, 0, -2379, 0, 23652, 0, -2378, 0, 20360, 0, -2377, 0, 20516, 0, -2376, 0, 21988, 0, -2375, 0, 23769, 0, -2374, 0, 24159, 0, -2373, 0, 24677, 0, -2372, 0, 26772, 0, -2371, 0, 27835, 0, -2370, 0, 28100, 0, -2369, 0, 29118, 0, -2368, 0, 30164, 0, -2367, 0, 30196, 0, -2366, 0, 30305, 0, -2365, 0, 31258, 0, -2364, 0, 31305, 0, -2363, 0, 32199, 0, -2362, 0, 32251, 0, -2361, 0, 32622, 0, -2360, 0, -32268, 0, -2359, 0, -31063, 0, -2358, 0, -28900, 0, -2357, 0, -26935, 0, -2356, 0, -26189, 0, -2355, 0, -24750, 0, -2354, 0, 21063, 0, -2353, 0, 21189, 0, -2352, 0, -26387, 0, -2351, 0, -30294, 0, -2350, 0, 19971, 0, -2349, 0, 26578, 0, -2348, 0, 28422, 0, -2347, 0, 20405, 0, -2346, 0, 23522, 0, -2345, 0, 26517, 0, -2344, 0, 27784, 0, -2343, 0, 28024, 0, -2342, 0, 29723, 0, -2341, 0, 30759, 0, -2340, 0, -28195, 0, -2339, 0, -27780, 0, -2338, 0, -30780, 0, -2337, 0, 31204, 0, -2336, 0, 31281, 0, -2335, 0, 24555, 0, -2334, 0, 20182, 0, -2333, 0, 21668, 0, -2332, 0, 21822, 0, -2331, 0, 22702, 0, -2330, 0, 22949, 0, -2329, 0, 24816, 0, -2328, 0, 25171, 0, -2327, 0, 25302, 0, -2326, 0, 26422, 0, -2325, 0, 26965, 0, -2324, 0, -32203, 0, -2323, 0, -27072, 0, -2322, 0, -26191, 0, -2321, 0, -26147, 0, -2320, 0, 20524, 0, -2319, 0, 21331, 0, -2318, 0, 21828, 0, -2317, 0, 22396, 0, -2316, 0, -1535, 0, -2315, 0, 25176, 0, -2314, 0, -1534, 0, -2313, 0, 25826, 0, -2312, 0, 26219, 0, -2311, 0, 26589, 0, -2310, 0, 28609, 0, -2309, 0, 28655, 0, -2308, 0, 29730, 0, -2307, 0, 29752, 0, -2306, 0, -30185, 0, -2143, 0, -27592, 0, -2142, 0, 21585, 0, -2141, 0, 22022, 0, -2140, 0, 22374, 0, -2139, 0, 24392, 0, -2138, 0, 24986, 0, -2137, 0, 27470, 0, -2136, 0, 28760, 0, -2135, 0, 28845, 0, -2134, 0, 32187, 0, -2133, 0, -30059, 0, -2132, 0, 22890, 0, -2131, 0, -32469, 0, -2130, 0, 25506, 0, -2129, 0, 30472, 0, -2128, 0, -32707, 0, -2127, 0, -29526, 0, -2126, 0, 22612, 0, -2125, 0, 25645, 0, -2124, 0, 27067, 0, -2123, 0, 23445, 0, -2122, 0, 24081, 0, -2121, 0, 28271, 0, -2120, 0, -1533, 0, -2119, 0, -31383, 0, -2118, 0, 20812, 0, -2117, 0, 21488, 0, -2116, 0, 22826, 0, -2115, 0, 24608, 0, -2114, 0, 24907, 0, -2113, 0, 27526, 0, -2112, 0, 27760, 0, -2111, 0, 27888, 0, -2110, 0, 31518, 0, -2109, 0, -32562, 0, -2108, 0, -32044, 0, -2107, 0, -29242, 0, -2106, 0, -28496, 0, -2105, 0, -26447, 0, -2104, 0, -1532, 0, -2103, 0, 25799, 0, -2102, 0, 28580, 0, -2101, 0, 25745, 0, -2100, 0, 25860, 0, -2099, 0, 20814, 0, -2098, 0, 21520, 0, -2097, 0, 22303, 0, -2096, 0, -30194, 0, -2095, 0, 24927, 0, -2094, 0, 26742, 0, -2093, 0, -1531, 0, -2092, 0, 30171, 0, -2091, 0, 31570, 0, -2090, 0, 32113, 0, -2089, 0, -28646, 0, -2088, 0, 22534, 0, -2087, 0, 27084, 0, -2086, 0, -32385, 0, -2085, 0, -30422, 0, -2084, 0, -28672, 0, -2083, 0, -26567, 0, -2082, 0, 20600, 0, -2081, 0, 22871, 0, -2080, 0, 22956, 0, -2079, 0, 25237, 0, -2078, 0, -28657, 0, -2077, 0, -25814, 0, -2076, 0, 24925, 0, -2075, 0, 29305, 0, -2074, 0, -27178, 0, -2073, 0, 22369, 0, -2072, 0, 23110, 0, -2071, 0, 24052, 0, -2070, 0, 25226, 0, -2069, 0, 25773, 0, -2068, 0, 25850, 0, -2067, 0, 26487, 0, -2066, 0, 27874, 0, -2065, 0, 27966, 0, -2064, 0, 29228, 0, -2063, 0, 29750, 0, -2062, 0, 30772, 0, -2061, 0, 32631, 0, -2060, 0, -32083, 0, -2059, 0, -29221, 0, -2058, 0, -26601, 0, -2057, 0, 21028, 0, -2056, 0, 22338, 0, -2055, 0, 26495, 0, -2054, 0, 29256, 0, -2053, 0, 29923, 0, -2052, 0, -29527, 0, -2051, 0, -28762, 0, -2050, 0, -28143, 0, -1887, 0, -27094, 0, -1886, 0, 20843, 0, -1885, 0, 21485, 0, -1884, 0, 25420, 0, -1883, 0, 20329, 0, -1882, 0, 21764, 0, -1881, 0, 24726, 0, -1880, 0, 25943, 0, -1879, 0, 27803, 0, -1878, 0, 28031, 0, -1877, 0, 29260, 0, -1876, 0, 29437, 0, -1875, 0, 31255, 0, -1874, 0, -30329, 0, -1873, 0, -29539, 0, -1872, 0, 24429, 0, -1871, 0, 28558, 0, -1870, 0, 28921, 0, -1869, 0, -32344, 0, -1868, 0, 24846, 0, -1867, 0, 20415, 0, -1866, 0, 20559, 0, -1865, 0, 25153, 0, -1864, 0, 29255, 0, -1863, 0, 31687, 0, -1862, 0, 32232, 0, -1861, 0, 32745, 0, -1860, 0, -28595, 0, -1859, 0, -26707, 0, -1858, 0, -26087, 0, -1857, 0, -29514, 0, -1856, 0, 22378, 0, -1855, 0, 24179, 0, -1854, 0, 26544, 0, -1853, 0, -31731, 0, -1852, 0, -30123, 0, -1851, 0, 21536, 0, -1850, 0, 23318, 0, -1849, 0, 24163, 0, -1848, 0, 24290, 0, -1847, 0, 24330, 0, -1846, 0, 25987, 0, -1845, 0, -32582, 0, -1844, 0, -31427, 0, -1843, 0, -27255, 0, -1842, 0, -27045, 0, -1841, 0, 20296, 0, -1840, 0, 21253, 0, -1839, 0, 21261, 0, -1838, 0, 21263, 0, -1837, 0, 21638, 0, -1836, 0, 21754, 0, -1835, 0, 22275, 0, -1834, 0, 24067, 0, -1833, 0, 24598, 0, -1832, 0, 25243, 0, -1831, 0, 25265, 0, -1830, 0, 25429, 0, -1829, 0, -1530, 0, -1828, 0, 27873, 0, -1827, 0, 28006, 0, -1826, 0, 30129, 0, -1825, 0, 30770, 0, -1824, 0, -32546, 0, -1823, 0, -32465, 0, -1822, 0, -32034, 0, -1821, 0, -31647, 0, -1820, 0, -31566, 0, -1819, 0, -30579, 0, -1818, 0, -30446, 0, -1817, 0, -28661, 0, -1816, 0, -27926, 0, -1815, 0, -26371, 0, -1814, 0, -25711, 0, -1813, 0, 24133, 0, -1812, 0, 26292, 0, -1811, 0, 26333, 0, -1810, 0, 28689, 0, -1809, 0, 29190, 0, -1808, 0, -1529, 0, -1807, 0, 20469, 0, -1806, 0, 21117, 0, -1805, 0, 24426, 0, -1804, 0, 24915, 0, -1803, 0, 26451, 0, -1802, 0, 27161, 0, -1801, 0, 28418, 0, -1800, 0, 29922, 0, -1799, 0, 31080, 0, -1798, 0, -30616, 0, -1797, 0, -29575, 0, -1796, 0, -26425, 0, -1795, 0, -26428, 0, -1794, 0, -26045, 0, -1631, 0, 21697, 0, -1630, 0, 31263, 0, -1629, 0, 26963, 0, -1628, 0, -29961, 0, -1627, 0, -29622, 0, -1626, 0, -26456, 0, -1625, 0, -26194, 0, -1624, 0, 24444, 0, -1623, 0, 25259, 0, -1622, 0, 30130, 0, -1621, 0, 30382, 0, -1620, 0, -30549, 0, -1619, 0, -28545, 0, -1618, 0, -27070, 0, -1617, 0, 21305, 0, -1616, 0, 24380, 0, -1615, 0, 24517, 0, -1614, 0, 27852, 0, -1613, 0, 29644, 0, -1612, 0, 30050, 0, -1611, 0, 30091, 0, -1610, 0, 31558, 0, -1609, 0, -32002, 0, -1608, 0, -26211, 0, -1607, 0, 20047, 0, -1606, 0, -28612, 0, -1605, 0, 19979, 0, -1604, 0, 20309, 0, -1603, 0, 21414, 0, -1602, 0, 22799, 0, -1601, 0, 24264, 0, -1600, 0, 26160, 0, -1599, 0, 27827, 0, -1598, 0, 29781, 0, -1597, 0, -31881, 0, -1596, 0, -30874, 0, -1595, 0, -29504, 0, -1594, 0, -28592, 0, -1593, 0, -26850, 0, -1592, 0, -25579, 0, -1591, 0, 22737, 0, -1590, 0, 23416, 0, -1589, 0, -31152, 0, -1588, 0, -29932, 0, -1587, 0, -25164, 0, -1586, 0, 23506, 0, -1585, 0, 24680, 0, -1584, 0, 24717, 0, -1583, 0, 26097, 0, -1582, 0, 27735, 0, -1581, 0, 28450, 0, -1580, 0, 28579, 0, -1579, 0, 28698, 0, -1578, 0, 32597, 0, -1577, 0, 32752, 0, -1576, 0, -27247, 0, -1575, 0, -27246, 0, -1574, 0, -27056, 0, -1573, 0, -26669, 0, -1572, 0, 21106, 0, -1571, 0, -28860, 0, -1570, 0, 20989, 0, -1569, 0, 21547, 0, -1568, 0, 21688, 0, -1567, 0, 21859, 0, -1566, 0, 21898, 0, -1565, 0, 27323, 0, -1564, 0, 28085, 0, -1563, 0, 32216, 0, -1562, 0, -32154, 0, -1561, 0, -28004, 0, -1560, 0, -27017, 0, -1559, 0, -24967, 0, -1558, 0, 21512, 0, -1557, 0, 21704, 0, -1556, 0, 30418, 0, -1555, 0, -31004, 0, -1554, 0, -27228, 0, -1553, 0, -27180, 0, -1552, 0, -27044, 0, -1551, 0, 20130, 0, -1550, 0, 20233, 0, -1549, 0, 23022, 0, -1548, 0, 23270, 0, -1547, 0, 24055, 0, -1546, 0, 24658, 0, -1545, 0, 25239, 0, -1544, 0, 26477, 0, -1543, 0, 26689, 0, -1542, 0, 27782, 0, -1541, 0, 28207, 0, -1540, 0, 32568, 0, -1539, 0, -32613, 0, -1538, 0, -32214, 0, -1375, 0, -1528, 0, -1374, 0, -1527, 0, -1373, 0, -26619, 0, -1372, 0, 20133, 0, -1371, 0, 20565, 0, -1370, 0, 21683, 0, -1369, 0, 22419, 0, -1368, 0, 22874, 0, -1367, 0, 23401, 0, -1366, 0, 23475, 0, -1365, 0, 25032, 0, -1364, 0, 26999, 0, -1363, 0, 28023, 0, -1362, 0, 28707, 0, -1361, 0, -30727, 0, -1360, 0, -30237, 0, -1359, 0, -30094, 0, -1358, 0, -29977, 0, -1357, 0, -28542, 0, -1356, 0, -26131, 0, -1355, 0, -25928, 0, -1354, 0, 21182, 0, -1353, 0, 26680, 0, -1352, 0, 20502, 0, -1351, 0, 24184, 0, -1350, 0, 26447, 0, -1349, 0, -31929, 0, -1348, 0, -30644, 0, -1347, 0, 20139, 0, -1346, 0, 21521, 0, -1345, 0, 22190, 0, -1344, 0, 29670, 0, -1343, 0, -28395, 0, -1342, 0, -26625, 0, -1341, 0, -26359, 0, -1340, 0, -26281, 0, -1339, 0, -26215, 0, -1338, 0, 22099, 0, -1337, 0, 22687, 0, -1336, 0, -31141, 0, -1335, 0, -30159, 0, -1334, 0, 25010, 0, -1333, 0, 27382, 0, -1332, 0, 29563, 0, -1331, 0, -28974, 0, -1330, 0, 27463, 0, -1329, 0, -26966, 0, -1328, 0, -26025, 0, -1327, 0, 22869, 0, -1326, 0, 29184, 0, -1325, 0, -29333, 0, -1324, 0, -26775, 0, -1323, 0, 20436, 0, -1322, 0, 23796, 0, -1321, 0, 24358, 0, -1320, 0, 25080, 0, -1319, 0, 26203, 0, -1318, 0, 27883, 0, -1317, 0, 28843, 0, -1316, 0, 29572, 0, -1315, 0, 29625, 0, -1314, 0, 29694, 0, -1313, 0, 30505, 0, -1312, 0, 30541, 0, -1311, 0, 32067, 0, -1310, 0, 32098, 0, -1309, 0, 32291, 0, -1308, 0, -32201, 0, -1307, 0, -30638, 0, -1306, 0, -1526, 0, -1305, 0, -29470, 0, -1304, 0, -28087, 0, -1303, 0, -26513, 0, -1302, 0, 23377, 0, -1301, 0, 31348, 0, -1300, 0, -30656, 0, -1299, 0, -26623, 0, -1298, 0, 23244, 0, -1297, 0, 20448, 0, -1296, 0, 21332, 0, -1295, 0, 22846, 0, -1294, 0, 23805, 0, -1293, 0, 25406, 0, -1292, 0, 28025, 0, -1291, 0, 29433, 0, -1290, 0, -32507, 0, -1289, 0, -32505, 0, -1288, 0, -31838, 0, -1287, 0, -27953, 0, -1286, 0, -26576, 0, -1285, 0, 20136, 0, -1284, 0, 20804, 0, -1283, 0, 21009, 0, -1282, 0, 22411, 0, -1119, 0, 24418, 0, -1118, 0, 27842, 0, -1117, 0, 28366, 0, -1116, 0, 28677, 0, -1115, 0, 28752, 0, -1114, 0, 28847, 0, -1113, 0, 29074, 0, -1112, 0, 29673, 0, -1111, 0, 29801, 0, -1110, 0, -31926, 0, -1109, 0, -30814, 0, -1108, 0, -30623, 0, -1107, 0, -28664, 0, -1106, 0, -28510, 0, -1105, 0, -27741, 0, -1104, 0, -26200, 0, -1103, 0, 20846, 0, -1102, 0, 24407, 0, -1101, 0, 24800, 0, -1100, 0, 24935, 0, -1099, 0, 26291, 0, -1098, 0, -31399, 0, -1097, 0, -29110, 0, -1096, 0, -28241, 0, -1095, 0, -26741, 0, -1094, 0, 20046, 0, -1093, 0, 20114, 0, -1092, 0, 21628, 0, -1091, 0, 22741, 0, -1090, 0, 22778, 0, -1089, 0, 22909, 0, -1088, 0, 23733, 0, -1087, 0, 24359, 0, -1086, 0, 25142, 0, -1085, 0, 25160, 0, -1084, 0, 26122, 0, -1083, 0, 26215, 0, -1082, 0, 27627, 0, -1081, 0, 28009, 0, -1080, 0, 28111, 0, -1079, 0, 28246, 0, -1078, 0, 28408, 0, -1077, 0, 28564, 0, -1076, 0, 28640, 0, -1075, 0, 28649, 0, -1074, 0, 28765, 0, -1073, 0, 29392, 0, -1072, 0, 29733, 0, -1071, 0, 29786, 0, -1070, 0, 29920, 0, -1069, 0, 30355, 0, -1068, 0, 31068, 0, -1067, 0, 31946, 0, -1066, 0, 32286, 0, -1065, 0, -32543, 0, -1064, 0, -32090, 0, -1063, 0, -31637, 0, -1062, 0, -31553, 0, -1061, 0, -31154, 0, -1060, 0, -31137, 0, -1059, 0, -30860, 0, -1058, 0, -29833, 0, -1057, 0, -29590, 0, -1056, 0, -27732, 0, -1055, 0, -26624, 0, -1054, 0, -26523, 0, -1053, 0, 24785, 0, -1052, 0, 25110, 0, -1051, 0, -28297, 0, -1050, 0, 23130, 0, -1049, 0, 26127, 0, -1048, 0, 28151, 0, -1047, 0, 28222, 0, -1046, 0, 29759, 0, -1045, 0, -25790, 0, -1044, 0, 24573, 0, -1043, 0, 24794, 0, -1042, 0, 31503, 0, -1041, 0, 21700, 0, -1040, 0, 24344, 0, -1039, 0, 27742, 0, -1038, 0, 27859, 0, -1037, 0, 27946, 0, -1036, 0, 28888, 0, -1035, 0, 32005, 0, -1034, 0, -31111, 0, -1033, 0, -30196, 0, -1032, 0, -25285, 0, -1031, 0, 21270, 0, -1030, 0, 21644, 0, -1029, 0, 23301, 0, -1028, 0, 27194, 0, -1027, 0, 28779, 0, -1026, 0, 30069, 0, -863, 0, 31117, 0, -862, 0, 31166, 0, -861, 0, -32079, 0, -860, 0, -31761, 0, -859, 0, -30095, 0, -858, 0, -29887, 0, -857, 0, -29528, 0, -856, 0, -26764, 0, -855, 0, -1525, 0, -854, 0, 25844, 0, -853, 0, 25899, 0, -852, 0, 30906, 0, -851, 0, 30907, 0, -850, 0, 31339, 0, -849, 0, 20024, 0, -848, 0, 21914, 0, -847, 0, 22864, 0, -846, 0, 23462, 0, -845, 0, 24187, 0, -844, 0, 24739, 0, -843, 0, 25563, 0, -842, 0, 27489, 0, -841, 0, 26213, 0, -840, 0, 26707, 0, -839, 0, 28185, 0, -838, 0, 29029, 0, -837, 0, 29872, 0, -836, 0, 32008, 0, -835, 0, -28540, 0, -834, 0, -26007, 0, -833, 0, -25563, 0, -832, 0, 27963, 0, -831, 0, 28369, 0, -830, 0, 29502, 0, -829, 0, -29631, 0, -828, 0, -27190, 0, -827, 0, 20976, 0, -826, 0, 24140, 0, -825, 0, 24488, 0, -824, 0, 24653, 0, -823, 0, 24822, 0, -822, 0, 24880, 0, -821, 0, 24908, 0, -820, 0, 26179, 0, -819, 0, 26180, 0, -818, 0, 27045, 0, -817, 0, 27841, 0, -816, 0, 28255, 0, -815, 0, 28361, 0, -814, 0, 28514, 0, -813, 0, 29004, 0, -812, 0, 29852, 0, -811, 0, 30343, 0, -810, 0, 31681, 0, -809, 0, 31783, 0, -808, 0, -31918, 0, -807, 0, -30889, 0, -806, 0, -28591, 0, -805, 0, -26995, 0, -804, 0, -24893, 0, -803, 0, 21295, 0, -802, 0, 22238, 0, -801, 0, 24315, 0, -800, 0, 24458, 0, -799, 0, 24674, 0, -798, 0, 24724, 0, -797, 0, 25079, 0, -796, 0, 26214, 0, -795, 0, 26371, 0, -794, 0, 27292, 0, -793, 0, 28142, 0, -792, 0, 28590, 0, -791, 0, 28784, 0, -790, 0, 29546, 0, -789, 0, 32362, 0, -788, 0, -32322, 0, -787, 0, -31948, 0, -786, 0, -31020, 0, -785, 0, -30040, 0, -784, 0, -29500, 0, -783, 0, 21123, 0, -782, 0, 29554, 0, -781, 0, 23446, 0, -780, 0, 27243, 0, -779, 0, -27644, 0, -778, 0, 21742, 0, -777, 0, 22150, 0, -776, 0, 23389, 0, -775, 0, 25928, 0, -774, 0, 25989, 0, -773, 0, 26313, 0, -772, 0, 26783, 0, -771, 0, 28045, 0, -770, 0, 28102, 0, -607, 0, 29243, 0, -606, 0, -32588, 0, -605, 0, -28299, 0, -604, 0, -26035, 0, -603, 0, 20399, 0, -602, 0, 20505, 0, -601, 0, 21402, 0, -600, 0, 21518, 0, -599, 0, 21564, 0, -598, 0, 21897, 0, -597, 0, 21957, 0, -596, 0, 24127, 0, -595, 0, 24460, 0, -594, 0, 26429, 0, -593, 0, 29030, 0, -592, 0, 29661, 0, -591, 0, -28667, 0, -590, 0, 21211, 0, -589, 0, 21235, 0, -588, 0, 22628, 0, -587, 0, 22734, 0, -586, 0, 28932, 0, -585, 0, 29071, 0, -584, 0, 29179, 0, -583, 0, -31312, 0, -582, 0, -30189, 0, -581, 0, 26248, 0, -580, 0, -31320, 0, -579, 0, 21927, 0, -578, 0, 26244, 0, -577, 0, 29002, 0, -576, 0, -31695, 0, -575, 0, 21321, 0, -574, 0, 21913, 0, -573, 0, 27585, 0, -572, 0, 24409, 0, -571, 0, 24509, 0, -570, 0, 25582, 0, -569, 0, 26249, 0, -568, 0, 28999, 0, -567, 0, -29967, 0, -566, 0, -28899, 0, -565, 0, -24898, 0, -564, 0, 20241, 0, -563, 0, 25658, 0, -562, 0, 28875, 0, -561, 0, 30054, 0, -560, 0, -31129, 0, -559, 0, 24676, 0, -558, 0, -29874, 0, -557, 0, -25096, 0, -556, 0, 20807, 0, -555, 0, 20982, 0, -554, 0, 21256, 0, -553, 0, 27958, 0, -552, 0, -32520, 0, -551, 0, -24879, 0, -550, 0, 26133, 0, -549, 0, 27427, 0, -548, 0, 28824, 0, -547, 0, 30165, 0, -546, 0, 21507, 0, -545, 0, 23673, 0, -544, 0, 32007, 0, -543, 0, -30186, 0, -542, 0, 27424, 0, -541, 0, 27453, 0, -540, 0, 27462, 0, -539, 0, 21560, 0, -538, 0, 24688, 0, -537, 0, 27965, 0, -536, 0, 32725, 0, -535, 0, -32248, 0, -534, 0, 20694, 0, -533, 0, 20958, 0, -532, 0, 21916, 0, -531, 0, 22123, 0, -530, 0, 22221, 0, -529, 0, 23020, 0, -528, 0, 23305, 0, -527, 0, 24076, 0, -526, 0, 24985, 0, -525, 0, 24984, 0, -524, 0, 25137, 0, -523, 0, 26206, 0, -522, 0, 26342, 0, -521, 0, 29081, 0, -520, 0, 29113, 0, -519, 0, 29114, 0, -518, 0, 29351, 0, -517, 0, 31143, 0, -516, 0, 31232, 0, -515, 0, 32690, 0, -514, 0, -30096, 0, -351, 0, -8098, 0, -350, 0, -8097, 0, -349, 0, -8096, 0, -348, 0, -8095, 0, -347, 0, -8094, 0, -346, 0, -8093, 0, -345, 0, -8092, 0, -344, 0, -8091, 0, -343, 0, -8090, 0, -342, 0, -8089, 0, -341, 0, -8088, 0, -340, 0, -8087, 0, -339, 0, -8086, 0, -338, 0, -8085, 0, -337, 0, -8084, 0, -336, 0, -8083, 0, -335, 0, -8082, 0, -334, 0, -8081, 0, -333, 0, -8080, 0, -332, 0, -8079, 0, -331, 0, -8078, 0, -330, 0, -8077, 0, -329, 0, -8076, 0, -328, 0, -8075, 0, -327, 0, -8074, 0, -326, 0, -8073, 0, -325, 0, -8072, 0, -324, 0, -8071, 0, -323, 0, -8070, 0, -322, 0, -8069, 0, -321, 0, -8068, 0, -320, 0, -8067, 0, -319, 0, -8066, 0, -318, 0, -8065, 0, -317, 0, -8064, 0, -316, 0, -8063, 0, -315, 0, -8062, 0, -314, 0, -8061, 0, -313, 0, -8060, 0, -312, 0, -8059, 0, -311, 0, -8058, 0, -310, 0, -8057, 0, -309, 0, -8056, 0, -308, 0, -8055, 0, -307, 0, -8054, 0, -306, 0, -8053, 0, -305, 0, -8052, 0, -304, 0, -8051, 0, -303, 0, -8050, 0, -302, 0, -8049, 0, -301, 0, -8048, 0, -300, 0, -8047, 0, -299, 0, -8046, 0, -298, 0, -8045, 0, -297, 0, -8044, 0, -296, 0, -8043, 0, -295, 0, -8042, 0, -294, 0, -8041, 0, -293, 0, -8040, 0, -292, 0, -8039, 0, -291, 0, -8038, 0, -290, 0, -8037, 0, -289, 0, -8036, 0, -288, 0, -8035, 0, -287, 0, -8034, 0, -286, 0, -8033, 0, -285, 0, -8032, 0, -284, 0, -8031, 0, -283, 0, -8030, 0, -282, 0, -8029, 0, -281, 0, -8028, 0, -280, 0, -8027, 0, -279, 0, -8026, 0, -278, 0, -8025, 0, -277, 0, -8024, 0, -276, 0, -8023, 0, -275, 0, -8022, 0, -274, 0, -8021, 0, -273, 0, -8020, 0, -272, 0, -8019, 0, -271, 0, -8018, 0, -270, 0, -8017, 0, -269, 0, -8016, 0, -268, 0, -8015, 0, -267, 0, -8014, 0, -266, 0, -8013, 0, -265, 0, -8012, 0, -264, 0, -8011, 0, -263, 0, -8010, 0, -262, 0, -8009, 0, -261, 0, -8008, 0, -260, 0, -8007, 0, -259, 0, -8006, 0, -258, 0, -8005, 0, -1, 0, -1, 0], ["i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0], ALLOC_STATIC);
_KSCms_UHC_AddCodeSpaceRange_code_space_range1=allocate([0, 0, 128, 0, 0, 0], ["i16",0,"i16",0,"i16",0], ALLOC_STATIC);
_KSCms_UHC_AddCodeSpaceRange_code_space_range2=allocate([-32447, 0, -258, 0, 0, 0], ["i16",0,"i16",0,"i16",0], ALLOC_STATIC);
_CMAP_ARRAY_KSCms_UHC_H=allocate([32, 0, 126, 0, 1, 0, -32447, 0, -32422, 0, 9333, 0, -32415, 0, -32390, 0, 9359, 0, -32383, 0, -32258, 0, 9385, 0, -32191, 0, -32166, 0, 9511, 0, -32159, 0, -32134, 0, 9537, 0, -32127, 0, -32002, 0, 9563, 0, -31935, 0, -31910, 0, 9689, 0, -31903, 0, -31878, 0, 9715, 0, -31871, 0, -31746, 0, 9741, 0, -31679, 0, -31654, 0, 9867, 0, -31647, 0, -31622, 0, 9893, 0, -31615, 0, -31490, 0, 9919, 0, -31423, 0, -31398, 0, 10045, 0, -31391, 0, -31366, 0, 10071, 0, -31359, 0, -31234, 0, 10097, 0, -31167, 0, -31142, 0, 10223, 0, -31135, 0, -31110, 0, 10249, 0, -31103, 0, -30978, 0, 10275, 0, -30911, 0, -30886, 0, 10401, 0, -30879, 0, -30854, 0, 10427, 0, -30847, 0, -30722, 0, 10453, 0, -30655, 0, -30630, 0, 10579, 0, -30623, 0, -30598, 0, 10605, 0, -30591, 0, -30466, 0, 10631, 0, -30399, 0, -30374, 0, 10757, 0, -30367, 0, -30342, 0, 10783, 0, -30335, 0, -30210, 0, 10809, 0, -30143, 0, -30118, 0, 10935, 0, -30111, 0, -30086, 0, 10961, 0, -30079, 0, -29954, 0, 10987, 0, -29887, 0, -29862, 0, 11113, 0, -29855, 0, -29830, 0, 11139, 0, -29823, 0, -29698, 0, 11165, 0, -29631, 0, -29606, 0, 11291, 0, -29599, 0, -29574, 0, 11317, 0, -29567, 0, -29442, 0, 11343, 0, -29375, 0, -29350, 0, 11469, 0, -29343, 0, -29318, 0, 11495, 0, -29311, 0, -29186, 0, 11521, 0, -29119, 0, -29094, 0, 11647, 0, -29087, 0, -29062, 0, 11673, 0, -29055, 0, -28930, 0, 11699, 0, -28863, 0, -28838, 0, 11825, 0, -28831, 0, -28806, 0, 11851, 0, -28799, 0, -28674, 0, 11877, 0, -28607, 0, -28582, 0, 12003, 0, -28575, 0, -28550, 0, 12029, 0, -28543, 0, -28418, 0, 12055, 0, -28351, 0, -28326, 0, 12181, 0, -28319, 0, -28294, 0, 12207, 0, -28287, 0, -28162, 0, 12233, 0, -28095, 0, -28070, 0, 12359, 0, -28063, 0, -28038, 0, 12385, 0, -28031, 0, -27906, 0, 12411, 0, -27839, 0, -27814, 0, 12537, 0, -27807, 0, -27782, 0, 12563, 0, -27775, 0, -27650, 0, 12589, 0, -27583, 0, -27558, 0, 12715, 0, -27551, 0, -27526, 0, 12741, 0, -27519, 0, -27394, 0, 12767, 0, -27327, 0, -27302, 0, 12893, 0, -27295, 0, -27270, 0, 12919, 0, -27263, 0, -27138, 0, 12945, 0, -27071, 0, -27046, 0, 13071, 0, -27039, 0, -27014, 0, 13097, 0, -27007, 0, -26882, 0, 13123, 0, -26815, 0, -26790, 0, 13249, 0, -26783, 0, -26758, 0, 13275, 0, -26751, 0, -26626, 0, 13301, 0, -26559, 0, -26534, 0, 13427, 0, -26527, 0, -26502, 0, 13453, 0, -26495, 0, -26370, 0, 13479, 0, -26303, 0, -26278, 0, 13605, 0, -26271, 0, -26246, 0, 13631, 0, -26239, 0, -26114, 0, 13657, 0, -26047, 0, -26022, 0, 13783, 0, -26015, 0, -25990, 0, 13809, 0, -25983, 0, -25858, 0, 13835, 0, -25791, 0, -25766, 0, 13961, 0, -25759, 0, -25734, 0, 13987, 0, -25727, 0, -25602, 0, 14013, 0, -25535, 0, -25510, 0, 14139, 0, -25503, 0, -25478, 0, 14165, 0, -25471, 0, -25346, 0, 14191, 0, -25279, 0, -25254, 0, 14317, 0, -25247, 0, -25222, 0, 14343, 0, -25215, 0, -25090, 0, 14369, 0, -25023, 0, -24998, 0, 14495, 0, -24991, 0, -24966, 0, 14521, 0, -24959, 0, -24834, 0, 14547, 0, -24767, 0, -24742, 0, 14673, 0, -24735, 0, -24710, 0, 14699, 0, -24703, 0, -24578, 0, 14725, 0, -24511, 0, -24486, 0, 14851, 0, -24479, 0, -24454, 0, 14877, 0, -24447, 0, -24322, 0, 14903, 0, -24255, 0, -24230, 0, 15029, 0, -24223, 0, -24198, 0, 15055, 0, -24191, 0, -24160, 0, 15081, 0, -24159, 0, -24066, 0, 101, 0, -23999, 0, -23974, 0, 15113, 0, -23967, 0, -23942, 0, 15139, 0, -23935, 0, -23904, 0, 15165, 0, -23903, 0, -23835, 0, 195, 0, -23743, 0, -23718, 0, 15197, 0, -23711, 0, -23686, 0, 15223, 0, -23679, 0, -23648, 0, 15249, 0, -23647, 0, -23554, 0, 264, 0, -23487, 0, -23462, 0, 15281, 0, -23455, 0, -23430, 0, 15307, 0, -23423, 0, -23392, 0, 15333, 0, -23391, 0, -23341, 0, 358, 0, -23339, 0, -23298, 0, 409, 0, -23231, 0, -23206, 0, 15365, 0, -23199, 0, -23174, 0, 15391, 0, -23167, 0, -23136, 0, 15417, 0, -23135, 0, -23126, 0, 451, 0, -23120, 0, -23111, 0, 461, 0, -23103, 0, -23080, 0, 471, 0, -23071, 0, -23048, 0, 495, 0, -22975, 0, -22950, 0, 15449, 0, -22943, 0, -22918, 0, 15475, 0, -22911, 0, -22880, 0, 15501, 0, -22879, 0, -22812, 0, 519, 0, -22719, 0, -22694, 0, 15533, 0, -22687, 0, -22662, 0, 15559, 0, -22655, 0, -22624, 0, 15585, 0, -22623, 0, -22545, 0, 587, 0, -22463, 0, -22438, 0, 15617, 0, -22431, 0, -22406, 0, 15643, 0, -22399, 0, -22368, 0, 15669, 0, -22367, 0, -22364, 0, 666, 0, -22362, 0, -22362, 0, 670, 0, -22360, 0, -22353, 0, 671, 0, -22351, 0, -22274, 0, 679, 0, -22207, 0, -22182, 0, 15701, 0, -22175, 0, -22150, 0, 15727, 0, -22143, 0, -22112, 0, 15753, 0, -22111, 0, -22018, 0, 757, 0, -21951, 0, -21926, 0, 15785, 0, -21919, 0, -21894, 0, 15811, 0, -21887, 0, -21856, 0, 15837, 0, -21855, 0, -21773, 0, 851, 0, -21695, 0, -21670, 0, 15869, 0, -21663, 0, -21638, 0, 15895, 0, -21631, 0, -21600, 0, 15921, 0, -21599, 0, -21514, 0, 934, 0, -21439, 0, -21414, 0, 15953, 0, -21407, 0, -21382, 0, 15979, 0, -21375, 0, -21344, 0, 16005, 0, -21343, 0, -21311, 0, 1020, 0, -21295, 0, -21263, 0, 1053, 0, -21183, 0, -21158, 0, 16037, 0, -21151, 0, -21126, 0, 16063, 0, -21119, 0, -21088, 0, 16089, 0, -20927, 0, -20902, 0, 16121, 0, -20895, 0, -20870, 0, 16147, 0, -20863, 0, -20832, 0, 16173, 0, -20671, 0, -20646, 0, 16205, 0, -20639, 0, -20614, 0, 16231, 0, -20607, 0, -20576, 0, 16257, 0, -20415, 0, -20390, 0, 16289, 0, -20383, 0, -20358, 0, 16315, 0, -20351, 0, -20320, 0, 16341, 0, -20319, 0, -20226, 0, 1086, 0, -20159, 0, -20134, 0, 16373, 0, -20127, 0, -20102, 0, 16399, 0, -20095, 0, -20064, 0, 16425, 0, -20063, 0, -19970, 0, 1180, 0, -19903, 0, -19878, 0, 16457, 0, -19871, 0, -19846, 0, 16483, 0, -19839, 0, -19808, 0, 16509, 0, -19807, 0, -19714, 0, 1274, 0, -19647, 0, -19622, 0, 16541, 0, -19615, 0, -19590, 0, 16567, 0, -19583, 0, -19552, 0, 16593, 0, -19551, 0, -19458, 0, 1368, 0, -19391, 0, -19366, 0, 16625, 0, -19359, 0, -19334, 0, 16651, 0, -19327, 0, -19296, 0, 16677, 0, -19295, 0, -19202, 0, 1462, 0, -19135, 0, -19110, 0, 16709, 0, -19103, 0, -19078, 0, 16735, 0, -19071, 0, -19040, 0, 16761, 0, -19039, 0, -18946, 0, 1556, 0, -18879, 0, -18854, 0, 16793, 0, -18847, 0, -18822, 0, 16819, 0, -18815, 0, -18784, 0, 16845, 0, -18783, 0, -18690, 0, 1650, 0, -18623, 0, -18598, 0, 16877, 0, -18591, 0, -18566, 0, 16903, 0, -18559, 0, -18528, 0, 16929, 0, -18527, 0, -18434, 0, 1744, 0, -18367, 0, -18342, 0, 16961, 0, -18335, 0, -18310, 0, 16987, 0, -18303, 0, -18272, 0, 17013, 0, -18271, 0, -18178, 0, 1838, 0, -18111, 0, -18086, 0, 17045, 0, -18079, 0, -18054, 0, 17071, 0, -18047, 0, -18016, 0, 17097, 0, -18015, 0, -17922, 0, 1932, 0, -17855, 0, -17830, 0, 17129, 0, -17823, 0, -17798, 0, 17155, 0, -17791, 0, -17760, 0, 17181, 0, -17759, 0, -17666, 0, 2026, 0, -17599, 0, -17574, 0, 17213, 0, -17567, 0, -17542, 0, 17239, 0, -17535, 0, -17504, 0, 17265, 0, -17503, 0, -17410, 0, 2120, 0, -17343, 0, -17318, 0, 17297, 0, -17311, 0, -17286, 0, 17323, 0, -17279, 0, -17248, 0, 17349, 0, -17247, 0, -17154, 0, 2214, 0, -17087, 0, -17062, 0, 17381, 0, -17055, 0, -17030, 0, 17407, 0, -17023, 0, -16992, 0, 17433, 0, -16991, 0, -16898, 0, 2308, 0, -16831, 0, -16806, 0, 17465, 0, -16799, 0, -16774, 0, 17491, 0, -16767, 0, -16736, 0, 17517, 0, -16735, 0, -16642, 0, 2402, 0, -16575, 0, -16550, 0, 17549, 0, -16543, 0, -16518, 0, 17575, 0, -16511, 0, -16480, 0, 17601, 0, -16479, 0, -16386, 0, 2496, 0, -16319, 0, -16294, 0, 17633, 0, -16287, 0, -16262, 0, 17659, 0, -16255, 0, -16224, 0, 17685, 0, -16223, 0, -16130, 0, 2590, 0, -16063, 0, -16038, 0, 17717, 0, -16031, 0, -16006, 0, 17743, 0, -15999, 0, -15968, 0, 17769, 0, -15967, 0, -15874, 0, 2684, 0, -15807, 0, -15782, 0, 17801, 0, -15775, 0, -15750, 0, 17827, 0, -15743, 0, -15712, 0, 17853, 0, -15711, 0, -15618, 0, 2778, 0, -15551, 0, -15526, 0, 17885, 0, -15519, 0, -15494, 0, 17911, 0, -15487, 0, -15456, 0, 17937, 0, -15455, 0, -15362, 0, 2872, 0, -15295, 0, -15270, 0, 17969, 0, -15263, 0, -15238, 0, 17995, 0, -15231, 0, -15200, 0, 18021, 0, -15199, 0, -15106, 0, 2966, 0, -15039, 0, -15014, 0, 18053, 0, -15007, 0, -14982, 0, 18079, 0, -14975, 0, -14944, 0, 18105, 0, -14943, 0, -14850, 0, 3060, 0, -14783, 0, -14766, 0, 18137, 0, -14687, 0, -14594, 0, 3154, 0, -14431, 0, -14338, 0, 3248, 0, -14175, 0, -14082, 0, 3342, 0, -13663, 0, -13570, 0, 3436, 0, -13407, 0, -13361, 0, 3530, 0, -13360, 0, -13360, 0, 4116, 0, -13359, 0, -13355, 0, 3577, 0, -13354, 0, -13354, 0, 3678, 0, -13353, 0, -13338, 0, 3582, 0, -13337, 0, -13337, 0, 7053, 0, -13336, 0, -13314, 0, 3598, 0, -13151, 0, -13058, 0, 3621, 0, -12895, 0, -12850, 0, 3715, 0, -12849, 0, -12849, 0, 3460, 0, -12848, 0, -12825, 0, 3761, 0, -12824, 0, -12824, 0, 7900, 0, -12823, 0, -12802, 0, 3785, 0, -12639, 0, -12628, 0, 3807, 0, -12627, 0, -12627, 0, 3802, 0, -12626, 0, -12546, 0, 3819, 0, -12383, 0, -12294, 0, 3900, 0, -12293, 0, -12293, 0, 3902, 0, -12292, 0, -12290, 0, 3990, 0, -12127, 0, -12127, 0, 3993, 0, -12126, 0, -12126, 0, 3946, 0, -12125, 0, -12105, 0, 3994, 0, -12104, 0, -12104, 0, 3946, 0, -12103, 0, -12081, 0, 4015, 0, -12080, 0, -12080, 0, 3708, 0, -12079, 0, -12068, 0, 4038, 0, -12067, 0, -12067, 0, 4131, 0, -12066, 0, -12034, 0, 4050, 0, -11871, 0, -11821, 0, 4083, 0, -11820, 0, -11820, 0, 4374, 0, -11819, 0, -11819, 0, 4156, 0, -11818, 0, -11817, 0, 4134, 0, -11816, 0, -11816, 0, 4375, 0, -11815, 0, -11814, 0, 4136, 0, -11813, 0, -11808, 0, 4376, 0, -11807, 0, -11807, 0, 4138, 0, -11806, 0, -11806, 0, 5800, 0, -11805, 0, -11803, 0, 4382, 0, -11802, 0, -11802, 0, 4386, 0, -11801, 0, -11801, 0, 4139, 0, -11800, 0, -11797, 0, 4387, 0, -11796, 0, -11796, 0, 4140, 0, -11795, 0, -11795, 0, 4391, 0, -11794, 0, -11794, 0, 4141, 0, -11793, 0, -11792, 0, 4394, 0, -11791, 0, -11791, 0, 4142, 0, -11790, 0, -11790, 0, 4396, 0, -11789, 0, -11787, 0, 4143, 0, -11786, 0, -11786, 0, 4399, 0, -11785, 0, -11783, 0, 4146, 0, -11782, 0, -11782, 0, 4403, 0, -11781, 0, -11781, 0, 4149, 0, -11780, 0, -11779, 0, 4406, 0, -11778, 0, -11778, 0, 4409, 0, -11615, 0, -11615, 0, 4150, 0, -11614, 0, -11613, 0, 4410, 0, -11612, 0, -11610, 0, 4151, 0, -11609, 0, -11606, 0, 4412, 0, -11605, 0, -11605, 0, 4419, 0, -11604, 0, -11604, 0, 4154, 0, -11603, 0, -11603, 0, 4420, 0, -11602, 0, -11599, 0, 4155, 0, -11598, 0, -11598, 0, 4424, 0, -11597, 0, -11587, 0, 4159, 0, -11586, 0, -11586, 0, 4511, 0, -11585, 0, -11583, 0, 4170, 0, -11582, 0, -11581, 0, 4513, 0, -11580, 0, -11580, 0, 4517, 0, -11579, 0, -11579, 0, 4173, 0, -11578, 0, -11574, 0, 4518, 0, -11573, 0, -11573, 0, 4524, 0, -11572, 0, -11572, 0, 4174, 0, -11571, 0, -11570, 0, 4525, 0, -11569, 0, -11564, 0, 4528, 0, -11563, 0, -11561, 0, 4535, 0, -11560, 0, -11560, 0, 4175, 0, -11559, 0, -11558, 0, 4541, 0, -11557, 0, -11555, 0, 4176, 0, -11554, 0, -11553, 0, 4545, 0, -11552, 0, -11552, 0, 4179, 0, -11551, 0, -11551, 0, 4547, 0, -11550, 0, -11550, 0, 4550, 0, -11549, 0, -11549, 0, 4180, 0, -11548, 0, -11548, 0, 4564, 0, -11547, 0, -11544, 0, 4566, 0, -11543, 0, -11542, 0, 4571, 0, -11541, 0, -11541, 0, 4576, 0, -11540, 0, -11537, 0, 4181, 0, -11536, 0, -11533, 0, 4604, 0, -11532, 0, -11531, 0, 4609, 0, -11530, 0, -11530, 0, 4185, 0, -11529, 0, -11528, 0, 4611, 0, -11527, 0, -11522, 0, 4186, 0, -11359, 0, -11266, 0, 4192, 0, -11103, 0, -11035, 0, 4286, 0, -11034, 0, -11034, 0, 4318, 0, -11033, 0, -11013, 0, 4355, 0, -11012, 0, -11012, 0, 4136, 0, -11011, 0, -11010, 0, 4376, 0, -10847, 0, -10844, 0, 4378, 0, -10843, 0, -10843, 0, 5800, 0, -10842, 0, -10838, 0, 4382, 0, -10837, 0, -10837, 0, 4139, 0, -10836, 0, -10835, 0, 4387, 0, -10834, 0, -10834, 0, 4192, 0, -10833, 0, -10754, 0, 4389, 0, -10591, 0, -10569, 0, 4469, 0, -10568, 0, -10568, 0, 4167, 0, -10567, 0, -10548, 0, 4492, 0, -10547, 0, -10547, 0, 4172, 0, -10546, 0, -10498, 0, 4512, 0, -10335, 0, -10294, 0, 4561, 0, -10293, 0, -10293, 0, 5552, 0, -10292, 0, -10269, 0, 4603, 0, -10268, 0, -10268, 0, 6424, 0, -10267, 0, -10242, 0, 4627, 0, -10079, 0, -9986, 0, 4653, 0, -9823, 0, -9730, 0, 4747, 0, -9567, 0, -9474, 0, 4841, 0, -9311, 0, -9276, 0, 4935, 0, -9275, 0, -9275, 0, 5151, 0, -9274, 0, -9245, 0, 4971, 0, -9244, 0, -9244, 0, 4922, 0, -9243, 0, -9218, 0, 5001, 0, -9055, 0, -9052, 0, 5027, 0, -9051, 0, -9051, 0, 7518, 0, -9050, 0, -8962, 0, 5031, 0, -8799, 0, -8796, 0, 5120, 0, -8795, 0, -8795, 0, 5079, 0, -8794, 0, -8748, 0, 5124, 0, -8747, 0, -8747, 0, 5109, 0, -8746, 0, -8717, 0, 5171, 0, -8716, 0, -8716, 0, 7607, 0, -8715, 0, -8706, 0, 5201, 0, -8543, 0, -8453, 0, 5211, 0, -8452, 0, -8452, 0, 5584, 0, -8451, 0, -8451, 0, 5302, 0, -8450, 0, -8450, 0, 5367, 0, -8287, 0, -8270, 0, 5303, 0, -8269, 0, -8269, 0, 7083, 0, -8268, 0, -8224, 0, 5321, 0, -8223, 0, -8223, 0, 5362, 0, -8222, 0, -8217, 0, 5366, 0, -8216, 0, -8216, 0, 5485, 0, -8215, 0, -8194, 0, 5372, 0, -8031, 0, -7952, 0, 5394, 0, -7951, 0, -7951, 0, 6001, 0, -7950, 0, -7938, 0, 5474, 0, -7775, 0, -7764, 0, 5487, 0, -7763, 0, -7763, 0, 5460, 0, -7762, 0, -7700, 0, 5499, 0, -7699, 0, -7699, 0, 5317, 0, -7698, 0, -7682, 0, 5562, 0, -7519, 0, -7426, 0, 5579, 0, -7263, 0, -7180, 0, 5673, 0, -7179, 0, -7179, 0, 7009, 0, -7178, 0, -7170, 0, 5757, 0, -7007, 0, -7007, 0, 7370, 0, -7006, 0, -7000, 0, 5766, 0, -6999, 0, -6999, 0, 5678, 0, -6998, 0, -6914, 0, 5773, 0, -6751, 0, -6739, 0, 5858, 0, -6738, 0, -6738, 0, 5874, 0, -6737, 0, -6736, 0, 5871, 0, -6735, 0, -6734, 0, 4425, 0, -6733, 0, -6728, 0, 5873, 0, -6727, 0, -6727, 0, 4427, 0, -6726, 0, -6726, 0, 5879, 0, -6725, 0, -6724, 0, 4429, 0, -6723, 0, -6717, 0, 5880, 0, -6716, 0, -6716, 0, 4431, 0, -6715, 0, -6707, 0, 5887, 0, -6706, 0, -6706, 0, 4435, 0, -6705, 0, -6705, 0, 5896, 0, -6704, 0, -6704, 0, 4436, 0, -6703, 0, -6703, 0, 5897, 0, -6702, 0, -6702, 0, 4437, 0, -6701, 0, -6699, 0, 5898, 0, -6698, 0, -6698, 0, 4439, 0, -6697, 0, -6663, 0, 5901, 0, -6662, 0, -6661, 0, 4442, 0, -6660, 0, -6660, 0, 4159, 0, -6659, 0, -6659, 0, 5936, 0, -6658, 0, -6658, 0, 4444, 0, -6495, 0, -6495, 0, 4447, 0, -6494, 0, -6493, 0, 5937, 0, -6492, 0, -6492, 0, 4449, 0, -6491, 0, -6490, 0, 5939, 0, -6489, 0, -6489, 0, 4450, 0, -6488, 0, -6484, 0, 5941, 0, -6483, 0, -6483, 0, 4453, 0, -6482, 0, -6482, 0, 5946, 0, -6481, 0, -6479, 0, 4455, 0, -6478, 0, -6478, 0, 5947, 0, -6477, 0, -6477, 0, 4458, 0, -6476, 0, -6474, 0, 5948, 0, -6473, 0, -6472, 0, 4459, 0, -6471, 0, -6469, 0, 5951, 0, -6468, 0, -6468, 0, 4463, 0, -6467, 0, -6461, 0, 5954, 0, -6460, 0, -6460, 0, 4160, 0, -6459, 0, -6459, 0, 5961, 0, -6458, 0, -6457, 0, 4465, 0, -6456, 0, -6455, 0, 5962, 0, -6454, 0, -6454, 0, 4161, 0, -6453, 0, -6447, 0, 5964, 0, -6446, 0, -6446, 0, 4468, 0, -6445, 0, -6443, 0, 5971, 0, -6442, 0, -6442, 0, 4469, 0, -6441, 0, -6440, 0, 5974, 0, -6439, 0, -6439, 0, 4470, 0, -6438, 0, -6437, 0, 5976, 0, -6436, 0, -6436, 0, 4162, 0, -6435, 0, -6434, 0, 5978, 0, -6433, 0, -6433, 0, 4471, 0, -6432, 0, -6432, 0, 5980, 0, -6431, 0, -6431, 0, 4472, 0, -6430, 0, -6429, 0, 5981, 0, -6428, 0, -6428, 0, 4474, 0, -6427, 0, -6427, 0, 4473, 0, -6426, 0, -6426, 0, 4475, 0, -6425, 0, -6425, 0, 5983, 0, -6424, 0, -6424, 0, 4476, 0, -6423, 0, -6423, 0, 5984, 0, -6422, 0, -6421, 0, 4478, 0, -6420, 0, -6420, 0, 6447, 0, -6419, 0, -6418, 0, 5985, 0, -6417, 0, -6417, 0, 4481, 0, -6416, 0, -6416, 0, 5987, 0, -6415, 0, -6415, 0, 4482, 0, -6414, 0, -6414, 0, 5460, 0, -6413, 0, -6412, 0, 5988, 0, -6411, 0, -6411, 0, 4483, 0, -6410, 0, -6410, 0, 4163, 0, -6409, 0, -6409, 0, 4166, 0, -6408, 0, -6408, 0, 5990, 0, -6407, 0, -6407, 0, 4485, 0, -6406, 0, -6402, 0, 5991, 0, -6239, 0, -6239, 0, 4487, 0, -6238, 0, -6235, 0, 5996, 0, -6234, 0, -6234, 0, 4488, 0, -6233, 0, -6232, 0, 6000, 0, -6231, 0, -6231, 0, 4489, 0, -6230, 0, -6230, 0, 4491, 0, -6229, 0, -6229, 0, 6002, 0, -6228, 0, -6228, 0, 4167, 0, -6227, 0, -6227, 0, 4493, 0, -6226, 0, -6225, 0, 6003, 0, -6224, 0, -6224, 0, 4494, 0, -6223, 0, -6210, 0, 6005, 0, -6209, 0, -6209, 0, 4495, 0, -6208, 0, -6208, 0, 6019, 0, -6207, 0, -6207, 0, 7783, 0, -6206, 0, -6203, 0, 6020, 0, -6202, 0, -6202, 0, 4497, 0, -6201, 0, -6201, 0, 4499, 0, -6200, 0, -6198, 0, 6024, 0, -6197, 0, -6197, 0, 4501, 0, -6196, 0, -6196, 0, 6027, 0, -6195, 0, -6195, 0, 4502, 0, -6194, 0, -6194, 0, 6028, 0, -6193, 0, -6192, 0, 4503, 0, -6191, 0, -6190, 0, 6029, 0, -6189, 0, -6189, 0, 4506, 0, -6188, 0, -6178, 0, 6031, 0, -6177, 0, -6177, 0, 4508, 0, -6176, 0, -6173, 0, 6042, 0, -6172, 0, -6172, 0, 4509, 0, -6171, 0, -6171, 0, 6046, 0, -6170, 0, -6170, 0, 4510, 0, -6169, 0, -6154, 0, 6047, 0, -6153, 0, -6153, 0, 5797, 0, -6152, 0, -6146, 0, 6063, 0, -5983, 0, -5914, 0, 6070, 0, -5913, 0, -5912, 0, 4551, 0, -5911, 0, -5905, 0, 6140, 0, -5904, 0, -5904, 0, 4553, 0, -5903, 0, -5903, 0, 4180, 0, -5902, 0, -5898, 0, 6147, 0, -5897, 0, -5897, 0, 4555, 0, -5896, 0, -5896, 0, 6152, 0, -5895, 0, -5895, 0, 5800, 0, -5894, 0, -5894, 0, 6153, 0, -5893, 0, -5893, 0, 4556, 0, -5892, 0, -5891, 0, 6154, 0, -5890, 0, -5890, 0, 4557, 0, -5727, 0, -5722, 0, 6156, 0, -5721, 0, -5721, 0, 4560, 0, -5720, 0, -5717, 0, 6162, 0, -5716, 0, -5716, 0, 4561, 0, -5715, 0, -5685, 0, 6166, 0, -5684, 0, -5684, 0, 4563, 0, -5683, 0, -5642, 0, 6197, 0, -5641, 0, -5641, 0, 7988, 0, -5640, 0, -5634, 0, 6239, 0, -5471, 0, -5440, 0, 6246, 0, -5439, 0, -5439, 0, 6123, 0, -5438, 0, -5404, 0, 6278, 0, -5403, 0, -5403, 0, 4577, 0, -5402, 0, -5389, 0, 6313, 0, -5388, 0, -5388, 0, 4183, 0, -5387, 0, -5386, 0, 6327, 0, -5385, 0, -5385, 0, 4579, 0, -5384, 0, -5381, 0, 6329, 0, -5380, 0, -5380, 0, 4581, 0, -5379, 0, -5379, 0, 6333, 0, -5378, 0, -5378, 0, 4582, 0, -5215, 0, -5213, 0, 6334, 0, -5212, 0, -5212, 0, 4584, 0, -5211, 0, -5210, 0, 6337, 0, -5209, 0, -5209, 0, 4586, 0, -5208, 0, -5208, 0, 6339, 0, -5207, 0, -5207, 0, 4588, 0, -5206, 0, -5206, 0, 4184, 0, -5205, 0, -5191, 0, 6340, 0, -5190, 0, -5189, 0, 4590, 0, -5188, 0, -5188, 0, 6355, 0, -5187, 0, -5187, 0, 4592, 0, -5186, 0, -5184, 0, 6356, 0, -5183, 0, -5183, 0, 4593, 0, -5182, 0, -5182, 0, 4595, 0, -5181, 0, -5179, 0, 6359, 0, -5178, 0, -5177, 0, 4596, 0, -5176, 0, -5173, 0, 6362, 0, -5172, 0, -5172, 0, 4599, 0, -5171, 0, -5170, 0, 6366, 0, -5169, 0, -5167, 0, 4600, 0, -5166, 0, -5166, 0, 5552, 0, -5165, 0, -5161, 0, 6368, 0, -5160, 0, -5160, 0, 4603, 0, -5159, 0, -5122, 0, 6373, 0, -4959, 0, -4955, 0, 6411, 0, -4954, 0, -4954, 0, 4614, 0, -4953, 0, -4953, 0, 4616, 0, -4952, 0, -4951, 0, 6416, 0, -4950, 0, -4950, 0, 4618, 0, -4949, 0, -4946, 0, 6418, 0, -4945, 0, -4945, 0, 5950, 0, -4944, 0, -4943, 0, 4620, 0, -4942, 0, -4942, 0, 4187, 0, -4941, 0, -4940, 0, 6422, 0, -4939, 0, -4939, 0, 4625, 0, -4938, 0, -4937, 0, 6424, 0, -4936, 0, -4936, 0, 4627, 0, -4935, 0, -4935, 0, 6426, 0, -4934, 0, -4934, 0, 4629, 0, -4933, 0, -4929, 0, 6427, 0, -4928, 0, -4927, 0, 4632, 0, -4926, 0, -4924, 0, 6432, 0, -4923, 0, -4923, 0, 4634, 0, -4922, 0, -4922, 0, 4636, 0, -4921, 0, -4920, 0, 6435, 0, -4919, 0, -4918, 0, 4188, 0, -4917, 0, -4908, 0, 6437, 0, -4907, 0, -4907, 0, 4638, 0, -4906, 0, -4900, 0, 6447, 0, -4899, 0, -4898, 0, 4640, 0, -4897, 0, -4896, 0, 6454, 0, -4895, 0, -4895, 0, 4642, 0, -4894, 0, -4893, 0, 6456, 0, -4892, 0, -4892, 0, 4644, 0, -4891, 0, -4890, 0, 6458, 0, -4889, 0, -4888, 0, 4645, 0, -4887, 0, -4874, 0, 6460, 0, -4873, 0, -4872, 0, 4647, 0, -4871, 0, -4871, 0, 6474, 0, -4870, 0, -4870, 0, 4650, 0, -4869, 0, -4866, 0, 6475, 0, -4703, 0, -4701, 0, 4653, 0, -4700, 0, -4627, 0, 6479, 0, -4626, 0, -4626, 0, 5351, 0, -4625, 0, -4610, 0, 6553, 0, -4447, 0, -4390, 0, 6569, 0, -4389, 0, -4389, 0, 6494, 0, -4388, 0, -4354, 0, 6627, 0, -4191, 0, -4098, 0, 6662, 0, -3935, 0, -3842, 0, 6756, 0, -3679, 0, -3586, 0, 6850, 0, -3423, 0, -3396, 0, 6944, 0, -3395, 0, -3395, 0, 5731, 0, -3394, 0, -3335, 0, 6972, 0, -3334, 0, -3334, 0, 5771, 0, -3333, 0, -3330, 0, 7032, 0, -3167, 0, -3152, 0, 7036, 0, -3151, 0, -3151, 0, 4191, 0, -3150, 0, -3074, 0, 7052, 0, -2911, 0, -2906, 0, 7129, 0, -2905, 0, -2905, 0, 6484, 0, -2904, 0, -2835, 0, 7135, 0, -2834, 0, -2834, 0, 6684, 0, -2833, 0, -2818, 0, 7205, 0, -2655, 0, -2562, 0, 7221, 0, -2399, 0, -2317, 0, 7315, 0, -2316, 0, -2316, 0, 4279, 0, -2315, 0, -2315, 0, 7398, 0, -2314, 0, -2314, 0, 7139, 0, -2313, 0, -2306, 0, 7399, 0, -2143, 0, -2121, 0, 7407, 0, -2120, 0, -2120, 0, 4247, 0, -2119, 0, -2105, 0, 7430, 0, -2104, 0, -2104, 0, 4266, 0, -2103, 0, -2094, 0, 7445, 0, -2093, 0, -2093, 0, 4340, 0, -2092, 0, -2050, 0, 7455, 0, -1887, 0, -1830, 0, 7498, 0, -1829, 0, -1829, 0, 7572, 0, -1828, 0, -1809, 0, 7556, 0, -1808, 0, -1808, 0, 5088, 0, -1807, 0, -1794, 0, 7576, 0, -1631, 0, -1538, 0, 7590, 0, -1375, 0, -1375, 0, 7709, 0, -1374, 0, -1374, 0, 3558, 0, -1373, 0, -1307, 0, 7684, 0, -1306, 0, -1306, 0, 3644, 0, -1305, 0, -1282, 0, 7751, 0, -1119, 0, -1026, 0, 7775, 0, -863, 0, -856, 0, 7869, 0, -855, 0, -855, 0, 3815, 0, -854, 0, -770, 0, 7877, 0, -607, 0, -514, 0, 7962, 0, -1, 0, -1, 0, 0, 0], ["i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0], ALLOC_STATIC);
_KSCms_UHC_NOTDEF_RANGE=allocate([0, 0, 31, 0, 1, 0], ["i16",0,"i16",0,"i16",0], ALLOC_STATIC);
STRING_TABLE._HPDF_PADDING_STRING=allocate([40,191,78,94,78,117,138,65,100,0,78,86,255,250,1,8,46,46,0,182,208,104,62,128,47,12,169,254,100,83,105,122] /* (\BFN^Nu\8AAd\00NV\F */, "i8", ALLOC_STATIC);
STRING_TABLE.__str1103=allocate([79,0] /* O\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str11104=allocate([85,0] /* U\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str21105=allocate([70,105,108,116,101,114,0] /* Filter\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str31106=allocate([83,116,97,110,100,97,114,100,0] /* Standard\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str41107=allocate([86,0] /* V\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str51108=allocate([82,0] /* R\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str61109=allocate([76,101,110,103,116,104,0] /* Length\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str71110=allocate([80,0] /* P\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str1135=allocate([84,121,112,101,0] /* Type\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str11136=allocate([69,120,116,71,83,116,97,116,101,0] /* ExtGState\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str21137=allocate([67,65,0] /* CA\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str31138=allocate([99,97,0] /* ca\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str41139=allocate([66,77,0] /* BM\00 */, "i8", ALLOC_STATIC);
_HPDF_BM_NAMES=allocate(48, "i8", ALLOC_STATIC);
STRING_TABLE.__str51140=allocate([78,111,114,109,97,108,0] /* Normal\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str61141=allocate([77,117,108,116,105,112,108,121,0] /* Multiply\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str71142=allocate([83,99,114,101,101,110,0] /* Screen\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str81143=allocate([79,118,101,114,108,97,121,0] /* Overlay\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str91144=allocate([68,97,114,107,101,110,0] /* Darken\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str101145=allocate([76,105,103,104,116,101,110,0] /* Lighten\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str111146=allocate([67,111,108,111,114,68,111,100,103,101,0] /* ColorDodge\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str121147=allocate([67,111,108,111,114,66,117,114,110,0] /* ColorBurn\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str131148=allocate([72,97,114,100,76,105,103,104,116,0] /* HardLight\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str141149=allocate([83,111,102,116,76,105,103,104,116,0] /* SoftLight\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str151150=allocate([68,105,102,102,101,114,101,110,99,101,0] /* Difference\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str161151=allocate([69,120,99,108,117,115,105,111,110,0] /* Exclusion\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str1156=allocate([84,121,112,101,0] /* Type\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str11157=allocate([70,111,110,116,0] /* Font\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str21158=allocate([66,97,115,101,70,111,110,116,0] /* BaseFont\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str31159=allocate([83,117,98,116,121,112,101,0] /* Subtype\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str41160=allocate([84,121,112,101,48,0] /* Type0\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str51161=allocate([69,110,99,111,100,105,110,103,0] /* Encoding\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str61162=allocate([68,101,115,99,101,110,100,97,110,116,70,111,110,116,115,0] /* DescendantFonts\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str71163=allocate([67,77,97,112,0] /* CMap\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str81164=allocate([67,77,97,112,78,97,109,101,0] /* CMapName\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str91165=allocate([67,73,68,83,121,115,116,101,109,73,110,102,111,0] /* CIDSystemInfo\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str101166=allocate([82,101,103,105,115,116,114,121,0] /* Registry\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str111167=allocate([79,114,100,101,114,105,110,103,0] /* Ordering\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str121168=allocate([83,117,112,112,108,101,109,101,110,116,0] /* Supplement\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str131169=allocate([87,77,111,100,101,0] /* WMode\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str141170=allocate([37,33,80,83,45,65,100,111,98,101,45,51,46,48,32,82,101,115,111,117,114,99,101,45,67,77,97,112,13,10,0] /* %!PS-Adobe-3.0 Resou */, "i8", ALLOC_STATIC);
STRING_TABLE.__str151171=allocate([37,37,68,111,99,117,109,101,110,116,78,101,101,100,101,100,82,101,115,111,117,114,99,101,115,58,32,80,114,111,99,83,101,116,32,40,67,73,68,73,110,105,116,41,13,10,0] /* %%DocumentNeededReso */, "i8", ALLOC_STATIC);
STRING_TABLE.__str161172=allocate([37,37,73,110,99,108,117,100,101,82,101,115,111,117,114,99,101,58,32,80,114,111,99,83,101,116,32,40,67,73,68,73,110,105,116,41,13,10,0] /* %%IncludeResource: P */, "i8", ALLOC_STATIC);
STRING_TABLE.__str171173=allocate([37,37,66,101,103,105,110,82,101,115,111,117,114,99,101,58,32,67,77,97,112,32,40,0] /* %%BeginResource: CMa */, "i8", ALLOC_STATIC);
STRING_TABLE.__str181174=allocate([41,13,10,0] /* )\0D\0A\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str191175=allocate([37,37,84,105,116,108,101,58,32,40,0] /* %%Title: (\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str201176=allocate([37,37,86,101,114,115,105,111,110,58,32,49,46,48,13,10,0] /* %%Version: 1.0\0D\0A */, "i8", ALLOC_STATIC);
STRING_TABLE.__str211177=allocate([37,37,69,110,100,67,111,109,109,101,110,116,115,13,10,0] /* %%EndComments\0D\0A\ */, "i8", ALLOC_STATIC);
STRING_TABLE.__str221178=allocate([47,67,73,68,73,110,105,116,32,47,80,114,111,99,83,101,116,32,102,105,110,100,114,101,115,111,117,114,99,101,32,98,101,103,105,110,13,10,13,10,0] /* /CIDInit /ProcSet fi */, "i8", ALLOC_STATIC);
STRING_TABLE.__str231179=allocate([49,50,32,100,105,99,116,32,98,101,103,105,110,13,10,13,10,0] /* 12 dict begin\0D\0A\ */, "i8", ALLOC_STATIC);
STRING_TABLE.__str241180=allocate([98,101,103,105,110,99,109,97,112,13,10,13,10,0] /* begincmap\0D\0A\0D\0 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str251181=allocate([47,67,73,68,83,121,115,116,101,109,73,110,102,111,32,51,32,100,105,99,116,32,100,117,112,32,98,101,103,105,110,13,10,0] /* /CIDSystemInfo 3 dic */, "i8", ALLOC_STATIC);
STRING_TABLE.__str261182=allocate([32,32,47,82,101,103,105,115,116,114,121,32,40,0] /*   /Registry (\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str271183=allocate([41,32,100,101,102,13,10,0] /* ) def\0D\0A\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str281184=allocate([32,32,47,79,114,100,101,114,105,110,103,32,40,0] /*   /Ordering (\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str291185=allocate([32,32,47,83,117,112,112,108,101,109,101,110,116,32,0] /*   /Supplement \00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str301186=allocate([32,100,101,102,13,10,0] /*  def\0D\0A\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str311187=allocate([101,110,100,32,100,101,102,13,10,13,10,0] /* end def\0D\0A\0D\0A\ */, "i8", ALLOC_STATIC);
STRING_TABLE.__str321188=allocate([47,67,77,97,112,78,97,109,101,32,47,0] /* /CMapName /\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str331189=allocate([47,67,77,97,112,86,101,114,115,105,111,110,32,49,46,48,32,100,101,102,13,10,0] /* /CMapVersion 1.0 def */, "i8", ALLOC_STATIC);
STRING_TABLE.__str341190=allocate([47,67,77,97,112,84,121,112,101,32,49,32,100,101,102,13,10,13,10,0] /* /CMapType 1 def\0D\0 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str351191=allocate([47,85,73,68,79,102,102,115,101,116,32,0] /* /UIDOffset \00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str361192=allocate([32,100,101,102,13,10,13,10,0] /*  def\0D\0A\0D\0A\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str371193=allocate([47,88,85,73,68,32,91,0] /* /XUID [\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str381194=allocate([93,32,100,101,102,13,10,13,10,0] /* ] def\0D\0A\0D\0A\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str391195=allocate([47,87,77,111,100,101,32,0] /* /WMode \00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str401196=allocate([32,98,101,103,105,110,99,111,100,101,115,112,97,99,101,114,97,110,103,101,13,10,0] /*  begincodespacerange */, "i8", ALLOC_STATIC);
STRING_TABLE.__str411197=allocate([13,10,0] /* \0D\0A\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str421198=allocate([101,110,100,99,111,100,101,115,112,97,99,101,114,97,110,103,101,13,10,13,10,0] /* endcodespacerange\0D */, "i8", ALLOC_STATIC);
STRING_TABLE.__str431199=allocate([32,98,101,103,105,110,110,111,116,100,101,102,114,97,110,103,101,13,10,0] /*  beginnotdefrange\0D */, "i8", ALLOC_STATIC);
STRING_TABLE.__str441200=allocate([101,110,100,110,111,116,100,101,102,114,97,110,103,101,13,10,13,10,0] /* endnotdefrange\0D\0A */, "i8", ALLOC_STATIC);
STRING_TABLE.__str451201=allocate([32,98,101,103,105,110,99,105,100,114,97,110,103,101,13,10,0] /*  begincidrange\0D\0A */, "i8", ALLOC_STATIC);
STRING_TABLE.__str461202=allocate([101,110,100,99,105,100,114,97,110,103,101,13,10,13,10,0] /* endcidrange\0D\0A\0D */, "i8", ALLOC_STATIC);
STRING_TABLE.__str471203=allocate([101,110,100,99,105,100,114,97,110,103,101,13,10,0] /* endcidrange\0D\0A\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str481204=allocate([101,110,100,99,109,97,112,13,10,0] /* endcmap\0D\0A\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str491205=allocate([67,77,97,112,78,97,109,101,32,99,117,114,114,101,110,116,100,105,99,116,32,47,67,77,97,112,32,100,101,102,105,110,101,114,101,115,111,117,114,99,101,32,112,111,112,13,10,0] /* CMapName currentdict */, "i8", ALLOC_STATIC);
STRING_TABLE.__str501206=allocate([101,110,100,13,10,0] /* end\0D\0A\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str511207=allocate([101,110,100,13,10,13,10,0] /* end\0D\0A\0D\0A\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str521208=allocate([37,37,69,110,100,82,101,115,111,117,114,99,101,13,10,0] /* %%EndResource\0D\0A\ */, "i8", ALLOC_STATIC);
STRING_TABLE.__str531209=allocate([37,37,69,79,70,13,10,0] /* %%EOF\0D\0A\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str541210=allocate([67,73,68,70,111,110,116,84,121,112,101,50,0] /* CIDFontType2\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str551211=allocate([68,87,0] /* DW\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str561212=allocate([68,87,50,0] /* DW2\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str571213=allocate([87,0] /* W\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str581214=allocate([67,73,68,84,111,71,73,68,77,97,112,0] /* CIDToGIDMap\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str591215=allocate([70,111,110,116,70,105,108,101,50,0] /* FontFile2\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str601216=allocate([76,101,110,103,116,104,49,0] /* Length1\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str611217=allocate([76,101,110,103,116,104,50,0] /* Length2\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str621218=allocate([76,101,110,103,116,104,51,0] /* Length3\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str631219=allocate([70,111,110,116,68,101,115,99,114,105,112,116,111,114,0] /* FontDescriptor\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str641220=allocate([65,115,99,101,110,116,0] /* Ascent\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str651221=allocate([68,101,115,99,101,110,116,0] /* Descent\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str661222=allocate([70,108,97,103,115,0] /* Flags\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str671223=allocate([70,111,110,116,66,66,111,120,0] /* FontBBox\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str681224=allocate([70,111,110,116,78,97,109,101,0] /* FontName\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str691225=allocate([73,116,97,108,105,99,65,110,103,108,101,0] /* ItalicAngle\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str701226=allocate([83,116,101,109,86,0] /* StemV\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str711227=allocate([88,72,101,105,103,104,116,0] /* XHeight\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str721228=allocate([67,73,68,70,111,110,116,84,121,112,101,48,0] /* CIDFontType0\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str731229=allocate([67,97,112,72,101,105,103,104,116,0] /* CapHeight\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str741230=allocate([77,105,115,115,105,110,103,87,105,100,116,104,0] /* MissingWidth\00 */, "i8", ALLOC_STATIC);
_HPDF_BUILTIN_FONTS=allocate([0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 629, 0, -157, 0, 426, 0, 562, 0, -23, 0, 0, 0, -250, 0, 0, 0, 715, 0, 0, 0, 805, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 629, 0, -157, 0, 439, 0, 562, 0, -113, 0, 0, 0, -250, 0, 0, 0, 749, 0, 0, 0, 801, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 629, 0, -157, 0, 426, 0, 562, 0, -27, 0, 0, 0, -250, 0, 0, 0, 849, 0, 0, 0, 805, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 629, 0, -157, 0, 439, 0, 562, 0, -57, 0, 0, 0, -250, 0, 0, 0, 869, 0, 0, 0, 801, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 718, 0, -207, 0, 523, 0, 718, 0, -166, 0, 0, 0, -225, 0, 0, 0, 1000, 0, 0, 0, 931, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 718, 0, -207, 0, 532, 0, 718, 0, -170, 0, 0, 0, -228, 0, 0, 0, 1003, 0, 0, 0, 962, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 718, 0, -207, 0, 532, 0, 718, 0, -170, 0, 0, 0, -225, 0, 0, 0, 1116, 0, 0, 0, 931, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 718, 0, -207, 0, 532, 0, 718, 0, -174, 0, 0, 0, -228, 0, 0, 0, 1114, 0, 0, 0, 962, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 683, 0, -217, 0, 450, 0, 662, 0, -168, 0, 0, 0, -218, 0, 0, 0, 1000, 0, 0, 0, 898, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 683, 0, -217, 0, 461, 0, 676, 0, -168, 0, 0, 0, -218, 0, 0, 0, 1000, 0, 0, 0, 935, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 683, 0, -217, 0, 441, 0, 653, 0, -169, 0, 0, 0, -217, 0, 0, 0, 1010, 0, 0, 0, 883, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 683, 0, -217, 0, 462, 0, 669, 0, -200, 0, 0, 0, -218, 0, 0, 0, 996, 0, 0, 0, 921, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -180, 0, 0, 0, -293, 0, 0, 0, 1090, 0, 0, 0, 1010, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0, 0, 0, -143, 0, 0, 0, 981, 0, 0, 0, 820, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], ["*",0,0,0,"*",0,0,0,"i32",0,0,0,"i16",0,"i16",0,"i16",0,"i16",0,"float",0,0,0,"float",0,0,0,"float",0,0,0,"float",0,0,0,"*",0,0,0,"*",0,0,0,"i32",0,0,0,"i16",0,"i16",0,"i16",0,"i16",0,"float",0,0,0,"float",0,0,0,"float",0,0,0,"float",0,0,0,"*",0,0,0,"*",0,0,0,"i32",0,0,0,"i16",0,"i16",0,"i16",0,"i16",0,"float",0,0,0,"float",0,0,0,"float",0,0,0,"float",0,0,0,"*",0,0,0,"*",0,0,0,"i32",0,0,0,"i16",0,"i16",0,"i16",0,"i16",0,"float",0,0,0,"float",0,0,0,"float",0,0,0,"float",0,0,0,"*",0,0,0,"*",0,0,0,"i32",0,0,0,"i16",0,"i16",0,"i16",0,"i16",0,"float",0,0,0,"float",0,0,0,"float",0,0,0,"float",0,0,0,"*",0,0,0,"*",0,0,0,"i32",0,0,0,"i16",0,"i16",0,"i16",0,"i16",0,"float",0,0,0,"float",0,0,0,"float",0,0,0,"float",0,0,0,"*",0,0,0,"*",0,0,0,"i32",0,0,0,"i16",0,"i16",0,"i16",0,"i16",0,"float",0,0,0,"float",0,0,0,"float",0,0,0,"float",0,0,0,"*",0,0,0,"*",0,0,0,"i32",0,0,0,"i16",0,"i16",0,"i16",0,"i16",0,"float",0,0,0,"float",0,0,0,"float",0,0,0,"float",0,0,0,"*",0,0,0,"*",0,0,0,"i32",0,0,0,"i16",0,"i16",0,"i16",0,"i16",0,"float",0,0,0,"float",0,0,0,"float",0,0,0,"float",0,0,0,"*",0,0,0,"*",0,0,0,"i32",0,0,0,"i16",0,"i16",0,"i16",0,"i16",0,"float",0,0,0,"float",0,0,0,"float",0,0,0,"float",0,0,0,"*",0,0,0,"*",0,0,0,"i32",0,0,0,"i16",0,"i16",0,"i16",0,"i16",0,"float",0,0,0,"float",0,0,0,"float",0,0,0,"float",0,0,0,"*",0,0,0,"*",0,0,0,"i32",0,0,0,"i16",0,"i16",0,"i16",0,"i16",0,"float",0,0,0,"float",0,0,0,"float",0,0,0,"float",0,0,0,"*",0,0,0,"*",0,0,0,"i32",0,0,0,"i16",0,"i16",0,"i16",0,"i16",0,"float",0,0,0,"float",0,0,0,"float",0,0,0,"float",0,0,0,"*",0,0,0,"*",0,0,0,"i32",0,0,0,"i16",0,"i16",0,"i16",0,"i16",0,"float",0,0,0,"float",0,0,0,"float",0,0,0,"float",0,0,0,"*",0,0,0,"*",0,0,0,"i32",0,0,0,"i16",0,"i16",0,"i16",0,"i16",0,"float",0,0,0,"float",0,0,0,"float",0,0,0,"float",0,0,0], ALLOC_STATIC);
STRING_TABLE.__str1233=allocate([70,111,110,116,83,112,101,99,105,102,105,99,0] /* FontSpecific\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str11234=allocate([67,111,117,114,105,101,114,0] /* Courier\00 */, "i8", ALLOC_STATIC);
_CHAR_DATA_COURIER=allocate([32, 0, 32, 0, 600, 0, 33, 0, 33, 0, 600, 0, 34, 0, 34, 0, 600, 0, 35, 0, 35, 0, 600, 0, 36, 0, 36, 0, 600, 0, 37, 0, 37, 0, 600, 0, 38, 0, 38, 0, 600, 0, 39, 0, 8217, 0, 600, 0, 40, 0, 40, 0, 600, 0, 41, 0, 41, 0, 600, 0, 42, 0, 42, 0, 600, 0, 43, 0, 43, 0, 600, 0, 44, 0, 44, 0, 600, 0, 45, 0, 45, 0, 600, 0, 46, 0, 46, 0, 600, 0, 47, 0, 47, 0, 600, 0, 48, 0, 48, 0, 600, 0, 49, 0, 49, 0, 600, 0, 50, 0, 50, 0, 600, 0, 51, 0, 51, 0, 600, 0, 52, 0, 52, 0, 600, 0, 53, 0, 53, 0, 600, 0, 54, 0, 54, 0, 600, 0, 55, 0, 55, 0, 600, 0, 56, 0, 56, 0, 600, 0, 57, 0, 57, 0, 600, 0, 58, 0, 58, 0, 600, 0, 59, 0, 59, 0, 600, 0, 60, 0, 60, 0, 600, 0, 61, 0, 61, 0, 600, 0, 62, 0, 62, 0, 600, 0, 63, 0, 63, 0, 600, 0, 64, 0, 64, 0, 600, 0, 65, 0, 65, 0, 600, 0, 66, 0, 66, 0, 600, 0, 67, 0, 67, 0, 600, 0, 68, 0, 68, 0, 600, 0, 69, 0, 69, 0, 600, 0, 70, 0, 70, 0, 600, 0, 71, 0, 71, 0, 600, 0, 72, 0, 72, 0, 600, 0, 73, 0, 73, 0, 600, 0, 74, 0, 74, 0, 600, 0, 75, 0, 75, 0, 600, 0, 76, 0, 76, 0, 600, 0, 77, 0, 77, 0, 600, 0, 78, 0, 78, 0, 600, 0, 79, 0, 79, 0, 600, 0, 80, 0, 80, 0, 600, 0, 81, 0, 81, 0, 600, 0, 82, 0, 82, 0, 600, 0, 83, 0, 83, 0, 600, 0, 84, 0, 84, 0, 600, 0, 85, 0, 85, 0, 600, 0, 86, 0, 86, 0, 600, 0, 87, 0, 87, 0, 600, 0, 88, 0, 88, 0, 600, 0, 89, 0, 89, 0, 600, 0, 90, 0, 90, 0, 600, 0, 91, 0, 91, 0, 600, 0, 92, 0, 92, 0, 600, 0, 93, 0, 93, 0, 600, 0, 94, 0, 94, 0, 600, 0, 95, 0, 95, 0, 600, 0, 96, 0, 8216, 0, 600, 0, 97, 0, 97, 0, 600, 0, 98, 0, 98, 0, 600, 0, 99, 0, 99, 0, 600, 0, 100, 0, 100, 0, 600, 0, 101, 0, 101, 0, 600, 0, 102, 0, 102, 0, 600, 0, 103, 0, 103, 0, 600, 0, 104, 0, 104, 0, 600, 0, 105, 0, 105, 0, 600, 0, 106, 0, 106, 0, 600, 0, 107, 0, 107, 0, 600, 0, 108, 0, 108, 0, 600, 0, 109, 0, 109, 0, 600, 0, 110, 0, 110, 0, 600, 0, 111, 0, 111, 0, 600, 0, 112, 0, 112, 0, 600, 0, 113, 0, 113, 0, 600, 0, 114, 0, 114, 0, 600, 0, 115, 0, 115, 0, 600, 0, 116, 0, 116, 0, 600, 0, 117, 0, 117, 0, 600, 0, 118, 0, 118, 0, 600, 0, 119, 0, 119, 0, 600, 0, 120, 0, 120, 0, 600, 0, 121, 0, 121, 0, 600, 0, 122, 0, 122, 0, 600, 0, 123, 0, 123, 0, 600, 0, 124, 0, 124, 0, 600, 0, 125, 0, 125, 0, 600, 0, 126, 0, 126, 0, 600, 0, 161, 0, 161, 0, 600, 0, 162, 0, 162, 0, 600, 0, 163, 0, 163, 0, 600, 0, 164, 0, 8260, 0, 600, 0, 165, 0, 165, 0, 600, 0, 166, 0, 402, 0, 600, 0, 167, 0, 167, 0, 600, 0, 168, 0, 164, 0, 600, 0, 169, 0, 39, 0, 600, 0, 170, 0, 8220, 0, 600, 0, 171, 0, 171, 0, 600, 0, 172, 0, 8249, 0, 600, 0, 173, 0, 8250, 0, 600, 0, 174, 0, -1279, 0, 600, 0, 175, 0, -1278, 0, 600, 0, 177, 0, 8211, 0, 600, 0, 178, 0, 8224, 0, 600, 0, 179, 0, 8225, 0, 600, 0, 180, 0, 183, 0, 600, 0, 182, 0, 182, 0, 600, 0, 183, 0, 8226, 0, 600, 0, 184, 0, 8218, 0, 600, 0, 185, 0, 8222, 0, 600, 0, 186, 0, 8221, 0, 600, 0, 187, 0, 187, 0, 600, 0, 188, 0, 8230, 0, 600, 0, 189, 0, 8240, 0, 600, 0, 191, 0, 191, 0, 600, 0, 193, 0, 96, 0, 600, 0, 194, 0, 180, 0, 600, 0, 195, 0, 710, 0, 600, 0, 196, 0, 732, 0, 600, 0, 197, 0, 175, 0, 600, 0, 198, 0, 728, 0, 600, 0, 199, 0, 729, 0, 600, 0, 200, 0, 168, 0, 600, 0, 202, 0, 730, 0, 600, 0, 203, 0, 184, 0, 600, 0, 205, 0, 733, 0, 600, 0, 206, 0, 731, 0, 600, 0, 207, 0, 711, 0, 600, 0, 208, 0, 8212, 0, 600, 0, 225, 0, 198, 0, 600, 0, 227, 0, 170, 0, 600, 0, 232, 0, 321, 0, 600, 0, 233, 0, 216, 0, 600, 0, 234, 0, 338, 0, 600, 0, 235, 0, 186, 0, 600, 0, 241, 0, 230, 0, 600, 0, 245, 0, 305, 0, 600, 0, 248, 0, 322, 0, 600, 0, 249, 0, 248, 0, 600, 0, 250, 0, 339, 0, 600, 0, 251, 0, 223, 0, 600, 0, -1, 0, 207, 0, 600, 0, -1, 0, 233, 0, 600, 0, -1, 0, 259, 0, 600, 0, -1, 0, 369, 0, 600, 0, -1, 0, 283, 0, 600, 0, -1, 0, 376, 0, 600, 0, -1, 0, 247, 0, 600, 0, -1, 0, 221, 0, 600, 0, -1, 0, 194, 0, 600, 0, -1, 0, 225, 0, 600, 0, -1, 0, 219, 0, 600, 0, -1, 0, 253, 0, 600, 0, -1, 0, 537, 0, 600, 0, -1, 0, 234, 0, 600, 0, -1, 0, 366, 0, 600, 0, -1, 0, 220, 0, 600, 0, -1, 0, 261, 0, 600, 0, -1, 0, 218, 0, 600, 0, -1, 0, 371, 0, 600, 0, -1, 0, 203, 0, 600, 0, -1, 0, 272, 0, 600, 0, -1, 0, -2365, 0, 600, 0, -1, 0, 169, 0, 600, 0, -1, 0, 274, 0, 600, 0, -1, 0, 269, 0, 600, 0, -1, 0, 229, 0, 600, 0, -1, 0, 325, 0, 600, 0, -1, 0, 314, 0, 600, 0, -1, 0, 224, 0, 600, 0, -1, 0, 354, 0, 600, 0, -1, 0, 262, 0, 600, 0, -1, 0, 227, 0, 600, 0, -1, 0, 278, 0, 600, 0, -1, 0, 353, 0, 600, 0, -1, 0, 351, 0, 600, 0, -1, 0, 237, 0, 600, 0, -1, 0, 9674, 0, 600, 0, -1, 0, 344, 0, 600, 0, -1, 0, 290, 0, 600, 0, -1, 0, 251, 0, 600, 0, -1, 0, 226, 0, 600, 0, -1, 0, 256, 0, 600, 0, -1, 0, 345, 0, 600, 0, -1, 0, 231, 0, 600, 0, -1, 0, 379, 0, 600, 0, -1, 0, 222, 0, 600, 0, -1, 0, 332, 0, 600, 0, -1, 0, 340, 0, 600, 0, -1, 0, 346, 0, 600, 0, -1, 0, 271, 0, 600, 0, -1, 0, 362, 0, 600, 0, -1, 0, 367, 0, 600, 0, -1, 0, 179, 0, 600, 0, -1, 0, 210, 0, 600, 0, -1, 0, 192, 0, 600, 0, -1, 0, 258, 0, 600, 0, -1, 0, 215, 0, 600, 0, -1, 0, 250, 0, 600, 0, -1, 0, 356, 0, 600, 0, -1, 0, 8706, 0, 600, 0, -1, 0, 255, 0, 600, 0, -1, 0, 323, 0, 600, 0, -1, 0, 238, 0, 600, 0, -1, 0, 202, 0, 600, 0, -1, 0, 228, 0, 600, 0, -1, 0, 235, 0, 600, 0, -1, 0, 263, 0, 600, 0, -1, 0, 324, 0, 600, 0, -1, 0, 363, 0, 600, 0, -1, 0, 327, 0, 600, 0, -1, 0, 205, 0, 600, 0, -1, 0, 177, 0, 600, 0, -1, 0, 166, 0, 600, 0, -1, 0, 174, 0, 600, 0, -1, 0, 286, 0, 600, 0, -1, 0, 304, 0, 600, 0, -1, 0, 8721, 0, 600, 0, -1, 0, 200, 0, 600, 0, -1, 0, 341, 0, 600, 0, -1, 0, 333, 0, 600, 0, -1, 0, 377, 0, 600, 0, -1, 0, 381, 0, 600, 0, -1, 0, 8805, 0, 600, 0, -1, 0, 208, 0, 600, 0, -1, 0, 199, 0, 600, 0, -1, 0, 316, 0, 600, 0, -1, 0, 357, 0, 600, 0, -1, 0, 281, 0, 600, 0, -1, 0, 370, 0, 600, 0, -1, 0, 193, 0, 600, 0, -1, 0, 196, 0, 600, 0, -1, 0, 232, 0, 600, 0, -1, 0, 378, 0, 600, 0, -1, 0, 303, 0, 600, 0, -1, 0, 211, 0, 600, 0, -1, 0, 243, 0, 600, 0, -1, 0, 257, 0, 600, 0, -1, 0, 347, 0, 600, 0, -1, 0, 239, 0, 600, 0, -1, 0, 212, 0, 600, 0, -1, 0, 217, 0, 600, 0, -1, 0, 916, 0, 600, 0, -1, 0, 254, 0, 600, 0, -1, 0, 178, 0, 600, 0, -1, 0, 214, 0, 600, 0, -1, 0, 181, 0, 600, 0, -1, 0, 236, 0, 600, 0, -1, 0, 337, 0, 600, 0, -1, 0, 280, 0, 600, 0, -1, 0, 273, 0, 600, 0, -1, 0, 190, 0, 600, 0, -1, 0, 350, 0, 600, 0, -1, 0, 318, 0, 600, 0, -1, 0, 310, 0, 600, 0, -1, 0, 313, 0, 600, 0, -1, 0, 8482, 0, 600, 0, -1, 0, 279, 0, 600, 0, -1, 0, 204, 0, 600, 0, -1, 0, 298, 0, 600, 0, -1, 0, 317, 0, 600, 0, -1, 0, 189, 0, 600, 0, -1, 0, 8804, 0, 600, 0, -1, 0, 244, 0, 600, 0, -1, 0, 241, 0, 600, 0, -1, 0, 368, 0, 600, 0, -1, 0, 201, 0, 600, 0, -1, 0, 275, 0, 600, 0, -1, 0, 287, 0, 600, 0, -1, 0, 188, 0, 600, 0, -1, 0, 352, 0, 600, 0, -1, 0, 536, 0, 600, 0, -1, 0, 336, 0, 600, 0, -1, 0, 176, 0, 600, 0, -1, 0, 242, 0, 600, 0, -1, 0, 268, 0, 600, 0, -1, 0, 249, 0, 600, 0, -1, 0, 8730, 0, 600, 0, -1, 0, 270, 0, 600, 0, -1, 0, 343, 0, 600, 0, -1, 0, 209, 0, 600, 0, -1, 0, 245, 0, 600, 0, -1, 0, 342, 0, 600, 0, -1, 0, 315, 0, 600, 0, -1, 0, 195, 0, 600, 0, -1, 0, 260, 0, 600, 0, -1, 0, 197, 0, 600, 0, -1, 0, 213, 0, 600, 0, -1, 0, 380, 0, 600, 0, -1, 0, 282, 0, 600, 0, -1, 0, 302, 0, 600, 0, -1, 0, 311, 0, 600, 0, -1, 0, 8722, 0, 600, 0, -1, 0, 206, 0, 600, 0, -1, 0, 328, 0, 600, 0, -1, 0, 355, 0, 600, 0, -1, 0, 172, 0, 600, 0, -1, 0, 246, 0, 600, 0, -1, 0, 252, 0, 600, 0, -1, 0, 8800, 0, 600, 0, -1, 0, 291, 0, 600, 0, -1, 0, 240, 0, 600, 0, -1, 0, 382, 0, 600, 0, -1, 0, 326, 0, 600, 0, -1, 0, 185, 0, 600, 0, -1, 0, 299, 0, 600, 0, -1, 0, 8364, 0, 600, 0, -1, 0, -1, 0, 0, 0], ["i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0], ALLOC_STATIC);
STRING_TABLE.__str21235=allocate([67,111,117,114,105,101,114,45,66,111,108,100,0] /* Courier-Bold\00 */, "i8", ALLOC_STATIC);
_CHAR_DATA_COURIER_BOLD=allocate([32, 0, 32, 0, 600, 0, 33, 0, 33, 0, 600, 0, 34, 0, 34, 0, 600, 0, 35, 0, 35, 0, 600, 0, 36, 0, 36, 0, 600, 0, 37, 0, 37, 0, 600, 0, 38, 0, 38, 0, 600, 0, 39, 0, 8217, 0, 600, 0, 40, 0, 40, 0, 600, 0, 41, 0, 41, 0, 600, 0, 42, 0, 42, 0, 600, 0, 43, 0, 43, 0, 600, 0, 44, 0, 44, 0, 600, 0, 45, 0, 45, 0, 600, 0, 46, 0, 46, 0, 600, 0, 47, 0, 47, 0, 600, 0, 48, 0, 48, 0, 600, 0, 49, 0, 49, 0, 600, 0, 50, 0, 50, 0, 600, 0, 51, 0, 51, 0, 600, 0, 52, 0, 52, 0, 600, 0, 53, 0, 53, 0, 600, 0, 54, 0, 54, 0, 600, 0, 55, 0, 55, 0, 600, 0, 56, 0, 56, 0, 600, 0, 57, 0, 57, 0, 600, 0, 58, 0, 58, 0, 600, 0, 59, 0, 59, 0, 600, 0, 60, 0, 60, 0, 600, 0, 61, 0, 61, 0, 600, 0, 62, 0, 62, 0, 600, 0, 63, 0, 63, 0, 600, 0, 64, 0, 64, 0, 600, 0, 65, 0, 65, 0, 600, 0, 66, 0, 66, 0, 600, 0, 67, 0, 67, 0, 600, 0, 68, 0, 68, 0, 600, 0, 69, 0, 69, 0, 600, 0, 70, 0, 70, 0, 600, 0, 71, 0, 71, 0, 600, 0, 72, 0, 72, 0, 600, 0, 73, 0, 73, 0, 600, 0, 74, 0, 74, 0, 600, 0, 75, 0, 75, 0, 600, 0, 76, 0, 76, 0, 600, 0, 77, 0, 77, 0, 600, 0, 78, 0, 78, 0, 600, 0, 79, 0, 79, 0, 600, 0, 80, 0, 80, 0, 600, 0, 81, 0, 81, 0, 600, 0, 82, 0, 82, 0, 600, 0, 83, 0, 83, 0, 600, 0, 84, 0, 84, 0, 600, 0, 85, 0, 85, 0, 600, 0, 86, 0, 86, 0, 600, 0, 87, 0, 87, 0, 600, 0, 88, 0, 88, 0, 600, 0, 89, 0, 89, 0, 600, 0, 90, 0, 90, 0, 600, 0, 91, 0, 91, 0, 600, 0, 92, 0, 92, 0, 600, 0, 93, 0, 93, 0, 600, 0, 94, 0, 94, 0, 600, 0, 95, 0, 95, 0, 600, 0, 96, 0, 8216, 0, 600, 0, 97, 0, 97, 0, 600, 0, 98, 0, 98, 0, 600, 0, 99, 0, 99, 0, 600, 0, 100, 0, 100, 0, 600, 0, 101, 0, 101, 0, 600, 0, 102, 0, 102, 0, 600, 0, 103, 0, 103, 0, 600, 0, 104, 0, 104, 0, 600, 0, 105, 0, 105, 0, 600, 0, 106, 0, 106, 0, 600, 0, 107, 0, 107, 0, 600, 0, 108, 0, 108, 0, 600, 0, 109, 0, 109, 0, 600, 0, 110, 0, 110, 0, 600, 0, 111, 0, 111, 0, 600, 0, 112, 0, 112, 0, 600, 0, 113, 0, 113, 0, 600, 0, 114, 0, 114, 0, 600, 0, 115, 0, 115, 0, 600, 0, 116, 0, 116, 0, 600, 0, 117, 0, 117, 0, 600, 0, 118, 0, 118, 0, 600, 0, 119, 0, 119, 0, 600, 0, 120, 0, 120, 0, 600, 0, 121, 0, 121, 0, 600, 0, 122, 0, 122, 0, 600, 0, 123, 0, 123, 0, 600, 0, 124, 0, 124, 0, 600, 0, 125, 0, 125, 0, 600, 0, 126, 0, 126, 0, 600, 0, 161, 0, 161, 0, 600, 0, 162, 0, 162, 0, 600, 0, 163, 0, 163, 0, 600, 0, 164, 0, 8260, 0, 600, 0, 165, 0, 165, 0, 600, 0, 166, 0, 402, 0, 600, 0, 167, 0, 167, 0, 600, 0, 168, 0, 164, 0, 600, 0, 169, 0, 39, 0, 600, 0, 170, 0, 8220, 0, 600, 0, 171, 0, 171, 0, 600, 0, 172, 0, 8249, 0, 600, 0, 173, 0, 8250, 0, 600, 0, 174, 0, -1279, 0, 600, 0, 175, 0, -1278, 0, 600, 0, 177, 0, 8211, 0, 600, 0, 178, 0, 8224, 0, 600, 0, 179, 0, 8225, 0, 600, 0, 180, 0, 183, 0, 600, 0, 182, 0, 182, 0, 600, 0, 183, 0, 8226, 0, 600, 0, 184, 0, 8218, 0, 600, 0, 185, 0, 8222, 0, 600, 0, 186, 0, 8221, 0, 600, 0, 187, 0, 187, 0, 600, 0, 188, 0, 8230, 0, 600, 0, 189, 0, 8240, 0, 600, 0, 191, 0, 191, 0, 600, 0, 193, 0, 96, 0, 600, 0, 194, 0, 180, 0, 600, 0, 195, 0, 710, 0, 600, 0, 196, 0, 732, 0, 600, 0, 197, 0, 175, 0, 600, 0, 198, 0, 728, 0, 600, 0, 199, 0, 729, 0, 600, 0, 200, 0, 168, 0, 600, 0, 202, 0, 730, 0, 600, 0, 203, 0, 184, 0, 600, 0, 205, 0, 733, 0, 600, 0, 206, 0, 731, 0, 600, 0, 207, 0, 711, 0, 600, 0, 208, 0, 8212, 0, 600, 0, 225, 0, 198, 0, 600, 0, 227, 0, 170, 0, 600, 0, 232, 0, 321, 0, 600, 0, 233, 0, 216, 0, 600, 0, 234, 0, 338, 0, 600, 0, 235, 0, 186, 0, 600, 0, 241, 0, 230, 0, 600, 0, 245, 0, 305, 0, 600, 0, 248, 0, 322, 0, 600, 0, 249, 0, 248, 0, 600, 0, 250, 0, 339, 0, 600, 0, 251, 0, 223, 0, 600, 0, -1, 0, 207, 0, 600, 0, -1, 0, 233, 0, 600, 0, -1, 0, 259, 0, 600, 0, -1, 0, 369, 0, 600, 0, -1, 0, 283, 0, 600, 0, -1, 0, 376, 0, 600, 0, -1, 0, 247, 0, 600, 0, -1, 0, 221, 0, 600, 0, -1, 0, 194, 0, 600, 0, -1, 0, 225, 0, 600, 0, -1, 0, 219, 0, 600, 0, -1, 0, 253, 0, 600, 0, -1, 0, 537, 0, 600, 0, -1, 0, 234, 0, 600, 0, -1, 0, 366, 0, 600, 0, -1, 0, 220, 0, 600, 0, -1, 0, 261, 0, 600, 0, -1, 0, 218, 0, 600, 0, -1, 0, 371, 0, 600, 0, -1, 0, 203, 0, 600, 0, -1, 0, 272, 0, 600, 0, -1, 0, -2365, 0, 600, 0, -1, 0, 169, 0, 600, 0, -1, 0, 274, 0, 600, 0, -1, 0, 269, 0, 600, 0, -1, 0, 229, 0, 600, 0, -1, 0, 325, 0, 600, 0, -1, 0, 314, 0, 600, 0, -1, 0, 224, 0, 600, 0, -1, 0, 354, 0, 600, 0, -1, 0, 262, 0, 600, 0, -1, 0, 227, 0, 600, 0, -1, 0, 278, 0, 600, 0, -1, 0, 353, 0, 600, 0, -1, 0, 351, 0, 600, 0, -1, 0, 237, 0, 600, 0, -1, 0, 9674, 0, 600, 0, -1, 0, 344, 0, 600, 0, -1, 0, 290, 0, 600, 0, -1, 0, 251, 0, 600, 0, -1, 0, 226, 0, 600, 0, -1, 0, 256, 0, 600, 0, -1, 0, 345, 0, 600, 0, -1, 0, 231, 0, 600, 0, -1, 0, 379, 0, 600, 0, -1, 0, 222, 0, 600, 0, -1, 0, 332, 0, 600, 0, -1, 0, 340, 0, 600, 0, -1, 0, 346, 0, 600, 0, -1, 0, 271, 0, 600, 0, -1, 0, 362, 0, 600, 0, -1, 0, 367, 0, 600, 0, -1, 0, 179, 0, 600, 0, -1, 0, 210, 0, 600, 0, -1, 0, 192, 0, 600, 0, -1, 0, 258, 0, 600, 0, -1, 0, 215, 0, 600, 0, -1, 0, 250, 0, 600, 0, -1, 0, 356, 0, 600, 0, -1, 0, 8706, 0, 600, 0, -1, 0, 255, 0, 600, 0, -1, 0, 323, 0, 600, 0, -1, 0, 238, 0, 600, 0, -1, 0, 202, 0, 600, 0, -1, 0, 228, 0, 600, 0, -1, 0, 235, 0, 600, 0, -1, 0, 263, 0, 600, 0, -1, 0, 324, 0, 600, 0, -1, 0, 363, 0, 600, 0, -1, 0, 327, 0, 600, 0, -1, 0, 205, 0, 600, 0, -1, 0, 177, 0, 600, 0, -1, 0, 166, 0, 600, 0, -1, 0, 174, 0, 600, 0, -1, 0, 286, 0, 600, 0, -1, 0, 304, 0, 600, 0, -1, 0, 8721, 0, 600, 0, -1, 0, 200, 0, 600, 0, -1, 0, 341, 0, 600, 0, -1, 0, 333, 0, 600, 0, -1, 0, 377, 0, 600, 0, -1, 0, 381, 0, 600, 0, -1, 0, 8805, 0, 600, 0, -1, 0, 208, 0, 600, 0, -1, 0, 199, 0, 600, 0, -1, 0, 316, 0, 600, 0, -1, 0, 357, 0, 600, 0, -1, 0, 281, 0, 600, 0, -1, 0, 370, 0, 600, 0, -1, 0, 193, 0, 600, 0, -1, 0, 196, 0, 600, 0, -1, 0, 232, 0, 600, 0, -1, 0, 378, 0, 600, 0, -1, 0, 303, 0, 600, 0, -1, 0, 211, 0, 600, 0, -1, 0, 243, 0, 600, 0, -1, 0, 257, 0, 600, 0, -1, 0, 347, 0, 600, 0, -1, 0, 239, 0, 600, 0, -1, 0, 212, 0, 600, 0, -1, 0, 217, 0, 600, 0, -1, 0, 916, 0, 600, 0, -1, 0, 254, 0, 600, 0, -1, 0, 178, 0, 600, 0, -1, 0, 214, 0, 600, 0, -1, 0, 181, 0, 600, 0, -1, 0, 236, 0, 600, 0, -1, 0, 337, 0, 600, 0, -1, 0, 280, 0, 600, 0, -1, 0, 273, 0, 600, 0, -1, 0, 190, 0, 600, 0, -1, 0, 350, 0, 600, 0, -1, 0, 318, 0, 600, 0, -1, 0, 310, 0, 600, 0, -1, 0, 313, 0, 600, 0, -1, 0, 8482, 0, 600, 0, -1, 0, 279, 0, 600, 0, -1, 0, 204, 0, 600, 0, -1, 0, 298, 0, 600, 0, -1, 0, 317, 0, 600, 0, -1, 0, 189, 0, 600, 0, -1, 0, 8804, 0, 600, 0, -1, 0, 244, 0, 600, 0, -1, 0, 241, 0, 600, 0, -1, 0, 368, 0, 600, 0, -1, 0, 201, 0, 600, 0, -1, 0, 275, 0, 600, 0, -1, 0, 287, 0, 600, 0, -1, 0, 188, 0, 600, 0, -1, 0, 352, 0, 600, 0, -1, 0, 536, 0, 600, 0, -1, 0, 336, 0, 600, 0, -1, 0, 176, 0, 600, 0, -1, 0, 242, 0, 600, 0, -1, 0, 268, 0, 600, 0, -1, 0, 249, 0, 600, 0, -1, 0, 8730, 0, 600, 0, -1, 0, 270, 0, 600, 0, -1, 0, 343, 0, 600, 0, -1, 0, 209, 0, 600, 0, -1, 0, 245, 0, 600, 0, -1, 0, 342, 0, 600, 0, -1, 0, 315, 0, 600, 0, -1, 0, 195, 0, 600, 0, -1, 0, 260, 0, 600, 0, -1, 0, 197, 0, 600, 0, -1, 0, 213, 0, 600, 0, -1, 0, 380, 0, 600, 0, -1, 0, 282, 0, 600, 0, -1, 0, 302, 0, 600, 0, -1, 0, 311, 0, 600, 0, -1, 0, 8722, 0, 600, 0, -1, 0, 206, 0, 600, 0, -1, 0, 328, 0, 600, 0, -1, 0, 355, 0, 600, 0, -1, 0, 172, 0, 600, 0, -1, 0, 246, 0, 600, 0, -1, 0, 252, 0, 600, 0, -1, 0, 8800, 0, 600, 0, -1, 0, 291, 0, 600, 0, -1, 0, 240, 0, 600, 0, -1, 0, 382, 0, 600, 0, -1, 0, 326, 0, 600, 0, -1, 0, 185, 0, 600, 0, -1, 0, 299, 0, 600, 0, -1, 0, 8364, 0, 600, 0, -1, 0, -1, 0, 0, 0], ["i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0], ALLOC_STATIC);
STRING_TABLE.__str31236=allocate([67,111,117,114,105,101,114,45,79,98,108,105,113,117,101,0] /* Courier-Oblique\00 */, "i8", ALLOC_STATIC);
_CHAR_DATA_COURIER_OBLIQUE=allocate([32, 0, 32, 0, 600, 0, 33, 0, 33, 0, 600, 0, 34, 0, 34, 0, 600, 0, 35, 0, 35, 0, 600, 0, 36, 0, 36, 0, 600, 0, 37, 0, 37, 0, 600, 0, 38, 0, 38, 0, 600, 0, 39, 0, 8217, 0, 600, 0, 40, 0, 40, 0, 600, 0, 41, 0, 41, 0, 600, 0, 42, 0, 42, 0, 600, 0, 43, 0, 43, 0, 600, 0, 44, 0, 44, 0, 600, 0, 45, 0, 45, 0, 600, 0, 46, 0, 46, 0, 600, 0, 47, 0, 47, 0, 600, 0, 48, 0, 48, 0, 600, 0, 49, 0, 49, 0, 600, 0, 50, 0, 50, 0, 600, 0, 51, 0, 51, 0, 600, 0, 52, 0, 52, 0, 600, 0, 53, 0, 53, 0, 600, 0, 54, 0, 54, 0, 600, 0, 55, 0, 55, 0, 600, 0, 56, 0, 56, 0, 600, 0, 57, 0, 57, 0, 600, 0, 58, 0, 58, 0, 600, 0, 59, 0, 59, 0, 600, 0, 60, 0, 60, 0, 600, 0, 61, 0, 61, 0, 600, 0, 62, 0, 62, 0, 600, 0, 63, 0, 63, 0, 600, 0, 64, 0, 64, 0, 600, 0, 65, 0, 65, 0, 600, 0, 66, 0, 66, 0, 600, 0, 67, 0, 67, 0, 600, 0, 68, 0, 68, 0, 600, 0, 69, 0, 69, 0, 600, 0, 70, 0, 70, 0, 600, 0, 71, 0, 71, 0, 600, 0, 72, 0, 72, 0, 600, 0, 73, 0, 73, 0, 600, 0, 74, 0, 74, 0, 600, 0, 75, 0, 75, 0, 600, 0, 76, 0, 76, 0, 600, 0, 77, 0, 77, 0, 600, 0, 78, 0, 78, 0, 600, 0, 79, 0, 79, 0, 600, 0, 80, 0, 80, 0, 600, 0, 81, 0, 81, 0, 600, 0, 82, 0, 82, 0, 600, 0, 83, 0, 83, 0, 600, 0, 84, 0, 84, 0, 600, 0, 85, 0, 85, 0, 600, 0, 86, 0, 86, 0, 600, 0, 87, 0, 87, 0, 600, 0, 88, 0, 88, 0, 600, 0, 89, 0, 89, 0, 600, 0, 90, 0, 90, 0, 600, 0, 91, 0, 91, 0, 600, 0, 92, 0, 92, 0, 600, 0, 93, 0, 93, 0, 600, 0, 94, 0, 94, 0, 600, 0, 95, 0, 95, 0, 600, 0, 96, 0, 8216, 0, 600, 0, 97, 0, 97, 0, 600, 0, 98, 0, 98, 0, 600, 0, 99, 0, 99, 0, 600, 0, 100, 0, 100, 0, 600, 0, 101, 0, 101, 0, 600, 0, 102, 0, 102, 0, 600, 0, 103, 0, 103, 0, 600, 0, 104, 0, 104, 0, 600, 0, 105, 0, 105, 0, 600, 0, 106, 0, 106, 0, 600, 0, 107, 0, 107, 0, 600, 0, 108, 0, 108, 0, 600, 0, 109, 0, 109, 0, 600, 0, 110, 0, 110, 0, 600, 0, 111, 0, 111, 0, 600, 0, 112, 0, 112, 0, 600, 0, 113, 0, 113, 0, 600, 0, 114, 0, 114, 0, 600, 0, 115, 0, 115, 0, 600, 0, 116, 0, 116, 0, 600, 0, 117, 0, 117, 0, 600, 0, 118, 0, 118, 0, 600, 0, 119, 0, 119, 0, 600, 0, 120, 0, 120, 0, 600, 0, 121, 0, 121, 0, 600, 0, 122, 0, 122, 0, 600, 0, 123, 0, 123, 0, 600, 0, 124, 0, 124, 0, 600, 0, 125, 0, 125, 0, 600, 0, 126, 0, 126, 0, 600, 0, 161, 0, 161, 0, 600, 0, 162, 0, 162, 0, 600, 0, 163, 0, 163, 0, 600, 0, 164, 0, 8260, 0, 600, 0, 165, 0, 165, 0, 600, 0, 166, 0, 402, 0, 600, 0, 167, 0, 167, 0, 600, 0, 168, 0, 164, 0, 600, 0, 169, 0, 39, 0, 600, 0, 170, 0, 8220, 0, 600, 0, 171, 0, 171, 0, 600, 0, 172, 0, 8249, 0, 600, 0, 173, 0, 8250, 0, 600, 0, 174, 0, -1279, 0, 600, 0, 175, 0, -1278, 0, 600, 0, 177, 0, 8211, 0, 600, 0, 178, 0, 8224, 0, 600, 0, 179, 0, 8225, 0, 600, 0, 180, 0, 183, 0, 600, 0, 182, 0, 182, 0, 600, 0, 183, 0, 8226, 0, 600, 0, 184, 0, 8218, 0, 600, 0, 185, 0, 8222, 0, 600, 0, 186, 0, 8221, 0, 600, 0, 187, 0, 187, 0, 600, 0, 188, 0, 8230, 0, 600, 0, 189, 0, 8240, 0, 600, 0, 191, 0, 191, 0, 600, 0, 193, 0, 96, 0, 600, 0, 194, 0, 180, 0, 600, 0, 195, 0, 710, 0, 600, 0, 196, 0, 732, 0, 600, 0, 197, 0, 175, 0, 600, 0, 198, 0, 728, 0, 600, 0, 199, 0, 729, 0, 600, 0, 200, 0, 168, 0, 600, 0, 202, 0, 730, 0, 600, 0, 203, 0, 184, 0, 600, 0, 205, 0, 733, 0, 600, 0, 206, 0, 731, 0, 600, 0, 207, 0, 711, 0, 600, 0, 208, 0, 8212, 0, 600, 0, 225, 0, 198, 0, 600, 0, 227, 0, 170, 0, 600, 0, 232, 0, 321, 0, 600, 0, 233, 0, 216, 0, 600, 0, 234, 0, 338, 0, 600, 0, 235, 0, 186, 0, 600, 0, 241, 0, 230, 0, 600, 0, 245, 0, 305, 0, 600, 0, 248, 0, 322, 0, 600, 0, 249, 0, 248, 0, 600, 0, 250, 0, 339, 0, 600, 0, 251, 0, 223, 0, 600, 0, -1, 0, 207, 0, 600, 0, -1, 0, 233, 0, 600, 0, -1, 0, 259, 0, 600, 0, -1, 0, 369, 0, 600, 0, -1, 0, 283, 0, 600, 0, -1, 0, 376, 0, 600, 0, -1, 0, 247, 0, 600, 0, -1, 0, 221, 0, 600, 0, -1, 0, 194, 0, 600, 0, -1, 0, 225, 0, 600, 0, -1, 0, 219, 0, 600, 0, -1, 0, 253, 0, 600, 0, -1, 0, 537, 0, 600, 0, -1, 0, 234, 0, 600, 0, -1, 0, 366, 0, 600, 0, -1, 0, 220, 0, 600, 0, -1, 0, 261, 0, 600, 0, -1, 0, 218, 0, 600, 0, -1, 0, 371, 0, 600, 0, -1, 0, 203, 0, 600, 0, -1, 0, 272, 0, 600, 0, -1, 0, -2365, 0, 600, 0, -1, 0, 169, 0, 600, 0, -1, 0, 274, 0, 600, 0, -1, 0, 269, 0, 600, 0, -1, 0, 229, 0, 600, 0, -1, 0, 325, 0, 600, 0, -1, 0, 314, 0, 600, 0, -1, 0, 224, 0, 600, 0, -1, 0, 354, 0, 600, 0, -1, 0, 262, 0, 600, 0, -1, 0, 227, 0, 600, 0, -1, 0, 278, 0, 600, 0, -1, 0, 353, 0, 600, 0, -1, 0, 351, 0, 600, 0, -1, 0, 237, 0, 600, 0, -1, 0, 9674, 0, 600, 0, -1, 0, 344, 0, 600, 0, -1, 0, 290, 0, 600, 0, -1, 0, 251, 0, 600, 0, -1, 0, 226, 0, 600, 0, -1, 0, 256, 0, 600, 0, -1, 0, 345, 0, 600, 0, -1, 0, 231, 0, 600, 0, -1, 0, 379, 0, 600, 0, -1, 0, 222, 0, 600, 0, -1, 0, 332, 0, 600, 0, -1, 0, 340, 0, 600, 0, -1, 0, 346, 0, 600, 0, -1, 0, 271, 0, 600, 0, -1, 0, 362, 0, 600, 0, -1, 0, 367, 0, 600, 0, -1, 0, 179, 0, 600, 0, -1, 0, 210, 0, 600, 0, -1, 0, 192, 0, 600, 0, -1, 0, 258, 0, 600, 0, -1, 0, 215, 0, 600, 0, -1, 0, 250, 0, 600, 0, -1, 0, 356, 0, 600, 0, -1, 0, 8706, 0, 600, 0, -1, 0, 255, 0, 600, 0, -1, 0, 323, 0, 600, 0, -1, 0, 238, 0, 600, 0, -1, 0, 202, 0, 600, 0, -1, 0, 228, 0, 600, 0, -1, 0, 235, 0, 600, 0, -1, 0, 263, 0, 600, 0, -1, 0, 324, 0, 600, 0, -1, 0, 363, 0, 600, 0, -1, 0, 327, 0, 600, 0, -1, 0, 205, 0, 600, 0, -1, 0, 177, 0, 600, 0, -1, 0, 166, 0, 600, 0, -1, 0, 174, 0, 600, 0, -1, 0, 286, 0, 600, 0, -1, 0, 304, 0, 600, 0, -1, 0, 8721, 0, 600, 0, -1, 0, 200, 0, 600, 0, -1, 0, 341, 0, 600, 0, -1, 0, 333, 0, 600, 0, -1, 0, 377, 0, 600, 0, -1, 0, 381, 0, 600, 0, -1, 0, 8805, 0, 600, 0, -1, 0, 208, 0, 600, 0, -1, 0, 199, 0, 600, 0, -1, 0, 316, 0, 600, 0, -1, 0, 357, 0, 600, 0, -1, 0, 281, 0, 600, 0, -1, 0, 370, 0, 600, 0, -1, 0, 193, 0, 600, 0, -1, 0, 196, 0, 600, 0, -1, 0, 232, 0, 600, 0, -1, 0, 378, 0, 600, 0, -1, 0, 303, 0, 600, 0, -1, 0, 211, 0, 600, 0, -1, 0, 243, 0, 600, 0, -1, 0, 257, 0, 600, 0, -1, 0, 347, 0, 600, 0, -1, 0, 239, 0, 600, 0, -1, 0, 212, 0, 600, 0, -1, 0, 217, 0, 600, 0, -1, 0, 916, 0, 600, 0, -1, 0, 254, 0, 600, 0, -1, 0, 178, 0, 600, 0, -1, 0, 214, 0, 600, 0, -1, 0, 181, 0, 600, 0, -1, 0, 236, 0, 600, 0, -1, 0, 337, 0, 600, 0, -1, 0, 280, 0, 600, 0, -1, 0, 273, 0, 600, 0, -1, 0, 190, 0, 600, 0, -1, 0, 350, 0, 600, 0, -1, 0, 318, 0, 600, 0, -1, 0, 310, 0, 600, 0, -1, 0, 313, 0, 600, 0, -1, 0, 8482, 0, 600, 0, -1, 0, 279, 0, 600, 0, -1, 0, 204, 0, 600, 0, -1, 0, 298, 0, 600, 0, -1, 0, 317, 0, 600, 0, -1, 0, 189, 0, 600, 0, -1, 0, 8804, 0, 600, 0, -1, 0, 244, 0, 600, 0, -1, 0, 241, 0, 600, 0, -1, 0, 368, 0, 600, 0, -1, 0, 201, 0, 600, 0, -1, 0, 275, 0, 600, 0, -1, 0, 287, 0, 600, 0, -1, 0, 188, 0, 600, 0, -1, 0, 352, 0, 600, 0, -1, 0, 536, 0, 600, 0, -1, 0, 336, 0, 600, 0, -1, 0, 176, 0, 600, 0, -1, 0, 242, 0, 600, 0, -1, 0, 268, 0, 600, 0, -1, 0, 249, 0, 600, 0, -1, 0, 8730, 0, 600, 0, -1, 0, 270, 0, 600, 0, -1, 0, 343, 0, 600, 0, -1, 0, 209, 0, 600, 0, -1, 0, 245, 0, 600, 0, -1, 0, 342, 0, 600, 0, -1, 0, 315, 0, 600, 0, -1, 0, 195, 0, 600, 0, -1, 0, 260, 0, 600, 0, -1, 0, 197, 0, 600, 0, -1, 0, 213, 0, 600, 0, -1, 0, 380, 0, 600, 0, -1, 0, 282, 0, 600, 0, -1, 0, 302, 0, 600, 0, -1, 0, 311, 0, 600, 0, -1, 0, 8722, 0, 600, 0, -1, 0, 206, 0, 600, 0, -1, 0, 328, 0, 600, 0, -1, 0, 355, 0, 600, 0, -1, 0, 172, 0, 600, 0, -1, 0, 246, 0, 600, 0, -1, 0, 252, 0, 600, 0, -1, 0, 8800, 0, 600, 0, -1, 0, 291, 0, 600, 0, -1, 0, 240, 0, 600, 0, -1, 0, 382, 0, 600, 0, -1, 0, 326, 0, 600, 0, -1, 0, 185, 0, 600, 0, -1, 0, 299, 0, 600, 0, -1, 0, 8364, 0, 600, 0, -1, 0, -1, 0, 0, 0], ["i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0], ALLOC_STATIC);
STRING_TABLE.__str41237=allocate([67,111,117,114,105,101,114,45,66,111,108,100,79,98,108,105,113,117,101,0] /* Courier-BoldOblique\ */, "i8", ALLOC_STATIC);
_CHAR_DATA_COURIER_BOLD_OBLIQUE=allocate([32, 0, 32, 0, 600, 0, 33, 0, 33, 0, 600, 0, 34, 0, 34, 0, 600, 0, 35, 0, 35, 0, 600, 0, 36, 0, 36, 0, 600, 0, 37, 0, 37, 0, 600, 0, 38, 0, 38, 0, 600, 0, 39, 0, 8217, 0, 600, 0, 40, 0, 40, 0, 600, 0, 41, 0, 41, 0, 600, 0, 42, 0, 42, 0, 600, 0, 43, 0, 43, 0, 600, 0, 44, 0, 44, 0, 600, 0, 45, 0, 45, 0, 600, 0, 46, 0, 46, 0, 600, 0, 47, 0, 47, 0, 600, 0, 48, 0, 48, 0, 600, 0, 49, 0, 49, 0, 600, 0, 50, 0, 50, 0, 600, 0, 51, 0, 51, 0, 600, 0, 52, 0, 52, 0, 600, 0, 53, 0, 53, 0, 600, 0, 54, 0, 54, 0, 600, 0, 55, 0, 55, 0, 600, 0, 56, 0, 56, 0, 600, 0, 57, 0, 57, 0, 600, 0, 58, 0, 58, 0, 600, 0, 59, 0, 59, 0, 600, 0, 60, 0, 60, 0, 600, 0, 61, 0, 61, 0, 600, 0, 62, 0, 62, 0, 600, 0, 63, 0, 63, 0, 600, 0, 64, 0, 64, 0, 600, 0, 65, 0, 65, 0, 600, 0, 66, 0, 66, 0, 600, 0, 67, 0, 67, 0, 600, 0, 68, 0, 68, 0, 600, 0, 69, 0, 69, 0, 600, 0, 70, 0, 70, 0, 600, 0, 71, 0, 71, 0, 600, 0, 72, 0, 72, 0, 600, 0, 73, 0, 73, 0, 600, 0, 74, 0, 74, 0, 600, 0, 75, 0, 75, 0, 600, 0, 76, 0, 76, 0, 600, 0, 77, 0, 77, 0, 600, 0, 78, 0, 78, 0, 600, 0, 79, 0, 79, 0, 600, 0, 80, 0, 80, 0, 600, 0, 81, 0, 81, 0, 600, 0, 82, 0, 82, 0, 600, 0, 83, 0, 83, 0, 600, 0, 84, 0, 84, 0, 600, 0, 85, 0, 85, 0, 600, 0, 86, 0, 86, 0, 600, 0, 87, 0, 87, 0, 600, 0, 88, 0, 88, 0, 600, 0, 89, 0, 89, 0, 600, 0, 90, 0, 90, 0, 600, 0, 91, 0, 91, 0, 600, 0, 92, 0, 92, 0, 600, 0, 93, 0, 93, 0, 600, 0, 94, 0, 94, 0, 600, 0, 95, 0, 95, 0, 600, 0, 96, 0, 8216, 0, 600, 0, 97, 0, 97, 0, 600, 0, 98, 0, 98, 0, 600, 0, 99, 0, 99, 0, 600, 0, 100, 0, 100, 0, 600, 0, 101, 0, 101, 0, 600, 0, 102, 0, 102, 0, 600, 0, 103, 0, 103, 0, 600, 0, 104, 0, 104, 0, 600, 0, 105, 0, 105, 0, 600, 0, 106, 0, 106, 0, 600, 0, 107, 0, 107, 0, 600, 0, 108, 0, 108, 0, 600, 0, 109, 0, 109, 0, 600, 0, 110, 0, 110, 0, 600, 0, 111, 0, 111, 0, 600, 0, 112, 0, 112, 0, 600, 0, 113, 0, 113, 0, 600, 0, 114, 0, 114, 0, 600, 0, 115, 0, 115, 0, 600, 0, 116, 0, 116, 0, 600, 0, 117, 0, 117, 0, 600, 0, 118, 0, 118, 0, 600, 0, 119, 0, 119, 0, 600, 0, 120, 0, 120, 0, 600, 0, 121, 0, 121, 0, 600, 0, 122, 0, 122, 0, 600, 0, 123, 0, 123, 0, 600, 0, 124, 0, 124, 0, 600, 0, 125, 0, 125, 0, 600, 0, 126, 0, 126, 0, 600, 0, 161, 0, 161, 0, 600, 0, 162, 0, 162, 0, 600, 0, 163, 0, 163, 0, 600, 0, 164, 0, 8260, 0, 600, 0, 165, 0, 165, 0, 600, 0, 166, 0, 402, 0, 600, 0, 167, 0, 167, 0, 600, 0, 168, 0, 164, 0, 600, 0, 169, 0, 39, 0, 600, 0, 170, 0, 8220, 0, 600, 0, 171, 0, 171, 0, 600, 0, 172, 0, 8249, 0, 600, 0, 173, 0, 8250, 0, 600, 0, 174, 0, -1279, 0, 600, 0, 175, 0, -1278, 0, 600, 0, 177, 0, 8211, 0, 600, 0, 178, 0, 8224, 0, 600, 0, 179, 0, 8225, 0, 600, 0, 180, 0, 183, 0, 600, 0, 182, 0, 182, 0, 600, 0, 183, 0, 8226, 0, 600, 0, 184, 0, 8218, 0, 600, 0, 185, 0, 8222, 0, 600, 0, 186, 0, 8221, 0, 600, 0, 187, 0, 187, 0, 600, 0, 188, 0, 8230, 0, 600, 0, 189, 0, 8240, 0, 600, 0, 191, 0, 191, 0, 600, 0, 193, 0, 96, 0, 600, 0, 194, 0, 180, 0, 600, 0, 195, 0, 710, 0, 600, 0, 196, 0, 732, 0, 600, 0, 197, 0, 175, 0, 600, 0, 198, 0, 728, 0, 600, 0, 199, 0, 729, 0, 600, 0, 200, 0, 168, 0, 600, 0, 202, 0, 730, 0, 600, 0, 203, 0, 184, 0, 600, 0, 205, 0, 733, 0, 600, 0, 206, 0, 731, 0, 600, 0, 207, 0, 711, 0, 600, 0, 208, 0, 8212, 0, 600, 0, 225, 0, 198, 0, 600, 0, 227, 0, 170, 0, 600, 0, 232, 0, 321, 0, 600, 0, 233, 0, 216, 0, 600, 0, 234, 0, 338, 0, 600, 0, 235, 0, 186, 0, 600, 0, 241, 0, 230, 0, 600, 0, 245, 0, 305, 0, 600, 0, 248, 0, 322, 0, 600, 0, 249, 0, 248, 0, 600, 0, 250, 0, 339, 0, 600, 0, 251, 0, 223, 0, 600, 0, -1, 0, 207, 0, 600, 0, -1, 0, 233, 0, 600, 0, -1, 0, 259, 0, 600, 0, -1, 0, 369, 0, 600, 0, -1, 0, 283, 0, 600, 0, -1, 0, 376, 0, 600, 0, -1, 0, 247, 0, 600, 0, -1, 0, 221, 0, 600, 0, -1, 0, 194, 0, 600, 0, -1, 0, 225, 0, 600, 0, -1, 0, 219, 0, 600, 0, -1, 0, 253, 0, 600, 0, -1, 0, 537, 0, 600, 0, -1, 0, 234, 0, 600, 0, -1, 0, 366, 0, 600, 0, -1, 0, 220, 0, 600, 0, -1, 0, 261, 0, 600, 0, -1, 0, 218, 0, 600, 0, -1, 0, 371, 0, 600, 0, -1, 0, 203, 0, 600, 0, -1, 0, 272, 0, 600, 0, -1, 0, -2365, 0, 600, 0, -1, 0, 169, 0, 600, 0, -1, 0, 274, 0, 600, 0, -1, 0, 269, 0, 600, 0, -1, 0, 229, 0, 600, 0, -1, 0, 325, 0, 600, 0, -1, 0, 314, 0, 600, 0, -1, 0, 224, 0, 600, 0, -1, 0, 354, 0, 600, 0, -1, 0, 262, 0, 600, 0, -1, 0, 227, 0, 600, 0, -1, 0, 278, 0, 600, 0, -1, 0, 353, 0, 600, 0, -1, 0, 351, 0, 600, 0, -1, 0, 237, 0, 600, 0, -1, 0, 9674, 0, 600, 0, -1, 0, 344, 0, 600, 0, -1, 0, 290, 0, 600, 0, -1, 0, 251, 0, 600, 0, -1, 0, 226, 0, 600, 0, -1, 0, 256, 0, 600, 0, -1, 0, 345, 0, 600, 0, -1, 0, 231, 0, 600, 0, -1, 0, 379, 0, 600, 0, -1, 0, 222, 0, 600, 0, -1, 0, 332, 0, 600, 0, -1, 0, 340, 0, 600, 0, -1, 0, 346, 0, 600, 0, -1, 0, 271, 0, 600, 0, -1, 0, 362, 0, 600, 0, -1, 0, 367, 0, 600, 0, -1, 0, 179, 0, 600, 0, -1, 0, 210, 0, 600, 0, -1, 0, 192, 0, 600, 0, -1, 0, 258, 0, 600, 0, -1, 0, 215, 0, 600, 0, -1, 0, 250, 0, 600, 0, -1, 0, 356, 0, 600, 0, -1, 0, 8706, 0, 600, 0, -1, 0, 255, 0, 600, 0, -1, 0, 323, 0, 600, 0, -1, 0, 238, 0, 600, 0, -1, 0, 202, 0, 600, 0, -1, 0, 228, 0, 600, 0, -1, 0, 235, 0, 600, 0, -1, 0, 263, 0, 600, 0, -1, 0, 324, 0, 600, 0, -1, 0, 363, 0, 600, 0, -1, 0, 327, 0, 600, 0, -1, 0, 205, 0, 600, 0, -1, 0, 177, 0, 600, 0, -1, 0, 166, 0, 600, 0, -1, 0, 174, 0, 600, 0, -1, 0, 286, 0, 600, 0, -1, 0, 304, 0, 600, 0, -1, 0, 8721, 0, 600, 0, -1, 0, 200, 0, 600, 0, -1, 0, 341, 0, 600, 0, -1, 0, 333, 0, 600, 0, -1, 0, 377, 0, 600, 0, -1, 0, 381, 0, 600, 0, -1, 0, 8805, 0, 600, 0, -1, 0, 208, 0, 600, 0, -1, 0, 199, 0, 600, 0, -1, 0, 316, 0, 600, 0, -1, 0, 357, 0, 600, 0, -1, 0, 281, 0, 600, 0, -1, 0, 370, 0, 600, 0, -1, 0, 193, 0, 600, 0, -1, 0, 196, 0, 600, 0, -1, 0, 232, 0, 600, 0, -1, 0, 378, 0, 600, 0, -1, 0, 303, 0, 600, 0, -1, 0, 211, 0, 600, 0, -1, 0, 243, 0, 600, 0, -1, 0, 257, 0, 600, 0, -1, 0, 347, 0, 600, 0, -1, 0, 239, 0, 600, 0, -1, 0, 212, 0, 600, 0, -1, 0, 217, 0, 600, 0, -1, 0, 916, 0, 600, 0, -1, 0, 254, 0, 600, 0, -1, 0, 178, 0, 600, 0, -1, 0, 214, 0, 600, 0, -1, 0, 181, 0, 600, 0, -1, 0, 236, 0, 600, 0, -1, 0, 337, 0, 600, 0, -1, 0, 280, 0, 600, 0, -1, 0, 273, 0, 600, 0, -1, 0, 190, 0, 600, 0, -1, 0, 350, 0, 600, 0, -1, 0, 318, 0, 600, 0, -1, 0, 310, 0, 600, 0, -1, 0, 313, 0, 600, 0, -1, 0, 8482, 0, 600, 0, -1, 0, 279, 0, 600, 0, -1, 0, 204, 0, 600, 0, -1, 0, 298, 0, 600, 0, -1, 0, 317, 0, 600, 0, -1, 0, 189, 0, 600, 0, -1, 0, 8804, 0, 600, 0, -1, 0, 244, 0, 600, 0, -1, 0, 241, 0, 600, 0, -1, 0, 368, 0, 600, 0, -1, 0, 201, 0, 600, 0, -1, 0, 275, 0, 600, 0, -1, 0, 287, 0, 600, 0, -1, 0, 188, 0, 600, 0, -1, 0, 352, 0, 600, 0, -1, 0, 536, 0, 600, 0, -1, 0, 336, 0, 600, 0, -1, 0, 176, 0, 600, 0, -1, 0, 242, 0, 600, 0, -1, 0, 268, 0, 600, 0, -1, 0, 249, 0, 600, 0, -1, 0, 8730, 0, 600, 0, -1, 0, 270, 0, 600, 0, -1, 0, 343, 0, 600, 0, -1, 0, 209, 0, 600, 0, -1, 0, 245, 0, 600, 0, -1, 0, 342, 0, 600, 0, -1, 0, 315, 0, 600, 0, -1, 0, 195, 0, 600, 0, -1, 0, 260, 0, 600, 0, -1, 0, 197, 0, 600, 0, -1, 0, 213, 0, 600, 0, -1, 0, 380, 0, 600, 0, -1, 0, 282, 0, 600, 0, -1, 0, 302, 0, 600, 0, -1, 0, 311, 0, 600, 0, -1, 0, 8722, 0, 600, 0, -1, 0, 206, 0, 600, 0, -1, 0, 328, 0, 600, 0, -1, 0, 355, 0, 600, 0, -1, 0, 172, 0, 600, 0, -1, 0, 246, 0, 600, 0, -1, 0, 252, 0, 600, 0, -1, 0, 8800, 0, 600, 0, -1, 0, 291, 0, 600, 0, -1, 0, 240, 0, 600, 0, -1, 0, 382, 0, 600, 0, -1, 0, 326, 0, 600, 0, -1, 0, 185, 0, 600, 0, -1, 0, 299, 0, 600, 0, -1, 0, 8364, 0, 600, 0, -1, 0, -1, 0, 0, 0], ["i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0], ALLOC_STATIC);
STRING_TABLE.__str51238=allocate([72,101,108,118,101,116,105,99,97,0] /* Helvetica\00 */, "i8", ALLOC_STATIC);
_CHAR_DATA_HELVETICA=allocate([32, 0, 32, 0, 278, 0, 33, 0, 33, 0, 278, 0, 34, 0, 34, 0, 355, 0, 35, 0, 35, 0, 556, 0, 36, 0, 36, 0, 556, 0, 37, 0, 37, 0, 889, 0, 38, 0, 38, 0, 667, 0, 39, 0, 8217, 0, 222, 0, 40, 0, 40, 0, 333, 0, 41, 0, 41, 0, 333, 0, 42, 0, 42, 0, 389, 0, 43, 0, 43, 0, 584, 0, 44, 0, 44, 0, 278, 0, 45, 0, 45, 0, 333, 0, 46, 0, 46, 0, 278, 0, 47, 0, 47, 0, 278, 0, 48, 0, 48, 0, 556, 0, 49, 0, 49, 0, 556, 0, 50, 0, 50, 0, 556, 0, 51, 0, 51, 0, 556, 0, 52, 0, 52, 0, 556, 0, 53, 0, 53, 0, 556, 0, 54, 0, 54, 0, 556, 0, 55, 0, 55, 0, 556, 0, 56, 0, 56, 0, 556, 0, 57, 0, 57, 0, 556, 0, 58, 0, 58, 0, 278, 0, 59, 0, 59, 0, 278, 0, 60, 0, 60, 0, 584, 0, 61, 0, 61, 0, 584, 0, 62, 0, 62, 0, 584, 0, 63, 0, 63, 0, 556, 0, 64, 0, 64, 0, 1015, 0, 65, 0, 65, 0, 667, 0, 66, 0, 66, 0, 667, 0, 67, 0, 67, 0, 722, 0, 68, 0, 68, 0, 722, 0, 69, 0, 69, 0, 667, 0, 70, 0, 70, 0, 611, 0, 71, 0, 71, 0, 778, 0, 72, 0, 72, 0, 722, 0, 73, 0, 73, 0, 278, 0, 74, 0, 74, 0, 500, 0, 75, 0, 75, 0, 667, 0, 76, 0, 76, 0, 556, 0, 77, 0, 77, 0, 833, 0, 78, 0, 78, 0, 722, 0, 79, 0, 79, 0, 778, 0, 80, 0, 80, 0, 667, 0, 81, 0, 81, 0, 778, 0, 82, 0, 82, 0, 722, 0, 83, 0, 83, 0, 667, 0, 84, 0, 84, 0, 611, 0, 85, 0, 85, 0, 722, 0, 86, 0, 86, 0, 667, 0, 87, 0, 87, 0, 944, 0, 88, 0, 88, 0, 667, 0, 89, 0, 89, 0, 667, 0, 90, 0, 90, 0, 611, 0, 91, 0, 91, 0, 278, 0, 92, 0, 92, 0, 278, 0, 93, 0, 93, 0, 278, 0, 94, 0, 94, 0, 469, 0, 95, 0, 95, 0, 556, 0, 96, 0, 8216, 0, 222, 0, 97, 0, 97, 0, 556, 0, 98, 0, 98, 0, 556, 0, 99, 0, 99, 0, 500, 0, 100, 0, 100, 0, 556, 0, 101, 0, 101, 0, 556, 0, 102, 0, 102, 0, 278, 0, 103, 0, 103, 0, 556, 0, 104, 0, 104, 0, 556, 0, 105, 0, 105, 0, 222, 0, 106, 0, 106, 0, 222, 0, 107, 0, 107, 0, 500, 0, 108, 0, 108, 0, 222, 0, 109, 0, 109, 0, 833, 0, 110, 0, 110, 0, 556, 0, 111, 0, 111, 0, 556, 0, 112, 0, 112, 0, 556, 0, 113, 0, 113, 0, 556, 0, 114, 0, 114, 0, 333, 0, 115, 0, 115, 0, 500, 0, 116, 0, 116, 0, 278, 0, 117, 0, 117, 0, 556, 0, 118, 0, 118, 0, 500, 0, 119, 0, 119, 0, 722, 0, 120, 0, 120, 0, 500, 0, 121, 0, 121, 0, 500, 0, 122, 0, 122, 0, 500, 0, 123, 0, 123, 0, 334, 0, 124, 0, 124, 0, 260, 0, 125, 0, 125, 0, 334, 0, 126, 0, 126, 0, 584, 0, 161, 0, 161, 0, 333, 0, 162, 0, 162, 0, 556, 0, 163, 0, 163, 0, 556, 0, 164, 0, 8260, 0, 167, 0, 165, 0, 165, 0, 556, 0, 166, 0, 402, 0, 556, 0, 167, 0, 167, 0, 556, 0, 168, 0, 164, 0, 556, 0, 169, 0, 39, 0, 191, 0, 170, 0, 8220, 0, 333, 0, 171, 0, 171, 0, 556, 0, 172, 0, 8249, 0, 333, 0, 173, 0, 8250, 0, 333, 0, 174, 0, -1279, 0, 500, 0, 175, 0, -1278, 0, 500, 0, 177, 0, 8211, 0, 556, 0, 178, 0, 8224, 0, 556, 0, 179, 0, 8225, 0, 556, 0, 180, 0, 183, 0, 278, 0, 182, 0, 182, 0, 537, 0, 183, 0, 8226, 0, 350, 0, 184, 0, 8218, 0, 222, 0, 185, 0, 8222, 0, 333, 0, 186, 0, 8221, 0, 333, 0, 187, 0, 187, 0, 556, 0, 188, 0, 8230, 0, 1000, 0, 189, 0, 8240, 0, 1000, 0, 191, 0, 191, 0, 611, 0, 193, 0, 96, 0, 333, 0, 194, 0, 180, 0, 333, 0, 195, 0, 710, 0, 333, 0, 196, 0, 732, 0, 333, 0, 197, 0, 175, 0, 333, 0, 198, 0, 728, 0, 333, 0, 199, 0, 729, 0, 333, 0, 200, 0, 168, 0, 333, 0, 202, 0, 730, 0, 333, 0, 203, 0, 184, 0, 333, 0, 205, 0, 733, 0, 333, 0, 206, 0, 731, 0, 333, 0, 207, 0, 711, 0, 333, 0, 208, 0, 8212, 0, 1000, 0, 225, 0, 198, 0, 1000, 0, 227, 0, 170, 0, 370, 0, 232, 0, 321, 0, 556, 0, 233, 0, 216, 0, 778, 0, 234, 0, 338, 0, 1000, 0, 235, 0, 186, 0, 365, 0, 241, 0, 230, 0, 889, 0, 245, 0, 305, 0, 278, 0, 248, 0, 322, 0, 222, 0, 249, 0, 248, 0, 611, 0, 250, 0, 339, 0, 944, 0, 251, 0, 223, 0, 611, 0, -1, 0, 207, 0, 278, 0, -1, 0, 233, 0, 556, 0, -1, 0, 259, 0, 556, 0, -1, 0, 369, 0, 556, 0, -1, 0, 283, 0, 556, 0, -1, 0, 376, 0, 667, 0, -1, 0, 247, 0, 584, 0, -1, 0, 221, 0, 667, 0, -1, 0, 194, 0, 667, 0, -1, 0, 225, 0, 556, 0, -1, 0, 219, 0, 722, 0, -1, 0, 253, 0, 500, 0, -1, 0, 537, 0, 500, 0, -1, 0, 234, 0, 556, 0, -1, 0, 366, 0, 722, 0, -1, 0, 220, 0, 722, 0, -1, 0, 261, 0, 556, 0, -1, 0, 218, 0, 722, 0, -1, 0, 371, 0, 556, 0, -1, 0, 203, 0, 667, 0, -1, 0, 272, 0, 722, 0, -1, 0, -2365, 0, 250, 0, -1, 0, 169, 0, 737, 0, -1, 0, 274, 0, 667, 0, -1, 0, 269, 0, 500, 0, -1, 0, 229, 0, 556, 0, -1, 0, 325, 0, 722, 0, -1, 0, 314, 0, 222, 0, -1, 0, 224, 0, 556, 0, -1, 0, 354, 0, 611, 0, -1, 0, 262, 0, 722, 0, -1, 0, 227, 0, 556, 0, -1, 0, 278, 0, 667, 0, -1, 0, 353, 0, 500, 0, -1, 0, 351, 0, 500, 0, -1, 0, 237, 0, 278, 0, -1, 0, 9674, 0, 471, 0, -1, 0, 344, 0, 722, 0, -1, 0, 290, 0, 778, 0, -1, 0, 251, 0, 556, 0, -1, 0, 226, 0, 556, 0, -1, 0, 256, 0, 667, 0, -1, 0, 345, 0, 333, 0, -1, 0, 231, 0, 500, 0, -1, 0, 379, 0, 611, 0, -1, 0, 222, 0, 667, 0, -1, 0, 332, 0, 778, 0, -1, 0, 340, 0, 722, 0, -1, 0, 346, 0, 667, 0, -1, 0, 271, 0, 643, 0, -1, 0, 362, 0, 722, 0, -1, 0, 367, 0, 556, 0, -1, 0, 179, 0, 333, 0, -1, 0, 210, 0, 778, 0, -1, 0, 192, 0, 667, 0, -1, 0, 258, 0, 667, 0, -1, 0, 215, 0, 584, 0, -1, 0, 250, 0, 556, 0, -1, 0, 356, 0, 611, 0, -1, 0, 8706, 0, 476, 0, -1, 0, 255, 0, 500, 0, -1, 0, 323, 0, 722, 0, -1, 0, 238, 0, 278, 0, -1, 0, 202, 0, 667, 0, -1, 0, 228, 0, 556, 0, -1, 0, 235, 0, 556, 0, -1, 0, 263, 0, 500, 0, -1, 0, 324, 0, 556, 0, -1, 0, 363, 0, 556, 0, -1, 0, 327, 0, 722, 0, -1, 0, 205, 0, 278, 0, -1, 0, 177, 0, 584, 0, -1, 0, 166, 0, 260, 0, -1, 0, 174, 0, 737, 0, -1, 0, 286, 0, 778, 0, -1, 0, 304, 0, 278, 0, -1, 0, 8721, 0, 600, 0, -1, 0, 200, 0, 667, 0, -1, 0, 341, 0, 333, 0, -1, 0, 333, 0, 556, 0, -1, 0, 377, 0, 611, 0, -1, 0, 381, 0, 611, 0, -1, 0, 8805, 0, 549, 0, -1, 0, 208, 0, 722, 0, -1, 0, 199, 0, 722, 0, -1, 0, 316, 0, 222, 0, -1, 0, 357, 0, 316, 0, -1, 0, 281, 0, 556, 0, -1, 0, 370, 0, 722, 0, -1, 0, 193, 0, 667, 0, -1, 0, 196, 0, 667, 0, -1, 0, 232, 0, 556, 0, -1, 0, 378, 0, 500, 0, -1, 0, 303, 0, 222, 0, -1, 0, 211, 0, 778, 0, -1, 0, 243, 0, 556, 0, -1, 0, 257, 0, 556, 0, -1, 0, 347, 0, 500, 0, -1, 0, 239, 0, 278, 0, -1, 0, 212, 0, 778, 0, -1, 0, 217, 0, 722, 0, -1, 0, 916, 0, 612, 0, -1, 0, 254, 0, 556, 0, -1, 0, 178, 0, 333, 0, -1, 0, 214, 0, 778, 0, -1, 0, 181, 0, 556, 0, -1, 0, 236, 0, 278, 0, -1, 0, 337, 0, 556, 0, -1, 0, 280, 0, 667, 0, -1, 0, 273, 0, 556, 0, -1, 0, 190, 0, 834, 0, -1, 0, 350, 0, 667, 0, -1, 0, 318, 0, 299, 0, -1, 0, 310, 0, 667, 0, -1, 0, 313, 0, 556, 0, -1, 0, 8482, 0, 1000, 0, -1, 0, 279, 0, 556, 0, -1, 0, 204, 0, 278, 0, -1, 0, 298, 0, 278, 0, -1, 0, 317, 0, 556, 0, -1, 0, 189, 0, 834, 0, -1, 0, 8804, 0, 549, 0, -1, 0, 244, 0, 556, 0, -1, 0, 241, 0, 556, 0, -1, 0, 368, 0, 722, 0, -1, 0, 201, 0, 667, 0, -1, 0, 275, 0, 556, 0, -1, 0, 287, 0, 556, 0, -1, 0, 188, 0, 834, 0, -1, 0, 352, 0, 667, 0, -1, 0, 536, 0, 667, 0, -1, 0, 336, 0, 778, 0, -1, 0, 176, 0, 400, 0, -1, 0, 242, 0, 556, 0, -1, 0, 268, 0, 722, 0, -1, 0, 249, 0, 556, 0, -1, 0, 8730, 0, 453, 0, -1, 0, 270, 0, 722, 0, -1, 0, 343, 0, 333, 0, -1, 0, 209, 0, 722, 0, -1, 0, 245, 0, 556, 0, -1, 0, 342, 0, 722, 0, -1, 0, 315, 0, 556, 0, -1, 0, 195, 0, 667, 0, -1, 0, 260, 0, 667, 0, -1, 0, 197, 0, 667, 0, -1, 0, 213, 0, 778, 0, -1, 0, 380, 0, 500, 0, -1, 0, 282, 0, 667, 0, -1, 0, 302, 0, 278, 0, -1, 0, 311, 0, 500, 0, -1, 0, 8722, 0, 584, 0, -1, 0, 206, 0, 278, 0, -1, 0, 328, 0, 556, 0, -1, 0, 355, 0, 278, 0, -1, 0, 172, 0, 584, 0, -1, 0, 246, 0, 556, 0, -1, 0, 252, 0, 556, 0, -1, 0, 8800, 0, 549, 0, -1, 0, 291, 0, 556, 0, -1, 0, 240, 0, 556, 0, -1, 0, 382, 0, 500, 0, -1, 0, 326, 0, 556, 0, -1, 0, 185, 0, 333, 0, -1, 0, 299, 0, 278, 0, -1, 0, 8364, 0, 556, 0, -1, 0, -1, 0, 0, 0], ["i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0], ALLOC_STATIC);
STRING_TABLE.__str61239=allocate([72,101,108,118,101,116,105,99,97,45,66,111,108,100,0] /* Helvetica-Bold\00 */, "i8", ALLOC_STATIC);
_CHAR_DATA_HELVETICA_BOLD=allocate([32, 0, 32, 0, 278, 0, 33, 0, 33, 0, 333, 0, 34, 0, 34, 0, 474, 0, 35, 0, 35, 0, 556, 0, 36, 0, 36, 0, 556, 0, 37, 0, 37, 0, 889, 0, 38, 0, 38, 0, 722, 0, 39, 0, 8217, 0, 278, 0, 40, 0, 40, 0, 333, 0, 41, 0, 41, 0, 333, 0, 42, 0, 42, 0, 389, 0, 43, 0, 43, 0, 584, 0, 44, 0, 44, 0, 278, 0, 45, 0, 45, 0, 333, 0, 46, 0, 46, 0, 278, 0, 47, 0, 47, 0, 278, 0, 48, 0, 48, 0, 556, 0, 49, 0, 49, 0, 556, 0, 50, 0, 50, 0, 556, 0, 51, 0, 51, 0, 556, 0, 52, 0, 52, 0, 556, 0, 53, 0, 53, 0, 556, 0, 54, 0, 54, 0, 556, 0, 55, 0, 55, 0, 556, 0, 56, 0, 56, 0, 556, 0, 57, 0, 57, 0, 556, 0, 58, 0, 58, 0, 333, 0, 59, 0, 59, 0, 333, 0, 60, 0, 60, 0, 584, 0, 61, 0, 61, 0, 584, 0, 62, 0, 62, 0, 584, 0, 63, 0, 63, 0, 611, 0, 64, 0, 64, 0, 975, 0, 65, 0, 65, 0, 722, 0, 66, 0, 66, 0, 722, 0, 67, 0, 67, 0, 722, 0, 68, 0, 68, 0, 722, 0, 69, 0, 69, 0, 667, 0, 70, 0, 70, 0, 611, 0, 71, 0, 71, 0, 778, 0, 72, 0, 72, 0, 722, 0, 73, 0, 73, 0, 278, 0, 74, 0, 74, 0, 556, 0, 75, 0, 75, 0, 722, 0, 76, 0, 76, 0, 611, 0, 77, 0, 77, 0, 833, 0, 78, 0, 78, 0, 722, 0, 79, 0, 79, 0, 778, 0, 80, 0, 80, 0, 667, 0, 81, 0, 81, 0, 778, 0, 82, 0, 82, 0, 722, 0, 83, 0, 83, 0, 667, 0, 84, 0, 84, 0, 611, 0, 85, 0, 85, 0, 722, 0, 86, 0, 86, 0, 667, 0, 87, 0, 87, 0, 944, 0, 88, 0, 88, 0, 667, 0, 89, 0, 89, 0, 667, 0, 90, 0, 90, 0, 611, 0, 91, 0, 91, 0, 333, 0, 92, 0, 92, 0, 278, 0, 93, 0, 93, 0, 333, 0, 94, 0, 94, 0, 584, 0, 95, 0, 95, 0, 556, 0, 96, 0, 8216, 0, 278, 0, 97, 0, 97, 0, 556, 0, 98, 0, 98, 0, 611, 0, 99, 0, 99, 0, 556, 0, 100, 0, 100, 0, 611, 0, 101, 0, 101, 0, 556, 0, 102, 0, 102, 0, 333, 0, 103, 0, 103, 0, 611, 0, 104, 0, 104, 0, 611, 0, 105, 0, 105, 0, 278, 0, 106, 0, 106, 0, 278, 0, 107, 0, 107, 0, 556, 0, 108, 0, 108, 0, 278, 0, 109, 0, 109, 0, 889, 0, 110, 0, 110, 0, 611, 0, 111, 0, 111, 0, 611, 0, 112, 0, 112, 0, 611, 0, 113, 0, 113, 0, 611, 0, 114, 0, 114, 0, 389, 0, 115, 0, 115, 0, 556, 0, 116, 0, 116, 0, 333, 0, 117, 0, 117, 0, 611, 0, 118, 0, 118, 0, 556, 0, 119, 0, 119, 0, 778, 0, 120, 0, 120, 0, 556, 0, 121, 0, 121, 0, 556, 0, 122, 0, 122, 0, 500, 0, 123, 0, 123, 0, 389, 0, 124, 0, 124, 0, 280, 0, 125, 0, 125, 0, 389, 0, 126, 0, 126, 0, 584, 0, 161, 0, 161, 0, 333, 0, 162, 0, 162, 0, 556, 0, 163, 0, 163, 0, 556, 0, 164, 0, 8260, 0, 167, 0, 165, 0, 165, 0, 556, 0, 166, 0, 402, 0, 556, 0, 167, 0, 167, 0, 556, 0, 168, 0, 164, 0, 556, 0, 169, 0, 39, 0, 238, 0, 170, 0, 8220, 0, 500, 0, 171, 0, 171, 0, 556, 0, 172, 0, 8249, 0, 333, 0, 173, 0, 8250, 0, 333, 0, 174, 0, -1279, 0, 611, 0, 175, 0, -1278, 0, 611, 0, 177, 0, 8211, 0, 556, 0, 178, 0, 8224, 0, 556, 0, 179, 0, 8225, 0, 556, 0, 180, 0, 183, 0, 278, 0, 182, 0, 182, 0, 556, 0, 183, 0, 8226, 0, 350, 0, 184, 0, 8218, 0, 278, 0, 185, 0, 8222, 0, 500, 0, 186, 0, 8221, 0, 500, 0, 187, 0, 187, 0, 556, 0, 188, 0, 8230, 0, 1000, 0, 189, 0, 8240, 0, 1000, 0, 191, 0, 191, 0, 611, 0, 193, 0, 96, 0, 333, 0, 194, 0, 180, 0, 333, 0, 195, 0, 710, 0, 333, 0, 196, 0, 732, 0, 333, 0, 197, 0, 175, 0, 333, 0, 198, 0, 728, 0, 333, 0, 199, 0, 729, 0, 333, 0, 200, 0, 168, 0, 333, 0, 202, 0, 730, 0, 333, 0, 203, 0, 184, 0, 333, 0, 205, 0, 733, 0, 333, 0, 206, 0, 731, 0, 333, 0, 207, 0, 711, 0, 333, 0, 208, 0, 8212, 0, 1000, 0, 225, 0, 198, 0, 1000, 0, 227, 0, 170, 0, 370, 0, 232, 0, 321, 0, 611, 0, 233, 0, 216, 0, 778, 0, 234, 0, 338, 0, 1000, 0, 235, 0, 186, 0, 365, 0, 241, 0, 230, 0, 889, 0, 245, 0, 305, 0, 278, 0, 248, 0, 322, 0, 278, 0, 249, 0, 248, 0, 611, 0, 250, 0, 339, 0, 944, 0, 251, 0, 223, 0, 611, 0, -1, 0, 207, 0, 278, 0, -1, 0, 233, 0, 556, 0, -1, 0, 259, 0, 556, 0, -1, 0, 369, 0, 611, 0, -1, 0, 283, 0, 556, 0, -1, 0, 376, 0, 667, 0, -1, 0, 247, 0, 584, 0, -1, 0, 221, 0, 667, 0, -1, 0, 194, 0, 722, 0, -1, 0, 225, 0, 556, 0, -1, 0, 219, 0, 722, 0, -1, 0, 253, 0, 556, 0, -1, 0, 537, 0, 556, 0, -1, 0, 234, 0, 556, 0, -1, 0, 366, 0, 722, 0, -1, 0, 220, 0, 722, 0, -1, 0, 261, 0, 556, 0, -1, 0, 218, 0, 722, 0, -1, 0, 371, 0, 611, 0, -1, 0, 203, 0, 667, 0, -1, 0, 272, 0, 722, 0, -1, 0, -2365, 0, 250, 0, -1, 0, 169, 0, 737, 0, -1, 0, 274, 0, 667, 0, -1, 0, 269, 0, 556, 0, -1, 0, 229, 0, 556, 0, -1, 0, 325, 0, 722, 0, -1, 0, 314, 0, 278, 0, -1, 0, 224, 0, 556, 0, -1, 0, 354, 0, 611, 0, -1, 0, 262, 0, 722, 0, -1, 0, 227, 0, 556, 0, -1, 0, 278, 0, 667, 0, -1, 0, 353, 0, 556, 0, -1, 0, 351, 0, 556, 0, -1, 0, 237, 0, 278, 0, -1, 0, 9674, 0, 494, 0, -1, 0, 344, 0, 722, 0, -1, 0, 290, 0, 778, 0, -1, 0, 251, 0, 611, 0, -1, 0, 226, 0, 556, 0, -1, 0, 256, 0, 722, 0, -1, 0, 345, 0, 389, 0, -1, 0, 231, 0, 556, 0, -1, 0, 379, 0, 611, 0, -1, 0, 222, 0, 667, 0, -1, 0, 332, 0, 778, 0, -1, 0, 340, 0, 722, 0, -1, 0, 346, 0, 667, 0, -1, 0, 271, 0, 743, 0, -1, 0, 362, 0, 722, 0, -1, 0, 367, 0, 611, 0, -1, 0, 179, 0, 333, 0, -1, 0, 210, 0, 778, 0, -1, 0, 192, 0, 722, 0, -1, 0, 258, 0, 722, 0, -1, 0, 215, 0, 584, 0, -1, 0, 250, 0, 611, 0, -1, 0, 356, 0, 611, 0, -1, 0, 8706, 0, 494, 0, -1, 0, 255, 0, 556, 0, -1, 0, 323, 0, 722, 0, -1, 0, 238, 0, 278, 0, -1, 0, 202, 0, 667, 0, -1, 0, 228, 0, 556, 0, -1, 0, 235, 0, 556, 0, -1, 0, 263, 0, 556, 0, -1, 0, 324, 0, 611, 0, -1, 0, 363, 0, 611, 0, -1, 0, 327, 0, 722, 0, -1, 0, 205, 0, 278, 0, -1, 0, 177, 0, 584, 0, -1, 0, 166, 0, 280, 0, -1, 0, 174, 0, 737, 0, -1, 0, 286, 0, 778, 0, -1, 0, 304, 0, 278, 0, -1, 0, 8721, 0, 600, 0, -1, 0, 200, 0, 667, 0, -1, 0, 341, 0, 389, 0, -1, 0, 333, 0, 611, 0, -1, 0, 377, 0, 611, 0, -1, 0, 381, 0, 611, 0, -1, 0, 8805, 0, 549, 0, -1, 0, 208, 0, 722, 0, -1, 0, 199, 0, 722, 0, -1, 0, 316, 0, 278, 0, -1, 0, 357, 0, 389, 0, -1, 0, 281, 0, 556, 0, -1, 0, 370, 0, 722, 0, -1, 0, 193, 0, 722, 0, -1, 0, 196, 0, 722, 0, -1, 0, 232, 0, 556, 0, -1, 0, 378, 0, 500, 0, -1, 0, 303, 0, 278, 0, -1, 0, 211, 0, 778, 0, -1, 0, 243, 0, 611, 0, -1, 0, 257, 0, 556, 0, -1, 0, 347, 0, 556, 0, -1, 0, 239, 0, 278, 0, -1, 0, 212, 0, 778, 0, -1, 0, 217, 0, 722, 0, -1, 0, 916, 0, 612, 0, -1, 0, 254, 0, 611, 0, -1, 0, 178, 0, 333, 0, -1, 0, 214, 0, 778, 0, -1, 0, 181, 0, 611, 0, -1, 0, 236, 0, 278, 0, -1, 0, 337, 0, 611, 0, -1, 0, 280, 0, 667, 0, -1, 0, 273, 0, 611, 0, -1, 0, 190, 0, 834, 0, -1, 0, 350, 0, 667, 0, -1, 0, 318, 0, 400, 0, -1, 0, 310, 0, 722, 0, -1, 0, 313, 0, 611, 0, -1, 0, 8482, 0, 1000, 0, -1, 0, 279, 0, 556, 0, -1, 0, 204, 0, 278, 0, -1, 0, 298, 0, 278, 0, -1, 0, 317, 0, 611, 0, -1, 0, 189, 0, 834, 0, -1, 0, 8804, 0, 549, 0, -1, 0, 244, 0, 611, 0, -1, 0, 241, 0, 611, 0, -1, 0, 368, 0, 722, 0, -1, 0, 201, 0, 667, 0, -1, 0, 275, 0, 556, 0, -1, 0, 287, 0, 611, 0, -1, 0, 188, 0, 834, 0, -1, 0, 352, 0, 667, 0, -1, 0, 536, 0, 667, 0, -1, 0, 336, 0, 778, 0, -1, 0, 176, 0, 400, 0, -1, 0, 242, 0, 611, 0, -1, 0, 268, 0, 722, 0, -1, 0, 249, 0, 611, 0, -1, 0, 8730, 0, 549, 0, -1, 0, 270, 0, 722, 0, -1, 0, 343, 0, 389, 0, -1, 0, 209, 0, 722, 0, -1, 0, 245, 0, 611, 0, -1, 0, 342, 0, 722, 0, -1, 0, 315, 0, 611, 0, -1, 0, 195, 0, 722, 0, -1, 0, 260, 0, 722, 0, -1, 0, 197, 0, 722, 0, -1, 0, 213, 0, 778, 0, -1, 0, 380, 0, 500, 0, -1, 0, 282, 0, 667, 0, -1, 0, 302, 0, 278, 0, -1, 0, 311, 0, 556, 0, -1, 0, 8722, 0, 584, 0, -1, 0, 206, 0, 278, 0, -1, 0, 328, 0, 611, 0, -1, 0, 355, 0, 333, 0, -1, 0, 172, 0, 584, 0, -1, 0, 246, 0, 611, 0, -1, 0, 252, 0, 611, 0, -1, 0, 8800, 0, 549, 0, -1, 0, 291, 0, 611, 0, -1, 0, 240, 0, 611, 0, -1, 0, 382, 0, 500, 0, -1, 0, 326, 0, 611, 0, -1, 0, 185, 0, 333, 0, -1, 0, 299, 0, 278, 0, -1, 0, 8364, 0, 556, 0, -1, 0, -1, 0, 0, 0], ["i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0], ALLOC_STATIC);
STRING_TABLE.__str71240=allocate([72,101,108,118,101,116,105,99,97,45,79,98,108,105,113,117,101,0] /* Helvetica-Oblique\00 */, "i8", ALLOC_STATIC);
_CHAR_DATA_HELVETICA_OBLIQUE=allocate([32, 0, 32, 0, 278, 0, 33, 0, 33, 0, 278, 0, 34, 0, 34, 0, 355, 0, 35, 0, 35, 0, 556, 0, 36, 0, 36, 0, 556, 0, 37, 0, 37, 0, 889, 0, 38, 0, 38, 0, 667, 0, 39, 0, 8217, 0, 222, 0, 40, 0, 40, 0, 333, 0, 41, 0, 41, 0, 333, 0, 42, 0, 42, 0, 389, 0, 43, 0, 43, 0, 584, 0, 44, 0, 44, 0, 278, 0, 45, 0, 45, 0, 333, 0, 46, 0, 46, 0, 278, 0, 47, 0, 47, 0, 278, 0, 48, 0, 48, 0, 556, 0, 49, 0, 49, 0, 556, 0, 50, 0, 50, 0, 556, 0, 51, 0, 51, 0, 556, 0, 52, 0, 52, 0, 556, 0, 53, 0, 53, 0, 556, 0, 54, 0, 54, 0, 556, 0, 55, 0, 55, 0, 556, 0, 56, 0, 56, 0, 556, 0, 57, 0, 57, 0, 556, 0, 58, 0, 58, 0, 278, 0, 59, 0, 59, 0, 278, 0, 60, 0, 60, 0, 584, 0, 61, 0, 61, 0, 584, 0, 62, 0, 62, 0, 584, 0, 63, 0, 63, 0, 556, 0, 64, 0, 64, 0, 1015, 0, 65, 0, 65, 0, 667, 0, 66, 0, 66, 0, 667, 0, 67, 0, 67, 0, 722, 0, 68, 0, 68, 0, 722, 0, 69, 0, 69, 0, 667, 0, 70, 0, 70, 0, 611, 0, 71, 0, 71, 0, 778, 0, 72, 0, 72, 0, 722, 0, 73, 0, 73, 0, 278, 0, 74, 0, 74, 0, 500, 0, 75, 0, 75, 0, 667, 0, 76, 0, 76, 0, 556, 0, 77, 0, 77, 0, 833, 0, 78, 0, 78, 0, 722, 0, 79, 0, 79, 0, 778, 0, 80, 0, 80, 0, 667, 0, 81, 0, 81, 0, 778, 0, 82, 0, 82, 0, 722, 0, 83, 0, 83, 0, 667, 0, 84, 0, 84, 0, 611, 0, 85, 0, 85, 0, 722, 0, 86, 0, 86, 0, 667, 0, 87, 0, 87, 0, 944, 0, 88, 0, 88, 0, 667, 0, 89, 0, 89, 0, 667, 0, 90, 0, 90, 0, 611, 0, 91, 0, 91, 0, 278, 0, 92, 0, 92, 0, 278, 0, 93, 0, 93, 0, 278, 0, 94, 0, 94, 0, 469, 0, 95, 0, 95, 0, 556, 0, 96, 0, 8216, 0, 222, 0, 97, 0, 97, 0, 556, 0, 98, 0, 98, 0, 556, 0, 99, 0, 99, 0, 500, 0, 100, 0, 100, 0, 556, 0, 101, 0, 101, 0, 556, 0, 102, 0, 102, 0, 278, 0, 103, 0, 103, 0, 556, 0, 104, 0, 104, 0, 556, 0, 105, 0, 105, 0, 222, 0, 106, 0, 106, 0, 222, 0, 107, 0, 107, 0, 500, 0, 108, 0, 108, 0, 222, 0, 109, 0, 109, 0, 833, 0, 110, 0, 110, 0, 556, 0, 111, 0, 111, 0, 556, 0, 112, 0, 112, 0, 556, 0, 113, 0, 113, 0, 556, 0, 114, 0, 114, 0, 333, 0, 115, 0, 115, 0, 500, 0, 116, 0, 116, 0, 278, 0, 117, 0, 117, 0, 556, 0, 118, 0, 118, 0, 500, 0, 119, 0, 119, 0, 722, 0, 120, 0, 120, 0, 500, 0, 121, 0, 121, 0, 500, 0, 122, 0, 122, 0, 500, 0, 123, 0, 123, 0, 334, 0, 124, 0, 124, 0, 260, 0, 125, 0, 125, 0, 334, 0, 126, 0, 126, 0, 584, 0, 161, 0, 161, 0, 333, 0, 162, 0, 162, 0, 556, 0, 163, 0, 163, 0, 556, 0, 164, 0, 8260, 0, 167, 0, 165, 0, 165, 0, 556, 0, 166, 0, 402, 0, 556, 0, 167, 0, 167, 0, 556, 0, 168, 0, 164, 0, 556, 0, 169, 0, 39, 0, 191, 0, 170, 0, 8220, 0, 333, 0, 171, 0, 171, 0, 556, 0, 172, 0, 8249, 0, 333, 0, 173, 0, 8250, 0, 333, 0, 174, 0, -1279, 0, 500, 0, 175, 0, -1278, 0, 500, 0, 177, 0, 8211, 0, 556, 0, 178, 0, 8224, 0, 556, 0, 179, 0, 8225, 0, 556, 0, 180, 0, 183, 0, 278, 0, 182, 0, 182, 0, 537, 0, 183, 0, 8226, 0, 350, 0, 184, 0, 8218, 0, 222, 0, 185, 0, 8222, 0, 333, 0, 186, 0, 8221, 0, 333, 0, 187, 0, 187, 0, 556, 0, 188, 0, 8230, 0, 1000, 0, 189, 0, 8240, 0, 1000, 0, 191, 0, 191, 0, 611, 0, 193, 0, 96, 0, 333, 0, 194, 0, 180, 0, 333, 0, 195, 0, 710, 0, 333, 0, 196, 0, 732, 0, 333, 0, 197, 0, 175, 0, 333, 0, 198, 0, 728, 0, 333, 0, 199, 0, 729, 0, 333, 0, 200, 0, 168, 0, 333, 0, 202, 0, 730, 0, 333, 0, 203, 0, 184, 0, 333, 0, 205, 0, 733, 0, 333, 0, 206, 0, 731, 0, 333, 0, 207, 0, 711, 0, 333, 0, 208, 0, 8212, 0, 1000, 0, 225, 0, 198, 0, 1000, 0, 227, 0, 170, 0, 370, 0, 232, 0, 321, 0, 556, 0, 233, 0, 216, 0, 778, 0, 234, 0, 338, 0, 1000, 0, 235, 0, 186, 0, 365, 0, 241, 0, 230, 0, 889, 0, 245, 0, 305, 0, 278, 0, 248, 0, 322, 0, 222, 0, 249, 0, 248, 0, 611, 0, 250, 0, 339, 0, 944, 0, 251, 0, 223, 0, 611, 0, -1, 0, 207, 0, 278, 0, -1, 0, 233, 0, 556, 0, -1, 0, 259, 0, 556, 0, -1, 0, 369, 0, 556, 0, -1, 0, 283, 0, 556, 0, -1, 0, 376, 0, 667, 0, -1, 0, 247, 0, 584, 0, -1, 0, 221, 0, 667, 0, -1, 0, 194, 0, 667, 0, -1, 0, 225, 0, 556, 0, -1, 0, 219, 0, 722, 0, -1, 0, 253, 0, 500, 0, -1, 0, 537, 0, 500, 0, -1, 0, 234, 0, 556, 0, -1, 0, 366, 0, 722, 0, -1, 0, 220, 0, 722, 0, -1, 0, 261, 0, 556, 0, -1, 0, 218, 0, 722, 0, -1, 0, 371, 0, 556, 0, -1, 0, 203, 0, 667, 0, -1, 0, 272, 0, 722, 0, -1, 0, -2365, 0, 250, 0, -1, 0, 169, 0, 737, 0, -1, 0, 274, 0, 667, 0, -1, 0, 269, 0, 500, 0, -1, 0, 229, 0, 556, 0, -1, 0, 325, 0, 722, 0, -1, 0, 314, 0, 222, 0, -1, 0, 224, 0, 556, 0, -1, 0, 354, 0, 611, 0, -1, 0, 262, 0, 722, 0, -1, 0, 227, 0, 556, 0, -1, 0, 278, 0, 667, 0, -1, 0, 353, 0, 500, 0, -1, 0, 351, 0, 500, 0, -1, 0, 237, 0, 278, 0, -1, 0, 9674, 0, 471, 0, -1, 0, 344, 0, 722, 0, -1, 0, 290, 0, 778, 0, -1, 0, 251, 0, 556, 0, -1, 0, 226, 0, 556, 0, -1, 0, 256, 0, 667, 0, -1, 0, 345, 0, 333, 0, -1, 0, 231, 0, 500, 0, -1, 0, 379, 0, 611, 0, -1, 0, 222, 0, 667, 0, -1, 0, 332, 0, 778, 0, -1, 0, 340, 0, 722, 0, -1, 0, 346, 0, 667, 0, -1, 0, 271, 0, 643, 0, -1, 0, 362, 0, 722, 0, -1, 0, 367, 0, 556, 0, -1, 0, 179, 0, 333, 0, -1, 0, 210, 0, 778, 0, -1, 0, 192, 0, 667, 0, -1, 0, 258, 0, 667, 0, -1, 0, 215, 0, 584, 0, -1, 0, 250, 0, 556, 0, -1, 0, 356, 0, 611, 0, -1, 0, 8706, 0, 476, 0, -1, 0, 255, 0, 500, 0, -1, 0, 323, 0, 722, 0, -1, 0, 238, 0, 278, 0, -1, 0, 202, 0, 667, 0, -1, 0, 228, 0, 556, 0, -1, 0, 235, 0, 556, 0, -1, 0, 263, 0, 500, 0, -1, 0, 324, 0, 556, 0, -1, 0, 363, 0, 556, 0, -1, 0, 327, 0, 722, 0, -1, 0, 205, 0, 278, 0, -1, 0, 177, 0, 584, 0, -1, 0, 166, 0, 260, 0, -1, 0, 174, 0, 737, 0, -1, 0, 286, 0, 778, 0, -1, 0, 304, 0, 278, 0, -1, 0, 8721, 0, 600, 0, -1, 0, 200, 0, 667, 0, -1, 0, 341, 0, 333, 0, -1, 0, 333, 0, 556, 0, -1, 0, 377, 0, 611, 0, -1, 0, 381, 0, 611, 0, -1, 0, 8805, 0, 549, 0, -1, 0, 208, 0, 722, 0, -1, 0, 199, 0, 722, 0, -1, 0, 316, 0, 222, 0, -1, 0, 357, 0, 316, 0, -1, 0, 281, 0, 556, 0, -1, 0, 370, 0, 722, 0, -1, 0, 193, 0, 667, 0, -1, 0, 196, 0, 667, 0, -1, 0, 232, 0, 556, 0, -1, 0, 378, 0, 500, 0, -1, 0, 303, 0, 222, 0, -1, 0, 211, 0, 778, 0, -1, 0, 243, 0, 556, 0, -1, 0, 257, 0, 556, 0, -1, 0, 347, 0, 500, 0, -1, 0, 239, 0, 278, 0, -1, 0, 212, 0, 778, 0, -1, 0, 217, 0, 722, 0, -1, 0, 916, 0, 612, 0, -1, 0, 254, 0, 556, 0, -1, 0, 178, 0, 333, 0, -1, 0, 214, 0, 778, 0, -1, 0, 181, 0, 556, 0, -1, 0, 236, 0, 278, 0, -1, 0, 337, 0, 556, 0, -1, 0, 280, 0, 667, 0, -1, 0, 273, 0, 556, 0, -1, 0, 190, 0, 834, 0, -1, 0, 350, 0, 667, 0, -1, 0, 318, 0, 299, 0, -1, 0, 310, 0, 667, 0, -1, 0, 313, 0, 556, 0, -1, 0, 8482, 0, 1000, 0, -1, 0, 279, 0, 556, 0, -1, 0, 204, 0, 278, 0, -1, 0, 298, 0, 278, 0, -1, 0, 317, 0, 556, 0, -1, 0, 189, 0, 834, 0, -1, 0, 8804, 0, 549, 0, -1, 0, 244, 0, 556, 0, -1, 0, 241, 0, 556, 0, -1, 0, 368, 0, 722, 0, -1, 0, 201, 0, 667, 0, -1, 0, 275, 0, 556, 0, -1, 0, 287, 0, 556, 0, -1, 0, 188, 0, 834, 0, -1, 0, 352, 0, 667, 0, -1, 0, 536, 0, 667, 0, -1, 0, 336, 0, 778, 0, -1, 0, 176, 0, 400, 0, -1, 0, 242, 0, 556, 0, -1, 0, 268, 0, 722, 0, -1, 0, 249, 0, 556, 0, -1, 0, 8730, 0, 453, 0, -1, 0, 270, 0, 722, 0, -1, 0, 343, 0, 333, 0, -1, 0, 209, 0, 722, 0, -1, 0, 245, 0, 556, 0, -1, 0, 342, 0, 722, 0, -1, 0, 315, 0, 556, 0, -1, 0, 195, 0, 667, 0, -1, 0, 260, 0, 667, 0, -1, 0, 197, 0, 667, 0, -1, 0, 213, 0, 778, 0, -1, 0, 380, 0, 500, 0, -1, 0, 282, 0, 667, 0, -1, 0, 302, 0, 278, 0, -1, 0, 311, 0, 500, 0, -1, 0, 8722, 0, 584, 0, -1, 0, 206, 0, 278, 0, -1, 0, 328, 0, 556, 0, -1, 0, 355, 0, 278, 0, -1, 0, 172, 0, 584, 0, -1, 0, 246, 0, 556, 0, -1, 0, 252, 0, 556, 0, -1, 0, 8800, 0, 549, 0, -1, 0, 291, 0, 556, 0, -1, 0, 240, 0, 556, 0, -1, 0, 382, 0, 500, 0, -1, 0, 326, 0, 556, 0, -1, 0, 185, 0, 333, 0, -1, 0, 299, 0, 278, 0, -1, 0, 8364, 0, 556, 0, -1, 0, -1, 0, 0, 0], ["i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0], ALLOC_STATIC);
STRING_TABLE.__str81241=allocate([72,101,108,118,101,116,105,99,97,45,66,111,108,100,79,98,108,105,113,117,101,0] /* Helvetica-BoldObliqu */, "i8", ALLOC_STATIC);
_CHAR_DATA_HELVETICA_BOLD_OBLIQUE=allocate([32, 0, 32, 0, 278, 0, 33, 0, 33, 0, 333, 0, 34, 0, 34, 0, 474, 0, 35, 0, 35, 0, 556, 0, 36, 0, 36, 0, 556, 0, 37, 0, 37, 0, 889, 0, 38, 0, 38, 0, 722, 0, 39, 0, 8217, 0, 278, 0, 40, 0, 40, 0, 333, 0, 41, 0, 41, 0, 333, 0, 42, 0, 42, 0, 389, 0, 43, 0, 43, 0, 584, 0, 44, 0, 44, 0, 278, 0, 45, 0, 45, 0, 333, 0, 46, 0, 46, 0, 278, 0, 47, 0, 47, 0, 278, 0, 48, 0, 48, 0, 556, 0, 49, 0, 49, 0, 556, 0, 50, 0, 50, 0, 556, 0, 51, 0, 51, 0, 556, 0, 52, 0, 52, 0, 556, 0, 53, 0, 53, 0, 556, 0, 54, 0, 54, 0, 556, 0, 55, 0, 55, 0, 556, 0, 56, 0, 56, 0, 556, 0, 57, 0, 57, 0, 556, 0, 58, 0, 58, 0, 333, 0, 59, 0, 59, 0, 333, 0, 60, 0, 60, 0, 584, 0, 61, 0, 61, 0, 584, 0, 62, 0, 62, 0, 584, 0, 63, 0, 63, 0, 611, 0, 64, 0, 64, 0, 975, 0, 65, 0, 65, 0, 722, 0, 66, 0, 66, 0, 722, 0, 67, 0, 67, 0, 722, 0, 68, 0, 68, 0, 722, 0, 69, 0, 69, 0, 667, 0, 70, 0, 70, 0, 611, 0, 71, 0, 71, 0, 778, 0, 72, 0, 72, 0, 722, 0, 73, 0, 73, 0, 278, 0, 74, 0, 74, 0, 556, 0, 75, 0, 75, 0, 722, 0, 76, 0, 76, 0, 611, 0, 77, 0, 77, 0, 833, 0, 78, 0, 78, 0, 722, 0, 79, 0, 79, 0, 778, 0, 80, 0, 80, 0, 667, 0, 81, 0, 81, 0, 778, 0, 82, 0, 82, 0, 722, 0, 83, 0, 83, 0, 667, 0, 84, 0, 84, 0, 611, 0, 85, 0, 85, 0, 722, 0, 86, 0, 86, 0, 667, 0, 87, 0, 87, 0, 944, 0, 88, 0, 88, 0, 667, 0, 89, 0, 89, 0, 667, 0, 90, 0, 90, 0, 611, 0, 91, 0, 91, 0, 333, 0, 92, 0, 92, 0, 278, 0, 93, 0, 93, 0, 333, 0, 94, 0, 94, 0, 584, 0, 95, 0, 95, 0, 556, 0, 96, 0, 8216, 0, 278, 0, 97, 0, 97, 0, 556, 0, 98, 0, 98, 0, 611, 0, 99, 0, 99, 0, 556, 0, 100, 0, 100, 0, 611, 0, 101, 0, 101, 0, 556, 0, 102, 0, 102, 0, 333, 0, 103, 0, 103, 0, 611, 0, 104, 0, 104, 0, 611, 0, 105, 0, 105, 0, 278, 0, 106, 0, 106, 0, 278, 0, 107, 0, 107, 0, 556, 0, 108, 0, 108, 0, 278, 0, 109, 0, 109, 0, 889, 0, 110, 0, 110, 0, 611, 0, 111, 0, 111, 0, 611, 0, 112, 0, 112, 0, 611, 0, 113, 0, 113, 0, 611, 0, 114, 0, 114, 0, 389, 0, 115, 0, 115, 0, 556, 0, 116, 0, 116, 0, 333, 0, 117, 0, 117, 0, 611, 0, 118, 0, 118, 0, 556, 0, 119, 0, 119, 0, 778, 0, 120, 0, 120, 0, 556, 0, 121, 0, 121, 0, 556, 0, 122, 0, 122, 0, 500, 0, 123, 0, 123, 0, 389, 0, 124, 0, 124, 0, 280, 0, 125, 0, 125, 0, 389, 0, 126, 0, 126, 0, 584, 0, 161, 0, 161, 0, 333, 0, 162, 0, 162, 0, 556, 0, 163, 0, 163, 0, 556, 0, 164, 0, 8260, 0, 167, 0, 165, 0, 165, 0, 556, 0, 166, 0, 402, 0, 556, 0, 167, 0, 167, 0, 556, 0, 168, 0, 164, 0, 556, 0, 169, 0, 39, 0, 238, 0, 170, 0, 8220, 0, 500, 0, 171, 0, 171, 0, 556, 0, 172, 0, 8249, 0, 333, 0, 173, 0, 8250, 0, 333, 0, 174, 0, -1279, 0, 611, 0, 175, 0, -1278, 0, 611, 0, 177, 0, 8211, 0, 556, 0, 178, 0, 8224, 0, 556, 0, 179, 0, 8225, 0, 556, 0, 180, 0, 183, 0, 278, 0, 182, 0, 182, 0, 556, 0, 183, 0, 8226, 0, 350, 0, 184, 0, 8218, 0, 278, 0, 185, 0, 8222, 0, 500, 0, 186, 0, 8221, 0, 500, 0, 187, 0, 187, 0, 556, 0, 188, 0, 8230, 0, 1000, 0, 189, 0, 8240, 0, 1000, 0, 191, 0, 191, 0, 611, 0, 193, 0, 96, 0, 333, 0, 194, 0, 180, 0, 333, 0, 195, 0, 710, 0, 333, 0, 196, 0, 732, 0, 333, 0, 197, 0, 175, 0, 333, 0, 198, 0, 728, 0, 333, 0, 199, 0, 729, 0, 333, 0, 200, 0, 168, 0, 333, 0, 202, 0, 730, 0, 333, 0, 203, 0, 184, 0, 333, 0, 205, 0, 733, 0, 333, 0, 206, 0, 731, 0, 333, 0, 207, 0, 711, 0, 333, 0, 208, 0, 8212, 0, 1000, 0, 225, 0, 198, 0, 1000, 0, 227, 0, 170, 0, 370, 0, 232, 0, 321, 0, 611, 0, 233, 0, 216, 0, 778, 0, 234, 0, 338, 0, 1000, 0, 235, 0, 186, 0, 365, 0, 241, 0, 230, 0, 889, 0, 245, 0, 305, 0, 278, 0, 248, 0, 322, 0, 278, 0, 249, 0, 248, 0, 611, 0, 250, 0, 339, 0, 944, 0, 251, 0, 223, 0, 611, 0, -1, 0, 207, 0, 278, 0, -1, 0, 233, 0, 556, 0, -1, 0, 259, 0, 556, 0, -1, 0, 369, 0, 611, 0, -1, 0, 283, 0, 556, 0, -1, 0, 376, 0, 667, 0, -1, 0, 247, 0, 584, 0, -1, 0, 221, 0, 667, 0, -1, 0, 194, 0, 722, 0, -1, 0, 225, 0, 556, 0, -1, 0, 219, 0, 722, 0, -1, 0, 253, 0, 556, 0, -1, 0, 537, 0, 556, 0, -1, 0, 234, 0, 556, 0, -1, 0, 366, 0, 722, 0, -1, 0, 220, 0, 722, 0, -1, 0, 261, 0, 556, 0, -1, 0, 218, 0, 722, 0, -1, 0, 371, 0, 611, 0, -1, 0, 203, 0, 667, 0, -1, 0, 272, 0, 722, 0, -1, 0, -2365, 0, 250, 0, -1, 0, 169, 0, 737, 0, -1, 0, 274, 0, 667, 0, -1, 0, 269, 0, 556, 0, -1, 0, 229, 0, 556, 0, -1, 0, 325, 0, 722, 0, -1, 0, 314, 0, 278, 0, -1, 0, 224, 0, 556, 0, -1, 0, 354, 0, 611, 0, -1, 0, 262, 0, 722, 0, -1, 0, 227, 0, 556, 0, -1, 0, 278, 0, 667, 0, -1, 0, 353, 0, 556, 0, -1, 0, 351, 0, 556, 0, -1, 0, 237, 0, 278, 0, -1, 0, 9674, 0, 494, 0, -1, 0, 344, 0, 722, 0, -1, 0, 290, 0, 778, 0, -1, 0, 251, 0, 611, 0, -1, 0, 226, 0, 556, 0, -1, 0, 256, 0, 722, 0, -1, 0, 345, 0, 389, 0, -1, 0, 231, 0, 556, 0, -1, 0, 379, 0, 611, 0, -1, 0, 222, 0, 667, 0, -1, 0, 332, 0, 778, 0, -1, 0, 340, 0, 722, 0, -1, 0, 346, 0, 667, 0, -1, 0, 271, 0, 743, 0, -1, 0, 362, 0, 722, 0, -1, 0, 367, 0, 611, 0, -1, 0, 179, 0, 333, 0, -1, 0, 210, 0, 778, 0, -1, 0, 192, 0, 722, 0, -1, 0, 258, 0, 722, 0, -1, 0, 215, 0, 584, 0, -1, 0, 250, 0, 611, 0, -1, 0, 356, 0, 611, 0, -1, 0, 8706, 0, 494, 0, -1, 0, 255, 0, 556, 0, -1, 0, 323, 0, 722, 0, -1, 0, 238, 0, 278, 0, -1, 0, 202, 0, 667, 0, -1, 0, 228, 0, 556, 0, -1, 0, 235, 0, 556, 0, -1, 0, 263, 0, 556, 0, -1, 0, 324, 0, 611, 0, -1, 0, 363, 0, 611, 0, -1, 0, 327, 0, 722, 0, -1, 0, 205, 0, 278, 0, -1, 0, 177, 0, 584, 0, -1, 0, 166, 0, 280, 0, -1, 0, 174, 0, 737, 0, -1, 0, 286, 0, 778, 0, -1, 0, 304, 0, 278, 0, -1, 0, 8721, 0, 600, 0, -1, 0, 200, 0, 667, 0, -1, 0, 341, 0, 389, 0, -1, 0, 333, 0, 611, 0, -1, 0, 377, 0, 611, 0, -1, 0, 381, 0, 611, 0, -1, 0, 8805, 0, 549, 0, -1, 0, 208, 0, 722, 0, -1, 0, 199, 0, 722, 0, -1, 0, 316, 0, 278, 0, -1, 0, 357, 0, 389, 0, -1, 0, 281, 0, 556, 0, -1, 0, 370, 0, 722, 0, -1, 0, 193, 0, 722, 0, -1, 0, 196, 0, 722, 0, -1, 0, 232, 0, 556, 0, -1, 0, 378, 0, 500, 0, -1, 0, 303, 0, 278, 0, -1, 0, 211, 0, 778, 0, -1, 0, 243, 0, 611, 0, -1, 0, 257, 0, 556, 0, -1, 0, 347, 0, 556, 0, -1, 0, 239, 0, 278, 0, -1, 0, 212, 0, 778, 0, -1, 0, 217, 0, 722, 0, -1, 0, 916, 0, 612, 0, -1, 0, 254, 0, 611, 0, -1, 0, 178, 0, 333, 0, -1, 0, 214, 0, 778, 0, -1, 0, 181, 0, 611, 0, -1, 0, 236, 0, 278, 0, -1, 0, 337, 0, 611, 0, -1, 0, 280, 0, 667, 0, -1, 0, 273, 0, 611, 0, -1, 0, 190, 0, 834, 0, -1, 0, 350, 0, 667, 0, -1, 0, 318, 0, 400, 0, -1, 0, 310, 0, 722, 0, -1, 0, 313, 0, 611, 0, -1, 0, 8482, 0, 1000, 0, -1, 0, 279, 0, 556, 0, -1, 0, 204, 0, 278, 0, -1, 0, 298, 0, 278, 0, -1, 0, 317, 0, 611, 0, -1, 0, 189, 0, 834, 0, -1, 0, 8804, 0, 549, 0, -1, 0, 244, 0, 611, 0, -1, 0, 241, 0, 611, 0, -1, 0, 368, 0, 722, 0, -1, 0, 201, 0, 667, 0, -1, 0, 275, 0, 556, 0, -1, 0, 287, 0, 611, 0, -1, 0, 188, 0, 834, 0, -1, 0, 352, 0, 667, 0, -1, 0, 536, 0, 667, 0, -1, 0, 336, 0, 778, 0, -1, 0, 176, 0, 400, 0, -1, 0, 242, 0, 611, 0, -1, 0, 268, 0, 722, 0, -1, 0, 249, 0, 611, 0, -1, 0, 8730, 0, 549, 0, -1, 0, 270, 0, 722, 0, -1, 0, 343, 0, 389, 0, -1, 0, 209, 0, 722, 0, -1, 0, 245, 0, 611, 0, -1, 0, 342, 0, 722, 0, -1, 0, 315, 0, 611, 0, -1, 0, 195, 0, 722, 0, -1, 0, 260, 0, 722, 0, -1, 0, 197, 0, 722, 0, -1, 0, 213, 0, 778, 0, -1, 0, 380, 0, 500, 0, -1, 0, 282, 0, 667, 0, -1, 0, 302, 0, 278, 0, -1, 0, 311, 0, 556, 0, -1, 0, 8722, 0, 584, 0, -1, 0, 206, 0, 278, 0, -1, 0, 328, 0, 611, 0, -1, 0, 355, 0, 333, 0, -1, 0, 172, 0, 584, 0, -1, 0, 246, 0, 611, 0, -1, 0, 252, 0, 611, 0, -1, 0, 8800, 0, 549, 0, -1, 0, 291, 0, 611, 0, -1, 0, 240, 0, 611, 0, -1, 0, 382, 0, 500, 0, -1, 0, 326, 0, 611, 0, -1, 0, 185, 0, 333, 0, -1, 0, 299, 0, 278, 0, -1, 0, 8364, 0, 556, 0, -1, 0, -1, 0, 0, 0], ["i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0], ALLOC_STATIC);
STRING_TABLE.__str91242=allocate([84,105,109,101,115,45,82,111,109,97,110,0] /* Times-Roman\00 */, "i8", ALLOC_STATIC);
_CHAR_DATA_TIMES_ROMAN=allocate([32, 0, 32, 0, 250, 0, 33, 0, 33, 0, 333, 0, 34, 0, 34, 0, 408, 0, 35, 0, 35, 0, 500, 0, 36, 0, 36, 0, 500, 0, 37, 0, 37, 0, 833, 0, 38, 0, 38, 0, 778, 0, 39, 0, 8217, 0, 333, 0, 40, 0, 40, 0, 333, 0, 41, 0, 41, 0, 333, 0, 42, 0, 42, 0, 500, 0, 43, 0, 43, 0, 564, 0, 44, 0, 44, 0, 250, 0, 45, 0, 45, 0, 333, 0, 46, 0, 46, 0, 250, 0, 47, 0, 47, 0, 278, 0, 48, 0, 48, 0, 500, 0, 49, 0, 49, 0, 500, 0, 50, 0, 50, 0, 500, 0, 51, 0, 51, 0, 500, 0, 52, 0, 52, 0, 500, 0, 53, 0, 53, 0, 500, 0, 54, 0, 54, 0, 500, 0, 55, 0, 55, 0, 500, 0, 56, 0, 56, 0, 500, 0, 57, 0, 57, 0, 500, 0, 58, 0, 58, 0, 278, 0, 59, 0, 59, 0, 278, 0, 60, 0, 60, 0, 564, 0, 61, 0, 61, 0, 564, 0, 62, 0, 62, 0, 564, 0, 63, 0, 63, 0, 444, 0, 64, 0, 64, 0, 921, 0, 65, 0, 65, 0, 722, 0, 66, 0, 66, 0, 667, 0, 67, 0, 67, 0, 667, 0, 68, 0, 68, 0, 722, 0, 69, 0, 69, 0, 611, 0, 70, 0, 70, 0, 556, 0, 71, 0, 71, 0, 722, 0, 72, 0, 72, 0, 722, 0, 73, 0, 73, 0, 333, 0, 74, 0, 74, 0, 389, 0, 75, 0, 75, 0, 722, 0, 76, 0, 76, 0, 611, 0, 77, 0, 77, 0, 889, 0, 78, 0, 78, 0, 722, 0, 79, 0, 79, 0, 722, 0, 80, 0, 80, 0, 556, 0, 81, 0, 81, 0, 722, 0, 82, 0, 82, 0, 667, 0, 83, 0, 83, 0, 556, 0, 84, 0, 84, 0, 611, 0, 85, 0, 85, 0, 722, 0, 86, 0, 86, 0, 722, 0, 87, 0, 87, 0, 944, 0, 88, 0, 88, 0, 722, 0, 89, 0, 89, 0, 722, 0, 90, 0, 90, 0, 611, 0, 91, 0, 91, 0, 333, 0, 92, 0, 92, 0, 278, 0, 93, 0, 93, 0, 333, 0, 94, 0, 94, 0, 469, 0, 95, 0, 95, 0, 500, 0, 96, 0, 8216, 0, 333, 0, 97, 0, 97, 0, 444, 0, 98, 0, 98, 0, 500, 0, 99, 0, 99, 0, 444, 0, 100, 0, 100, 0, 500, 0, 101, 0, 101, 0, 444, 0, 102, 0, 102, 0, 333, 0, 103, 0, 103, 0, 500, 0, 104, 0, 104, 0, 500, 0, 105, 0, 105, 0, 278, 0, 106, 0, 106, 0, 278, 0, 107, 0, 107, 0, 500, 0, 108, 0, 108, 0, 278, 0, 109, 0, 109, 0, 778, 0, 110, 0, 110, 0, 500, 0, 111, 0, 111, 0, 500, 0, 112, 0, 112, 0, 500, 0, 113, 0, 113, 0, 500, 0, 114, 0, 114, 0, 333, 0, 115, 0, 115, 0, 389, 0, 116, 0, 116, 0, 278, 0, 117, 0, 117, 0, 500, 0, 118, 0, 118, 0, 500, 0, 119, 0, 119, 0, 722, 0, 120, 0, 120, 0, 500, 0, 121, 0, 121, 0, 500, 0, 122, 0, 122, 0, 444, 0, 123, 0, 123, 0, 480, 0, 124, 0, 124, 0, 200, 0, 125, 0, 125, 0, 480, 0, 126, 0, 126, 0, 541, 0, 161, 0, 161, 0, 333, 0, 162, 0, 162, 0, 500, 0, 163, 0, 163, 0, 500, 0, 164, 0, 8260, 0, 167, 0, 165, 0, 165, 0, 500, 0, 166, 0, 402, 0, 500, 0, 167, 0, 167, 0, 500, 0, 168, 0, 164, 0, 500, 0, 169, 0, 39, 0, 180, 0, 170, 0, 8220, 0, 444, 0, 171, 0, 171, 0, 500, 0, 172, 0, 8249, 0, 333, 0, 173, 0, 8250, 0, 333, 0, 174, 0, -1279, 0, 556, 0, 175, 0, -1278, 0, 556, 0, 177, 0, 8211, 0, 500, 0, 178, 0, 8224, 0, 500, 0, 179, 0, 8225, 0, 500, 0, 180, 0, 183, 0, 250, 0, 182, 0, 182, 0, 453, 0, 183, 0, 8226, 0, 350, 0, 184, 0, 8218, 0, 333, 0, 185, 0, 8222, 0, 444, 0, 186, 0, 8221, 0, 444, 0, 187, 0, 187, 0, 500, 0, 188, 0, 8230, 0, 1000, 0, 189, 0, 8240, 0, 1000, 0, 191, 0, 191, 0, 444, 0, 193, 0, 96, 0, 333, 0, 194, 0, 180, 0, 333, 0, 195, 0, 710, 0, 333, 0, 196, 0, 732, 0, 333, 0, 197, 0, 175, 0, 333, 0, 198, 0, 728, 0, 333, 0, 199, 0, 729, 0, 333, 0, 200, 0, 168, 0, 333, 0, 202, 0, 730, 0, 333, 0, 203, 0, 184, 0, 333, 0, 205, 0, 733, 0, 333, 0, 206, 0, 731, 0, 333, 0, 207, 0, 711, 0, 333, 0, 208, 0, 8212, 0, 1000, 0, 225, 0, 198, 0, 889, 0, 227, 0, 170, 0, 276, 0, 232, 0, 321, 0, 611, 0, 233, 0, 216, 0, 722, 0, 234, 0, 338, 0, 889, 0, 235, 0, 186, 0, 310, 0, 241, 0, 230, 0, 667, 0, 245, 0, 305, 0, 278, 0, 248, 0, 322, 0, 278, 0, 249, 0, 248, 0, 500, 0, 250, 0, 339, 0, 722, 0, 251, 0, 223, 0, 500, 0, -1, 0, 207, 0, 333, 0, -1, 0, 233, 0, 444, 0, -1, 0, 259, 0, 444, 0, -1, 0, 369, 0, 500, 0, -1, 0, 283, 0, 444, 0, -1, 0, 376, 0, 722, 0, -1, 0, 247, 0, 564, 0, -1, 0, 221, 0, 722, 0, -1, 0, 194, 0, 722, 0, -1, 0, 225, 0, 444, 0, -1, 0, 219, 0, 722, 0, -1, 0, 253, 0, 500, 0, -1, 0, 537, 0, 389, 0, -1, 0, 234, 0, 444, 0, -1, 0, 366, 0, 722, 0, -1, 0, 220, 0, 722, 0, -1, 0, 261, 0, 444, 0, -1, 0, 218, 0, 722, 0, -1, 0, 371, 0, 500, 0, -1, 0, 203, 0, 611, 0, -1, 0, 272, 0, 722, 0, -1, 0, -2365, 0, 250, 0, -1, 0, 169, 0, 760, 0, -1, 0, 274, 0, 611, 0, -1, 0, 269, 0, 444, 0, -1, 0, 229, 0, 444, 0, -1, 0, 325, 0, 722, 0, -1, 0, 314, 0, 278, 0, -1, 0, 224, 0, 444, 0, -1, 0, 354, 0, 611, 0, -1, 0, 262, 0, 667, 0, -1, 0, 227, 0, 444, 0, -1, 0, 278, 0, 611, 0, -1, 0, 353, 0, 389, 0, -1, 0, 351, 0, 389, 0, -1, 0, 237, 0, 278, 0, -1, 0, 9674, 0, 471, 0, -1, 0, 344, 0, 667, 0, -1, 0, 290, 0, 722, 0, -1, 0, 251, 0, 500, 0, -1, 0, 226, 0, 444, 0, -1, 0, 256, 0, 722, 0, -1, 0, 345, 0, 333, 0, -1, 0, 231, 0, 444, 0, -1, 0, 379, 0, 611, 0, -1, 0, 222, 0, 556, 0, -1, 0, 332, 0, 722, 0, -1, 0, 340, 0, 667, 0, -1, 0, 346, 0, 556, 0, -1, 0, 271, 0, 588, 0, -1, 0, 362, 0, 722, 0, -1, 0, 367, 0, 500, 0, -1, 0, 179, 0, 300, 0, -1, 0, 210, 0, 722, 0, -1, 0, 192, 0, 722, 0, -1, 0, 258, 0, 722, 0, -1, 0, 215, 0, 564, 0, -1, 0, 250, 0, 500, 0, -1, 0, 356, 0, 611, 0, -1, 0, 8706, 0, 476, 0, -1, 0, 255, 0, 500, 0, -1, 0, 323, 0, 722, 0, -1, 0, 238, 0, 278, 0, -1, 0, 202, 0, 611, 0, -1, 0, 228, 0, 444, 0, -1, 0, 235, 0, 444, 0, -1, 0, 263, 0, 444, 0, -1, 0, 324, 0, 500, 0, -1, 0, 363, 0, 500, 0, -1, 0, 327, 0, 722, 0, -1, 0, 205, 0, 333, 0, -1, 0, 177, 0, 564, 0, -1, 0, 166, 0, 200, 0, -1, 0, 174, 0, 760, 0, -1, 0, 286, 0, 722, 0, -1, 0, 304, 0, 333, 0, -1, 0, 8721, 0, 600, 0, -1, 0, 200, 0, 611, 0, -1, 0, 341, 0, 333, 0, -1, 0, 333, 0, 500, 0, -1, 0, 377, 0, 611, 0, -1, 0, 381, 0, 611, 0, -1, 0, 8805, 0, 549, 0, -1, 0, 208, 0, 722, 0, -1, 0, 199, 0, 667, 0, -1, 0, 316, 0, 278, 0, -1, 0, 357, 0, 326, 0, -1, 0, 281, 0, 444, 0, -1, 0, 370, 0, 722, 0, -1, 0, 193, 0, 722, 0, -1, 0, 196, 0, 722, 0, -1, 0, 232, 0, 444, 0, -1, 0, 378, 0, 444, 0, -1, 0, 303, 0, 278, 0, -1, 0, 211, 0, 722, 0, -1, 0, 243, 0, 500, 0, -1, 0, 257, 0, 444, 0, -1, 0, 347, 0, 389, 0, -1, 0, 239, 0, 278, 0, -1, 0, 212, 0, 722, 0, -1, 0, 217, 0, 722, 0, -1, 0, 916, 0, 612, 0, -1, 0, 254, 0, 500, 0, -1, 0, 178, 0, 300, 0, -1, 0, 214, 0, 722, 0, -1, 0, 181, 0, 500, 0, -1, 0, 236, 0, 278, 0, -1, 0, 337, 0, 500, 0, -1, 0, 280, 0, 611, 0, -1, 0, 273, 0, 500, 0, -1, 0, 190, 0, 750, 0, -1, 0, 350, 0, 556, 0, -1, 0, 318, 0, 344, 0, -1, 0, 310, 0, 722, 0, -1, 0, 313, 0, 611, 0, -1, 0, 8482, 0, 980, 0, -1, 0, 279, 0, 444, 0, -1, 0, 204, 0, 333, 0, -1, 0, 298, 0, 333, 0, -1, 0, 317, 0, 611, 0, -1, 0, 189, 0, 750, 0, -1, 0, 8804, 0, 549, 0, -1, 0, 244, 0, 500, 0, -1, 0, 241, 0, 500, 0, -1, 0, 368, 0, 722, 0, -1, 0, 201, 0, 611, 0, -1, 0, 275, 0, 444, 0, -1, 0, 287, 0, 500, 0, -1, 0, 188, 0, 750, 0, -1, 0, 352, 0, 556, 0, -1, 0, 536, 0, 556, 0, -1, 0, 336, 0, 722, 0, -1, 0, 176, 0, 400, 0, -1, 0, 242, 0, 500, 0, -1, 0, 268, 0, 667, 0, -1, 0, 249, 0, 500, 0, -1, 0, 8730, 0, 453, 0, -1, 0, 270, 0, 722, 0, -1, 0, 343, 0, 333, 0, -1, 0, 209, 0, 722, 0, -1, 0, 245, 0, 500, 0, -1, 0, 342, 0, 667, 0, -1, 0, 315, 0, 611, 0, -1, 0, 195, 0, 722, 0, -1, 0, 260, 0, 722, 0, -1, 0, 197, 0, 722, 0, -1, 0, 213, 0, 722, 0, -1, 0, 380, 0, 444, 0, -1, 0, 282, 0, 611, 0, -1, 0, 302, 0, 333, 0, -1, 0, 311, 0, 500, 0, -1, 0, 8722, 0, 564, 0, -1, 0, 206, 0, 333, 0, -1, 0, 328, 0, 500, 0, -1, 0, 355, 0, 278, 0, -1, 0, 172, 0, 564, 0, -1, 0, 246, 0, 500, 0, -1, 0, 252, 0, 500, 0, -1, 0, 8800, 0, 549, 0, -1, 0, 291, 0, 500, 0, -1, 0, 240, 0, 500, 0, -1, 0, 382, 0, 444, 0, -1, 0, 326, 0, 500, 0, -1, 0, 185, 0, 300, 0, -1, 0, 299, 0, 278, 0, -1, 0, 8364, 0, 500, 0, -1, 0, -1, 0, 0, 0], ["i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0], ALLOC_STATIC);
STRING_TABLE.__str101243=allocate([84,105,109,101,115,45,66,111,108,100,0] /* Times-Bold\00 */, "i8", ALLOC_STATIC);
_CHAR_DATA_TIMES_BOLD=allocate([32, 0, 32, 0, 250, 0, 33, 0, 33, 0, 333, 0, 34, 0, 34, 0, 555, 0, 35, 0, 35, 0, 500, 0, 36, 0, 36, 0, 500, 0, 37, 0, 37, 0, 1000, 0, 38, 0, 38, 0, 833, 0, 39, 0, 8217, 0, 333, 0, 40, 0, 40, 0, 333, 0, 41, 0, 41, 0, 333, 0, 42, 0, 42, 0, 500, 0, 43, 0, 43, 0, 570, 0, 44, 0, 44, 0, 250, 0, 45, 0, 45, 0, 333, 0, 46, 0, 46, 0, 250, 0, 47, 0, 47, 0, 278, 0, 48, 0, 48, 0, 500, 0, 49, 0, 49, 0, 500, 0, 50, 0, 50, 0, 500, 0, 51, 0, 51, 0, 500, 0, 52, 0, 52, 0, 500, 0, 53, 0, 53, 0, 500, 0, 54, 0, 54, 0, 500, 0, 55, 0, 55, 0, 500, 0, 56, 0, 56, 0, 500, 0, 57, 0, 57, 0, 500, 0, 58, 0, 58, 0, 333, 0, 59, 0, 59, 0, 333, 0, 60, 0, 60, 0, 570, 0, 61, 0, 61, 0, 570, 0, 62, 0, 62, 0, 570, 0, 63, 0, 63, 0, 500, 0, 64, 0, 64, 0, 930, 0, 65, 0, 65, 0, 722, 0, 66, 0, 66, 0, 667, 0, 67, 0, 67, 0, 722, 0, 68, 0, 68, 0, 722, 0, 69, 0, 69, 0, 667, 0, 70, 0, 70, 0, 611, 0, 71, 0, 71, 0, 778, 0, 72, 0, 72, 0, 778, 0, 73, 0, 73, 0, 389, 0, 74, 0, 74, 0, 500, 0, 75, 0, 75, 0, 778, 0, 76, 0, 76, 0, 667, 0, 77, 0, 77, 0, 944, 0, 78, 0, 78, 0, 722, 0, 79, 0, 79, 0, 778, 0, 80, 0, 80, 0, 611, 0, 81, 0, 81, 0, 778, 0, 82, 0, 82, 0, 722, 0, 83, 0, 83, 0, 556, 0, 84, 0, 84, 0, 667, 0, 85, 0, 85, 0, 722, 0, 86, 0, 86, 0, 722, 0, 87, 0, 87, 0, 1000, 0, 88, 0, 88, 0, 722, 0, 89, 0, 89, 0, 722, 0, 90, 0, 90, 0, 667, 0, 91, 0, 91, 0, 333, 0, 92, 0, 92, 0, 278, 0, 93, 0, 93, 0, 333, 0, 94, 0, 94, 0, 581, 0, 95, 0, 95, 0, 500, 0, 96, 0, 8216, 0, 333, 0, 97, 0, 97, 0, 500, 0, 98, 0, 98, 0, 556, 0, 99, 0, 99, 0, 444, 0, 100, 0, 100, 0, 556, 0, 101, 0, 101, 0, 444, 0, 102, 0, 102, 0, 333, 0, 103, 0, 103, 0, 500, 0, 104, 0, 104, 0, 556, 0, 105, 0, 105, 0, 278, 0, 106, 0, 106, 0, 333, 0, 107, 0, 107, 0, 556, 0, 108, 0, 108, 0, 278, 0, 109, 0, 109, 0, 833, 0, 110, 0, 110, 0, 556, 0, 111, 0, 111, 0, 500, 0, 112, 0, 112, 0, 556, 0, 113, 0, 113, 0, 556, 0, 114, 0, 114, 0, 444, 0, 115, 0, 115, 0, 389, 0, 116, 0, 116, 0, 333, 0, 117, 0, 117, 0, 556, 0, 118, 0, 118, 0, 500, 0, 119, 0, 119, 0, 722, 0, 120, 0, 120, 0, 500, 0, 121, 0, 121, 0, 500, 0, 122, 0, 122, 0, 444, 0, 123, 0, 123, 0, 394, 0, 124, 0, 124, 0, 220, 0, 125, 0, 125, 0, 394, 0, 126, 0, 126, 0, 520, 0, 161, 0, 161, 0, 333, 0, 162, 0, 162, 0, 500, 0, 163, 0, 163, 0, 500, 0, 164, 0, 8260, 0, 167, 0, 165, 0, 165, 0, 500, 0, 166, 0, 402, 0, 500, 0, 167, 0, 167, 0, 500, 0, 168, 0, 164, 0, 500, 0, 169, 0, 39, 0, 278, 0, 170, 0, 8220, 0, 500, 0, 171, 0, 171, 0, 500, 0, 172, 0, 8249, 0, 333, 0, 173, 0, 8250, 0, 333, 0, 174, 0, -1279, 0, 556, 0, 175, 0, -1278, 0, 556, 0, 177, 0, 8211, 0, 500, 0, 178, 0, 8224, 0, 500, 0, 179, 0, 8225, 0, 500, 0, 180, 0, 183, 0, 250, 0, 182, 0, 182, 0, 540, 0, 183, 0, 8226, 0, 350, 0, 184, 0, 8218, 0, 333, 0, 185, 0, 8222, 0, 500, 0, 186, 0, 8221, 0, 500, 0, 187, 0, 187, 0, 500, 0, 188, 0, 8230, 0, 1000, 0, 189, 0, 8240, 0, 1000, 0, 191, 0, 191, 0, 500, 0, 193, 0, 96, 0, 333, 0, 194, 0, 180, 0, 333, 0, 195, 0, 710, 0, 333, 0, 196, 0, 732, 0, 333, 0, 197, 0, 175, 0, 333, 0, 198, 0, 728, 0, 333, 0, 199, 0, 729, 0, 333, 0, 200, 0, 168, 0, 333, 0, 202, 0, 730, 0, 333, 0, 203, 0, 184, 0, 333, 0, 205, 0, 733, 0, 333, 0, 206, 0, 731, 0, 333, 0, 207, 0, 711, 0, 333, 0, 208, 0, 8212, 0, 1000, 0, 225, 0, 198, 0, 1000, 0, 227, 0, 170, 0, 300, 0, 232, 0, 321, 0, 667, 0, 233, 0, 216, 0, 778, 0, 234, 0, 338, 0, 1000, 0, 235, 0, 186, 0, 330, 0, 241, 0, 230, 0, 722, 0, 245, 0, 305, 0, 278, 0, 248, 0, 322, 0, 278, 0, 249, 0, 248, 0, 500, 0, 250, 0, 339, 0, 722, 0, 251, 0, 223, 0, 556, 0, -1, 0, 207, 0, 389, 0, -1, 0, 233, 0, 444, 0, -1, 0, 259, 0, 500, 0, -1, 0, 369, 0, 556, 0, -1, 0, 283, 0, 444, 0, -1, 0, 376, 0, 722, 0, -1, 0, 247, 0, 570, 0, -1, 0, 221, 0, 722, 0, -1, 0, 194, 0, 722, 0, -1, 0, 225, 0, 500, 0, -1, 0, 219, 0, 722, 0, -1, 0, 253, 0, 500, 0, -1, 0, 537, 0, 389, 0, -1, 0, 234, 0, 444, 0, -1, 0, 366, 0, 722, 0, -1, 0, 220, 0, 722, 0, -1, 0, 261, 0, 500, 0, -1, 0, 218, 0, 722, 0, -1, 0, 371, 0, 556, 0, -1, 0, 203, 0, 667, 0, -1, 0, 272, 0, 722, 0, -1, 0, -2365, 0, 250, 0, -1, 0, 169, 0, 747, 0, -1, 0, 274, 0, 667, 0, -1, 0, 269, 0, 444, 0, -1, 0, 229, 0, 500, 0, -1, 0, 325, 0, 722, 0, -1, 0, 314, 0, 278, 0, -1, 0, 224, 0, 500, 0, -1, 0, 354, 0, 667, 0, -1, 0, 262, 0, 722, 0, -1, 0, 227, 0, 500, 0, -1, 0, 278, 0, 667, 0, -1, 0, 353, 0, 389, 0, -1, 0, 351, 0, 389, 0, -1, 0, 237, 0, 278, 0, -1, 0, 9674, 0, 494, 0, -1, 0, 344, 0, 722, 0, -1, 0, 290, 0, 778, 0, -1, 0, 251, 0, 556, 0, -1, 0, 226, 0, 500, 0, -1, 0, 256, 0, 722, 0, -1, 0, 345, 0, 444, 0, -1, 0, 231, 0, 444, 0, -1, 0, 379, 0, 667, 0, -1, 0, 222, 0, 611, 0, -1, 0, 332, 0, 778, 0, -1, 0, 340, 0, 722, 0, -1, 0, 346, 0, 556, 0, -1, 0, 271, 0, 672, 0, -1, 0, 362, 0, 722, 0, -1, 0, 367, 0, 556, 0, -1, 0, 179, 0, 300, 0, -1, 0, 210, 0, 778, 0, -1, 0, 192, 0, 722, 0, -1, 0, 258, 0, 722, 0, -1, 0, 215, 0, 570, 0, -1, 0, 250, 0, 556, 0, -1, 0, 356, 0, 667, 0, -1, 0, 8706, 0, 494, 0, -1, 0, 255, 0, 500, 0, -1, 0, 323, 0, 722, 0, -1, 0, 238, 0, 278, 0, -1, 0, 202, 0, 667, 0, -1, 0, 228, 0, 500, 0, -1, 0, 235, 0, 444, 0, -1, 0, 263, 0, 444, 0, -1, 0, 324, 0, 556, 0, -1, 0, 363, 0, 556, 0, -1, 0, 327, 0, 722, 0, -1, 0, 205, 0, 389, 0, -1, 0, 177, 0, 570, 0, -1, 0, 166, 0, 220, 0, -1, 0, 174, 0, 747, 0, -1, 0, 286, 0, 778, 0, -1, 0, 304, 0, 389, 0, -1, 0, 8721, 0, 600, 0, -1, 0, 200, 0, 667, 0, -1, 0, 341, 0, 444, 0, -1, 0, 333, 0, 500, 0, -1, 0, 377, 0, 667, 0, -1, 0, 381, 0, 667, 0, -1, 0, 8805, 0, 549, 0, -1, 0, 208, 0, 722, 0, -1, 0, 199, 0, 722, 0, -1, 0, 316, 0, 278, 0, -1, 0, 357, 0, 416, 0, -1, 0, 281, 0, 444, 0, -1, 0, 370, 0, 722, 0, -1, 0, 193, 0, 722, 0, -1, 0, 196, 0, 722, 0, -1, 0, 232, 0, 444, 0, -1, 0, 378, 0, 444, 0, -1, 0, 303, 0, 278, 0, -1, 0, 211, 0, 778, 0, -1, 0, 243, 0, 500, 0, -1, 0, 257, 0, 500, 0, -1, 0, 347, 0, 389, 0, -1, 0, 239, 0, 278, 0, -1, 0, 212, 0, 778, 0, -1, 0, 217, 0, 722, 0, -1, 0, 916, 0, 612, 0, -1, 0, 254, 0, 556, 0, -1, 0, 178, 0, 300, 0, -1, 0, 214, 0, 778, 0, -1, 0, 181, 0, 556, 0, -1, 0, 236, 0, 278, 0, -1, 0, 337, 0, 500, 0, -1, 0, 280, 0, 667, 0, -1, 0, 273, 0, 556, 0, -1, 0, 190, 0, 750, 0, -1, 0, 350, 0, 556, 0, -1, 0, 318, 0, 394, 0, -1, 0, 310, 0, 778, 0, -1, 0, 313, 0, 667, 0, -1, 0, 8482, 0, 1000, 0, -1, 0, 279, 0, 444, 0, -1, 0, 204, 0, 389, 0, -1, 0, 298, 0, 389, 0, -1, 0, 317, 0, 667, 0, -1, 0, 189, 0, 750, 0, -1, 0, 8804, 0, 549, 0, -1, 0, 244, 0, 500, 0, -1, 0, 241, 0, 556, 0, -1, 0, 368, 0, 722, 0, -1, 0, 201, 0, 667, 0, -1, 0, 275, 0, 444, 0, -1, 0, 287, 0, 500, 0, -1, 0, 188, 0, 750, 0, -1, 0, 352, 0, 556, 0, -1, 0, 536, 0, 556, 0, -1, 0, 336, 0, 778, 0, -1, 0, 176, 0, 400, 0, -1, 0, 242, 0, 500, 0, -1, 0, 268, 0, 722, 0, -1, 0, 249, 0, 556, 0, -1, 0, 8730, 0, 549, 0, -1, 0, 270, 0, 722, 0, -1, 0, 343, 0, 444, 0, -1, 0, 209, 0, 722, 0, -1, 0, 245, 0, 500, 0, -1, 0, 342, 0, 722, 0, -1, 0, 315, 0, 667, 0, -1, 0, 195, 0, 722, 0, -1, 0, 260, 0, 722, 0, -1, 0, 197, 0, 722, 0, -1, 0, 213, 0, 778, 0, -1, 0, 380, 0, 444, 0, -1, 0, 282, 0, 667, 0, -1, 0, 302, 0, 389, 0, -1, 0, 311, 0, 556, 0, -1, 0, 8722, 0, 570, 0, -1, 0, 206, 0, 389, 0, -1, 0, 328, 0, 556, 0, -1, 0, 355, 0, 333, 0, -1, 0, 172, 0, 570, 0, -1, 0, 246, 0, 500, 0, -1, 0, 252, 0, 556, 0, -1, 0, 8800, 0, 549, 0, -1, 0, 291, 0, 500, 0, -1, 0, 240, 0, 500, 0, -1, 0, 382, 0, 444, 0, -1, 0, 326, 0, 556, 0, -1, 0, 185, 0, 300, 0, -1, 0, 299, 0, 278, 0, -1, 0, 8364, 0, 500, 0, -1, 0, -1, 0, 0, 0], ["i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0], ALLOC_STATIC);
STRING_TABLE.__str111244=allocate([84,105,109,101,115,45,73,116,97,108,105,99,0] /* Times-Italic\00 */, "i8", ALLOC_STATIC);
_CHAR_DATA_TIMES_ITALIC=allocate([32, 0, 32, 0, 250, 0, 33, 0, 33, 0, 333, 0, 34, 0, 34, 0, 420, 0, 35, 0, 35, 0, 500, 0, 36, 0, 36, 0, 500, 0, 37, 0, 37, 0, 833, 0, 38, 0, 38, 0, 778, 0, 39, 0, 8217, 0, 333, 0, 40, 0, 40, 0, 333, 0, 41, 0, 41, 0, 333, 0, 42, 0, 42, 0, 500, 0, 43, 0, 43, 0, 675, 0, 44, 0, 44, 0, 250, 0, 45, 0, 45, 0, 333, 0, 46, 0, 46, 0, 250, 0, 47, 0, 47, 0, 278, 0, 48, 0, 48, 0, 500, 0, 49, 0, 49, 0, 500, 0, 50, 0, 50, 0, 500, 0, 51, 0, 51, 0, 500, 0, 52, 0, 52, 0, 500, 0, 53, 0, 53, 0, 500, 0, 54, 0, 54, 0, 500, 0, 55, 0, 55, 0, 500, 0, 56, 0, 56, 0, 500, 0, 57, 0, 57, 0, 500, 0, 58, 0, 58, 0, 333, 0, 59, 0, 59, 0, 333, 0, 60, 0, 60, 0, 675, 0, 61, 0, 61, 0, 675, 0, 62, 0, 62, 0, 675, 0, 63, 0, 63, 0, 500, 0, 64, 0, 64, 0, 920, 0, 65, 0, 65, 0, 611, 0, 66, 0, 66, 0, 611, 0, 67, 0, 67, 0, 667, 0, 68, 0, 68, 0, 722, 0, 69, 0, 69, 0, 611, 0, 70, 0, 70, 0, 611, 0, 71, 0, 71, 0, 722, 0, 72, 0, 72, 0, 722, 0, 73, 0, 73, 0, 333, 0, 74, 0, 74, 0, 444, 0, 75, 0, 75, 0, 667, 0, 76, 0, 76, 0, 556, 0, 77, 0, 77, 0, 833, 0, 78, 0, 78, 0, 667, 0, 79, 0, 79, 0, 722, 0, 80, 0, 80, 0, 611, 0, 81, 0, 81, 0, 722, 0, 82, 0, 82, 0, 611, 0, 83, 0, 83, 0, 500, 0, 84, 0, 84, 0, 556, 0, 85, 0, 85, 0, 722, 0, 86, 0, 86, 0, 611, 0, 87, 0, 87, 0, 833, 0, 88, 0, 88, 0, 611, 0, 89, 0, 89, 0, 556, 0, 90, 0, 90, 0, 556, 0, 91, 0, 91, 0, 389, 0, 92, 0, 92, 0, 278, 0, 93, 0, 93, 0, 389, 0, 94, 0, 94, 0, 422, 0, 95, 0, 95, 0, 500, 0, 96, 0, 8216, 0, 333, 0, 97, 0, 97, 0, 500, 0, 98, 0, 98, 0, 500, 0, 99, 0, 99, 0, 444, 0, 100, 0, 100, 0, 500, 0, 101, 0, 101, 0, 444, 0, 102, 0, 102, 0, 278, 0, 103, 0, 103, 0, 500, 0, 104, 0, 104, 0, 500, 0, 105, 0, 105, 0, 278, 0, 106, 0, 106, 0, 278, 0, 107, 0, 107, 0, 444, 0, 108, 0, 108, 0, 278, 0, 109, 0, 109, 0, 722, 0, 110, 0, 110, 0, 500, 0, 111, 0, 111, 0, 500, 0, 112, 0, 112, 0, 500, 0, 113, 0, 113, 0, 500, 0, 114, 0, 114, 0, 389, 0, 115, 0, 115, 0, 389, 0, 116, 0, 116, 0, 278, 0, 117, 0, 117, 0, 500, 0, 118, 0, 118, 0, 444, 0, 119, 0, 119, 0, 667, 0, 120, 0, 120, 0, 444, 0, 121, 0, 121, 0, 444, 0, 122, 0, 122, 0, 389, 0, 123, 0, 123, 0, 400, 0, 124, 0, 124, 0, 275, 0, 125, 0, 125, 0, 400, 0, 126, 0, 126, 0, 541, 0, 161, 0, 161, 0, 389, 0, 162, 0, 162, 0, 500, 0, 163, 0, 163, 0, 500, 0, 164, 0, 8260, 0, 167, 0, 165, 0, 165, 0, 500, 0, 166, 0, 402, 0, 500, 0, 167, 0, 167, 0, 500, 0, 168, 0, 164, 0, 500, 0, 169, 0, 39, 0, 214, 0, 170, 0, 8220, 0, 556, 0, 171, 0, 171, 0, 500, 0, 172, 0, 8249, 0, 333, 0, 173, 0, 8250, 0, 333, 0, 174, 0, -1279, 0, 500, 0, 175, 0, -1278, 0, 500, 0, 177, 0, 8211, 0, 500, 0, 178, 0, 8224, 0, 500, 0, 179, 0, 8225, 0, 500, 0, 180, 0, 183, 0, 250, 0, 182, 0, 182, 0, 523, 0, 183, 0, 8226, 0, 350, 0, 184, 0, 8218, 0, 333, 0, 185, 0, 8222, 0, 556, 0, 186, 0, 8221, 0, 556, 0, 187, 0, 187, 0, 500, 0, 188, 0, 8230, 0, 889, 0, 189, 0, 8240, 0, 1000, 0, 191, 0, 191, 0, 500, 0, 193, 0, 96, 0, 333, 0, 194, 0, 180, 0, 333, 0, 195, 0, 710, 0, 333, 0, 196, 0, 732, 0, 333, 0, 197, 0, 175, 0, 333, 0, 198, 0, 728, 0, 333, 0, 199, 0, 729, 0, 333, 0, 200, 0, 168, 0, 333, 0, 202, 0, 730, 0, 333, 0, 203, 0, 184, 0, 333, 0, 205, 0, 733, 0, 333, 0, 206, 0, 731, 0, 333, 0, 207, 0, 711, 0, 333, 0, 208, 0, 8212, 0, 889, 0, 225, 0, 198, 0, 889, 0, 227, 0, 170, 0, 276, 0, 232, 0, 321, 0, 556, 0, 233, 0, 216, 0, 722, 0, 234, 0, 338, 0, 944, 0, 235, 0, 186, 0, 310, 0, 241, 0, 230, 0, 667, 0, 245, 0, 305, 0, 278, 0, 248, 0, 322, 0, 278, 0, 249, 0, 248, 0, 500, 0, 250, 0, 339, 0, 667, 0, 251, 0, 223, 0, 500, 0, -1, 0, 207, 0, 333, 0, -1, 0, 233, 0, 444, 0, -1, 0, 259, 0, 500, 0, -1, 0, 369, 0, 500, 0, -1, 0, 283, 0, 444, 0, -1, 0, 376, 0, 556, 0, -1, 0, 247, 0, 675, 0, -1, 0, 221, 0, 556, 0, -1, 0, 194, 0, 611, 0, -1, 0, 225, 0, 500, 0, -1, 0, 219, 0, 722, 0, -1, 0, 253, 0, 444, 0, -1, 0, 537, 0, 389, 0, -1, 0, 234, 0, 444, 0, -1, 0, 366, 0, 722, 0, -1, 0, 220, 0, 722, 0, -1, 0, 261, 0, 500, 0, -1, 0, 218, 0, 722, 0, -1, 0, 371, 0, 500, 0, -1, 0, 203, 0, 611, 0, -1, 0, 272, 0, 722, 0, -1, 0, -2365, 0, 250, 0, -1, 0, 169, 0, 760, 0, -1, 0, 274, 0, 611, 0, -1, 0, 269, 0, 444, 0, -1, 0, 229, 0, 500, 0, -1, 0, 325, 0, 667, 0, -1, 0, 314, 0, 278, 0, -1, 0, 224, 0, 500, 0, -1, 0, 354, 0, 556, 0, -1, 0, 262, 0, 667, 0, -1, 0, 227, 0, 500, 0, -1, 0, 278, 0, 611, 0, -1, 0, 353, 0, 389, 0, -1, 0, 351, 0, 389, 0, -1, 0, 237, 0, 278, 0, -1, 0, 9674, 0, 471, 0, -1, 0, 344, 0, 611, 0, -1, 0, 290, 0, 722, 0, -1, 0, 251, 0, 500, 0, -1, 0, 226, 0, 500, 0, -1, 0, 256, 0, 611, 0, -1, 0, 345, 0, 389, 0, -1, 0, 231, 0, 444, 0, -1, 0, 379, 0, 556, 0, -1, 0, 222, 0, 611, 0, -1, 0, 332, 0, 722, 0, -1, 0, 340, 0, 611, 0, -1, 0, 346, 0, 500, 0, -1, 0, 271, 0, 544, 0, -1, 0, 362, 0, 722, 0, -1, 0, 367, 0, 500, 0, -1, 0, 179, 0, 300, 0, -1, 0, 210, 0, 722, 0, -1, 0, 192, 0, 611, 0, -1, 0, 258, 0, 611, 0, -1, 0, 215, 0, 675, 0, -1, 0, 250, 0, 500, 0, -1, 0, 356, 0, 556, 0, -1, 0, 8706, 0, 476, 0, -1, 0, 255, 0, 444, 0, -1, 0, 323, 0, 667, 0, -1, 0, 238, 0, 278, 0, -1, 0, 202, 0, 611, 0, -1, 0, 228, 0, 500, 0, -1, 0, 235, 0, 444, 0, -1, 0, 263, 0, 444, 0, -1, 0, 324, 0, 500, 0, -1, 0, 363, 0, 500, 0, -1, 0, 327, 0, 667, 0, -1, 0, 205, 0, 333, 0, -1, 0, 177, 0, 675, 0, -1, 0, 166, 0, 275, 0, -1, 0, 174, 0, 760, 0, -1, 0, 286, 0, 722, 0, -1, 0, 304, 0, 333, 0, -1, 0, 8721, 0, 600, 0, -1, 0, 200, 0, 611, 0, -1, 0, 341, 0, 389, 0, -1, 0, 333, 0, 500, 0, -1, 0, 377, 0, 556, 0, -1, 0, 381, 0, 556, 0, -1, 0, 8805, 0, 549, 0, -1, 0, 208, 0, 722, 0, -1, 0, 199, 0, 667, 0, -1, 0, 316, 0, 278, 0, -1, 0, 357, 0, 300, 0, -1, 0, 281, 0, 444, 0, -1, 0, 370, 0, 722, 0, -1, 0, 193, 0, 611, 0, -1, 0, 196, 0, 611, 0, -1, 0, 232, 0, 444, 0, -1, 0, 378, 0, 389, 0, -1, 0, 303, 0, 278, 0, -1, 0, 211, 0, 722, 0, -1, 0, 243, 0, 500, 0, -1, 0, 257, 0, 500, 0, -1, 0, 347, 0, 389, 0, -1, 0, 239, 0, 278, 0, -1, 0, 212, 0, 722, 0, -1, 0, 217, 0, 722, 0, -1, 0, 916, 0, 612, 0, -1, 0, 254, 0, 500, 0, -1, 0, 178, 0, 300, 0, -1, 0, 214, 0, 722, 0, -1, 0, 181, 0, 500, 0, -1, 0, 236, 0, 278, 0, -1, 0, 337, 0, 500, 0, -1, 0, 280, 0, 611, 0, -1, 0, 273, 0, 500, 0, -1, 0, 190, 0, 750, 0, -1, 0, 350, 0, 500, 0, -1, 0, 318, 0, 300, 0, -1, 0, 310, 0, 667, 0, -1, 0, 313, 0, 556, 0, -1, 0, 8482, 0, 980, 0, -1, 0, 279, 0, 444, 0, -1, 0, 204, 0, 333, 0, -1, 0, 298, 0, 333, 0, -1, 0, 317, 0, 611, 0, -1, 0, 189, 0, 750, 0, -1, 0, 8804, 0, 549, 0, -1, 0, 244, 0, 500, 0, -1, 0, 241, 0, 500, 0, -1, 0, 368, 0, 722, 0, -1, 0, 201, 0, 611, 0, -1, 0, 275, 0, 444, 0, -1, 0, 287, 0, 500, 0, -1, 0, 188, 0, 750, 0, -1, 0, 352, 0, 500, 0, -1, 0, 536, 0, 500, 0, -1, 0, 336, 0, 722, 0, -1, 0, 176, 0, 400, 0, -1, 0, 242, 0, 500, 0, -1, 0, 268, 0, 667, 0, -1, 0, 249, 0, 500, 0, -1, 0, 8730, 0, 453, 0, -1, 0, 270, 0, 722, 0, -1, 0, 343, 0, 389, 0, -1, 0, 209, 0, 667, 0, -1, 0, 245, 0, 500, 0, -1, 0, 342, 0, 611, 0, -1, 0, 315, 0, 556, 0, -1, 0, 195, 0, 611, 0, -1, 0, 260, 0, 611, 0, -1, 0, 197, 0, 611, 0, -1, 0, 213, 0, 722, 0, -1, 0, 380, 0, 389, 0, -1, 0, 282, 0, 611, 0, -1, 0, 302, 0, 333, 0, -1, 0, 311, 0, 444, 0, -1, 0, 8722, 0, 675, 0, -1, 0, 206, 0, 333, 0, -1, 0, 328, 0, 500, 0, -1, 0, 355, 0, 278, 0, -1, 0, 172, 0, 675, 0, -1, 0, 246, 0, 500, 0, -1, 0, 252, 0, 500, 0, -1, 0, 8800, 0, 549, 0, -1, 0, 291, 0, 500, 0, -1, 0, 240, 0, 500, 0, -1, 0, 382, 0, 389, 0, -1, 0, 326, 0, 500, 0, -1, 0, 185, 0, 300, 0, -1, 0, 299, 0, 278, 0, -1, 0, 8364, 0, 500, 0, -1, 0, -1, 0, 0, 0], ["i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0], ALLOC_STATIC);
STRING_TABLE.__str121245=allocate([84,105,109,101,115,45,66,111,108,100,73,116,97,108,105,99,0] /* Times-BoldItalic\00 */, "i8", ALLOC_STATIC);
_CHAR_DATA_TIMES_BOLD_ITALIC=allocate([32, 0, 32, 0, 250, 0, 33, 0, 33, 0, 389, 0, 34, 0, 34, 0, 555, 0, 35, 0, 35, 0, 500, 0, 36, 0, 36, 0, 500, 0, 37, 0, 37, 0, 833, 0, 38, 0, 38, 0, 778, 0, 39, 0, 8217, 0, 333, 0, 40, 0, 40, 0, 333, 0, 41, 0, 41, 0, 333, 0, 42, 0, 42, 0, 500, 0, 43, 0, 43, 0, 570, 0, 44, 0, 44, 0, 250, 0, 45, 0, 45, 0, 333, 0, 46, 0, 46, 0, 250, 0, 47, 0, 47, 0, 278, 0, 48, 0, 48, 0, 500, 0, 49, 0, 49, 0, 500, 0, 50, 0, 50, 0, 500, 0, 51, 0, 51, 0, 500, 0, 52, 0, 52, 0, 500, 0, 53, 0, 53, 0, 500, 0, 54, 0, 54, 0, 500, 0, 55, 0, 55, 0, 500, 0, 56, 0, 56, 0, 500, 0, 57, 0, 57, 0, 500, 0, 58, 0, 58, 0, 333, 0, 59, 0, 59, 0, 333, 0, 60, 0, 60, 0, 570, 0, 61, 0, 61, 0, 570, 0, 62, 0, 62, 0, 570, 0, 63, 0, 63, 0, 500, 0, 64, 0, 64, 0, 832, 0, 65, 0, 65, 0, 667, 0, 66, 0, 66, 0, 667, 0, 67, 0, 67, 0, 667, 0, 68, 0, 68, 0, 722, 0, 69, 0, 69, 0, 667, 0, 70, 0, 70, 0, 667, 0, 71, 0, 71, 0, 722, 0, 72, 0, 72, 0, 778, 0, 73, 0, 73, 0, 389, 0, 74, 0, 74, 0, 500, 0, 75, 0, 75, 0, 667, 0, 76, 0, 76, 0, 611, 0, 77, 0, 77, 0, 889, 0, 78, 0, 78, 0, 722, 0, 79, 0, 79, 0, 722, 0, 80, 0, 80, 0, 611, 0, 81, 0, 81, 0, 722, 0, 82, 0, 82, 0, 667, 0, 83, 0, 83, 0, 556, 0, 84, 0, 84, 0, 611, 0, 85, 0, 85, 0, 722, 0, 86, 0, 86, 0, 667, 0, 87, 0, 87, 0, 889, 0, 88, 0, 88, 0, 667, 0, 89, 0, 89, 0, 611, 0, 90, 0, 90, 0, 611, 0, 91, 0, 91, 0, 333, 0, 92, 0, 92, 0, 278, 0, 93, 0, 93, 0, 333, 0, 94, 0, 94, 0, 570, 0, 95, 0, 95, 0, 500, 0, 96, 0, 8216, 0, 333, 0, 97, 0, 97, 0, 500, 0, 98, 0, 98, 0, 500, 0, 99, 0, 99, 0, 444, 0, 100, 0, 100, 0, 500, 0, 101, 0, 101, 0, 444, 0, 102, 0, 102, 0, 333, 0, 103, 0, 103, 0, 500, 0, 104, 0, 104, 0, 556, 0, 105, 0, 105, 0, 278, 0, 106, 0, 106, 0, 278, 0, 107, 0, 107, 0, 500, 0, 108, 0, 108, 0, 278, 0, 109, 0, 109, 0, 778, 0, 110, 0, 110, 0, 556, 0, 111, 0, 111, 0, 500, 0, 112, 0, 112, 0, 500, 0, 113, 0, 113, 0, 500, 0, 114, 0, 114, 0, 389, 0, 115, 0, 115, 0, 389, 0, 116, 0, 116, 0, 278, 0, 117, 0, 117, 0, 556, 0, 118, 0, 118, 0, 444, 0, 119, 0, 119, 0, 667, 0, 120, 0, 120, 0, 500, 0, 121, 0, 121, 0, 444, 0, 122, 0, 122, 0, 389, 0, 123, 0, 123, 0, 348, 0, 124, 0, 124, 0, 220, 0, 125, 0, 125, 0, 348, 0, 126, 0, 126, 0, 570, 0, 161, 0, 161, 0, 389, 0, 162, 0, 162, 0, 500, 0, 163, 0, 163, 0, 500, 0, 164, 0, 8260, 0, 167, 0, 165, 0, 165, 0, 500, 0, 166, 0, 402, 0, 500, 0, 167, 0, 167, 0, 500, 0, 168, 0, 164, 0, 500, 0, 169, 0, 39, 0, 278, 0, 170, 0, 8220, 0, 500, 0, 171, 0, 171, 0, 500, 0, 172, 0, 8249, 0, 333, 0, 173, 0, 8250, 0, 333, 0, 174, 0, -1279, 0, 556, 0, 175, 0, -1278, 0, 556, 0, 177, 0, 8211, 0, 500, 0, 178, 0, 8224, 0, 500, 0, 179, 0, 8225, 0, 500, 0, 180, 0, 183, 0, 250, 0, 182, 0, 182, 0, 500, 0, 183, 0, 8226, 0, 350, 0, 184, 0, 8218, 0, 333, 0, 185, 0, 8222, 0, 500, 0, 186, 0, 8221, 0, 500, 0, 187, 0, 187, 0, 500, 0, 188, 0, 8230, 0, 1000, 0, 189, 0, 8240, 0, 1000, 0, 191, 0, 191, 0, 500, 0, 193, 0, 96, 0, 333, 0, 194, 0, 180, 0, 333, 0, 195, 0, 710, 0, 333, 0, 196, 0, 732, 0, 333, 0, 197, 0, 175, 0, 333, 0, 198, 0, 728, 0, 333, 0, 199, 0, 729, 0, 333, 0, 200, 0, 168, 0, 333, 0, 202, 0, 730, 0, 333, 0, 203, 0, 184, 0, 333, 0, 205, 0, 733, 0, 333, 0, 206, 0, 731, 0, 333, 0, 207, 0, 711, 0, 333, 0, 208, 0, 8212, 0, 1000, 0, 225, 0, 198, 0, 944, 0, 227, 0, 170, 0, 266, 0, 232, 0, 321, 0, 611, 0, 233, 0, 216, 0, 722, 0, 234, 0, 338, 0, 944, 0, 235, 0, 186, 0, 300, 0, 241, 0, 230, 0, 722, 0, 245, 0, 305, 0, 278, 0, 248, 0, 322, 0, 278, 0, 249, 0, 248, 0, 500, 0, 250, 0, 339, 0, 722, 0, 251, 0, 223, 0, 500, 0, -1, 0, 207, 0, 389, 0, -1, 0, 233, 0, 444, 0, -1, 0, 259, 0, 500, 0, -1, 0, 369, 0, 556, 0, -1, 0, 283, 0, 444, 0, -1, 0, 376, 0, 611, 0, -1, 0, 247, 0, 570, 0, -1, 0, 221, 0, 611, 0, -1, 0, 194, 0, 667, 0, -1, 0, 225, 0, 500, 0, -1, 0, 219, 0, 722, 0, -1, 0, 253, 0, 444, 0, -1, 0, 537, 0, 389, 0, -1, 0, 234, 0, 444, 0, -1, 0, 366, 0, 722, 0, -1, 0, 220, 0, 722, 0, -1, 0, 261, 0, 500, 0, -1, 0, 218, 0, 722, 0, -1, 0, 371, 0, 556, 0, -1, 0, 203, 0, 667, 0, -1, 0, 272, 0, 722, 0, -1, 0, -2365, 0, 250, 0, -1, 0, 169, 0, 747, 0, -1, 0, 274, 0, 667, 0, -1, 0, 269, 0, 444, 0, -1, 0, 229, 0, 500, 0, -1, 0, 325, 0, 722, 0, -1, 0, 314, 0, 278, 0, -1, 0, 224, 0, 500, 0, -1, 0, 354, 0, 611, 0, -1, 0, 262, 0, 667, 0, -1, 0, 227, 0, 500, 0, -1, 0, 278, 0, 667, 0, -1, 0, 353, 0, 389, 0, -1, 0, 351, 0, 389, 0, -1, 0, 237, 0, 278, 0, -1, 0, 9674, 0, 494, 0, -1, 0, 344, 0, 667, 0, -1, 0, 290, 0, 722, 0, -1, 0, 251, 0, 556, 0, -1, 0, 226, 0, 500, 0, -1, 0, 256, 0, 667, 0, -1, 0, 345, 0, 389, 0, -1, 0, 231, 0, 444, 0, -1, 0, 379, 0, 611, 0, -1, 0, 222, 0, 611, 0, -1, 0, 332, 0, 722, 0, -1, 0, 340, 0, 667, 0, -1, 0, 346, 0, 556, 0, -1, 0, 271, 0, 608, 0, -1, 0, 362, 0, 722, 0, -1, 0, 367, 0, 556, 0, -1, 0, 179, 0, 300, 0, -1, 0, 210, 0, 722, 0, -1, 0, 192, 0, 667, 0, -1, 0, 258, 0, 667, 0, -1, 0, 215, 0, 570, 0, -1, 0, 250, 0, 556, 0, -1, 0, 356, 0, 611, 0, -1, 0, 8706, 0, 494, 0, -1, 0, 255, 0, 444, 0, -1, 0, 323, 0, 722, 0, -1, 0, 238, 0, 278, 0, -1, 0, 202, 0, 667, 0, -1, 0, 228, 0, 500, 0, -1, 0, 235, 0, 444, 0, -1, 0, 263, 0, 444, 0, -1, 0, 324, 0, 556, 0, -1, 0, 363, 0, 556, 0, -1, 0, 327, 0, 722, 0, -1, 0, 205, 0, 389, 0, -1, 0, 177, 0, 570, 0, -1, 0, 166, 0, 220, 0, -1, 0, 174, 0, 747, 0, -1, 0, 286, 0, 722, 0, -1, 0, 304, 0, 389, 0, -1, 0, 8721, 0, 600, 0, -1, 0, 200, 0, 667, 0, -1, 0, 341, 0, 389, 0, -1, 0, 333, 0, 500, 0, -1, 0, 377, 0, 611, 0, -1, 0, 381, 0, 611, 0, -1, 0, 8805, 0, 549, 0, -1, 0, 208, 0, 722, 0, -1, 0, 199, 0, 667, 0, -1, 0, 316, 0, 278, 0, -1, 0, 357, 0, 366, 0, -1, 0, 281, 0, 444, 0, -1, 0, 370, 0, 722, 0, -1, 0, 193, 0, 667, 0, -1, 0, 196, 0, 667, 0, -1, 0, 232, 0, 444, 0, -1, 0, 378, 0, 389, 0, -1, 0, 303, 0, 278, 0, -1, 0, 211, 0, 722, 0, -1, 0, 243, 0, 500, 0, -1, 0, 257, 0, 500, 0, -1, 0, 347, 0, 389, 0, -1, 0, 239, 0, 278, 0, -1, 0, 212, 0, 722, 0, -1, 0, 217, 0, 722, 0, -1, 0, 916, 0, 612, 0, -1, 0, 254, 0, 500, 0, -1, 0, 178, 0, 300, 0, -1, 0, 214, 0, 722, 0, -1, 0, 181, 0, 576, 0, -1, 0, 236, 0, 278, 0, -1, 0, 337, 0, 500, 0, -1, 0, 280, 0, 667, 0, -1, 0, 273, 0, 500, 0, -1, 0, 190, 0, 750, 0, -1, 0, 350, 0, 556, 0, -1, 0, 318, 0, 382, 0, -1, 0, 310, 0, 667, 0, -1, 0, 313, 0, 611, 0, -1, 0, 8482, 0, 1000, 0, -1, 0, 279, 0, 444, 0, -1, 0, 204, 0, 389, 0, -1, 0, 298, 0, 389, 0, -1, 0, 317, 0, 611, 0, -1, 0, 189, 0, 750, 0, -1, 0, 8804, 0, 549, 0, -1, 0, 244, 0, 500, 0, -1, 0, 241, 0, 556, 0, -1, 0, 368, 0, 722, 0, -1, 0, 201, 0, 667, 0, -1, 0, 275, 0, 444, 0, -1, 0, 287, 0, 500, 0, -1, 0, 188, 0, 750, 0, -1, 0, 352, 0, 556, 0, -1, 0, 536, 0, 556, 0, -1, 0, 336, 0, 722, 0, -1, 0, 176, 0, 400, 0, -1, 0, 242, 0, 500, 0, -1, 0, 268, 0, 667, 0, -1, 0, 249, 0, 556, 0, -1, 0, 8730, 0, 549, 0, -1, 0, 270, 0, 722, 0, -1, 0, 343, 0, 389, 0, -1, 0, 209, 0, 722, 0, -1, 0, 245, 0, 500, 0, -1, 0, 342, 0, 667, 0, -1, 0, 315, 0, 611, 0, -1, 0, 195, 0, 667, 0, -1, 0, 260, 0, 667, 0, -1, 0, 197, 0, 667, 0, -1, 0, 213, 0, 722, 0, -1, 0, 380, 0, 389, 0, -1, 0, 282, 0, 667, 0, -1, 0, 302, 0, 389, 0, -1, 0, 311, 0, 500, 0, -1, 0, 8722, 0, 606, 0, -1, 0, 206, 0, 389, 0, -1, 0, 328, 0, 556, 0, -1, 0, 355, 0, 278, 0, -1, 0, 172, 0, 606, 0, -1, 0, 246, 0, 500, 0, -1, 0, 252, 0, 556, 0, -1, 0, 8800, 0, 549, 0, -1, 0, 291, 0, 500, 0, -1, 0, 240, 0, 500, 0, -1, 0, 382, 0, 389, 0, -1, 0, 326, 0, 556, 0, -1, 0, 185, 0, 300, 0, -1, 0, 299, 0, 278, 0, -1, 0, 8364, 0, 500, 0, -1, 0, -1, 0, 0, 0], ["i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0], ALLOC_STATIC);
STRING_TABLE.__str131246=allocate([83,121,109,98,111,108,0] /* Symbol\00 */, "i8", ALLOC_STATIC);
_CHAR_DATA_SYMBOL=allocate([32, 0, 32, 0, 250, 0, 33, 0, 33, 0, 333, 0, 34, 0, 34, 0, 713, 0, 35, 0, 35, 0, 500, 0, 36, 0, 36, 0, 549, 0, 37, 0, 37, 0, 833, 0, 38, 0, 38, 0, 778, 0, 39, 0, 39, 0, 439, 0, 40, 0, 40, 0, 333, 0, 41, 0, 41, 0, 333, 0, 42, 0, 42, 0, 500, 0, 43, 0, 43, 0, 549, 0, 44, 0, 44, 0, 250, 0, 45, 0, 45, 0, 549, 0, 46, 0, 46, 0, 250, 0, 47, 0, 47, 0, 278, 0, 48, 0, 48, 0, 500, 0, 49, 0, 49, 0, 500, 0, 50, 0, 50, 0, 500, 0, 51, 0, 51, 0, 500, 0, 52, 0, 52, 0, 500, 0, 53, 0, 53, 0, 500, 0, 54, 0, 54, 0, 500, 0, 55, 0, 55, 0, 500, 0, 56, 0, 56, 0, 500, 0, 57, 0, 57, 0, 500, 0, 58, 0, 58, 0, 278, 0, 59, 0, 59, 0, 278, 0, 60, 0, 60, 0, 549, 0, 61, 0, 61, 0, 549, 0, 62, 0, 62, 0, 549, 0, 63, 0, 63, 0, 444, 0, 64, 0, 64, 0, 549, 0, 65, 0, 65, 0, 722, 0, 66, 0, 66, 0, 667, 0, 67, 0, 67, 0, 722, 0, 68, 0, 68, 0, 612, 0, 69, 0, 69, 0, 611, 0, 70, 0, 70, 0, 763, 0, 71, 0, 71, 0, 603, 0, 72, 0, 72, 0, 722, 0, 73, 0, 73, 0, 333, 0, 74, 0, 74, 0, 631, 0, 75, 0, 75, 0, 722, 0, 76, 0, 76, 0, 686, 0, 77, 0, 77, 0, 889, 0, 78, 0, 78, 0, 722, 0, 79, 0, 79, 0, 722, 0, 80, 0, 80, 0, 768, 0, 81, 0, 81, 0, 741, 0, 82, 0, 82, 0, 556, 0, 83, 0, 83, 0, 592, 0, 84, 0, 84, 0, 611, 0, 85, 0, 85, 0, 690, 0, 86, 0, 86, 0, 439, 0, 87, 0, 87, 0, 768, 0, 88, 0, 88, 0, 645, 0, 89, 0, 89, 0, 795, 0, 90, 0, 90, 0, 611, 0, 91, 0, 91, 0, 333, 0, 92, 0, 92, 0, 863, 0, 93, 0, 93, 0, 333, 0, 94, 0, 94, 0, 658, 0, 95, 0, 95, 0, 500, 0, 96, 0, 96, 0, 500, 0, 97, 0, 97, 0, 631, 0, 98, 0, 98, 0, 549, 0, 99, 0, 99, 0, 549, 0, 100, 0, 100, 0, 494, 0, 101, 0, 101, 0, 439, 0, 102, 0, 102, 0, 521, 0, 103, 0, 103, 0, 411, 0, 104, 0, 104, 0, 603, 0, 105, 0, 105, 0, 329, 0, 106, 0, 106, 0, 603, 0, 107, 0, 107, 0, 549, 0, 108, 0, 108, 0, 549, 0, 109, 0, 109, 0, 576, 0, 110, 0, 110, 0, 521, 0, 111, 0, 111, 0, 549, 0, 112, 0, 112, 0, 549, 0, 113, 0, 113, 0, 521, 0, 114, 0, 114, 0, 549, 0, 115, 0, 115, 0, 603, 0, 116, 0, 116, 0, 439, 0, 117, 0, 117, 0, 576, 0, 118, 0, 118, 0, 713, 0, 119, 0, 119, 0, 686, 0, 120, 0, 120, 0, 493, 0, 121, 0, 121, 0, 686, 0, 122, 0, 122, 0, 494, 0, 123, 0, 123, 0, 480, 0, 124, 0, 124, 0, 200, 0, 125, 0, 125, 0, 480, 0, 126, 0, 126, 0, 549, 0, 160, 0, 160, 0, 750, 0, 161, 0, 161, 0, 620, 0, 162, 0, 162, 0, 247, 0, 163, 0, 163, 0, 549, 0, 164, 0, 164, 0, 167, 0, 165, 0, 165, 0, 713, 0, 166, 0, 166, 0, 500, 0, 167, 0, 167, 0, 753, 0, 168, 0, 168, 0, 753, 0, 169, 0, 169, 0, 753, 0, 170, 0, 170, 0, 753, 0, 171, 0, 171, 0, 1042, 0, 172, 0, 172, 0, 987, 0, 173, 0, 173, 0, 603, 0, 174, 0, 174, 0, 987, 0, 175, 0, 175, 0, 603, 0, 176, 0, 176, 0, 400, 0, 177, 0, 177, 0, 549, 0, 178, 0, 178, 0, 411, 0, 179, 0, 179, 0, 549, 0, 180, 0, 180, 0, 549, 0, 181, 0, 181, 0, 713, 0, 182, 0, 182, 0, 494, 0, 183, 0, 183, 0, 460, 0, 184, 0, 184, 0, 549, 0, 185, 0, 185, 0, 549, 0, 186, 0, 186, 0, 549, 0, 187, 0, 187, 0, 549, 0, 188, 0, 188, 0, 1000, 0, 189, 0, 189, 0, 603, 0, 190, 0, 190, 0, 1000, 0, 191, 0, 191, 0, 658, 0, 192, 0, 192, 0, 823, 0, 193, 0, 193, 0, 686, 0, 194, 0, 194, 0, 795, 0, 195, 0, 195, 0, 987, 0, 196, 0, 196, 0, 768, 0, 197, 0, 197, 0, 768, 0, 198, 0, 198, 0, 823, 0, 199, 0, 199, 0, 768, 0, 200, 0, 200, 0, 768, 0, 201, 0, 201, 0, 713, 0, 202, 0, 202, 0, 713, 0, 203, 0, 203, 0, 713, 0, 204, 0, 204, 0, 713, 0, 205, 0, 205, 0, 713, 0, 206, 0, 206, 0, 713, 0, 207, 0, 207, 0, 713, 0, 208, 0, 208, 0, 768, 0, 209, 0, 209, 0, 713, 0, 210, 0, 210, 0, 790, 0, 211, 0, 211, 0, 790, 0, 212, 0, 212, 0, 890, 0, 213, 0, 213, 0, 823, 0, 214, 0, 214, 0, 549, 0, 215, 0, 215, 0, 250, 0, 216, 0, 216, 0, 713, 0, 217, 0, 217, 0, 603, 0, 218, 0, 218, 0, 603, 0, 219, 0, 219, 0, 1042, 0, 220, 0, 220, 0, 987, 0, 221, 0, 221, 0, 603, 0, 222, 0, 222, 0, 987, 0, 223, 0, 223, 0, 603, 0, 224, 0, 224, 0, 494, 0, 225, 0, 225, 0, 329, 0, 226, 0, 226, 0, 790, 0, 227, 0, 227, 0, 790, 0, 228, 0, 228, 0, 786, 0, 229, 0, 229, 0, 713, 0, 230, 0, 230, 0, 384, 0, 231, 0, 231, 0, 384, 0, 232, 0, 232, 0, 384, 0, 233, 0, 233, 0, 384, 0, 234, 0, 234, 0, 384, 0, 235, 0, 235, 0, 384, 0, 236, 0, 236, 0, 494, 0, 237, 0, 237, 0, 494, 0, 238, 0, 238, 0, 494, 0, 239, 0, 239, 0, 494, 0, 241, 0, 241, 0, 329, 0, 242, 0, 242, 0, 274, 0, 243, 0, 243, 0, 686, 0, 244, 0, 244, 0, 686, 0, 245, 0, 245, 0, 686, 0, 246, 0, 246, 0, 384, 0, 247, 0, 247, 0, 384, 0, 248, 0, 248, 0, 384, 0, 249, 0, 249, 0, 384, 0, 250, 0, 250, 0, 384, 0, 251, 0, 251, 0, 384, 0, 252, 0, 252, 0, 494, 0, 253, 0, 253, 0, 494, 0, 254, 0, 254, 0, 494, 0, -1, 0, -1, 0, 0, 0], ["i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0], ALLOC_STATIC);
STRING_TABLE.__str141247=allocate([90,97,112,102,68,105,110,103,98,97,116,115,0] /* ZapfDingbats\00 */, "i8", ALLOC_STATIC);
_CHAR_DATA_ZAPF_DINGBATS=allocate([32, 0, 32, 0, 278, 0, 33, 0, 33, 0, 974, 0, 34, 0, 34, 0, 961, 0, 35, 0, 35, 0, 974, 0, 36, 0, 36, 0, 980, 0, 37, 0, 37, 0, 719, 0, 38, 0, 38, 0, 789, 0, 39, 0, 39, 0, 790, 0, 40, 0, 40, 0, 791, 0, 41, 0, 41, 0, 690, 0, 42, 0, 42, 0, 960, 0, 43, 0, 43, 0, 939, 0, 44, 0, 44, 0, 549, 0, 45, 0, 45, 0, 855, 0, 46, 0, 46, 0, 911, 0, 47, 0, 47, 0, 933, 0, 48, 0, 48, 0, 911, 0, 49, 0, 49, 0, 945, 0, 50, 0, 50, 0, 974, 0, 51, 0, 51, 0, 755, 0, 52, 0, 52, 0, 846, 0, 53, 0, 53, 0, 762, 0, 54, 0, 54, 0, 761, 0, 55, 0, 55, 0, 571, 0, 56, 0, 56, 0, 677, 0, 57, 0, 57, 0, 763, 0, 58, 0, 58, 0, 760, 0, 59, 0, 59, 0, 759, 0, 60, 0, 60, 0, 754, 0, 61, 0, 61, 0, 494, 0, 62, 0, 62, 0, 552, 0, 63, 0, 63, 0, 537, 0, 64, 0, 64, 0, 577, 0, 65, 0, 65, 0, 692, 0, 66, 0, 66, 0, 786, 0, 67, 0, 67, 0, 788, 0, 68, 0, 68, 0, 788, 0, 69, 0, 69, 0, 790, 0, 70, 0, 70, 0, 793, 0, 71, 0, 71, 0, 794, 0, 72, 0, 72, 0, 816, 0, 73, 0, 73, 0, 823, 0, 74, 0, 74, 0, 789, 0, 75, 0, 75, 0, 841, 0, 76, 0, 76, 0, 823, 0, 77, 0, 77, 0, 833, 0, 78, 0, 78, 0, 816, 0, 79, 0, 79, 0, 831, 0, 80, 0, 80, 0, 923, 0, 81, 0, 81, 0, 744, 0, 82, 0, 82, 0, 723, 0, 83, 0, 83, 0, 749, 0, 84, 0, 84, 0, 790, 0, 85, 0, 85, 0, 792, 0, 86, 0, 86, 0, 695, 0, 87, 0, 87, 0, 776, 0, 88, 0, 88, 0, 768, 0, 89, 0, 89, 0, 792, 0, 90, 0, 90, 0, 759, 0, 91, 0, 91, 0, 707, 0, 92, 0, 92, 0, 708, 0, 93, 0, 93, 0, 682, 0, 94, 0, 94, 0, 701, 0, 95, 0, 95, 0, 826, 0, 96, 0, 96, 0, 815, 0, 97, 0, 97, 0, 789, 0, 98, 0, 98, 0, 789, 0, 99, 0, 99, 0, 707, 0, 100, 0, 100, 0, 687, 0, 101, 0, 101, 0, 696, 0, 102, 0, 102, 0, 689, 0, 103, 0, 103, 0, 786, 0, 104, 0, 104, 0, 787, 0, 105, 0, 105, 0, 713, 0, 106, 0, 106, 0, 791, 0, 107, 0, 107, 0, 785, 0, 108, 0, 108, 0, 791, 0, 109, 0, 109, 0, 873, 0, 110, 0, 110, 0, 761, 0, 111, 0, 111, 0, 762, 0, 112, 0, 112, 0, 762, 0, 113, 0, 113, 0, 759, 0, 114, 0, 114, 0, 759, 0, 115, 0, 115, 0, 892, 0, 116, 0, 116, 0, 892, 0, 117, 0, 117, 0, 788, 0, 118, 0, 118, 0, 784, 0, 119, 0, 119, 0, 438, 0, 120, 0, 120, 0, 138, 0, 121, 0, 121, 0, 277, 0, 122, 0, 122, 0, 415, 0, 123, 0, 123, 0, 392, 0, 124, 0, 124, 0, 392, 0, 125, 0, 125, 0, 668, 0, 126, 0, 126, 0, 668, 0, 128, 0, 128, 0, 390, 0, 129, 0, 129, 0, 390, 0, 130, 0, 130, 0, 317, 0, 131, 0, 131, 0, 317, 0, 132, 0, 132, 0, 276, 0, 133, 0, 133, 0, 276, 0, 134, 0, 134, 0, 509, 0, 135, 0, 135, 0, 509, 0, 136, 0, 136, 0, 410, 0, 137, 0, 137, 0, 410, 0, 138, 0, 138, 0, 234, 0, 139, 0, 139, 0, 234, 0, 140, 0, 140, 0, 334, 0, 141, 0, 141, 0, 334, 0, 161, 0, 161, 0, 732, 0, 162, 0, 162, 0, 544, 0, 163, 0, 163, 0, 544, 0, 164, 0, 164, 0, 910, 0, 165, 0, 165, 0, 667, 0, 166, 0, 166, 0, 760, 0, 167, 0, 167, 0, 760, 0, 168, 0, 168, 0, 776, 0, 169, 0, 169, 0, 595, 0, 170, 0, 170, 0, 694, 0, 171, 0, 171, 0, 626, 0, 172, 0, 172, 0, 788, 0, 173, 0, 173, 0, 788, 0, 174, 0, 174, 0, 788, 0, 175, 0, 175, 0, 788, 0, 176, 0, 176, 0, 788, 0, 177, 0, 177, 0, 788, 0, 178, 0, 178, 0, 788, 0, 179, 0, 179, 0, 788, 0, 180, 0, 180, 0, 788, 0, 181, 0, 181, 0, 788, 0, 182, 0, 182, 0, 788, 0, 183, 0, 183, 0, 788, 0, 184, 0, 184, 0, 788, 0, 185, 0, 185, 0, 788, 0, 186, 0, 186, 0, 788, 0, 187, 0, 187, 0, 788, 0, 188, 0, 188, 0, 788, 0, 189, 0, 189, 0, 788, 0, 190, 0, 190, 0, 788, 0, 191, 0, 191, 0, 788, 0, 192, 0, 192, 0, 788, 0, 193, 0, 193, 0, 788, 0, 194, 0, 194, 0, 788, 0, 195, 0, 195, 0, 788, 0, 196, 0, 196, 0, 788, 0, 197, 0, 197, 0, 788, 0, 198, 0, 198, 0, 788, 0, 199, 0, 199, 0, 788, 0, 200, 0, 200, 0, 788, 0, 201, 0, 201, 0, 788, 0, 202, 0, 202, 0, 788, 0, 203, 0, 203, 0, 788, 0, 204, 0, 204, 0, 788, 0, 205, 0, 205, 0, 788, 0, 206, 0, 206, 0, 788, 0, 207, 0, 207, 0, 788, 0, 208, 0, 208, 0, 788, 0, 209, 0, 209, 0, 788, 0, 210, 0, 210, 0, 788, 0, 211, 0, 211, 0, 788, 0, 212, 0, 212, 0, 894, 0, 213, 0, 213, 0, 838, 0, 214, 0, 214, 0, 1016, 0, 215, 0, 215, 0, 458, 0, 216, 0, 216, 0, 748, 0, 217, 0, 217, 0, 924, 0, 218, 0, 218, 0, 748, 0, 219, 0, 219, 0, 918, 0, 220, 0, 220, 0, 927, 0, 221, 0, 221, 0, 928, 0, 222, 0, 222, 0, 928, 0, 223, 0, 223, 0, 834, 0, 224, 0, 224, 0, 873, 0, 225, 0, 225, 0, 828, 0, 226, 0, 226, 0, 924, 0, 227, 0, 227, 0, 924, 0, 228, 0, 228, 0, 917, 0, 229, 0, 229, 0, 930, 0, 230, 0, 230, 0, 931, 0, 231, 0, 231, 0, 463, 0, 232, 0, 232, 0, 883, 0, 233, 0, 233, 0, 836, 0, 234, 0, 234, 0, 836, 0, 235, 0, 235, 0, 867, 0, 236, 0, 236, 0, 867, 0, 237, 0, 237, 0, 696, 0, 238, 0, 238, 0, 696, 0, 239, 0, 239, 0, 874, 0, 241, 0, 241, 0, 874, 0, 242, 0, 242, 0, 760, 0, 243, 0, 243, 0, 946, 0, 244, 0, 244, 0, 771, 0, 245, 0, 245, 0, 865, 0, 246, 0, 246, 0, 771, 0, 247, 0, 247, 0, 888, 0, 248, 0, 248, 0, 967, 0, 249, 0, 249, 0, 888, 0, 250, 0, 250, 0, 831, 0, 251, 0, 251, 0, 873, 0, 252, 0, 252, 0, 927, 0, 253, 0, 253, 0, 970, 0, 254, 0, 254, 0, 918, 0, -1, 0, -1, 0, 0, 0], ["i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0], ALLOC_STATIC);
STRING_TABLE.__str1256=allocate([83,105,109,83,117,110,0] /* SimSun\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str11257=allocate([83,105,109,83,117,110,44,66,111,108,100,0] /* SimSun,Bold\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str21258=allocate([83,105,109,83,117,110,44,73,116,97,108,105,99,0] /* SimSun,Italic\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str31259=allocate([83,105,109,83,117,110,44,66,111,108,100,73,116,97,108,105,99,0] /* SimSun,BoldItalic\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str41260=allocate([83,105,109,72,101,105,0] /* SimHei\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str51261=allocate([83,105,109,72,101,105,44,66,111,108,100,0] /* SimHei,Bold\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str61262=allocate([83,105,109,72,101,105,44,73,116,97,108,105,99,0] /* SimHei,Italic\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str71263=allocate([83,105,109,72,101,105,44,66,111,108,100,73,116,97,108,105,99,0] /* SimHei,BoldItalic\00 */, "i8", ALLOC_STATIC);
_SIMHEI_W_ARRAY=allocate([668, 0, 500, 0, 669, 0, 500, 0, 670, 0, 500, 0, 671, 0, 500, 0, 672, 0, 500, 0, 673, 0, 500, 0, 674, 0, 500, 0, 675, 0, 500, 0, 676, 0, 500, 0, 677, 0, 500, 0, 678, 0, 500, 0, 679, 0, 500, 0, 680, 0, 500, 0, 681, 0, 500, 0, 682, 0, 500, 0, 683, 0, 500, 0, 684, 0, 500, 0, 685, 0, 500, 0, 686, 0, 500, 0, 687, 0, 500, 0, 688, 0, 500, 0, 689, 0, 500, 0, 690, 0, 500, 0, 691, 0, 500, 0, 692, 0, 500, 0, 693, 0, 500, 0, 694, 0, 500, 0, 696, 0, 500, 0, 697, 0, 500, 0, 698, 0, 500, 0, 699, 0, 500, 0, 814, 0, 500, 0, 815, 0, 500, 0, 816, 0, 500, 0, 817, 0, 500, 0, 818, 0, 500, 0, 819, 0, 500, 0, 820, 0, 500, 0, 821, 0, 500, 0, 822, 0, 500, 0, 823, 0, 500, 0, 824, 0, 500, 0, 825, 0, 500, 0, 826, 0, 500, 0, 827, 0, 500, 0, 828, 0, 500, 0, 829, 0, 500, 0, 830, 0, 500, 0, 831, 0, 500, 0, 832, 0, 500, 0, 833, 0, 500, 0, 834, 0, 500, 0, 835, 0, 500, 0, 836, 0, 500, 0, 837, 0, 500, 0, 838, 0, 500, 0, 839, 0, 500, 0, 840, 0, 500, 0, 841, 0, 500, 0, 842, 0, 500, 0, 843, 0, 500, 0, 844, 0, 500, 0, 845, 0, 500, 0, 846, 0, 500, 0, 847, 0, 500, 0, 848, 0, 500, 0, 849, 0, 500, 0, 850, 0, 500, 0, 851, 0, 500, 0, 852, 0, 500, 0, 853, 0, 500, 0, 854, 0, 500, 0, 855, 0, 500, 0, 856, 0, 500, 0, 857, 0, 500, 0, 858, 0, 500, 0, 859, 0, 500, 0, 860, 0, 500, 0, 861, 0, 500, 0, 862, 0, 500, 0, 863, 0, 500, 0, 864, 0, 500, 0, 865, 0, 500, 0, 866, 0, 500, 0, 867, 0, 500, 0, 868, 0, 500, 0, 869, 0, 500, 0, 870, 0, 500, 0, 871, 0, 500, 0, 872, 0, 500, 0, 873, 0, 500, 0, 874, 0, 500, 0, 875, 0, 500, 0, 876, 0, 500, 0, 877, 0, 500, 0, 878, 0, 500, 0, 879, 0, 500, 0, 880, 0, 500, 0, 881, 0, 500, 0, 882, 0, 500, 0, 883, 0, 500, 0, 884, 0, 500, 0, 885, 0, 500, 0, 886, 0, 500, 0, 887, 0, 500, 0, 888, 0, 500, 0, 889, 0, 500, 0, 890, 0, 500, 0, 891, 0, 500, 0, 892, 0, 500, 0, 893, 0, 500, 0, 894, 0, 500, 0, 895, 0, 500, 0, 896, 0, 500, 0, 897, 0, 500, 0, 898, 0, 500, 0, 899, 0, 500, 0, 900, 0, 500, 0, 901, 0, 500, 0, 902, 0, 500, 0, 903, 0, 500, 0, 904, 0, 500, 0, 905, 0, 500, 0, 906, 0, 500, 0, 907, 0, 500, 0, 7716, 0, 500, 0, -1, 0, 0, 0], ["i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0], ALLOC_STATIC);
_SIMSUN_W_ARRAY=allocate([668, 0, 500, 0, 669, 0, 500, 0, 670, 0, 500, 0, 671, 0, 500, 0, 672, 0, 500, 0, 673, 0, 500, 0, 674, 0, 500, 0, 675, 0, 500, 0, 676, 0, 500, 0, 677, 0, 500, 0, 678, 0, 500, 0, 679, 0, 500, 0, 680, 0, 500, 0, 681, 0, 500, 0, 682, 0, 500, 0, 683, 0, 500, 0, 684, 0, 500, 0, 685, 0, 500, 0, 686, 0, 500, 0, 687, 0, 500, 0, 688, 0, 500, 0, 689, 0, 500, 0, 690, 0, 500, 0, 691, 0, 500, 0, 692, 0, 500, 0, 693, 0, 500, 0, 694, 0, 500, 0, 696, 0, 500, 0, 697, 0, 500, 0, 698, 0, 500, 0, 699, 0, 500, 0, 814, 0, 500, 0, 815, 0, 500, 0, 816, 0, 500, 0, 817, 0, 500, 0, 818, 0, 500, 0, 819, 0, 500, 0, 820, 0, 500, 0, 821, 0, 500, 0, 822, 0, 500, 0, 823, 0, 500, 0, 824, 0, 500, 0, 825, 0, 500, 0, 826, 0, 500, 0, 827, 0, 500, 0, 828, 0, 500, 0, 829, 0, 500, 0, 830, 0, 500, 0, 831, 0, 500, 0, 832, 0, 500, 0, 833, 0, 500, 0, 834, 0, 500, 0, 835, 0, 500, 0, 836, 0, 500, 0, 837, 0, 500, 0, 838, 0, 500, 0, 839, 0, 500, 0, 840, 0, 500, 0, 841, 0, 500, 0, 842, 0, 500, 0, 843, 0, 500, 0, 844, 0, 500, 0, 845, 0, 500, 0, 846, 0, 500, 0, 847, 0, 500, 0, 848, 0, 500, 0, 849, 0, 500, 0, 850, 0, 500, 0, 851, 0, 500, 0, 852, 0, 500, 0, 853, 0, 500, 0, 854, 0, 500, 0, 855, 0, 500, 0, 856, 0, 500, 0, 857, 0, 500, 0, 858, 0, 500, 0, 859, 0, 500, 0, 860, 0, 500, 0, 861, 0, 500, 0, 862, 0, 500, 0, 863, 0, 500, 0, 864, 0, 500, 0, 865, 0, 500, 0, 866, 0, 500, 0, 867, 0, 500, 0, 868, 0, 500, 0, 869, 0, 500, 0, 870, 0, 500, 0, 871, 0, 500, 0, 872, 0, 500, 0, 873, 0, 500, 0, 874, 0, 500, 0, 875, 0, 500, 0, 876, 0, 500, 0, 877, 0, 500, 0, 878, 0, 500, 0, 879, 0, 500, 0, 880, 0, 500, 0, 881, 0, 500, 0, 882, 0, 500, 0, 883, 0, 500, 0, 884, 0, 500, 0, 885, 0, 500, 0, 886, 0, 500, 0, 887, 0, 500, 0, 888, 0, 500, 0, 889, 0, 500, 0, 890, 0, 500, 0, 891, 0, 500, 0, 892, 0, 500, 0, 893, 0, 500, 0, 894, 0, 500, 0, 895, 0, 500, 0, 896, 0, 500, 0, 897, 0, 500, 0, 898, 0, 500, 0, 899, 0, 500, 0, 900, 0, 500, 0, 901, 0, 500, 0, 902, 0, 500, 0, 903, 0, 500, 0, 904, 0, 500, 0, 905, 0, 500, 0, 906, 0, 500, 0, 907, 0, 500, 0, 7716, 0, 500, 0, -1, 0, 0, 0], ["i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0], ALLOC_STATIC);
STRING_TABLE.__str1265=allocate([77,105,110,103,76,105,85,0] /* MingLiU\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str11266=allocate([77,105,110,103,76,105,85,44,66,111,108,100,0] /* MingLiU,Bold\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str21267=allocate([77,105,110,103,76,105,85,44,73,116,97,108,105,99,0] /* MingLiU,Italic\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str31268=allocate([77,105,110,103,76,105,85,44,66,111,108,100,73,116,97,108,105,99,0] /* MingLiU,BoldItalic\0 */, "i8", ALLOC_STATIC);
_MING_LIU_W_ARRAY=allocate([668, 0, 500, 0, 669, 0, 500, 0, 670, 0, 500, 0, 671, 0, 500, 0, 672, 0, 500, 0, 673, 0, 500, 0, 674, 0, 500, 0, 675, 0, 500, 0, 676, 0, 500, 0, 677, 0, 500, 0, 678, 0, 500, 0, 679, 0, 500, 0, 680, 0, 500, 0, 681, 0, 500, 0, 682, 0, 500, 0, 683, 0, 500, 0, 684, 0, 500, 0, 685, 0, 500, 0, 686, 0, 500, 0, 687, 0, 500, 0, 688, 0, 500, 0, 689, 0, 500, 0, 690, 0, 500, 0, 691, 0, 500, 0, 692, 0, 500, 0, 693, 0, 500, 0, 694, 0, 500, 0, 696, 0, 500, 0, 697, 0, 500, 0, 698, 0, 500, 0, 699, 0, 500, 0, 814, 0, 500, 0, 815, 0, 500, 0, 816, 0, 500, 0, 817, 0, 500, 0, 818, 0, 500, 0, 819, 0, 500, 0, 820, 0, 500, 0, 821, 0, 500, 0, 822, 0, 500, 0, 823, 0, 500, 0, 824, 0, 500, 0, 825, 0, 500, 0, 826, 0, 500, 0, 827, 0, 500, 0, 828, 0, 500, 0, 829, 0, 500, 0, 830, 0, 500, 0, 831, 0, 500, 0, 832, 0, 500, 0, 833, 0, 500, 0, 834, 0, 500, 0, 835, 0, 500, 0, 836, 0, 500, 0, 837, 0, 500, 0, 838, 0, 500, 0, 839, 0, 500, 0, 840, 0, 500, 0, 841, 0, 500, 0, 842, 0, 500, 0, 843, 0, 500, 0, 844, 0, 500, 0, 845, 0, 500, 0, 846, 0, 500, 0, 847, 0, 500, 0, 848, 0, 500, 0, 849, 0, 500, 0, 850, 0, 500, 0, 851, 0, 500, 0, 852, 0, 500, 0, 853, 0, 500, 0, 854, 0, 500, 0, 855, 0, 500, 0, 856, 0, 500, 0, 857, 0, 500, 0, 858, 0, 500, 0, 859, 0, 500, 0, 860, 0, 500, 0, 861, 0, 500, 0, 862, 0, 500, 0, 863, 0, 500, 0, 864, 0, 500, 0, 865, 0, 500, 0, 866, 0, 500, 0, 867, 0, 500, 0, 868, 0, 500, 0, 869, 0, 500, 0, 870, 0, 500, 0, 871, 0, 500, 0, 872, 0, 500, 0, 873, 0, 500, 0, 874, 0, 500, 0, 875, 0, 500, 0, 876, 0, 500, 0, 877, 0, 500, 0, 878, 0, 500, 0, 879, 0, 500, 0, 880, 0, 500, 0, 881, 0, 500, 0, 882, 0, 500, 0, 883, 0, 500, 0, 884, 0, 500, 0, 885, 0, 500, 0, 886, 0, 500, 0, 887, 0, 500, 0, 888, 0, 500, 0, 889, 0, 500, 0, 890, 0, 500, 0, 891, 0, 500, 0, 892, 0, 500, 0, 893, 0, 500, 0, 894, 0, 500, 0, 895, 0, 500, 0, 896, 0, 500, 0, 897, 0, 500, 0, 898, 0, 500, 0, 899, 0, 500, 0, 900, 0, 500, 0, 901, 0, 500, 0, 902, 0, 500, 0, 903, 0, 500, 0, 904, 0, 500, 0, 905, 0, 500, 0, 906, 0, 500, 0, 907, 0, 500, 0, 7716, 0, 500, 0, -1, 0, 0, 0], ["i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0], ALLOC_STATIC);
STRING_TABLE.__str1270=allocate([77,83,45,71,111,116,104,105,99,0] /* MS-Gothic\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str11271=allocate([77,83,45,71,111,116,104,105,99,44,66,111,108,100,0] /* MS-Gothic,Bold\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str21272=allocate([77,83,45,71,111,116,104,105,99,44,73,116,97,108,105,99,0] /* MS-Gothic,Italic\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str31273=allocate([77,83,45,71,111,116,104,105,99,44,66,111,108,100,73,116,97,108,105,99,0] /* MS-Gothic,BoldItalic */, "i8", ALLOC_STATIC);
STRING_TABLE.__str41274=allocate([77,83,45,80,71,111,116,104,105,99,0] /* MS-PGothic\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str51275=allocate([77,83,45,80,71,111,116,104,105,99,44,66,111,108,100,0] /* MS-PGothic,Bold\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str61276=allocate([77,83,45,80,71,111,116,104,105,99,44,73,116,97,108,105,99,0] /* MS-PGothic,Italic\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str71277=allocate([77,83,45,80,71,111,116,104,105,99,44,66,111,108,100,73,116,97,108,105,99,0] /* MS-PGothic,BoldItali */, "i8", ALLOC_STATIC);
STRING_TABLE.__str81278=allocate([77,83,45,77,105,110,99,121,111,0] /* MS-Mincyo\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str91279=allocate([77,83,45,77,105,110,99,121,111,44,66,111,108,100,0] /* MS-Mincyo,Bold\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str101280=allocate([77,83,45,77,105,110,99,121,111,44,73,116,97,108,105,99,0] /* MS-Mincyo,Italic\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str111281=allocate([77,83,45,77,105,110,99,121,111,44,66,111,108,100,73,116,97,108,105,99,0] /* MS-Mincyo,BoldItalic */, "i8", ALLOC_STATIC);
STRING_TABLE.__str121282=allocate([77,83,45,80,77,105,110,99,121,111,0] /* MS-PMincyo\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str131283=allocate([77,83,45,80,77,105,110,99,121,111,44,66,111,108,100,0] /* MS-PMincyo,Bold\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str141284=allocate([77,83,45,80,77,105,110,99,121,111,44,73,116,97,108,105,99,0] /* MS-PMincyo,Italic\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str151285=allocate([77,83,45,80,77,105,110,99,121,111,44,66,111,108,100,73,116,97,108,105,99,0] /* MS-PMincyo,BoldItali */, "i8", ALLOC_STATIC);
_MS_PGothic_W_ARRAY=allocate([1, 0, 304, 0, 2, 0, 218, 0, 3, 0, 500, 0, 4, 0, 500, 0, 5, 0, 500, 0, 6, 0, 500, 0, 7, 0, 593, 0, 8, 0, 203, 0, 9, 0, 304, 0, 10, 0, 304, 0, 11, 0, 500, 0, 12, 0, 500, 0, 13, 0, 203, 0, 14, 0, 500, 0, 15, 0, 203, 0, 16, 0, 500, 0, 17, 0, 500, 0, 18, 0, 500, 0, 19, 0, 500, 0, 20, 0, 500, 0, 21, 0, 500, 0, 22, 0, 500, 0, 23, 0, 500, 0, 24, 0, 500, 0, 25, 0, 500, 0, 26, 0, 500, 0, 27, 0, 203, 0, 28, 0, 203, 0, 29, 0, 500, 0, 30, 0, 500, 0, 31, 0, 500, 0, 32, 0, 453, 0, 33, 0, 667, 0, 34, 0, 632, 0, 35, 0, 636, 0, 36, 0, 664, 0, 37, 0, 648, 0, 38, 0, 566, 0, 39, 0, 550, 0, 40, 0, 679, 0, 41, 0, 640, 0, 42, 0, 246, 0, 43, 0, 542, 0, 44, 0, 597, 0, 45, 0, 539, 0, 46, 0, 742, 0, 47, 0, 640, 0, 48, 0, 707, 0, 49, 0, 617, 0, 50, 0, 707, 0, 51, 0, 625, 0, 52, 0, 601, 0, 53, 0, 589, 0, 54, 0, 640, 0, 55, 0, 632, 0, 56, 0, 742, 0, 57, 0, 601, 0, 58, 0, 589, 0, 59, 0, 566, 0, 60, 0, 335, 0, 61, 0, 503, 0, 62, 0, 335, 0, 63, 0, 414, 0, 64, 0, 304, 0, 65, 0, 414, 0, 66, 0, 476, 0, 67, 0, 496, 0, 68, 0, 500, 0, 69, 0, 496, 0, 70, 0, 500, 0, 71, 0, 304, 0, 72, 0, 460, 0, 73, 0, 500, 0, 74, 0, 210, 0, 75, 0, 218, 0, 76, 0, 460, 0, 77, 0, 210, 0, 78, 0, 734, 0, 79, 0, 500, 0, 80, 0, 507, 0, 81, 0, 496, 0, 82, 0, 496, 0, 83, 0, 347, 0, 84, 0, 460, 0, 85, 0, 351, 0, 86, 0, 500, 0, 87, 0, 476, 0, 88, 0, 648, 0, 89, 0, 460, 0, 90, 0, 476, 0, 91, 0, 457, 0, 92, 0, 234, 0, 93, 0, 234, 0, 94, 0, 234, 0, 95, 0, 414, 0, 231, 0, 304, 0, 232, 0, 218, 0, 233, 0, 500, 0, 234, 0, 500, 0, 235, 0, 500, 0, 236, 0, 500, 0, 237, 0, 593, 0, 238, 0, 203, 0, 239, 0, 304, 0, 240, 0, 304, 0, 241, 0, 500, 0, 242, 0, 500, 0, 243, 0, 203, 0, 244, 0, 500, 0, 245, 0, 203, 0, 246, 0, 500, 0, 247, 0, 500, 0, 248, 0, 500, 0, 249, 0, 500, 0, 250, 0, 500, 0, 251, 0, 500, 0, 252, 0, 500, 0, 253, 0, 500, 0, 254, 0, 500, 0, 255, 0, 500, 0, 256, 0, 500, 0, 257, 0, 203, 0, 258, 0, 203, 0, 259, 0, 500, 0, 260, 0, 500, 0, 261, 0, 500, 0, 262, 0, 453, 0, 263, 0, 667, 0, 264, 0, 632, 0, 265, 0, 636, 0, 266, 0, 664, 0, 267, 0, 648, 0, 268, 0, 566, 0, 269, 0, 550, 0, 270, 0, 679, 0, 271, 0, 640, 0, 272, 0, 246, 0, 273, 0, 542, 0, 274, 0, 597, 0, 275, 0, 539, 0, 276, 0, 742, 0, 277, 0, 640, 0, 278, 0, 707, 0, 279, 0, 617, 0, 280, 0, 707, 0, 281, 0, 625, 0, 282, 0, 601, 0, 283, 0, 589, 0, 284, 0, 640, 0, 285, 0, 632, 0, 286, 0, 742, 0, 287, 0, 601, 0, 288, 0, 589, 0, 289, 0, 566, 0, 290, 0, 335, 0, 291, 0, 503, 0, 292, 0, 335, 0, 293, 0, 414, 0, 294, 0, 304, 0, 295, 0, 414, 0, 296, 0, 476, 0, 297, 0, 496, 0, 298, 0, 500, 0, 299, 0, 496, 0, 300, 0, 500, 0, 301, 0, 304, 0, 302, 0, 460, 0, 303, 0, 500, 0, 304, 0, 210, 0, 305, 0, 218, 0, 306, 0, 460, 0, 307, 0, 210, 0, 308, 0, 734, 0, 309, 0, 500, 0, 310, 0, 507, 0, 311, 0, 496, 0, 312, 0, 496, 0, 313, 0, 347, 0, 314, 0, 460, 0, 315, 0, 351, 0, 316, 0, 500, 0, 317, 0, 476, 0, 318, 0, 648, 0, 319, 0, 460, 0, 320, 0, 476, 0, 321, 0, 457, 0, 322, 0, 234, 0, 323, 0, 234, 0, 324, 0, 234, 0, 327, 0, 441, 0, 328, 0, 441, 0, 329, 0, 441, 0, 330, 0, 441, 0, 331, 0, 441, 0, 332, 0, 546, 0, 333, 0, 523, 0, 334, 0, 445, 0, 335, 0, 480, 0, 336, 0, 468, 0, 337, 0, 515, 0, 338, 0, 523, 0, 339, 0, 503, 0, 340, 0, 437, 0, 341, 0, 500, 0, 342, 0, 640, 0, 343, 0, 617, 0, 344, 0, 566, 0, 345, 0, 625, 0, 346, 0, 597, 0, 347, 0, 636, 0, 348, 0, 562, 0, 349, 0, 652, 0, 350, 0, 539, 0, 351, 0, 621, 0, 352, 0, 523, 0, 353, 0, 664, 0, 354, 0, 589, 0, 355, 0, 636, 0, 356, 0, 644, 0, 357, 0, 554, 0, 358, 0, 527, 0, 359, 0, 601, 0, 360, 0, 601, 0, 361, 0, 601, 0, 362, 0, 460, 0, 363, 0, 644, 0, 364, 0, 597, 0, 365, 0, 578, 0, 366, 0, 648, 0, 367, 0, 492, 0, 368, 0, 636, 0, 369, 0, 515, 0, 370, 0, 546, 0, 371, 0, 613, 0, 372, 0, 640, 0, 373, 0, 605, 0, 374, 0, 453, 0, 375, 0, 660, 0, 376, 0, 507, 0, 377, 0, 609, 0, 378, 0, 664, 0, 379, 0, 640, 0, 380, 0, 519, 0, 381, 0, 558, 0, 382, 0, 511, 0, 383, 0, 656, 0, 384, 0, 566, 0, 385, 0, 558, 0, 386, 0, 589, 0, 387, 0, 562, 0, 388, 0, 250, 0, 389, 0, 230, 0, 631, 0, 414, 0, 633, 0, 664, 0, 634, 0, 664, 0, 635, 0, 664, 0, 636, 0, 664, 0, 637, 0, 664, 0, 638, 0, 500, 0, 639, 0, 500, 0, 640, 0, 500, 0, 643, 0, 500, 0, 644, 0, 500, 0, 645, 0, 500, 0, 646, 0, 500, 0, 647, 0, 500, 0, 648, 0, 500, 0, 651, 0, 746, 0, 652, 0, 746, 0, 653, 0, 734, 0, 654, 0, 699, 0, 660, 0, 960, 0, 662, 0, 500, 0, 670, 0, 500, 0, 671, 0, 500, 0, 672, 0, 500, 0, 673, 0, 500, 0, 674, 0, 500, 0, 675, 0, 500, 0, 676, 0, 500, 0, 677, 0, 500, 0, 678, 0, 500, 0, 679, 0, 500, 0, 680, 0, 500, 0, 681, 0, 500, 0, 682, 0, 500, 0, 683, 0, 500, 0, 684, 0, 500, 0, 685, 0, 500, 0, 686, 0, 500, 0, 687, 0, 500, 0, 688, 0, 500, 0, 689, 0, 500, 0, 690, 0, 500, 0, 691, 0, 500, 0, 776, 0, 500, 0, 777, 0, 500, 0, 778, 0, 500, 0, 780, 0, 683, 0, 781, 0, 683, 0, 782, 0, 683, 0, 783, 0, 683, 0, 784, 0, 683, 0, 785, 0, 683, 0, 786, 0, 683, 0, 787, 0, 683, 0, 788, 0, 683, 0, 789, 0, 683, 0, 790, 0, 714, 0, 791, 0, 777, 0, 792, 0, 742, 0, 793, 0, 757, 0, 794, 0, 710, 0, 795, 0, 632, 0, 796, 0, 773, 0, 797, 0, 769, 0, 798, 0, 273, 0, 799, 0, 605, 0, 800, 0, 753, 0, 801, 0, 628, 0, 802, 0, 933, 0, 803, 0, 769, 0, 804, 0, 804, 0, 805, 0, 710, 0, 806, 0, 804, 0, 807, 0, 757, 0, 808, 0, 742, 0, 809, 0, 617, 0, 810, 0, 769, 0, 811, 0, 714, 0, 812, 0, 980, 0, 813, 0, 652, 0, 814, 0, 648, 0, 815, 0, 648, 0, 816, 0, 574, 0, 817, 0, 601, 0, 818, 0, 562, 0, 819, 0, 601, 0, 820, 0, 562, 0, 821, 0, 296, 0, 822, 0, 578, 0, 823, 0, 621, 0, 824, 0, 250, 0, 825, 0, 250, 0, 826, 0, 593, 0, 827, 0, 250, 0, 828, 0, 937, 0, 829, 0, 621, 0, 830, 0, 605, 0, 831, 0, 605, 0, 832, 0, 601, 0, 833, 0, 378, 0, 834, 0, 570, 0, 835, 0, 335, 0, 836, 0, 621, 0, 837, 0, 511, 0, 838, 0, 777, 0, 839, 0, 519, 0, 840, 0, 496, 0, 841, 0, 507, 0, 842, 0, 746, 0, 843, 0, 941, 0, 844, 0, 804, 0, 845, 0, 945, 0, 846, 0, 601, 0, 847, 0, 707, 0, 848, 0, 750, 0, 849, 0, 902, 0, 850, 0, 804, 0, 851, 0, 945, 0, 854, 0, 843, 0, 855, 0, 902, 0, 856, 0, 589, 0, 857, 0, 816, 0, 858, 0, 945, 0, 859, 0, 980, 0, 860, 0, 796, 0, 861, 0, 894, 0, 862, 0, 765, 0, 863, 0, 882, 0, 864, 0, 765, 0, 865, 0, 765, 0, 866, 0, 960, 0, 867, 0, 980, 0, 870, 0, 921, 0, 871, 0, 960, 0, 872, 0, 921, 0, 873, 0, 921, 0, 874, 0, 863, 0, 875, 0, 902, 0, 876, 0, 804, 0, 877, 0, 953, 0, 878, 0, 957, 0, 879, 0, 902, 0, 880, 0, 902, 0, 881, 0, 765, 0, 882, 0, 882, 0, 883, 0, 902, 0, 884, 0, 941, 0, 891, 0, 960, 0, 892, 0, 960, 0, 893, 0, 960, 0, 903, 0, 890, 0, 905, 0, 980, 0, 906, 0, 980, 0, 907, 0, 804, 0, 908, 0, 843, 0, 910, 0, 843, 0, 911, 0, 980, 0, 912, 0, 726, 0, 913, 0, 863, 0, 914, 0, 804, 0, 915, 0, 746, 0, 916, 0, 863, 0, 918, 0, 843, 0, 919, 0, 863, 0, 923, 0, 855, 0, 924, 0, 960, 0, 925, 0, 757, 0, 926, 0, 898, 0, 927, 0, 652, 0, 928, 0, 824, 0, 929, 0, 753, 0, 930, 0, 941, 0, 931, 0, 742, 0, 932, 0, 894, 0, 933, 0, 808, 0, 934, 0, 933, 0, 935, 0, 824, 0, 936, 0, 921, 0, 937, 0, 960, 0, 938, 0, 964, 0, 939, 0, 804, 0, 940, 0, 941, 0, 941, 0, 929, 0, 942, 0, 960, 0, 943, 0, 796, 0, 944, 0, 890, 0, 947, 0, 898, 0, 948, 0, 898, 0, 949, 0, 902, 0, 950, 0, 964, 0, 951, 0, 914, 0, 952, 0, 980, 0, 953, 0, 804, 0, 954, 0, 882, 0, 955, 0, 765, 0, 956, 0, 921, 0, 957, 0, 910, 0, 958, 0, 960, 0, 959, 0, 734, 0, 960, 0, 863, 0, 961, 0, 921, 0, 962, 0, 886, 0, 963, 0, 960, 0, 964, 0, 648, 0, 965, 0, 707, 0, 966, 0, 941, 0, 967, 0, 910, 0, 968, 0, 824, 0, 969, 0, 929, 0, 970, 0, 707, 0, 974, 0, 765, 0, 975, 0, 863, 0, 976, 0, 863, 0, 977, 0, 804, 0, 978, 0, 882, 0, 979, 0, 882, 0, 980, 0, 945, 0, 981, 0, 945, 0, 982, 0, 945, 0, 983, 0, 921, 0, 984, 0, 953, 0, 985, 0, 953, 0, 986, 0, 902, 0, 987, 0, 667, 0, 988, 0, 976, 0, 989, 0, 718, 0, 990, 0, 898, 0, 991, 0, 804, 0, 992, 0, 980, 0, 993, 0, 812, 0, 994, 0, 960, 0, 995, 0, 628, 0, 996, 0, 726, 0, 997, 0, 808, 0, 998, 0, 746, 0, 1000, 0, 851, 0, 1001, 0, 863, 0, 1002, 0, 765, 0, 1003, 0, 941, 0, 1006, 0, 804, 0, 1007, 0, 863, 0, 1008, 0, 960, 0, 1009, 0, 726, 0, 1010, 0, 777, 0, -1, 0, 0, 0], ["i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0], ALLOC_STATIC);
_MS_Gothic_W_ARRAY=allocate([1, 0, 500, 0, 2, 0, 500, 0, 3, 0, 500, 0, 4, 0, 500, 0, 5, 0, 500, 0, 6, 0, 500, 0, 7, 0, 500, 0, 8, 0, 500, 0, 9, 0, 500, 0, 10, 0, 500, 0, 11, 0, 500, 0, 12, 0, 500, 0, 13, 0, 500, 0, 14, 0, 500, 0, 15, 0, 500, 0, 16, 0, 500, 0, 17, 0, 500, 0, 18, 0, 500, 0, 19, 0, 500, 0, 20, 0, 500, 0, 21, 0, 500, 0, 22, 0, 500, 0, 23, 0, 500, 0, 24, 0, 500, 0, 25, 0, 500, 0, 26, 0, 500, 0, 27, 0, 500, 0, 28, 0, 500, 0, 29, 0, 500, 0, 30, 0, 500, 0, 31, 0, 500, 0, 32, 0, 500, 0, 33, 0, 500, 0, 34, 0, 500, 0, 35, 0, 500, 0, 36, 0, 500, 0, 37, 0, 500, 0, 38, 0, 500, 0, 39, 0, 500, 0, 40, 0, 500, 0, 41, 0, 500, 0, 42, 0, 500, 0, 43, 0, 500, 0, 44, 0, 500, 0, 45, 0, 500, 0, 46, 0, 500, 0, 47, 0, 500, 0, 48, 0, 500, 0, 49, 0, 500, 0, 50, 0, 500, 0, 51, 0, 500, 0, 52, 0, 500, 0, 53, 0, 500, 0, 54, 0, 500, 0, 55, 0, 500, 0, 56, 0, 500, 0, 57, 0, 500, 0, 58, 0, 500, 0, 59, 0, 500, 0, 60, 0, 500, 0, 61, 0, 500, 0, 62, 0, 500, 0, 63, 0, 500, 0, 64, 0, 500, 0, 65, 0, 500, 0, 66, 0, 500, 0, 67, 0, 500, 0, 68, 0, 500, 0, 69, 0, 500, 0, 70, 0, 500, 0, 71, 0, 500, 0, 72, 0, 500, 0, 73, 0, 500, 0, 74, 0, 500, 0, 75, 0, 500, 0, 76, 0, 500, 0, 77, 0, 500, 0, 78, 0, 500, 0, 79, 0, 500, 0, 80, 0, 500, 0, 81, 0, 500, 0, 82, 0, 500, 0, 83, 0, 500, 0, 84, 0, 500, 0, 85, 0, 500, 0, 86, 0, 500, 0, 87, 0, 500, 0, 88, 0, 500, 0, 89, 0, 500, 0, 90, 0, 500, 0, 91, 0, 500, 0, 92, 0, 500, 0, 93, 0, 500, 0, 94, 0, 500, 0, 95, 0, 500, 0, 231, 0, 500, 0, 232, 0, 500, 0, 233, 0, 500, 0, 234, 0, 500, 0, 235, 0, 500, 0, 236, 0, 500, 0, 237, 0, 500, 0, 238, 0, 500, 0, 239, 0, 500, 0, 240, 0, 500, 0, 241, 0, 500, 0, 242, 0, 500, 0, 243, 0, 500, 0, 244, 0, 500, 0, 245, 0, 500, 0, 246, 0, 500, 0, 247, 0, 500, 0, 248, 0, 500, 0, 249, 0, 500, 0, 250, 0, 500, 0, 251, 0, 500, 0, 252, 0, 500, 0, 253, 0, 500, 0, 254, 0, 500, 0, 255, 0, 500, 0, 256, 0, 500, 0, 257, 0, 500, 0, 258, 0, 500, 0, 259, 0, 500, 0, 260, 0, 500, 0, 261, 0, 500, 0, 262, 0, 500, 0, 263, 0, 500, 0, 264, 0, 500, 0, 265, 0, 500, 0, 266, 0, 500, 0, 267, 0, 500, 0, 268, 0, 500, 0, 269, 0, 500, 0, 270, 0, 500, 0, 271, 0, 500, 0, 272, 0, 500, 0, 273, 0, 500, 0, 274, 0, 500, 0, 275, 0, 500, 0, 276, 0, 500, 0, 277, 0, 500, 0, 278, 0, 500, 0, 279, 0, 500, 0, 280, 0, 500, 0, 281, 0, 500, 0, 282, 0, 500, 0, 283, 0, 500, 0, 284, 0, 500, 0, 285, 0, 500, 0, 286, 0, 500, 0, 287, 0, 500, 0, 288, 0, 500, 0, 289, 0, 500, 0, 290, 0, 500, 0, 291, 0, 500, 0, 292, 0, 500, 0, 293, 0, 500, 0, 294, 0, 500, 0, 295, 0, 500, 0, 296, 0, 500, 0, 297, 0, 500, 0, 298, 0, 500, 0, 299, 0, 500, 0, 300, 0, 500, 0, 301, 0, 500, 0, 302, 0, 500, 0, 303, 0, 500, 0, 304, 0, 500, 0, 305, 0, 500, 0, 306, 0, 500, 0, 307, 0, 500, 0, 308, 0, 500, 0, 309, 0, 500, 0, 310, 0, 500, 0, 311, 0, 500, 0, 312, 0, 500, 0, 313, 0, 500, 0, 314, 0, 500, 0, 315, 0, 500, 0, 316, 0, 500, 0, 317, 0, 500, 0, 318, 0, 500, 0, 319, 0, 500, 0, 320, 0, 500, 0, 321, 0, 500, 0, 322, 0, 500, 0, 323, 0, 500, 0, 324, 0, 500, 0, 327, 0, 500, 0, 328, 0, 500, 0, 329, 0, 500, 0, 330, 0, 500, 0, 331, 0, 500, 0, 332, 0, 500, 0, 333, 0, 500, 0, 334, 0, 500, 0, 335, 0, 500, 0, 336, 0, 500, 0, 337, 0, 500, 0, 338, 0, 500, 0, 339, 0, 500, 0, 340, 0, 500, 0, 341, 0, 500, 0, 342, 0, 500, 0, 343, 0, 500, 0, 344, 0, 500, 0, 345, 0, 500, 0, 346, 0, 500, 0, 347, 0, 500, 0, 348, 0, 500, 0, 349, 0, 500, 0, 350, 0, 500, 0, 351, 0, 500, 0, 352, 0, 500, 0, 353, 0, 500, 0, 354, 0, 500, 0, 355, 0, 500, 0, 356, 0, 500, 0, 357, 0, 500, 0, 358, 0, 500, 0, 359, 0, 500, 0, 360, 0, 500, 0, 361, 0, 500, 0, 362, 0, 500, 0, 363, 0, 500, 0, 364, 0, 500, 0, 365, 0, 500, 0, 366, 0, 500, 0, 367, 0, 500, 0, 368, 0, 500, 0, 369, 0, 500, 0, 370, 0, 500, 0, 371, 0, 500, 0, 372, 0, 500, 0, 373, 0, 500, 0, 374, 0, 500, 0, 375, 0, 500, 0, 376, 0, 500, 0, 377, 0, 500, 0, 378, 0, 500, 0, 379, 0, 500, 0, 380, 0, 500, 0, 381, 0, 500, 0, 382, 0, 500, 0, 383, 0, 500, 0, 384, 0, 500, 0, 385, 0, 500, 0, 386, 0, 500, 0, 387, 0, 500, 0, 388, 0, 500, 0, 389, 0, 500, 0, 631, 0, 500, 0, -1, 0, 0, 0], ["i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0], ALLOC_STATIC);
STRING_TABLE.__str1287=allocate([68,111,116,117,109,67,104,101,0] /* DotumChe\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str11288=allocate([68,111,116,117,109,67,104,101,44,66,111,108,100,0] /* DotumChe,Bold\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str21289=allocate([68,111,116,117,109,67,104,101,44,73,116,97,108,105,99,0] /* DotumChe,Italic\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str31290=allocate([68,111,116,117,109,67,104,101,44,66,111,108,100,73,116,97,108,105,99,0] /* DotumChe,BoldItalic\ */, "i8", ALLOC_STATIC);
STRING_TABLE.__str41291=allocate([68,111,116,117,109,0] /* Dotum\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str51292=allocate([68,111,116,117,109,44,66,111,108,100,0] /* Dotum,Bold\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str61293=allocate([68,111,116,117,109,44,73,116,97,108,105,99,0] /* Dotum,Italic\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str71294=allocate([68,111,116,117,109,44,66,111,108,100,73,116,97,108,105,99,0] /* Dotum,BoldItalic\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str81295=allocate([66,97,116,97,110,103,67,104,101,0] /* BatangChe\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str91296=allocate([66,97,116,97,110,103,67,104,101,44,66,111,108,100,0] /* BatangChe,Bold\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str101297=allocate([66,97,116,97,110,103,67,104,101,44,73,116,97,108,105,99,0] /* BatangChe,Italic\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str111298=allocate([66,97,116,97,110,103,67,104,101,44,66,111,108,100,73,116,97,108,105,99,0] /* BatangChe,BoldItalic */, "i8", ALLOC_STATIC);
STRING_TABLE.__str121299=allocate([66,97,116,97,110,103,0] /* Batang\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str131300=allocate([66,97,116,97,110,103,44,66,111,108,100,0] /* Batang,Bold\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str141301=allocate([66,97,116,97,110,103,44,73,116,97,108,105,99,0] /* Batang,Italic\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str151302=allocate([66,97,116,97,110,103,44,66,111,108,100,73,116,97,108,105,99,0] /* Batang,BoldItalic\00 */, "i8", ALLOC_STATIC);
_Dotum_W_ARRAY=allocate([1, 0, 333, 0, 2, 0, 333, 0, 3, 0, 416, 0, 4, 0, 625, 0, 5, 0, 500, 0, 6, 0, 916, 0, 7, 0, 708, 0, 8, 0, 291, 0, 9, 0, 375, 0, 10, 0, 375, 0, 11, 0, 583, 0, 12, 0, 582, 0, 13, 0, 375, 0, 14, 0, 589, 0, 15, 0, 375, 0, 16, 0, 416, 0, 17, 0, 583, 0, 18, 0, 583, 0, 19, 0, 583, 0, 20, 0, 583, 0, 21, 0, 583, 0, 22, 0, 583, 0, 23, 0, 583, 0, 24, 0, 583, 0, 25, 0, 583, 0, 26, 0, 583, 0, 27, 0, 339, 0, 28, 0, 339, 0, 29, 0, 625, 0, 30, 0, 583, 0, 31, 0, 625, 0, 32, 0, 583, 0, 34, 0, 666, 0, 35, 0, 679, 0, 36, 0, 720, 0, 37, 0, 724, 0, 38, 0, 628, 0, 39, 0, 599, 0, 40, 0, 750, 0, 41, 0, 722, 0, 42, 0, 257, 0, 43, 0, 484, 0, 44, 0, 656, 0, 45, 0, 541, 0, 46, 0, 808, 0, 47, 0, 697, 0, 48, 0, 750, 0, 49, 0, 642, 0, 50, 0, 750, 0, 51, 0, 667, 0, 52, 0, 638, 0, 53, 0, 583, 0, 54, 0, 724, 0, 55, 0, 601, 0, 56, 0, 892, 0, 57, 0, 603, 0, 58, 0, 601, 0, 59, 0, 603, 0, 60, 0, 500, 0, 61, 0, 958, 0, 62, 0, 500, 0, 63, 0, 625, 0, 64, 0, 500, 0, 65, 0, 332, 0, 66, 0, 583, 0, 67, 0, 599, 0, 68, 0, 558, 0, 69, 0, 603, 0, 70, 0, 558, 0, 71, 0, 343, 0, 72, 0, 597, 0, 73, 0, 560, 0, 74, 0, 228, 0, 75, 0, 228, 0, 76, 0, 509, 0, 77, 0, 230, 0, 78, 0, 916, 0, 79, 0, 568, 0, 80, 0, 599, 0, 81, 0, 601, 0, 82, 0, 603, 0, 83, 0, 320, 0, 84, 0, 515, 0, 85, 0, 312, 0, 86, 0, 554, 0, 87, 0, 474, 0, 88, 0, 724, 0, 89, 0, 478, 0, 90, 0, 480, 0, 91, 0, 482, 0, 92, 0, 500, 0, 93, 0, 500, 0, 94, 0, 500, 0, 95, 0, 791, 0, 104, 0, 332, 0, 107, 0, 500, 0, 109, 0, 500, 0, 110, 0, 687, 0, 114, 0, 291, 0, 115, 0, 291, 0, 116, 0, 458, 0, 117, 0, 458, 0, 130, 0, 833, 0, 131, 0, 833, 0, 132, 0, 833, 0, 133, 0, 833, 0, 134, 0, 833, 0, 135, 0, 833, 0, 136, 0, 911, 0, 138, 0, 405, 0, 139, 0, 335, 0, 140, 0, 563, 0, 146, 0, 625, 0, 147, 0, 625, 0, 151, 0, 562, 0, 153, 0, 833, 0, 155, 0, 562, 0, 160, 0, 937, 0, 164, 0, 889, 0, 165, 0, 889, 0, 167, 0, 914, 0, 169, 0, 914, 0, 172, 0, 750, 0, 173, 0, 750, 0, 178, 0, 500, 0, 182, 0, 375, 0, 191, 0, 718, 0, 199, 0, 333, 0, 201, 0, 437, 0, 202, 0, 375, 0, 203, 0, 437, 0, 204, 0, 312, 0, 205, 0, 317, 0, 206, 0, 333, 0, 207, 0, 312, 0, 208, 0, 416, 0, 209, 0, 583, 0, 212, 0, 812, 0, 213, 0, 687, 0, 214, 0, 562, 0, 222, 0, 750, 0, 224, 0, 792, 0, 226, 0, 843, 0, 244, 0, 562, 0, 245, 0, 562, 0, 246, 0, 562, 0, 247, 0, 750, 0, 254, 0, 687, 0, 471, 0, 666, 0, 472, 0, 708, 0, 473, 0, 594, 0, 474, 0, 705, 0, 475, 0, 666, 0, 476, 0, 625, 0, 477, 0, 750, 0, 478, 0, 791, 0, 479, 0, 291, 0, 480, 0, 708, 0, 481, 0, 666, 0, 482, 0, 875, 0, 483, 0, 750, 0, 484, 0, 750, 0, 485, 0, 791, 0, 486, 0, 702, 0, 487, 0, 666, 0, 488, 0, 674, 0, 489, 0, 583, 0, 490, 0, 625, 0, 491, 0, 770, 0, 492, 0, 625, 0, 493, 0, 794, 0, 494, 0, 750, 0, 495, 0, 625, 0, 496, 0, 563, 0, 497, 0, 562, 0, 498, 0, 571, 0, 499, 0, 562, 0, 500, 0, 500, 0, 501, 0, 625, 0, 502, 0, 687, 0, 503, 0, 375, 0, 504, 0, 562, 0, 505, 0, 687, 0, 506, 0, 567, 0, 507, 0, 500, 0, 508, 0, 500, 0, 509, 0, 625, 0, 510, 0, 687, 0, 511, 0, 625, 0, 512, 0, 625, 0, 513, 0, 583, 0, 514, 0, 583, 0, 515, 0, 625, 0, 516, 0, 583, 0, 517, 0, 731, 0, 518, 0, 750, 0, 590, 0, 500, 0, 643, 0, 750, 0, 666, 0, 937, 0, 667, 0, 751, 0, 668, 0, 403, 0, 669, 0, 750, 0, 670, 0, 750, 0, 671, 0, 583, 0, 672, 0, 583, 0, 673, 0, 791, 0, 674, 0, 934, 0, 675, 0, 375, 0, 676, 0, 666, 0, 677, 0, 583, 0, 678, 0, 750, 0, 748, 0, 500, 0, 751, 0, 500, 0, 752, 0, 500, 0, 753, 0, 562, 0, 754, 0, 561, 0, 755, 0, 562, 0, 756, 0, 562, 0, 757, 0, 812, 0, 758, 0, 625, 0, 759, 0, 625, 0, 760, 0, 583, 0, 761, 0, 250, 0, 762, 0, 500, 0, 763, 0, 562, 0, 764, 0, 312, 0, 765, 0, 250, 0, 766, 0, 625, 0, 767, 0, 875, 0, 768, 0, 625, 0, 769, 0, 625, 0, 770, 0, 333, 0, 771, 0, 625, 0, 772, 0, 687, 0, 842, 0, 375, 0, 843, 0, 322, 0, 844, 0, 322, 0, 846, 0, 500, 0, 1020, 0, 666, 0, 1021, 0, 708, 0, 1022, 0, 708, 0, 1023, 0, 594, 0, 1024, 0, 812, 0, 1025, 0, 666, 0, 1026, 0, 666, 0, 1027, 0, 937, 0, 1028, 0, 583, 0, 1029, 0, 750, 0, 1030, 0, 750, 0, 1031, 0, 708, 0, 1032, 0, 714, 0, 1033, 0, 875, 0, 1034, 0, 750, 0, 1035, 0, 791, 0, 1036, 0, 750, 0, 1037, 0, 666, 0, 1038, 0, 750, 0, 1039, 0, 583, 0, 1040, 0, 500, 0, 1041, 0, 770, 0, 1042, 0, 625, 0, 1043, 0, 742, 0, 1044, 0, 583, 0, 1045, 0, 966, 0, 1046, 0, 966, 0, 1047, 0, 787, 0, 1048, 0, 825, 0, 1049, 0, 666, 0, 1050, 0, 738, 0, 1051, 0, 991, 0, 1052, 0, 708, 0, 1053, 0, 583, 0, 1054, 0, 583, 0, 1055, 0, 610, 0, 1056, 0, 583, 0, 1057, 0, 653, 0, 1058, 0, 583, 0, 1059, 0, 583, 0, 1060, 0, 768, 0, 1061, 0, 563, 0, 1062, 0, 658, 0, 1063, 0, 662, 0, 1064, 0, 562, 0, 1065, 0, 641, 0, 1066, 0, 740, 0, 1067, 0, 640, 0, 1068, 0, 625, 0, 1069, 0, 645, 0, 1070, 0, 625, 0, 1071, 0, 583, 0, 1072, 0, 595, 0, 1073, 0, 500, 0, 1074, 0, 763, 0, 1075, 0, 500, 0, 1076, 0, 619, 0, 1077, 0, 583, 0, 1078, 0, 840, 0, 1079, 0, 838, 0, 1080, 0, 609, 0, 1081, 0, 779, 0, 1082, 0, 512, 0, 1083, 0, 574, 0, 1084, 0, 770, 0, 1085, 0, 581, 0, 8094, 0, 333, 0, 8095, 0, 333, 0, 8096, 0, 416, 0, 8097, 0, 625, 0, 8098, 0, 500, 0, 8099, 0, 916, 0, 8100, 0, 708, 0, 8101, 0, 291, 0, 8102, 0, 375, 0, 8103, 0, 375, 0, 8104, 0, 583, 0, 8105, 0, 582, 0, 8106, 0, 375, 0, 8107, 0, 589, 0, 8108, 0, 375, 0, 8109, 0, 416, 0, 8110, 0, 583, 0, 8111, 0, 583, 0, 8112, 0, 583, 0, 8113, 0, 583, 0, 8114, 0, 583, 0, 8115, 0, 583, 0, 8116, 0, 583, 0, 8117, 0, 583, 0, 8118, 0, 583, 0, 8119, 0, 583, 0, 8120, 0, 339, 0, 8121, 0, 339, 0, 8122, 0, 625, 0, 8123, 0, 583, 0, 8124, 0, 625, 0, 8125, 0, 583, 0, 8127, 0, 666, 0, 8128, 0, 679, 0, 8129, 0, 720, 0, 8130, 0, 724, 0, 8131, 0, 628, 0, 8132, 0, 599, 0, 8133, 0, 750, 0, 8134, 0, 722, 0, 8135, 0, 257, 0, 8136, 0, 484, 0, 8137, 0, 656, 0, 8138, 0, 541, 0, 8139, 0, 808, 0, 8140, 0, 697, 0, 8141, 0, 750, 0, 8142, 0, 642, 0, 8143, 0, 750, 0, 8144, 0, 667, 0, 8145, 0, 638, 0, 8146, 0, 583, 0, 8147, 0, 724, 0, 8148, 0, 601, 0, 8149, 0, 892, 0, 8150, 0, 603, 0, 8151, 0, 601, 0, 8152, 0, 603, 0, 8153, 0, 500, 0, 8154, 0, 958, 0, 8155, 0, 500, 0, 8156, 0, 625, 0, 8157, 0, 500, 0, 8158, 0, 332, 0, 8159, 0, 583, 0, 8160, 0, 599, 0, 8161, 0, 558, 0, 8162, 0, 603, 0, 8163, 0, 558, 0, 8164, 0, 343, 0, 8165, 0, 597, 0, 8166, 0, 560, 0, 8167, 0, 228, 0, 8168, 0, 228, 0, 8169, 0, 509, 0, 8170, 0, 230, 0, 8171, 0, 916, 0, 8172, 0, 568, 0, 8173, 0, 599, 0, 8174, 0, 601, 0, 8175, 0, 603, 0, 8176, 0, 320, 0, 8177, 0, 515, 0, 8178, 0, 312, 0, 8179, 0, 554, 0, 8180, 0, 474, 0, 8181, 0, 724, 0, 8182, 0, 478, 0, 8183, 0, 480, 0, 8184, 0, 482, 0, 8185, 0, 500, 0, 8186, 0, 500, 0, 8187, 0, 500, 0, 8188, 0, 791, 0, -1, 0, 0, 0], ["i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0], ALLOC_STATIC);
_DotumChe_W_ARRAY=allocate([1, 0, 500, 0, 2, 0, 500, 0, 3, 0, 500, 0, 4, 0, 500, 0, 5, 0, 500, 0, 6, 0, 500, 0, 7, 0, 500, 0, 8, 0, 500, 0, 9, 0, 500, 0, 10, 0, 500, 0, 11, 0, 500, 0, 12, 0, 500, 0, 13, 0, 500, 0, 14, 0, 500, 0, 15, 0, 500, 0, 16, 0, 500, 0, 17, 0, 500, 0, 18, 0, 500, 0, 19, 0, 500, 0, 20, 0, 500, 0, 21, 0, 500, 0, 22, 0, 500, 0, 23, 0, 500, 0, 24, 0, 500, 0, 25, 0, 500, 0, 26, 0, 500, 0, 27, 0, 500, 0, 28, 0, 500, 0, 29, 0, 500, 0, 30, 0, 500, 0, 31, 0, 500, 0, 32, 0, 500, 0, 33, 0, 500, 0, 34, 0, 500, 0, 35, 0, 500, 0, 36, 0, 500, 0, 37, 0, 500, 0, 38, 0, 500, 0, 39, 0, 500, 0, 40, 0, 500, 0, 41, 0, 500, 0, 42, 0, 500, 0, 43, 0, 500, 0, 44, 0, 500, 0, 45, 0, 500, 0, 46, 0, 500, 0, 47, 0, 500, 0, 48, 0, 500, 0, 49, 0, 500, 0, 50, 0, 500, 0, 51, 0, 500, 0, 52, 0, 500, 0, 53, 0, 500, 0, 54, 0, 500, 0, 55, 0, 500, 0, 56, 0, 500, 0, 57, 0, 500, 0, 58, 0, 500, 0, 59, 0, 500, 0, 60, 0, 500, 0, 61, 0, 500, 0, 62, 0, 500, 0, 63, 0, 500, 0, 64, 0, 500, 0, 65, 0, 500, 0, 66, 0, 500, 0, 67, 0, 500, 0, 68, 0, 500, 0, 69, 0, 500, 0, 70, 0, 500, 0, 71, 0, 500, 0, 72, 0, 500, 0, 73, 0, 500, 0, 74, 0, 500, 0, 75, 0, 500, 0, 76, 0, 500, 0, 77, 0, 500, 0, 78, 0, 500, 0, 79, 0, 500, 0, 80, 0, 500, 0, 81, 0, 500, 0, 82, 0, 500, 0, 83, 0, 500, 0, 84, 0, 500, 0, 85, 0, 500, 0, 86, 0, 500, 0, 87, 0, 500, 0, 88, 0, 500, 0, 89, 0, 500, 0, 90, 0, 500, 0, 91, 0, 500, 0, 92, 0, 500, 0, 93, 0, 500, 0, 94, 0, 500, 0, 95, 0, 500, 0, 8094, 0, 500, 0, 8095, 0, 500, 0, 8096, 0, 500, 0, 8097, 0, 500, 0, 8098, 0, 500, 0, 8099, 0, 500, 0, 8100, 0, 500, 0, 8101, 0, 500, 0, 8102, 0, 500, 0, 8103, 0, 500, 0, 8104, 0, 500, 0, 8105, 0, 500, 0, 8106, 0, 500, 0, 8107, 0, 500, 0, 8108, 0, 500, 0, 8109, 0, 500, 0, 8110, 0, 500, 0, 8111, 0, 500, 0, 8112, 0, 500, 0, 8113, 0, 500, 0, 8114, 0, 500, 0, 8115, 0, 500, 0, 8116, 0, 500, 0, 8117, 0, 500, 0, 8118, 0, 500, 0, 8119, 0, 500, 0, 8120, 0, 500, 0, 8121, 0, 500, 0, 8122, 0, 500, 0, 8123, 0, 500, 0, 8124, 0, 500, 0, 8125, 0, 500, 0, 8126, 0, 500, 0, 8127, 0, 500, 0, 8128, 0, 500, 0, 8129, 0, 500, 0, 8130, 0, 500, 0, 8131, 0, 500, 0, 8132, 0, 500, 0, 8133, 0, 500, 0, 8134, 0, 500, 0, 8135, 0, 500, 0, 8136, 0, 500, 0, 8137, 0, 500, 0, 8138, 0, 500, 0, 8139, 0, 500, 0, 8140, 0, 500, 0, 8141, 0, 500, 0, 8142, 0, 500, 0, 8143, 0, 500, 0, 8144, 0, 500, 0, 8145, 0, 500, 0, 8146, 0, 500, 0, 8147, 0, 500, 0, 8148, 0, 500, 0, 8149, 0, 500, 0, 8150, 0, 500, 0, 8151, 0, 500, 0, 8152, 0, 500, 0, 8153, 0, 500, 0, 8154, 0, 500, 0, 8155, 0, 500, 0, 8156, 0, 500, 0, 8157, 0, 500, 0, 8158, 0, 500, 0, 8159, 0, 500, 0, 8160, 0, 500, 0, 8161, 0, 500, 0, 8162, 0, 500, 0, 8163, 0, 500, 0, 8164, 0, 500, 0, 8165, 0, 500, 0, 8166, 0, 500, 0, 8167, 0, 500, 0, 8168, 0, 500, 0, 8169, 0, 500, 0, 8170, 0, 500, 0, 8171, 0, 500, 0, 8172, 0, 500, 0, 8173, 0, 500, 0, 8174, 0, 500, 0, 8175, 0, 500, 0, 8176, 0, 500, 0, 8177, 0, 500, 0, 8178, 0, 500, 0, 8179, 0, 500, 0, 8180, 0, 500, 0, 8181, 0, 500, 0, 8182, 0, 500, 0, 8183, 0, 500, 0, 8184, 0, 500, 0, 8185, 0, 500, 0, 8186, 0, 500, 0, 8187, 0, 500, 0, 8188, 0, 500, 0, -1, 0, 0, 0], ["i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0,"i16",0], ALLOC_STATIC);
_REQUIRED_TAGS=allocate(52, "i8", ALLOC_STATIC);
STRING_TABLE.__str1304=allocate([104,101,97,100,0] /* head\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str11305=allocate([103,108,121,102,0] /* glyf\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str21306=allocate([108,111,99,97,0] /* loca\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str31307=allocate([110,97,109,101,0] /* name\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str41308=allocate([79,83,47,50,0] /* OS/2\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str51309=allocate([99,109,97,112,0] /* cmap\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str61310=allocate([99,118,116,32,0] /* cvt \00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str71311=allocate([102,112,103,109,0] /* fpgm\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str81312=allocate([104,104,101,97,0] /* hhea\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str91313=allocate([104,109,116,120,0] /* hmtx\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str101314=allocate([109,97,120,112,0] /* maxp\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str111315=allocate([112,111,115,116,0] /* post\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str121316=allocate([112,114,101,112,0] /* prep\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str131317=allocate([116,116,99,102,0] /* ttcf\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str141318=allocate([82,101,103,117,108,97,114,0] /* Regular\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str151319=allocate([66,111,108,100,0] /* Bold\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str161320=allocate([73,116,97,108,105,99,0] /* Italic\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str1336=allocate([101,101,120,101,99,0] /* eexec\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str11337=allocate([99,108,101,97,114,116,111,109,97,114,107,0] /* cleartomark\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str21338=allocate([83,116,97,114,116,70,111,110,116,77,101,116,114,105,99,115,0] /* StartFontMetrics\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str31339=allocate([70,111,110,116,78,97,109,101,0] /* FontName\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str41340=allocate([87,101,105,103,104,116,0] /* Weight\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str51341=allocate([66,111,108,100,0] /* Bold\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str61342=allocate([73,115,70,105,120,101,100,80,105,116,99,104,0] /* IsFixedPitch\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str71343=allocate([116,114,117,101,0] /* true\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str81344=allocate([73,116,97,108,105,99,65,110,103,108,101,0] /* ItalicAngle\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str91345=allocate([67,104,97,114,97,99,116,101,114,83,101,116,0] /* CharacterSet\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str101346=allocate([70,111,110,116,66,66,111,120,0] /* FontBBox\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str111347=allocate([69,110,99,111,100,105,110,103,83,99,104,101,109,101,0] /* EncodingScheme\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str121348=allocate([67,97,112,72,101,105,103,104,116,0] /* CapHeight\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str131349=allocate([65,115,99,101,110,100,101,114,0] /* Ascender\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str141350=allocate([68,101,115,99,101,110,100,101,114,0] /* Descender\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str151351=allocate([83,84,68,72,87,0] /* STDHW\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str161352=allocate([83,84,68,72,86,0] /* STDHV\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str171353=allocate([83,116,97,114,116,67,104,97,114,77,101,116,114,105,99,115,0] /* StartCharMetrics\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str181354=allocate([67,88,0] /* CX\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str191355=allocate([67,0] /* C\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str201356=allocate([87,88,32,0] /* WX \00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str211357=allocate([78,32,0] /* N \00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str1368=allocate([84,121,112,101,0] /* Type\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str11369=allocate([70,111,110,116,0] /* Font\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str21370=allocate([66,97,115,101,70,111,110,116,0] /* BaseFont\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str31371=allocate([83,117,98,116,121,112,101,0] /* Subtype\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str41372=allocate([84,114,117,101,84,121,112,101,0] /* TrueType\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str51373=allocate([70,105,114,115,116,67,104,97,114,0] /* FirstChar\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str61374=allocate([76,97,115,116,67,104,97,114,0] /* LastChar\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str71375=allocate([77,105,115,115,105,110,103,87,105,100,116,104,0] /* MissingWidth\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str81376=allocate([70,111,110,116,68,101,115,99,114,105,112,116,111,114,0] /* FontDescriptor\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str91377=allocate([65,115,99,101,110,116,0] /* Ascent\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str101378=allocate([68,101,115,99,101,110,116,0] /* Descent\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str111379=allocate([70,108,97,103,115,0] /* Flags\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str121380=allocate([70,111,110,116,66,66,111,120,0] /* FontBBox\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str131381=allocate([70,111,110,116,78,97,109,101,0] /* FontName\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str141382=allocate([73,116,97,108,105,99,65,110,103,108,101,0] /* ItalicAngle\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str151383=allocate([83,116,101,109,86,0] /* StemV\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str161384=allocate([88,72,101,105,103,104,116,0] /* XHeight\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str171385=allocate([67,104,97,114,83,101,116,0] /* CharSet\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str181386=allocate([70,111,110,116,70,105,108,101,50,0] /* FontFile2\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str191387=allocate([76,101,110,103,116,104,49,0] /* Length1\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str201388=allocate([76,101,110,103,116,104,50,0] /* Length2\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str211389=allocate([76,101,110,103,116,104,51,0] /* Length3\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str221390=allocate([87,105,100,116,104,115,0] /* Widths\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str231391=allocate([32,91,10,0] /*  [\0A\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str241392=allocate([10,0] /* \0A\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str251393=allocate([93,10,0] /* ]\0A\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str1398=allocate([84,121,112,101,0] /* Type\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str11399=allocate([70,111,110,116,0] /* Font\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str21400=allocate([66,97,115,101,70,111,110,116,0] /* BaseFont\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str31401=allocate([83,117,98,116,121,112,101,0] /* Subtype\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str41402=allocate([84,121,112,101,49,0] /* Type1\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str51403=allocate([77,105,115,115,105,110,103,87,105,100,116,104,0] /* MissingWidth\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str61404=allocate([47,70,105,114,115,116,67,104,97,114,32,0] /* /FirstChar \00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str71405=allocate([10,0] /* \0A\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str81406=allocate([47,76,97,115,116,67,104,97,114,32,0] /* /LastChar \00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str91407=allocate([87,105,100,116,104,115,0] /* Widths\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str101408=allocate([32,91,10,0] /*  [\0A\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str111409=allocate([93,10,0] /* ]\0A\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str121410=allocate([70,111,110,116,68,101,115,99,114,105,112,116,111,114,0] /* FontDescriptor\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str131411=allocate([65,115,99,101,110,116,0] /* Ascent\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str141412=allocate([68,101,115,99,101,110,116,0] /* Descent\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str151413=allocate([70,108,97,103,115,0] /* Flags\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str161414=allocate([70,111,110,116,66,66,111,120,0] /* FontBBox\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str171415=allocate([70,111,110,116,78,97,109,101,0] /* FontName\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str181416=allocate([73,116,97,108,105,99,65,110,103,108,101,0] /* ItalicAngle\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str191417=allocate([83,116,101,109,86,0] /* StemV\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str201418=allocate([88,72,101,105,103,104,116,0] /* XHeight\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str211419=allocate([67,104,97,114,83,101,116,0] /* CharSet\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str221420=allocate([70,111,110,116,70,105,108,101,0] /* FontFile\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str231421=allocate([76,101,110,103,116,104,49,0] /* Length1\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str241422=allocate([76,101,110,103,116,104,50,0] /* Length2\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str251423=allocate([76,101,110,103,116,104,51,0] /* Length3\00 */, "i8", ALLOC_STATIC);
_HPDF_GState_New_DEF_MATRIX=allocate([1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], ["float",0,0,0,"float",0,0,0,"float",0,0,0,"float",0,0,0,"float",0,0,0,"float",0,0,0], ALLOC_STATIC);
STRING_TABLE.__str1426=allocate([84,121,112,101,0] /* Type\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str11427=allocate([88,79,98,106,101,99,116,0] /* XObject\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str21428=allocate([83,117,98,116,121,112,101,0] /* Subtype\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str31429=allocate([73,109,97,103,101,0] /* Image\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str41430=allocate([67,111,108,111,114,83,112,97,99,101,0] /* ColorSpace\00 */, "i8", ALLOC_STATIC);
_COL_GRAY=allocate(4, "i8", ALLOC_STATIC);
_COL_CMYK=allocate(4, "i8", ALLOC_STATIC);
_COL_RGB=allocate(4, "i8", ALLOC_STATIC);
STRING_TABLE.__str51431=allocate([87,105,100,116,104,0] /* Width\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str61432=allocate([72,101,105,103,104,116,0] /* Height\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str71433=allocate([66,105,116,115,80,101,114,67,111,109,112,111,110,101,110,116,0] /* BitsPerComponent\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str81434=allocate([73,109,97,103,101,77,97,115,107,0] /* ImageMask\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str91435=allocate([77,97,115,107,0] /* Mask\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str101436=allocate([83,77,97,115,107,0] /* SMask\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str111437=allocate([68,101,118,105,99,101,82,71,66,0] /* DeviceRGB\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str121438=allocate([68,101,118,105,99,101,67,77,89,75,0] /* DeviceCMYK\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str131439=allocate([68,101,118,105,99,101,71,114,97,121,0] /* DeviceGray\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str141440=allocate([68,101,99,111,100,101,0] /* Decode\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str1450=allocate([84,121,112,101,0] /* Type\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str11451=allocate([88,79,98,106,101,99,116,0] /* XObject\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str21452=allocate([83,117,98,116,121,112,101,0] /* Subtype\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str31453=allocate([73,109,97,103,101,0] /* Image\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str41454=allocate([49,46,52,46,49,50,0] /* 1.4.12\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str51455=allocate([87,105,100,116,104,0] /* Width\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str61456=allocate([72,101,105,103,104,116,0] /* Height\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str71457=allocate([67,111,108,111,114,83,112,97,99,101,0] /* ColorSpace\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str81458=allocate([68,101,118,105,99,101,71,114,97,121,0] /* DeviceGray\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str91459=allocate([66,105,116,115,80,101,114,67,111,109,112,111,110,101,110,116,0] /* BitsPerComponent\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str101460=allocate([83,77,97,115,107,0] /* SMask\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str111461=allocate([68,101,118,105,99,101,82,71,66,0] /* DeviceRGB\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str121462=allocate([95,70,73,76,69,95,78,65,77,69,0] /* _FILE_NAME\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str131463=allocate([73,110,100,101,120,101,100,0] /* Indexed\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str1466=allocate([68,58,0] /* D:\00 */, "i8", ALLOC_STATIC);
_HPDF_INFO_ATTR_NAMES=allocate(36, "i8", ALLOC_STATIC);
STRING_TABLE.__str11467=allocate([67,114,101,97,116,105,111,110,68,97,116,101,0] /* CreationDate\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str21468=allocate([77,111,100,68,97,116,101,0] /* ModDate\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str31469=allocate([65,117,116,104,111,114,0] /* Author\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str41470=allocate([67,114,101,97,116,111,114,0] /* Creator\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str51471=allocate([80,114,111,100,117,99,101,114,0] /* Producer\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str61472=allocate([84,105,116,108,101,0] /* Title\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str71473=allocate([83,117,98,106,101,99,116,0] /* Subject\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str81474=allocate([75,101,121,119,111,114,100,115,0] /* Keywords\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str1512=allocate([32,82,0] /*  R\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str11513=allocate([110,117,108,108,0] /* null\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str1520=allocate([95,79,80,69,78,69,68,0] /* _OPENED\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str11522=allocate([84,121,112,101,0] /* Type\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str21523=allocate([79,117,116,108,105,110,101,0] /* Outline\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str31524=allocate([84,105,116,108,101,0] /* Title\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str41525=allocate([70,105,114,115,116,0] /* First\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str51526=allocate([76,97,115,116,0] /* Last\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str61527=allocate([80,114,101,118,0] /* Prev\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str71528=allocate([78,101,120,116,0] /* Next\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str81529=allocate([80,97,114,101,110,116,0] /* Parent\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str91530=allocate([68,101,115,116,0] /* Dest\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str101531=allocate([67,111,117,110,116,0] /* Count\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str1540=allocate([83,0] /* S\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str11541=allocate([68,0] /* D\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str21542=allocate([82,0] /* R\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str31543=allocate([114,0] /* r\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str41544=allocate([65,0] /* A\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str51545=allocate([97,0] /* a\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str61546=allocate([80,0] /* P\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str71547=allocate([83,116,0] /* St\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str1550=allocate([32,119,10,0] /*  w\0A\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str11551=allocate([32,74,10,0] /*  J\0A\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str21552=allocate([32,106,10,0] /*  j\0A\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str31553=allocate([32,77,10,0] /*  M\0A\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str41554=allocate([32,100,10,0] /*  d\0A\00 */, "i8", ALLOC_STATIC);
_INIT_MODE=allocate(24, "i8", ALLOC_STATIC);
STRING_TABLE.__str51555=allocate([32,105,10,0] /*  i\0A\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str61556=allocate([32,103,115,10,0] /*  gs\0A\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str71557=allocate([113,10,0] /* q\0A\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str81558=allocate([81,10,0] /* Q\0A\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str91559=allocate([32,99,109,10,0] /*  cm\0A\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str101560=allocate([32,109,10,0] /*  m\0A\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str111561=allocate([32,108,10,0] /*  l\0A\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str121562=allocate([32,99,10,0] /*  c\0A\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str131563=allocate([32,118,10,0] /*  v\0A\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str141564=allocate([32,121,10,0] /*  y\0A\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str151565=allocate([104,10,0] /* h\0A\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str161566=allocate([32,114,101,10,0] /*  re\0A\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str171567=allocate([83,10,0] /* S\0A\00 */, "i8", ALLOC_STATIC);
_INIT_POS=allocate(8, "i8", ALLOC_STATIC);
STRING_TABLE.__str181568=allocate([115,10,0] /* s\0A\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str191569=allocate([102,10,0] /* f\0A\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str201570=allocate([102,42,10,0] /* f_\0A\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str211571=allocate([66,10,0] /* B\0A\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str221572=allocate([66,42,10,0] /* B_\0A\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str231573=allocate([98,10,0] /* b\0A\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str241574=allocate([98,42,10,0] /* b_\0A\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str251575=allocate([110,10,0] /* n\0A\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str261576=allocate([87,10,0] /* W\0A\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str271577=allocate([87,42,10,0] /* W_\0A\00 */, "i8", ALLOC_STATIC);
_HPDF_Page_BeginText_INIT_MATRIX=allocate([1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], ["float",0,0,0,"float",0,0,0,"float",0,0,0,"float",0,0,0,"float",0,0,0,"float",0,0,0], ALLOC_STATIC);
STRING_TABLE.__str281578=allocate([66,84,10,0] /* BT\0A\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str291579=allocate([69,84,10,0] /* ET\0A\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str301580=allocate([32,84,99,10,0] /*  Tc\0A\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str311581=allocate([32,84,119,10,0] /*  Tw\0A\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str321582=allocate([32,84,122,10,0] /*  Tz\0A\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str331583=allocate([32,84,76,10,0] /*  TL\0A\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str341584=allocate([32,84,102,10,0] /*  Tf\0A\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str351585=allocate([32,84,114,10,0] /*  Tr\0A\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str361586=allocate([32,84,115,10,0] /*  Ts\0A\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str371587=allocate([32,84,100,10,0] /*  Td\0A\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str381588=allocate([32,84,68,10,0] /*  TD\0A\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str391589=allocate([32,84,109,10,0] /*  Tm\0A\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str401590=allocate([84,42,10,0] /* T_\0A\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str411591=allocate([32,84,106,10,0] /*  Tj\0A\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str421592=allocate([32,39,10,0] /*  '\0A\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str431593=allocate([32,34,10,0] /*  \22\0A\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str441594=allocate([32,103,10,0] /*  g\0A\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str451595=allocate([32,71,10,0] /*  G\0A\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str461596=allocate([32,114,103,10,0] /*  rg\0A\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str471597=allocate([32,82,71,10,0] /*  RG\0A\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str481598=allocate([32,107,10,0] /*  k\0A\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str491599=allocate([32,75,10,0] /*  K\0A\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str501600=allocate([32,68,111,10,0] /*  Do\0A\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str511601=allocate([84,121,112,101,0] /* Type\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str521602=allocate([84,114,97,110,115,0] /* Trans\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str531603=allocate([68,0] /* D\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str541604=allocate([83,0] /* S\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str551605=allocate([87,105,112,101,0] /* Wipe\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str561606=allocate([68,105,0] /* Di\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str571607=allocate([83,112,108,105,116,0] /* Split\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str581608=allocate([68,109,0] /* Dm\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str591609=allocate([72,0] /* H\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str601610=allocate([77,0] /* M\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str611611=allocate([79,0] /* O\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str621612=allocate([73,0] /* I\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str631613=allocate([86,0] /* V\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str641614=allocate([66,111,120,0] /* Box\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str651615=allocate([66,108,105,110,100,115,0] /* Blinds\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str661616=allocate([68,105,115,115,111,108,118,101,0] /* Dissolve\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str671617=allocate([71,108,105,116,116,101,114,0] /* Glitter\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str681618=allocate([82,0] /* R\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str691619=allocate([68,117,114,0] /* Dur\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str701620=allocate([60,0] /* _\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str711621=allocate([62,0] /* _\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str1623=allocate([84,121,112,101,0] /* Type\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str11624=allocate([80,97,103,101,115,0] /* Pages\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str21625=allocate([75,105,100,115,0] /* Kids\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str31626=allocate([67,111,117,110,116,0] /* Count\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str41627=allocate([80,97,114,101,110,116,0] /* Parent\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str51628=allocate([80,97,103,101,0] /* Page\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str61629=allocate([77,101,100,105,97,66,111,120,0] /* MediaBox\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str71630=allocate([67,111,110,116,101,110,116,115,0] /* Contents\00 */, "i8", ALLOC_STATIC);
_HPDF_INHERITABLE_ENTRIES=allocate(20, "i8", ALLOC_STATIC);
STRING_TABLE.__str81631=allocate([82,101,115,111,117,114,99,101,115,0] /* Resources\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str91632=allocate([70,111,110,116,0] /* Font\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str101633=allocate([70,0] /* F\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str111634=allocate([88,79,98,106,101,99,116,0] /* XObject\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str121635=allocate([88,0] /* X\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str131636=allocate([69,120,116,71,83,116,97,116,101,0] /* ExtGState\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str141637=allocate([69,0] /* E\00 */, "i8", ALLOC_STATIC);
_HPDF_Page_GetTransMatrix_DEF_MATRIX=allocate([1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], ["float",0,0,0,"float",0,0,0,"float",0,0,0,"float",0,0,0,"float",0,0,0,"float",0,0,0], ALLOC_STATIC);
_HPDF_Page_GetTextMatrix_DEF_MATRIX=allocate([1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], ["float",0,0,0,"float",0,0,0,"float",0,0,0,"float",0,0,0,"float",0,0,0,"float",0,0,0], ALLOC_STATIC);
STRING_TABLE.__str151638=allocate([82,111,116,97,116,101,0] /* Rotate\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str161639=allocate([80,90,0] /* PZ\00 */, "i8", ALLOC_STATIC);
_HPDF_PREDEFINED_PAGE_SIZES=allocate([612, 0, 0, 0, 792, 0, 0, 0, 612, 0, 0, 0, 1008, 0, 0, 0, 841.8900146484375, 0, 0, 0, 1199.551025390625, 0, 0, 0, 595.2760009765625, 0, 0, 0, 841.8900146484375, 0, 0, 0, 419.52801513671875, 0, 0, 0, 595.2760009765625, 0, 0, 0, 708.6610107421875, 0, 0, 0, 1000.6300048828125, 0, 0, 0, 498.89801025390625, 0, 0, 0, 708.6610107421875, 0, 0, 0, 522, 0, 0, 0, 756, 0, 0, 0, 288, 0, 0, 0, 432, 0, 0, 0, 288, 0, 0, 0, 576, 0, 0, 0, 360, 0, 0, 0, 504, 0, 0, 0, 297, 0, 0, 0, 684, 0, 0, 0], ["float",0,0,0,"float",0,0,0,"float",0,0,0,"float",0,0,0,"float",0,0,0,"float",0,0,0,"float",0,0,0,"float",0,0,0,"float",0,0,0,"float",0,0,0,"float",0,0,0,"float",0,0,0,"float",0,0,0,"float",0,0,0,"float",0,0,0,"float",0,0,0,"float",0,0,0,"float",0,0,0,"float",0,0,0,"float",0,0,0,"float",0,0,0,"float",0,0,0,"float",0,0,0,"float",0,0,0], ALLOC_STATIC);
STRING_TABLE.__str171640=allocate([65,110,110,111,116,115,0] /* Annots\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str181641=allocate([80,114,111,99,83,101,116,0] /* ProcSet\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str191642=allocate([80,68,70,0] /* PDF\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str201643=allocate([84,101,120,116,0] /* Text\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str211644=allocate([73,109,97,103,101,66,0] /* ImageB\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str221645=allocate([73,109,97,103,101,67,0] /* ImageC\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str231646=allocate([73,109,97,103,101,73,0] /* ImageI\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str241647=allocate([67,114,111,112,66,111,120,0] /* CropBox\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str1679=allocate([49,46,50,46,53,0] /* 1.2.5\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str11680=allocate([114,98,0] /* rb\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str21681=allocate([119,98,0] /* wb\00 */, "i8", ALLOC_STATIC);
STRING_TABLE._UNICODE_HEADER=allocate([254,255] /* \FE\FF */, "i8", ALLOC_STATIC);
STRING_TABLE.__str1732=allocate([84,121,112,101,0] /* Type\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str21734=allocate([83,117,98,116,121,112,101,0] /* Subtype\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str41736=allocate([51,68,0] /* 3D\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str51737=allocate([84,89,80,69,0] /* TYPE\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str61738=allocate([51,68,86,105,101,119,0] /* 3DView\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str71739=allocate([88,78,0] /* XN\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str81740=allocate([73,78,0] /* IN\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str91741=allocate([86,65,0] /* VA\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str101742=allocate([68,86,0] /* DV\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str111743=allocate([78,65,0] /* NA\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str121744=allocate([51,68,78,111,100,101,0] /* 3DNode\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str131745=allocate([78,0] /* N\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str141746=allocate([79,0] /* O\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str151747=allocate([86,0] /* V\00 */, "i8", ALLOC_STATIC);
_HPDF_3DView_SetLighting_schemes=allocate(48, "i8", ALLOC_STATIC);
STRING_TABLE.__str161748=allocate([65,114,116,119,111,114,107,0] /* Artwork\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str171749=allocate([78,111,110,101,0] /* None\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str181750=allocate([87,104,105,116,101,0] /* White\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str191751=allocate([68,97,121,0] /* Day\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str201752=allocate([78,105,103,104,116,0] /* Night\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str211753=allocate([72,97,114,100,0] /* Hard\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str221754=allocate([80,114,105,109,97,114,121,0] /* Primary\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str231755=allocate([66,108,117,101,0] /* Blue\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str241756=allocate([82,101,100,0] /* Red\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str251757=allocate([67,117,98,101,0] /* Cube\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str261758=allocate([67,65,68,0] /* CAD\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str271759=allocate([72,101,97,100,108,97,109,112,0] /* Headlamp\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str281760=allocate([51,68,76,105,103,104,116,105,110,103,83,99,104,101,109,101,0] /* 3DLightingScheme\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str291761=allocate([76,83,0] /* LS\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str301762=allocate([51,68,66,71,0] /* 3DBG\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str311763=allocate([67,0] /* C\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str321764=allocate([66,71,0] /* BG\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str331765=allocate([80,0] /* P\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str341766=allocate([80,83,0] /* PS\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str351767=allocate([77,105,110,0] /* Min\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str361768=allocate([70,79,86,0] /* FOV\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str371769=allocate([79,83,0] /* OS\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str381770=allocate([77,83,0] /* MS\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str391771=allocate([77,0] /* M\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str401772=allocate([67,50,87,0] /* C2W\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str411773=allocate([67,79,0] /* CO\00 */, "i8", ALLOC_STATIC);
STRING_TABLE._u3d=allocate([85,51,68,0] /* U3D\00 */, "i8", ALLOC_STATIC);
STRING_TABLE._prc=allocate([80,82,67,0] /* PRC\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str1803=allocate([32,111,98,106,10,0] /*  obj\0A\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str11804=allocate([10,101,110,100,111,98,106,10,0] /* \0Aendobj\0A\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str21805=allocate([120,114,101,102,10,0] /* xref\0A\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str31806=allocate([10,0] /* \0A\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str41807=allocate([83,105,122,101,0] /* Size\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str51808=allocate([80,114,101,118,0] /* Prev\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str61809=allocate([116,114,97,105,108,101,114,10,0] /* trailer\0A\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str71810=allocate([10,115,116,97,114,116,120,114,101,102,10,0] /* \0Astartxref\0A\00 */, "i8", ALLOC_STATIC);
STRING_TABLE.__str81811=allocate([10,37,37,69,79,70,10,0] /* \0A%%EOF\0A\00 */, "i8", ALLOC_STATIC);
__gm_=allocate(468, "i8", ALLOC_STATIC);
_mparams=allocate(24, "i8", ALLOC_STATIC);
HEAP32[((_static_l_desc)>>2)]=((_static_ltree)|0);
HEAP32[(((_static_l_desc)+(4))>>2)]=((_extra_lbits)|0);
HEAP32[((_static_d_desc)>>2)]=((_static_dtree)|0);
HEAP32[(((_static_d_desc)+(4))>>2)]=((_extra_dbits)|0);
HEAP32[(((_static_bl_desc)+(4))>>2)]=((_extra_blbits)|0);
HEAP32[((_z_errmsg)>>2)]=((STRING_TABLE.__str75)|0);
HEAP32[(((_z_errmsg)+(4))>>2)]=((STRING_TABLE.__str176)|0);
HEAP32[(((_z_errmsg)+(8))>>2)]=((__str277)|0);
HEAP32[(((_z_errmsg)+(12))>>2)]=((STRING_TABLE.__str378)|0);
HEAP32[(((_z_errmsg)+(16))>>2)]=((STRING_TABLE.__str479)|0);
HEAP32[(((_z_errmsg)+(20))>>2)]=((STRING_TABLE.__str580)|0);
HEAP32[(((_z_errmsg)+(24))>>2)]=((STRING_TABLE.__str681)|0);
HEAP32[(((_z_errmsg)+(28))>>2)]=((STRING_TABLE.__str782)|0);
HEAP32[(((_z_errmsg)+(32))>>2)]=((STRING_TABLE.__str883)|0);
HEAP32[(((_z_errmsg)+(36))>>2)]=((__str277)|0);
HEAP32[((_HPDF_ANNOT_TYPE_NAMES)>>2)]=((STRING_TABLE.__str36546)|0);
HEAP32[(((_HPDF_ANNOT_TYPE_NAMES)+(4))>>2)]=((STRING_TABLE.__str37547)|0);
HEAP32[(((_HPDF_ANNOT_TYPE_NAMES)+(8))>>2)]=((STRING_TABLE.__str38548)|0);
HEAP32[(((_HPDF_ANNOT_TYPE_NAMES)+(12))>>2)]=((STRING_TABLE.__str39549)|0);
HEAP32[(((_HPDF_ANNOT_TYPE_NAMES)+(16))>>2)]=((STRING_TABLE.__str40550)|0);
HEAP32[(((_HPDF_ANNOT_TYPE_NAMES)+(20))>>2)]=((STRING_TABLE.__str41551)|0);
HEAP32[(((_HPDF_ANNOT_TYPE_NAMES)+(24))>>2)]=((STRING_TABLE.__str42552)|0);
HEAP32[(((_HPDF_ANNOT_TYPE_NAMES)+(28))>>2)]=((STRING_TABLE.__str43553)|0);
HEAP32[(((_HPDF_ANNOT_TYPE_NAMES)+(32))>>2)]=((STRING_TABLE.__str44554)|0);
HEAP32[(((_HPDF_ANNOT_TYPE_NAMES)+(36))>>2)]=((STRING_TABLE.__str45555)|0);
HEAP32[(((_HPDF_ANNOT_TYPE_NAMES)+(40))>>2)]=((STRING_TABLE.__str46556)|0);
HEAP32[(((_HPDF_ANNOT_TYPE_NAMES)+(44))>>2)]=((STRING_TABLE.__str47557)|0);
HEAP32[(((_HPDF_ANNOT_TYPE_NAMES)+(48))>>2)]=((STRING_TABLE.__str48558)|0);
HEAP32[(((_HPDF_ANNOT_TYPE_NAMES)+(52))>>2)]=((STRING_TABLE.__str49559)|0);
HEAP32[((_HPDF_ANNOT_ICON_NAMES_NAMES)>>2)]=((STRING_TABLE.__str29539)|0);
HEAP32[(((_HPDF_ANNOT_ICON_NAMES_NAMES)+(4))>>2)]=((STRING_TABLE.__str30540)|0);
HEAP32[(((_HPDF_ANNOT_ICON_NAMES_NAMES)+(8))>>2)]=((STRING_TABLE.__str31541)|0);
HEAP32[(((_HPDF_ANNOT_ICON_NAMES_NAMES)+(12))>>2)]=((STRING_TABLE.__str32542)|0);
HEAP32[(((_HPDF_ANNOT_ICON_NAMES_NAMES)+(16))>>2)]=((STRING_TABLE.__str33543)|0);
HEAP32[(((_HPDF_ANNOT_ICON_NAMES_NAMES)+(20))>>2)]=((STRING_TABLE.__str34544)|0);
HEAP32[(((_HPDF_ANNOT_ICON_NAMES_NAMES)+(24))>>2)]=((STRING_TABLE.__str35545)|0);
HEAP32[((_HPDF_PAGE_LAYOUT_NAMES)>>2)]=((STRING_TABLE.__str20594)|0);
HEAP32[(((_HPDF_PAGE_LAYOUT_NAMES)+(4))>>2)]=((STRING_TABLE.__str21595)|0);
HEAP32[(((_HPDF_PAGE_LAYOUT_NAMES)+(8))>>2)]=((STRING_TABLE.__str22596)|0);
HEAP32[(((_HPDF_PAGE_LAYOUT_NAMES)+(12))>>2)]=((STRING_TABLE.__str23597)|0);
HEAP32[((_HPDF_PAGE_MODE_NAMES)>>2)]=((STRING_TABLE.__str14588)|0);
HEAP32[(((_HPDF_PAGE_MODE_NAMES)+(4))>>2)]=((STRING_TABLE.__str15589)|0);
HEAP32[(((_HPDF_PAGE_MODE_NAMES)+(8))>>2)]=((STRING_TABLE.__str16590)|0);
HEAP32[(((_HPDF_PAGE_MODE_NAMES)+(12))>>2)]=((STRING_TABLE.__str17591)|0);
HEAP32[(((_HPDF_PAGE_MODE_NAMES)+(16))>>2)]=((STRING_TABLE.__str18592)|0);
HEAP32[(((_HPDF_PAGE_MODE_NAMES)+(20))>>2)]=((STRING_TABLE.__str19593)|0);
HEAP32[((_HPDF_DESTINATION_TYPE_NAMES)>>2)]=((STRING_TABLE.__str598)|0);
HEAP32[(((_HPDF_DESTINATION_TYPE_NAMES)+(4))>>2)]=((STRING_TABLE.__str1599)|0);
HEAP32[(((_HPDF_DESTINATION_TYPE_NAMES)+(8))>>2)]=((STRING_TABLE.__str2600)|0);
HEAP32[(((_HPDF_DESTINATION_TYPE_NAMES)+(12))>>2)]=((STRING_TABLE.__str3601)|0);
HEAP32[(((_HPDF_DESTINATION_TYPE_NAMES)+(16))>>2)]=((STRING_TABLE.__str4602)|0);
HEAP32[(((_HPDF_DESTINATION_TYPE_NAMES)+(20))>>2)]=((STRING_TABLE.__str5603)|0);
HEAP32[(((_HPDF_DESTINATION_TYPE_NAMES)+(24))>>2)]=((STRING_TABLE.__str6604)|0);
HEAP32[(((_HPDF_DESTINATION_TYPE_NAMES)+(28))>>2)]=((STRING_TABLE.__str7605)|0);
HEAP32[((_HPDF_VERSION_STR)>>2)]=((STRING_TABLE.__str10640)|0);
HEAP32[(((_HPDF_VERSION_STR)+(4))>>2)]=((STRING_TABLE.__str11641)|0);
HEAP32[(((_HPDF_VERSION_STR)+(8))>>2)]=((STRING_TABLE.__str12642)|0);
HEAP32[(((_HPDF_VERSION_STR)+(12))>>2)]=((STRING_TABLE.__str13643)|0);
HEAP32[(((_HPDF_VERSION_STR)+(16))>>2)]=((STRING_TABLE.__str14644)|0);
HEAP32[(((_HPDF_VERSION_STR)+(20))>>2)]=((STRING_TABLE.__str15645)|0);
HEAP32[((_HPDF_BUILTIN_ENCODINGS)>>2)]=((STRING_TABLE.__str3652)|0);
HEAP32[(((_HPDF_BUILTIN_ENCODINGS)+(12))>>2)]=((STRING_TABLE.__str649)|0);
HEAP32[(((_HPDF_BUILTIN_ENCODINGS)+(24))>>2)]=((STRING_TABLE.__str2651)|0);
HEAP32[(((_HPDF_BUILTIN_ENCODINGS)+(36))>>2)]=((STRING_TABLE.__str1650)|0);
HEAP32[(((_HPDF_BUILTIN_ENCODINGS)+(48))>>2)]=((STRING_TABLE.__str1049)|0);
HEAP32[(((_HPDF_BUILTIN_ENCODINGS)+(56))>>2)]=((_HPDF_UNICODE_MAP_ISO8859_2)|0);
HEAP32[(((_HPDF_BUILTIN_ENCODINGS)+(60))>>2)]=((STRING_TABLE.__str1050)|0);
HEAP32[(((_HPDF_BUILTIN_ENCODINGS)+(68))>>2)]=((_HPDF_UNICODE_MAP_ISO8859_3)|0);
HEAP32[(((_HPDF_BUILTIN_ENCODINGS)+(72))>>2)]=((STRING_TABLE.__str1051)|0);
HEAP32[(((_HPDF_BUILTIN_ENCODINGS)+(80))>>2)]=((_HPDF_UNICODE_MAP_ISO8859_4)|0);
HEAP32[(((_HPDF_BUILTIN_ENCODINGS)+(84))>>2)]=((STRING_TABLE.__str1052)|0);
HEAP32[(((_HPDF_BUILTIN_ENCODINGS)+(92))>>2)]=((_HPDF_UNICODE_MAP_ISO8859_5)|0);
HEAP32[(((_HPDF_BUILTIN_ENCODINGS)+(96))>>2)]=((STRING_TABLE.__str1053)|0);
HEAP32[(((_HPDF_BUILTIN_ENCODINGS)+(104))>>2)]=((_HPDF_UNICODE_MAP_ISO8859_6)|0);
HEAP32[(((_HPDF_BUILTIN_ENCODINGS)+(108))>>2)]=((STRING_TABLE.__str1054)|0);
HEAP32[(((_HPDF_BUILTIN_ENCODINGS)+(116))>>2)]=((_HPDF_UNICODE_MAP_ISO8859_7)|0);
HEAP32[(((_HPDF_BUILTIN_ENCODINGS)+(120))>>2)]=((STRING_TABLE.__str1055)|0);
HEAP32[(((_HPDF_BUILTIN_ENCODINGS)+(128))>>2)]=((_HPDF_UNICODE_MAP_ISO8859_8)|0);
HEAP32[(((_HPDF_BUILTIN_ENCODINGS)+(132))>>2)]=((STRING_TABLE.__str1056)|0);
HEAP32[(((_HPDF_BUILTIN_ENCODINGS)+(140))>>2)]=((_HPDF_UNICODE_MAP_ISO8859_9)|0);
HEAP32[(((_HPDF_BUILTIN_ENCODINGS)+(144))>>2)]=((STRING_TABLE.__str1057)|0);
HEAP32[(((_HPDF_BUILTIN_ENCODINGS)+(152))>>2)]=((_HPDF_UNICODE_MAP_ISO8859_10)|0);
HEAP32[(((_HPDF_BUILTIN_ENCODINGS)+(156))>>2)]=((STRING_TABLE.__str1058)|0);
HEAP32[(((_HPDF_BUILTIN_ENCODINGS)+(164))>>2)]=((_HPDF_UNICODE_MAP_ISO8859_11)|0);
HEAP32[(((_HPDF_BUILTIN_ENCODINGS)+(168))>>2)]=((STRING_TABLE.__str1059)|0);
HEAP32[(((_HPDF_BUILTIN_ENCODINGS)+(176))>>2)]=((_HPDF_UNICODE_MAP_ISO8859_13)|0);
HEAP32[(((_HPDF_BUILTIN_ENCODINGS)+(180))>>2)]=((STRING_TABLE.__str1060)|0);
HEAP32[(((_HPDF_BUILTIN_ENCODINGS)+(188))>>2)]=((_HPDF_UNICODE_MAP_ISO8859_14)|0);
HEAP32[(((_HPDF_BUILTIN_ENCODINGS)+(192))>>2)]=((STRING_TABLE.__str1061)|0);
HEAP32[(((_HPDF_BUILTIN_ENCODINGS)+(200))>>2)]=((_HPDF_UNICODE_MAP_ISO8859_15)|0);
HEAP32[(((_HPDF_BUILTIN_ENCODINGS)+(204))>>2)]=((STRING_TABLE.__str1062)|0);
HEAP32[(((_HPDF_BUILTIN_ENCODINGS)+(212))>>2)]=((_HPDF_UNICODE_MAP_ISO8859_16)|0);
HEAP32[(((_HPDF_BUILTIN_ENCODINGS)+(216))>>2)]=((STRING_TABLE.__str1063)|0);
HEAP32[(((_HPDF_BUILTIN_ENCODINGS)+(224))>>2)]=((_HPDF_UNICODE_MAP_CP1250)|0);
HEAP32[(((_HPDF_BUILTIN_ENCODINGS)+(228))>>2)]=((STRING_TABLE.__str1064)|0);
HEAP32[(((_HPDF_BUILTIN_ENCODINGS)+(236))>>2)]=((_HPDF_UNICODE_MAP_CP1251)|0);
HEAP32[(((_HPDF_BUILTIN_ENCODINGS)+(240))>>2)]=((STRING_TABLE.__str1065)|0);
HEAP32[(((_HPDF_BUILTIN_ENCODINGS)+(248))>>2)]=((_HPDF_UNICODE_MAP_CP1252)|0);
HEAP32[(((_HPDF_BUILTIN_ENCODINGS)+(252))>>2)]=((STRING_TABLE.__str1066)|0);
HEAP32[(((_HPDF_BUILTIN_ENCODINGS)+(260))>>2)]=((_HPDF_UNICODE_MAP_CP1253)|0);
HEAP32[(((_HPDF_BUILTIN_ENCODINGS)+(264))>>2)]=((STRING_TABLE.__str1067)|0);
HEAP32[(((_HPDF_BUILTIN_ENCODINGS)+(272))>>2)]=((_HPDF_UNICODE_MAP_CP1254)|0);
HEAP32[(((_HPDF_BUILTIN_ENCODINGS)+(276))>>2)]=((STRING_TABLE.__str1068)|0);
HEAP32[(((_HPDF_BUILTIN_ENCODINGS)+(284))>>2)]=((_HPDF_UNICODE_MAP_CP1255)|0);
HEAP32[(((_HPDF_BUILTIN_ENCODINGS)+(288))>>2)]=((STRING_TABLE.__str1069)|0);
HEAP32[(((_HPDF_BUILTIN_ENCODINGS)+(296))>>2)]=((_HPDF_UNICODE_MAP_CP1256)|0);
HEAP32[(((_HPDF_BUILTIN_ENCODINGS)+(300))>>2)]=((STRING_TABLE.__str1070)|0);
HEAP32[(((_HPDF_BUILTIN_ENCODINGS)+(308))>>2)]=((_HPDF_UNICODE_MAP_CP1257)|0);
HEAP32[(((_HPDF_BUILTIN_ENCODINGS)+(312))>>2)]=((STRING_TABLE.__str1071)|0);
HEAP32[(((_HPDF_BUILTIN_ENCODINGS)+(320))>>2)]=((_HPDF_UNICODE_MAP_CP1258)|0);
HEAP32[(((_HPDF_BUILTIN_ENCODINGS)+(324))>>2)]=((STRING_TABLE.__str1072)|0);
HEAP32[(((_HPDF_BUILTIN_ENCODINGS)+(332))>>2)]=((_HPDF_UNICODE_MAP_KOI8_R)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4))>>2)]=((STRING_TABLE.__str9658)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(12))>>2)]=((STRING_TABLE.__str10659)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(20))>>2)]=((STRING_TABLE.__str11660)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(28))>>2)]=((STRING_TABLE.__str12661)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(36))>>2)]=((STRING_TABLE.__str13662)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(44))>>2)]=((STRING_TABLE.__str14663)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(52))>>2)]=((STRING_TABLE.__str15664)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(60))>>2)]=((STRING_TABLE.__str16665)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(68))>>2)]=((STRING_TABLE.__str17666)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(76))>>2)]=((STRING_TABLE.__str18667)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(84))>>2)]=((STRING_TABLE.__str19668)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(92))>>2)]=((STRING_TABLE.__str20669)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(100))>>2)]=((STRING_TABLE.__str21670)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(108))>>2)]=((STRING_TABLE.__str22671)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(116))>>2)]=((STRING_TABLE.__str23672)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(124))>>2)]=((STRING_TABLE.__str24673)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(132))>>2)]=((STRING_TABLE.__str25674)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(140))>>2)]=((STRING_TABLE.__str26675)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(148))>>2)]=((STRING_TABLE.__str27676)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(156))>>2)]=((STRING_TABLE.__str28677)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(164))>>2)]=((STRING_TABLE.__str29678)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(172))>>2)]=((STRING_TABLE.__str30679)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(180))>>2)]=((STRING_TABLE.__str31680)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(188))>>2)]=((STRING_TABLE.__str32681)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(196))>>2)]=((STRING_TABLE.__str33682)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(204))>>2)]=((STRING_TABLE.__str34683)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(212))>>2)]=((STRING_TABLE.__str35684)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(220))>>2)]=((STRING_TABLE.__str36685)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(228))>>2)]=((STRING_TABLE.__str37686)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(236))>>2)]=((STRING_TABLE.__str38687)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(244))>>2)]=((STRING_TABLE.__str39688)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(252))>>2)]=((STRING_TABLE.__str40689)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(260))>>2)]=((STRING_TABLE.__str41690)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(268))>>2)]=((STRING_TABLE.__str42691)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(276))>>2)]=((STRING_TABLE.__str43692)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(284))>>2)]=((STRING_TABLE.__str44693)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(292))>>2)]=((STRING_TABLE.__str45694)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(300))>>2)]=((STRING_TABLE.__str46695)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(308))>>2)]=((STRING_TABLE.__str47696)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(316))>>2)]=((STRING_TABLE.__str48697)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(324))>>2)]=((STRING_TABLE.__str49698)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(332))>>2)]=((STRING_TABLE.__str50699)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(340))>>2)]=((STRING_TABLE.__str51700)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(348))>>2)]=((STRING_TABLE.__str52701)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(356))>>2)]=((STRING_TABLE.__str53702)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(364))>>2)]=((STRING_TABLE.__str54703)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(372))>>2)]=((STRING_TABLE.__str55704)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(380))>>2)]=((STRING_TABLE.__str56705)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(388))>>2)]=((STRING_TABLE.__str57706)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(396))>>2)]=((STRING_TABLE.__str58707)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(404))>>2)]=((STRING_TABLE.__str59708)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(412))>>2)]=((STRING_TABLE.__str60709)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(420))>>2)]=((STRING_TABLE.__str61710)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(428))>>2)]=((STRING_TABLE.__str62711)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(436))>>2)]=((STRING_TABLE.__str63712)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(444))>>2)]=((STRING_TABLE.__str64713)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(452))>>2)]=((STRING_TABLE.__str65714)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(460))>>2)]=((STRING_TABLE.__str66715)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(468))>>2)]=((STRING_TABLE.__str67716)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(476))>>2)]=((STRING_TABLE.__str68717)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(484))>>2)]=((STRING_TABLE.__str69718)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(492))>>2)]=((STRING_TABLE.__str70719)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(500))>>2)]=((STRING_TABLE.__str71720)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(508))>>2)]=((STRING_TABLE.__str72721)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(516))>>2)]=((STRING_TABLE.__str73722)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(524))>>2)]=((STRING_TABLE.__str74723)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(532))>>2)]=((STRING_TABLE.__str75724)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(540))>>2)]=((STRING_TABLE.__str76725)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(548))>>2)]=((STRING_TABLE.__str77726)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(556))>>2)]=((STRING_TABLE.__str78727)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(564))>>2)]=((STRING_TABLE.__str79728)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(572))>>2)]=((STRING_TABLE.__str80729)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(580))>>2)]=((STRING_TABLE.__str81730)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(588))>>2)]=((STRING_TABLE.__str82731)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(596))>>2)]=((STRING_TABLE.__str83732)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(604))>>2)]=((STRING_TABLE.__str84733)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(612))>>2)]=((STRING_TABLE.__str85734)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(620))>>2)]=((STRING_TABLE.__str86735)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(628))>>2)]=((STRING_TABLE.__str87736)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(636))>>2)]=((STRING_TABLE.__str88737)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(644))>>2)]=((STRING_TABLE.__str89738)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(652))>>2)]=((STRING_TABLE.__str90739)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(660))>>2)]=((STRING_TABLE.__str91740)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(668))>>2)]=((STRING_TABLE.__str92741)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(676))>>2)]=((STRING_TABLE.__str93742)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(684))>>2)]=((STRING_TABLE.__str94743)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(692))>>2)]=((STRING_TABLE.__str95744)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(700))>>2)]=((STRING_TABLE.__str96745)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(708))>>2)]=((STRING_TABLE.__str97746)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(716))>>2)]=((STRING_TABLE.__str98747)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(724))>>2)]=((STRING_TABLE.__str99748)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(732))>>2)]=((STRING_TABLE.__str100749)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(740))>>2)]=((STRING_TABLE.__str101750)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(748))>>2)]=((STRING_TABLE.__str102751)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(756))>>2)]=((STRING_TABLE.__str103752)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(764))>>2)]=((STRING_TABLE.__str104753)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(772))>>2)]=((STRING_TABLE.__str10659)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(780))>>2)]=((STRING_TABLE.__str105754)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(788))>>2)]=((STRING_TABLE.__str106755)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(796))>>2)]=((STRING_TABLE.__str107756)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(804))>>2)]=((STRING_TABLE.__str108757)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(812))>>2)]=((STRING_TABLE.__str109758)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(820))>>2)]=((STRING_TABLE.__str110759)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(828))>>2)]=((STRING_TABLE.__str111760)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(836))>>2)]=((STRING_TABLE.__str112761)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(844))>>2)]=((STRING_TABLE.__str113762)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(852))>>2)]=((STRING_TABLE.__str114763)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(860))>>2)]=((STRING_TABLE.__str115764)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(868))>>2)]=((STRING_TABLE.__str116765)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(876))>>2)]=((STRING_TABLE.__str23672)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(884))>>2)]=((STRING_TABLE.__str117766)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(892))>>2)]=((STRING_TABLE.__str118767)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(900))>>2)]=((STRING_TABLE.__str119768)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(908))>>2)]=((STRING_TABLE.__str120769)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(916))>>2)]=((STRING_TABLE.__str121770)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(924))>>2)]=((STRING_TABLE.__str122771)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(932))>>2)]=((STRING_TABLE.__str123772)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(940))>>2)]=((STRING_TABLE.__str124773)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(948))>>2)]=((STRING_TABLE.__str125774)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(956))>>2)]=((STRING_TABLE.__str126775)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(964))>>2)]=((STRING_TABLE.__str127776)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(972))>>2)]=((STRING_TABLE.__str128777)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(980))>>2)]=((STRING_TABLE.__str129778)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(988))>>2)]=((STRING_TABLE.__str130779)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(996))>>2)]=((STRING_TABLE.__str131780)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1004))>>2)]=((STRING_TABLE.__str132781)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1012))>>2)]=((STRING_TABLE.__str133782)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1020))>>2)]=((STRING_TABLE.__str134783)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1028))>>2)]=((STRING_TABLE.__str135784)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1036))>>2)]=((STRING_TABLE.__str136785)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1044))>>2)]=((STRING_TABLE.__str137786)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1052))>>2)]=((STRING_TABLE.__str138787)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1060))>>2)]=((STRING_TABLE.__str139788)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1068))>>2)]=((STRING_TABLE.__str140789)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1076))>>2)]=((STRING_TABLE.__str141790)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1084))>>2)]=((STRING_TABLE.__str142791)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1092))>>2)]=((STRING_TABLE.__str143)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1100))>>2)]=((STRING_TABLE.__str144)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1108))>>2)]=((STRING_TABLE.__str145)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1116))>>2)]=((STRING_TABLE.__str146)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1124))>>2)]=((STRING_TABLE.__str147)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1132))>>2)]=((STRING_TABLE.__str148792)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1140))>>2)]=((STRING_TABLE.__str149)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1148))>>2)]=((STRING_TABLE.__str150)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1156))>>2)]=((STRING_TABLE.__str151)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1164))>>2)]=((STRING_TABLE.__str152)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1172))>>2)]=((STRING_TABLE.__str153)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1180))>>2)]=((STRING_TABLE.__str154)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1188))>>2)]=((STRING_TABLE.__str155)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1196))>>2)]=((STRING_TABLE.__str156)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1204))>>2)]=((STRING_TABLE.__str157)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1212))>>2)]=((STRING_TABLE.__str158)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1220))>>2)]=((STRING_TABLE.__str159)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1228))>>2)]=((STRING_TABLE.__str160)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1236))>>2)]=((STRING_TABLE.__str161)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1244))>>2)]=((STRING_TABLE.__str162)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1252))>>2)]=((STRING_TABLE.__str163)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1260))>>2)]=((STRING_TABLE.__str164793)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1268))>>2)]=((STRING_TABLE.__str165)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1276))>>2)]=((STRING_TABLE.__str166)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1284))>>2)]=((STRING_TABLE.__str167)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1292))>>2)]=((STRING_TABLE.__str168)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1300))>>2)]=((STRING_TABLE.__str169)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1308))>>2)]=((STRING_TABLE.__str170794)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1316))>>2)]=((STRING_TABLE.__str171)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1324))>>2)]=((STRING_TABLE.__str172)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1332))>>2)]=((STRING_TABLE.__str173)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1340))>>2)]=((STRING_TABLE.__str174)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1348))>>2)]=((STRING_TABLE.__str175)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1356))>>2)]=((STRING_TABLE.__str176795)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1364))>>2)]=((STRING_TABLE.__str177)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1372))>>2)]=((STRING_TABLE.__str178)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1380))>>2)]=((STRING_TABLE.__str179)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1388))>>2)]=((STRING_TABLE.__str180)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1396))>>2)]=((STRING_TABLE.__str181)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1404))>>2)]=((STRING_TABLE.__str182)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1412))>>2)]=((STRING_TABLE.__str183)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1420))>>2)]=((STRING_TABLE.__str184)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1428))>>2)]=((STRING_TABLE.__str185)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1436))>>2)]=((STRING_TABLE.__str186)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1444))>>2)]=((STRING_TABLE.__str187)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1452))>>2)]=((STRING_TABLE.__str188)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1460))>>2)]=((STRING_TABLE.__str189)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1468))>>2)]=((STRING_TABLE.__str190)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1476))>>2)]=((STRING_TABLE.__str191)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1484))>>2)]=((STRING_TABLE.__str192796)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1492))>>2)]=((STRING_TABLE.__str193797)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1500))>>2)]=((STRING_TABLE.__str194)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1508))>>2)]=((STRING_TABLE.__str195)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1516))>>2)]=((STRING_TABLE.__str196)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1524))>>2)]=((STRING_TABLE.__str197)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1532))>>2)]=((STRING_TABLE.__str198)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1540))>>2)]=((STRING_TABLE.__str199)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1548))>>2)]=((STRING_TABLE.__str200)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1556))>>2)]=((STRING_TABLE.__str201)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1564))>>2)]=((STRING_TABLE.__str202)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1572))>>2)]=((STRING_TABLE.__str203)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1580))>>2)]=((STRING_TABLE.__str204)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1588))>>2)]=((STRING_TABLE.__str205)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1596))>>2)]=((STRING_TABLE.__str206)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1604))>>2)]=((STRING_TABLE.__str207)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1612))>>2)]=((STRING_TABLE.__str208)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1620))>>2)]=((STRING_TABLE.__str209)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1628))>>2)]=((STRING_TABLE.__str210798)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1636))>>2)]=((STRING_TABLE.__str211)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1644))>>2)]=((STRING_TABLE.__str212)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1652))>>2)]=((STRING_TABLE.__str213)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1660))>>2)]=((STRING_TABLE.__str214)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1668))>>2)]=((STRING_TABLE.__str215)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1676))>>2)]=((STRING_TABLE.__str216799)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1684))>>2)]=((STRING_TABLE.__str217)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1692))>>2)]=((STRING_TABLE.__str218)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1700))>>2)]=((STRING_TABLE.__str219)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1708))>>2)]=((STRING_TABLE.__str220)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1716))>>2)]=((STRING_TABLE.__str221)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1724))>>2)]=((STRING_TABLE.__str222800)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1732))>>2)]=((STRING_TABLE.__str223)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1740))>>2)]=((STRING_TABLE.__str224)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1748))>>2)]=((STRING_TABLE.__str225)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1756))>>2)]=((STRING_TABLE.__str226)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1764))>>2)]=((STRING_TABLE.__str227)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1772))>>2)]=((STRING_TABLE.__str228)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1780))>>2)]=((STRING_TABLE.__str229)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1788))>>2)]=((STRING_TABLE.__str230)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1796))>>2)]=((STRING_TABLE.__str231801)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1804))>>2)]=((STRING_TABLE.__str232)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1812))>>2)]=((STRING_TABLE.__str233)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1820))>>2)]=((STRING_TABLE.__str234)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1828))>>2)]=((STRING_TABLE.__str235)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1836))>>2)]=((STRING_TABLE.__str236802)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1844))>>2)]=((STRING_TABLE.__str237)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1852))>>2)]=((STRING_TABLE.__str238)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1860))>>2)]=((STRING_TABLE.__str239)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1868))>>2)]=((STRING_TABLE.__str240)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1876))>>2)]=((STRING_TABLE.__str241)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1884))>>2)]=((STRING_TABLE.__str242)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1892))>>2)]=((STRING_TABLE.__str243)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1900))>>2)]=((STRING_TABLE.__str244)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1908))>>2)]=((STRING_TABLE.__str245)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1916))>>2)]=((STRING_TABLE.__str246)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1924))>>2)]=((STRING_TABLE.__str247)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1932))>>2)]=((STRING_TABLE.__str248)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1940))>>2)]=((STRING_TABLE.__str249)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1948))>>2)]=((STRING_TABLE.__str250)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1956))>>2)]=((STRING_TABLE.__str251)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1964))>>2)]=((STRING_TABLE.__str252)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1972))>>2)]=((STRING_TABLE.__str253)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1980))>>2)]=((STRING_TABLE.__str254)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1988))>>2)]=((STRING_TABLE.__str255)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(1996))>>2)]=((STRING_TABLE.__str256)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2004))>>2)]=((STRING_TABLE.__str257)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2012))>>2)]=((STRING_TABLE.__str258)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2020))>>2)]=((STRING_TABLE.__str259)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2028))>>2)]=((STRING_TABLE.__str260)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2036))>>2)]=((STRING_TABLE.__str261)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2044))>>2)]=((STRING_TABLE.__str262)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2052))>>2)]=((STRING_TABLE.__str263)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2060))>>2)]=((STRING_TABLE.__str264)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2068))>>2)]=((STRING_TABLE.__str265)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2076))>>2)]=((STRING_TABLE.__str266)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2084))>>2)]=((STRING_TABLE.__str267)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2092))>>2)]=((STRING_TABLE.__str268)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2100))>>2)]=((STRING_TABLE.__str269)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2108))>>2)]=((STRING_TABLE.__str270)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2116))>>2)]=((STRING_TABLE.__str271)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2124))>>2)]=((STRING_TABLE.__str272)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2132))>>2)]=((STRING_TABLE.__str273)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2140))>>2)]=((STRING_TABLE.__str274)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2148))>>2)]=((STRING_TABLE.__str275)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2156))>>2)]=((STRING_TABLE.__str276)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2164))>>2)]=((STRING_TABLE.__str277803)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2172))>>2)]=((STRING_TABLE.__str278)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2180))>>2)]=((STRING_TABLE.__str279)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2188))>>2)]=((STRING_TABLE.__str280)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2196))>>2)]=((STRING_TABLE.__str281)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2204))>>2)]=((STRING_TABLE.__str282)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2212))>>2)]=((STRING_TABLE.__str283)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2220))>>2)]=((STRING_TABLE.__str284)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2228))>>2)]=((STRING_TABLE.__str285)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2236))>>2)]=((STRING_TABLE.__str286)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2244))>>2)]=((STRING_TABLE.__str287)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2252))>>2)]=((STRING_TABLE.__str288)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2260))>>2)]=((STRING_TABLE.__str289)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2268))>>2)]=((STRING_TABLE.__str290)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2276))>>2)]=((STRING_TABLE.__str291)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2284))>>2)]=((STRING_TABLE.__str292)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2292))>>2)]=((STRING_TABLE.__str293804)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2300))>>2)]=((STRING_TABLE.__str294)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2308))>>2)]=((STRING_TABLE.__str295)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2316))>>2)]=((STRING_TABLE.__str296)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2324))>>2)]=((STRING_TABLE.__str297)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2332))>>2)]=((STRING_TABLE.__str298805)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2340))>>2)]=((STRING_TABLE.__str299)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2348))>>2)]=((STRING_TABLE.__str300)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2356))>>2)]=((STRING_TABLE.__str301)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2364))>>2)]=((STRING_TABLE.__str302)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2372))>>2)]=((STRING_TABLE.__str303)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2380))>>2)]=((STRING_TABLE.__str304)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2388))>>2)]=((STRING_TABLE.__str305)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2396))>>2)]=((STRING_TABLE.__str306)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2404))>>2)]=((STRING_TABLE.__str307)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2412))>>2)]=((STRING_TABLE.__str308)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2420))>>2)]=((STRING_TABLE.__str309)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2428))>>2)]=((STRING_TABLE.__str310)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2436))>>2)]=((STRING_TABLE.__str311806)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2444))>>2)]=((STRING_TABLE.__str312)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2452))>>2)]=((STRING_TABLE.__str313)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2460))>>2)]=((STRING_TABLE.__str314)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2468))>>2)]=((STRING_TABLE.__str315)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2476))>>2)]=((STRING_TABLE.__str316)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2484))>>2)]=((STRING_TABLE.__str317807)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2492))>>2)]=((STRING_TABLE.__str318)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2500))>>2)]=((STRING_TABLE.__str319)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2508))>>2)]=((STRING_TABLE.__str320)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2516))>>2)]=((STRING_TABLE.__str321)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2524))>>2)]=((STRING_TABLE.__str322)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2532))>>2)]=((STRING_TABLE.__str323808)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2540))>>2)]=((STRING_TABLE.__str324)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2548))>>2)]=((STRING_TABLE.__str325)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2556))>>2)]=((STRING_TABLE.__str326)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2564))>>2)]=((STRING_TABLE.__str327)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2572))>>2)]=((STRING_TABLE.__str328)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2580))>>2)]=((STRING_TABLE.__str329)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2588))>>2)]=((STRING_TABLE.__str330)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2596))>>2)]=((STRING_TABLE.__str331)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2604))>>2)]=((STRING_TABLE.__str332)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2612))>>2)]=((STRING_TABLE.__str333)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2620))>>2)]=((STRING_TABLE.__str334)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2628))>>2)]=((STRING_TABLE.__str335)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2636))>>2)]=((STRING_TABLE.__str336)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2644))>>2)]=((STRING_TABLE.__str337809)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2652))>>2)]=((STRING_TABLE.__str338)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2660))>>2)]=((STRING_TABLE.__str339)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2668))>>2)]=((STRING_TABLE.__str340)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2676))>>2)]=((STRING_TABLE.__str341)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2684))>>2)]=((STRING_TABLE.__str297)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2692))>>2)]=((STRING_TABLE.__str298805)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2700))>>2)]=((STRING_TABLE.__str342)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2708))>>2)]=((STRING_TABLE.__str343)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2716))>>2)]=((STRING_TABLE.__str344)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2724))>>2)]=((STRING_TABLE.__str345)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2732))>>2)]=((STRING_TABLE.__str118767)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2740))>>2)]=((STRING_TABLE.__str346)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2748))>>2)]=((STRING_TABLE.__str347)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2756))>>2)]=((STRING_TABLE.__str348)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2764))>>2)]=((STRING_TABLE.__str349)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2772))>>2)]=((STRING_TABLE.__str350)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2780))>>2)]=((STRING_TABLE.__str351)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2788))>>2)]=((STRING_TABLE.__str352)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2796))>>2)]=((STRING_TABLE.__str353)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2804))>>2)]=((STRING_TABLE.__str354)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2812))>>2)]=((STRING_TABLE.__str355)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2820))>>2)]=((STRING_TABLE.__str356)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2828))>>2)]=((STRING_TABLE.__str357)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2836))>>2)]=((STRING_TABLE.__str358)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2844))>>2)]=((STRING_TABLE.__str359)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2852))>>2)]=((STRING_TABLE.__str360)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2860))>>2)]=((STRING_TABLE.__str361)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2868))>>2)]=((STRING_TABLE.__str362)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2876))>>2)]=((STRING_TABLE.__str363)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2884))>>2)]=((STRING_TABLE.__str364)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2892))>>2)]=((STRING_TABLE.__str365)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2900))>>2)]=((STRING_TABLE.__str366)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2908))>>2)]=((STRING_TABLE.__str367)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2916))>>2)]=((STRING_TABLE.__str368)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2924))>>2)]=((STRING_TABLE.__str369)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2932))>>2)]=((STRING_TABLE.__str370)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2940))>>2)]=((STRING_TABLE.__str371)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2948))>>2)]=((STRING_TABLE.__str372)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2956))>>2)]=((STRING_TABLE.__str373)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2964))>>2)]=((STRING_TABLE.__str374)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2972))>>2)]=((STRING_TABLE.__str375)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2980))>>2)]=((STRING_TABLE.__str376)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2988))>>2)]=((STRING_TABLE.__str377)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(2996))>>2)]=((STRING_TABLE.__str378810)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3004))>>2)]=((STRING_TABLE.__str379)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3012))>>2)]=((STRING_TABLE.__str380)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3020))>>2)]=((STRING_TABLE.__str381)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3028))>>2)]=((STRING_TABLE.__str382811)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3036))>>2)]=((STRING_TABLE.__str383)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3044))>>2)]=((STRING_TABLE.__str384)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3052))>>2)]=((STRING_TABLE.__str385)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3060))>>2)]=((STRING_TABLE.__str386812)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3068))>>2)]=((STRING_TABLE.__str387)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3076))>>2)]=((STRING_TABLE.__str388)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3084))>>2)]=((STRING_TABLE.__str389)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3092))>>2)]=((STRING_TABLE.__str390)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3100))>>2)]=((STRING_TABLE.__str391)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3108))>>2)]=((STRING_TABLE.__str392)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3116))>>2)]=((STRING_TABLE.__str393)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3124))>>2)]=((STRING_TABLE.__str394813)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3132))>>2)]=((STRING_TABLE.__str395)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3140))>>2)]=((STRING_TABLE.__str396)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3148))>>2)]=((STRING_TABLE.__str397)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3156))>>2)]=((STRING_TABLE.__str398)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3164))>>2)]=((STRING_TABLE.__str399)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3172))>>2)]=((STRING_TABLE.__str400)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3180))>>2)]=((STRING_TABLE.__str401)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3188))>>2)]=((STRING_TABLE.__str402)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3196))>>2)]=((STRING_TABLE.__str403)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3204))>>2)]=((STRING_TABLE.__str404)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3212))>>2)]=((STRING_TABLE.__str405)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3220))>>2)]=((STRING_TABLE.__str406)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3228))>>2)]=((STRING_TABLE.__str407)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3236))>>2)]=((STRING_TABLE.__str408)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3244))>>2)]=((STRING_TABLE.__str409814)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3252))>>2)]=((STRING_TABLE.__str124773)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3260))>>2)]=((STRING_TABLE.__str410)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3268))>>2)]=((STRING_TABLE.__str411)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3276))>>2)]=((STRING_TABLE.__str412)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3284))>>2)]=((STRING_TABLE.__str413)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3292))>>2)]=((STRING_TABLE.__str414)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3300))>>2)]=((STRING_TABLE.__str415)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3308))>>2)]=((STRING_TABLE.__str416)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3316))>>2)]=((STRING_TABLE.__str417)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3324))>>2)]=((STRING_TABLE.__str418)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3332))>>2)]=((STRING_TABLE.__str419)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3340))>>2)]=((STRING_TABLE.__str420)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3348))>>2)]=((STRING_TABLE.__str421)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3356))>>2)]=((STRING_TABLE.__str422)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3364))>>2)]=((STRING_TABLE.__str423)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3372))>>2)]=((STRING_TABLE.__str424815)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3380))>>2)]=((STRING_TABLE.__str425)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3388))>>2)]=((STRING_TABLE.__str426)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3396))>>2)]=((STRING_TABLE.__str427)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3404))>>2)]=((STRING_TABLE.__str428)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3412))>>2)]=((STRING_TABLE.__str429)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3420))>>2)]=((STRING_TABLE.__str430)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3428))>>2)]=((STRING_TABLE.__str431)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3436))>>2)]=((STRING_TABLE.__str432)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3444))>>2)]=((STRING_TABLE.__str433)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3452))>>2)]=((STRING_TABLE.__str434)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3460))>>2)]=((STRING_TABLE.__str435)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3468))>>2)]=((STRING_TABLE.__str436)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3476))>>2)]=((STRING_TABLE.__str437)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3484))>>2)]=((STRING_TABLE.__str438816)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3492))>>2)]=((STRING_TABLE.__str439)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3500))>>2)]=((STRING_TABLE.__str440)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3508))>>2)]=((STRING_TABLE.__str441)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3516))>>2)]=((STRING_TABLE.__str442)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3524))>>2)]=((STRING_TABLE.__str443)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3532))>>2)]=((STRING_TABLE.__str444)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3540))>>2)]=((STRING_TABLE.__str445)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3548))>>2)]=((STRING_TABLE.__str446)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3556))>>2)]=((STRING_TABLE.__str447)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3564))>>2)]=((STRING_TABLE.__str448)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3572))>>2)]=((STRING_TABLE.__str449)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3580))>>2)]=((STRING_TABLE.__str450)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3588))>>2)]=((STRING_TABLE.__str451)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3596))>>2)]=((STRING_TABLE.__str452)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3604))>>2)]=((STRING_TABLE.__str453)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3612))>>2)]=((STRING_TABLE.__str454)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3620))>>2)]=((STRING_TABLE.__str455)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3628))>>2)]=((STRING_TABLE.__str456)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3636))>>2)]=((STRING_TABLE.__str457)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3644))>>2)]=((STRING_TABLE.__str458)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3652))>>2)]=((STRING_TABLE.__str459)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3660))>>2)]=((STRING_TABLE.__str460)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3668))>>2)]=((STRING_TABLE.__str461)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3676))>>2)]=((STRING_TABLE.__str462)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3684))>>2)]=((STRING_TABLE.__str463)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3692))>>2)]=((STRING_TABLE.__str464)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3700))>>2)]=((STRING_TABLE.__str465)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3708))>>2)]=((STRING_TABLE.__str466)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3716))>>2)]=((STRING_TABLE.__str467)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3724))>>2)]=((STRING_TABLE.__str468)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3732))>>2)]=((STRING_TABLE.__str469)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3740))>>2)]=((STRING_TABLE.__str470)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3748))>>2)]=((STRING_TABLE.__str471)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3756))>>2)]=((STRING_TABLE.__str472)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3764))>>2)]=((STRING_TABLE.__str473)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3772))>>2)]=((STRING_TABLE.__str474)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3780))>>2)]=((STRING_TABLE.__str475)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3788))>>2)]=((STRING_TABLE.__str476)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3796))>>2)]=((STRING_TABLE.__str477)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3804))>>2)]=((STRING_TABLE.__str478)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3812))>>2)]=((STRING_TABLE.__str479817)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3820))>>2)]=((STRING_TABLE.__str480)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3828))>>2)]=((STRING_TABLE.__str481)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3836))>>2)]=((STRING_TABLE.__str482)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3844))>>2)]=((STRING_TABLE.__str483)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3852))>>2)]=((STRING_TABLE.__str484)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3860))>>2)]=((STRING_TABLE.__str485)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3868))>>2)]=((STRING_TABLE.__str486)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3876))>>2)]=((STRING_TABLE.__str487)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3884))>>2)]=((STRING_TABLE.__str488)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3892))>>2)]=((STRING_TABLE.__str489)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3900))>>2)]=((STRING_TABLE.__str490)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3908))>>2)]=((STRING_TABLE.__str491)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3916))>>2)]=((STRING_TABLE.__str492)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3924))>>2)]=((STRING_TABLE.__str493)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3932))>>2)]=((STRING_TABLE.__str494)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3940))>>2)]=((STRING_TABLE.__str495818)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3948))>>2)]=((STRING_TABLE.__str496)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3956))>>2)]=((STRING_TABLE.__str497)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3964))>>2)]=((STRING_TABLE.__str498)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3972))>>2)]=((STRING_TABLE.__str499)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3980))>>2)]=((STRING_TABLE.__str500)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3988))>>2)]=((STRING_TABLE.__str501)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(3996))>>2)]=((STRING_TABLE.__str502)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4004))>>2)]=((STRING_TABLE.__str503)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4012))>>2)]=((STRING_TABLE.__str504)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4020))>>2)]=((STRING_TABLE.__str505)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4028))>>2)]=((STRING_TABLE.__str506)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4036))>>2)]=((STRING_TABLE.__str507)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4044))>>2)]=((STRING_TABLE.__str508)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4052))>>2)]=((STRING_TABLE.__str509)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4060))>>2)]=((STRING_TABLE.__str510819)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4068))>>2)]=((STRING_TABLE.__str511)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4076))>>2)]=((STRING_TABLE.__str512)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4084))>>2)]=((STRING_TABLE.__str513)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4092))>>2)]=((STRING_TABLE.__str514)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4100))>>2)]=((STRING_TABLE.__str515)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4108))>>2)]=((STRING_TABLE.__str516)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4116))>>2)]=((STRING_TABLE.__str517)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4124))>>2)]=((STRING_TABLE.__str518)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4132))>>2)]=((STRING_TABLE.__str519)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4140))>>2)]=((STRING_TABLE.__str520)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4148))>>2)]=((STRING_TABLE.__str521)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4156))>>2)]=((STRING_TABLE.__str522)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4164))>>2)]=((STRING_TABLE.__str523)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4172))>>2)]=((STRING_TABLE.__str524)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4180))>>2)]=((STRING_TABLE.__str525820)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4188))>>2)]=((STRING_TABLE.__str526)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4196))>>2)]=((STRING_TABLE.__str527)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4204))>>2)]=((STRING_TABLE.__str528)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4212))>>2)]=((STRING_TABLE.__str529)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4220))>>2)]=((STRING_TABLE.__str530)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4228))>>2)]=((STRING_TABLE.__str531)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4236))>>2)]=((STRING_TABLE.__str532)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4244))>>2)]=((STRING_TABLE.__str533)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4252))>>2)]=((STRING_TABLE.__str534)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4260))>>2)]=((STRING_TABLE.__str535)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4268))>>2)]=((STRING_TABLE.__str536)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4276))>>2)]=((STRING_TABLE.__str537)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4284))>>2)]=((STRING_TABLE.__str538)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4292))>>2)]=((STRING_TABLE.__str539821)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4300))>>2)]=((STRING_TABLE.__str540)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4308))>>2)]=((STRING_TABLE.__str541)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4316))>>2)]=((STRING_TABLE.__str542)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4324))>>2)]=((STRING_TABLE.__str543)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4332))>>2)]=((STRING_TABLE.__str544)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4340))>>2)]=((STRING_TABLE.__str545)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4348))>>2)]=((STRING_TABLE.__str546)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4356))>>2)]=((STRING_TABLE.__str547)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4364))>>2)]=((STRING_TABLE.__str548)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4372))>>2)]=((STRING_TABLE.__str549)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4380))>>2)]=((STRING_TABLE.__str550)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4388))>>2)]=((STRING_TABLE.__str551)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4396))>>2)]=((STRING_TABLE.__str552)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4404))>>2)]=((STRING_TABLE.__str553)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4412))>>2)]=((STRING_TABLE.__str554)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4420))>>2)]=((STRING_TABLE.__str555)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4428))>>2)]=((STRING_TABLE.__str556)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4436))>>2)]=((STRING_TABLE.__str557)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4444))>>2)]=((STRING_TABLE.__str558)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4452))>>2)]=((STRING_TABLE.__str559)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4460))>>2)]=((STRING_TABLE.__str560822)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4468))>>2)]=((STRING_TABLE.__str561)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4476))>>2)]=((STRING_TABLE.__str562)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4484))>>2)]=((STRING_TABLE.__str563)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4492))>>2)]=((STRING_TABLE.__str564)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4500))>>2)]=((STRING_TABLE.__str565)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4508))>>2)]=((STRING_TABLE.__str566)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4516))>>2)]=((STRING_TABLE.__str567)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4524))>>2)]=((STRING_TABLE.__str568)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4532))>>2)]=((STRING_TABLE.__str569823)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4540))>>2)]=((STRING_TABLE.__str570824)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4548))>>2)]=((STRING_TABLE.__str571)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4556))>>2)]=((STRING_TABLE.__str572)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4564))>>2)]=((STRING_TABLE.__str573)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4572))>>2)]=((STRING_TABLE.__str574825)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4580))>>2)]=((STRING_TABLE.__str575)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4588))>>2)]=((STRING_TABLE.__str576)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4596))>>2)]=((STRING_TABLE.__str577)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4604))>>2)]=((STRING_TABLE.__str578)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4612))>>2)]=((STRING_TABLE.__str579)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4620))>>2)]=((STRING_TABLE.__str580826)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4628))>>2)]=((STRING_TABLE.__str581)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4636))>>2)]=((STRING_TABLE.__str582)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4644))>>2)]=((STRING_TABLE.__str583)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4652))>>2)]=((STRING_TABLE.__str584)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4660))>>2)]=((STRING_TABLE.__str585)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4668))>>2)]=((STRING_TABLE.__str586)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4676))>>2)]=((STRING_TABLE.__str587)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4684))>>2)]=((STRING_TABLE.__str588)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4692))>>2)]=((STRING_TABLE.__str589)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4700))>>2)]=((STRING_TABLE.__str590)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4708))>>2)]=((STRING_TABLE.__str591)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4716))>>2)]=((STRING_TABLE.__str592)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4724))>>2)]=((STRING_TABLE.__str593)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4732))>>2)]=((STRING_TABLE.__str594)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4740))>>2)]=((STRING_TABLE.__str595)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4748))>>2)]=((STRING_TABLE.__str596827)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4756))>>2)]=((STRING_TABLE.__str597)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4764))>>2)]=((STRING_TABLE.__str598828)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4772))>>2)]=((STRING_TABLE.__str599)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4780))>>2)]=((STRING_TABLE.__str600)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4788))>>2)]=((STRING_TABLE.__str601)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4796))>>2)]=((STRING_TABLE.__str602)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4804))>>2)]=((STRING_TABLE.__str603)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4812))>>2)]=((STRING_TABLE.__str604)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4820))>>2)]=((STRING_TABLE.__str605)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4828))>>2)]=((STRING_TABLE.__str606)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4836))>>2)]=((STRING_TABLE.__str607829)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4844))>>2)]=((STRING_TABLE.__str608)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4852))>>2)]=((STRING_TABLE.__str609)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4860))>>2)]=((STRING_TABLE.__str610)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4868))>>2)]=((STRING_TABLE.__str611)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4876))>>2)]=((STRING_TABLE.__str612)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4884))>>2)]=((STRING_TABLE.__str613)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4892))>>2)]=((STRING_TABLE.__str614)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4900))>>2)]=((STRING_TABLE.__str615)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4908))>>2)]=((STRING_TABLE.__str616)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4916))>>2)]=((STRING_TABLE.__str617)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4924))>>2)]=((STRING_TABLE.__str618)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4932))>>2)]=((STRING_TABLE.__str619)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4940))>>2)]=((STRING_TABLE.__str620)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4948))>>2)]=((STRING_TABLE.__str621)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4956))>>2)]=((STRING_TABLE.__str622)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4964))>>2)]=((STRING_TABLE.__str623)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4972))>>2)]=((STRING_TABLE.__str624)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4980))>>2)]=((STRING_TABLE.__str625)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4988))>>2)]=((STRING_TABLE.__str626830)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(4996))>>2)]=((STRING_TABLE.__str627)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5004))>>2)]=((STRING_TABLE.__str628)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5012))>>2)]=((STRING_TABLE.__str629)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5020))>>2)]=((STRING_TABLE.__str630831)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5028))>>2)]=((STRING_TABLE.__str631)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5036))>>2)]=((STRING_TABLE.__str632)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5044))>>2)]=((STRING_TABLE.__str633)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5052))>>2)]=((STRING_TABLE.__str634)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5060))>>2)]=((STRING_TABLE.__str635)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5068))>>2)]=((STRING_TABLE.__str636)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5076))>>2)]=((STRING_TABLE.__str637)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5084))>>2)]=((STRING_TABLE.__str638)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5092))>>2)]=((STRING_TABLE.__str639)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5100))>>2)]=((STRING_TABLE.__str640832)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5108))>>2)]=((STRING_TABLE.__str641)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5116))>>2)]=((STRING_TABLE.__str642)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5124))>>2)]=((STRING_TABLE.__str643)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5132))>>2)]=((STRING_TABLE.__str644)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5140))>>2)]=((STRING_TABLE.__str645)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5148))>>2)]=((STRING_TABLE.__str646)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5156))>>2)]=((STRING_TABLE.__str647833)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5164))>>2)]=((STRING_TABLE.__str648)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5172))>>2)]=((STRING_TABLE.__str649834)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5180))>>2)]=((STRING_TABLE.__str650)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5188))>>2)]=((STRING_TABLE.__str651)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5196))>>2)]=((STRING_TABLE.__str652)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5204))>>2)]=((STRING_TABLE.__str653)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5212))>>2)]=((STRING_TABLE.__str654)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5220))>>2)]=((STRING_TABLE.__str655)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5228))>>2)]=((STRING_TABLE.__str656)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5236))>>2)]=((STRING_TABLE.__str657)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5244))>>2)]=((STRING_TABLE.__str658)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5252))>>2)]=((STRING_TABLE.__str659)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5260))>>2)]=((STRING_TABLE.__str660)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5268))>>2)]=((STRING_TABLE.__str661)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5276))>>2)]=((STRING_TABLE.__str662)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5284))>>2)]=((STRING_TABLE.__str663)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5292))>>2)]=((STRING_TABLE.__str664)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5300))>>2)]=((STRING_TABLE.__str665)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5308))>>2)]=((STRING_TABLE.__str666)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5316))>>2)]=((STRING_TABLE.__str667)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5324))>>2)]=((STRING_TABLE.__str668)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5332))>>2)]=((STRING_TABLE.__str669)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5340))>>2)]=((STRING_TABLE.__str670)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5348))>>2)]=((STRING_TABLE.__str671)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5356))>>2)]=((STRING_TABLE.__str672)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5364))>>2)]=((STRING_TABLE.__str673)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5372))>>2)]=((STRING_TABLE.__str674)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5380))>>2)]=((STRING_TABLE.__str675)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5388))>>2)]=((STRING_TABLE.__str676)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5396))>>2)]=((STRING_TABLE.__str677)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5404))>>2)]=((STRING_TABLE.__str678)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5412))>>2)]=((STRING_TABLE.__str679)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5420))>>2)]=((STRING_TABLE.__str680)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5428))>>2)]=((STRING_TABLE.__str681835)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5436))>>2)]=((STRING_TABLE.__str682)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5444))>>2)]=((STRING_TABLE.__str683)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5452))>>2)]=((STRING_TABLE.__str684)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5460))>>2)]=((STRING_TABLE.__str685)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5468))>>2)]=((STRING_TABLE.__str686)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5476))>>2)]=((STRING_TABLE.__str687)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5484))>>2)]=((STRING_TABLE.__str688)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5492))>>2)]=((STRING_TABLE.__str689)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5500))>>2)]=((STRING_TABLE.__str690)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5508))>>2)]=((STRING_TABLE.__str691)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5516))>>2)]=((STRING_TABLE.__str692)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5524))>>2)]=((STRING_TABLE.__str693)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5532))>>2)]=((STRING_TABLE.__str694)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5540))>>2)]=((STRING_TABLE.__str695)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5548))>>2)]=((STRING_TABLE.__str696)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5556))>>2)]=((STRING_TABLE.__str697836)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5564))>>2)]=((STRING_TABLE.__str698)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5572))>>2)]=((STRING_TABLE.__str699)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5580))>>2)]=((STRING_TABLE.__str700)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5588))>>2)]=((STRING_TABLE.__str701)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5596))>>2)]=((STRING_TABLE.__str702)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5604))>>2)]=((STRING_TABLE.__str703)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5612))>>2)]=((STRING_TABLE.__str704)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5620))>>2)]=((STRING_TABLE.__str705)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5628))>>2)]=((STRING_TABLE.__str706)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5636))>>2)]=((STRING_TABLE.__str707)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5644))>>2)]=((STRING_TABLE.__str708)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5652))>>2)]=((STRING_TABLE.__str709)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5660))>>2)]=((STRING_TABLE.__str710)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5668))>>2)]=((STRING_TABLE.__str711)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5676))>>2)]=((STRING_TABLE.__str712)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5684))>>2)]=((STRING_TABLE.__str713)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5692))>>2)]=((STRING_TABLE.__str714)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5700))>>2)]=((STRING_TABLE.__str715)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5708))>>2)]=((STRING_TABLE.__str716)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5716))>>2)]=((STRING_TABLE.__str717)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5724))>>2)]=((STRING_TABLE.__str718)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5732))>>2)]=((STRING_TABLE.__str719)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5740))>>2)]=((STRING_TABLE.__str720)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5748))>>2)]=((STRING_TABLE.__str721)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5756))>>2)]=((STRING_TABLE.__str722)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5764))>>2)]=((STRING_TABLE.__str723)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5772))>>2)]=((STRING_TABLE.__str724)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5780))>>2)]=((STRING_TABLE.__str725)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5788))>>2)]=((STRING_TABLE.__str726)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5796))>>2)]=((STRING_TABLE.__str727837)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5804))>>2)]=((STRING_TABLE.__str728)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5812))>>2)]=((STRING_TABLE.__str729)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5820))>>2)]=((STRING_TABLE.__str391)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5828))>>2)]=((STRING_TABLE.__str730)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5836))>>2)]=((STRING_TABLE.__str731)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5844))>>2)]=((STRING_TABLE.__str732)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5852))>>2)]=((STRING_TABLE.__str733)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5860))>>2)]=((STRING_TABLE.__str734)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5868))>>2)]=((STRING_TABLE.__str735)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5876))>>2)]=((STRING_TABLE.__str736)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5884))>>2)]=((STRING_TABLE.__str737)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5892))>>2)]=((STRING_TABLE.__str738)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5900))>>2)]=((STRING_TABLE.__str739)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5908))>>2)]=((STRING_TABLE.__str740)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5916))>>2)]=((STRING_TABLE.__str741838)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5924))>>2)]=((STRING_TABLE.__str742)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5932))>>2)]=((STRING_TABLE.__str743)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5940))>>2)]=((STRING_TABLE.__str744)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5948))>>2)]=((STRING_TABLE.__str745)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5956))>>2)]=((STRING_TABLE.__str746)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5964))>>2)]=((STRING_TABLE.__str747)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5972))>>2)]=((STRING_TABLE.__str748)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5980))>>2)]=((STRING_TABLE.__str749)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5988))>>2)]=((STRING_TABLE.__str750)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(5996))>>2)]=((STRING_TABLE.__str751)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6004))>>2)]=((STRING_TABLE.__str752)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6012))>>2)]=((STRING_TABLE.__str753)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6020))>>2)]=((STRING_TABLE.__str754)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6028))>>2)]=((STRING_TABLE.__str371)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6036))>>2)]=((STRING_TABLE.__str755)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6044))>>2)]=((STRING_TABLE.__str756)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6052))>>2)]=((STRING_TABLE.__str757)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6060))>>2)]=((STRING_TABLE.__str758)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6068))>>2)]=((STRING_TABLE.__str759)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6076))>>2)]=((STRING_TABLE.__str760)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6084))>>2)]=((STRING_TABLE.__str761)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6092))>>2)]=((STRING_TABLE.__str692)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6100))>>2)]=((STRING_TABLE.__str762)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6108))>>2)]=((STRING_TABLE.__str126775)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6116))>>2)]=((STRING_TABLE.__str763)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6124))>>2)]=((STRING_TABLE.__str764)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6132))>>2)]=((STRING_TABLE.__str765)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6140))>>2)]=((STRING_TABLE.__str766)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6148))>>2)]=((STRING_TABLE.__str767)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6156))>>2)]=((STRING_TABLE.__str768)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6164))>>2)]=((STRING_TABLE.__str769)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6172))>>2)]=((STRING_TABLE.__str770)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6180))>>2)]=((STRING_TABLE.__str771)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6188))>>2)]=((STRING_TABLE.__str772)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6196))>>2)]=((STRING_TABLE.__str773)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6204))>>2)]=((STRING_TABLE.__str774)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6212))>>2)]=((STRING_TABLE.__str775)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6220))>>2)]=((STRING_TABLE.__str776)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6228))>>2)]=((STRING_TABLE.__str777)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6236))>>2)]=((STRING_TABLE.__str778)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6244))>>2)]=((STRING_TABLE.__str779)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6252))>>2)]=((STRING_TABLE.__str780)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6260))>>2)]=((STRING_TABLE.__str781)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6268))>>2)]=((STRING_TABLE.__str782839)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6276))>>2)]=((STRING_TABLE.__str783)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6284))>>2)]=((STRING_TABLE.__str784)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6292))>>2)]=((STRING_TABLE.__str785)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6300))>>2)]=((STRING_TABLE.__str786)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6308))>>2)]=((STRING_TABLE.__str787)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6316))>>2)]=((STRING_TABLE.__str788)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6324))>>2)]=((STRING_TABLE.__str789)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6332))>>2)]=((STRING_TABLE.__str790)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6340))>>2)]=((STRING_TABLE.__str791)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6348))>>2)]=((STRING_TABLE.__str792)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6356))>>2)]=((STRING_TABLE.__str793)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6364))>>2)]=((STRING_TABLE.__str794)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6372))>>2)]=((STRING_TABLE.__str795)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6380))>>2)]=((STRING_TABLE.__str796)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6388))>>2)]=((STRING_TABLE.__str797)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6396))>>2)]=((STRING_TABLE.__str798840)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6404))>>2)]=((STRING_TABLE.__str799)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6412))>>2)]=((STRING_TABLE.__str800)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6420))>>2)]=((STRING_TABLE.__str801)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6428))>>2)]=((STRING_TABLE.__str802)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6436))>>2)]=((STRING_TABLE.__str803)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6444))>>2)]=((STRING_TABLE.__str804)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6452))>>2)]=((STRING_TABLE.__str805)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6460))>>2)]=((STRING_TABLE.__str806)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6468))>>2)]=((STRING_TABLE.__str807)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6476))>>2)]=((STRING_TABLE.__str808)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6484))>>2)]=((STRING_TABLE.__str809)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6492))>>2)]=((STRING_TABLE.__str810)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6500))>>2)]=((STRING_TABLE.__str811)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6508))>>2)]=((STRING_TABLE.__str812)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6516))>>2)]=((STRING_TABLE.__str813)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6524))>>2)]=((STRING_TABLE.__str814)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6532))>>2)]=((STRING_TABLE.__str815)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6540))>>2)]=((STRING_TABLE.__str816)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6548))>>2)]=((STRING_TABLE.__str817)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6556))>>2)]=((STRING_TABLE.__str818)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6564))>>2)]=((STRING_TABLE.__str819)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6572))>>2)]=((STRING_TABLE.__str820)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6580))>>2)]=((STRING_TABLE.__str821)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6588))>>2)]=((STRING_TABLE.__str822)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6596))>>2)]=((STRING_TABLE.__str823)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6604))>>2)]=((STRING_TABLE.__str824)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6612))>>2)]=((STRING_TABLE.__str825)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6620))>>2)]=((STRING_TABLE.__str826)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6628))>>2)]=((STRING_TABLE.__str827)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6636))>>2)]=((STRING_TABLE.__str828841)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6644))>>2)]=((STRING_TABLE.__str829)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6652))>>2)]=((STRING_TABLE.__str830)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6660))>>2)]=((STRING_TABLE.__str831)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6668))>>2)]=((STRING_TABLE.__str832)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6676))>>2)]=((STRING_TABLE.__str833)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6684))>>2)]=((STRING_TABLE.__str834)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6692))>>2)]=((STRING_TABLE.__str835)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6700))>>2)]=((STRING_TABLE.__str836)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6708))>>2)]=((STRING_TABLE.__str837)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6716))>>2)]=((STRING_TABLE.__str838)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6724))>>2)]=((STRING_TABLE.__str839)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6732))>>2)]=((STRING_TABLE.__str840)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6740))>>2)]=((STRING_TABLE.__str841)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6748))>>2)]=((STRING_TABLE.__str842842)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6756))>>2)]=((STRING_TABLE.__str843)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6764))>>2)]=((STRING_TABLE.__str844)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6772))>>2)]=((STRING_TABLE.__str845)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6780))>>2)]=((STRING_TABLE.__str846)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6788))>>2)]=((STRING_TABLE.__str847)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6796))>>2)]=((STRING_TABLE.__str848)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6804))>>2)]=((STRING_TABLE.__str849)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6812))>>2)]=((STRING_TABLE.__str850)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6820))>>2)]=((STRING_TABLE.__str851)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6828))>>2)]=((STRING_TABLE.__str852)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6836))>>2)]=((STRING_TABLE.__str853)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6844))>>2)]=((STRING_TABLE.__str854)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6852))>>2)]=((STRING_TABLE.__str855)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6860))>>2)]=((STRING_TABLE.__str856)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6868))>>2)]=((STRING_TABLE.__str857)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6876))>>2)]=((STRING_TABLE.__str858)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6884))>>2)]=((STRING_TABLE.__str859)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6892))>>2)]=((STRING_TABLE.__str860)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6900))>>2)]=((STRING_TABLE.__str861)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6908))>>2)]=((STRING_TABLE.__str862)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6916))>>2)]=((STRING_TABLE.__str863)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6924))>>2)]=((STRING_TABLE.__str864)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6932))>>2)]=((STRING_TABLE.__str865)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6940))>>2)]=((STRING_TABLE.__str866)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6948))>>2)]=((STRING_TABLE.__str867)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6956))>>2)]=((STRING_TABLE.__str868)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6964))>>2)]=((STRING_TABLE.__str869)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6972))>>2)]=((STRING_TABLE.__str870)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6980))>>2)]=((STRING_TABLE.__str871)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6988))>>2)]=((STRING_TABLE.__str872)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(6996))>>2)]=((STRING_TABLE.__str293804)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7004))>>2)]=((STRING_TABLE.__str294)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7012))>>2)]=((STRING_TABLE.__str873)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7020))>>2)]=((STRING_TABLE.__str874)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7028))>>2)]=((STRING_TABLE.__str875)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7036))>>2)]=((STRING_TABLE.__str876)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7044))>>2)]=((STRING_TABLE.__str877)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7052))>>2)]=((STRING_TABLE.__str878)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7060))>>2)]=((STRING_TABLE.__str879)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7068))>>2)]=((STRING_TABLE.__str880)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7076))>>2)]=((STRING_TABLE.__str881)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7084))>>2)]=((STRING_TABLE.__str882)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7092))>>2)]=((STRING_TABLE.__str883843)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7100))>>2)]=((STRING_TABLE.__str884)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7108))>>2)]=((STRING_TABLE.__str885)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7116))>>2)]=((STRING_TABLE.__str886)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7124))>>2)]=((STRING_TABLE.__str887)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7132))>>2)]=((STRING_TABLE.__str888)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7140))>>2)]=((STRING_TABLE.__str889)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7148))>>2)]=((STRING_TABLE.__str890)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7156))>>2)]=((STRING_TABLE.__str891)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7164))>>2)]=((STRING_TABLE.__str892)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7172))>>2)]=((STRING_TABLE.__str893)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7180))>>2)]=((STRING_TABLE.__str894)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7188))>>2)]=((STRING_TABLE.__str895)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7196))>>2)]=((STRING_TABLE.__str896)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7204))>>2)]=((STRING_TABLE.__str897)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7212))>>2)]=((STRING_TABLE.__str898)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7220))>>2)]=((STRING_TABLE.__str899844)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7228))>>2)]=((STRING_TABLE.__str900)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7236))>>2)]=((STRING_TABLE.__str901)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7244))>>2)]=((STRING_TABLE.__str902)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7252))>>2)]=((STRING_TABLE.__str903)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7260))>>2)]=((STRING_TABLE.__str904)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7268))>>2)]=((STRING_TABLE.__str905)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7276))>>2)]=((STRING_TABLE.__str906)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7284))>>2)]=((STRING_TABLE.__str907)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7292))>>2)]=((STRING_TABLE.__str908)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7300))>>2)]=((STRING_TABLE.__str909)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7308))>>2)]=((STRING_TABLE.__str910)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7316))>>2)]=((STRING_TABLE.__str911)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7324))>>2)]=((STRING_TABLE.__str912)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7332))>>2)]=((STRING_TABLE.__str913)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7340))>>2)]=((STRING_TABLE.__str914)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7348))>>2)]=((STRING_TABLE.__str915)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7356))>>2)]=((STRING_TABLE.__str916)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7364))>>2)]=((STRING_TABLE.__str917)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7372))>>2)]=((STRING_TABLE.__str918)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7380))>>2)]=((STRING_TABLE.__str919)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7388))>>2)]=((STRING_TABLE.__str920)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7396))>>2)]=((STRING_TABLE.__str921)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7404))>>2)]=((STRING_TABLE.__str922)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7412))>>2)]=((STRING_TABLE.__str923)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7420))>>2)]=((STRING_TABLE.__str924)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7428))>>2)]=((STRING_TABLE.__str925)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7436))>>2)]=((STRING_TABLE.__str926)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7444))>>2)]=((STRING_TABLE.__str927)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7452))>>2)]=((STRING_TABLE.__str928)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7460))>>2)]=((STRING_TABLE.__str929)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7468))>>2)]=((STRING_TABLE.__str930)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7476))>>2)]=((STRING_TABLE.__str931)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7484))>>2)]=((STRING_TABLE.__str932)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7492))>>2)]=((STRING_TABLE.__str933)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7500))>>2)]=((STRING_TABLE.__str934)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7508))>>2)]=((STRING_TABLE.__str935)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7516))>>2)]=((STRING_TABLE.__str936)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7524))>>2)]=((STRING_TABLE.__str937)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7532))>>2)]=((STRING_TABLE.__str938)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7540))>>2)]=((STRING_TABLE.__str939)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7548))>>2)]=((STRING_TABLE.__str940)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7556))>>2)]=((STRING_TABLE.__str941)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7564))>>2)]=((STRING_TABLE.__str942)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7572))>>2)]=((STRING_TABLE.__str943845)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7580))>>2)]=((STRING_TABLE.__str944)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7588))>>2)]=((STRING_TABLE.__str945)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7596))>>2)]=((STRING_TABLE.__str946)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7604))>>2)]=((STRING_TABLE.__str947)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7612))>>2)]=((STRING_TABLE.__str948)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7620))>>2)]=((STRING_TABLE.__str949)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7628))>>2)]=((STRING_TABLE.__str950)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7636))>>2)]=((STRING_TABLE.__str951)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7644))>>2)]=((STRING_TABLE.__str952)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7652))>>2)]=((STRING_TABLE.__str953)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7660))>>2)]=((STRING_TABLE.__str954)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7668))>>2)]=((STRING_TABLE.__str955)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7676))>>2)]=((STRING_TABLE.__str956)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7684))>>2)]=((STRING_TABLE.__str957)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7692))>>2)]=((STRING_TABLE.__str958)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7700))>>2)]=((STRING_TABLE.__str959)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7708))>>2)]=((STRING_TABLE.__str960)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7716))>>2)]=((STRING_TABLE.__str961)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7724))>>2)]=((STRING_TABLE.__str962)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7732))>>2)]=((STRING_TABLE.__str963)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7740))>>2)]=((STRING_TABLE.__str964)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7748))>>2)]=((STRING_TABLE.__str965)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7756))>>2)]=((STRING_TABLE.__str966)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7764))>>2)]=((STRING_TABLE.__str967)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7772))>>2)]=((STRING_TABLE.__str968)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7780))>>2)]=((STRING_TABLE.__str969)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7788))>>2)]=((STRING_TABLE.__str970)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7796))>>2)]=((STRING_TABLE.__str971)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7804))>>2)]=((STRING_TABLE.__str972)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7812))>>2)]=((STRING_TABLE.__str973)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7820))>>2)]=((STRING_TABLE.__str974)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7828))>>2)]=((STRING_TABLE.__str975)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7836))>>2)]=((STRING_TABLE.__str976)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7844))>>2)]=((STRING_TABLE.__str977)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7852))>>2)]=((STRING_TABLE.__str978)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7860))>>2)]=((STRING_TABLE.__str979)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7868))>>2)]=((STRING_TABLE.__str980)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7876))>>2)]=((STRING_TABLE.__str981)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7884))>>2)]=((STRING_TABLE.__str982)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7892))>>2)]=((STRING_TABLE.__str983)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7900))>>2)]=((STRING_TABLE.__str984)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7908))>>2)]=((STRING_TABLE.__str985)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7916))>>2)]=((STRING_TABLE.__str986846)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7924))>>2)]=((STRING_TABLE.__str987)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7932))>>2)]=((STRING_TABLE.__str988)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7940))>>2)]=((STRING_TABLE.__str989)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7948))>>2)]=((STRING_TABLE.__str990)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7956))>>2)]=((STRING_TABLE.__str991)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7964))>>2)]=((STRING_TABLE.__str992)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7972))>>2)]=((STRING_TABLE.__str993)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7980))>>2)]=((STRING_TABLE.__str994)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7988))>>2)]=((STRING_TABLE.__str995)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(7996))>>2)]=((STRING_TABLE.__str996)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(8004))>>2)]=((STRING_TABLE.__str997)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(8012))>>2)]=((STRING_TABLE.__str998)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(8020))>>2)]=((STRING_TABLE.__str999)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(8028))>>2)]=((STRING_TABLE.__str1000)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(8036))>>2)]=((STRING_TABLE.__str1001)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(8044))>>2)]=((STRING_TABLE.__str1002)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(8052))>>2)]=((STRING_TABLE.__str1003)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(8060))>>2)]=((STRING_TABLE.__str1004)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(8068))>>2)]=((STRING_TABLE.__str1005)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(8076))>>2)]=((STRING_TABLE.__str1006)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(8084))>>2)]=((STRING_TABLE.__str1007)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(8092))>>2)]=((STRING_TABLE.__str1008)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(8100))>>2)]=((STRING_TABLE.__str1009)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(8108))>>2)]=((STRING_TABLE.__str1010)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(8116))>>2)]=((STRING_TABLE.__str1011)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(8124))>>2)]=((STRING_TABLE.__str1012)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(8132))>>2)]=((STRING_TABLE.__str1013)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(8140))>>2)]=((STRING_TABLE.__str1014)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(8148))>>2)]=((STRING_TABLE.__str1015)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(8156))>>2)]=((STRING_TABLE.__str1016)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(8164))>>2)]=((STRING_TABLE.__str1017)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(8172))>>2)]=((STRING_TABLE.__str1018)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(8180))>>2)]=((STRING_TABLE.__str1019)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(8188))>>2)]=((STRING_TABLE.__str1020)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(8196))>>2)]=((STRING_TABLE.__str1021)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(8204))>>2)]=((STRING_TABLE.__str1022)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(8212))>>2)]=((STRING_TABLE.__str1023)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(8220))>>2)]=((STRING_TABLE.__str1024)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(8228))>>2)]=((STRING_TABLE.__str1025)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(8236))>>2)]=((STRING_TABLE.__str1026)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(8244))>>2)]=((STRING_TABLE.__str1027)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(8252))>>2)]=((STRING_TABLE.__str1028)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(8260))>>2)]=((STRING_TABLE.__str1029)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(8268))>>2)]=((STRING_TABLE.__str1030)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(8276))>>2)]=((STRING_TABLE.__str1031)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(8284))>>2)]=((STRING_TABLE.__str1032)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(8292))>>2)]=((STRING_TABLE.__str1033)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(8300))>>2)]=((STRING_TABLE.__str1034)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(8308))>>2)]=((STRING_TABLE.__str1035)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(8316))>>2)]=((STRING_TABLE.__str1036)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(8324))>>2)]=((STRING_TABLE.__str1037)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(8332))>>2)]=((STRING_TABLE.__str1038)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(8340))>>2)]=((STRING_TABLE.__str1039)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(8348))>>2)]=((STRING_TABLE.__str1040)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(8356))>>2)]=((STRING_TABLE.__str1041)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(8364))>>2)]=((STRING_TABLE.__str1042)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(8372))>>2)]=((STRING_TABLE.__str1043)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(8380))>>2)]=((STRING_TABLE.__str1044847)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(8388))>>2)]=((STRING_TABLE.__str1045)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(8396))>>2)]=((STRING_TABLE.__str1046)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(8404))>>2)]=((STRING_TABLE.__str1047)|0);
HEAP32[(((_HPDF_UNICODE_GRYPH_NAME_MAP)+(8412))>>2)]=((STRING_TABLE.__str1048)|0);
HEAP32[((_HPDF_BM_NAMES)>>2)]=((STRING_TABLE.__str51140)|0);
HEAP32[(((_HPDF_BM_NAMES)+(4))>>2)]=((STRING_TABLE.__str61141)|0);
HEAP32[(((_HPDF_BM_NAMES)+(8))>>2)]=((STRING_TABLE.__str71142)|0);
HEAP32[(((_HPDF_BM_NAMES)+(12))>>2)]=((STRING_TABLE.__str81143)|0);
HEAP32[(((_HPDF_BM_NAMES)+(16))>>2)]=((STRING_TABLE.__str91144)|0);
HEAP32[(((_HPDF_BM_NAMES)+(20))>>2)]=((STRING_TABLE.__str101145)|0);
HEAP32[(((_HPDF_BM_NAMES)+(24))>>2)]=((STRING_TABLE.__str111146)|0);
HEAP32[(((_HPDF_BM_NAMES)+(28))>>2)]=((STRING_TABLE.__str121147)|0);
HEAP32[(((_HPDF_BM_NAMES)+(32))>>2)]=((STRING_TABLE.__str131148)|0);
HEAP32[(((_HPDF_BM_NAMES)+(36))>>2)]=((STRING_TABLE.__str141149)|0);
HEAP32[(((_HPDF_BM_NAMES)+(40))>>2)]=((STRING_TABLE.__str151150)|0);
HEAP32[(((_HPDF_BM_NAMES)+(44))>>2)]=((STRING_TABLE.__str161151)|0);
HEAP32[((_HPDF_BUILTIN_FONTS)>>2)]=((STRING_TABLE.__str11234)|0);
HEAP32[(((_HPDF_BUILTIN_FONTS)+(4))>>2)]=((_CHAR_DATA_COURIER)|0);
HEAP32[(((_HPDF_BUILTIN_FONTS)+(36))>>2)]=((STRING_TABLE.__str21235)|0);
HEAP32[(((_HPDF_BUILTIN_FONTS)+(40))>>2)]=((_CHAR_DATA_COURIER_BOLD)|0);
HEAP32[(((_HPDF_BUILTIN_FONTS)+(72))>>2)]=((STRING_TABLE.__str31236)|0);
HEAP32[(((_HPDF_BUILTIN_FONTS)+(76))>>2)]=((_CHAR_DATA_COURIER_OBLIQUE)|0);
HEAP32[(((_HPDF_BUILTIN_FONTS)+(108))>>2)]=((STRING_TABLE.__str41237)|0);
HEAP32[(((_HPDF_BUILTIN_FONTS)+(112))>>2)]=((_CHAR_DATA_COURIER_BOLD_OBLIQUE)|0);
HEAP32[(((_HPDF_BUILTIN_FONTS)+(144))>>2)]=((STRING_TABLE.__str51238)|0);
HEAP32[(((_HPDF_BUILTIN_FONTS)+(148))>>2)]=((_CHAR_DATA_HELVETICA)|0);
HEAP32[(((_HPDF_BUILTIN_FONTS)+(180))>>2)]=((STRING_TABLE.__str61239)|0);
HEAP32[(((_HPDF_BUILTIN_FONTS)+(184))>>2)]=((_CHAR_DATA_HELVETICA_BOLD)|0);
HEAP32[(((_HPDF_BUILTIN_FONTS)+(216))>>2)]=((STRING_TABLE.__str71240)|0);
HEAP32[(((_HPDF_BUILTIN_FONTS)+(220))>>2)]=((_CHAR_DATA_HELVETICA_OBLIQUE)|0);
HEAP32[(((_HPDF_BUILTIN_FONTS)+(252))>>2)]=((STRING_TABLE.__str81241)|0);
HEAP32[(((_HPDF_BUILTIN_FONTS)+(256))>>2)]=((_CHAR_DATA_HELVETICA_BOLD_OBLIQUE)|0);
HEAP32[(((_HPDF_BUILTIN_FONTS)+(288))>>2)]=((STRING_TABLE.__str91242)|0);
HEAP32[(((_HPDF_BUILTIN_FONTS)+(292))>>2)]=((_CHAR_DATA_TIMES_ROMAN)|0);
HEAP32[(((_HPDF_BUILTIN_FONTS)+(324))>>2)]=((STRING_TABLE.__str101243)|0);
HEAP32[(((_HPDF_BUILTIN_FONTS)+(328))>>2)]=((_CHAR_DATA_TIMES_BOLD)|0);
HEAP32[(((_HPDF_BUILTIN_FONTS)+(360))>>2)]=((STRING_TABLE.__str111244)|0);
HEAP32[(((_HPDF_BUILTIN_FONTS)+(364))>>2)]=((_CHAR_DATA_TIMES_ITALIC)|0);
HEAP32[(((_HPDF_BUILTIN_FONTS)+(396))>>2)]=((STRING_TABLE.__str121245)|0);
HEAP32[(((_HPDF_BUILTIN_FONTS)+(400))>>2)]=((_CHAR_DATA_TIMES_BOLD_ITALIC)|0);
HEAP32[(((_HPDF_BUILTIN_FONTS)+(432))>>2)]=((STRING_TABLE.__str131246)|0);
HEAP32[(((_HPDF_BUILTIN_FONTS)+(436))>>2)]=((_CHAR_DATA_SYMBOL)|0);
HEAP32[(((_HPDF_BUILTIN_FONTS)+(468))>>2)]=((STRING_TABLE.__str141247)|0);
HEAP32[(((_HPDF_BUILTIN_FONTS)+(472))>>2)]=((_CHAR_DATA_ZAPF_DINGBATS)|0);
HEAP32[((_REQUIRED_TAGS)>>2)]=((STRING_TABLE.__str41308)|0);
HEAP32[(((_REQUIRED_TAGS)+(4))>>2)]=((STRING_TABLE.__str51309)|0);
HEAP32[(((_REQUIRED_TAGS)+(8))>>2)]=((STRING_TABLE.__str61310)|0);
HEAP32[(((_REQUIRED_TAGS)+(12))>>2)]=((STRING_TABLE.__str71311)|0);
HEAP32[(((_REQUIRED_TAGS)+(16))>>2)]=((STRING_TABLE.__str11305)|0);
HEAP32[(((_REQUIRED_TAGS)+(20))>>2)]=((STRING_TABLE.__str1304)|0);
HEAP32[(((_REQUIRED_TAGS)+(24))>>2)]=((STRING_TABLE.__str81312)|0);
HEAP32[(((_REQUIRED_TAGS)+(28))>>2)]=((STRING_TABLE.__str91313)|0);
HEAP32[(((_REQUIRED_TAGS)+(32))>>2)]=((STRING_TABLE.__str21306)|0);
HEAP32[(((_REQUIRED_TAGS)+(36))>>2)]=((STRING_TABLE.__str101314)|0);
HEAP32[(((_REQUIRED_TAGS)+(40))>>2)]=((STRING_TABLE.__str31307)|0);
HEAP32[(((_REQUIRED_TAGS)+(44))>>2)]=((STRING_TABLE.__str111315)|0);
HEAP32[(((_REQUIRED_TAGS)+(48))>>2)]=((STRING_TABLE.__str121316)|0);
HEAP32[((_COL_GRAY)>>2)]=((STRING_TABLE.__str131439)|0);
HEAP32[((_COL_CMYK)>>2)]=((STRING_TABLE.__str121438)|0);
HEAP32[((_COL_RGB)>>2)]=((STRING_TABLE.__str111437)|0);
HEAP32[((_HPDF_INFO_ATTR_NAMES)>>2)]=((STRING_TABLE.__str11467)|0);
HEAP32[(((_HPDF_INFO_ATTR_NAMES)+(4))>>2)]=((STRING_TABLE.__str21468)|0);
HEAP32[(((_HPDF_INFO_ATTR_NAMES)+(8))>>2)]=((STRING_TABLE.__str31469)|0);
HEAP32[(((_HPDF_INFO_ATTR_NAMES)+(12))>>2)]=((STRING_TABLE.__str41470)|0);
HEAP32[(((_HPDF_INFO_ATTR_NAMES)+(16))>>2)]=((STRING_TABLE.__str51471)|0);
HEAP32[(((_HPDF_INFO_ATTR_NAMES)+(20))>>2)]=((STRING_TABLE.__str61472)|0);
HEAP32[(((_HPDF_INFO_ATTR_NAMES)+(24))>>2)]=((STRING_TABLE.__str71473)|0);
HEAP32[(((_HPDF_INFO_ATTR_NAMES)+(28))>>2)]=((STRING_TABLE.__str81474)|0);
HEAP32[((_HPDF_INHERITABLE_ENTRIES)>>2)]=((STRING_TABLE.__str81631)|0);
HEAP32[(((_HPDF_INHERITABLE_ENTRIES)+(4))>>2)]=((STRING_TABLE.__str61629)|0);
HEAP32[(((_HPDF_INHERITABLE_ENTRIES)+(8))>>2)]=((STRING_TABLE.__str241647)|0);
HEAP32[(((_HPDF_INHERITABLE_ENTRIES)+(12))>>2)]=((STRING_TABLE.__str151638)|0);
HEAP32[((_HPDF_3DView_SetLighting_schemes)>>2)]=((STRING_TABLE.__str161748)|0);
HEAP32[(((_HPDF_3DView_SetLighting_schemes)+(4))>>2)]=((STRING_TABLE.__str171749)|0);
HEAP32[(((_HPDF_3DView_SetLighting_schemes)+(8))>>2)]=((STRING_TABLE.__str181750)|0);
HEAP32[(((_HPDF_3DView_SetLighting_schemes)+(12))>>2)]=((STRING_TABLE.__str191751)|0);
HEAP32[(((_HPDF_3DView_SetLighting_schemes)+(16))>>2)]=((STRING_TABLE.__str201752)|0);
HEAP32[(((_HPDF_3DView_SetLighting_schemes)+(20))>>2)]=((STRING_TABLE.__str211753)|0);
HEAP32[(((_HPDF_3DView_SetLighting_schemes)+(24))>>2)]=((STRING_TABLE.__str221754)|0);
HEAP32[(((_HPDF_3DView_SetLighting_schemes)+(28))>>2)]=((STRING_TABLE.__str231755)|0);
HEAP32[(((_HPDF_3DView_SetLighting_schemes)+(32))>>2)]=((STRING_TABLE.__str241756)|0);
HEAP32[(((_HPDF_3DView_SetLighting_schemes)+(36))>>2)]=((STRING_TABLE.__str251757)|0);
HEAP32[(((_HPDF_3DView_SetLighting_schemes)+(40))>>2)]=((STRING_TABLE.__str261758)|0);
HEAP32[(((_HPDF_3DView_SetLighting_schemes)+(44))>>2)]=((STRING_TABLE.__str271759)|0);
FUNCTION_TABLE = [0,0,_zcalloc,0,_zcfree,0,_png_zalloc,0,_png_zfree,0,_longjmp,0,_png_default_read_data,0,_HPDF_BasicEncoder_ToUnicode,0,_HPDF_BasicEncoder_Write,0,_HPDF_BasicEncoder_Free,0,_HPDF_CMapEncoder_ByteType,0,_HPDF_CMapEncoder_ToUnicode,0,_HPDF_CMapEncoder_Write,0,_HPDF_CMapEncoder_Free,0,_GBK_EUC_IsLeadByte,0,_GBK_EUC_IsTrialByte,0,_GB_EUC_IsLeadByte,0,_GB_EUC_IsTrialByte,0,_ETen_B5_IsLeadByte,0,_ETen_B5_IsTrialByte,0,_GBK_EUC_H_Init,0,_GBK_EUC_V_Init,0,_GB_EUC_H_Init,0,_GB_EUC_V_Init,0,_ETen_B5_H_Init,0,_ETen_B5_V_Init,0,_RKSJ_IsLeadByte,0,_RKSJ_IsTrialByte,0,_EUC_IsLeadByte,0,_EUC_IsTrialByte,0,_MS_RKSJ_H_Init,0,_MS_RKSJ_V_Init,0,_MSP_RKSJ_H_Init,0,_EUC_H_Init,0,_EUC_V_Init,0,_KSCms_UHC_IsLeadByte,0,_KSCms_UHC_IsTrialByte,0,_KSC_EUC_IsLeadByte,0,_KSC_EUC_IsTrialByte,0,_KSCms_UHC_H_Init,0,_KSCms_UHC_HW_H_Init,0,_KSCms_UHC_HW_V_Init,0,_KSC_EUC_H_Init,0,_KSC_EUC_V_Init,0,_HPDF_EncryptDict_OnFree,0,_OnFree_Func,0,_TextWidth,0,_MeasureText,0,_CIDFontType2_BeforeWrite_Func,0,_HPDF_CIDFontDef_FreeFunc,0,_SimSun_Init,0,_SimSun_Bold_Init,0,_SimSun_Italic_Init,0,_SimSun_BoldItalic_Init,0,_SimHei_Init,0,_SimHei_Bold_Init,0,_SimHei_Italic_Init,0,_SimHei_BoldItalic_Init,0,_MingLiU_Init,0,_MingLiU_Bold_Init,0,_MingLiU_Italic_Init,0,_MingLiU_BoldItalic_Init,0,_MS_Gothic_Init,0,_MS_Gothic_Bold_Init,0,_MS_Gothic_Italic_Init,0,_MS_Gothic_BoldItalic_Init,0,_MS_PGothic_Init,0,_MS_PGothic_Bold_Init,0,_MS_PGothic_Italic_Init,0,_MS_PGothic_BoldItalic_Init,0,_MS_Mincyo_Init,0,_MS_Mincyo_Bold_Init,0,_MS_Mincyo_Italic_Init,0,_MS_Mincyo_BoldItalic_Init,0,_MS_PMincyo_Init,0,_MS_PMincyo_Bold_Init,0,_MS_PMincyo_Italic_Init,0,_MS_PMincyo_BoldItalic_Init,0,_CleanFunc,0,_FreeFunc,0,_DotumChe_Init,0,_DotumChe_Bold_Init,0,_DotumChe_Italic_Init,0,_DotumChe_BoldItalic_Init,0,_Dotum_Init,0,_Dotum_Bold_Init,0,_Dotum_Italic_Init,0,_Dotum_BoldItalic_Init,0,_BatangChe_Init,0,_BatangChe_Bold_Init,0,_BatangChe_Italic_Init,0,_BatangChe_BoldItalic_Init,0,_Batang_Init,0,_Batang_Bold_Init,0,_Batang_Italic_Init,0,_Batang_BoldItalic_Init,0,_FreeFunc1360,0,_OnWrite,0,_BeforeWrite,0,_OnFree,0,_TextWidth1396,0,_MeasureText1397,0,_Type1Font_OnWrite,0,_Type1Font_OnFree,0,_Type1Font_TextWidth,0,_Type1Font_MeasureText,0,_PngBeforeWrite,0,_PngAfterWrite,0,_PngErrorFunc,0,_PngReadFunc,0,_InternalGetMem,0,_InternalFreeMem,0,_BeforeWrite1535,0,_Pages_BeforeWrite,0,_Page_OnFree,0,_Page_BeforeWrite,0,_HPDF_FileReader_ReadFunc,0,_HPDF_FileReader_SeekFunc,0,_HPDF_FileStream_TellFunc,0,_HPDF_FileStream_SizeFunc,0,_HPDF_FileStream_FreeFunc,0,_HPDF_FileWriter_WriteFunc,0,_HPDF_MemStream_WriteFunc,0,_HPDF_MemStream_ReadFunc,0,_HPDF_MemStream_SeekFunc,0,_HPDF_MemStream_TellFunc,0,_HPDF_MemStream_SizeFunc,0,_HPDF_MemStream_FreeFunc,0,_deflate_stored,0,_deflate_fast,0,_deflate_slow,0,_HPDF_LinkAnnot_SetBorderStyle,0,_HPDF_LinkAnnot_SetHighlightMode,0,_HPDF_3DAnnot_Set3DView,0,_HPDF_TextAnnot_SetIcon,0,_HPDF_TextAnnot_SetOpened,0,_HPDF_Destination_SetXYZ,0,_HPDF_Destination_SetFit,0,_HPDF_Destination_SetFitH,0,_HPDF_Destination_SetFitV,0,_HPDF_Destination_SetFitR,0,_HPDF_Destination_SetFitB,0,_HPDF_Destination_SetFitBH,0,_HPDF_Destination_SetFitBV,0,_HPDF_GetVersion,0,_HPDF_HasDoc,0,_HPDF_New,0,_HPDF_NewEx,0,_HPDF_Free,0,_HPDF_NewDoc,0,_HPDF_FreeDoc,0,_HPDF_FreeDocAll,0,_HPDF_SetPagesConfiguration,0,_HPDF_SetPassword,0,_HPDF_SetPermission,0,_HPDF_SetEncryptionMode,0,_HPDF_SaveToStream,0,_HPDF_GetContents,0,_HPDF_GetStreamSize,0,_HPDF_ReadFromStream,0,_HPDF_ResetStream,0,_HPDF_SaveToFile,0,_HPDF_GetCurrentPage,0,_HPDF_GetPageByIndex,0,_HPDF_AddPage,0,_HPDF_InsertPage,0,_HPDF_SetErrorHandler,0,_HPDF_GetEncoder,0,_HPDF_GetCurrentEncoder,0,_HPDF_SetCurrentEncoder,0,_HPDF_GetFont,0,_HPDF_LoadType1FontFromFile,0,_HPDF_GetTTFontDefFromFile,0,_HPDF_LoadTTFontFromFile,0,_HPDF_LoadTTFontFromFile2,0,_HPDF_LoadRawImageFromFile,0,_HPDF_LoadRawImageFromMem,0,_HPDF_LoadJpegImageFromFile,0,_HPDF_LoadJpegImageFromMem,0,_HPDF_GetPageLayout,0,_HPDF_SetPageLayout,0,_HPDF_GetPageMode,0,_HPDF_SetPageMode,0,_HPDF_SetOpenAction,0,_HPDF_GetViewerPreference,0,_HPDF_SetViewerPreference,0,_HPDF_AddPageLabel,0,_HPDF_SetInfoAttr,0,_HPDF_GetInfoAttr,0,_HPDF_SetInfoDateAttr,0,_HPDF_CreateOutline,0,_HPDF_CreateExtGState,0,_HPDF_SetCompressionMode,0,_HPDF_GetError,0,_HPDF_GetErrorDetail,0,_HPDF_ResetError,0,_HPDF_LoadPngImageFromMem,0,_HPDF_LoadPngImageFromFile,0,_HPDF_LoadPngImageFromFile2,0,_HPDF_Encoder_GetUnicode,0,_HPDF_Encoder_GetByteType,0,_HPDF_Encoder_GetType,0,_HPDF_Encoder_GetWritingMode,0,_HPDF_UseCNSEncodings,0,_HPDF_UseCNTEncodings,0,_HPDF_UseJPEncodings,0,_HPDF_UseKREncodings,0,_HPDF_CheckError,0,_HPDF_ExtGState_SetAlphaStroke,0,_HPDF_ExtGState_SetAlphaFill,0,_HPDF_ExtGState_SetBlendMode,0,_HPDF_Font_TextWidth,0,_HPDF_Font_MeasureText,0,_HPDF_Font_GetFontName,0,_HPDF_Font_GetEncodingName,0,_HPDF_Font_GetUnicodeWidth,0,_HPDF_Font_GetBBox,0,_HPDF_Font_GetAscent,0,_HPDF_Font_GetDescent,0,_HPDF_Font_GetXHeight,0,_HPDF_Font_GetCapHeight,0,_HPDF_UseCNSFonts,0,_HPDF_UseCNTFonts,0,_HPDF_UseJPFonts,0,_HPDF_UseKRFonts,0,_HPDF_Image_GetSize,0,_HPDF_Image_GetSize2,0,_HPDF_Image_GetBitsPerComponent,0,_HPDF_Image_GetColorSpace,0,_HPDF_Image_GetWidth,0,_HPDF_Image_GetHeight,0,_HPDF_Image_SetMaskImage,0,_HPDF_Image_SetColorMask,0,_HPDF_Image_AddSMask,0,_HPDF_Outline_SetDestination,0,_HPDF_Outline_SetOpened,0,_HPDF_Page_SetLineWidth,0,_HPDF_Page_SetLineCap,0,_HPDF_Page_SetLineJoin,0,_HPDF_Page_SetMiterLimit,0,_HPDF_Page_SetDash,0,_HPDF_Page_SetFlat,0,_HPDF_Page_SetExtGState,0,_HPDF_Page_GSave,0,_HPDF_Page_GRestore,0,_HPDF_Page_Concat,0,_HPDF_Page_MoveTo,0,_HPDF_Page_LineTo,0,_HPDF_Page_CurveTo,0,_HPDF_Page_CurveTo2,0,_HPDF_Page_CurveTo3,0,_HPDF_Page_ClosePath,0,_HPDF_Page_Rectangle,0,_HPDF_Page_Stroke,0,_HPDF_Page_ClosePathStroke,0,_HPDF_Page_Fill,0,_HPDF_Page_Eofill,0,_HPDF_Page_FillStroke,0,_HPDF_Page_EofillStroke,0,_HPDF_Page_ClosePathFillStroke,0,_HPDF_Page_ClosePathEofillStroke,0,_HPDF_Page_EndPath,0,_HPDF_Page_Clip,0,_HPDF_Page_Eoclip,0,_HPDF_Page_BeginText,0,_HPDF_Page_EndText,0,_HPDF_Page_SetCharSpace,0,_HPDF_Page_SetWordSpace,0,_HPDF_Page_SetHorizontalScalling,0,_HPDF_Page_SetTextLeading,0,_HPDF_Page_SetFontAndSize,0,_HPDF_Page_SetTextRenderingMode,0,_HPDF_Page_SetTextRaise,0,_HPDF_Page_SetTextRise,0,_HPDF_Page_MoveTextPos,0,_HPDF_Page_MoveTextPos2,0,_HPDF_Page_SetTextMatrix,0,_HPDF_Page_MoveToNextLine,0,_HPDF_Page_ShowText,0,_HPDF_Page_ShowTextNextLine,0,_HPDF_Page_ShowTextNextLineEx,0,_HPDF_Page_SetGrayFill,0,_HPDF_Page_SetGrayStroke,0,_HPDF_Page_SetRGBFill,0,_HPDF_Page_SetRGBStroke,0,_HPDF_Page_SetCMYKFill,0,_HPDF_Page_SetCMYKStroke,0,_HPDF_Page_ExecuteXObject,0,_HPDF_Page_Circle,0,_HPDF_Page_Ellipse,0,_HPDF_Page_Arc,0,_HPDF_Page_DrawImage,0,_HPDF_Page_TextOut,0,_HPDF_Page_TextRect,0,_HPDF_Page_SetSlideShow,0,_HPDF_Page_TextWidth,0,_HPDF_Page_MeasureText,0,_HPDF_Page_GetWidth,0,_HPDF_Page_GetHeight,0,_HPDF_Page_GetCurrentFont,0,_HPDF_Page_GetCurrentFontSize,0,_HPDF_Page_GetTransMatrix,0,_HPDF_Page_GetLineWidth,0,_HPDF_Page_GetLineCap,0,_HPDF_Page_GetLineJoin,0,_HPDF_Page_GetMiterLimit,0,_HPDF_Page_GetDash,0,_HPDF_Page_GetFlat,0,_HPDF_Page_GetWordSpace,0,_HPDF_Page_GetCharSpace,0,_HPDF_Page_GetHorizontalScalling,0,_HPDF_Page_GetTextLeading,0,_HPDF_Page_GetTextRenderingMode,0,_HPDF_Page_GetTextRaise,0,_HPDF_Page_GetTextRise,0,_HPDF_Page_GetRGBFill,0,_HPDF_Page_GetRGBStroke,0,_HPDF_Page_GetCMYKFill,0,_HPDF_Page_GetCMYKStroke,0,_HPDF_Page_GetGrayFill,0,_HPDF_Page_GetGrayStroke,0,_HPDF_Page_GetStrokingColorSpace,0,_HPDF_Page_GetFillingColorSpace,0,_HPDF_Page_GetTextMatrix,0,_HPDF_Page_GetGStateDepth,0,_HPDF_Page_GetGMode,0,_HPDF_Page_GetCurrentPos,0,_HPDF_Page_GetCurrentPos2,0,_HPDF_Page_GetCurrentTextPos,0,_HPDF_Page_GetCurrentTextPos2,0,_HPDF_Page_SetRotate,0,_HPDF_Page_SetZoom,0,_HPDF_Page_SetWidth,0,_HPDF_Page_SetHeight,0,_HPDF_Page_SetSize,0,_HPDF_Page_CreateDestination,0,_HPDF_Page_Create3DAnnot,0,_HPDF_Page_CreateTextAnnot,0,_HPDF_Page_CreateLinkAnnot,0,_HPDF_Page_CreateURILinkAnnot,0,_HPDF_LoadU3DFromFile,0,_HPDF_Create3DView,0,_HPDF_U3D_Add3DView,0,_HPDF_U3D_SetDefault3DView,0,_HPDF_3DView_AddNode,0,_HPDF_3DView_SetLighting,0,_HPDF_3DView_SetBackgroundColor,0,_HPDF_3DView_SetPerspectiveProjection,0,_HPDF_3DView_SetOrthogonalProjection,0,_HPDF_3DView_SetCamera,0]; Module["FUNCTION_TABLE"] = FUNCTION_TABLE;


function run(args) {
  args = args || Module['arguments'];

  if (runDependencies > 0) {
    Module.printErr('run() called, but dependencies remain, so not running');
    return 0;
  }

  if (Module['preRun']) {
    if (typeof Module['preRun'] == 'function') Module['preRun'] = [Module['preRun']];
    var toRun = Module['preRun'];
    Module['preRun'] = [];
    for (var i = toRun.length-1; i >= 0; i--) {
      toRun[i]();
    }
    if (runDependencies > 0) {
      // a preRun added a dependency, run will be called later
      return 0;
    }
  }

  function doRun() {
    var ret = 0;
    calledRun = true;
    if (Module['_main']) {
      preMain();
      ret = Module.callMain(args);
      if (!Module['noExitRuntime']) {
        exitRuntime();
      }
    }
    if (Module['postRun']) {
      if (typeof Module['postRun'] == 'function') Module['postRun'] = [Module['postRun']];
      while (Module['postRun'].length > 0) {
        Module['postRun'].pop()();
      }
    }
    return ret;
  }

  if (Module['setStatus']) {
    Module['setStatus']('Running...');
    setTimeout(function() {
      setTimeout(function() {
        Module['setStatus']('');
      }, 1);
      doRun();
    }, 1);
    return 0;
  } else {
    return doRun();
  }
}
Module['run'] = run;

// {{PRE_RUN_ADDITIONS}}

if (Module['preInit']) {
  if (typeof Module['preInit'] == 'function') Module['preInit'] = [Module['preInit']];
  while (Module['preInit'].length > 0) {
    Module['preInit'].pop()();
  }
}

initRuntime();

var shouldRunNow = true;
if (Module['noInitialRun']) {
  shouldRunNow = false;
}

if (shouldRunNow) {
  var ret = run();
}

// {{POST_RUN_ADDITIONS}}





  // {{MODULE_ADDITIONS}}


// EMSCRIPTEN_GENERATED_FUNCTIONS: ["_adler32","_crc32","_crc32_little","_crc32_big","_deflateInit_","_deflateInit2_","_deflateEnd","_deflateReset","_fill_window","_deflateResetKeep","_lm_init","_deflate","_putShortMSB","_flush_pending","_deflate_huff","_deflate_rle","_read_buf","_deflate_stored","_deflate_fast","_deflate_slow","_longest_match","_inflate_fast","_inflateResetKeep","_inflateReset","_inflateReset2","_inflateInit2_","_inflateInit_","_inflate","_fixedtables55","_updatewindow","_inflateEnd","_tr_static_init","_init_block","_inflate_table","__tr_init","_bi_flush","__tr_stored_block","_copy_block","__tr_flush_bits","__tr_align","__tr_flush_block","_detect_data_type","_build_tree","_build_bl_tree","_compress_block","_bi_windup","_send_all_trees","_send_tree","_bi_reverse","_scan_tree","_pqdownheap","_gen_bitlen","_gen_codes","_zcalloc","_zcfree","_png_set_sig_bytes","_png_sig_cmp","_png_zalloc","_png_zfree","_png_reset_crc","_png_calculate_crc","_png_create_info_struct","_png_info_init_3","_png_info_destroy","_png_get_header_ver","_png_64bit_product","_png_get_io_ptr","_png_free_data","_png_handle_as_unknown","_png_format_buffer","_png_set_longjmp_fn","_png_check_cHRM_fixed","_png_check_IHDR","_png_error","_png_warning","_png_default_warning","_png_chunk_error","_png_chunk_warning","_png_default_error","_png_set_error_fn","_png_get_error_ptr","_png_get_valid","_png_get_rowbytes","_png_get_color_type","_png_get_interlace_type","_png_get_PLTE","_png_get_tRNS","_png_set_mem_fn","_png_create_struct","_png_create_struct_2","_png_destroy_struct","_png_destroy_struct_2","_png_calloc","_png_malloc","_png_malloc_default","_png_free","_png_free_default","_png_malloc_warn","_png_create_read_struct","_png_read_info","_png_read_update_info","_png_create_read_struct_2","_png_read_row","_png_set_strip_16","_png_read_rows","_png_read_image","_png_destroy_read_struct","_png_read_destroy","_png_read_data","_png_default_read_data","_png_set_read_fn","_png_init_read_transformations","_png_build_gamma_table","_png_read_transform_info","_png_do_read_transformations","_png_do_expand_palette","_png_do_expand","_png_do_rgb_to_gray","_png_do_gray_to_rgb","_png_do_background","_png_do_gamma","_png_do_chop","_png_do_quantize","_png_do_unshift","_png_do_unpack","_png_do_read_filler","_png_do_read_invert_alpha","_png_do_read_swap_alpha","_png_do_read_intrapixel","_png_get_uint_31","_png_read_sig","_png_read_chunk_header","_png_check_chunk_name","_png_crc_read","_png_crc_finish","_png_crc_error","_png_decompress_chunk","_png_inflate","_png_handle_IHDR","_png_handle_PLTE","_png_handle_IEND","_png_handle_gAMA","_png_handle_sBIT","_png_handle_cHRM","_png_handle_sRGB","_png_handle_iCCP","_png_handle_sPLT","_png_handle_tRNS","_png_handle_bKGD","_png_handle_hIST","_png_handle_pHYs","_png_handle_oFFs","_png_handle_pCAL","_png_handle_sCAL","_png_handle_tIME","_png_handle_tEXt","_png_handle_zTXt","_png_handle_iTXt","_png_handle_unknown","_png_combine_row","_png_do_read_interlace","_png_read_filter_row","_png_read_finish_row","_png_set_cHRM","_png_read_start_row","_png_set_bKGD","_png_set_cHRM_fixed","_png_set_gAMA","_png_set_oFFs","_png_set_sCAL","_png_set_pHYs","_png_set_sRGB","_png_set_gAMA_fixed","_png_set_hIST","_png_set_IHDR","_png_set_pCAL","_png_set_PLTE","_png_set_sBIT","_png_set_sRGB_gAMA_and_cHRM","_png_set_iCCP","_png_set_text_2","_png_set_tIME","_png_set_tRNS","_png_set_interlace_handling","_png_do_invert","_png_do_swap","_png_do_packswap","_png_set_sPLT","_png_set_unknown_chunks","_png_do_strip_filler","_png_do_bgr","_HPDF_Annotation_New","_HPDF_LinkAnnot_New","_HPDF_URILinkAnnot_New","_HPDF_LinkAnnot_SetBorderStyle","_CheckSubType","_HPDF_LinkAnnot_SetHighlightMode","_HPDF_3DAnnot_New","_HPDF_3DAnnot_Set3DView","_HPDF_TextAnnot_New","_HPDF_TextAnnot_SetIcon","_HPDF_Annotation_Validate","_HPDF_TextAnnot_SetOpened","_HPDF_Array_New","_HPDF_Box_Array_New","_HPDF_Array_Add","_HPDF_Array_Free","_HPDF_Array_Clear","_HPDF_Array_Write","_HPDF_Array_AddNumber","_HPDF_Array_AddReal","_HPDF_Array_AddName","_HPDF_Array_Insert","_HPDF_Array_GetItem","_HPDF_Binary_New","_HPDF_Binary_SetValue","_HPDF_Binary_Write","_HPDF_Binary_Free","_HPDF_Boolean_New","_HPDF_Boolean_Write","_HPDF_Catalog_New","_HPDF_Catalog_GetRoot","_HPDF_Catalog_GetPageLayout","_HPDF_Catalog_SetPageLayout","_HPDF_Catalog_GetPageMode","_HPDF_Catalog_SetPageMode","_HPDF_Catalog_SetOpenAction","_HPDF_Catalog_AddPageLabel","_HPDF_Catalog_SetViewerPreference","_HPDF_Catalog_GetViewerPreference","_HPDF_Destination_New","_HPDF_Destination_Validate","_HPDF_Destination_SetXYZ","_HPDF_Destination_SetFit","_HPDF_Destination_SetFitH","_HPDF_Destination_SetFitV","_HPDF_Destination_SetFitR","_HPDF_Destination_SetFitB","_HPDF_Destination_SetFitBH","_HPDF_Destination_SetFitBV","_HPDF_Dict_New","_HPDF_DictStream_New","_HPDF_Dict_Add","_HPDF_Dict_Free","_HPDF_GetVersion","_HPDF_Doc_Validate","_HPDF_Dict_Write","_HPDF_Dict_RemoveElement","_HPDF_Dict_GetItem","_GetElement","_HPDF_Dict_AddName","_HPDF_Dict_AddNumber","_HPDF_Dict_AddReal","_HPDF_Dict_AddBoolean","_HPDF_Dict_GetKeyByObj","_HPDF_HasDoc","_HPDF_New","_HPDF_NewEx","_HPDF_NewDoc","_HPDF_Free","_HPDF_FreeDocAll","_HPDF_FreeDoc","_HPDF_SetInfoAttr","_CleanupFontDefList","_FreeFontDefList","_FreeEncoderList","_HPDF_SetPagesConfiguration","_HPDF_Doc_AddPagesTo","_HPDF_Doc_SetEncryptOn","_HPDF_SetPassword","_HPDF_SetPermission","_HPDF_SetEncryptionMode","_HPDF_Doc_PrepareEncryption","_GetInfo","_HPDF_SaveToStream","_InternalSaveToStream","_HPDF_GetContents","_HPDF_GetStreamSize","_HPDF_ReadFromStream","_HPDF_ResetStream","_HPDF_SaveToFile","_HPDF_GetCurrentPage","_HPDF_GetPageByIndex","_HPDF_AddPage","_HPDF_InsertPage","_HPDF_SetErrorHandler","_HPDF_Doc_FindFontDef","_HPDF_Doc_RegisterFontDef","_HPDF_GetFontDef","_HPDF_Doc_FindEncoder","_HPDF_Doc_RegisterEncoder","_HPDF_GetEncoder","_HPDF_GetCurrentEncoder","_HPDF_SetCurrentEncoder","_HPDF_GetError","_HPDF_Doc_FindFont","_HPDF_GetFont","_HPDF_LoadType1FontFromFile","_LoadType1FontFromStream","_HPDF_GetTTFontDefFromFile","_HPDF_LoadTTFontFromFile","_LoadTTFontFromStream","_HPDF_LoadTTFontFromFile2","_LoadTTFontFromStream2","_HPDF_LoadRawImageFromFile","_HPDF_LoadRawImageFromMem","_HPDF_LoadJpegImageFromFile","_HPDF_LoadJpegImageFromMem","_HPDF_GetPageLayout","_HPDF_SetPageLayout","_HPDF_GetPageMode","_HPDF_SetPageMode","_HPDF_SetOpenAction","_HPDF_GetViewerPreference","_HPDF_SetViewerPreference","_HPDF_AddPageLabel","_HPDF_GetInfoAttr","_HPDF_SetInfoDateAttr","_HPDF_BasicEncoder_ToUnicode","_HPDF_CreateOutline","_HPDF_CreateExtGState","_HPDF_SetCompressionMode","_HPDF_GetErrorDetail","_HPDF_ResetError","_WriteHeader","_PrepareTrailer","_HPDF_LoadPngImageFromMem","_LoadPngImageFromStream","_HPDF_LoadPngImageFromFile","_HPDF_LoadPngImageFromFile2","_HPDF_BasicEncoder_New","_HPDF_BasicEncoder_FindBuiltinData","_HPDF_CMapEncoder_Write","_HPDF_BasicEncoder_CopyMap","_HPDF_UnicodeToGryphName","_HPDF_Encoder_Validate","_HPDF_CMapEncoder_ToUnicode","_HPDF_BasicEncoder_Write","_HPDF_BasicEncoder_Free","_HPDF_BasicEncoder_OverrideMap","_HPDF_Encoder_ToUnicode","_HPDF_Encoder_Free","_HPDF_GryphNameToUnicode","_HPDF_CMapEncoder_New","_HPDF_CMapEncoder_ByteType","_HPDF_CMapEncoder_Free","_HPDF_CMapEncoder_ToCID","_HPDF_Encoder_SetParseText","_HPDF_CMapEncoder_SetUnicodeArray","_HPDF_CMapEncoder_InitAttr","_HPDF_Encoder_ByteType","_HPDF_CMapEncoder_AddCMap","_HPDF_CMapEncoder_AddNotDefRange","_AddCidRainge","_HPDF_CMapEncoder_AddCodeSpaceRange","_HPDF_CMapEncoder_AddJWWLineHead","_HPDF_Encoder_CheckJWWLineHead","_HPDF_Encoder_GetUnicode","_HPDF_Encoder_GetByteType","_HPDF_Encoder_GetType","_HPDF_Encoder_GetWritingMode","_GB_EUC_IsLeadByte","_GB_EUC_IsTrialByte","_GBK_EUC_IsLeadByte","_GBK_EUC_IsTrialByte","_HPDF_UseCNSEncodings","_GBK_EUC_H_Init","_GBK_EUC_V_Init","_GB_EUC_H_Init","_GB_EUC_V_Init","_GB_EUC_AddCodeSpaceRange","_GBK_EUC_AddCodeSpaceRange","_HPDF_UseCNTEncodings","_ETen_B5_H_Init","_ETen_B5_IsLeadByte","_ETen_B5_IsTrialByte","_ETen_B5_V_Init","_ETen_B5_AddCodeSpaceRange","_HPDF_UseJPEncodings","_MS_RKSJ_H_Init","_MS_RKSJ_V_Init","_MSP_RKSJ_H_Init","_EUC_H_Init","_EUC_V_Init","_EUC_IsLeadByte","_EUC_IsTrialByte","_RKSJ_IsLeadByte","_RKSJ_IsTrialByte","_EUC_AddCodeSpaceRange","_RKSJ_AddCodeSpaceRange","_HPDF_UseKREncodings","_KSCms_UHC_H_Init","_KSCms_UHC_HW_H_Init","_KSCms_UHC_HW_V_Init","_KSC_EUC_H_Init","_KSC_EUC_V_Init","_KSC_EUC_IsLeadByte","_KSC_EUC_IsTrialByte","_KSCms_UHC_IsLeadByte","_KSCms_UHC_IsTrialByte","_HPDF_MD5Init","_MD5ByteReverse","_KSC_EUC_AddCodeSpaceRange","_KSCms_UHC_AddCodeSpaceRange","_HPDF_MD5Update","_MD5Transform","_ARC4Init","_ARC4CryptBuf","_HPDF_MD5Final","_HPDF_PadOrTrancatePasswd","_HPDF_Encrypt_Init","_HPDF_Encrypt_CreateOwnerKey","_HPDF_Encrypt_CreateEncryptionKey","_HPDF_Encrypt_CreateUserKey","_HPDF_Encrypt_InitKey","_HPDF_Encrypt_Reset","_HPDF_Encrypt_CryptBuf","_HPDF_EncryptDict_GetAttr","_HPDF_Error_GetCode","_HPDF_Error_GetDetailCode","_HPDF_SetError","_HPDF_Error_Reset","_HPDF_ExtGState_Validate","_HPDF_EncryptDict_New","_HPDF_EncryptDict_OnFree","_HPDF_EncryptDict_CreateID","_HPDF_EncryptDict_Prepare","_HPDF_EncryptDict_SetPassword","_HPDF_Error_Init","_HPDF_CheckError","_HPDF_RaiseError","_ExtGState_Check","_HPDF_ExtGState_New","_HPDF_ExtGState_SetAlphaStroke","_HPDF_ExtGState_SetAlphaFill","_HPDF_ExtGState_SetBlendMode","_HPDF_Font_Validate","_HPDF_Font_TextWidth","_HPDF_Font_MeasureText","_HPDF_Font_GetFontName","_HPDF_Font_GetEncodingName","_HPDF_Font_GetUnicodeWidth","_HPDF_Font_GetBBox","_HPDF_Font_GetAscent","_HPDF_Font_GetDescent","_HPDF_Font_GetXHeight","_HPDF_Font_GetCapHeight","_HPDF_Type0Font_New","_OnFree_Func","_TextWidth","_MeasureText","_CreateCMap","_CIDFontType0_New","_CIDFontType2_New","_UINT16ToHex","_CIDFontType2_BeforeWrite_Func","_HPDF_Base14FontDef_FindBuiltinData","_HPDF_Base14FontDef_New","_HPDF_FontDef_Cleanup","_HPDF_FontDef_Free","_HPDF_CIDFontDef_FreeWidth","_HPDF_CIDFontDef_New","_HPDF_CIDFontDef_FreeFunc","_HPDF_CIDFontDef_GetCIDWidth","_HPDF_CIDFontDef_AddWidth","_HPDF_CIDFontDef_ChangeStyle","_HPDF_UseCNSFonts","_SimSun_Init","_SimSun_Bold_Init","_SimSun_Italic_Init","_SimSun_BoldItalic_Init","_SimHei_Init","_SimHei_Bold_Init","_SimHei_Italic_Init","_SimHei_BoldItalic_Init","_HPDF_UseCNTFonts","_MingLiU_Init","_MingLiU_Bold_Init","_MingLiU_Italic_Init","_MingLiU_BoldItalic_Init","_HPDF_UseJPFonts","_MS_Gothic_Init","_MS_Gothic_Bold_Init","_MS_Gothic_Italic_Init","_MS_Gothic_BoldItalic_Init","_MS_PGothic_Init","_MS_PGothic_Bold_Init","_MS_PGothic_Italic_Init","_MS_PGothic_BoldItalic_Init","_MS_Mincyo_Init","_MS_Mincyo_Bold_Init","_MS_Mincyo_Italic_Init","_MS_Mincyo_BoldItalic_Init","_MS_PMincyo_Init","_MS_PMincyo_Bold_Init","_MS_PMincyo_Italic_Init","_MS_PMincyo_BoldItalic_Init","_HPDF_UseKRFonts","_DotumChe_Init","_DotumChe_Bold_Init","_DotumChe_Italic_Init","_DotumChe_BoldItalic_Init","_Dotum_Init","_Dotum_Bold_Init","_Dotum_Italic_Init","_Dotum_BoldItalic_Init","_BatangChe_Init","_BatangChe_Bold_Init","_BatangChe_Italic_Init","_BatangChe_BoldItalic_Init","_Batang_Init","_Batang_Bold_Init","_Batang_Italic_Init","_Batang_BoldItalic_Init","_HPDF_TTFontDef_New","_CleanFunc","_FreeFunc","_HPDF_TTFontDef_Load","_LoadFontData","_HPDF_TTFontDef_Load2","_LoadFontData2","_HPDF_TTFontDef_GetCharBBox","_HPDF_TTFontDef_GetGlyphid","_GetINT16","_HPDF_TTFontDef_GetCharWidth","_CheckCompositGryph","_HPDF_TTFontDef_GetGidWidth","_HPDF_TTFontDef_SaveFontData","_WriteUINT32","_WriteUINT16","_FindTable","_WriteHeader1333","_RecreateGLYF","_RecreateName","_UINT32Swap","_HPDF_TTFontDef_SetTagName","_WriteINT16","_INT16Swap","_UINT16Swap","_GetUINT32","_LoadTTFTable","_ParseHead","_ParseMaxp","_ParseHhea","_ParseCMap","_ParseHmtx","_ParseLoca","_ParseName","_ParseOS2","_GetUINT16","_LoadUnicodeName","_ParseCMAP_format4","_ParseCMAP_format0","_InitAttr","_HPDF_Type1FontDef_New","_FreeFunc1360","_HPDF_Type1FontDef_Load","_LoadAfm","_LoadFontData1363","_HPDF_Type1FontDef_GetWidth","_HPDF_Type1FontDef_SetWidths","_FreeWidth","_GetKeyword","_HPDF_TTFont_New","_OnWrite","_BeforeWrite","_OnFree","_TextWidth1396","_MeasureText1397","_CreateDescriptor","_CharWidth","_Type1Font_MeasureText","_HPDF_Type1Font_New","_Type1Font_OnWrite","_Type1Font_OnFree","_Type1Font_TextWidth","_Type1Font_CreateDescriptor","_HPDF_GState_New","_HPDF_GState_Free","_HPDF_Image_LoadJpegImage","_LoadJpegHeader","_HPDF_Image_LoadJpegImageFromMem","_HPDF_Image_LoadRawImage","_HPDF_Image_LoadRawImageFromMem","_HPDF_Image_Validate","_HPDF_Image_GetSize","_HPDF_Image_GetSize2","_HPDF_Image_GetBitsPerComponent","_HPDF_Image_GetColorSpace","_HPDF_Image_GetWidth","_HPDF_Image_GetHeight","_HPDF_Image_SetMask","_HPDF_Image_SetMaskImage","_HPDF_Image_SetColorMask","_HPDF_Image_AddSMask","_HPDF_Image_LoadPngImage","_LoadPngData","_PngErrorFunc","_PngReadFunc","_ReadTransparentPaletteData","_CreatePallet","_ReadTransparentPngData","_PngBeforeWrite","_PngAfterWrite","_InfoTypeToName","_ReadPngData_Interlaced","_ReadPngData","_HPDF_Info_SetInfoAttr","_HPDF_Info_GetInfoAttr","_HPDF_Info_SetInfoDateAttr","_HPDF_List_New","_HPDF_List_Add","_Resize","_HPDF_List_Insert","_HPDF_List_Find","_HPDF_List_RemoveByIndex","_HPDF_List_ItemAt","_HPDF_Number_SetValue","_HPDF_List_Remove","_HPDF_List_Free","_HPDF_List_Clear","_HPDF_MMgr_New","_InternalGetMem","_InternalFreeMem","_HPDF_MMgr_Free","_HPDF_GetMem","_HPDF_FreeMem","_HPDF_Name_New","_HPDF_Name_SetValue","_HPDF_Name_Write","_HPDF_Number_New","_HPDF_Number_Write","_HPDF_Obj_Free","_HPDF_Obj_ForceFree","_HPDF_Outline_Validate","_HPDF_Obj_Write","_HPDF_Obj_WriteValue","_HPDF_Proxy_New","_HPDF_OutlineRoot_New","_BeforeWrite1535","_HPDF_Outline_New","_AddChild","_HPDF_Outline_GetOpened","_HPDF_Outline_GetFirst","_HPDF_Outline_GetNext","_HPDF_Outline_SetDestination","_HPDF_Outline_SetOpened","_CountChild","_HPDF_PageLabel_New","_HPDF_Page_SetLineWidth","_HPDF_Page_SetLineCap","_HPDF_Page_SetLineJoin","_HPDF_Page_SetMiterLimit","_HPDF_Page_SetDash","_HPDF_Page_SetFlat","_HPDF_Page_SetExtGState","_HPDF_Page_GSave","_HPDF_Page_GRestore","_HPDF_Page_Concat","_HPDF_Page_MoveTo","_HPDF_Page_LineTo","_HPDF_Page_CurveTo","_HPDF_Page_CurveTo2","_HPDF_Page_CurveTo3","_HPDF_Page_ClosePath","_HPDF_Page_Rectangle","_HPDF_Page_Stroke","_HPDF_Page_ClosePathStroke","_HPDF_Page_Fill","_HPDF_Page_Eofill","_HPDF_Page_FillStroke","_HPDF_Page_EofillStroke","_HPDF_Page_ClosePathFillStroke","_HPDF_Page_ClosePathEofillStroke","_HPDF_Page_EndPath","_HPDF_Page_Clip","_HPDF_Page_Eoclip","_HPDF_Page_BeginText","_HPDF_Page_EndText","_HPDF_Page_SetCharSpace","_HPDF_Page_SetWordSpace","_HPDF_Page_SetHorizontalScalling","_HPDF_Page_SetTextLeading","_HPDF_Page_SetFontAndSize","_HPDF_Page_SetTextRenderingMode","_HPDF_Page_SetTextRaise","_HPDF_Page_SetTextRise","_HPDF_Page_MoveTextPos","_HPDF_Page_MoveTextPos2","_HPDF_Page_SetTextMatrix","_HPDF_Page_MoveToNextLine","_HPDF_Page_ShowText","_InternalWriteText","_HPDF_Page_ShowTextNextLine","_HPDF_Page_ShowTextNextLineEx","_HPDF_Page_SetGrayFill","_HPDF_Page_SetGrayStroke","_HPDF_Page_SetRGBFill","_HPDF_Page_SetRGBStroke","_HPDF_Page_SetCMYKFill","_HPDF_Page_SetCMYKStroke","_HPDF_Page_ExecuteXObject","_HPDF_Page_Circle","_QuarterCircleA","_QuarterCircleB","_QuarterCircleC","_QuarterCircleD","_HPDF_Page_Ellipse","_QuarterEllipseA","_QuarterEllipseB","_QuarterEllipseC","_QuarterEllipseD","_HPDF_Page_Arc","_InternalArc","_HPDF_Page_DrawImage","_HPDF_Page_TextOut","_HPDF_Page_TextRect","_InternalShowTextNextLine","_HPDF_Page_SetSlideShow","_HPDF_Pages_New","_Pages_BeforeWrite","_HPDF_Pages_AddKids","_HPDF_Pages_Validate","_HPDF_Page_InsertBefore","_HPDF_Page_New","_Page_OnFree","_Page_BeforeWrite","_AddResource","_HPDF_Page_CheckState","_HPDF_Page_GetInheritableItem","_HPDF_Page_GetLocalFontName","_HPDF_Page_GetMediaBox","_HPDF_Page_Validate","_HPDF_Page_GetXObjectName","_HPDF_Page_GetExtGStateName","_HPDF_Page_TextWidth","_HPDF_Page_MeasureText","_HPDF_Page_GetWidth","_HPDF_Page_GetHeight","_HPDF_Page_GetCurrentFont","_HPDF_Page_GetCurrentFontSize","_HPDF_Page_GetTransMatrix","_HPDF_Page_GetLineWidth","_HPDF_Page_GetLineCap","_HPDF_Page_GetLineJoin","_HPDF_Page_GetMiterLimit","_HPDF_Page_GetDash","_HPDF_Page_GetFlat","_HPDF_Page_GetWordSpace","_HPDF_Page_GetCharSpace","_HPDF_Page_GetHorizontalScalling","_HPDF_Page_GetTextLeading","_HPDF_Page_GetTextRenderingMode","_HPDF_Page_GetTextRaise","_HPDF_Page_GetTextRise","_HPDF_Page_GetRGBFill","_HPDF_Page_GetRGBStroke","_HPDF_Page_GetCMYKFill","_HPDF_Page_GetCMYKStroke","_HPDF_Page_GetGrayFill","_HPDF_Page_GetGrayStroke","_HPDF_Page_GetStrokingColorSpace","_HPDF_Page_GetFillingColorSpace","_HPDF_Page_GetTextMatrix","_HPDF_Page_GetGStateDepth","_HPDF_Page_GetGMode","_HPDF_Page_GetCurrentPos","_HPDF_Page_GetCurrentPos2","_HPDF_Page_GetCurrentTextPos","_HPDF_Page_GetCurrentTextPos2","_HPDF_Page_SetBoxValue","_HPDF_Page_SetRotate","_HPDF_Page_SetZoom","_HPDF_Page_SetWidth","_HPDF_Page_SetHeight","_HPDF_Page_SetFilter","_HPDF_Page_SetSize","_HPDF_Page_CreateDestination","_HPDF_Page_Create3DAnnot","_AddAnnotation","_HPDF_Page_CreateTextAnnot","_HPDF_Page_CreateLinkAnnot","_HPDF_Page_CreateURILinkAnnot","_GetPageCount","_HPDF_Real_New","_HPDF_Real_SetValue","_HPDF_Real_Write","_HPDF_Stream_Read","_HPDF_Stream_ReadLn","_HPDF_Stream_Seek","_HPDF_Stream_Write","_HPDF_Stream_WriteChar","_HPDF_Stream_WriteStr","_HPDF_Stream_WriteInt","_HPDF_Stream_WriteUInt","_HPDF_Stream_WriteReal","_HPDF_Stream_Free","_HPDF_Stream_Tell","_HPDF_Stream_Size","_HPDF_Stream_WriteEscapeName","_HPDF_Stream_WriteEscapeText2","_HPDF_Stream_WriteEscapeText","_HPDF_Stream_WriteBinary","_HPDF_Stream_WriteToStreamWithDeflate","_HPDF_Stream_WriteToStream","_HPDF_MemStream_TellFunc","_HPDF_MemStream_SizeFunc","_HPDF_FileReader_New","_HPDF_FileReader_ReadFunc","_HPDF_FileReader_SeekFunc","_HPDF_FileStream_TellFunc","_HPDF_FileStream_SizeFunc","_HPDF_FileStream_FreeFunc","_HPDF_FileWriter_New","_HPDF_FileWriter_WriteFunc","_HPDF_MemStream_InWrite","_HPDF_MemStream_WriteFunc","_HPDF_MemStream_SeekFunc","_HPDF_MemStream_GetBufPtr","_HPDF_Stream_Validate","_HPDF_MemStream_FreeData","_HPDF_MemStream_FreeFunc","_HPDF_MemStream_New","_HPDF_MemStream_ReadFunc","_HPDF_MemStream_Rewrite","_HPDF_String_New","_HPDF_String_SetValue","_HPDF_String_Free","_HPDF_String_Write","_HPDF_LoadU3DFromFile","_HPDF_U3D_LoadU3D","_Get3DStreamType","_HPDF_Create3DView","_HPDF_U3D_Add3DView","_HPDF_U3D_SetDefault3DView","_HPDF_3DView_AddNode","_HPDF_3DView_SetLighting","_HPDF_3DView_SetBackgroundColor","_HPDF_3DView_SetPerspectiveProjection","_HPDF_3DView_SetOrthogonalProjection","_HPDF_AToI","_HPDF_IToA","_HPDF_IToA2","_HPDF_3DView_SetCamera","_HPDF_FToA","_HPDF_MemCpy","_HPDF_StrCpy","_HPDF_MemCmp","_HPDF_StrCmp","_HPDF_MemSet","_HPDF_StrLen","_HPDF_StrStr","_HPDF_ToBox","_HPDF_ToPoint","_HPDF_UInt16Swap","_HPDF_Xref_New","_HPDF_Xref_Free","_main","_HPDF_Xref_GetEntry","_HPDF_Xref_Add","_HPDF_Xref_WriteToStream","_WriteTrailer","_malloc","_tmalloc_small","_tmalloc_large","_sys_alloc","_free","_sys_trim","_segment_holding","_release_unused_segments","_init_mparams","_init_top","_mmap_alloc","_init_bins","_prepend_alloc","_add_segment"]

(function() {
  var Annotation, Destination, Encoder, ExtGState, FLOAT_SIZE, Font, HPDF, HPDF_ANNOT_INVALID_BORDER_STYLE, HPDF_ANNOT_INVALID_ICON, HPDF_ARRAY_COUNT_ERR, HPDF_ARRAY_ITEM_NOT_FOUND, HPDF_ARRAY_ITEM_UNEXPECTED_TYPE, HPDF_BINARY_LENGTH_ERR, HPDF_CANNOT_GET_PALLET, HPDF_DICT_COUNT_ERR, HPDF_DICT_ITEM_NOT_FOUND, HPDF_DICT_ITEM_UNEXPECTED_TYPE, HPDF_DICT_STREAM_LENGTH_NOT_FOUND, HPDF_DOC_ENCRYPTDICT_NOT_FOUND, HPDF_DOC_INVALID_OBJECT, HPDF_DUPLICATE_REGISTRATION, HPDF_ENCRYPT_INVALID_PASSWORD, HPDF_ERR_UNKNOWN_CLASS, HPDF_EXCEED_GSTATE_LIMIT, HPDF_EXCEED_JWW_CODE_NUM_LIMIT, HPDF_EXT_GSTATE_OUT_OF_RANGE, HPDF_EXT_GSTATE_READ_ONLY, HPDF_FAILD_TO_ALLOC_MEM, HPDF_FILE_IO_ERROR, HPDF_FILE_OPEN_ERROR, HPDF_FONT_EXISTS, HPDF_FONT_INVALID_WIDTHS_TABLE, HPDF_INVALID_AFM_HEADER, HPDF_INVALID_ANNOTATION, HPDF_INVALID_BIT_PER_COMPONENT, HPDF_INVALID_CHAR_MATRICS_DATA, HPDF_INVALID_COLOR_SPACE, HPDF_INVALID_COMPRESSION_MODE, HPDF_INVALID_DATE_TIME, HPDF_INVALID_DESTINATION, HPDF_INVALID_DOCUMENT, HPDF_INVALID_DOCUMENT_STATE, HPDF_INVALID_ENCODER, HPDF_INVALID_ENCODER_TYPE, HPDF_INVALID_ENCODING_NAME, HPDF_INVALID_ENCRYPT_KEY_LEN, HPDF_INVALID_EXT_GSTATE, HPDF_INVALID_FONT, HPDF_INVALID_FONTDEF_DATA, HPDF_INVALID_FONTDEF_TYPE, HPDF_INVALID_FONT_NAME, HPDF_INVALID_ICC_COMPONENT_NUM, HPDF_INVALID_IMAGE, HPDF_INVALID_JPEG_DATA, HPDF_INVALID_N_DATA, HPDF_INVALID_OBJECT, HPDF_INVALID_OBJ_ID, HPDF_INVALID_OPERATION, HPDF_INVALID_OUTLINE, HPDF_INVALID_PAGE, HPDF_INVALID_PAGES, HPDF_INVALID_PAGE_INDEX, HPDF_INVALID_PAGE_SLIDESHOW_TYPE, HPDF_INVALID_PARAMETER, HPDF_INVALID_PNG_IMAGE, HPDF_INVALID_STREAM, HPDF_INVALID_TTC_FILE, HPDF_INVALID_TTC_INDEX, HPDF_INVALID_U3D_DATA, HPDF_INVALID_URI, HPDF_INVALID_WX_DATA, HPDF_ITEM_NOT_FOUND, HPDF_LIBPNG_ERROR, HPDF_MISSING_FILE_NAME_ENTRY, HPDF_NAME_CANNOT_GET_NAMES, HPDF_NAME_INVALID_VALUE, HPDF_NAME_OUT_OF_RANGE, HPDF_OK, HPDF_PAGES_MISSING_KIDS_ENTRY, HPDF_PAGE_CANNOT_FIND_OBJECT, HPDF_PAGE_CANNOT_GET_ROOT_PAGES, HPDF_PAGE_CANNOT_RESTORE_GSTATE, HPDF_PAGE_CANNOT_SET_PARENT, HPDF_PAGE_FONT_NOT_FOUND, HPDF_PAGE_INSUFFICIENT_SPACE, HPDF_PAGE_INVALID_DIRECTION, HPDF_PAGE_INVALID_DISPLAY_TIME, HPDF_PAGE_INVALID_FONT, HPDF_PAGE_INVALID_FONT_SIZE, HPDF_PAGE_INVALID_GMODE, HPDF_PAGE_INVALID_INDEX, HPDF_PAGE_INVALID_PARAM_COUNT, HPDF_PAGE_INVALID_ROTATE_VALUE, HPDF_PAGE_INVALID_SIZE, HPDF_PAGE_INVALID_TRANSITION_TIME, HPDF_PAGE_INVALID_XOBJECT, HPDF_PAGE_LANDSCAPE, HPDF_PAGE_LAYOUT_OUT_OF_RANGE, HPDF_PAGE_MODE_OUT_OF_RANGE, HPDF_PAGE_NUM_STYLE_OUT_OF_RANGE, HPDF_PAGE_OUT_OF_RANGE, HPDF_PAGE_PORTRAIT, HPDF_PAGE_SIZE_A3, HPDF_PAGE_SIZE_A4, HPDF_PAGE_SIZE_A5, HPDF_PAGE_SIZE_B4, HPDF_PAGE_SIZE_B5, HPDF_PAGE_SIZE_COMM10, HPDF_PAGE_SIZE_EOF, HPDF_PAGE_SIZE_EXECUTIVE, HPDF_PAGE_SIZE_LEGAL, HPDF_PAGE_SIZE_LETTER, HPDF_PAGE_SIZE_US4x6, HPDF_PAGE_SIZE_US4x8, HPDF_PAGE_SIZE_US5x7, HPDF_REAL_OUT_OF_RANGE, HPDF_STREAM_EOF, HPDF_STREAM_READLN_CONTINUE, HPDF_STRING_OUT_OF_RANGE, HPDF_THIS_FUNC_WAS_SKIPPED, HPDF_TTF_CANNOT_EMBEDDING_FONT, HPDF_TTF_INVALID_CMAP, HPDF_TTF_INVALID_FOMAT, HPDF_TTF_MISSING_TABLE, HPDF_UNSUPPORTED_FONT_TYPE, HPDF_UNSUPPORTED_FUNC, HPDF_UNSUPPORTED_JPEG_FORMAT, HPDF_UNSUPPORTED_TYPE1_FONT, HPDF_XREF_COUNT_ERR, HPDF_ZLIB_ERROR, Image, LinkAnnotation, Outline, Page, TextAnnotation, ccall, env, fileCounter, fileify, throwIfFailed,
    __hasProp = Object.prototype.hasOwnProperty,
    __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor; child.__super__ = parent.prototype; return child; },
    __slice = Array.prototype.slice;

  if (typeof Module === "undefined" || Module === null) Module = [];

  env = typeof window !== "undefined" && window !== null ? 'browser' : 'nodejs';

  fileCounter = 0;

  FLOAT_SIZE = 4;

  HPDF = {};

  Font = (function() {

    function Font(doc, font) {
      this.doc = doc;
      this.font = font;
    }

    Font.prototype.fontName = function() {
      return ccall(this.doc, 'HPDF_Font_GetFontName', 'string', ['number'], [this.font]);
    };

    return Font;

  })();

  Encoder = (function() {

    function Encoder(doc, encoder) {
      this.doc = doc;
      this.encoder = encoder;
    }

    return Encoder;

  })();

  ExtGState = (function() {

    function ExtGState(doc, gstate) {
      this.doc = doc;
      this.gstate = gstate;
    }

    ExtGState.prototype.setAlphaFill = function(alpha) {
      return ccall(this.doc, 'HPDF_ExtGState_SetAlphaFill', 'number', ['number', 'number'], [this.gstate, alpha]);
    };

    ExtGState.prototype.setAlphaStroke = function(alpha) {
      return ccall(this.doc, 'HPDF_ExtGState_SetAlphaStroke', 'number', ['number', 'number'], [this.gstate, alpha]);
    };

    ExtGState.prototype.setBlendMode = function(mode) {
      var id;
      id = 0;
      switch (mode.toLowerCase()) {
        case 'normal':
          id = 0;
          break;
        case 'multiply':
          id = 1;
          break;
        case 'screen':
          id = 2;
          break;
        case 'overlay':
          id = 3;
          break;
        case 'darken':
          id = 4;
          break;
        case 'lighten':
          id = 5;
          break;
        case 'color_dodge':
          id = 6;
          break;
        case 'color_bum':
          id = 7;
          break;
        case 'hard_light':
          id = 8;
          break;
        case 'soft_light':
          id = 9;
          break;
        case 'difference':
          id = 10;
          break;
        case 'exclushon':
          id = 11;
      }
      return ccall(this.doc, 'HPDF_ExtGState_SetBlendMode', 'number', ['number', 'number'], [this.gstate, id]);
    };

    return ExtGState;

  })();

  Annotation = (function() {

    function Annotation(doc, annot) {
      this.doc = doc;
      this.annot = annot;
    }

    Annotation.prototype.setBorderStyle = function(subtype, width, dash_on, dash_off, dash_phase) {
      switch (subtype.toLowerCase()[0]) {
        case 's':
          0;
          break;
        case 'd':
          1;
          break;
        case 'b':
          2;
          break;
        case 'i':
          3;
          break;
        case 'u':
          4;
      }
      return ccall(this.doc, 'HPDF_Annot_SetBorderStyle', 'number', ['number', 'number', 'number', 'number', 'number', 'number'], [this.annot, id, width, dash_on, dash_off, dash_phase]);
    };

    return Annotation;

  })();

  LinkAnnotation = (function(_super) {

    __extends(LinkAnnotation, _super);

    function LinkAnnotation() {
      LinkAnnotation.__super__.constructor.apply(this, arguments);
    }

    LinkAnnotation.prototype.setHighlightMode = function(mode) {
      var id;
      id = 0;
      switch (mode.toUpperCase()) {
        case 'NO_HIGHTLIGHT':
          id = 0;
          break;
        case 'INVERT_BOX':
          id = 1;
          break;
        case 'INVERT_BORDER':
          id = 2;
          break;
        case 'DOWN_APPEARANCE':
          id = 3;
      }
      return ccall(this.doc, 'HPDF_LinkAnnot_SetHighlightMode', 'number', ['number'], [this.annot, id]);
    };

    LinkAnnotation.prototype.setBorderStyle = function(width, dash_on, dash_off) {
      return ccall(this.doc, 'HPDF_LinkAnnot_SetBorderStyle', 'number', ['number', 'number', 'number', 'number'], [this.annot, width, dash_on, dash_off]);
    };

    return LinkAnnotation;

  })(Annotation);

  TextAnnotation = (function(_super) {

    __extends(TextAnnotation, _super);

    function TextAnnotation() {
      TextAnnotation.__super__.constructor.apply(this, arguments);
    }

    TextAnnotation.prototype.setIcon = function(icon) {
      var id;
      id = 0;
      switch (icon.toLowerCase()[0]) {
        case 'c':
          id = 0;
          break;
        case 'k':
          id = 1;
          break;
        case 'n':
          id = 2;
          break;
        case 'h':
          id = 3;
          break;
        case 'n':
          id = 4;
          break;
        case 'p':
          id = 5;
          break;
        case 'i':
          id = 6;
      }
      return ccall(this.doc, 'HPDF_TextAnnot_SetIcon', 'number', ['number'], [this.annot, id]);
    };

    TextAnnotation.prototype.setOpened = function(opened) {
      return ccall(this.doc, 'HPDF_TextAnnot_SetOpened', 'number', ['number'], [this.annot, opened ? 1 : 0]);
    };

    return TextAnnotation;

  })(Annotation);

  Outline = (function() {

    function Outline(doc, outline) {
      this.doc = doc;
      this.outline = outline;
    }

    Outline.prototype.setDestination = function(dst) {
      return ccall(this.doc, 'HPDF_Outline_SetDestination', 'number', ['number', 'number'], [this.outline, dst.dst]);
    };

    Outline.prototype.setOpened = function(is_open) {
      return ccall(this.doc, 'HPDF_Outline_SetOpened', 'number', ['number', 'number'], [this.outline, is_open ? 1 : 0]);
    };

    return Outline;

  })();

  Destination = (function() {

    function Destination(doc, dst) {
      this.doc = doc;
      this.dst = dst;
    }

    Destination.prototype.setXYZ = function(left, top, zoom) {
      return ccall(this.doc, 'HPDF_Destination_SetXYZ', 'number', ['number', 'number', 'number', 'number'], [this.dst, left, top, zoom]);
    };

    return Destination;

  })();

  Image = (function() {

    function Image(doc, image) {
      this.doc = doc;
      this.image = image;
    }

    Image.prototype.width = function() {
      return ccall(this.doc, 'HPDF_Image_GetWidth', 'number', ['number'], [this.image]);
    };

    Image.prototype.height = function() {
      return ccall(this.doc, 'HPDF_Image_GetHeight', 'number', ['number'], [this.image]);
    };

    return Image;

  })();

  Page = (function() {

    function Page(doc, page) {
      this.doc = doc;
      this.page = page;
    }

    Page.prototype.concat = function(a, b, c, d, x, y) {
      return ccall(this.doc, 'HPDF_Page_Concat', 'number', ['number', 'number', 'number', 'number', 'number', 'number', 'number'], [this.page, a, b, c, d, x, y]);
    };

    Page.prototype.setTextMatrix = function(a, b, c, d, x, y) {
      return ccall(this.doc, 'HPDF_Page_SetTextMatrix', 'number', ['number', 'number', 'number', 'number', 'number', 'number', 'number'], [this.page, a, b, c, d, x, y]);
    };

    Page.prototype.textMatrix = function() {
      return ccall(this.doc, 'HPDF_Page_GetTextMatrix', 'number', ['number'], [this.page]);
    };

    Page.prototype.closePathFillStroke = function() {
      return ccall(this.doc, 'HPDF_Page_ClosePathFillStroke', 'number', ['number'], [this.page]);
    };

    Page.prototype.setFontAndSize = function(font, size) {
      return ccall(this.doc, 'HPDF_Page_SetFontAndSize', 'number', ['number', 'number', 'number'], [this.page, font.font, size]);
    };

    Page.prototype.setGrayFill = function(grayness) {
      return ccall(this.doc, 'HPDF_Page_SetGrayFill', 'number', ['number', 'number'], [this.page, grayness]);
    };

    Page.prototype.setGrayStroke = function(stroke) {
      return ccall(this.doc, 'HPDF_Page_SetGrayStroke', 'number', ['number', 'number'], [this.page, stroke]);
    };

    Page.prototype.currentPos = function() {
      var ptr;
      ptr = Module['allocate']([0, 0], 'float', ALLOC_NORMAL);
      ccall(this.doc, 'HPDF_Page_GetCurrentPos', 'number', ['number', 'number'], [ptr, this.page]);
      return {
        x: getValue(ptr, 'float'),
        y: getValue(ptr + FLOAT_SIZE, 'float')
      };
    };

    Page.prototype.currentTextPos = function() {
      var ptr;
      ptr = Module['allocate']([0, 0], 'float', ALLOC_NORMAL);
      ccall(this.doc, 'HPDF_Page_GetCurrentTextPos', 'number', ['number', 'number'], [ptr, this.page]);
      return {
        x: getValue(ptr, 'float'),
        y: getValue(ptr + FLOAT_SIZE, 'float')
      };
    };

    Page.prototype.createDestination = function() {
      var ret;
      ret = ccall(this.doc, 'HPDF_Page_CreateDestination', 'number', ['number'], [this.page]);
      return new Destination(this.doc, ret);
    };

    Page.prototype.createTextAnnot = function(rect, text, encoder) {
      var ret;
      if (!(rect instanceof Array)) {
        rect = [rect.left, rect.bottom, rect.right, rect.top];
      }
      ret = ccall(this.doc, 'HPDF_Page_CreateTextAnnot', 'number', ['number', 'number', 'number', 'number', 'number', 'string', 'number'], [this.page, rect[0], rect[1], rect[2], rect[3], text, encoder != null ? encoder.encoder : void 0]);
      return new TextAnnotation(this.doc, ret);
    };

    Page.prototype.createURILinkAnnot = function(rect, uri) {
      var ret;
      if (!(rect instanceof Array)) {
        rect = [rect.left, rect.bottom, rect.right, rect.top];
      }
      ret = ccall(this.doc, 'HPDF_Page_CreateURILinkAnnot', 'number', ['number', 'number', 'number', 'number', 'number', 'string'], [this.page, rect[0], rect[1], rect[2], rect[3], uri]);
      return new Annotation(this.doc, ret);
    };

    Page.prototype.createLinkAnnot = function(rect, dst) {
      var ret;
      if (!(rect instanceof Array)) {
        rect = [rect.left, rect.bottom, rect.right, rect.top];
      }
      ret = ccall(this.doc, 'HPDF_Page_CreateLinkAnnot', 'number', ['number', 'number', 'number', 'number', 'number', 'number'], [this.page, rect[0], rect[1], rect[2], rect[3], dst.dst]);
      return new LinkAnnotation(this.doc, ret);
    };

    Page.prototype.setSize = function(size, orientation) {
      var o, s;
      switch (size.toLowerCase()) {
        case 'letter':
          s = HPDF_PAGE_SIZE_LETTER;
          break;
        case 'legal':
          s = HPDF_PAGE_SIZE_LEGAL;
          break;
        case 'a3':
          s = HPDF_PAGE_SIZE_A3;
          break;
        case 'a4':
          s = HPDF_PAGE_SIZE_A4;
          break;
        case 'a5':
          s = HPDF_PAGE_SIZE_A5;
          break;
        case 'b4':
          s = HPDF_PAGE_SIZE_B4;
          break;
        case 'b5':
          s = HPDF_PAGE_SIZE_B5;
          break;
        case 'executive':
          s = HPDF_PAGE_SIZE_EXECUTIVE;
          break;
        case 'us4x6':
          s = HPDF_PAGE_SIZE_US4x6;
          break;
        case 'us4x8':
          s = HPDF_PAGE_SIZE_US4x8;
          break;
        case 'us5x7':
          s = HPDF_PAGE_SIZE_US5x7;
      }
      if (orientation === 'l' || orientation === 'landscape') {
        o = HPDF_PAGE_LANDSCAPE;
      } else {
        o = HPDF_PAGE_PORTRAIT;
      }
      return ccall(this.doc, 'HPDF_Page_SetSize', 'number', ['number', 'number', 'number'], [this.page, s, o]);
    };

    Page.prototype.drawImage = function(image, x, y, w, h) {
      return ccall(this.doc, 'HPDF_Page_DrawImage', 'number', ['number', 'number', 'number', 'number', 'number', 'number'], [this.page, image.image, x, y, w, h]);
    };

    Page.prototype.textWidth = function(text) {
      return ccall(this.doc, 'HPDF_Page_TextWidth', 'number', ['number', 'string'], [this.page, text]);
    };

    Page.prototype.setWidth = function(w) {
      return ccall(this.doc, 'HPDF_Page_SetWidth', 'number', ['number', 'number'], [this.page, w]);
    };

    Page.prototype.setHeight = function(h) {
      return ccall(this.doc, 'HPDF_Page_SetHeight', 'number', ['number', 'number'], [this.page, h]);
    };

    Page.prototype.beginText = function() {
      return ccall(this.doc, 'HPDF_Page_BeginText', 'number', ['number'], [this.page]);
    };

    Page.prototype.height = function() {
      return ccall(this.doc, 'HPDF_Page_GetHeight', 'number', ['number'], [this.page]);
    };

    Page.prototype.width = function() {
      return ccall(this.doc, 'HPDF_Page_GetWidth', 'number', ['number'], [this.page]);
    };

    Page.prototype.setLineWidth = function(w) {
      return ccall(this.doc, 'HPDF_Page_SetLineWidth', 'number', ['number', 'number'], [this.page, w]);
    };

    Page.prototype.getLineWidth = function() {
      return ccall(this.doc, 'HPDF_Page_GetLineWidth', 'number', ['number'], [this.page]);
    };

    Page.prototype.rectangle = function(x1, y1, x2, y2) {
      return ccall(this.doc, 'HPDF_Page_Rectangle', 'number', ['number', 'number', 'number', 'number', 'number'], [this.page, x1, y1, x2, y2]);
    };

    Page.prototype.stroke = function() {
      return ccall(this.doc, 'HPDF_Page_Stroke', 'number', ['number'], [this.page]);
    };

    Page.prototype.moveTextPos = function(x, y) {
      return ccall(this.doc, 'HPDF_Page_MoveTextPos', 'number', ['number', 'number', 'number'], [this.page, x, y]);
    };

    Page.prototype.showText = function(text) {
      return ccall(this.doc, 'HPDF_Page_ShowText', 'number', ['number', 'string'], [this.page, text]);
    };

    Page.prototype.textOut = function(x, y, text) {
      return ccall(this.doc, 'HPDF_Page_TextOut', 'number', ['number', 'number', 'number', 'string'], [this.page, x, y, text]);
    };

    Page.prototype.textRect = function(left, top, right, bottom, text, align) {
      var len_ptr, rect;
      if (left instanceof Array) {
        rect = left;
        text = top;
        align = right;
        left = rect[0], top = rect[1], right = rect[2], bottom = rect[3];
      }
      if (left instanceof Object) {
        rect = left;
        text = top;
        align = right;
        left = rect.left;
        top = rect.top;
        right = rect.right;
        bottom = rect.bottom;
      }
      switch (align[0].toLowerCase()) {
        case 'l':
          align = 0;
          break;
        case 'r':
          align = 1;
          break;
        case 'c':
          align = 2;
          break;
        case 'j':
          align = 3;
      }
      len_ptr = Module['allocate']([0], 'i32', ALLOC_NORMAL);
      ccall(this.doc, 'HPDF_Page_TextRect', 'number', ['number', 'number', 'number', 'number', 'number', 'string', 'number', 'number'], [this.page, left, top, right, bottom, text, align, len_ptr]);
      return getValue(len_ptr, 'i32');
    };

    Page.prototype.moveTo = function(x, y) {
      return ccall(this.doc, 'HPDF_Page_MoveTo', 'number', ['number', 'number', 'number'], [this.page, x, y]);
    };

    Page.prototype.moveToNextLine = function() {
      return ccall(this.doc, 'HPDF_Page_MoveToNextLine', 'number', ['number'], [this.page]);
    };

    Page.prototype.setRGBStroke = function(r, g, b) {
      return ccall(this.doc, 'HPDF_Page_SetRGBStroke', 'number', ['number', 'number', 'number', 'number'], [this.page, r, g, b]);
    };

    Page.prototype.setRGBFill = function(r, g, b) {
      return ccall(this.doc, 'HPDF_Page_SetRGBFill', 'number', ['number', 'number', 'number', 'number'], [this.page, r, g, b]);
    };

    Page.prototype.lineTo = function(x, y) {
      return ccall(this.doc, 'HPDF_Page_LineTo', 'number', ['number', 'number', 'number'], [this.page, x, y]);
    };

    Page.prototype.curveTo2 = function(x2, y2, x3, y3) {
      return ccall(this.doc, 'HPDF_Page_CurveTo2', 'number', ['number', 'number', 'number', 'number', 'number'], [this.page, x2, y2, x3, y3]);
    };

    Page.prototype.curveTo3 = function(x1, y1, x3, y3) {
      return ccall(this.doc, 'HPDF_Page_CurveTo3', 'number', ['number', 'number', 'number', 'number', 'number'], [this.page, x1, y1, x3, y3]);
    };

    Page.prototype.curveTo = function(x1, y1, x2, y2, x3, y3) {
      return ccall(this.doc, 'HPDF_Page_CurveTo', 'number', ['number', 'number', 'number', 'number', 'number', 'number', 'number'], [this.page, x1, y1, x2, y2, x3, y3]);
    };

    Page.prototype.setTextLeading = function(leading) {
      return ccall(this.doc, 'HPDF_Page_SetTextLeading', 'number', ['number', 'number'], [this.page, leading]);
    };

    Page.prototype.showTextNextLine = function(text) {
      return ccall(this.doc, 'HPDF_Page_ShowTextNextLine', 'number', ['number', 'string'], [this.page, text]);
    };

    Page.prototype.fill = function() {
      return ccall(this.doc, 'HPDF_Page_Fill', 'number', ['number'], [this.page]);
    };

    Page.prototype.fillStroke = function() {
      return ccall(this.doc, 'HPDF_Page_FillStroke', 'number', ['number'], [this.page]);
    };

    Page.prototype.setLineCap = function(type) {
      var id;
      switch (type.toLowerCase()[0]) {
        case 'b':
          id = 0;
          break;
        case 'r':
          id = 1;
          break;
        case 'p':
          id = 2;
          break;
        default:
          id = 0;
      }
      return ccall(this.doc, 'HPDF_Page_SetLineCap', 'number', ['number', 'number'], [this.page, id]);
    };

    Page.prototype.setDash = function(dash, phase) {
      if (dash.length === 0) {
        return ccall(this.doc, 'HPDF_Page_SetDash', 'number', ['number', 'number', 'number', 'number'], [this.page, 0, 0, phase]);
      } else {
        return console.warn('setDash() TODO: understand why the "dash" variable is not passed correctly');
      }
    };

    Page.prototype.gSave = function() {
      return ccall(this.doc, 'HPDF_Page_GSave', 'number', ['number'], [this.page]);
    };

    Page.prototype.gRestore = function() {
      return ccall(this.doc, 'HPDF_Page_GRestore', 'number', ['number'], [this.page]);
    };

    Page.prototype.clip = function() {
      return ccall(this.doc, 'HPDF_Page_Clip', 'number', ['number'], [this.page]);
    };

    Page.prototype.setLineJoin = function(type) {
      var id;
      switch (type.toLowerCase()[0]) {
        case 'm':
          id = 0;
          break;
        case 'r':
          id = 1;
          break;
        case 'b':
          id = 2;
          break;
        default:
          id = 0;
      }
      return ccall(this.doc, 'HPDF_Page_SetLineJoin', 'number', ['number', 'number'], [this.page, id]);
    };

    Page.prototype.endText = function() {
      return ccall(this.doc, 'HPDF_Page_EndText', 'number', ['number'], [this.page]);
    };

    Page.prototype.setFillRGB = function(r, g, b) {
      return ccall(this.doc, 'HPDF_Page_SetFillRGB', 'number', ['number', 'number', 'number', 'number'], [this.page, r, g, b]);
    };

    Page.prototype.arc = function(x, y, ray, arc1, arc2) {
      return ccall(this.doc, 'HPDF_Page_Arc', 'number', ['number', 'number', 'number', 'number', 'number', 'number'], [this.page, x, y, ray, arc1, arc2]);
    };

    Page.prototype.setExtGState = function(gstate) {
      return ccall(this.doc, 'HPDF_Page_SetExtGState', 'number', ['number', 'number'], [this.page, gstate.gstate]);
    };

    Page.prototype.circle = function(x, y, ray) {
      return ccall(this.doc, 'HPDF_Page_Circle', 'number', ['number', 'number', 'number', 'number'], [this.page, x, y, ray]);
    };

    return Page;

  })();

  HPDF = (function() {

    function HPDF() {
      this.hpdf = Module['ccall']('HPDF_New', 'number', ['number', 'number'], [0, 0]);
      if (this.hpdf === 0) throw 'Error calling HPDF_New';
    }

    HPDF.prototype.free = function() {
      return Module['ccall']('HPDF_Free', 'void', ['number'], [this.hpdf]);
    };

    HPDF.prototype.font = function(name, encoding) {
      var ret;
      ret = ccall(this, 'HPDF_GetFont', 'number', ['number', 'string', 'string'], [this.hpdf, name, encoding]);
      return new Font(this, ret);
    };

    HPDF.prototype.createExtGState = function() {
      var ret;
      ret = ccall(this, 'HPDF_CreateExtGState', 'number', ['number'], [this.hpdf]);
      return new ExtGState(this, ret);
    };

    HPDF.prototype.encoder = function(name) {
      var ret;
      ret = ccall(this, 'HPDF_GetEncoder', 'number', ['number', 'string'], [this.hpdf, name]);
      return new Encoder(this, ret);
    };

    HPDF.prototype.toArrayBuffer = function() {
      var filename;
      filename = "pdf_file" + (fileCounter++) + ".pdf";
      FS.createDataFile('/', filename, '', true, true);
      ccall(this, 'HPDF_SaveToFile', 'number', ['number', 'string'], [this.hpdf, filename]);
      return FS.analyzePath(filename).object.contents;
    };

    HPDF.prototype.toBuffer = function() {
      return new Buffer(new Uint8Array(this.toArrayBuffer()));
    };

    HPDF.prototype.saveToFile = function(file_name) {
      var fs;
      if (env !== 'nodejs') {
        throw 'saveToFile() is only supported for NodeJS and not for browsers';
      }
      fs = require('fs');
      return fs.writeFileSync(file_name, this.toBuffer());
    };

    HPDF.prototype.loadTTFont = function(file, opts) {
      var embed_flag, filename, font_name;
      embed_flag = 1;
      if (opts == null) opts = {};
      if ((opts.embed != null) && opts.embed === false) embed_flag = 0;
      filename = fileify(file);
      font_name = ccall(this, 'HPDF_LoadTTFontFromFile', 'string', ['number', 'string', 'number'], [this.hpdf, filename, embed_flag]);
      return this.font(font_name, opts.encoding);
    };

    HPDF.prototype.loadType1Font = function(afm_file, pfm_file, opts) {
      var afm_filename, font_name, pfm_filename;
      if (opts == null) opts = {};
      afm_filename = fileify(afm_file);
      if (!(pfm_file != null)) {
        font_name = ccall(this, 'HPDF_LoadType1FontFromFile', 'string', ['number', 'string', 'number'], [this.hpdf, afm_filename, 0]);
      } else {
        pfm_filename = fileify(pfm_file);
        font_name = ccall(this, 'HPDF_LoadType1FontFromFile', 'string', ['number', 'string', 'string'], [this.hpdf, afm_filename, pfm_filename]);
      }
      return font_name;
    };

    HPDF.prototype.setCompressionMode = function(mode) {
      var id;
      mode = mode.toLowerCase();
      id = 0;
      if (mode.indexOf('t') !== -1) id |= 0x1;
      if (mode.indexOf('i') !== -1) id |= 0x2;
      if (mode.indexOf('m') !== -1) id |= 0x4;
      if (mode.indexOf('a') !== -1) id |= 0xf;
      return ccall(this, 'HPDF_SetCompressionMode', 'number', ['number', 'number'], [this.hpdf, id]);
    };

    HPDF.prototype.currentPage = function() {
      var page;
      page = ccall(this, 'HPDF_GetCurrentPage', 'number', ['number'], [this.hpdf]);
      return new Page(this, page);
    };

    HPDF.prototype.setPassword = function(owner_passwd, user_passwd) {
      return ccall(this, 'HPDF_SetPassword', 'number', ['number', 'string', 'string'], [this.hpdf, owner_passwd, user_passwd]);
    };

    HPDF.prototype.loadPngImage = function(file) {
      var filename, image;
      filename = fileify(file);
      image = ccall(this, 'HPDF_LoadPngImageFromFile', 'number', ['number', 'string'], [this.hpdf, filename]);
      return new Image(this, image);
    };

    HPDF.prototype.loadRawImage = function(file, width, height, color_space) {
      var filename, id, image;
      filename = fileify(file);
      id = 0;
      switch (color_space.toLowerCase()[0]) {
        case 'g':
          id = 0;
          break;
        case 'r':
          id = 1;
          break;
        case 'c':
          id = 2;
      }
      image = ccall(this, 'HPDF_LoadRawImageFromFile', 'number', ['number', 'string', 'number', 'number', 'number'], [this.hpdf, filename, width, height, id]);
      return new Image(this, image);
    };

    HPDF.prototype.loadJpegImage = function(file) {
      var filename, image;
      filename = fileify(file);
      image = ccall(this, 'HPDF_LoadJpegImageFromFile', 'number', ['number', 'string'], [this.hpdf, filename]);
      return new Image(this, image);
    };

    HPDF.prototype.toDataUri = function() {
      var base64, bytes;
      bytes = new Uint8Array(this.toArrayBuffer());
      base64 = window.btoa(String.fromCharCode.apply(null, bytes));
      return 'data:application/pdf;base64,' + base64;
    };

    HPDF.prototype.setOpenAction = function(dst) {
      return ccall(this, 'HPDF_SetOpenAction', 'number', ['number', 'number'], [this.hpdf, dst.dst]);
    };

    HPDF.prototype.useJPEncodings = function() {
      return ccall(this, 'HPDF_UseJPEncodings', 'number', ['number'], [this.hpdf]);
    };

    HPDF.prototype.useJPFonts = function() {
      return ccall(this, 'HPDF_UseJPFonts', 'number', ['number'], [this.hpdf]);
    };

    HPDF.prototype.setPageMode = function(mode) {
      var id;
      switch (mode.toLowerCase()[0]) {
        case 'n':
          id = 0;
          break;
        case 'o':
          id = 1;
          break;
        case 't':
          id = 2;
          break;
        case 'f':
          id = 3;
      }
      return ccall(this, 'HPDF_SetPageMode', 'number', ['number', 'number'], [this.hpdf, id]);
    };

    HPDF.prototype.addPage = function() {
      var ret;
      ret = ccall(this, 'HPDF_AddPage', 'number', ['number'], [this.hpdf]);
      return new Page(this, ret);
    };

    HPDF.prototype.createOutline = function(parent, title, encoder) {
      var ret;
      ret = ccall(this, 'HPDF_CreateOutline', 'number', ['number', 'number', 'string', 'number'], [this.hpdf, parent, title, encoder != null ? encoder.encoder : void 0]);
      return new Outline(this, ret);
    };

    return HPDF;

  })();

  fileify = function(file) {
    var contents, filename, real_fs;
    filename = 'cannot_fileify_';
    if (file instanceof ArrayBuffer) {
      filename = "file" + (fileCounter++);
      FS.createDataFile('/', filename, new Uint8Array(file), true, true);
    }
    if (typeof file === 'string') {
      if (env !== 'nodejs') throw 'Filenames are only be supported for nodejs';
      real_fs = require('fs');
      contents = real_fs.readFileSync(file);
      filename = "file" + (fileCounter++);
      FS.createDataFile('/', filename, contents, true, true);
    }
    return filename;
  };

  ccall = function() {
    var args, doc, fn_name, ret;
    args = 1 <= arguments.length ? __slice.call(arguments, 0) : [];
    doc = args.shift();
    console.log(doc, args);
    ret = Module['ccall'].apply(Module, args);
    fn_name = args[0];
    throwIfFailed(doc, fn_name);
    return ret;
  };

  HPDF_OK = 0;

  throwIfFailed = function(doc, function_name) {
    var ret;
    ret = Module['ccall']('HPDF_GetError', 'number', ['number'], [doc.hpdf]);
    if (ret === HPDF_INVALID_DOCUMENT) throw 'Error calling HPDF_GetError';
    if (ret !== HPDF_OK) {
      throw ("Error calling " + function_name + ": error code ") + ret;
    }
    return true;
  };

  HPDF_ARRAY_COUNT_ERR = 0x1001;

  HPDF_ARRAY_ITEM_NOT_FOUND = 0x1002;

  HPDF_ARRAY_ITEM_UNEXPECTED_TYPE = 0x1003;

  HPDF_BINARY_LENGTH_ERR = 0x1004;

  HPDF_CANNOT_GET_PALLET = 0x1005;

  HPDF_DICT_COUNT_ERR = 0x1007;

  HPDF_DICT_ITEM_NOT_FOUND = 0x1008;

  HPDF_DICT_ITEM_UNEXPECTED_TYPE = 0x1009;

  HPDF_DICT_STREAM_LENGTH_NOT_FOUND = 0x100A;

  HPDF_DOC_ENCRYPTDICT_NOT_FOUND = 0x100B;

  HPDF_DOC_INVALID_OBJECT = 0x100C;

  HPDF_DUPLICATE_REGISTRATION = 0x100E;

  HPDF_EXCEED_JWW_CODE_NUM_LIMIT = 0x100F;

  HPDF_ENCRYPT_INVALID_PASSWORD = 0x1011;

  HPDF_ERR_UNKNOWN_CLASS = 0x1013;

  HPDF_EXCEED_GSTATE_LIMIT = 0x1014;

  HPDF_FAILD_TO_ALLOC_MEM = 0x1015;

  HPDF_FILE_IO_ERROR = 0x1016;

  HPDF_FILE_OPEN_ERROR = 0x1017;

  HPDF_FONT_EXISTS = 0x1019;

  HPDF_FONT_INVALID_WIDTHS_TABLE = 0x101A;

  HPDF_INVALID_AFM_HEADER = 0x101B;

  HPDF_INVALID_ANNOTATION = 0x101C;

  HPDF_INVALID_BIT_PER_COMPONENT = 0x101E;

  HPDF_INVALID_CHAR_MATRICS_DATA = 0x101F;

  HPDF_INVALID_COLOR_SPACE = 0x1020;

  HPDF_INVALID_COMPRESSION_MODE = 0x1021;

  HPDF_INVALID_DATE_TIME = 0x1022;

  HPDF_INVALID_DESTINATION = 0x1023;

  HPDF_INVALID_DOCUMENT = 0x1025;

  HPDF_INVALID_DOCUMENT_STATE = 0x1026;

  HPDF_INVALID_ENCODER = 0x1027;

  HPDF_INVALID_ENCODER_TYPE = 0x1028;

  HPDF_INVALID_ENCODING_NAME = 0x102B;

  HPDF_INVALID_ENCRYPT_KEY_LEN = 0x102C;

  HPDF_INVALID_FONTDEF_DATA = 0x102D;

  HPDF_INVALID_FONTDEF_TYPE = 0x102E;

  HPDF_INVALID_FONT_NAME = 0x102F;

  HPDF_INVALID_IMAGE = 0x1030;

  HPDF_INVALID_JPEG_DATA = 0x1031;

  HPDF_INVALID_N_DATA = 0x1032;

  HPDF_INVALID_OBJECT = 0x1033;

  HPDF_INVALID_OBJ_ID = 0x1034;

  HPDF_INVALID_OPERATION = 0x1035;

  HPDF_INVALID_OUTLINE = 0x1036;

  HPDF_INVALID_PAGE = 0x1037;

  HPDF_INVALID_PAGES = 0x1038;

  HPDF_INVALID_PARAMETER = 0x1039;

  HPDF_INVALID_PNG_IMAGE = 0x103B;

  HPDF_INVALID_STREAM = 0x103C;

  HPDF_MISSING_FILE_NAME_ENTRY = 0x103D;

  HPDF_INVALID_TTC_FILE = 0x103F;

  HPDF_INVALID_TTC_INDEX = 0x1040;

  HPDF_INVALID_WX_DATA = 0x1041;

  HPDF_ITEM_NOT_FOUND = 0x1042;

  HPDF_LIBPNG_ERROR = 0x1043;

  HPDF_NAME_INVALID_VALUE = 0x1044;

  HPDF_NAME_OUT_OF_RANGE = 0x1045;

  HPDF_PAGE_INVALID_PARAM_COUNT = 0x1048;

  HPDF_PAGES_MISSING_KIDS_ENTRY = 0x1049;

  HPDF_PAGE_CANNOT_FIND_OBJECT = 0x104A;

  HPDF_PAGE_CANNOT_GET_ROOT_PAGES = 0x104B;

  HPDF_PAGE_CANNOT_RESTORE_GSTATE = 0x104C;

  HPDF_PAGE_CANNOT_SET_PARENT = 0x104D;

  HPDF_PAGE_FONT_NOT_FOUND = 0x104E;

  HPDF_PAGE_INVALID_FONT = 0x104F;

  HPDF_PAGE_INVALID_FONT_SIZE = 0x1050;

  HPDF_PAGE_INVALID_GMODE = 0x1051;

  HPDF_PAGE_INVALID_INDEX = 0x1052;

  HPDF_PAGE_INVALID_ROTATE_VALUE = 0x1053;

  HPDF_PAGE_INVALID_SIZE = 0x1054;

  HPDF_PAGE_INVALID_XOBJECT = 0x1055;

  HPDF_PAGE_OUT_OF_RANGE = 0x1056;

  HPDF_REAL_OUT_OF_RANGE = 0x1057;

  HPDF_STREAM_EOF = 0x1058;

  HPDF_STREAM_READLN_CONTINUE = 0x1059;

  HPDF_STRING_OUT_OF_RANGE = 0x105B;

  HPDF_THIS_FUNC_WAS_SKIPPED = 0x105C;

  HPDF_TTF_CANNOT_EMBEDDING_FONT = 0x105D;

  HPDF_TTF_INVALID_CMAP = 0x105E;

  HPDF_TTF_INVALID_FOMAT = 0x105F;

  HPDF_TTF_MISSING_TABLE = 0x1060;

  HPDF_UNSUPPORTED_FONT_TYPE = 0x1061;

  HPDF_UNSUPPORTED_FUNC = 0x1062;

  HPDF_UNSUPPORTED_JPEG_FORMAT = 0x1063;

  HPDF_UNSUPPORTED_TYPE1_FONT = 0x1064;

  HPDF_XREF_COUNT_ERR = 0x1065;

  HPDF_ZLIB_ERROR = 0x1066;

  HPDF_INVALID_PAGE_INDEX = 0x1067;

  HPDF_INVALID_URI = 0x1068;

  HPDF_PAGE_LAYOUT_OUT_OF_RANGE = 0x1069;

  HPDF_PAGE_MODE_OUT_OF_RANGE = 0x1070;

  HPDF_PAGE_NUM_STYLE_OUT_OF_RANGE = 0x1071;

  HPDF_ANNOT_INVALID_ICON = 0x1072;

  HPDF_ANNOT_INVALID_BORDER_STYLE = 0x1073;

  HPDF_PAGE_INVALID_DIRECTION = 0x1074;

  HPDF_INVALID_FONT = 0x1075;

  HPDF_PAGE_INSUFFICIENT_SPACE = 0x1076;

  HPDF_PAGE_INVALID_DISPLAY_TIME = 0x1077;

  HPDF_PAGE_INVALID_TRANSITION_TIME = 0x1078;

  HPDF_INVALID_PAGE_SLIDESHOW_TYPE = 0x1079;

  HPDF_EXT_GSTATE_OUT_OF_RANGE = 0x1080;

  HPDF_INVALID_EXT_GSTATE = 0x1081;

  HPDF_EXT_GSTATE_READ_ONLY = 0x1082;

  HPDF_INVALID_U3D_DATA = 0x1083;

  HPDF_NAME_CANNOT_GET_NAMES = 0x1084;

  HPDF_INVALID_ICC_COMPONENT_NUM = 0x1085;

  HPDF_PAGE_SIZE_LETTER = 0;

  HPDF_PAGE_SIZE_LEGAL = 1;

  HPDF_PAGE_SIZE_A3 = 2;

  HPDF_PAGE_SIZE_A4 = 3;

  HPDF_PAGE_SIZE_A5 = 4;

  HPDF_PAGE_SIZE_B4 = 5;

  HPDF_PAGE_SIZE_B5 = 6;

  HPDF_PAGE_SIZE_EXECUTIVE = 7;

  HPDF_PAGE_SIZE_US4x6 = 8;

  HPDF_PAGE_SIZE_US4x8 = 9;

  HPDF_PAGE_SIZE_US5x7 = 10;

  HPDF_PAGE_SIZE_COMM10 = 11;

  HPDF_PAGE_SIZE_EOF = 12;

  HPDF_PAGE_PORTRAIT = 0;

  HPDF_PAGE_LANDSCAPE = 1;

  this['HPDF'] = HPDF;

}).call(this);

